searchData={"items":[{"type":"module","title":"Evision","doc":"","ref":"Evision.html"},{"type":"function","title":"Evision.absdiff/1","doc":"","ref":"Evision.html#absdiff/1"},{"type":"function","title":"Evision.absdiff/2","doc":"Calculates the per-element absolute difference between two arrays or between an array and a scalar.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array or a scalar.\n\n- **src2**: `Evision.Mat`.\n\n  second input array or a scalar.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array that has the same size and type as input arrays.\n\nThe function cv::absdiff calculates:\n   Absolute difference between two arrays when they have the same\nsize and type:\n\\f[\\texttt{dst}(I) =  \\texttt{saturate} (| \\texttt{src1}(I) -  \\texttt{src2}(I)|)\\f]\n   Absolute difference between an array and a scalar when the second\narray is constructed from Scalar or has as many elements as the\nnumber of channels in `src1`:\n\\f[\\texttt{dst}(I) =  \\texttt{saturate} (| \\texttt{src1}(I) -  \\texttt{src2} |)\\f]\n   Absolute difference between a scalar and an array when the first\narray is constructed from Scalar or has as many elements as the\nnumber of channels in `src2`:\n\\f[\\texttt{dst}(I) =  \\texttt{saturate} (| \\texttt{src1} -  \\texttt{src2}(I) |)\\f]\nwhere I is a multi-dimensional index of array elements. In case of\nmulti-channel arrays, each channel is processed independently.\n**Note**: Saturation is not applied when the arrays have the depth CV_32S.\nYou may even get a negative value in the case of overflow.\n**Note**: (Python) Be careful to difference behaviour between src1/src2 are single number and they are tuple/array.\n`absdiff(src,X)` means `absdiff(src,(X,X,X,X))`.\n`absdiff(src,(X,))` means `absdiff(src,(X,0,0,0))`.\n@sa cv::abs(const Mat&)\n\nPython prototype (for reference only):\n```python3\nabsdiff(src1, src2[, dst]) -> dst\n```","ref":"Evision.html#absdiff/2"},{"type":"function","title":"Evision.absdiff/3","doc":"Calculates the per-element absolute difference between two arrays or between an array and a scalar.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array or a scalar.\n\n- **src2**: `Evision.Mat`.\n\n  second input array or a scalar.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array that has the same size and type as input arrays.\n\nThe function cv::absdiff calculates:\n   Absolute difference between two arrays when they have the same\nsize and type:\n\\f[\\texttt{dst}(I) =  \\texttt{saturate} (| \\texttt{src1}(I) -  \\texttt{src2}(I)|)\\f]\n   Absolute difference between an array and a scalar when the second\narray is constructed from Scalar or has as many elements as the\nnumber of channels in `src1`:\n\\f[\\texttt{dst}(I) =  \\texttt{saturate} (| \\texttt{src1}(I) -  \\texttt{src2} |)\\f]\n   Absolute difference between a scalar and an array when the first\narray is constructed from Scalar or has as many elements as the\nnumber of channels in `src2`:\n\\f[\\texttt{dst}(I) =  \\texttt{saturate} (| \\texttt{src1} -  \\texttt{src2}(I) |)\\f]\nwhere I is a multi-dimensional index of array elements. In case of\nmulti-channel arrays, each channel is processed independently.\n**Note**: Saturation is not applied when the arrays have the depth CV_32S.\nYou may even get a negative value in the case of overflow.\n**Note**: (Python) Be careful to difference behaviour between src1/src2 are single number and they are tuple/array.\n`absdiff(src,X)` means `absdiff(src,(X,X,X,X))`.\n`absdiff(src,(X,))` means `absdiff(src,(X,0,0,0))`.\n@sa cv::abs(const Mat&)\n\nPython prototype (for reference only):\n```python3\nabsdiff(src1, src2[, dst]) -> dst\n```","ref":"Evision.html#absdiff/3"},{"type":"function","title":"Evision.accumulate/1","doc":"","ref":"Evision.html#accumulate/1"},{"type":"function","title":"Evision.accumulate/2","doc":"Adds an image to the accumulator image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input image of type CV_8UC(n), CV_16UC(n), CV_32FC(n) or CV_64FC(n), where n is a positive integer.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional operation mask.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  %Accumulator image with the same number of channels as input image, and a depth of CV_32F or CV_64F.\n\nThe function adds src or some of its elements to dst :\n\\f[\\texttt{dst} (x,y)  \\leftarrow \\texttt{dst} (x,y) +  \\texttt{src} (x,y)  \\quad \\text{if} \\quad \\texttt{mask} (x,y)  \\ne 0\\f]\nThe function supports multi-channel images. Each channel is processed independently.\nThe function cv::accumulate can be used, for example, to collect statistics of a scene background\nviewed by a still camera and for the further foreground-background segmentation.\n\n@sa  accumulateSquare, accumulateProduct, accumulateWeighted\n\nPython prototype (for reference only):\n```python3\naccumulate(src, dst[, mask]) -> dst\n```","ref":"Evision.html#accumulate/2"},{"type":"function","title":"Evision.accumulate/3","doc":"Adds an image to the accumulator image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input image of type CV_8UC(n), CV_16UC(n), CV_32FC(n) or CV_64FC(n), where n is a positive integer.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional operation mask.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  %Accumulator image with the same number of channels as input image, and a depth of CV_32F or CV_64F.\n\nThe function adds src or some of its elements to dst :\n\\f[\\texttt{dst} (x,y)  \\leftarrow \\texttt{dst} (x,y) +  \\texttt{src} (x,y)  \\quad \\text{if} \\quad \\texttt{mask} (x,y)  \\ne 0\\f]\nThe function supports multi-channel images. Each channel is processed independently.\nThe function cv::accumulate can be used, for example, to collect statistics of a scene background\nviewed by a still camera and for the further foreground-background segmentation.\n\n@sa  accumulateSquare, accumulateProduct, accumulateWeighted\n\nPython prototype (for reference only):\n```python3\naccumulate(src, dst[, mask]) -> dst\n```","ref":"Evision.html#accumulate/3"},{"type":"function","title":"Evision.accumulateProduct/1","doc":"","ref":"Evision.html#accumulateProduct/1"},{"type":"function","title":"Evision.accumulateProduct/3","doc":"Adds the per-element product of two input images to the accumulator image.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First input image, 1- or 3-channel, 8-bit or 32-bit floating point.\n\n- **src2**: `Evision.Mat`.\n\n  Second input image of the same type and the same size as src1 .\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional operation mask.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  %Accumulator image with the same number of channels as input images, 32-bit or 64-bit\n  floating-point.\n\nThe function adds the product of two images or their selected regions to the accumulator dst :\n\\f[\\texttt{dst} (x,y)  \\leftarrow \\texttt{dst} (x,y) +  \\texttt{src1} (x,y)  \\cdot \\texttt{src2} (x,y)  \\quad \\text{if} \\quad \\texttt{mask} (x,y)  \\ne 0\\f]\nThe function supports multi-channel images. Each channel is processed independently.\n\n@sa  accumulate, accumulateSquare, accumulateWeighted\n\nPython prototype (for reference only):\n```python3\naccumulateProduct(src1, src2, dst[, mask]) -> dst\n```","ref":"Evision.html#accumulateProduct/3"},{"type":"function","title":"Evision.accumulateProduct/4","doc":"Adds the per-element product of two input images to the accumulator image.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First input image, 1- or 3-channel, 8-bit or 32-bit floating point.\n\n- **src2**: `Evision.Mat`.\n\n  Second input image of the same type and the same size as src1 .\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional operation mask.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  %Accumulator image with the same number of channels as input images, 32-bit or 64-bit\n  floating-point.\n\nThe function adds the product of two images or their selected regions to the accumulator dst :\n\\f[\\texttt{dst} (x,y)  \\leftarrow \\texttt{dst} (x,y) +  \\texttt{src1} (x,y)  \\cdot \\texttt{src2} (x,y)  \\quad \\text{if} \\quad \\texttt{mask} (x,y)  \\ne 0\\f]\nThe function supports multi-channel images. Each channel is processed independently.\n\n@sa  accumulate, accumulateSquare, accumulateWeighted\n\nPython prototype (for reference only):\n```python3\naccumulateProduct(src1, src2, dst[, mask]) -> dst\n```","ref":"Evision.html#accumulateProduct/4"},{"type":"function","title":"Evision.accumulateSquare/1","doc":"","ref":"Evision.html#accumulateSquare/1"},{"type":"function","title":"Evision.accumulateSquare/2","doc":"Adds the square of a source image to the accumulator image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input image as 1- or 3-channel, 8-bit or 32-bit floating point.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional operation mask.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  %Accumulator image with the same number of channels as input image, 32-bit or 64-bit\n  floating-point.\n\nThe function adds the input image src or its selected region, raised to a power of 2, to the\naccumulator dst :\n\\f[\\texttt{dst} (x,y)  \\leftarrow \\texttt{dst} (x,y) +  \\texttt{src} (x,y)^2  \\quad \\text{if} \\quad \\texttt{mask} (x,y)  \\ne 0\\f]\nThe function supports multi-channel images. Each channel is processed independently.\n\n@sa  accumulateSquare, accumulateProduct, accumulateWeighted\n\nPython prototype (for reference only):\n```python3\naccumulateSquare(src, dst[, mask]) -> dst\n```","ref":"Evision.html#accumulateSquare/2"},{"type":"function","title":"Evision.accumulateSquare/3","doc":"Adds the square of a source image to the accumulator image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input image as 1- or 3-channel, 8-bit or 32-bit floating point.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional operation mask.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  %Accumulator image with the same number of channels as input image, 32-bit or 64-bit\n  floating-point.\n\nThe function adds the input image src or its selected region, raised to a power of 2, to the\naccumulator dst :\n\\f[\\texttt{dst} (x,y)  \\leftarrow \\texttt{dst} (x,y) +  \\texttt{src} (x,y)^2  \\quad \\text{if} \\quad \\texttt{mask} (x,y)  \\ne 0\\f]\nThe function supports multi-channel images. Each channel is processed independently.\n\n@sa  accumulateSquare, accumulateProduct, accumulateWeighted\n\nPython prototype (for reference only):\n```python3\naccumulateSquare(src, dst[, mask]) -> dst\n```","ref":"Evision.html#accumulateSquare/3"},{"type":"function","title":"Evision.accumulateWeighted/1","doc":"","ref":"Evision.html#accumulateWeighted/1"},{"type":"function","title":"Evision.accumulateWeighted/3","doc":"Updates a running average.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input image as 1- or 3-channel, 8-bit or 32-bit floating point.\n\n- **alpha**: `double`.\n\n  Weight of the input image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional operation mask.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  %Accumulator image with the same number of channels as input image, 32-bit or 64-bit\n  floating-point.\n\nThe function calculates the weighted sum of the input image src and the accumulator dst so that dst\nbecomes a running average of a frame sequence:\n\\f[\\texttt{dst} (x,y)  \\leftarrow (1- \\texttt{alpha} )  \\cdot \\texttt{dst} (x,y) +  \\texttt{alpha} \\cdot \\texttt{src} (x,y)  \\quad \\text{if} \\quad \\texttt{mask} (x,y)  \\ne 0\\f]\nThat is, alpha regulates the update speed (how fast the accumulator \"forgets\" about earlier images).\nThe function supports multi-channel images. Each channel is processed independently.\n\n@sa  accumulate, accumulateSquare, accumulateProduct\n\nPython prototype (for reference only):\n```python3\naccumulateWeighted(src, dst, alpha[, mask]) -> dst\n```","ref":"Evision.html#accumulateWeighted/3"},{"type":"function","title":"Evision.accumulateWeighted/4","doc":"Updates a running average.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input image as 1- or 3-channel, 8-bit or 32-bit floating point.\n\n- **alpha**: `double`.\n\n  Weight of the input image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional operation mask.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  %Accumulator image with the same number of channels as input image, 32-bit or 64-bit\n  floating-point.\n\nThe function calculates the weighted sum of the input image src and the accumulator dst so that dst\nbecomes a running average of a frame sequence:\n\\f[\\texttt{dst} (x,y)  \\leftarrow (1- \\texttt{alpha} )  \\cdot \\texttt{dst} (x,y) +  \\texttt{alpha} \\cdot \\texttt{src} (x,y)  \\quad \\text{if} \\quad \\texttt{mask} (x,y)  \\ne 0\\f]\nThat is, alpha regulates the update speed (how fast the accumulator \"forgets\" about earlier images).\nThe function supports multi-channel images. Each channel is processed independently.\n\n@sa  accumulate, accumulateSquare, accumulateProduct\n\nPython prototype (for reference only):\n```python3\naccumulateWeighted(src, dst, alpha[, mask]) -> dst\n```","ref":"Evision.html#accumulateWeighted/4"},{"type":"function","title":"Evision.adaptiveThreshold/1","doc":"","ref":"Evision.html#adaptiveThreshold/1"},{"type":"function","title":"Evision.adaptiveThreshold/6","doc":"Applies an adaptive threshold to an array.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source 8-bit single-channel image.\n\n- **maxValue**: `double`.\n\n  Non-zero value assigned to the pixels for which the condition is satisfied\n\n- **adaptiveMethod**: `integer()`.\n\n  Adaptive thresholding algorithm to use, see #AdaptiveThresholdTypes.\n  The #BORDER_REPLICATE | #BORDER_ISOLATED is used to process boundaries.\n\n- **thresholdType**: `integer()`.\n\n  Thresholding type that must be either #THRESH_BINARY or #THRESH_BINARY_INV,\n  see #ThresholdTypes.\n\n- **blockSize**: `integer()`.\n\n  Size of a pixel neighborhood that is used to calculate a threshold value for the\n  pixel: 3, 5, 7, and so on.\n\n- **c**: `double`.\n\n  Constant subtracted from the mean or weighted mean (see the details below). Normally, it\n  is positive but may be zero or negative as well.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and the same type as src.\n\nThe function transforms a grayscale image to a binary image according to the formulae:\n- **THRESH_BINARY**\n  \\f[dst(x,y) =  \\fork{\\texttt{maxValue}}{if \\(src(x,y) > T(x,y)\\)}{0}{otherwise}\\f]\n\n- **THRESH_BINARY_INV**\n  \\f[dst(x,y) =  \\fork{0}{if \\(src(x,y) > T(x,y)\\)}{\\texttt{maxValue}}{otherwise}\\f]\n  where \\f$T(x,y)\\f$ is a threshold calculated individually for each pixel (see adaptiveMethod parameter).\n\nThe function can process the image in-place.\n\n@sa  threshold, blur, GaussianBlur\n\nPython prototype (for reference only):\n```python3\nadaptiveThreshold(src, maxValue, adaptiveMethod, thresholdType, blockSize, C[, dst]) -> dst\n```","ref":"Evision.html#adaptiveThreshold/6"},{"type":"function","title":"Evision.adaptiveThreshold/7","doc":"Applies an adaptive threshold to an array.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source 8-bit single-channel image.\n\n- **maxValue**: `double`.\n\n  Non-zero value assigned to the pixels for which the condition is satisfied\n\n- **adaptiveMethod**: `integer()`.\n\n  Adaptive thresholding algorithm to use, see #AdaptiveThresholdTypes.\n  The #BORDER_REPLICATE | #BORDER_ISOLATED is used to process boundaries.\n\n- **thresholdType**: `integer()`.\n\n  Thresholding type that must be either #THRESH_BINARY or #THRESH_BINARY_INV,\n  see #ThresholdTypes.\n\n- **blockSize**: `integer()`.\n\n  Size of a pixel neighborhood that is used to calculate a threshold value for the\n  pixel: 3, 5, 7, and so on.\n\n- **c**: `double`.\n\n  Constant subtracted from the mean or weighted mean (see the details below). Normally, it\n  is positive but may be zero or negative as well.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and the same type as src.\n\nThe function transforms a grayscale image to a binary image according to the formulae:\n- **THRESH_BINARY**\n  \\f[dst(x,y) =  \\fork{\\texttt{maxValue}}{if \\(src(x,y) > T(x,y)\\)}{0}{otherwise}\\f]\n\n- **THRESH_BINARY_INV**\n  \\f[dst(x,y) =  \\fork{0}{if \\(src(x,y) > T(x,y)\\)}{\\texttt{maxValue}}{otherwise}\\f]\n  where \\f$T(x,y)\\f$ is a threshold calculated individually for each pixel (see adaptiveMethod parameter).\n\nThe function can process the image in-place.\n\n@sa  threshold, blur, GaussianBlur\n\nPython prototype (for reference only):\n```python3\nadaptiveThreshold(src, maxValue, adaptiveMethod, thresholdType, blockSize, C[, dst]) -> dst\n```","ref":"Evision.html#adaptiveThreshold/7"},{"type":"function","title":"Evision.add/1","doc":"","ref":"Evision.html#add/1"},{"type":"function","title":"Evision.add/2","doc":"Calculates the per-element sum of two arrays or an array and a scalar.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array or a scalar.\n\n- **src2**: `Evision.Mat`.\n\n  second input array or a scalar.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  optional operation mask - 8-bit single channel array, that specifies elements of the\n  output array to be changed.\n\n- **dtype**: `integer()`.\n\n  optional depth of the output array (see the discussion below).\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array that has the same size and number of channels as the input array(s); the\n  depth is defined by dtype or src1/src2.\n\nThe function add calculates:\n- Sum of two arrays when both input arrays have the same size and the same number of channels:\n  \\f[\\texttt{dst}(I) =  \\texttt{saturate} ( \\texttt{src1}(I) +  \\texttt{src2}(I)) \\quad \\texttt{if mask}(I) \\ne0\\f]\n\n- Sum of an array and a scalar when src2 is constructed from Scalar or has the same number of\n  elements as `src1.channels()`:\n  \\f[\\texttt{dst}(I) =  \\texttt{saturate} ( \\texttt{src1}(I) +  \\texttt{src2} ) \\quad \\texttt{if mask}(I) \\ne0\\f]\n\n- Sum of a scalar and an array when src1 is constructed from Scalar or has the same number of\n  elements as `src2.channels()`:\n  \\f[\\texttt{dst}(I) =  \\texttt{saturate} ( \\texttt{src1} +  \\texttt{src2}(I) ) \\quad \\texttt{if mask}(I) \\ne0\\f]\n  where `I` is a multi-dimensional index of array elements. In case of multi-channel arrays, each\n  channel is processed independently.\n\nThe first function in the list above can be replaced with matrix expressions:\n```cpp\ndst = src1 + src2;\ndst += src1; // equivalent to add(dst, src1, dst);\n```\nThe input arrays and the output array can all have the same or different depths. For example, you\ncan add a 16-bit unsigned array to a 8-bit signed array and store the sum as a 32-bit\nfloating-point array. Depth of the output array is determined by the dtype parameter. In the second\nand third cases above, as well as in the first case, when src1.depth() == src2.depth(), dtype can\nbe set to the default -1. In this case, the output array will have the same depth as the input\narray, be it src1, src2 or both.\n**Note**: Saturation is not applied when the output array has the depth CV_32S. You may even get\nresult of an incorrect sign in the case of overflow.\n**Note**: (Python) Be careful to difference behaviour between src1/src2 are single number and they are tuple/array.\n`add(src,X)` means `add(src,(X,X,X,X))`.\n`add(src,(X,))` means `add(src,(X,0,0,0))`.\n@sa subtract, addWeighted, scaleAdd, Mat::convertTo\n\nPython prototype (for reference only):\n```python3\nadd(src1, src2[, dst[, mask[, dtype]]]) -> dst\n```","ref":"Evision.html#add/2"},{"type":"function","title":"Evision.add/3","doc":"Calculates the per-element sum of two arrays or an array and a scalar.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array or a scalar.\n\n- **src2**: `Evision.Mat`.\n\n  second input array or a scalar.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  optional operation mask - 8-bit single channel array, that specifies elements of the\n  output array to be changed.\n\n- **dtype**: `integer()`.\n\n  optional depth of the output array (see the discussion below).\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array that has the same size and number of channels as the input array(s); the\n  depth is defined by dtype or src1/src2.\n\nThe function add calculates:\n- Sum of two arrays when both input arrays have the same size and the same number of channels:\n  \\f[\\texttt{dst}(I) =  \\texttt{saturate} ( \\texttt{src1}(I) +  \\texttt{src2}(I)) \\quad \\texttt{if mask}(I) \\ne0\\f]\n\n- Sum of an array and a scalar when src2 is constructed from Scalar or has the same number of\n  elements as `src1.channels()`:\n  \\f[\\texttt{dst}(I) =  \\texttt{saturate} ( \\texttt{src1}(I) +  \\texttt{src2} ) \\quad \\texttt{if mask}(I) \\ne0\\f]\n\n- Sum of a scalar and an array when src1 is constructed from Scalar or has the same number of\n  elements as `src2.channels()`:\n  \\f[\\texttt{dst}(I) =  \\texttt{saturate} ( \\texttt{src1} +  \\texttt{src2}(I) ) \\quad \\texttt{if mask}(I) \\ne0\\f]\n  where `I` is a multi-dimensional index of array elements. In case of multi-channel arrays, each\n  channel is processed independently.\n\nThe first function in the list above can be replaced with matrix expressions:\n```cpp\ndst = src1 + src2;\ndst += src1; // equivalent to add(dst, src1, dst);\n```\nThe input arrays and the output array can all have the same or different depths. For example, you\ncan add a 16-bit unsigned array to a 8-bit signed array and store the sum as a 32-bit\nfloating-point array. Depth of the output array is determined by the dtype parameter. In the second\nand third cases above, as well as in the first case, when src1.depth() == src2.depth(), dtype can\nbe set to the default -1. In this case, the output array will have the same depth as the input\narray, be it src1, src2 or both.\n**Note**: Saturation is not applied when the output array has the depth CV_32S. You may even get\nresult of an incorrect sign in the case of overflow.\n**Note**: (Python) Be careful to difference behaviour between src1/src2 are single number and they are tuple/array.\n`add(src,X)` means `add(src,(X,X,X,X))`.\n`add(src,(X,))` means `add(src,(X,0,0,0))`.\n@sa subtract, addWeighted, scaleAdd, Mat::convertTo\n\nPython prototype (for reference only):\n```python3\nadd(src1, src2[, dst[, mask[, dtype]]]) -> dst\n```","ref":"Evision.html#add/3"},{"type":"function","title":"Evision.addText/1","doc":"","ref":"Evision.html#addText/1"},{"type":"function","title":"Evision.addText/4","doc":"Draws a text on the image.\n\n##### Positional Arguments\n- **img**: `Evision.Mat`.\n\n  8-bit 3-channel image where the text should be drawn.\n\n- **text**: `String`.\n\n  Text to write on an image.\n\n- **org**: `Point`.\n\n  Point(x,y) where the text should start on an image.\n\n- **nameFont**: `String`.\n\n  Name of the font. The name should match the name of a system font (such as\n  Times*). If the font is not found, a default one is used.\n\n##### Keyword Arguments\n- **pointSize**: `integer()`.\n\n  Size of the font. If not specified, equal zero or negative, the point size of the\n  font is set to a system-dependent default value. Generally, this is 12 points.\n\n- **color**: `Evision.scalar()`.\n\n  Color of the font in BGRA where A = 255 is fully transparent.\n\n- **weight**: `integer()`.\n\n  Font weight. Available operation flags are : cv::QtFontWeights You can also specify a positive integer for better control.\n\n- **style**: `integer()`.\n\n  Font style. Available operation flags are : cv::QtFontStyles\n\n- **spacing**: `integer()`.\n\n  Spacing between characters. It can be negative or positive.\n\nPython prototype (for reference only):\n```python3\naddText(img, text, org, nameFont[, pointSize[, color[, weight[, style[, spacing]]]]]) -> None\n```","ref":"Evision.html#addText/4"},{"type":"function","title":"Evision.addText/5","doc":"Draws a text on the image.\n\n##### Positional Arguments\n- **img**: `Evision.Mat`.\n\n  8-bit 3-channel image where the text should be drawn.\n\n- **text**: `String`.\n\n  Text to write on an image.\n\n- **org**: `Point`.\n\n  Point(x,y) where the text should start on an image.\n\n- **nameFont**: `String`.\n\n  Name of the font. The name should match the name of a system font (such as\n  Times*). If the font is not found, a default one is used.\n\n##### Keyword Arguments\n- **pointSize**: `integer()`.\n\n  Size of the font. If not specified, equal zero or negative, the point size of the\n  font is set to a system-dependent default value. Generally, this is 12 points.\n\n- **color**: `Evision.scalar()`.\n\n  Color of the font in BGRA where A = 255 is fully transparent.\n\n- **weight**: `integer()`.\n\n  Font weight. Available operation flags are : cv::QtFontWeights You can also specify a positive integer for better control.\n\n- **style**: `integer()`.\n\n  Font style. Available operation flags are : cv::QtFontStyles\n\n- **spacing**: `integer()`.\n\n  Spacing between characters. It can be negative or positive.\n\nPython prototype (for reference only):\n```python3\naddText(img, text, org, nameFont[, pointSize[, color[, weight[, style[, spacing]]]]]) -> None\n```","ref":"Evision.html#addText/5"},{"type":"function","title":"Evision.addWeighted/1","doc":"","ref":"Evision.html#addWeighted/1"},{"type":"function","title":"Evision.addWeighted/5","doc":"Calculates the weighted sum of two arrays.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array.\n\n- **alpha**: `double`.\n\n  weight of the first array elements.\n\n- **src2**: `Evision.Mat`.\n\n  second input array of the same size and channel number as src1.\n\n- **beta**: `double`.\n\n  weight of the second array elements.\n\n- **gamma**: `double`.\n\n  scalar added to each sum.\n\n##### Keyword Arguments\n- **dtype**: `integer()`.\n\n  optional depth of the output array; when both input arrays have the same depth, dtype\n  can be set to -1, which will be equivalent to src1.depth().\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array that has the same size and number of channels as the input arrays.\n\nThe function addWeighted calculates the weighted sum of two arrays as follows:\n\\f[\\texttt{dst} (I)= \\texttt{saturate} ( \\texttt{src1} (I)\\* \\texttt{alpha} +  \\texttt{src2} (I)\\* \\texttt{beta} +  \\texttt{gamma} )\\f]\nwhere I is a multi-dimensional index of array elements. In case of multi-channel arrays, each\nchannel is processed independently.\nThe function can be replaced with a matrix expression:\n```cpp\ndst = src1*alpha + src2*beta + gamma;\n```\n**Note**: Saturation is not applied when the output array has the depth CV_32S. You may even get\nresult of an incorrect sign in the case of overflow.\n@sa  add, subtract, scaleAdd, Mat::convertTo\n\nPython prototype (for reference only):\n```python3\naddWeighted(src1, alpha, src2, beta, gamma[, dst[, dtype]]) -> dst\n```","ref":"Evision.html#addWeighted/5"},{"type":"function","title":"Evision.addWeighted/6","doc":"Calculates the weighted sum of two arrays.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array.\n\n- **alpha**: `double`.\n\n  weight of the first array elements.\n\n- **src2**: `Evision.Mat`.\n\n  second input array of the same size and channel number as src1.\n\n- **beta**: `double`.\n\n  weight of the second array elements.\n\n- **gamma**: `double`.\n\n  scalar added to each sum.\n\n##### Keyword Arguments\n- **dtype**: `integer()`.\n\n  optional depth of the output array; when both input arrays have the same depth, dtype\n  can be set to -1, which will be equivalent to src1.depth().\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array that has the same size and number of channels as the input arrays.\n\nThe function addWeighted calculates the weighted sum of two arrays as follows:\n\\f[\\texttt{dst} (I)= \\texttt{saturate} ( \\texttt{src1} (I)\\* \\texttt{alpha} +  \\texttt{src2} (I)\\* \\texttt{beta} +  \\texttt{gamma} )\\f]\nwhere I is a multi-dimensional index of array elements. In case of multi-channel arrays, each\nchannel is processed independently.\nThe function can be replaced with a matrix expression:\n```cpp\ndst = src1*alpha + src2*beta + gamma;\n```\n**Note**: Saturation is not applied when the output array has the depth CV_32S. You may even get\nresult of an incorrect sign in the case of overflow.\n@sa  add, subtract, scaleAdd, Mat::convertTo\n\nPython prototype (for reference only):\n```python3\naddWeighted(src1, alpha, src2, beta, gamma[, dst[, dtype]]) -> dst\n```","ref":"Evision.html#addWeighted/6"},{"type":"function","title":"Evision.applyColorMap/1","doc":"","ref":"Evision.html#applyColorMap/1"},{"type":"function","title":"Evision.applyColorMap/2","doc":"#### Variant 1:\nApplies a user colormap on a given image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  The source image, grayscale or colored of type CV_8UC1 or CV_8UC3. If CV_8UC3, then the CV_8UC1 image is generated internally using cv::COLOR_BGR2GRAY.\n\n- **userColor**: `Evision.Mat`.\n\n  The colormap to apply of type CV_8UC1 or CV_8UC3 and size 256\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  The result is the colormapped source image of the same number of channels as userColor. Note: Mat::create is called on dst.\n\nPython prototype (for reference only):\n```python3\napplyColorMap(src, userColor[, dst]) -> dst\n```\n#### Variant 2:\nApplies a GNU Octave/MATLAB equivalent colormap on a given image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  The source image, grayscale or colored of type CV_8UC1 or CV_8UC3. If CV_8UC3, then the CV_8UC1 image is generated internally using cv::COLOR_BGR2GRAY.\n\n- **colormap**: `integer()`.\n\n  The colormap to apply, see #ColormapTypes\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  The result is the colormapped source image. Note: Mat::create is called on dst.\n\nPython prototype (for reference only):\n```python3\napplyColorMap(src, colormap[, dst]) -> dst\n```","ref":"Evision.html#applyColorMap/2"},{"type":"function","title":"Evision.applyColorMap/3","doc":"#### Variant 1:\nApplies a user colormap on a given image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  The source image, grayscale or colored of type CV_8UC1 or CV_8UC3. If CV_8UC3, then the CV_8UC1 image is generated internally using cv::COLOR_BGR2GRAY.\n\n- **userColor**: `Evision.Mat`.\n\n  The colormap to apply of type CV_8UC1 or CV_8UC3 and size 256\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  The result is the colormapped source image of the same number of channels as userColor. Note: Mat::create is called on dst.\n\nPython prototype (for reference only):\n```python3\napplyColorMap(src, userColor[, dst]) -> dst\n```\n#### Variant 2:\nApplies a GNU Octave/MATLAB equivalent colormap on a given image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  The source image, grayscale or colored of type CV_8UC1 or CV_8UC3. If CV_8UC3, then the CV_8UC1 image is generated internally using cv::COLOR_BGR2GRAY.\n\n- **colormap**: `integer()`.\n\n  The colormap to apply, see #ColormapTypes\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  The result is the colormapped source image. Note: Mat::create is called on dst.\n\nPython prototype (for reference only):\n```python3\napplyColorMap(src, colormap[, dst]) -> dst\n```","ref":"Evision.html#applyColorMap/3"},{"type":"function","title":"Evision.approxPolyDP/1","doc":"","ref":"Evision.html#approxPolyDP/1"},{"type":"function","title":"Evision.approxPolyDP/3","doc":"Approximates a polygonal curve(s) with the specified precision.\n\n##### Positional Arguments\n- **curve**: `Evision.Mat`.\n\n  Input vector of a 2D point stored in std::vector or Mat\n\n- **epsilon**: `double`.\n\n  Parameter specifying the approximation accuracy. This is the maximum distance\n  between the original curve and its approximation.\n\n- **closed**: `bool`.\n\n  If true, the approximated curve is closed (its first and last vertices are\n  connected). Otherwise, it is not closed.\n\n##### Return\n- **approxCurve**: `Evision.Mat.t()`.\n\n  Result of the approximation. The type should match the type of the input curve.\n\nThe function cv::approxPolyDP approximates a curve or a polygon with another curve/polygon with less\nvertices so that the distance between them is less or equal to the specified precision. It uses the\nDouglas-Peucker algorithm  \n\nPython prototype (for reference only):\n```python3\napproxPolyDP(curve, epsilon, closed[, approxCurve]) -> approxCurve\n```","ref":"Evision.html#approxPolyDP/3"},{"type":"function","title":"Evision.approxPolyDP/4","doc":"Approximates a polygonal curve(s) with the specified precision.\n\n##### Positional Arguments\n- **curve**: `Evision.Mat`.\n\n  Input vector of a 2D point stored in std::vector or Mat\n\n- **epsilon**: `double`.\n\n  Parameter specifying the approximation accuracy. This is the maximum distance\n  between the original curve and its approximation.\n\n- **closed**: `bool`.\n\n  If true, the approximated curve is closed (its first and last vertices are\n  connected). Otherwise, it is not closed.\n\n##### Return\n- **approxCurve**: `Evision.Mat.t()`.\n\n  Result of the approximation. The type should match the type of the input curve.\n\nThe function cv::approxPolyDP approximates a curve or a polygon with another curve/polygon with less\nvertices so that the distance between them is less or equal to the specified precision. It uses the\nDouglas-Peucker algorithm  \n\nPython prototype (for reference only):\n```python3\napproxPolyDP(curve, epsilon, closed[, approxCurve]) -> approxCurve\n```","ref":"Evision.html#approxPolyDP/4"},{"type":"function","title":"Evision.arcLength/1","doc":"","ref":"Evision.html#arcLength/1"},{"type":"function","title":"Evision.arcLength/2","doc":"Calculates a contour perimeter or a curve length.\n\n##### Positional Arguments\n- **curve**: `Evision.Mat`.\n\n  Input vector of 2D points, stored in std::vector or Mat.\n\n- **closed**: `bool`.\n\n  Flag indicating whether the curve is closed or not.\n\n##### Return\n- **retval**: `double`\n\nThe function computes a curve length or a closed contour perimeter.\n\nPython prototype (for reference only):\n```python3\narcLength(curve, closed) -> retval\n```","ref":"Evision.html#arcLength/2"},{"type":"function","title":"Evision.arrowedLine/1","doc":"","ref":"Evision.html#arrowedLine/1"},{"type":"function","title":"Evision.arrowedLine/4","doc":"Draws an arrow segment pointing from the first point to the second one.\n\n##### Positional Arguments\n- **pt1**: `Point`.\n\n  The point the arrow starts from.\n\n- **pt2**: `Point`.\n\n  The point the arrow points to.\n\n- **color**: `Evision.scalar()`.\n\n  Line color.\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n\n  Line thickness.\n\n- **line_type**: `integer()`.\n\n  Type of the line. See #LineTypes\n\n- **shift**: `integer()`.\n\n  Number of fractional bits in the point coordinates.\n\n- **tipLength**: `double`.\n\n  The length of the arrow tip in relation to the arrow length\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  Image.\n\nThe function cv::arrowedLine draws an arrow between pt1 and pt2 points in the image. See also #line.\n\nPython prototype (for reference only):\n```python3\narrowedLine(img, pt1, pt2, color[, thickness[, line_type[, shift[, tipLength]]]]) -> img\n```","ref":"Evision.html#arrowedLine/4"},{"type":"function","title":"Evision.arrowedLine/5","doc":"Draws an arrow segment pointing from the first point to the second one.\n\n##### Positional Arguments\n- **pt1**: `Point`.\n\n  The point the arrow starts from.\n\n- **pt2**: `Point`.\n\n  The point the arrow points to.\n\n- **color**: `Evision.scalar()`.\n\n  Line color.\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n\n  Line thickness.\n\n- **line_type**: `integer()`.\n\n  Type of the line. See #LineTypes\n\n- **shift**: `integer()`.\n\n  Number of fractional bits in the point coordinates.\n\n- **tipLength**: `double`.\n\n  The length of the arrow tip in relation to the arrow length\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  Image.\n\nThe function cv::arrowedLine draws an arrow between pt1 and pt2 points in the image. See also #line.\n\nPython prototype (for reference only):\n```python3\narrowedLine(img, pt1, pt2, color[, thickness[, line_type[, shift[, tipLength]]]]) -> img\n```","ref":"Evision.html#arrowedLine/5"},{"type":"function","title":"Evision.batchDistance/1","doc":"","ref":"Evision.html#batchDistance/1"},{"type":"function","title":"Evision.batchDistance/3","doc":"naive nearest neighbor finder\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`\n- **src2**: `Evision.Mat`\n- **dtype**: `integer()`\n\n##### Keyword Arguments\n- **normType**: `integer()`.\n- **k**: `integer()`.\n- **mask**: `Evision.Mat`.\n- **update**: `integer()`.\n- **crosscheck**: `bool`.\n\n##### Return\n- **dist**: `Evision.Mat.t()`.\n- **nidx**: `Evision.Mat.t()`.\n\nsee http://en.wikipedia.org/wiki/Nearest_neighbor_search\n@todo document\n\nPython prototype (for reference only):\n```python3\nbatchDistance(src1, src2, dtype[, dist[, nidx[, normType[, K[, mask[, update[, crosscheck]]]]]]]) -> dist, nidx\n```","ref":"Evision.html#batchDistance/3"},{"type":"function","title":"Evision.batchDistance/4","doc":"naive nearest neighbor finder\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`\n- **src2**: `Evision.Mat`\n- **dtype**: `integer()`\n\n##### Keyword Arguments\n- **normType**: `integer()`.\n- **k**: `integer()`.\n- **mask**: `Evision.Mat`.\n- **update**: `integer()`.\n- **crosscheck**: `bool`.\n\n##### Return\n- **dist**: `Evision.Mat.t()`.\n- **nidx**: `Evision.Mat.t()`.\n\nsee http://en.wikipedia.org/wiki/Nearest_neighbor_search\n@todo document\n\nPython prototype (for reference only):\n```python3\nbatchDistance(src1, src2, dtype[, dist[, nidx[, normType[, K[, mask[, update[, crosscheck]]]]]]]) -> dist, nidx\n```","ref":"Evision.html#batchDistance/4"},{"type":"function","title":"Evision.bilateralFilter/1","doc":"","ref":"Evision.html#bilateralFilter/1"},{"type":"function","title":"Evision.bilateralFilter/4","doc":"Applies the bilateral filter to an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source 8-bit or floating-point, 1-channel or 3-channel image.\n\n- **d**: `integer()`.\n\n  Diameter of each pixel neighborhood that is used during filtering. If it is non-positive,\n  it is computed from sigmaSpace.\n\n- **sigmaColor**: `double`.\n\n  Filter sigma in the color space. A larger value of the parameter means that\n  farther colors within the pixel neighborhood (see sigmaSpace) will be mixed together, resulting\n  in larger areas of semi-equal color.\n\n- **sigmaSpace**: `double`.\n\n  Filter sigma in the coordinate space. A larger value of the parameter means that\n  farther pixels will influence each other as long as their colors are close enough (see sigmaColor\n  ). When d\\>0, it specifies the neighborhood size regardless of sigmaSpace. Otherwise, d is\n  proportional to sigmaSpace.\n\n##### Keyword Arguments\n- **borderType**: `integer()`.\n\n  border mode used to extrapolate pixels outside of the image, see #BorderTypes\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and type as src .\n\nThe function applies bilateral filtering to the input image, as described in\nhttp://www.dai.ed.ac.uk/CVonline/LOCAL_COPIES/MANDUCHI1/Bilateral_Filtering.html\nbilateralFilter can reduce unwanted noise very well while keeping edges fairly sharp. However, it is\nvery slow compared to most filters.\n_Sigma values_: For simplicity, you can set the 2 sigma values to be the same. If they are small (\\<\n10), the filter will not have much effect, whereas if they are large (\\> 150), they will have a very\nstrong effect, making the image look \"cartoonish\".\n_Filter size_: Large filters (d \\> 5) are very slow, so it is recommended to use d=5 for real-time\napplications, and perhaps d=9 for offline applications that need heavy noise filtering.\nThis filter does not work inplace.\n\nPython prototype (for reference only):\n```python3\nbilateralFilter(src, d, sigmaColor, sigmaSpace[, dst[, borderType]]) -> dst\n```","ref":"Evision.html#bilateralFilter/4"},{"type":"function","title":"Evision.bilateralFilter/5","doc":"Applies the bilateral filter to an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source 8-bit or floating-point, 1-channel or 3-channel image.\n\n- **d**: `integer()`.\n\n  Diameter of each pixel neighborhood that is used during filtering. If it is non-positive,\n  it is computed from sigmaSpace.\n\n- **sigmaColor**: `double`.\n\n  Filter sigma in the color space. A larger value of the parameter means that\n  farther colors within the pixel neighborhood (see sigmaSpace) will be mixed together, resulting\n  in larger areas of semi-equal color.\n\n- **sigmaSpace**: `double`.\n\n  Filter sigma in the coordinate space. A larger value of the parameter means that\n  farther pixels will influence each other as long as their colors are close enough (see sigmaColor\n  ). When d\\>0, it specifies the neighborhood size regardless of sigmaSpace. Otherwise, d is\n  proportional to sigmaSpace.\n\n##### Keyword Arguments\n- **borderType**: `integer()`.\n\n  border mode used to extrapolate pixels outside of the image, see #BorderTypes\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and type as src .\n\nThe function applies bilateral filtering to the input image, as described in\nhttp://www.dai.ed.ac.uk/CVonline/LOCAL_COPIES/MANDUCHI1/Bilateral_Filtering.html\nbilateralFilter can reduce unwanted noise very well while keeping edges fairly sharp. However, it is\nvery slow compared to most filters.\n_Sigma values_: For simplicity, you can set the 2 sigma values to be the same. If they are small (\\<\n10), the filter will not have much effect, whereas if they are large (\\> 150), they will have a very\nstrong effect, making the image look \"cartoonish\".\n_Filter size_: Large filters (d \\> 5) are very slow, so it is recommended to use d=5 for real-time\napplications, and perhaps d=9 for offline applications that need heavy noise filtering.\nThis filter does not work inplace.\n\nPython prototype (for reference only):\n```python3\nbilateralFilter(src, d, sigmaColor, sigmaSpace[, dst[, borderType]]) -> dst\n```","ref":"Evision.html#bilateralFilter/5"},{"type":"function","title":"Evision.blendLinear/1","doc":"","ref":"Evision.html#blendLinear/1"},{"type":"function","title":"Evision.blendLinear/4","doc":"blendLinear\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`\n- **src2**: `Evision.Mat`\n- **weights1**: `Evision.Mat`\n- **weights2**: `Evision.Mat`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nvariant without `mask` parameter\n\nPython prototype (for reference only):\n```python3\nblendLinear(src1, src2, weights1, weights2[, dst]) -> dst\n```","ref":"Evision.html#blendLinear/4"},{"type":"function","title":"Evision.blendLinear/5","doc":"blendLinear\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`\n- **src2**: `Evision.Mat`\n- **weights1**: `Evision.Mat`\n- **weights2**: `Evision.Mat`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nvariant without `mask` parameter\n\nPython prototype (for reference only):\n```python3\nblendLinear(src1, src2, weights1, weights2[, dst]) -> dst\n```","ref":"Evision.html#blendLinear/5"},{"type":"function","title":"Evision.blur/1","doc":"","ref":"Evision.html#blur/1"},{"type":"function","title":"Evision.blur/2","doc":"Blurs an image using the normalized box filter.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image; it can have any number of channels, which are processed independently, but\n  the depth should be CV_8U, CV_16U, CV_16S, CV_32F or CV_64F.\n\n- **ksize**: `Size`.\n\n  blurring kernel size.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  anchor point; default value Point(-1,-1) means that the anchor is at the kernel\n  center.\n\n- **borderType**: `integer()`.\n\n  border mode used to extrapolate pixels outside of the image, see #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and type as src.\n\nThe function smooths an image using the kernel:\n\\f[\\texttt{K} =  \\frac{1}{\\texttt{ksize.width\\*ksize.height}} \\begin{bmatrix} 1 & 1 & 1 &  \\cdots & 1 & 1  \\\\\\\\ 1 & 1 & 1 &  \\cdots & 1 & 1  \\\\\\\\ \\hdotsfor{6} \\\\\\\\ 1 & 1 & 1 &  \\cdots & 1 & 1  \\\\\\\\ \\end{bmatrix}\\f]\nThe call `blur(src, dst, ksize, anchor, borderType)` is equivalent to `boxFilter(src, dst, src.type(), ksize,\nanchor, true, borderType)`.\n@sa  boxFilter, bilateralFilter, GaussianBlur, medianBlur\n\nPython prototype (for reference only):\n```python3\nblur(src, ksize[, dst[, anchor[, borderType]]]) -> dst\n```","ref":"Evision.html#blur/2"},{"type":"function","title":"Evision.blur/3","doc":"Blurs an image using the normalized box filter.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image; it can have any number of channels, which are processed independently, but\n  the depth should be CV_8U, CV_16U, CV_16S, CV_32F or CV_64F.\n\n- **ksize**: `Size`.\n\n  blurring kernel size.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  anchor point; default value Point(-1,-1) means that the anchor is at the kernel\n  center.\n\n- **borderType**: `integer()`.\n\n  border mode used to extrapolate pixels outside of the image, see #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and type as src.\n\nThe function smooths an image using the kernel:\n\\f[\\texttt{K} =  \\frac{1}{\\texttt{ksize.width\\*ksize.height}} \\begin{bmatrix} 1 & 1 & 1 &  \\cdots & 1 & 1  \\\\\\\\ 1 & 1 & 1 &  \\cdots & 1 & 1  \\\\\\\\ \\hdotsfor{6} \\\\\\\\ 1 & 1 & 1 &  \\cdots & 1 & 1  \\\\\\\\ \\end{bmatrix}\\f]\nThe call `blur(src, dst, ksize, anchor, borderType)` is equivalent to `boxFilter(src, dst, src.type(), ksize,\nanchor, true, borderType)`.\n@sa  boxFilter, bilateralFilter, GaussianBlur, medianBlur\n\nPython prototype (for reference only):\n```python3\nblur(src, ksize[, dst[, anchor[, borderType]]]) -> dst\n```","ref":"Evision.html#blur/3"},{"type":"function","title":"Evision.borderInterpolate/1","doc":"","ref":"Evision.html#borderInterpolate/1"},{"type":"function","title":"Evision.borderInterpolate/3","doc":"Computes the source location of an extrapolated pixel.\n\n##### Positional Arguments\n- **p**: `integer()`.\n\n  0-based coordinate of the extrapolated pixel along one of the axes, likely \\<0 or \\>= len\n\n- **len**: `integer()`.\n\n  Length of the array along the corresponding axis.\n\n- **borderType**: `integer()`.\n\n  Border type, one of the #BorderTypes, except for #BORDER_TRANSPARENT and\n  #BORDER_ISOLATED. When borderType==#BORDER_CONSTANT, the function always returns -1, regardless\n  of p and len.\n\n##### Return\n- **retval**: `integer()`\n\nThe function computes and returns the coordinate of a donor pixel corresponding to the specified\nextrapolated pixel when using the specified extrapolation border mode. For example, if you use\ncv::BORDER_WRAP mode in the horizontal direction, cv::BORDER_REFLECT_101 in the vertical direction and\nwant to compute value of the \"virtual\" pixel Point(-5, 100) in a floating-point image img, it\nlooks like:\n```cpp\nfloat val = img.at (borderInterpolate(100, img.rows, cv::BORDER_REFLECT_101),\nborderInterpolate(-5, img.cols, cv::BORDER_WRAP));\n```\nNormally, the function is not called directly. It is used inside filtering functions and also in\ncopyMakeBorder.\n\n@sa copyMakeBorder\n\nPython prototype (for reference only):\n```python3\nborderInterpolate(p, len, borderType) -> retval\n```","ref":"Evision.html#borderInterpolate/3"},{"type":"function","title":"Evision.boundingRect/1","doc":"Calculates the up-right bounding rectangle of a point set or non-zero pixels of gray-scale image.\n\n##### Positional Arguments\n- **array**: `Evision.Mat`.\n\n  Input gray-scale image or 2D point set, stored in std::vector or Mat.\n\n##### Return\n- **retval**: `Rect`\n\nThe function calculates and returns the minimal up-right bounding rectangle for the specified point set or\nnon-zero pixels of gray-scale image.\n\nPython prototype (for reference only):\n```python3\nboundingRect(array) -> retval\n```","ref":"Evision.html#boundingRect/1"},{"type":"function","title":"Evision.boxFilter/1","doc":"","ref":"Evision.html#boxFilter/1"},{"type":"function","title":"Evision.boxFilter/3","doc":"Blurs an image using the box filter.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image.\n\n- **ddepth**: `integer()`.\n\n  the output image depth (-1 to use src.depth()).\n\n- **ksize**: `Size`.\n\n  blurring kernel size.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  anchor point; default value Point(-1,-1) means that the anchor is at the kernel\n  center.\n\n- **normalize**: `bool`.\n\n  flag, specifying whether the kernel is normalized by its area or not.\n\n- **borderType**: `integer()`.\n\n  border mode used to extrapolate pixels outside of the image, see #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and type as src.\n\nThe function smooths an image using the kernel:\n\\f[\\texttt{K} =  \\alpha \\begin{bmatrix} 1 & 1 & 1 &  \\cdots & 1 & 1  \\\\\\\\ 1 & 1 & 1 &  \\cdots & 1 & 1  \\\\\\\\ \\hdotsfor{6} \\\\\\\\ 1 & 1 & 1 &  \\cdots & 1 & 1 \\end{bmatrix}\\f]\nwhere\n\\f[\\alpha = \\begin{cases} \\frac{1}{\\texttt{ksize.width\\*ksize.height}} & \\texttt{when } \\texttt{normalize=true}  \\\\\\\\1 & \\texttt{otherwise}\\end{cases}\\f]\nUnnormalized box filter is useful for computing various integral characteristics over each pixel\nneighborhood, such as covariance matrices of image derivatives (used in dense optical flow\nalgorithms, and so on). If you need to compute pixel sums over variable-size windows, use #integral.\n@sa  blur, bilateralFilter, GaussianBlur, medianBlur, integral\n\nPython prototype (for reference only):\n```python3\nboxFilter(src, ddepth, ksize[, dst[, anchor[, normalize[, borderType]]]]) -> dst\n```","ref":"Evision.html#boxFilter/3"},{"type":"function","title":"Evision.boxFilter/4","doc":"Blurs an image using the box filter.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image.\n\n- **ddepth**: `integer()`.\n\n  the output image depth (-1 to use src.depth()).\n\n- **ksize**: `Size`.\n\n  blurring kernel size.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  anchor point; default value Point(-1,-1) means that the anchor is at the kernel\n  center.\n\n- **normalize**: `bool`.\n\n  flag, specifying whether the kernel is normalized by its area or not.\n\n- **borderType**: `integer()`.\n\n  border mode used to extrapolate pixels outside of the image, see #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and type as src.\n\nThe function smooths an image using the kernel:\n\\f[\\texttt{K} =  \\alpha \\begin{bmatrix} 1 & 1 & 1 &  \\cdots & 1 & 1  \\\\\\\\ 1 & 1 & 1 &  \\cdots & 1 & 1  \\\\\\\\ \\hdotsfor{6} \\\\\\\\ 1 & 1 & 1 &  \\cdots & 1 & 1 \\end{bmatrix}\\f]\nwhere\n\\f[\\alpha = \\begin{cases} \\frac{1}{\\texttt{ksize.width\\*ksize.height}} & \\texttt{when } \\texttt{normalize=true}  \\\\\\\\1 & \\texttt{otherwise}\\end{cases}\\f]\nUnnormalized box filter is useful for computing various integral characteristics over each pixel\nneighborhood, such as covariance matrices of image derivatives (used in dense optical flow\nalgorithms, and so on). If you need to compute pixel sums over variable-size windows, use #integral.\n@sa  blur, bilateralFilter, GaussianBlur, medianBlur, integral\n\nPython prototype (for reference only):\n```python3\nboxFilter(src, ddepth, ksize[, dst[, anchor[, normalize[, borderType]]]]) -> dst\n```","ref":"Evision.html#boxFilter/4"},{"type":"function","title":"Evision.boxPoints/1","doc":"Finds the four vertices of a rotated rect. Useful to draw the rotated rectangle.\n\n##### Positional Arguments\n- **box**: `{centre={x, y}, size={s1, s2}, angle}`.\n\n  The input rotated rectangle. It may be the output of @ref minAreaRect.\n\n##### Return\n- **points**: `Evision.Mat.t()`.\n\n  The output array of four vertices of rectangles.\n\nThe function finds the four vertices of a rotated rectangle. This function is useful to draw the\nrectangle. In C++, instead of using this function, you can directly use RotatedRect::points method. Please\nvisit the @ref tutorial_bounding_rotated_ellipses \"tutorial on Creating Bounding rotated boxes and ellipses for contours\" for more information.\n\nPython prototype (for reference only):\n```python3\nboxPoints(box[, points]) -> points\n```","ref":"Evision.html#boxPoints/1"},{"type":"function","title":"Evision.boxPoints/2","doc":"Finds the four vertices of a rotated rect. Useful to draw the rotated rectangle.\n\n##### Positional Arguments\n- **box**: `{centre={x, y}, size={s1, s2}, angle}`.\n\n  The input rotated rectangle. It may be the output of @ref minAreaRect.\n\n##### Return\n- **points**: `Evision.Mat.t()`.\n\n  The output array of four vertices of rectangles.\n\nThe function finds the four vertices of a rotated rectangle. This function is useful to draw the\nrectangle. In C++, instead of using this function, you can directly use RotatedRect::points method. Please\nvisit the @ref tutorial_bounding_rotated_ellipses \"tutorial on Creating Bounding rotated boxes and ellipses for contours\" for more information.\n\nPython prototype (for reference only):\n```python3\nboxPoints(box[, points]) -> points\n```","ref":"Evision.html#boxPoints/2"},{"type":"function","title":"Evision.broadcast/1","doc":"","ref":"Evision.html#broadcast/1"},{"type":"function","title":"Evision.broadcast/2","doc":"Broadcast the given Mat to the given shape.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array\n\n- **shape**: `Evision.Mat`.\n\n  target shape. Should be a list of CV_32S numbers. Note that negative values are not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array that has the given shape\n\nPython prototype (for reference only):\n```python3\nbroadcast(src, shape[, dst]) -> dst\n```","ref":"Evision.html#broadcast/2"},{"type":"function","title":"Evision.broadcast/3","doc":"Broadcast the given Mat to the given shape.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array\n\n- **shape**: `Evision.Mat`.\n\n  target shape. Should be a list of CV_32S numbers. Note that negative values are not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array that has the given shape\n\nPython prototype (for reference only):\n```python3\nbroadcast(src, shape[, dst]) -> dst\n```","ref":"Evision.html#broadcast/3"},{"type":"function","title":"Evision.buildOpticalFlowPyramid/1","doc":"","ref":"Evision.html#buildOpticalFlowPyramid/1"},{"type":"function","title":"Evision.buildOpticalFlowPyramid/3","doc":"Constructs the image pyramid which can be passed to calcOpticalFlowPyrLK.\n\n##### Positional Arguments\n- **img**: `Evision.Mat`.\n\n  8-bit input image.\n\n- **winSize**: `Size`.\n\n  window size of optical flow algorithm. Must be not less than winSize argument of\n  calcOpticalFlowPyrLK. It is needed to calculate required padding for pyramid levels.\n\n- **maxLevel**: `integer()`.\n\n  0-based maximal pyramid level number.\n\n##### Keyword Arguments\n- **withDerivatives**: `bool`.\n\n  set to precompute gradients for the every pyramid level. If pyramid is\n  constructed without the gradients then calcOpticalFlowPyrLK will calculate them internally.\n\n- **pyrBorder**: `integer()`.\n\n  the border mode for pyramid layers.\n\n- **derivBorder**: `integer()`.\n\n  the border mode for gradients.\n\n- **tryReuseInputImage**: `bool`.\n\n  put ROI of input image into the pyramid if possible. You can pass false\n  to force data copying.\n\n##### Return\n- **retval**: `integer()`\n- **pyramid**: `[Evision.Mat]`.\n\n  output pyramid.\n\n@return number of levels in constructed pyramid. Can be less than maxLevel.\n\nPython prototype (for reference only):\n```python3\nbuildOpticalFlowPyramid(img, winSize, maxLevel[, pyramid[, withDerivatives[, pyrBorder[, derivBorder[, tryReuseInputImage]]]]]) -> retval, pyramid\n```","ref":"Evision.html#buildOpticalFlowPyramid/3"},{"type":"function","title":"Evision.buildOpticalFlowPyramid/4","doc":"Constructs the image pyramid which can be passed to calcOpticalFlowPyrLK.\n\n##### Positional Arguments\n- **img**: `Evision.Mat`.\n\n  8-bit input image.\n\n- **winSize**: `Size`.\n\n  window size of optical flow algorithm. Must be not less than winSize argument of\n  calcOpticalFlowPyrLK. It is needed to calculate required padding for pyramid levels.\n\n- **maxLevel**: `integer()`.\n\n  0-based maximal pyramid level number.\n\n##### Keyword Arguments\n- **withDerivatives**: `bool`.\n\n  set to precompute gradients for the every pyramid level. If pyramid is\n  constructed without the gradients then calcOpticalFlowPyrLK will calculate them internally.\n\n- **pyrBorder**: `integer()`.\n\n  the border mode for pyramid layers.\n\n- **derivBorder**: `integer()`.\n\n  the border mode for gradients.\n\n- **tryReuseInputImage**: `bool`.\n\n  put ROI of input image into the pyramid if possible. You can pass false\n  to force data copying.\n\n##### Return\n- **retval**: `integer()`\n- **pyramid**: `[Evision.Mat]`.\n\n  output pyramid.\n\n@return number of levels in constructed pyramid. Can be less than maxLevel.\n\nPython prototype (for reference only):\n```python3\nbuildOpticalFlowPyramid(img, winSize, maxLevel[, pyramid[, withDerivatives[, pyrBorder[, derivBorder[, tryReuseInputImage]]]]]) -> retval, pyramid\n```","ref":"Evision.html#buildOpticalFlowPyramid/4"},{"type":"function","title":"Evision.calcBackProject/1","doc":"","ref":"Evision.html#calcBackProject/1"},{"type":"function","title":"Evision.calcBackProject/5","doc":"calcBackProject\n\n##### Positional Arguments\n- **images**: `[Evision.Mat]`\n- **channels**: `[integer()]`\n- **hist**: `Evision.Mat`\n- **ranges**: `[float]`\n- **scale**: `double`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalcBackProject(images, channels, hist, ranges, scale[, dst]) -> dst\n```","ref":"Evision.html#calcBackProject/5"},{"type":"function","title":"Evision.calcBackProject/6","doc":"calcBackProject\n\n##### Positional Arguments\n- **images**: `[Evision.Mat]`\n- **channels**: `[integer()]`\n- **hist**: `Evision.Mat`\n- **ranges**: `[float]`\n- **scale**: `double`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalcBackProject(images, channels, hist, ranges, scale[, dst]) -> dst\n```","ref":"Evision.html#calcBackProject/6"},{"type":"function","title":"Evision.calcCovarMatrix/1","doc":"","ref":"Evision.html#calcCovarMatrix/1"},{"type":"function","title":"Evision.calcCovarMatrix/3","doc":"calcCovarMatrix\n\n##### Positional Arguments\n- **samples**: `Evision.Mat`.\n\n  samples stored as rows/columns of a single matrix.\n\n- **flags**: `integer()`.\n\n  operation flags as a combination of #CovarFlags\n\n##### Keyword Arguments\n- **ctype**: `integer()`.\n\n  type of the matrixl; it equals 'CV_64F' by default.\n\n##### Return\n- **covar**: `Evision.Mat.t()`.\n\n  output covariance matrix of the type ctype and square size.\n\n- **mean**: `Evision.Mat.t()`.\n\n  input or output (depending on the flags) array as the average value of the input vectors.\n\nHas overloading in C++\n\n**Note**: use #COVAR_ROWS or #COVAR_COLS flag\n\nPython prototype (for reference only):\n```python3\ncalcCovarMatrix(samples, mean, flags[, covar[, ctype]]) -> covar, mean\n```","ref":"Evision.html#calcCovarMatrix/3"},{"type":"function","title":"Evision.calcCovarMatrix/4","doc":"calcCovarMatrix\n\n##### Positional Arguments\n- **samples**: `Evision.Mat`.\n\n  samples stored as rows/columns of a single matrix.\n\n- **flags**: `integer()`.\n\n  operation flags as a combination of #CovarFlags\n\n##### Keyword Arguments\n- **ctype**: `integer()`.\n\n  type of the matrixl; it equals 'CV_64F' by default.\n\n##### Return\n- **covar**: `Evision.Mat.t()`.\n\n  output covariance matrix of the type ctype and square size.\n\n- **mean**: `Evision.Mat.t()`.\n\n  input or output (depending on the flags) array as the average value of the input vectors.\n\nHas overloading in C++\n\n**Note**: use #COVAR_ROWS or #COVAR_COLS flag\n\nPython prototype (for reference only):\n```python3\ncalcCovarMatrix(samples, mean, flags[, covar[, ctype]]) -> covar, mean\n```","ref":"Evision.html#calcCovarMatrix/4"},{"type":"function","title":"Evision.calcHist/1","doc":"","ref":"Evision.html#calcHist/1"},{"type":"function","title":"Evision.calcHist/5","doc":"calcHist\n\n##### Positional Arguments\n- **images**: `[Evision.Mat]`\n- **channels**: `[integer()]`\n- **mask**: `Evision.Mat`\n- **histSize**: `[integer()]`\n- **ranges**: `[float]`\n\n##### Keyword Arguments\n- **accumulate**: `bool`.\n\n##### Return\n- **hist**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nthis variant supports only uniform histograms.\nranges argument is either empty vector or a flattened vector of histSize.size()*2 elements\n(histSize.size() element pairs). The first and second elements of each pair specify the lower and\nupper boundaries.\n\nPython prototype (for reference only):\n```python3\ncalcHist(images, channels, mask, histSize, ranges[, hist[, accumulate]]) -> hist\n```","ref":"Evision.html#calcHist/5"},{"type":"function","title":"Evision.calcHist/6","doc":"calcHist\n\n##### Positional Arguments\n- **images**: `[Evision.Mat]`\n- **channels**: `[integer()]`\n- **mask**: `Evision.Mat`\n- **histSize**: `[integer()]`\n- **ranges**: `[float]`\n\n##### Keyword Arguments\n- **accumulate**: `bool`.\n\n##### Return\n- **hist**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nthis variant supports only uniform histograms.\nranges argument is either empty vector or a flattened vector of histSize.size()*2 elements\n(histSize.size() element pairs). The first and second elements of each pair specify the lower and\nupper boundaries.\n\nPython prototype (for reference only):\n```python3\ncalcHist(images, channels, mask, histSize, ranges[, hist[, accumulate]]) -> hist\n```","ref":"Evision.html#calcHist/6"},{"type":"function","title":"Evision.calcOpticalFlowFarneback/1","doc":"","ref":"Evision.html#calcOpticalFlowFarneback/1"},{"type":"function","title":"Evision.calcOpticalFlowFarneback/10","doc":"Computes a dense optical flow using the Gunnar Farneback's algorithm.\n\n##### Positional Arguments\n- **prev**: `Evision.Mat`.\n\n  first 8-bit single-channel input image.\n\n- **next**: `Evision.Mat`.\n\n  second input image of the same size and the same type as prev.\n\n- **pyr_scale**: `double`.\n\n  parameter, specifying the image scale (\\<1) to build pyramids for each image;\n  pyr_scale=0.5 means a classical pyramid, where each next layer is twice smaller than the previous\n  one.\n\n- **levels**: `integer()`.\n\n  number of pyramid layers including the initial image; levels=1 means that no extra\n  layers are created and only the original images are used.\n\n- **winsize**: `integer()`.\n\n  averaging window size; larger values increase the algorithm robustness to image\n  noise and give more chances for fast motion detection, but yield more blurred motion field.\n\n- **iterations**: `integer()`.\n\n  number of iterations the algorithm does at each pyramid level.\n\n- **poly_n**: `integer()`.\n\n  size of the pixel neighborhood used to find polynomial expansion in each pixel;\n  larger values mean that the image will be approximated with smoother surfaces, yielding more\n  robust algorithm and more blurred motion field, typically poly_n =5 or 7.\n\n- **poly_sigma**: `double`.\n\n  standard deviation of the Gaussian that is used to smooth derivatives used as a\n  basis for the polynomial expansion; for poly_n=5, you can set poly_sigma=1.1, for poly_n=7, a\n  good value would be poly_sigma=1.5.\n\n- **flags**: `integer()`.\n\n  operation flags that can be a combination of the following:\n  - **OPTFLOW_USE_INITIAL_FLOW** uses the input flow as an initial flow approximation.\n  - **OPTFLOW_FARNEBACK_GAUSSIAN** uses the Gaussian \\f$\\texttt{winsize}\\times\\texttt{winsize}\\f$\n    filter instead of a box filter of the same size for optical flow estimation; usually, this\n    option gives z more accurate flow than with a box filter, at the cost of lower speed;\n    normally, winsize for a Gaussian window should be set to a larger value to achieve the same\n    level of robustness.\n\n##### Return\n- **flow**: `Evision.Mat.t()`.\n\n  computed flow image that has the same size as prev and type CV_32FC2.\n\nThe function finds an optical flow for each prev pixel using the @cite Farneback2003 algorithm so that\n\\f[\\texttt{prev} (y,x)  \\sim \\texttt{next} ( y + \\texttt{flow} (y,x)\\[1],  x + \\texttt{flow} (y,x)\\[0])\\f]\n**Note**: Some examples:\n- An example using the optical flow algorithm described by Gunnar Farneback can be found at\n  opencv_source_code/samples/cpp/fback.cpp\n\n- (Python) An example using the optical flow algorithm described by Gunnar Farneback can be\n  found at opencv_source_code/samples/python/opt_flow.py\n\nPython prototype (for reference only):\n```python3\ncalcOpticalFlowFarneback(prev, next, flow, pyr_scale, levels, winsize, iterations, poly_n, poly_sigma, flags) -> flow\n```","ref":"Evision.html#calcOpticalFlowFarneback/10"},{"type":"function","title":"Evision.calcOpticalFlowPyrLK/1","doc":"","ref":"Evision.html#calcOpticalFlowPyrLK/1"},{"type":"function","title":"Evision.calcOpticalFlowPyrLK/4","doc":"Calculates an optical flow for a sparse feature set using the iterative Lucas-Kanade method with\npyramids.\n\n##### Positional Arguments\n- **prevImg**: `Evision.Mat`.\n\n  first 8-bit input image or pyramid constructed by buildOpticalFlowPyramid.\n\n- **nextImg**: `Evision.Mat`.\n\n  second input image or pyramid of the same size and the same type as prevImg.\n\n- **prevPts**: `Evision.Mat`.\n\n  vector of 2D points for which the flow needs to be found; point coordinates must be\n  single-precision floating-point numbers.\n\n##### Keyword Arguments\n- **winSize**: `Size`.\n\n  size of the search window at each pyramid level.\n\n- **maxLevel**: `integer()`.\n\n  0-based maximal pyramid level number; if set to 0, pyramids are not used (single\n  level), if set to 1, two levels are used, and so on; if pyramids are passed to input then\n  algorithm will use as many levels as pyramids have but no more than maxLevel.\n\n- **criteria**: `TermCriteria`.\n\n  parameter, specifying the termination criteria of the iterative search algorithm\n  (after the specified maximum number of iterations criteria.maxCount or when the search window\n  moves by less than criteria.epsilon.\n\n- **flags**: `integer()`.\n\n  operation flags:\n  - **OPTFLOW_USE_INITIAL_FLOW** uses initial estimations, stored in nextPts; if the flag is\n    not set, then prevPts is copied to nextPts and is considered the initial estimate.\n  - **OPTFLOW_LK_GET_MIN_EIGENVALS** use minimum eigen values as an error measure (see\n    minEigThreshold description); if the flag is not set, then L1 distance between patches\n    around the original and a moved point, divided by number of pixels in a window, is used as a\n    error measure.\n\n- **minEigThreshold**: `double`.\n\n  the algorithm calculates the minimum eigen value of a 2x2 normal matrix of\n  optical flow equations (this matrix is called a spatial gradient matrix in @cite Bouguet00), divided\n  by number of pixels in a window; if this value is less than minEigThreshold, then a corresponding\n  feature is filtered out and its flow is not processed, so it allows to remove bad points and get a\n  performance boost.\n\n##### Return\n- **nextPts**: `Evision.Mat.t()`.\n\n  output vector of 2D points (with single-precision floating-point coordinates)\n  containing the calculated new positions of input features in the second image; when\n  OPTFLOW_USE_INITIAL_FLOW flag is passed, the vector must have the same size as in the input.\n\n- **status**: `Evision.Mat.t()`.\n\n  output status vector (of unsigned chars); each element of the vector is set to 1 if\n  the flow for the corresponding features has been found, otherwise, it is set to 0.\n\n- **err**: `Evision.Mat.t()`.\n\n  output vector of errors; each element of the vector is set to an error for the\n  corresponding feature, type of the error measure can be set in flags parameter; if the flow wasn't\n  found then the error is not defined (use the status parameter to find such cases).\n\nThe function implements a sparse iterative version of the Lucas-Kanade optical flow in pyramids. See\n@cite Bouguet00 . The function is parallelized with the TBB library.\n**Note**: Some examples:\n- An example using the Lucas-Kanade optical flow algorithm can be found at\n  opencv_source_code/samples/cpp/lkdemo.cpp\n\n- (Python) An example using the Lucas-Kanade optical flow algorithm can be found at\n  opencv_source_code/samples/python/lk_track.py\n\n- (Python) An example using the Lucas-Kanade tracker for homography matching can be found at\n  opencv_source_code/samples/python/lk_homography.py\n\nPython prototype (for reference only):\n```python3\ncalcOpticalFlowPyrLK(prevImg, nextImg, prevPts, nextPts[, status[, err[, winSize[, maxLevel[, criteria[, flags[, minEigThreshold]]]]]]]) -> nextPts, status, err\n```","ref":"Evision.html#calcOpticalFlowPyrLK/4"},{"type":"function","title":"Evision.calcOpticalFlowPyrLK/5","doc":"Calculates an optical flow for a sparse feature set using the iterative Lucas-Kanade method with\npyramids.\n\n##### Positional Arguments\n- **prevImg**: `Evision.Mat`.\n\n  first 8-bit input image or pyramid constructed by buildOpticalFlowPyramid.\n\n- **nextImg**: `Evision.Mat`.\n\n  second input image or pyramid of the same size and the same type as prevImg.\n\n- **prevPts**: `Evision.Mat`.\n\n  vector of 2D points for which the flow needs to be found; point coordinates must be\n  single-precision floating-point numbers.\n\n##### Keyword Arguments\n- **winSize**: `Size`.\n\n  size of the search window at each pyramid level.\n\n- **maxLevel**: `integer()`.\n\n  0-based maximal pyramid level number; if set to 0, pyramids are not used (single\n  level), if set to 1, two levels are used, and so on; if pyramids are passed to input then\n  algorithm will use as many levels as pyramids have but no more than maxLevel.\n\n- **criteria**: `TermCriteria`.\n\n  parameter, specifying the termination criteria of the iterative search algorithm\n  (after the specified maximum number of iterations criteria.maxCount or when the search window\n  moves by less than criteria.epsilon.\n\n- **flags**: `integer()`.\n\n  operation flags:\n  - **OPTFLOW_USE_INITIAL_FLOW** uses initial estimations, stored in nextPts; if the flag is\n    not set, then prevPts is copied to nextPts and is considered the initial estimate.\n  - **OPTFLOW_LK_GET_MIN_EIGENVALS** use minimum eigen values as an error measure (see\n    minEigThreshold description); if the flag is not set, then L1 distance between patches\n    around the original and a moved point, divided by number of pixels in a window, is used as a\n    error measure.\n\n- **minEigThreshold**: `double`.\n\n  the algorithm calculates the minimum eigen value of a 2x2 normal matrix of\n  optical flow equations (this matrix is called a spatial gradient matrix in @cite Bouguet00), divided\n  by number of pixels in a window; if this value is less than minEigThreshold, then a corresponding\n  feature is filtered out and its flow is not processed, so it allows to remove bad points and get a\n  performance boost.\n\n##### Return\n- **nextPts**: `Evision.Mat.t()`.\n\n  output vector of 2D points (with single-precision floating-point coordinates)\n  containing the calculated new positions of input features in the second image; when\n  OPTFLOW_USE_INITIAL_FLOW flag is passed, the vector must have the same size as in the input.\n\n- **status**: `Evision.Mat.t()`.\n\n  output status vector (of unsigned chars); each element of the vector is set to 1 if\n  the flow for the corresponding features has been found, otherwise, it is set to 0.\n\n- **err**: `Evision.Mat.t()`.\n\n  output vector of errors; each element of the vector is set to an error for the\n  corresponding feature, type of the error measure can be set in flags parameter; if the flow wasn't\n  found then the error is not defined (use the status parameter to find such cases).\n\nThe function implements a sparse iterative version of the Lucas-Kanade optical flow in pyramids. See\n@cite Bouguet00 . The function is parallelized with the TBB library.\n**Note**: Some examples:\n- An example using the Lucas-Kanade optical flow algorithm can be found at\n  opencv_source_code/samples/cpp/lkdemo.cpp\n\n- (Python) An example using the Lucas-Kanade optical flow algorithm can be found at\n  opencv_source_code/samples/python/lk_track.py\n\n- (Python) An example using the Lucas-Kanade tracker for homography matching can be found at\n  opencv_source_code/samples/python/lk_homography.py\n\nPython prototype (for reference only):\n```python3\ncalcOpticalFlowPyrLK(prevImg, nextImg, prevPts, nextPts[, status[, err[, winSize[, maxLevel[, criteria[, flags[, minEigThreshold]]]]]]]) -> nextPts, status, err\n```","ref":"Evision.html#calcOpticalFlowPyrLK/5"},{"type":"function","title":"Evision.calibrateCamera/1","doc":"","ref":"Evision.html#calibrateCamera/1"},{"type":"function","title":"Evision.calibrateCamera/5","doc":"calibrateCamera\n\n##### Positional Arguments\n- **objectPoints**: `[Evision.Mat]`\n- **imagePoints**: `[Evision.Mat]`\n- **imageSize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **criteria**: `TermCriteria`.\n\n##### Return\n- **retval**: `double`\n- **cameraMatrix**: `Evision.Mat.t()`\n- **distCoeffs**: `Evision.Mat.t()`\n- **rvecs**: `[Evision.Mat]`.\n- **tvecs**: `[Evision.Mat]`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalibrateCamera(objectPoints, imagePoints, imageSize, cameraMatrix, distCoeffs[, rvecs[, tvecs[, flags[, criteria]]]]) -> retval, cameraMatrix, distCoeffs, rvecs, tvecs\n```","ref":"Evision.html#calibrateCamera/5"},{"type":"function","title":"Evision.calibrateCamera/6","doc":"calibrateCamera\n\n##### Positional Arguments\n- **objectPoints**: `[Evision.Mat]`\n- **imagePoints**: `[Evision.Mat]`\n- **imageSize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **criteria**: `TermCriteria`.\n\n##### Return\n- **retval**: `double`\n- **cameraMatrix**: `Evision.Mat.t()`\n- **distCoeffs**: `Evision.Mat.t()`\n- **rvecs**: `[Evision.Mat]`.\n- **tvecs**: `[Evision.Mat]`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalibrateCamera(objectPoints, imagePoints, imageSize, cameraMatrix, distCoeffs[, rvecs[, tvecs[, flags[, criteria]]]]) -> retval, cameraMatrix, distCoeffs, rvecs, tvecs\n```","ref":"Evision.html#calibrateCamera/6"},{"type":"function","title":"Evision.calibrateCameraExtended/1","doc":"","ref":"Evision.html#calibrateCameraExtended/1"},{"type":"function","title":"Evision.calibrateCameraExtended/5","doc":"Finds the camera intrinsic and extrinsic parameters from several views of a calibration\npattern.\n\n##### Positional Arguments\n- **objectPoints**: `[Evision.Mat]`.\n\n  In the new interface it is a vector of vectors of calibration pattern points in\n  the calibration pattern coordinate space (e.g. std::vector >). The outer\n  vector contains as many elements as the number of pattern views. If the same calibration pattern\n  is shown in each view and it is fully visible, all the vectors will be the same. Although, it is\n  possible to use partially occluded patterns or even different patterns in different views. Then,\n  the vectors will be different. Although the points are 3D, they all lie in the calibration pattern's\n  XY coordinate plane (thus 0 in the Z-coordinate), if the used calibration pattern is a planar rig.\n  In the old interface all the vectors of object points from different views are concatenated\n  together.\n\n- **imagePoints**: `[Evision.Mat]`.\n\n  In the new interface it is a vector of vectors of the projections of calibration\n  pattern points (e.g. std::vector >). imagePoints.size() and\n  objectPoints.size(), and imagePoints[i].size() and objectPoints[i].size() for each i, must be equal,\n  respectively. In the old interface all the vectors of object points from different views are\n  concatenated together.\n\n- **imageSize**: `Size`.\n\n  Size of the image used only to initialize the camera intrinsic matrix.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Different flags that may be zero or a combination of the following values:\n  - @ref CALIB_USE_INTRINSIC_GUESS cameraMatrix contains valid initial values of\n    fx, fy, cx, cy that are optimized further. Otherwise, (cx, cy) is initially set to the image\n    center ( imageSize is used), and focal distances are computed in a least-squares fashion.\n    Note, that if intrinsic parameters are known, there is no need to use this function just to\n    estimate extrinsic parameters. Use @ref solvePnP instead.\n  - @ref CALIB_FIX_PRINCIPAL_POINT The principal point is not changed during the global\n    optimization. It stays at the center or at a different location specified when\n\n- **criteria**: `TermCriteria`.\n\n  Termination criteria for the iterative optimization algorithm.\n\n##### Return\n- **retval**: `double`\n- **cameraMatrix**: `Evision.Mat.t()`.\n\n  Input/output 3x3 floating-point camera intrinsic matrix\n  \\f$\\cameramatrix{A}\\f$ . If @ref CALIB_USE_INTRINSIC_GUESS\n  and/or @ref CALIB_FIX_ASPECT_RATIO, @ref CALIB_FIX_PRINCIPAL_POINT or @ref CALIB_FIX_FOCAL_LENGTH\n  are specified, some or all of fx, fy, cx, cy must be initialized before calling the function.\n\n- **distCoeffs**: `Evision.Mat.t()`.\n\n  Input/output vector of distortion coefficients\n  \\f$\\distcoeffs\\f$.\n\n- **rvecs**: `[Evision.Mat]`.\n\n  Output vector of rotation vectors (@ref Rodrigues ) estimated for each pattern view\n  (e.g. std::vector >). That is, each i-th rotation vector together with the corresponding\n  i-th translation vector (see the next output parameter description) brings the calibration pattern\n  from the object coordinate space (in which object points are specified) to the camera coordinate\n  space. In more technical terms, the tuple of the i-th rotation and translation vector performs\n  a change of basis from object coordinate space to camera coordinate space. Due to its duality, this\n  tuple is equivalent to the position of the calibration pattern with respect to the camera coordinate\n  space.\n\n- **tvecs**: `[Evision.Mat]`.\n\n  Output vector of translation vectors estimated for each pattern view, see parameter\n  describtion above.\n\n- **stdDeviationsIntrinsics**: `Evision.Mat.t()`.\n\n  Output vector of standard deviations estimated for intrinsic\n  parameters. Order of deviations values:\n  \\f$(f_x, f_y, c_x, c_y, k_1, k_2, p_1, p_2, k_3, k_4, k_5, k_6 , s_1, s_2, s_3,\n  s_4, \\tau_x, \\tau_y)\\f$ If one of parameters is not estimated, it's deviation is equals to zero.\n\n- **stdDeviationsExtrinsics**: `Evision.Mat.t()`.\n\n  Output vector of standard deviations estimated for extrinsic\n  parameters. Order of deviations values: \\f$(R_0, T_0, \\dotsc , R_{M - 1}, T_{M - 1})\\f$ where M is\n  the number of pattern views. \\f$R_i, T_i\\f$ are concatenated 1x3 vectors.\n\n- **perViewErrors**: `Evision.Mat.t()`.\n\n  Output vector of the RMS re-projection error estimated for each pattern view.\n\n@ref CALIB_USE_INTRINSIC_GUESS is set too.\n- @ref CALIB_FIX_ASPECT_RATIO The functions consider only fy as a free parameter. The\n  ratio fx/fy stays the same as in the input cameraMatrix . When\n\n@ref CALIB_USE_INTRINSIC_GUESS is not set, the actual input values of fx and fy are\nignored, only their ratio is computed and used further.\n- @ref CALIB_ZERO_TANGENT_DIST Tangential distortion coefficients \\f$(p\\_1, p\\_2)\\f$ are set\n  to zeros and stay zero.\n\n- @ref CALIB_FIX_FOCAL_LENGTH The focal length is not changed during the global optimization if\n@ref CALIB_USE_INTRINSIC_GUESS is set.\n- @ref CALIB_FIX_K1,..., @ref CALIB_FIX_K6 The corresponding radial distortion\n  coefficient is not changed during the optimization. If @ref CALIB_USE_INTRINSIC_GUESS is\n  set, the coefficient from the supplied distCoeffs matrix is used. Otherwise, it is set to 0.\n\n- @ref CALIB_RATIONAL_MODEL Coefficients k4, k5, and k6 are enabled. To provide the\n  backward compatibility, this extra flag should be explicitly specified to make the\n  calibration function use the rational model and return 8 coefficients or more.\n\n- @ref CALIB_THIN_PRISM_MODEL Coefficients s1, s2, s3 and s4 are enabled. To provide the\n  backward compatibility, this extra flag should be explicitly specified to make the\n  calibration function use the thin prism model and return 12 coefficients or more.\n\n- @ref CALIB_FIX_S1_S2_S3_S4 The thin prism distortion coefficients are not changed during\n  the optimization. If @ref CALIB_USE_INTRINSIC_GUESS is set, the coefficient from the\n  supplied distCoeffs matrix is used. Otherwise, it is set to 0.\n\n- @ref CALIB_TILTED_MODEL Coefficients tauX and tauY are enabled. To provide the\n  backward compatibility, this extra flag should be explicitly specified to make the\n  calibration function use the tilted sensor model and return 14 coefficients.\n\n- @ref CALIB_FIX_TAUX_TAUY The coefficients of the tilted sensor model are not changed during\n  the optimization. If @ref CALIB_USE_INTRINSIC_GUESS is set, the coefficient from the\n  supplied distCoeffs matrix is used. Otherwise, it is set to 0.\n\n@return the overall RMS re-projection error.\nThe function estimates the intrinsic camera parameters and extrinsic parameters for each of the\nviews. The algorithm is based on @cite Zhang2000 and @cite BouguetMCT . The coordinates of 3D object\npoints and their corresponding 2D projections in each view must be specified. That may be achieved\nby using an object with known geometry and easily detectable feature points. Such an object is\ncalled a calibration rig or calibration pattern, and OpenCV has built-in support for a chessboard as\na calibration rig (see @ref findChessboardCorners). Currently, initialization of intrinsic\nparameters (when @ref CALIB_USE_INTRINSIC_GUESS is not set) is only implemented for planar calibration\npatterns (where Z-coordinates of the object points must be all zeros). 3D calibration rigs can also\nbe used as long as initial cameraMatrix is provided.\nThe algorithm performs the following steps:\n- Compute the initial intrinsic parameters (the option only available for planar calibration\n  patterns) or read them from the input parameters. The distortion coefficients are all set to\n  zeros initially unless some of CALIB_FIX_K? are specified.\n\n- Estimate the initial camera pose as if the intrinsic parameters have been already known. This is\n  done using @ref solvePnP .\n\n- Run the global Levenberg-Marquardt optimization algorithm to minimize the reprojection error,\n  that is, the total sum of squared distances between the observed feature points imagePoints and\n  the projected (using the current estimates for camera parameters and the poses) object points\n  objectPoints. See @ref projectPoints for details.\n\n**Note**: \nIf you use a non-square (i.e. non-N-by-N) grid and @ref findChessboardCorners for calibration,\nand @ref calibrateCamera returns bad values (zero distortion coefficients, \\f$c\\_x\\f$ and\n\\f$c\\_y\\f$ very far from the image center, and/or large differences between \\f$f\\_x\\f$ and\n\\f$f\\_y\\f$ (ratios of 10:1 or more)), then you are probably using patternSize=cvSize(rows,cols)\ninstead of using patternSize=cvSize(cols,rows) in @ref findChessboardCorners.\n**Note**: \nThe function may throw exceptions, if unsupported combination of parameters is provided or\nthe system is underconstrained.\n@sa\ncalibrateCameraRO, findChessboardCorners, solvePnP, initCameraMatrix2D, stereoCalibrate,\nundistort\n\nPython prototype (for reference only):\n```python3\ncalibrateCameraExtended(objectPoints, imagePoints, imageSize, cameraMatrix, distCoeffs[, rvecs[, tvecs[, stdDeviationsIntrinsics[, stdDeviationsExtrinsics[, perViewErrors[, flags[, criteria]]]]]]]) -> retval, cameraMatrix, distCoeffs, rvecs, tvecs, stdDeviationsIntrinsics, stdDeviationsExtrinsics, perViewErrors\n```","ref":"Evision.html#calibrateCameraExtended/5"},{"type":"function","title":"Evision.calibrateCameraExtended/6","doc":"Finds the camera intrinsic and extrinsic parameters from several views of a calibration\npattern.\n\n##### Positional Arguments\n- **objectPoints**: `[Evision.Mat]`.\n\n  In the new interface it is a vector of vectors of calibration pattern points in\n  the calibration pattern coordinate space (e.g. std::vector >). The outer\n  vector contains as many elements as the number of pattern views. If the same calibration pattern\n  is shown in each view and it is fully visible, all the vectors will be the same. Although, it is\n  possible to use partially occluded patterns or even different patterns in different views. Then,\n  the vectors will be different. Although the points are 3D, they all lie in the calibration pattern's\n  XY coordinate plane (thus 0 in the Z-coordinate), if the used calibration pattern is a planar rig.\n  In the old interface all the vectors of object points from different views are concatenated\n  together.\n\n- **imagePoints**: `[Evision.Mat]`.\n\n  In the new interface it is a vector of vectors of the projections of calibration\n  pattern points (e.g. std::vector >). imagePoints.size() and\n  objectPoints.size(), and imagePoints[i].size() and objectPoints[i].size() for each i, must be equal,\n  respectively. In the old interface all the vectors of object points from different views are\n  concatenated together.\n\n- **imageSize**: `Size`.\n\n  Size of the image used only to initialize the camera intrinsic matrix.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Different flags that may be zero or a combination of the following values:\n  - @ref CALIB_USE_INTRINSIC_GUESS cameraMatrix contains valid initial values of\n    fx, fy, cx, cy that are optimized further. Otherwise, (cx, cy) is initially set to the image\n    center ( imageSize is used), and focal distances are computed in a least-squares fashion.\n    Note, that if intrinsic parameters are known, there is no need to use this function just to\n    estimate extrinsic parameters. Use @ref solvePnP instead.\n  - @ref CALIB_FIX_PRINCIPAL_POINT The principal point is not changed during the global\n    optimization. It stays at the center or at a different location specified when\n\n- **criteria**: `TermCriteria`.\n\n  Termination criteria for the iterative optimization algorithm.\n\n##### Return\n- **retval**: `double`\n- **cameraMatrix**: `Evision.Mat.t()`.\n\n  Input/output 3x3 floating-point camera intrinsic matrix\n  \\f$\\cameramatrix{A}\\f$ . If @ref CALIB_USE_INTRINSIC_GUESS\n  and/or @ref CALIB_FIX_ASPECT_RATIO, @ref CALIB_FIX_PRINCIPAL_POINT or @ref CALIB_FIX_FOCAL_LENGTH\n  are specified, some or all of fx, fy, cx, cy must be initialized before calling the function.\n\n- **distCoeffs**: `Evision.Mat.t()`.\n\n  Input/output vector of distortion coefficients\n  \\f$\\distcoeffs\\f$.\n\n- **rvecs**: `[Evision.Mat]`.\n\n  Output vector of rotation vectors (@ref Rodrigues ) estimated for each pattern view\n  (e.g. std::vector >). That is, each i-th rotation vector together with the corresponding\n  i-th translation vector (see the next output parameter description) brings the calibration pattern\n  from the object coordinate space (in which object points are specified) to the camera coordinate\n  space. In more technical terms, the tuple of the i-th rotation and translation vector performs\n  a change of basis from object coordinate space to camera coordinate space. Due to its duality, this\n  tuple is equivalent to the position of the calibration pattern with respect to the camera coordinate\n  space.\n\n- **tvecs**: `[Evision.Mat]`.\n\n  Output vector of translation vectors estimated for each pattern view, see parameter\n  describtion above.\n\n- **stdDeviationsIntrinsics**: `Evision.Mat.t()`.\n\n  Output vector of standard deviations estimated for intrinsic\n  parameters. Order of deviations values:\n  \\f$(f_x, f_y, c_x, c_y, k_1, k_2, p_1, p_2, k_3, k_4, k_5, k_6 , s_1, s_2, s_3,\n  s_4, \\tau_x, \\tau_y)\\f$ If one of parameters is not estimated, it's deviation is equals to zero.\n\n- **stdDeviationsExtrinsics**: `Evision.Mat.t()`.\n\n  Output vector of standard deviations estimated for extrinsic\n  parameters. Order of deviations values: \\f$(R_0, T_0, \\dotsc , R_{M - 1}, T_{M - 1})\\f$ where M is\n  the number of pattern views. \\f$R_i, T_i\\f$ are concatenated 1x3 vectors.\n\n- **perViewErrors**: `Evision.Mat.t()`.\n\n  Output vector of the RMS re-projection error estimated for each pattern view.\n\n@ref CALIB_USE_INTRINSIC_GUESS is set too.\n- @ref CALIB_FIX_ASPECT_RATIO The functions consider only fy as a free parameter. The\n  ratio fx/fy stays the same as in the input cameraMatrix . When\n\n@ref CALIB_USE_INTRINSIC_GUESS is not set, the actual input values of fx and fy are\nignored, only their ratio is computed and used further.\n- @ref CALIB_ZERO_TANGENT_DIST Tangential distortion coefficients \\f$(p\\_1, p\\_2)\\f$ are set\n  to zeros and stay zero.\n\n- @ref CALIB_FIX_FOCAL_LENGTH The focal length is not changed during the global optimization if\n@ref CALIB_USE_INTRINSIC_GUESS is set.\n- @ref CALIB_FIX_K1,..., @ref CALIB_FIX_K6 The corresponding radial distortion\n  coefficient is not changed during the optimization. If @ref CALIB_USE_INTRINSIC_GUESS is\n  set, the coefficient from the supplied distCoeffs matrix is used. Otherwise, it is set to 0.\n\n- @ref CALIB_RATIONAL_MODEL Coefficients k4, k5, and k6 are enabled. To provide the\n  backward compatibility, this extra flag should be explicitly specified to make the\n  calibration function use the rational model and return 8 coefficients or more.\n\n- @ref CALIB_THIN_PRISM_MODEL Coefficients s1, s2, s3 and s4 are enabled. To provide the\n  backward compatibility, this extra flag should be explicitly specified to make the\n  calibration function use the thin prism model and return 12 coefficients or more.\n\n- @ref CALIB_FIX_S1_S2_S3_S4 The thin prism distortion coefficients are not changed during\n  the optimization. If @ref CALIB_USE_INTRINSIC_GUESS is set, the coefficient from the\n  supplied distCoeffs matrix is used. Otherwise, it is set to 0.\n\n- @ref CALIB_TILTED_MODEL Coefficients tauX and tauY are enabled. To provide the\n  backward compatibility, this extra flag should be explicitly specified to make the\n  calibration function use the tilted sensor model and return 14 coefficients.\n\n- @ref CALIB_FIX_TAUX_TAUY The coefficients of the tilted sensor model are not changed during\n  the optimization. If @ref CALIB_USE_INTRINSIC_GUESS is set, the coefficient from the\n  supplied distCoeffs matrix is used. Otherwise, it is set to 0.\n\n@return the overall RMS re-projection error.\nThe function estimates the intrinsic camera parameters and extrinsic parameters for each of the\nviews. The algorithm is based on @cite Zhang2000 and @cite BouguetMCT . The coordinates of 3D object\npoints and their corresponding 2D projections in each view must be specified. That may be achieved\nby using an object with known geometry and easily detectable feature points. Such an object is\ncalled a calibration rig or calibration pattern, and OpenCV has built-in support for a chessboard as\na calibration rig (see @ref findChessboardCorners). Currently, initialization of intrinsic\nparameters (when @ref CALIB_USE_INTRINSIC_GUESS is not set) is only implemented for planar calibration\npatterns (where Z-coordinates of the object points must be all zeros). 3D calibration rigs can also\nbe used as long as initial cameraMatrix is provided.\nThe algorithm performs the following steps:\n- Compute the initial intrinsic parameters (the option only available for planar calibration\n  patterns) or read them from the input parameters. The distortion coefficients are all set to\n  zeros initially unless some of CALIB_FIX_K? are specified.\n\n- Estimate the initial camera pose as if the intrinsic parameters have been already known. This is\n  done using @ref solvePnP .\n\n- Run the global Levenberg-Marquardt optimization algorithm to minimize the reprojection error,\n  that is, the total sum of squared distances between the observed feature points imagePoints and\n  the projected (using the current estimates for camera parameters and the poses) object points\n  objectPoints. See @ref projectPoints for details.\n\n**Note**: \nIf you use a non-square (i.e. non-N-by-N) grid and @ref findChessboardCorners for calibration,\nand @ref calibrateCamera returns bad values (zero distortion coefficients, \\f$c\\_x\\f$ and\n\\f$c\\_y\\f$ very far from the image center, and/or large differences between \\f$f\\_x\\f$ and\n\\f$f\\_y\\f$ (ratios of 10:1 or more)), then you are probably using patternSize=cvSize(rows,cols)\ninstead of using patternSize=cvSize(cols,rows) in @ref findChessboardCorners.\n**Note**: \nThe function may throw exceptions, if unsupported combination of parameters is provided or\nthe system is underconstrained.\n@sa\ncalibrateCameraRO, findChessboardCorners, solvePnP, initCameraMatrix2D, stereoCalibrate,\nundistort\n\nPython prototype (for reference only):\n```python3\ncalibrateCameraExtended(objectPoints, imagePoints, imageSize, cameraMatrix, distCoeffs[, rvecs[, tvecs[, stdDeviationsIntrinsics[, stdDeviationsExtrinsics[, perViewErrors[, flags[, criteria]]]]]]]) -> retval, cameraMatrix, distCoeffs, rvecs, tvecs, stdDeviationsIntrinsics, stdDeviationsExtrinsics, perViewErrors\n```","ref":"Evision.html#calibrateCameraExtended/6"},{"type":"function","title":"Evision.calibrateCameraRO/1","doc":"","ref":"Evision.html#calibrateCameraRO/1"},{"type":"function","title":"Evision.calibrateCameraRO/6","doc":"calibrateCameraRO\n\n##### Positional Arguments\n- **objectPoints**: `[Evision.Mat]`\n- **imagePoints**: `[Evision.Mat]`\n- **imageSize**: `Size`\n- **iFixedPoint**: `integer()`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **criteria**: `TermCriteria`.\n\n##### Return\n- **retval**: `double`\n- **cameraMatrix**: `Evision.Mat.t()`\n- **distCoeffs**: `Evision.Mat.t()`\n- **rvecs**: `[Evision.Mat]`.\n- **tvecs**: `[Evision.Mat]`.\n- **newObjPoints**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalibrateCameraRO(objectPoints, imagePoints, imageSize, iFixedPoint, cameraMatrix, distCoeffs[, rvecs[, tvecs[, newObjPoints[, flags[, criteria]]]]]) -> retval, cameraMatrix, distCoeffs, rvecs, tvecs, newObjPoints\n```","ref":"Evision.html#calibrateCameraRO/6"},{"type":"function","title":"Evision.calibrateCameraRO/7","doc":"calibrateCameraRO\n\n##### Positional Arguments\n- **objectPoints**: `[Evision.Mat]`\n- **imagePoints**: `[Evision.Mat]`\n- **imageSize**: `Size`\n- **iFixedPoint**: `integer()`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **criteria**: `TermCriteria`.\n\n##### Return\n- **retval**: `double`\n- **cameraMatrix**: `Evision.Mat.t()`\n- **distCoeffs**: `Evision.Mat.t()`\n- **rvecs**: `[Evision.Mat]`.\n- **tvecs**: `[Evision.Mat]`.\n- **newObjPoints**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalibrateCameraRO(objectPoints, imagePoints, imageSize, iFixedPoint, cameraMatrix, distCoeffs[, rvecs[, tvecs[, newObjPoints[, flags[, criteria]]]]]) -> retval, cameraMatrix, distCoeffs, rvecs, tvecs, newObjPoints\n```","ref":"Evision.html#calibrateCameraRO/7"},{"type":"function","title":"Evision.calibrateCameraROExtended/1","doc":"","ref":"Evision.html#calibrateCameraROExtended/1"},{"type":"function","title":"Evision.calibrateCameraROExtended/6","doc":"Finds the camera intrinsic and extrinsic parameters from several views of a calibration pattern.\n\n##### Positional Arguments\n- **objectPoints**: `[Evision.Mat]`.\n\n  Vector of vectors of calibration pattern points in the calibration pattern\n  coordinate space. See #calibrateCamera for details. If the method of releasing object to be used,\n  the identical calibration board must be used in each view and it must be fully visible, and all\n  objectPoints[i] must be the same and all points should be roughly close to a plane. **The calibration\n  target has to be rigid, or at least static if the camera (rather than the calibration target) is\n  shifted for grabbing images.**\n\n- **imagePoints**: `[Evision.Mat]`.\n\n  Vector of vectors of the projections of calibration pattern points. See\n  #calibrateCamera for details.\n\n- **imageSize**: `Size`.\n\n  Size of the image used only to initialize the intrinsic camera matrix.\n\n- **iFixedPoint**: `integer()`.\n\n  The index of the 3D object point in objectPoints[0] to be fixed. It also acts as\n  a switch for calibration method selection. If object-releasing method to be used, pass in the\n  parameter in the range of [1, objectPoints[0].size()-2], otherwise a value out of this range will\n  make standard calibration method selected. Usually the top-right corner point of the calibration\n  board grid is recommended to be fixed when object-releasing method being utilized. According to\n  \\cite strobl2011iccv, two other points are also fixed. In this implementation, objectPoints[0].front\n  and objectPoints[0].back.z are used. With object-releasing method, accurate rvecs, tvecs and\n  newObjPoints are only possible if coordinates of these three fixed points are accurate enough.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Different flags that may be zero or a combination of some predefined values. See\n  #calibrateCamera for details. If the method of releasing object is used, the calibration time may\n  be much longer. CALIB_USE_QR or CALIB_USE_LU could be used for faster calibration with potentially\n  less precise and less stable in some rare cases.\n\n- **criteria**: `TermCriteria`.\n\n  Termination criteria for the iterative optimization algorithm.\n\n##### Return\n- **retval**: `double`\n- **cameraMatrix**: `Evision.Mat.t()`.\n\n  Output 3x3 floating-point camera matrix. See #calibrateCamera for details.\n\n- **distCoeffs**: `Evision.Mat.t()`.\n\n  Output vector of distortion coefficients. See #calibrateCamera for details.\n\n- **rvecs**: `[Evision.Mat]`.\n\n  Output vector of rotation vectors estimated for each pattern view. See #calibrateCamera\n  for details.\n\n- **tvecs**: `[Evision.Mat]`.\n\n  Output vector of translation vectors estimated for each pattern view.\n\n- **newObjPoints**: `Evision.Mat.t()`.\n\n  The updated output vector of calibration pattern points. The coordinates might\n  be scaled based on three fixed points. The returned coordinates are accurate only if the above\n  mentioned three fixed points are accurate. If not needed, noArray() can be passed in. This parameter\n  is ignored with standard calibration method.\n\n- **stdDeviationsIntrinsics**: `Evision.Mat.t()`.\n\n  Output vector of standard deviations estimated for intrinsic parameters.\n  See #calibrateCamera for details.\n\n- **stdDeviationsExtrinsics**: `Evision.Mat.t()`.\n\n  Output vector of standard deviations estimated for extrinsic parameters.\n  See #calibrateCamera for details.\n\n- **stdDeviationsObjPoints**: `Evision.Mat.t()`.\n\n  Output vector of standard deviations estimated for refined coordinates\n  of calibration pattern points. It has the same size and order as objectPoints[0] vector. This\n  parameter is ignored with standard calibration method.\n\n- **perViewErrors**: `Evision.Mat.t()`.\n\n  Output vector of the RMS re-projection error estimated for each pattern view.\n\nThis function is an extension of #calibrateCamera with the method of releasing object which was\nproposed in @cite strobl2011iccv. In many common cases with inaccurate, unmeasured, roughly planar\ntargets (calibration plates), this method can dramatically improve the precision of the estimated\ncamera parameters. Both the object-releasing method and standard method are supported by this\nfunction. Use the parameter **iFixedPoint** for method selection. In the internal implementation,\n#calibrateCamera is a wrapper for this function.\n\n@return the overall RMS re-projection error.\nThe function estimates the intrinsic camera parameters and extrinsic parameters for each of the\nviews. The algorithm is based on @cite Zhang2000, @cite BouguetMCT and @cite strobl2011iccv. See\n#calibrateCamera for other detailed explanations.\n@sa\ncalibrateCamera, findChessboardCorners, solvePnP, initCameraMatrix2D, stereoCalibrate, undistort\n\nPython prototype (for reference only):\n```python3\ncalibrateCameraROExtended(objectPoints, imagePoints, imageSize, iFixedPoint, cameraMatrix, distCoeffs[, rvecs[, tvecs[, newObjPoints[, stdDeviationsIntrinsics[, stdDeviationsExtrinsics[, stdDeviationsObjPoints[, perViewErrors[, flags[, criteria]]]]]]]]]) -> retval, cameraMatrix, distCoeffs, rvecs, tvecs, newObjPoints, stdDeviationsIntrinsics, stdDeviationsExtrinsics, stdDeviationsObjPoints, perViewErrors\n```","ref":"Evision.html#calibrateCameraROExtended/6"},{"type":"function","title":"Evision.calibrateCameraROExtended/7","doc":"Finds the camera intrinsic and extrinsic parameters from several views of a calibration pattern.\n\n##### Positional Arguments\n- **objectPoints**: `[Evision.Mat]`.\n\n  Vector of vectors of calibration pattern points in the calibration pattern\n  coordinate space. See #calibrateCamera for details. If the method of releasing object to be used,\n  the identical calibration board must be used in each view and it must be fully visible, and all\n  objectPoints[i] must be the same and all points should be roughly close to a plane. **The calibration\n  target has to be rigid, or at least static if the camera (rather than the calibration target) is\n  shifted for grabbing images.**\n\n- **imagePoints**: `[Evision.Mat]`.\n\n  Vector of vectors of the projections of calibration pattern points. See\n  #calibrateCamera for details.\n\n- **imageSize**: `Size`.\n\n  Size of the image used only to initialize the intrinsic camera matrix.\n\n- **iFixedPoint**: `integer()`.\n\n  The index of the 3D object point in objectPoints[0] to be fixed. It also acts as\n  a switch for calibration method selection. If object-releasing method to be used, pass in the\n  parameter in the range of [1, objectPoints[0].size()-2], otherwise a value out of this range will\n  make standard calibration method selected. Usually the top-right corner point of the calibration\n  board grid is recommended to be fixed when object-releasing method being utilized. According to\n  \\cite strobl2011iccv, two other points are also fixed. In this implementation, objectPoints[0].front\n  and objectPoints[0].back.z are used. With object-releasing method, accurate rvecs, tvecs and\n  newObjPoints are only possible if coordinates of these three fixed points are accurate enough.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Different flags that may be zero or a combination of some predefined values. See\n  #calibrateCamera for details. If the method of releasing object is used, the calibration time may\n  be much longer. CALIB_USE_QR or CALIB_USE_LU could be used for faster calibration with potentially\n  less precise and less stable in some rare cases.\n\n- **criteria**: `TermCriteria`.\n\n  Termination criteria for the iterative optimization algorithm.\n\n##### Return\n- **retval**: `double`\n- **cameraMatrix**: `Evision.Mat.t()`.\n\n  Output 3x3 floating-point camera matrix. See #calibrateCamera for details.\n\n- **distCoeffs**: `Evision.Mat.t()`.\n\n  Output vector of distortion coefficients. See #calibrateCamera for details.\n\n- **rvecs**: `[Evision.Mat]`.\n\n  Output vector of rotation vectors estimated for each pattern view. See #calibrateCamera\n  for details.\n\n- **tvecs**: `[Evision.Mat]`.\n\n  Output vector of translation vectors estimated for each pattern view.\n\n- **newObjPoints**: `Evision.Mat.t()`.\n\n  The updated output vector of calibration pattern points. The coordinates might\n  be scaled based on three fixed points. The returned coordinates are accurate only if the above\n  mentioned three fixed points are accurate. If not needed, noArray() can be passed in. This parameter\n  is ignored with standard calibration method.\n\n- **stdDeviationsIntrinsics**: `Evision.Mat.t()`.\n\n  Output vector of standard deviations estimated for intrinsic parameters.\n  See #calibrateCamera for details.\n\n- **stdDeviationsExtrinsics**: `Evision.Mat.t()`.\n\n  Output vector of standard deviations estimated for extrinsic parameters.\n  See #calibrateCamera for details.\n\n- **stdDeviationsObjPoints**: `Evision.Mat.t()`.\n\n  Output vector of standard deviations estimated for refined coordinates\n  of calibration pattern points. It has the same size and order as objectPoints[0] vector. This\n  parameter is ignored with standard calibration method.\n\n- **perViewErrors**: `Evision.Mat.t()`.\n\n  Output vector of the RMS re-projection error estimated for each pattern view.\n\nThis function is an extension of #calibrateCamera with the method of releasing object which was\nproposed in @cite strobl2011iccv. In many common cases with inaccurate, unmeasured, roughly planar\ntargets (calibration plates), this method can dramatically improve the precision of the estimated\ncamera parameters. Both the object-releasing method and standard method are supported by this\nfunction. Use the parameter **iFixedPoint** for method selection. In the internal implementation,\n#calibrateCamera is a wrapper for this function.\n\n@return the overall RMS re-projection error.\nThe function estimates the intrinsic camera parameters and extrinsic parameters for each of the\nviews. The algorithm is based on @cite Zhang2000, @cite BouguetMCT and @cite strobl2011iccv. See\n#calibrateCamera for other detailed explanations.\n@sa\ncalibrateCamera, findChessboardCorners, solvePnP, initCameraMatrix2D, stereoCalibrate, undistort\n\nPython prototype (for reference only):\n```python3\ncalibrateCameraROExtended(objectPoints, imagePoints, imageSize, iFixedPoint, cameraMatrix, distCoeffs[, rvecs[, tvecs[, newObjPoints[, stdDeviationsIntrinsics[, stdDeviationsExtrinsics[, stdDeviationsObjPoints[, perViewErrors[, flags[, criteria]]]]]]]]]) -> retval, cameraMatrix, distCoeffs, rvecs, tvecs, newObjPoints, stdDeviationsIntrinsics, stdDeviationsExtrinsics, stdDeviationsObjPoints, perViewErrors\n```","ref":"Evision.html#calibrateCameraROExtended/7"},{"type":"function","title":"Evision.calibrateHandEye/1","doc":"","ref":"Evision.html#calibrateHandEye/1"},{"type":"function","title":"Evision.calibrateHandEye/4","doc":"Computes Hand-Eye calibration: \\f$\\_{}^{g}\\textrm{T}\\_c\\f$\n\n##### Positional Arguments\n- **r_gripper2base**: `[Evision.Mat]`.\n\n  Rotation part extracted from the homogeneous matrix that transforms a point\n  expressed in the gripper frame to the robot base frame (\\f$_{}^{b}\\textrm{T}_g\\f$).\n  This is a vector (`vector `) that contains the rotation, `(3x3)` rotation matrices or `(3x1)` rotation vectors,\n  for all the transformations from gripper frame to robot base frame.\n\n- **t_gripper2base**: `[Evision.Mat]`.\n\n  Translation part extracted from the homogeneous matrix that transforms a point\n  expressed in the gripper frame to the robot base frame (\\f$_{}^{b}\\textrm{T}_g\\f$).\n  This is a vector (`vector `) that contains the `(3x1)` translation vectors for all the transformations\n  from gripper frame to robot base frame.\n\n- **r_target2cam**: `[Evision.Mat]`.\n\n  Rotation part extracted from the homogeneous matrix that transforms a point\n  expressed in the target frame to the camera frame (\\f$_{}^{c}\\textrm{T}_t\\f$).\n  This is a vector (`vector `) that contains the rotation, `(3x3)` rotation matrices or `(3x1)` rotation vectors,\n  for all the transformations from calibration target frame to camera frame.\n\n- **t_target2cam**: `[Evision.Mat]`.\n\n  Rotation part extracted from the homogeneous matrix that transforms a point\n  expressed in the target frame to the camera frame (\\f$_{}^{c}\\textrm{T}_t\\f$).\n  This is a vector (`vector `) that contains the `(3x1)` translation vectors for all the transformations\n  from calibration target frame to camera frame.\n\n##### Keyword Arguments\n- **method**: `HandEyeCalibrationMethod`.\n\n  One of the implemented Hand-Eye calibration method, see cv::HandEyeCalibrationMethod\n\n##### Return\n- **r_cam2gripper**: `Evision.Mat.t()`.\n\n  Estimated `(3x3)` rotation part extracted from the homogeneous matrix that transforms a point\n  expressed in the camera frame to the gripper frame (\\f$_{}^{g}\\textrm{T}_c\\f$).\n\n- **t_cam2gripper**: `Evision.Mat.t()`.\n\n  Estimated `(3x1)` translation part extracted from the homogeneous matrix that transforms a point\n  expressed in the camera frame to the gripper frame (\\f$_{}^{g}\\textrm{T}_c\\f$).\n\nThe function performs the Hand-Eye calibration using various methods. One approach consists in estimating the\nrotation then the translation (separable solutions) and the following methods are implemented:\n- R. Tsai, R. Lenz A New Technique for Fully Autonomous and Efficient 3D Robotics Hand/EyeCalibration \\cite Tsai89\n- F. Park, B. Martin Robot Sensor Calibration: Solving AX = XB on the Euclidean Group \\cite Park94\n- R. Horaud, F. Dornaika Hand-Eye Calibration \\cite Horaud95\n\nAnother approach consists in estimating simultaneously the rotation and the translation (simultaneous solutions),\nwith the following implemented methods:\n- N. Andreff, R. Horaud, B. Espiau On-line Hand-Eye Calibration \\cite Andreff99\n- K. Daniilidis Hand-Eye Calibration Using Dual Quaternions \\cite Daniilidis98\n\nThe following picture describes the Hand-Eye calibration problem where the transformation between a camera (\"eye\")\nmounted on a robot gripper (\"hand\") has to be estimated. This configuration is called eye-in-hand.\nThe eye-to-hand configuration consists in a static camera observing a calibration pattern mounted on the robot\nend-effector. The transformation from the camera to the robot base frame can then be estimated by inputting\nthe suitable transformations to the function, see below.\n![](pics/hand-eye_figure.png)\nThe calibration procedure is the following:\n- a static calibration pattern is used to estimate the transformation between the target frame\n  and the camera frame\n\n- the robot gripper is moved in order to acquire several poses\n- for each pose, the homogeneous transformation between the gripper frame and the robot base frame is recorded using for\n  instance the robot kinematics\n  \\f[\n  \\begin{bmatrix}\n  X\\_b\\\\\\\\\n  Y\\_b\\\\\\\\\n  Z\\_b\\\\\\\\\n  1\n  \\end{bmatrix}=\n  \\begin{bmatrix}\n  \\_{}^{b}\\textrm{R}\\_g & \\_{}^{b}\\textrm{t}\\_g \\\\\\\\\n  0\\_{1 \\times 3} & 1\n  \\end{bmatrix}\n  \\begin{bmatrix}\n  X\\_g\\\\\\\\\n  Y\\_g\\\\\\\\\n  Z\\_g\\\\\\\\\n  1\n  \\end{bmatrix}\n  \\f]\n\n- for each pose, the homogeneous transformation between the calibration target frame and the camera frame is recorded using\n  for instance a pose estimation method (PnP) from 2D-3D point correspondences\n  \\f[\n  \\begin{bmatrix}\n  X\\_c\\\\\\\\\n  Y\\_c\\\\\\\\\n  Z\\_c\\\\\\\\\n  1\n  \\end{bmatrix}=\n  \\begin{bmatrix}\n  \\_{}^{c}\\textrm{R}\\_t & \\_{}^{c}\\textrm{t}\\_t \\\\\\\\\n  0\\_{1 \\times 3} & 1\n  \\end{bmatrix}\n  \\begin{bmatrix}\n  X\\_t\\\\\\\\\n  Y\\_t\\\\\\\\\n  Z\\_t\\\\\\\\\n  1\n  \\end{bmatrix}\n  \\f]\n\nThe Hand-Eye calibration procedure returns the following homogeneous transformation\n\\f[\n\\begin{bmatrix}\nX\\_g\\\\\\\\\nY\\_g\\\\\\\\\nZ\\_g\\\\\\\\\n1\n\\end{bmatrix}\n\\begin{bmatrix}\n\\_{}^{g}\\textrm{R}\\_c & \\_{}^{g}\\textrm{t}\\_c \\\\\\\\\n0\\_{1 \\times 3} & 1\n\\end{bmatrix}\n\\begin{bmatrix}\nX\\_c\\\\\\\\\nY\\_c\\\\\\\\\nZ\\_c\\\\\\\\\n1\n\\end{bmatrix}\n\\f]\nThis problem is also known as solving the \\f$\\mathbf{A}\\mathbf{X}=\\mathbf{X}\\mathbf{B}\\f$ equation:\n- for an eye-in-hand configuration\n  \\f[\n  \\begin{align\\*}\n  ^{b}{\\textrm{T}\\_g}^{(1)} \\hspace{0.2em} ^{g}\\textrm{T}\\_c \\hspace{0.2em} ^{c}{\\textrm{T}\\_t}^{(1)} &=\n  \\hspace{0.1em} ^{b}{\\textrm{T}\\_g}^{(2)} \\hspace{0.2em} ^{g}\\textrm{T}\\_c \\hspace{0.2em} ^{c}{\\textrm{T}\\_t}^{(2)} \\\\\\\\\n  (^{b}{\\textrm{T}\\_g}^{(2)})^{-1} \\hspace{0.2em} ^{b}{\\textrm{T}\\_g}^{(1)} \\hspace{0.2em} ^{g}\\textrm{T}\\_c &=\n  \\hspace{0.1em} ^{g}\\textrm{T}\\_c \\hspace{0.2em} ^{c}{\\textrm{T}\\_t}^{(2)} (^{c}{\\textrm{T}\\_t}^{(1)})^{-1} \\\\\\\\\n  \\textrm{A}\\_i \\textrm{X} &= \\textrm{X} \\textrm{B}\\_i \\\\\\\\\n  \\end{align\\*}\n  \\f]\n\n- for an eye-to-hand configuration\n  \\f[\n  \\begin{align\\*}\n  ^{g}{\\textrm{T}\\_b}^{(1)} \\hspace{0.2em} ^{b}\\textrm{T}\\_c \\hspace{0.2em} ^{c}{\\textrm{T}\\_t}^{(1)} &=\n  \\hspace{0.1em} ^{g}{\\textrm{T}\\_b}^{(2)} \\hspace{0.2em} ^{b}\\textrm{T}\\_c \\hspace{0.2em} ^{c}{\\textrm{T}\\_t}^{(2)} \\\\\\\\\n  (^{g}{\\textrm{T}\\_b}^{(2)})^{-1} \\hspace{0.2em} ^{g}{\\textrm{T}\\_b}^{(1)} \\hspace{0.2em} ^{b}\\textrm{T}\\_c &=\n  \\hspace{0.1em} ^{b}\\textrm{T}\\_c \\hspace{0.2em} ^{c}{\\textrm{T}\\_t}^{(2)} (^{c}{\\textrm{T}\\_t}^{(1)})^{-1} \\\\\\\\\n  \\textrm{A}\\_i \\textrm{X} &= \\textrm{X} \\textrm{B}\\_i \\\\\\\\\n  \\end{align\\*}\n  \\f]\n\n\\note\nAdditional information can be found on this [website](http://campar.in.tum.de/Chair/HandEyeCalibration).\n\\note\nA minimum of 2 motions with non parallel rotation axes are necessary to determine the hand-eye transformation.\nSo at least 3 different poses are required, but it is strongly recommended to use many more poses.\n\nPython prototype (for reference only):\n```python3\ncalibrateHandEye(R_gripper2base, t_gripper2base, R_target2cam, t_target2cam[, R_cam2gripper[, t_cam2gripper[, method]]]) -> R_cam2gripper, t_cam2gripper\n```","ref":"Evision.html#calibrateHandEye/4"},{"type":"function","title":"Evision.calibrateHandEye/5","doc":"Computes Hand-Eye calibration: \\f$\\_{}^{g}\\textrm{T}\\_c\\f$\n\n##### Positional Arguments\n- **r_gripper2base**: `[Evision.Mat]`.\n\n  Rotation part extracted from the homogeneous matrix that transforms a point\n  expressed in the gripper frame to the robot base frame (\\f$_{}^{b}\\textrm{T}_g\\f$).\n  This is a vector (`vector `) that contains the rotation, `(3x3)` rotation matrices or `(3x1)` rotation vectors,\n  for all the transformations from gripper frame to robot base frame.\n\n- **t_gripper2base**: `[Evision.Mat]`.\n\n  Translation part extracted from the homogeneous matrix that transforms a point\n  expressed in the gripper frame to the robot base frame (\\f$_{}^{b}\\textrm{T}_g\\f$).\n  This is a vector (`vector `) that contains the `(3x1)` translation vectors for all the transformations\n  from gripper frame to robot base frame.\n\n- **r_target2cam**: `[Evision.Mat]`.\n\n  Rotation part extracted from the homogeneous matrix that transforms a point\n  expressed in the target frame to the camera frame (\\f$_{}^{c}\\textrm{T}_t\\f$).\n  This is a vector (`vector `) that contains the rotation, `(3x3)` rotation matrices or `(3x1)` rotation vectors,\n  for all the transformations from calibration target frame to camera frame.\n\n- **t_target2cam**: `[Evision.Mat]`.\n\n  Rotation part extracted from the homogeneous matrix that transforms a point\n  expressed in the target frame to the camera frame (\\f$_{}^{c}\\textrm{T}_t\\f$).\n  This is a vector (`vector `) that contains the `(3x1)` translation vectors for all the transformations\n  from calibration target frame to camera frame.\n\n##### Keyword Arguments\n- **method**: `HandEyeCalibrationMethod`.\n\n  One of the implemented Hand-Eye calibration method, see cv::HandEyeCalibrationMethod\n\n##### Return\n- **r_cam2gripper**: `Evision.Mat.t()`.\n\n  Estimated `(3x3)` rotation part extracted from the homogeneous matrix that transforms a point\n  expressed in the camera frame to the gripper frame (\\f$_{}^{g}\\textrm{T}_c\\f$).\n\n- **t_cam2gripper**: `Evision.Mat.t()`.\n\n  Estimated `(3x1)` translation part extracted from the homogeneous matrix that transforms a point\n  expressed in the camera frame to the gripper frame (\\f$_{}^{g}\\textrm{T}_c\\f$).\n\nThe function performs the Hand-Eye calibration using various methods. One approach consists in estimating the\nrotation then the translation (separable solutions) and the following methods are implemented:\n- R. Tsai, R. Lenz A New Technique for Fully Autonomous and Efficient 3D Robotics Hand/EyeCalibration \\cite Tsai89\n- F. Park, B. Martin Robot Sensor Calibration: Solving AX = XB on the Euclidean Group \\cite Park94\n- R. Horaud, F. Dornaika Hand-Eye Calibration \\cite Horaud95\n\nAnother approach consists in estimating simultaneously the rotation and the translation (simultaneous solutions),\nwith the following implemented methods:\n- N. Andreff, R. Horaud, B. Espiau On-line Hand-Eye Calibration \\cite Andreff99\n- K. Daniilidis Hand-Eye Calibration Using Dual Quaternions \\cite Daniilidis98\n\nThe following picture describes the Hand-Eye calibration problem where the transformation between a camera (\"eye\")\nmounted on a robot gripper (\"hand\") has to be estimated. This configuration is called eye-in-hand.\nThe eye-to-hand configuration consists in a static camera observing a calibration pattern mounted on the robot\nend-effector. The transformation from the camera to the robot base frame can then be estimated by inputting\nthe suitable transformations to the function, see below.\n![](pics/hand-eye_figure.png)\nThe calibration procedure is the following:\n- a static calibration pattern is used to estimate the transformation between the target frame\n  and the camera frame\n\n- the robot gripper is moved in order to acquire several poses\n- for each pose, the homogeneous transformation between the gripper frame and the robot base frame is recorded using for\n  instance the robot kinematics\n  \\f[\n  \\begin{bmatrix}\n  X\\_b\\\\\\\\\n  Y\\_b\\\\\\\\\n  Z\\_b\\\\\\\\\n  1\n  \\end{bmatrix}=\n  \\begin{bmatrix}\n  \\_{}^{b}\\textrm{R}\\_g & \\_{}^{b}\\textrm{t}\\_g \\\\\\\\\n  0\\_{1 \\times 3} & 1\n  \\end{bmatrix}\n  \\begin{bmatrix}\n  X\\_g\\\\\\\\\n  Y\\_g\\\\\\\\\n  Z\\_g\\\\\\\\\n  1\n  \\end{bmatrix}\n  \\f]\n\n- for each pose, the homogeneous transformation between the calibration target frame and the camera frame is recorded using\n  for instance a pose estimation method (PnP) from 2D-3D point correspondences\n  \\f[\n  \\begin{bmatrix}\n  X\\_c\\\\\\\\\n  Y\\_c\\\\\\\\\n  Z\\_c\\\\\\\\\n  1\n  \\end{bmatrix}=\n  \\begin{bmatrix}\n  \\_{}^{c}\\textrm{R}\\_t & \\_{}^{c}\\textrm{t}\\_t \\\\\\\\\n  0\\_{1 \\times 3} & 1\n  \\end{bmatrix}\n  \\begin{bmatrix}\n  X\\_t\\\\\\\\\n  Y\\_t\\\\\\\\\n  Z\\_t\\\\\\\\\n  1\n  \\end{bmatrix}\n  \\f]\n\nThe Hand-Eye calibration procedure returns the following homogeneous transformation\n\\f[\n\\begin{bmatrix}\nX\\_g\\\\\\\\\nY\\_g\\\\\\\\\nZ\\_g\\\\\\\\\n1\n\\end{bmatrix}\n\\begin{bmatrix}\n\\_{}^{g}\\textrm{R}\\_c & \\_{}^{g}\\textrm{t}\\_c \\\\\\\\\n0\\_{1 \\times 3} & 1\n\\end{bmatrix}\n\\begin{bmatrix}\nX\\_c\\\\\\\\\nY\\_c\\\\\\\\\nZ\\_c\\\\\\\\\n1\n\\end{bmatrix}\n\\f]\nThis problem is also known as solving the \\f$\\mathbf{A}\\mathbf{X}=\\mathbf{X}\\mathbf{B}\\f$ equation:\n- for an eye-in-hand configuration\n  \\f[\n  \\begin{align\\*}\n  ^{b}{\\textrm{T}\\_g}^{(1)} \\hspace{0.2em} ^{g}\\textrm{T}\\_c \\hspace{0.2em} ^{c}{\\textrm{T}\\_t}^{(1)} &=\n  \\hspace{0.1em} ^{b}{\\textrm{T}\\_g}^{(2)} \\hspace{0.2em} ^{g}\\textrm{T}\\_c \\hspace{0.2em} ^{c}{\\textrm{T}\\_t}^{(2)} \\\\\\\\\n  (^{b}{\\textrm{T}\\_g}^{(2)})^{-1} \\hspace{0.2em} ^{b}{\\textrm{T}\\_g}^{(1)} \\hspace{0.2em} ^{g}\\textrm{T}\\_c &=\n  \\hspace{0.1em} ^{g}\\textrm{T}\\_c \\hspace{0.2em} ^{c}{\\textrm{T}\\_t}^{(2)} (^{c}{\\textrm{T}\\_t}^{(1)})^{-1} \\\\\\\\\n  \\textrm{A}\\_i \\textrm{X} &= \\textrm{X} \\textrm{B}\\_i \\\\\\\\\n  \\end{align\\*}\n  \\f]\n\n- for an eye-to-hand configuration\n  \\f[\n  \\begin{align\\*}\n  ^{g}{\\textrm{T}\\_b}^{(1)} \\hspace{0.2em} ^{b}\\textrm{T}\\_c \\hspace{0.2em} ^{c}{\\textrm{T}\\_t}^{(1)} &=\n  \\hspace{0.1em} ^{g}{\\textrm{T}\\_b}^{(2)} \\hspace{0.2em} ^{b}\\textrm{T}\\_c \\hspace{0.2em} ^{c}{\\textrm{T}\\_t}^{(2)} \\\\\\\\\n  (^{g}{\\textrm{T}\\_b}^{(2)})^{-1} \\hspace{0.2em} ^{g}{\\textrm{T}\\_b}^{(1)} \\hspace{0.2em} ^{b}\\textrm{T}\\_c &=\n  \\hspace{0.1em} ^{b}\\textrm{T}\\_c \\hspace{0.2em} ^{c}{\\textrm{T}\\_t}^{(2)} (^{c}{\\textrm{T}\\_t}^{(1)})^{-1} \\\\\\\\\n  \\textrm{A}\\_i \\textrm{X} &= \\textrm{X} \\textrm{B}\\_i \\\\\\\\\n  \\end{align\\*}\n  \\f]\n\n\\note\nAdditional information can be found on this [website](http://campar.in.tum.de/Chair/HandEyeCalibration).\n\\note\nA minimum of 2 motions with non parallel rotation axes are necessary to determine the hand-eye transformation.\nSo at least 3 different poses are required, but it is strongly recommended to use many more poses.\n\nPython prototype (for reference only):\n```python3\ncalibrateHandEye(R_gripper2base, t_gripper2base, R_target2cam, t_target2cam[, R_cam2gripper[, t_cam2gripper[, method]]]) -> R_cam2gripper, t_cam2gripper\n```","ref":"Evision.html#calibrateHandEye/5"},{"type":"function","title":"Evision.calibrateRobotWorldHandEye/1","doc":"","ref":"Evision.html#calibrateRobotWorldHandEye/1"},{"type":"function","title":"Evision.calibrateRobotWorldHandEye/4","doc":"Computes Robot-World/Hand-Eye calibration: \\f$\\_{}^{w}\\textrm{T}\\_b\\f$ and \\f$\\_{}^{c}\\textrm{T}\\_g\\f$\n\n##### Positional Arguments\n- **r_world2cam**: `[Evision.Mat]`.\n\n  Rotation part extracted from the homogeneous matrix that transforms a point\n  expressed in the world frame to the camera frame (\\f$_{}^{c}\\textrm{T}_w\\f$).\n  This is a vector (`vector `) that contains the rotation, `(3x3)` rotation matrices or `(3x1)` rotation vectors,\n  for all the transformations from world frame to the camera frame.\n\n- **t_world2cam**: `[Evision.Mat]`.\n\n  Translation part extracted from the homogeneous matrix that transforms a point\n  expressed in the world frame to the camera frame (\\f$_{}^{c}\\textrm{T}_w\\f$).\n  This is a vector (`vector `) that contains the `(3x1)` translation vectors for all the transformations\n  from world frame to the camera frame.\n\n- **r_base2gripper**: `[Evision.Mat]`.\n\n  Rotation part extracted from the homogeneous matrix that transforms a point\n  expressed in the robot base frame to the gripper frame (\\f$_{}^{g}\\textrm{T}_b\\f$).\n  This is a vector (`vector `) that contains the rotation, `(3x3)` rotation matrices or `(3x1)` rotation vectors,\n  for all the transformations from robot base frame to the gripper frame.\n\n- **t_base2gripper**: `[Evision.Mat]`.\n\n  Rotation part extracted from the homogeneous matrix that transforms a point\n  expressed in the robot base frame to the gripper frame (\\f$_{}^{g}\\textrm{T}_b\\f$).\n  This is a vector (`vector `) that contains the `(3x1)` translation vectors for all the transformations\n  from robot base frame to the gripper frame.\n\n##### Keyword Arguments\n- **method**: `RobotWorldHandEyeCalibrationMethod`.\n\n  One of the implemented Robot-World/Hand-Eye calibration method, see cv::RobotWorldHandEyeCalibrationMethod\n\n##### Return\n- **r_base2world**: `Evision.Mat.t()`.\n\n  Estimated `(3x3)` rotation part extracted from the homogeneous matrix that transforms a point\n  expressed in the robot base frame to the world frame (\\f$_{}^{w}\\textrm{T}_b\\f$).\n\n- **t_base2world**: `Evision.Mat.t()`.\n\n  Estimated `(3x1)` translation part extracted from the homogeneous matrix that transforms a point\n  expressed in the robot base frame to the world frame (\\f$_{}^{w}\\textrm{T}_b\\f$).\n\n- **r_gripper2cam**: `Evision.Mat.t()`.\n\n  Estimated `(3x3)` rotation part extracted from the homogeneous matrix that transforms a point\n  expressed in the gripper frame to the camera frame (\\f$_{}^{c}\\textrm{T}_g\\f$).\n\n- **t_gripper2cam**: `Evision.Mat.t()`.\n\n  Estimated `(3x1)` translation part extracted from the homogeneous matrix that transforms a point\n  expressed in the gripper frame to the camera frame (\\f$_{}^{c}\\textrm{T}_g\\f$).\n\nThe function performs the Robot-World/Hand-Eye calibration using various methods. One approach consists in estimating the\nrotation then the translation (separable solutions):\n- M. Shah, Solving the robot-world/hand-eye calibration problem using the kronecker product \\cite Shah2013SolvingTR\n\nAnother approach consists in estimating simultaneously the rotation and the translation (simultaneous solutions),\nwith the following implemented method:\n- A. Li, L. Wang, and D. Wu, Simultaneous robot-world and hand-eye calibration using dual-quaternions and kronecker product \\cite Li2010SimultaneousRA\n\nThe following picture describes the Robot-World/Hand-Eye calibration problem where the transformations between a robot and a world frame\nand between a robot gripper (\"hand\") and a camera (\"eye\") mounted at the robot end-effector have to be estimated.\n![](pics/robot-world_hand-eye_figure.png)\nThe calibration procedure is the following:\n- a static calibration pattern is used to estimate the transformation between the target frame\n  and the camera frame\n\n- the robot gripper is moved in order to acquire several poses\n- for each pose, the homogeneous transformation between the gripper frame and the robot base frame is recorded using for\n  instance the robot kinematics\n  \\f[\n  \\begin{bmatrix}\n  X\\_g\\\\\\\\\n  Y\\_g\\\\\\\\\n  Z\\_g\\\\\\\\\n  1\n  \\end{bmatrix}=\n  \\begin{bmatrix}\n  \\_{}^{g}\\textrm{R}\\_b & \\_{}^{g}\\textrm{t}\\_b \\\\\\\\\n  0\\_{1 \\times 3} & 1\n  \\end{bmatrix}\n  \\begin{bmatrix}\n  X\\_b\\\\\\\\\n  Y\\_b\\\\\\\\\n  Z\\_b\\\\\\\\\n  1\n  \\end{bmatrix}\n  \\f]\n\n- for each pose, the homogeneous transformation between the calibration target frame (the world frame) and the camera frame is recorded using\n  for instance a pose estimation method (PnP) from 2D-3D point correspondences\n  \\f[\n  \\begin{bmatrix}\n  X\\_c\\\\\\\\\n  Y\\_c\\\\\\\\\n  Z\\_c\\\\\\\\\n  1\n  \\end{bmatrix}=\n  \\begin{bmatrix}\n  \\_{}^{c}\\textrm{R}\\_w & \\_{}^{c}\\textrm{t}\\_w \\\\\\\\\n  0\\_{1 \\times 3} & 1\n  \\end{bmatrix}\n  \\begin{bmatrix}\n  X\\_w\\\\\\\\\n  Y\\_w\\\\\\\\\n  Z\\_w\\\\\\\\\n  1\n  \\end{bmatrix}\n  \\f]\n\nThe Robot-World/Hand-Eye calibration procedure returns the following homogeneous transformations\n\\f[\n\\begin{bmatrix}\nX\\_w\\\\\\\\\nY\\_w\\\\\\\\\nZ\\_w\\\\\\\\\n1\n\\end{bmatrix}\n\\begin{bmatrix}\n\\_{}^{w}\\textrm{R}\\_b & \\_{}^{w}\\textrm{t}\\_b \\\\\\\\\n0\\_{1 \\times 3} & 1\n\\end{bmatrix}\n\\begin{bmatrix}\nX\\_b\\\\\\\\\nY\\_b\\\\\\\\\nZ\\_b\\\\\\\\\n1\n\\end{bmatrix}\n\\f]\n\\f[\n\\begin{bmatrix}\nX\\_c\\\\\\\\\nY\\_c\\\\\\\\\nZ\\_c\\\\\\\\\n1\n\\end{bmatrix}\n\\begin{bmatrix}\n\\_{}^{c}\\textrm{R}\\_g & \\_{}^{c}\\textrm{t}\\_g \\\\\\\\\n0\\_{1 \\times 3} & 1\n\\end{bmatrix}\n\\begin{bmatrix}\nX\\_g\\\\\\\\\nY\\_g\\\\\\\\\nZ\\_g\\\\\\\\\n1\n\\end{bmatrix}\n\\f]\nThis problem is also known as solving the \\f$\\mathbf{A}\\mathbf{X}=\\mathbf{Z}\\mathbf{B}\\f$ equation, with:\n- \\f$\\mathbf{A} \\Leftrightarrow \\hspace{0.1em} \\_{}^{c}\\textrm{T}\\_w\\f$\n- \\f$\\mathbf{X} \\Leftrightarrow \\hspace{0.1em} \\_{}^{w}\\textrm{T}\\_b\\f$\n- \\f$\\mathbf{Z} \\Leftrightarrow \\hspace{0.1em} \\_{}^{c}\\textrm{T}\\_g\\f$\n- \\f$\\mathbf{B} \\Leftrightarrow \\hspace{0.1em} \\_{}^{g}\\textrm{T}\\_b\\f$\n\n\\note\nAt least 3 measurements are required (input vectors size must be greater or equal to 3).\n\nPython prototype (for reference only):\n```python3\ncalibrateRobotWorldHandEye(R_world2cam, t_world2cam, R_base2gripper, t_base2gripper[, R_base2world[, t_base2world[, R_gripper2cam[, t_gripper2cam[, method]]]]]) -> R_base2world, t_base2world, R_gripper2cam, t_gripper2cam\n```","ref":"Evision.html#calibrateRobotWorldHandEye/4"},{"type":"function","title":"Evision.calibrateRobotWorldHandEye/5","doc":"Computes Robot-World/Hand-Eye calibration: \\f$\\_{}^{w}\\textrm{T}\\_b\\f$ and \\f$\\_{}^{c}\\textrm{T}\\_g\\f$\n\n##### Positional Arguments\n- **r_world2cam**: `[Evision.Mat]`.\n\n  Rotation part extracted from the homogeneous matrix that transforms a point\n  expressed in the world frame to the camera frame (\\f$_{}^{c}\\textrm{T}_w\\f$).\n  This is a vector (`vector `) that contains the rotation, `(3x3)` rotation matrices or `(3x1)` rotation vectors,\n  for all the transformations from world frame to the camera frame.\n\n- **t_world2cam**: `[Evision.Mat]`.\n\n  Translation part extracted from the homogeneous matrix that transforms a point\n  expressed in the world frame to the camera frame (\\f$_{}^{c}\\textrm{T}_w\\f$).\n  This is a vector (`vector `) that contains the `(3x1)` translation vectors for all the transformations\n  from world frame to the camera frame.\n\n- **r_base2gripper**: `[Evision.Mat]`.\n\n  Rotation part extracted from the homogeneous matrix that transforms a point\n  expressed in the robot base frame to the gripper frame (\\f$_{}^{g}\\textrm{T}_b\\f$).\n  This is a vector (`vector `) that contains the rotation, `(3x3)` rotation matrices or `(3x1)` rotation vectors,\n  for all the transformations from robot base frame to the gripper frame.\n\n- **t_base2gripper**: `[Evision.Mat]`.\n\n  Rotation part extracted from the homogeneous matrix that transforms a point\n  expressed in the robot base frame to the gripper frame (\\f$_{}^{g}\\textrm{T}_b\\f$).\n  This is a vector (`vector `) that contains the `(3x1)` translation vectors for all the transformations\n  from robot base frame to the gripper frame.\n\n##### Keyword Arguments\n- **method**: `RobotWorldHandEyeCalibrationMethod`.\n\n  One of the implemented Robot-World/Hand-Eye calibration method, see cv::RobotWorldHandEyeCalibrationMethod\n\n##### Return\n- **r_base2world**: `Evision.Mat.t()`.\n\n  Estimated `(3x3)` rotation part extracted from the homogeneous matrix that transforms a point\n  expressed in the robot base frame to the world frame (\\f$_{}^{w}\\textrm{T}_b\\f$).\n\n- **t_base2world**: `Evision.Mat.t()`.\n\n  Estimated `(3x1)` translation part extracted from the homogeneous matrix that transforms a point\n  expressed in the robot base frame to the world frame (\\f$_{}^{w}\\textrm{T}_b\\f$).\n\n- **r_gripper2cam**: `Evision.Mat.t()`.\n\n  Estimated `(3x3)` rotation part extracted from the homogeneous matrix that transforms a point\n  expressed in the gripper frame to the camera frame (\\f$_{}^{c}\\textrm{T}_g\\f$).\n\n- **t_gripper2cam**: `Evision.Mat.t()`.\n\n  Estimated `(3x1)` translation part extracted from the homogeneous matrix that transforms a point\n  expressed in the gripper frame to the camera frame (\\f$_{}^{c}\\textrm{T}_g\\f$).\n\nThe function performs the Robot-World/Hand-Eye calibration using various methods. One approach consists in estimating the\nrotation then the translation (separable solutions):\n- M. Shah, Solving the robot-world/hand-eye calibration problem using the kronecker product \\cite Shah2013SolvingTR\n\nAnother approach consists in estimating simultaneously the rotation and the translation (simultaneous solutions),\nwith the following implemented method:\n- A. Li, L. Wang, and D. Wu, Simultaneous robot-world and hand-eye calibration using dual-quaternions and kronecker product \\cite Li2010SimultaneousRA\n\nThe following picture describes the Robot-World/Hand-Eye calibration problem where the transformations between a robot and a world frame\nand between a robot gripper (\"hand\") and a camera (\"eye\") mounted at the robot end-effector have to be estimated.\n![](pics/robot-world_hand-eye_figure.png)\nThe calibration procedure is the following:\n- a static calibration pattern is used to estimate the transformation between the target frame\n  and the camera frame\n\n- the robot gripper is moved in order to acquire several poses\n- for each pose, the homogeneous transformation between the gripper frame and the robot base frame is recorded using for\n  instance the robot kinematics\n  \\f[\n  \\begin{bmatrix}\n  X\\_g\\\\\\\\\n  Y\\_g\\\\\\\\\n  Z\\_g\\\\\\\\\n  1\n  \\end{bmatrix}=\n  \\begin{bmatrix}\n  \\_{}^{g}\\textrm{R}\\_b & \\_{}^{g}\\textrm{t}\\_b \\\\\\\\\n  0\\_{1 \\times 3} & 1\n  \\end{bmatrix}\n  \\begin{bmatrix}\n  X\\_b\\\\\\\\\n  Y\\_b\\\\\\\\\n  Z\\_b\\\\\\\\\n  1\n  \\end{bmatrix}\n  \\f]\n\n- for each pose, the homogeneous transformation between the calibration target frame (the world frame) and the camera frame is recorded using\n  for instance a pose estimation method (PnP) from 2D-3D point correspondences\n  \\f[\n  \\begin{bmatrix}\n  X\\_c\\\\\\\\\n  Y\\_c\\\\\\\\\n  Z\\_c\\\\\\\\\n  1\n  \\end{bmatrix}=\n  \\begin{bmatrix}\n  \\_{}^{c}\\textrm{R}\\_w & \\_{}^{c}\\textrm{t}\\_w \\\\\\\\\n  0\\_{1 \\times 3} & 1\n  \\end{bmatrix}\n  \\begin{bmatrix}\n  X\\_w\\\\\\\\\n  Y\\_w\\\\\\\\\n  Z\\_w\\\\\\\\\n  1\n  \\end{bmatrix}\n  \\f]\n\nThe Robot-World/Hand-Eye calibration procedure returns the following homogeneous transformations\n\\f[\n\\begin{bmatrix}\nX\\_w\\\\\\\\\nY\\_w\\\\\\\\\nZ\\_w\\\\\\\\\n1\n\\end{bmatrix}\n\\begin{bmatrix}\n\\_{}^{w}\\textrm{R}\\_b & \\_{}^{w}\\textrm{t}\\_b \\\\\\\\\n0\\_{1 \\times 3} & 1\n\\end{bmatrix}\n\\begin{bmatrix}\nX\\_b\\\\\\\\\nY\\_b\\\\\\\\\nZ\\_b\\\\\\\\\n1\n\\end{bmatrix}\n\\f]\n\\f[\n\\begin{bmatrix}\nX\\_c\\\\\\\\\nY\\_c\\\\\\\\\nZ\\_c\\\\\\\\\n1\n\\end{bmatrix}\n\\begin{bmatrix}\n\\_{}^{c}\\textrm{R}\\_g & \\_{}^{c}\\textrm{t}\\_g \\\\\\\\\n0\\_{1 \\times 3} & 1\n\\end{bmatrix}\n\\begin{bmatrix}\nX\\_g\\\\\\\\\nY\\_g\\\\\\\\\nZ\\_g\\\\\\\\\n1\n\\end{bmatrix}\n\\f]\nThis problem is also known as solving the \\f$\\mathbf{A}\\mathbf{X}=\\mathbf{Z}\\mathbf{B}\\f$ equation, with:\n- \\f$\\mathbf{A} \\Leftrightarrow \\hspace{0.1em} \\_{}^{c}\\textrm{T}\\_w\\f$\n- \\f$\\mathbf{X} \\Leftrightarrow \\hspace{0.1em} \\_{}^{w}\\textrm{T}\\_b\\f$\n- \\f$\\mathbf{Z} \\Leftrightarrow \\hspace{0.1em} \\_{}^{c}\\textrm{T}\\_g\\f$\n- \\f$\\mathbf{B} \\Leftrightarrow \\hspace{0.1em} \\_{}^{g}\\textrm{T}\\_b\\f$\n\n\\note\nAt least 3 measurements are required (input vectors size must be greater or equal to 3).\n\nPython prototype (for reference only):\n```python3\ncalibrateRobotWorldHandEye(R_world2cam, t_world2cam, R_base2gripper, t_base2gripper[, R_base2world[, t_base2world[, R_gripper2cam[, t_gripper2cam[, method]]]]]) -> R_base2world, t_base2world, R_gripper2cam, t_gripper2cam\n```","ref":"Evision.html#calibrateRobotWorldHandEye/5"},{"type":"function","title":"Evision.calibrationMatrixValues/1","doc":"","ref":"Evision.html#calibrationMatrixValues/1"},{"type":"function","title":"Evision.calibrationMatrixValues/4","doc":"Computes useful camera characteristics from the camera intrinsic matrix.\n\n##### Positional Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input camera intrinsic matrix that can be estimated by #calibrateCamera or\n  #stereoCalibrate .\n\n- **imageSize**: `Size`.\n\n  Input image size in pixels.\n\n- **apertureWidth**: `double`.\n\n  Physical width in mm of the sensor.\n\n- **apertureHeight**: `double`.\n\n  Physical height in mm of the sensor.\n\n##### Return\n- **fovx**: `double`.\n\n  Output field of view in degrees along the horizontal sensor axis.\n\n- **fovy**: `double`.\n\n  Output field of view in degrees along the vertical sensor axis.\n\n- **focalLength**: `double`.\n\n  Focal length of the lens in mm.\n\n- **principalPoint**: `Point2d`.\n\n  Principal point in mm.\n\n- **aspectRatio**: `double`.\n\n  \\f$f_y/f_x\\f$\n\nThe function computes various useful camera characteristics from the previously estimated camera\nmatrix.\n**Note**: \nDo keep in mind that the unity measure 'mm' stands for whatever unit of measure one chooses for\nthe chessboard pitch (it can thus be any value).\n\nPython prototype (for reference only):\n```python3\ncalibrationMatrixValues(cameraMatrix, imageSize, apertureWidth, apertureHeight) -> fovx, fovy, focalLength, principalPoint, aspectRatio\n```","ref":"Evision.html#calibrationMatrixValues/4"},{"type":"function","title":"Evision.camShift/1","doc":"","ref":"Evision.html#camShift/1"},{"type":"function","title":"Evision.camShift/3","doc":"Finds an object center, size, and orientation.\n\n##### Positional Arguments\n- **probImage**: `Evision.Mat`.\n\n  Back projection of the object histogram. See calcBackProject.\n\n- **criteria**: `TermCriteria`.\n\n  Stop criteria for the underlying meanShift.\n  returns\n  (in old interfaces) Number of iterations CAMSHIFT took to converge\n  The function implements the CAMSHIFT object tracking algorithm @cite Bradski98 . First, it finds an\n  object center using meanShift and then adjusts the window size and finds the optimal rotation. The\n  function returns the rotated rectangle structure that includes the object position, size, and\n  orientation. The next position of the search window can be obtained with RotatedRect::boundingRect()\n\n##### Return\n- **retval**: `{centre={x, y}, size={s1, s2}, angle}`\n- **window**: `Rect`.\n\n  Initial search window.\n\nSee the OpenCV sample camshiftdemo.c that tracks colored objects.\n**Note**: \n- (Python) A sample explaining the camshift tracking algorithm can be found at\n  opencv_source_code/samples/python/camshift.py\n\nPython prototype (for reference only):\n```python3\nCamShift(probImage, window, criteria) -> retval, window\n```","ref":"Evision.html#camShift/3"},{"type":"function","title":"Evision.canny/1","doc":"","ref":"Evision.html#canny/1"},{"type":"function","title":"Evision.canny/3","doc":"Finds edges in an image using the Canny algorithm @cite Canny86 .\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  8-bit input image.\n\n- **threshold1**: `double`.\n\n  first threshold for the hysteresis procedure.\n\n- **threshold2**: `double`.\n\n  second threshold for the hysteresis procedure.\n\n##### Keyword Arguments\n- **apertureSize**: `integer()`.\n\n  aperture size for the Sobel operator.\n\n- **l2gradient**: `bool`.\n\n  a flag, indicating whether a more accurate \\f$L_2\\f$ norm\n  \\f$=\\sqrt{(dI/dx)^2 + (dI/dy)^2}\\f$ should be used to calculate the image gradient magnitude (\n  L2gradient=true ), or whether the default \\f$L_1\\f$ norm \\f$=|dI/dx|+|dI/dy|\\f$ is enough (\n  L2gradient=false ).\n\n##### Return\n- **edges**: `Evision.Mat.t()`.\n\n  output edge map; single channels 8-bit image, which has the same size as image .\n\nThe function finds edges in the input image and marks them in the output map edges using the\nCanny algorithm. The smallest value between threshold1 and threshold2 is used for edge linking. The\nlargest value is used to find initial segments of strong edges. See\n \n\nPython prototype (for reference only):\n```python3\nCanny(image, threshold1, threshold2[, edges[, apertureSize[, L2gradient]]]) -> edges\n```","ref":"Evision.html#canny/3"},{"type":"function","title":"Evision.canny/4","doc":"#### Variant 1:\nCanny\n\n##### Positional Arguments\n- **dx**: `Evision.Mat`.\n\n  16-bit x derivative of input image (CV_16SC1 or CV_16SC3).\n\n- **dy**: `Evision.Mat`.\n\n  16-bit y derivative of input image (same type as dx).\n\n- **threshold1**: `double`.\n\n  first threshold for the hysteresis procedure.\n\n- **threshold2**: `double`.\n\n  second threshold for the hysteresis procedure.\n\n##### Keyword Arguments\n- **l2gradient**: `bool`.\n\n  a flag, indicating whether a more accurate \\f$L_2\\f$ norm\n  \\f$=\\sqrt{(dI/dx)^2 + (dI/dy)^2}\\f$ should be used to calculate the image gradient magnitude (\n  L2gradient=true ), or whether the default \\f$L_1\\f$ norm \\f$=|dI/dx|+|dI/dy|\\f$ is enough (\n  L2gradient=false ).\n\n##### Return\n- **edges**: `Evision.Mat.t()`.\n\n  output edge map; single channels 8-bit image, which has the same size as image .\n\nFinds edges in an image using the Canny algorithm with custom image gradient.\n\nPython prototype (for reference only):\n```python3\nCanny(dx, dy, threshold1, threshold2[, edges[, L2gradient]]) -> edges\n```\n#### Variant 2:\nFinds edges in an image using the Canny algorithm @cite Canny86 .\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  8-bit input image.\n\n- **threshold1**: `double`.\n\n  first threshold for the hysteresis procedure.\n\n- **threshold2**: `double`.\n\n  second threshold for the hysteresis procedure.\n\n##### Keyword Arguments\n- **apertureSize**: `integer()`.\n\n  aperture size for the Sobel operator.\n\n- **l2gradient**: `bool`.\n\n  a flag, indicating whether a more accurate \\f$L_2\\f$ norm\n  \\f$=\\sqrt{(dI/dx)^2 + (dI/dy)^2}\\f$ should be used to calculate the image gradient magnitude (\n  L2gradient=true ), or whether the default \\f$L_1\\f$ norm \\f$=|dI/dx|+|dI/dy|\\f$ is enough (\n  L2gradient=false ).\n\n##### Return\n- **edges**: `Evision.Mat.t()`.\n\n  output edge map; single channels 8-bit image, which has the same size as image .\n\nThe function finds edges in the input image and marks them in the output map edges using the\nCanny algorithm. The smallest value between threshold1 and threshold2 is used for edge linking. The\nlargest value is used to find initial segments of strong edges. See\n \n\nPython prototype (for reference only):\n```python3\nCanny(image, threshold1, threshold2[, edges[, apertureSize[, L2gradient]]]) -> edges\n```","ref":"Evision.html#canny/4"},{"type":"function","title":"Evision.canny/5","doc":"Canny\n\n##### Positional Arguments\n- **dx**: `Evision.Mat`.\n\n  16-bit x derivative of input image (CV_16SC1 or CV_16SC3).\n\n- **dy**: `Evision.Mat`.\n\n  16-bit y derivative of input image (same type as dx).\n\n- **threshold1**: `double`.\n\n  first threshold for the hysteresis procedure.\n\n- **threshold2**: `double`.\n\n  second threshold for the hysteresis procedure.\n\n##### Keyword Arguments\n- **l2gradient**: `bool`.\n\n  a flag, indicating whether a more accurate \\f$L_2\\f$ norm\n  \\f$=\\sqrt{(dI/dx)^2 + (dI/dy)^2}\\f$ should be used to calculate the image gradient magnitude (\n  L2gradient=true ), or whether the default \\f$L_1\\f$ norm \\f$=|dI/dx|+|dI/dy|\\f$ is enough (\n  L2gradient=false ).\n\n##### Return\n- **edges**: `Evision.Mat.t()`.\n\n  output edge map; single channels 8-bit image, which has the same size as image .\n\nFinds edges in an image using the Canny algorithm with custom image gradient.\n\nPython prototype (for reference only):\n```python3\nCanny(dx, dy, threshold1, threshold2[, edges[, L2gradient]]) -> edges\n```","ref":"Evision.html#canny/5"},{"type":"function","title":"Evision.cartToPolar/1","doc":"","ref":"Evision.html#cartToPolar/1"},{"type":"function","title":"Evision.cartToPolar/2","doc":"Calculates the magnitude and angle of 2D vectors.\n\n##### Positional Arguments\n- **x**: `Evision.Mat`.\n\n  array of x-coordinates; this must be a single-precision or\n  double-precision floating-point array.\n\n- **y**: `Evision.Mat`.\n\n  array of y-coordinates, that must have the same size and same type as x.\n\n##### Keyword Arguments\n- **angleInDegrees**: `bool`.\n\n  a flag, indicating whether the angles are measured\n  in radians (which is by default), or in degrees.\n\n##### Return\n- **magnitude**: `Evision.Mat.t()`.\n\n  output array of magnitudes of the same size and type as x.\n\n- **angle**: `Evision.Mat.t()`.\n\n  output array of angles that has the same size and type as\n  x; the angles are measured in radians (from 0 to 2\\*Pi) or in degrees (0 to 360 degrees).\n\nThe function cv::cartToPolar calculates either the magnitude, angle, or both\nfor every 2D vector (x(I),y(I)):\n\\f[\\begin{array}{l} \\texttt{magnitude} (I)= \\sqrt{\\texttt{x}(I)^2+\\texttt{y}(I)^2} , \\\\\\\\ \\texttt{angle} (I)= \\texttt{atan2} ( \\texttt{y} (I), \\texttt{x} (I))\\[ \\cdot180 / \\pi ] \\end{array}\\f]\nThe angles are calculated with accuracy about 0.3 degrees. For the point\n(0,0), the angle is set to 0.\n@sa Sobel, Scharr\n\nPython prototype (for reference only):\n```python3\ncartToPolar(x, y[, magnitude[, angle[, angleInDegrees]]]) -> magnitude, angle\n```","ref":"Evision.html#cartToPolar/2"},{"type":"function","title":"Evision.cartToPolar/3","doc":"Calculates the magnitude and angle of 2D vectors.\n\n##### Positional Arguments\n- **x**: `Evision.Mat`.\n\n  array of x-coordinates; this must be a single-precision or\n  double-precision floating-point array.\n\n- **y**: `Evision.Mat`.\n\n  array of y-coordinates, that must have the same size and same type as x.\n\n##### Keyword Arguments\n- **angleInDegrees**: `bool`.\n\n  a flag, indicating whether the angles are measured\n  in radians (which is by default), or in degrees.\n\n##### Return\n- **magnitude**: `Evision.Mat.t()`.\n\n  output array of magnitudes of the same size and type as x.\n\n- **angle**: `Evision.Mat.t()`.\n\n  output array of angles that has the same size and type as\n  x; the angles are measured in radians (from 0 to 2\\*Pi) or in degrees (0 to 360 degrees).\n\nThe function cv::cartToPolar calculates either the magnitude, angle, or both\nfor every 2D vector (x(I),y(I)):\n\\f[\\begin{array}{l} \\texttt{magnitude} (I)= \\sqrt{\\texttt{x}(I)^2+\\texttt{y}(I)^2} , \\\\\\\\ \\texttt{angle} (I)= \\texttt{atan2} ( \\texttt{y} (I), \\texttt{x} (I))\\[ \\cdot180 / \\pi ] \\end{array}\\f]\nThe angles are calculated with accuracy about 0.3 degrees. For the point\n(0,0), the angle is set to 0.\n@sa Sobel, Scharr\n\nPython prototype (for reference only):\n```python3\ncartToPolar(x, y[, magnitude[, angle[, angleInDegrees]]]) -> magnitude, angle\n```","ref":"Evision.html#cartToPolar/3"},{"type":"function","title":"Evision.checkChessboard/1","doc":"","ref":"Evision.html#checkChessboard/1"},{"type":"function","title":"Evision.checkChessboard/2","doc":"checkChessboard\n\n##### Positional Arguments\n- **img**: `Evision.Mat`\n- **size**: `Size`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ncheckChessboard(img, size) -> retval\n```","ref":"Evision.html#checkChessboard/2"},{"type":"function","title":"Evision.checkHardwareSupport/1","doc":"Returns true if the specified feature is supported by the host hardware.\n\n##### Positional Arguments\n- **feature**: `integer()`.\n\n  The feature of interest, one of cv::CpuFeatures\n\n##### Return\n- **retval**: `bool`\n\nThe function returns true if the host hardware supports the specified feature. When user calls\nsetUseOptimized(false), the subsequent calls to checkHardwareSupport() will return false until\nsetUseOptimized(true) is called. This way user can dynamically switch on and off the optimized code\nin OpenCV.\n\nPython prototype (for reference only):\n```python3\ncheckHardwareSupport(feature) -> retval\n```","ref":"Evision.html#checkHardwareSupport/1"},{"type":"function","title":"Evision.checkRange/1","doc":"Checks every element of an input array for invalid values.\n\n##### Positional Arguments\n- **a**: `Evision.Mat`.\n\n  input array.\n\n##### Keyword Arguments\n- **quiet**: `bool`.\n\n  a flag, indicating whether the functions quietly return false when the array elements\n  are out of range or they throw an exception.\n\n- **minVal**: `double`.\n\n  inclusive lower boundary of valid values range.\n\n- **maxVal**: `double`.\n\n  exclusive upper boundary of valid values range.\n\n##### Return\n- **retval**: `bool`\n- **pos**: `Point*`.\n\n  optional output parameter, when not NULL, must be a pointer to array of src.dims\n  elements.\n\nThe function cv::checkRange checks that every array element is neither NaN nor infinite. When minVal \\>\n- DBL_MAX and maxVal \\  retval, pos\n```","ref":"Evision.html#checkRange/1"},{"type":"function","title":"Evision.checkRange/2","doc":"Checks every element of an input array for invalid values.\n\n##### Positional Arguments\n- **a**: `Evision.Mat`.\n\n  input array.\n\n##### Keyword Arguments\n- **quiet**: `bool`.\n\n  a flag, indicating whether the functions quietly return false when the array elements\n  are out of range or they throw an exception.\n\n- **minVal**: `double`.\n\n  inclusive lower boundary of valid values range.\n\n- **maxVal**: `double`.\n\n  exclusive upper boundary of valid values range.\n\n##### Return\n- **retval**: `bool`\n- **pos**: `Point*`.\n\n  optional output parameter, when not NULL, must be a pointer to array of src.dims\n  elements.\n\nThe function cv::checkRange checks that every array element is neither NaN nor infinite. When minVal \\>\n- DBL_MAX and maxVal \\  retval, pos\n```","ref":"Evision.html#checkRange/2"},{"type":"function","title":"Evision.circle/1","doc":"","ref":"Evision.html#circle/1"},{"type":"function","title":"Evision.circle/4","doc":"Draws a circle.\n\n##### Positional Arguments\n- **center**: `Point`.\n\n  Center of the circle.\n\n- **radius**: `integer()`.\n\n  Radius of the circle.\n\n- **color**: `Evision.scalar()`.\n\n  Circle color.\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n\n  Thickness of the circle outline, if positive. Negative values, like #FILLED,\n  mean that a filled circle is to be drawn.\n\n- **lineType**: `integer()`.\n\n  Type of the circle boundary. See #LineTypes\n\n- **shift**: `integer()`.\n\n  Number of fractional bits in the coordinates of the center and in the radius value.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  Image where the circle is drawn.\n\nThe function cv::circle draws a simple or filled circle with a given center and radius.\n\nPython prototype (for reference only):\n```python3\ncircle(img, center, radius, color[, thickness[, lineType[, shift]]]) -> img\n```","ref":"Evision.html#circle/4"},{"type":"function","title":"Evision.circle/5","doc":"Draws a circle.\n\n##### Positional Arguments\n- **center**: `Point`.\n\n  Center of the circle.\n\n- **radius**: `integer()`.\n\n  Radius of the circle.\n\n- **color**: `Evision.scalar()`.\n\n  Circle color.\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n\n  Thickness of the circle outline, if positive. Negative values, like #FILLED,\n  mean that a filled circle is to be drawn.\n\n- **lineType**: `integer()`.\n\n  Type of the circle boundary. See #LineTypes\n\n- **shift**: `integer()`.\n\n  Number of fractional bits in the coordinates of the center and in the radius value.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  Image where the circle is drawn.\n\nThe function cv::circle draws a simple or filled circle with a given center and radius.\n\nPython prototype (for reference only):\n```python3\ncircle(img, center, radius, color[, thickness[, lineType[, shift]]]) -> img\n```","ref":"Evision.html#circle/5"},{"type":"function","title":"Evision.clipLine/1","doc":"","ref":"Evision.html#clipLine/1"},{"type":"function","title":"Evision.clipLine/3","doc":"clipLine\n\n##### Positional Arguments\n- **imgRect**: `Rect`.\n\n  Image rectangle.\n\n##### Return\n- **retval**: `bool`\n- **pt1**: `Point`.\n\n  First line point.\n\n- **pt2**: `Point`.\n\n  Second line point.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nclipLine(imgRect, pt1, pt2) -> retval, pt1, pt2\n```","ref":"Evision.html#clipLine/3"},{"type":"function","title":"Evision.colorChange/1","doc":"","ref":"Evision.html#colorChange/1"},{"type":"function","title":"Evision.colorChange/2","doc":"Given an original color image, two differently colored versions of this image can be mixed\nseamlessly.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n- **mask**: `Evision.Mat`.\n\n  Input 8-bit 1 or 3-channel image.\n\n##### Keyword Arguments\n- **red_mul**: `float`.\n\n  R-channel multiply factor.\n\n- **green_mul**: `float`.\n\n  G-channel multiply factor.\n\n- **blue_mul**: `float`.\n\n  B-channel multiply factor.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as src .\n\nMultiplication factor is between .5 to 2.5.\n\nPython prototype (for reference only):\n```python3\ncolorChange(src, mask[, dst[, red_mul[, green_mul[, blue_mul]]]]) -> dst\n```","ref":"Evision.html#colorChange/2"},{"type":"function","title":"Evision.colorChange/3","doc":"Given an original color image, two differently colored versions of this image can be mixed\nseamlessly.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n- **mask**: `Evision.Mat`.\n\n  Input 8-bit 1 or 3-channel image.\n\n##### Keyword Arguments\n- **red_mul**: `float`.\n\n  R-channel multiply factor.\n\n- **green_mul**: `float`.\n\n  G-channel multiply factor.\n\n- **blue_mul**: `float`.\n\n  B-channel multiply factor.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as src .\n\nMultiplication factor is between .5 to 2.5.\n\nPython prototype (for reference only):\n```python3\ncolorChange(src, mask[, dst[, red_mul[, green_mul[, blue_mul]]]]) -> dst\n```","ref":"Evision.html#colorChange/3"},{"type":"function","title":"Evision.compare/1","doc":"","ref":"Evision.html#compare/1"},{"type":"function","title":"Evision.compare/3","doc":"Performs the per-element comparison of two arrays or an array and scalar value.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array or a scalar; when it is an array, it must have a single channel.\n\n- **src2**: `Evision.Mat`.\n\n  second input array or a scalar; when it is an array, it must have a single channel.\n\n- **cmpop**: `integer()`.\n\n  a flag, that specifies correspondence between the arrays (cv::CmpTypes)\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of type ref CV_8U that has the same size and the same number of channels as\n  the input arrays.\n\nThe function compares:\n   Elements of two arrays when src1 and src2 have the same size:\n\\f[\\texttt{dst} (I) =  \\texttt{src1} (I)  \\,\\texttt{cmpop}\\, \\texttt{src2} (I)\\f]\n   Elements of src1 with a scalar src2 when src2 is constructed from\nScalar or has a single element:\n\\f[\\texttt{dst} (I) =  \\texttt{src1}(I) \\,\\texttt{cmpop}\\,  \\texttt{src2}\\f]\n   src1 with elements of src2 when src1 is constructed from Scalar or\nhas a single element:\n\\f[\\texttt{dst} (I) =  \\texttt{src1}  \\,\\texttt{cmpop}\\, \\texttt{src2} (I)\\f]\nWhen the comparison result is true, the corresponding element of output\narray is set to 255. The comparison operations can be replaced with the\nequivalent matrix expressions:\n```cpp\nMat dst1 = src1 >= src2;\nMat dst2 = src1 < 8;\n...\n```\n@sa checkRange, min, max, threshold\n\nPython prototype (for reference only):\n```python3\ncompare(src1, src2, cmpop[, dst]) -> dst\n```","ref":"Evision.html#compare/3"},{"type":"function","title":"Evision.compare/4","doc":"Performs the per-element comparison of two arrays or an array and scalar value.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array or a scalar; when it is an array, it must have a single channel.\n\n- **src2**: `Evision.Mat`.\n\n  second input array or a scalar; when it is an array, it must have a single channel.\n\n- **cmpop**: `integer()`.\n\n  a flag, that specifies correspondence between the arrays (cv::CmpTypes)\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of type ref CV_8U that has the same size and the same number of channels as\n  the input arrays.\n\nThe function compares:\n   Elements of two arrays when src1 and src2 have the same size:\n\\f[\\texttt{dst} (I) =  \\texttt{src1} (I)  \\,\\texttt{cmpop}\\, \\texttt{src2} (I)\\f]\n   Elements of src1 with a scalar src2 when src2 is constructed from\nScalar or has a single element:\n\\f[\\texttt{dst} (I) =  \\texttt{src1}(I) \\,\\texttt{cmpop}\\,  \\texttt{src2}\\f]\n   src1 with elements of src2 when src1 is constructed from Scalar or\nhas a single element:\n\\f[\\texttt{dst} (I) =  \\texttt{src1}  \\,\\texttt{cmpop}\\, \\texttt{src2} (I)\\f]\nWhen the comparison result is true, the corresponding element of output\narray is set to 255. The comparison operations can be replaced with the\nequivalent matrix expressions:\n```cpp\nMat dst1 = src1 >= src2;\nMat dst2 = src1 < 8;\n...\n```\n@sa checkRange, min, max, threshold\n\nPython prototype (for reference only):\n```python3\ncompare(src1, src2, cmpop[, dst]) -> dst\n```","ref":"Evision.html#compare/4"},{"type":"function","title":"Evision.compareHist/1","doc":"","ref":"Evision.html#compareHist/1"},{"type":"function","title":"Evision.compareHist/3","doc":"Compares two histograms.\n\n##### Positional Arguments\n- **h1**: `Evision.Mat`.\n\n  First compared histogram.\n\n- **h2**: `Evision.Mat`.\n\n  Second compared histogram of the same size as H1 .\n\n- **method**: `integer()`.\n\n  Comparison method, see #HistCompMethods\n\n##### Return\n- **retval**: `double`\n\nThe function cv::compareHist compares two dense or two sparse histograms using the specified method.\nThe function returns \\f$d(H\\_1, H\\_2)\\f$ .\nWhile the function works well with 1-, 2-, 3-dimensional dense histograms, it may not be suitable\nfor high-dimensional sparse histograms. In such histograms, because of aliasing and sampling\nproblems, the coordinates of non-zero histogram bins can slightly shift. To compare such histograms\nor more general sparse configurations of weighted points, consider using the #EMD function.\n\nPython prototype (for reference only):\n```python3\ncompareHist(H1, H2, method) -> retval\n```","ref":"Evision.html#compareHist/3"},{"type":"function","title":"Evision.completeSymm/1","doc":"Copies the lower or the upper half of a square matrix to its another half.\n##### Keyword Arguments\n- **lowerToUpper**: `bool`.\n\n  operation flag; if true, the lower half is copied to\n  the upper half. Otherwise, the upper half is copied to the lower half.\n\n##### Return\n- **m**: `Evision.Mat.t()`.\n\n  input-output floating-point square matrix.\n\nThe function cv::completeSymm copies the lower or the upper half of a square matrix to\nits another half. The matrix diagonal remains unchanged:\n- \\f$\\texttt{m}\\_{ij}=\\texttt{m}\\_{ji}\\f$ for \\f$i > j\\f$ if\n  lowerToUpper=false\n\n- \\f$\\texttt{m}\\_{ij}=\\texttt{m}\\_{ji}\\f$ for \\f$i   m\n```","ref":"Evision.html#completeSymm/1"},{"type":"function","title":"Evision.completeSymm/2","doc":"Copies the lower or the upper half of a square matrix to its another half.\n##### Keyword Arguments\n- **lowerToUpper**: `bool`.\n\n  operation flag; if true, the lower half is copied to\n  the upper half. Otherwise, the upper half is copied to the lower half.\n\n##### Return\n- **m**: `Evision.Mat.t()`.\n\n  input-output floating-point square matrix.\n\nThe function cv::completeSymm copies the lower or the upper half of a square matrix to\nits another half. The matrix diagonal remains unchanged:\n- \\f$\\texttt{m}\\_{ij}=\\texttt{m}\\_{ji}\\f$ for \\f$i > j\\f$ if\n  lowerToUpper=false\n\n- \\f$\\texttt{m}\\_{ij}=\\texttt{m}\\_{ji}\\f$ for \\f$i   m\n```","ref":"Evision.html#completeSymm/2"},{"type":"function","title":"Evision.composeRT/1","doc":"","ref":"Evision.html#composeRT/1"},{"type":"function","title":"Evision.composeRT/4","doc":"Combines two rotation-and-shift transformations.\n\n##### Positional Arguments\n- **rvec1**: `Evision.Mat`.\n\n  First rotation vector.\n\n- **tvec1**: `Evision.Mat`.\n\n  First translation vector.\n\n- **rvec2**: `Evision.Mat`.\n\n  Second rotation vector.\n\n- **tvec2**: `Evision.Mat`.\n\n  Second translation vector.\n\n##### Return\n- **rvec3**: `Evision.Mat.t()`.\n\n  Output rotation vector of the superposition.\n\n- **tvec3**: `Evision.Mat.t()`.\n\n  Output translation vector of the superposition.\n\n- **dr3dr1**: `Evision.Mat.t()`.\n\n  Optional output derivative of rvec3 with regard to rvec1\n\n- **dr3dt1**: `Evision.Mat.t()`.\n\n  Optional output derivative of rvec3 with regard to tvec1\n\n- **dr3dr2**: `Evision.Mat.t()`.\n\n  Optional output derivative of rvec3 with regard to rvec2\n\n- **dr3dt2**: `Evision.Mat.t()`.\n\n  Optional output derivative of rvec3 with regard to tvec2\n\n- **dt3dr1**: `Evision.Mat.t()`.\n\n  Optional output derivative of tvec3 with regard to rvec1\n\n- **dt3dt1**: `Evision.Mat.t()`.\n\n  Optional output derivative of tvec3 with regard to tvec1\n\n- **dt3dr2**: `Evision.Mat.t()`.\n\n  Optional output derivative of tvec3 with regard to rvec2\n\n- **dt3dt2**: `Evision.Mat.t()`.\n\n  Optional output derivative of tvec3 with regard to tvec2\n\nThe functions compute:\n\\f[\\begin{array}{l} \\texttt{rvec3} =  \\mathrm{rodrigues} ^{-1} \\left ( \\mathrm{rodrigues} ( \\texttt{rvec2} )  \\cdot \\mathrm{rodrigues} ( \\texttt{rvec1} ) \\right )  \\\\\\\\ \\texttt{tvec3} =  \\mathrm{rodrigues} ( \\texttt{rvec2} )  \\cdot \\texttt{tvec1} +  \\texttt{tvec2} \\end{array} ,\\f]\nwhere \\f$\\mathrm{rodrigues}\\f$ denotes a rotation vector to a rotation matrix transformation, and\n\\f$\\mathrm{rodrigues}^{-1}\\f$ denotes the inverse transformation. See #Rodrigues for details.\nAlso, the functions can compute the derivatives of the output vectors with regards to the input\nvectors (see #matMulDeriv ). The functions are used inside #stereoCalibrate but can also be used in\nyour own code where Levenberg-Marquardt or another gradient-based solver is used to optimize a\nfunction that contains a matrix multiplication.\n\nPython prototype (for reference only):\n```python3\ncomposeRT(rvec1, tvec1, rvec2, tvec2[, rvec3[, tvec3[, dr3dr1[, dr3dt1[, dr3dr2[, dr3dt2[, dt3dr1[, dt3dt1[, dt3dr2[, dt3dt2]]]]]]]]]]) -> rvec3, tvec3, dr3dr1, dr3dt1, dr3dr2, dr3dt2, dt3dr1, dt3dt1, dt3dr2, dt3dt2\n```","ref":"Evision.html#composeRT/4"},{"type":"function","title":"Evision.composeRT/5","doc":"Combines two rotation-and-shift transformations.\n\n##### Positional Arguments\n- **rvec1**: `Evision.Mat`.\n\n  First rotation vector.\n\n- **tvec1**: `Evision.Mat`.\n\n  First translation vector.\n\n- **rvec2**: `Evision.Mat`.\n\n  Second rotation vector.\n\n- **tvec2**: `Evision.Mat`.\n\n  Second translation vector.\n\n##### Return\n- **rvec3**: `Evision.Mat.t()`.\n\n  Output rotation vector of the superposition.\n\n- **tvec3**: `Evision.Mat.t()`.\n\n  Output translation vector of the superposition.\n\n- **dr3dr1**: `Evision.Mat.t()`.\n\n  Optional output derivative of rvec3 with regard to rvec1\n\n- **dr3dt1**: `Evision.Mat.t()`.\n\n  Optional output derivative of rvec3 with regard to tvec1\n\n- **dr3dr2**: `Evision.Mat.t()`.\n\n  Optional output derivative of rvec3 with regard to rvec2\n\n- **dr3dt2**: `Evision.Mat.t()`.\n\n  Optional output derivative of rvec3 with regard to tvec2\n\n- **dt3dr1**: `Evision.Mat.t()`.\n\n  Optional output derivative of tvec3 with regard to rvec1\n\n- **dt3dt1**: `Evision.Mat.t()`.\n\n  Optional output derivative of tvec3 with regard to tvec1\n\n- **dt3dr2**: `Evision.Mat.t()`.\n\n  Optional output derivative of tvec3 with regard to rvec2\n\n- **dt3dt2**: `Evision.Mat.t()`.\n\n  Optional output derivative of tvec3 with regard to tvec2\n\nThe functions compute:\n\\f[\\begin{array}{l} \\texttt{rvec3} =  \\mathrm{rodrigues} ^{-1} \\left ( \\mathrm{rodrigues} ( \\texttt{rvec2} )  \\cdot \\mathrm{rodrigues} ( \\texttt{rvec1} ) \\right )  \\\\\\\\ \\texttt{tvec3} =  \\mathrm{rodrigues} ( \\texttt{rvec2} )  \\cdot \\texttt{tvec1} +  \\texttt{tvec2} \\end{array} ,\\f]\nwhere \\f$\\mathrm{rodrigues}\\f$ denotes a rotation vector to a rotation matrix transformation, and\n\\f$\\mathrm{rodrigues}^{-1}\\f$ denotes the inverse transformation. See #Rodrigues for details.\nAlso, the functions can compute the derivatives of the output vectors with regards to the input\nvectors (see #matMulDeriv ). The functions are used inside #stereoCalibrate but can also be used in\nyour own code where Levenberg-Marquardt or another gradient-based solver is used to optimize a\nfunction that contains a matrix multiplication.\n\nPython prototype (for reference only):\n```python3\ncomposeRT(rvec1, tvec1, rvec2, tvec2[, rvec3[, tvec3[, dr3dr1[, dr3dt1[, dr3dr2[, dr3dt2[, dt3dr1[, dt3dt1[, dt3dr2[, dt3dt2]]]]]]]]]]) -> rvec3, tvec3, dr3dr1, dr3dt1, dr3dr2, dr3dt2, dt3dr1, dt3dt1, dt3dr2, dt3dt2\n```","ref":"Evision.html#composeRT/5"},{"type":"function","title":"Evision.computeCorrespondEpilines/1","doc":"","ref":"Evision.html#computeCorrespondEpilines/1"},{"type":"function","title":"Evision.computeCorrespondEpilines/3","doc":"For points in an image of a stereo pair, computes the corresponding epilines in the other image.\n\n##### Positional Arguments\n- **points**: `Evision.Mat`.\n\n  Input points. \\f$N \\times 1\\f$ or \\f$1 \\times N\\f$ matrix of type CV_32FC2 or\n  vector\\  .\n\n- **whichImage**: `integer()`.\n\n  Index of the image (1 or 2) that contains the points .\n\n- **f**: `Evision.Mat`.\n\n  Fundamental matrix that can be estimated using #findFundamentalMat or #stereoRectify .\n\n##### Return\n- **lines**: `Evision.Mat.t()`.\n\n  Output vector of the epipolar lines corresponding to the points in the other image.\n  Each line \\f$ax + by + c=0\\f$ is encoded by 3 numbers \\f$(a, b, c)\\f$ .\n\nFor every point in one of the two images of a stereo pair, the function finds the equation of the\ncorresponding epipolar line in the other image.\nFrom the fundamental matrix definition (see #findFundamentalMat ), line \\f$l^{(2)}\\_i\\f$ in the second\nimage for the point \\f$p^{(1)}\\_i\\f$ in the first image (when whichImage=1 ) is computed as:\n\\f[l^{(2)}\\_i = F p^{(1)}\\_i\\f]\nAnd vice versa, when whichImage=2, \\f$l^{(1)}\\_i\\f$ is computed from \\f$p^{(2)}\\_i\\f$ as:\n\\f[l^{(1)}\\_i = F^T p^{(2)}\\_i\\f]\nLine coefficients are defined up to a scale. They are normalized so that \\f$a\\_i^2+b\\_i^2=1\\f$ .\n\nPython prototype (for reference only):\n```python3\ncomputeCorrespondEpilines(points, whichImage, F[, lines]) -> lines\n```","ref":"Evision.html#computeCorrespondEpilines/3"},{"type":"function","title":"Evision.computeCorrespondEpilines/4","doc":"For points in an image of a stereo pair, computes the corresponding epilines in the other image.\n\n##### Positional Arguments\n- **points**: `Evision.Mat`.\n\n  Input points. \\f$N \\times 1\\f$ or \\f$1 \\times N\\f$ matrix of type CV_32FC2 or\n  vector\\  .\n\n- **whichImage**: `integer()`.\n\n  Index of the image (1 or 2) that contains the points .\n\n- **f**: `Evision.Mat`.\n\n  Fundamental matrix that can be estimated using #findFundamentalMat or #stereoRectify .\n\n##### Return\n- **lines**: `Evision.Mat.t()`.\n\n  Output vector of the epipolar lines corresponding to the points in the other image.\n  Each line \\f$ax + by + c=0\\f$ is encoded by 3 numbers \\f$(a, b, c)\\f$ .\n\nFor every point in one of the two images of a stereo pair, the function finds the equation of the\ncorresponding epipolar line in the other image.\nFrom the fundamental matrix definition (see #findFundamentalMat ), line \\f$l^{(2)}\\_i\\f$ in the second\nimage for the point \\f$p^{(1)}\\_i\\f$ in the first image (when whichImage=1 ) is computed as:\n\\f[l^{(2)}\\_i = F p^{(1)}\\_i\\f]\nAnd vice versa, when whichImage=2, \\f$l^{(1)}\\_i\\f$ is computed from \\f$p^{(2)}\\_i\\f$ as:\n\\f[l^{(1)}\\_i = F^T p^{(2)}\\_i\\f]\nLine coefficients are defined up to a scale. They are normalized so that \\f$a\\_i^2+b\\_i^2=1\\f$ .\n\nPython prototype (for reference only):\n```python3\ncomputeCorrespondEpilines(points, whichImage, F[, lines]) -> lines\n```","ref":"Evision.html#computeCorrespondEpilines/4"},{"type":"function","title":"Evision.computeECC/1","doc":"","ref":"Evision.html#computeECC/1"},{"type":"function","title":"Evision.computeECC/2","doc":"Computes the Enhanced Correlation Coefficient value between two images @cite EP08 .\n\n##### Positional Arguments\n- **templateImage**: `Evision.Mat`.\n\n  single-channel template image; CV_8U or CV_32F array.\n\n- **inputImage**: `Evision.Mat`.\n\n  single-channel input image to be warped to provide an image similar to\n  templateImage, same type as templateImage.\n\n##### Keyword Arguments\n- **inputMask**: `Evision.Mat`.\n\n  An optional mask to indicate valid values of inputImage.\n\n##### Return\n- **retval**: `double`\n\n@sa\nfindTransformECC\n\nPython prototype (for reference only):\n```python3\ncomputeECC(templateImage, inputImage[, inputMask]) -> retval\n```","ref":"Evision.html#computeECC/2"},{"type":"function","title":"Evision.computeECC/3","doc":"Computes the Enhanced Correlation Coefficient value between two images @cite EP08 .\n\n##### Positional Arguments\n- **templateImage**: `Evision.Mat`.\n\n  single-channel template image; CV_8U or CV_32F array.\n\n- **inputImage**: `Evision.Mat`.\n\n  single-channel input image to be warped to provide an image similar to\n  templateImage, same type as templateImage.\n\n##### Keyword Arguments\n- **inputMask**: `Evision.Mat`.\n\n  An optional mask to indicate valid values of inputImage.\n\n##### Return\n- **retval**: `double`\n\n@sa\nfindTransformECC\n\nPython prototype (for reference only):\n```python3\ncomputeECC(templateImage, inputImage[, inputMask]) -> retval\n```","ref":"Evision.html#computeECC/3"},{"type":"function","title":"Evision.connectedComponents/1","doc":"connectedComponents\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  the 8-bit single-channel image to be labeled\n\n##### Keyword Arguments\n- **connectivity**: `integer()`.\n\n  8 or 4 for 8-way or 4-way connectivity respectively\n\n- **ltype**: `integer()`.\n\n  output image label type. Currently CV_32S and CV_16U are supported.\n\n##### Return\n- **retval**: `integer()`\n- **labels**: `Evision.Mat.t()`.\n\n  destination labeled image\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nconnectedComponents(image[, labels[, connectivity[, ltype]]]) -> retval, labels\n```","ref":"Evision.html#connectedComponents/1"},{"type":"function","title":"Evision.connectedComponents/2","doc":"connectedComponents\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  the 8-bit single-channel image to be labeled\n\n##### Keyword Arguments\n- **connectivity**: `integer()`.\n\n  8 or 4 for 8-way or 4-way connectivity respectively\n\n- **ltype**: `integer()`.\n\n  output image label type. Currently CV_32S and CV_16U are supported.\n\n##### Return\n- **retval**: `integer()`\n- **labels**: `Evision.Mat.t()`.\n\n  destination labeled image\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nconnectedComponents(image[, labels[, connectivity[, ltype]]]) -> retval, labels\n```","ref":"Evision.html#connectedComponents/2"},{"type":"function","title":"Evision.connectedComponentsWithAlgorithm/1","doc":"","ref":"Evision.html#connectedComponentsWithAlgorithm/1"},{"type":"function","title":"Evision.connectedComponentsWithAlgorithm/4","doc":"computes the connected components labeled image of boolean image\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  the 8-bit single-channel image to be labeled\n\n- **connectivity**: `integer()`.\n\n  8 or 4 for 8-way or 4-way connectivity respectively\n\n- **ltype**: `integer()`.\n\n  output image label type. Currently CV_32S and CV_16U are supported.\n\n- **ccltype**: `integer()`.\n\n  connected components algorithm type (see the #ConnectedComponentsAlgorithmsTypes).\n\n##### Return\n- **retval**: `integer()`\n- **labels**: `Evision.Mat.t()`.\n\n  destination labeled image\n\nimage with 4 or 8 way connectivity - returns N, the total number of labels [0, N-1] where 0\nrepresents the background label. ltype specifies the output label image type, an important\nconsideration based on the total number of labels or alternatively the total number of pixels in\nthe source image. ccltype specifies the connected components labeling algorithm to use, currently\nBolelli (Spaghetti) @cite Bolelli2019, Grana (BBDT) @cite Grana2010 and Wu's (SAUF) @cite Wu2009 algorithms\nare supported, see the #ConnectedComponentsAlgorithmsTypes for details. Note that SAUF algorithm forces\na row major ordering of labels while Spaghetti and BBDT do not.\nThis function uses parallel version of the algorithms if at least one allowed\nparallel framework is enabled and if the rows of the image are at least twice the number returned by #getNumberOfCPUs.\n\nPython prototype (for reference only):\n```python3\nconnectedComponentsWithAlgorithm(image, connectivity, ltype, ccltype[, labels]) -> retval, labels\n```","ref":"Evision.html#connectedComponentsWithAlgorithm/4"},{"type":"function","title":"Evision.connectedComponentsWithAlgorithm/5","doc":"computes the connected components labeled image of boolean image\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  the 8-bit single-channel image to be labeled\n\n- **connectivity**: `integer()`.\n\n  8 or 4 for 8-way or 4-way connectivity respectively\n\n- **ltype**: `integer()`.\n\n  output image label type. Currently CV_32S and CV_16U are supported.\n\n- **ccltype**: `integer()`.\n\n  connected components algorithm type (see the #ConnectedComponentsAlgorithmsTypes).\n\n##### Return\n- **retval**: `integer()`\n- **labels**: `Evision.Mat.t()`.\n\n  destination labeled image\n\nimage with 4 or 8 way connectivity - returns N, the total number of labels [0, N-1] where 0\nrepresents the background label. ltype specifies the output label image type, an important\nconsideration based on the total number of labels or alternatively the total number of pixels in\nthe source image. ccltype specifies the connected components labeling algorithm to use, currently\nBolelli (Spaghetti) @cite Bolelli2019, Grana (BBDT) @cite Grana2010 and Wu's (SAUF) @cite Wu2009 algorithms\nare supported, see the #ConnectedComponentsAlgorithmsTypes for details. Note that SAUF algorithm forces\na row major ordering of labels while Spaghetti and BBDT do not.\nThis function uses parallel version of the algorithms if at least one allowed\nparallel framework is enabled and if the rows of the image are at least twice the number returned by #getNumberOfCPUs.\n\nPython prototype (for reference only):\n```python3\nconnectedComponentsWithAlgorithm(image, connectivity, ltype, ccltype[, labels]) -> retval, labels\n```","ref":"Evision.html#connectedComponentsWithAlgorithm/5"},{"type":"function","title":"Evision.connectedComponentsWithStats/1","doc":"connectedComponentsWithStats\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  the 8-bit single-channel image to be labeled\n\n##### Keyword Arguments\n- **connectivity**: `integer()`.\n\n  8 or 4 for 8-way or 4-way connectivity respectively\n\n- **ltype**: `integer()`.\n\n  output image label type. Currently CV_32S and CV_16U are supported.\n\n##### Return\n- **retval**: `integer()`\n- **labels**: `Evision.Mat.t()`.\n\n  destination labeled image\n\n- **stats**: `Evision.Mat.t()`.\n\n  statistics output for each label, including the background label.\n  Statistics are accessed via stats(label, COLUMN) where COLUMN is one of\n  #ConnectedComponentsTypes, selecting the statistic. The data type is CV_32S.\n\n- **centroids**: `Evision.Mat.t()`.\n\n  centroid output for each label, including the background label. Centroids are\n  accessed via centroids(label, 0) for x and centroids(label, 1) for y. The data type CV_64F.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nconnectedComponentsWithStats(image[, labels[, stats[, centroids[, connectivity[, ltype]]]]]) -> retval, labels, stats, centroids\n```","ref":"Evision.html#connectedComponentsWithStats/1"},{"type":"function","title":"Evision.connectedComponentsWithStats/2","doc":"connectedComponentsWithStats\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  the 8-bit single-channel image to be labeled\n\n##### Keyword Arguments\n- **connectivity**: `integer()`.\n\n  8 or 4 for 8-way or 4-way connectivity respectively\n\n- **ltype**: `integer()`.\n\n  output image label type. Currently CV_32S and CV_16U are supported.\n\n##### Return\n- **retval**: `integer()`\n- **labels**: `Evision.Mat.t()`.\n\n  destination labeled image\n\n- **stats**: `Evision.Mat.t()`.\n\n  statistics output for each label, including the background label.\n  Statistics are accessed via stats(label, COLUMN) where COLUMN is one of\n  #ConnectedComponentsTypes, selecting the statistic. The data type is CV_32S.\n\n- **centroids**: `Evision.Mat.t()`.\n\n  centroid output for each label, including the background label. Centroids are\n  accessed via centroids(label, 0) for x and centroids(label, 1) for y. The data type CV_64F.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nconnectedComponentsWithStats(image[, labels[, stats[, centroids[, connectivity[, ltype]]]]]) -> retval, labels, stats, centroids\n```","ref":"Evision.html#connectedComponentsWithStats/2"},{"type":"function","title":"Evision.connectedComponentsWithStatsWithAlgorithm/1","doc":"","ref":"Evision.html#connectedComponentsWithStatsWithAlgorithm/1"},{"type":"function","title":"Evision.connectedComponentsWithStatsWithAlgorithm/4","doc":"computes the connected components labeled image of boolean image and also produces a statistics output for each label\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  the 8-bit single-channel image to be labeled\n\n- **connectivity**: `integer()`.\n\n  8 or 4 for 8-way or 4-way connectivity respectively\n\n- **ltype**: `integer()`.\n\n  output image label type. Currently CV_32S and CV_16U are supported.\n\n- **ccltype**: `integer()`.\n\n  connected components algorithm type (see #ConnectedComponentsAlgorithmsTypes).\n\n##### Return\n- **retval**: `integer()`\n- **labels**: `Evision.Mat.t()`.\n\n  destination labeled image\n\n- **stats**: `Evision.Mat.t()`.\n\n  statistics output for each label, including the background label.\n  Statistics are accessed via stats(label, COLUMN) where COLUMN is one of\n  #ConnectedComponentsTypes, selecting the statistic. The data type is CV_32S.\n\n- **centroids**: `Evision.Mat.t()`.\n\n  centroid output for each label, including the background label. Centroids are\n  accessed via centroids(label, 0) for x and centroids(label, 1) for y. The data type CV_64F.\n\nimage with 4 or 8 way connectivity - returns N, the total number of labels [0, N-1] where 0\nrepresents the background label. ltype specifies the output label image type, an important\nconsideration based on the total number of labels or alternatively the total number of pixels in\nthe source image. ccltype specifies the connected components labeling algorithm to use, currently\nBolelli (Spaghetti) @cite Bolelli2019, Grana (BBDT) @cite Grana2010 and Wu's (SAUF) @cite Wu2009 algorithms\nare supported, see the #ConnectedComponentsAlgorithmsTypes for details. Note that SAUF algorithm forces\na row major ordering of labels while Spaghetti and BBDT do not.\nThis function uses parallel version of the algorithms (statistics included) if at least one allowed\nparallel framework is enabled and if the rows of the image are at least twice the number returned by #getNumberOfCPUs.\n\nPython prototype (for reference only):\n```python3\nconnectedComponentsWithStatsWithAlgorithm(image, connectivity, ltype, ccltype[, labels[, stats[, centroids]]]) -> retval, labels, stats, centroids\n```","ref":"Evision.html#connectedComponentsWithStatsWithAlgorithm/4"},{"type":"function","title":"Evision.connectedComponentsWithStatsWithAlgorithm/5","doc":"computes the connected components labeled image of boolean image and also produces a statistics output for each label\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  the 8-bit single-channel image to be labeled\n\n- **connectivity**: `integer()`.\n\n  8 or 4 for 8-way or 4-way connectivity respectively\n\n- **ltype**: `integer()`.\n\n  output image label type. Currently CV_32S and CV_16U are supported.\n\n- **ccltype**: `integer()`.\n\n  connected components algorithm type (see #ConnectedComponentsAlgorithmsTypes).\n\n##### Return\n- **retval**: `integer()`\n- **labels**: `Evision.Mat.t()`.\n\n  destination labeled image\n\n- **stats**: `Evision.Mat.t()`.\n\n  statistics output for each label, including the background label.\n  Statistics are accessed via stats(label, COLUMN) where COLUMN is one of\n  #ConnectedComponentsTypes, selecting the statistic. The data type is CV_32S.\n\n- **centroids**: `Evision.Mat.t()`.\n\n  centroid output for each label, including the background label. Centroids are\n  accessed via centroids(label, 0) for x and centroids(label, 1) for y. The data type CV_64F.\n\nimage with 4 or 8 way connectivity - returns N, the total number of labels [0, N-1] where 0\nrepresents the background label. ltype specifies the output label image type, an important\nconsideration based on the total number of labels or alternatively the total number of pixels in\nthe source image. ccltype specifies the connected components labeling algorithm to use, currently\nBolelli (Spaghetti) @cite Bolelli2019, Grana (BBDT) @cite Grana2010 and Wu's (SAUF) @cite Wu2009 algorithms\nare supported, see the #ConnectedComponentsAlgorithmsTypes for details. Note that SAUF algorithm forces\na row major ordering of labels while Spaghetti and BBDT do not.\nThis function uses parallel version of the algorithms (statistics included) if at least one allowed\nparallel framework is enabled and if the rows of the image are at least twice the number returned by #getNumberOfCPUs.\n\nPython prototype (for reference only):\n```python3\nconnectedComponentsWithStatsWithAlgorithm(image, connectivity, ltype, ccltype[, labels[, stats[, centroids]]]) -> retval, labels, stats, centroids\n```","ref":"Evision.html#connectedComponentsWithStatsWithAlgorithm/5"},{"type":"function","title":"Evision.contourArea/1","doc":"Calculates a contour area.\n\n##### Positional Arguments\n- **contour**: `Evision.Mat`.\n\n  Input vector of 2D points (contour vertices), stored in std::vector or Mat.\n\n##### Keyword Arguments\n- **oriented**: `bool`.\n\n  Oriented area flag. If it is true, the function returns a signed area value,\n  depending on the contour orientation (clockwise or counter-clockwise). Using this feature you can\n  determine orientation of a contour by taking the sign of an area. By default, the parameter is\n  false, which means that the absolute value is returned.\n\n##### Return\n- **retval**: `double`\n\nThe function computes a contour area. Similarly to moments , the area is computed using the Green\nformula. Thus, the returned area and the number of non-zero pixels, if you draw the contour using\n#drawContours or #fillPoly , can be different. Also, the function will most certainly give a wrong\nresults for contours with self-intersections.\nExample:\n```\nvector  contour;\ncontour.push_back(Point2f(0, 0));\ncontour.push_back(Point2f(10, 0));\ncontour.push_back(Point2f(10, 10));\ncontour.push_back(Point2f(5, 4));\ndouble area0 = contourArea(contour);\nvector  approx;\napproxPolyDP(contour, approx, 5, true);\ndouble area1 = contourArea(approx);\ncout << \"area0 =\" <  retval\n```","ref":"Evision.html#contourArea/1"},{"type":"function","title":"Evision.contourArea/2","doc":"Calculates a contour area.\n\n##### Positional Arguments\n- **contour**: `Evision.Mat`.\n\n  Input vector of 2D points (contour vertices), stored in std::vector or Mat.\n\n##### Keyword Arguments\n- **oriented**: `bool`.\n\n  Oriented area flag. If it is true, the function returns a signed area value,\n  depending on the contour orientation (clockwise or counter-clockwise). Using this feature you can\n  determine orientation of a contour by taking the sign of an area. By default, the parameter is\n  false, which means that the absolute value is returned.\n\n##### Return\n- **retval**: `double`\n\nThe function computes a contour area. Similarly to moments , the area is computed using the Green\nformula. Thus, the returned area and the number of non-zero pixels, if you draw the contour using\n#drawContours or #fillPoly , can be different. Also, the function will most certainly give a wrong\nresults for contours with self-intersections.\nExample:\n```\nvector  contour;\ncontour.push_back(Point2f(0, 0));\ncontour.push_back(Point2f(10, 0));\ncontour.push_back(Point2f(10, 10));\ncontour.push_back(Point2f(5, 4));\ndouble area0 = contourArea(contour);\nvector  approx;\napproxPolyDP(contour, approx, 5, true);\ndouble area1 = contourArea(approx);\ncout << \"area0 =\" <  retval\n```","ref":"Evision.html#contourArea/2"},{"type":"function","title":"Evision.convertFp16/1","doc":"Converts an array to half precision floating number.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array.\n\nThis function converts FP32 (single precision floating point) from/to FP16 (half precision floating point). CV_16S format is used to represent FP16 data.\nThere are two use modes (src -> dst): CV_32F -> CV_16S and CV_16S -> CV_32F. The input array has to have type of CV_32F or\nCV_16S to represent the bit depth. If the input array is neither of them, the function will raise an error.\nThe format of half precision floating point is defined in IEEE 754-2008.\n\n@deprecated Use Mat::convertTo with CV_16F instead.\n\nPython prototype (for reference only):\n```python3\nconvertFp16(src[, dst]) -> dst\n```","ref":"Evision.html#convertFp16/1"},{"type":"function","title":"Evision.convertFp16/2","doc":"Converts an array to half precision floating number.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array.\n\nThis function converts FP32 (single precision floating point) from/to FP16 (half precision floating point). CV_16S format is used to represent FP16 data.\nThere are two use modes (src -> dst): CV_32F -> CV_16S and CV_16S -> CV_32F. The input array has to have type of CV_32F or\nCV_16S to represent the bit depth. If the input array is neither of them, the function will raise an error.\nThe format of half precision floating point is defined in IEEE 754-2008.\n\n@deprecated Use Mat::convertTo with CV_16F instead.\n\nPython prototype (for reference only):\n```python3\nconvertFp16(src[, dst]) -> dst\n```","ref":"Evision.html#convertFp16/2"},{"type":"function","title":"Evision.convertMaps/1","doc":"","ref":"Evision.html#convertMaps/1"},{"type":"function","title":"Evision.convertMaps/3","doc":"Converts image transformation maps from one representation to another.\n\n##### Positional Arguments\n- **map1**: `Evision.Mat`.\n\n  The first input map of type CV_16SC2, CV_32FC1, or CV_32FC2 .\n\n- **map2**: `Evision.Mat`.\n\n  The second input map of type CV_16UC1, CV_32FC1, or none (empty matrix),\n  respectively.\n\n- **dstmap1type**: `integer()`.\n\n  Type of the first output map that should be CV_16SC2, CV_32FC1, or\n  CV_32FC2 .\n\n##### Keyword Arguments\n- **nninterpolation**: `bool`.\n\n  Flag indicating whether the fixed-point maps are used for the\n  nearest-neighbor or for a more complex interpolation.\n\n##### Return\n- **dstmap1**: `Evision.Mat.t()`.\n\n  The first output map that has the type dstmap1type and the same size as src .\n\n- **dstmap2**: `Evision.Mat.t()`.\n\n  The second output map.\n\nThe function converts a pair of maps for remap from one representation to another. The following\noptions ( (map1.type(), map2.type()) \\f$\\rightarrow\\f$ (dstmap1.type(), dstmap2.type()) ) are\nsupported:\n- \\f$\\texttt{(CV\\_32FC1, CV\\_32FC1)} \\rightarrow \\texttt{(CV\\_16SC2, CV\\_16UC1)}\\f$. This is the\n  most frequently used conversion operation, in which the original floating-point maps (see #remap)\n  are converted to a more compact and much faster fixed-point representation. The first output array\n  contains the rounded coordinates and the second array (created only when nninterpolation=false )\n  contains indices in the interpolation tables.\n\n- \\f$\\texttt{(CV\\_32FC2)} \\rightarrow \\texttt{(CV\\_16SC2, CV\\_16UC1)}\\f$. The same as above but\n  the original maps are stored in one 2-channel matrix.\n\n- Reverse conversion. Obviously, the reconstructed floating-point maps will not be exactly the same\n  as the originals.\n\n@sa  remap, undistort, initUndistortRectifyMap\n\nPython prototype (for reference only):\n```python3\nconvertMaps(map1, map2, dstmap1type[, dstmap1[, dstmap2[, nninterpolation]]]) -> dstmap1, dstmap2\n```","ref":"Evision.html#convertMaps/3"},{"type":"function","title":"Evision.convertMaps/4","doc":"Converts image transformation maps from one representation to another.\n\n##### Positional Arguments\n- **map1**: `Evision.Mat`.\n\n  The first input map of type CV_16SC2, CV_32FC1, or CV_32FC2 .\n\n- **map2**: `Evision.Mat`.\n\n  The second input map of type CV_16UC1, CV_32FC1, or none (empty matrix),\n  respectively.\n\n- **dstmap1type**: `integer()`.\n\n  Type of the first output map that should be CV_16SC2, CV_32FC1, or\n  CV_32FC2 .\n\n##### Keyword Arguments\n- **nninterpolation**: `bool`.\n\n  Flag indicating whether the fixed-point maps are used for the\n  nearest-neighbor or for a more complex interpolation.\n\n##### Return\n- **dstmap1**: `Evision.Mat.t()`.\n\n  The first output map that has the type dstmap1type and the same size as src .\n\n- **dstmap2**: `Evision.Mat.t()`.\n\n  The second output map.\n\nThe function converts a pair of maps for remap from one representation to another. The following\noptions ( (map1.type(), map2.type()) \\f$\\rightarrow\\f$ (dstmap1.type(), dstmap2.type()) ) are\nsupported:\n- \\f$\\texttt{(CV\\_32FC1, CV\\_32FC1)} \\rightarrow \\texttt{(CV\\_16SC2, CV\\_16UC1)}\\f$. This is the\n  most frequently used conversion operation, in which the original floating-point maps (see #remap)\n  are converted to a more compact and much faster fixed-point representation. The first output array\n  contains the rounded coordinates and the second array (created only when nninterpolation=false )\n  contains indices in the interpolation tables.\n\n- \\f$\\texttt{(CV\\_32FC2)} \\rightarrow \\texttt{(CV\\_16SC2, CV\\_16UC1)}\\f$. The same as above but\n  the original maps are stored in one 2-channel matrix.\n\n- Reverse conversion. Obviously, the reconstructed floating-point maps will not be exactly the same\n  as the originals.\n\n@sa  remap, undistort, initUndistortRectifyMap\n\nPython prototype (for reference only):\n```python3\nconvertMaps(map1, map2, dstmap1type[, dstmap1[, dstmap2[, nninterpolation]]]) -> dstmap1, dstmap2\n```","ref":"Evision.html#convertMaps/4"},{"type":"function","title":"Evision.convertPointsFromHomogeneous/1","doc":"Converts points from homogeneous to Euclidean space.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input vector of N-dimensional points.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output vector of N-1-dimensional points.\n\nThe function converts points homogeneous to Euclidean space using perspective projection. That is,\neach point (x1, x2, ... x(n-1), xn) is converted to (x1/xn, x2/xn, ..., x(n-1)/xn). When xn=0, the\noutput point coordinates will be (0,0,0,...).\n\nPython prototype (for reference only):\n```python3\nconvertPointsFromHomogeneous(src[, dst]) -> dst\n```","ref":"Evision.html#convertPointsFromHomogeneous/1"},{"type":"function","title":"Evision.convertPointsFromHomogeneous/2","doc":"Converts points from homogeneous to Euclidean space.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input vector of N-dimensional points.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output vector of N-1-dimensional points.\n\nThe function converts points homogeneous to Euclidean space using perspective projection. That is,\neach point (x1, x2, ... x(n-1), xn) is converted to (x1/xn, x2/xn, ..., x(n-1)/xn). When xn=0, the\noutput point coordinates will be (0,0,0,...).\n\nPython prototype (for reference only):\n```python3\nconvertPointsFromHomogeneous(src[, dst]) -> dst\n```","ref":"Evision.html#convertPointsFromHomogeneous/2"},{"type":"function","title":"Evision.convertPointsToHomogeneous/1","doc":"Converts points from Euclidean to homogeneous space.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input vector of N-dimensional points.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output vector of N+1-dimensional points.\n\nThe function converts points from Euclidean to homogeneous space by appending 1's to the tuple of\npoint coordinates. That is, each point (x1, x2, ..., xn) is converted to (x1, x2, ..., xn, 1).\n\nPython prototype (for reference only):\n```python3\nconvertPointsToHomogeneous(src[, dst]) -> dst\n```","ref":"Evision.html#convertPointsToHomogeneous/1"},{"type":"function","title":"Evision.convertPointsToHomogeneous/2","doc":"Converts points from Euclidean to homogeneous space.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input vector of N-dimensional points.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output vector of N+1-dimensional points.\n\nThe function converts points from Euclidean to homogeneous space by appending 1's to the tuple of\npoint coordinates. That is, each point (x1, x2, ..., xn) is converted to (x1, x2, ..., xn, 1).\n\nPython prototype (for reference only):\n```python3\nconvertPointsToHomogeneous(src[, dst]) -> dst\n```","ref":"Evision.html#convertPointsToHomogeneous/2"},{"type":"function","title":"Evision.convertScaleAbs/1","doc":"Scales, calculates absolute values, and converts the result to 8-bit.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array.\n\n##### Keyword Arguments\n- **alpha**: `double`.\n\n  optional scale factor.\n\n- **beta**: `double`.\n\n  optional delta added to the scaled values.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array.\n\nOn each element of the input array, the function convertScaleAbs\nperforms three operations sequentially: scaling, taking an absolute\nvalue, conversion to an unsigned 8-bit type:\n\\f[\\texttt{dst} (I)= \\texttt{saturate\\\\_cast } (| \\texttt{src} (I)\\* \\texttt{alpha} +  \\texttt{beta} |)\\f]\nIn case of multi-channel arrays, the function processes each channel\nindependently. When the output is not 8-bit, the operation can be\nemulated by calling the Mat::convertTo method (or by using matrix\nexpressions) and then by calculating an absolute value of the result.\nFor example:\n```cpp\nMat_  A(30,30);\nrandu(A, Scalar(-100), Scalar(100));\nMat_  B = A*5 + 3;\nB = abs(B);\n// Mat_  B = abs(A*5+3) will also do the job,\n// but it will allocate a temporary matrix\n```\n@sa  Mat::convertTo, cv::abs(const Mat&)\n\nPython prototype (for reference only):\n```python3\nconvertScaleAbs(src[, dst[, alpha[, beta]]]) -> dst\n```","ref":"Evision.html#convertScaleAbs/1"},{"type":"function","title":"Evision.convertScaleAbs/2","doc":"Scales, calculates absolute values, and converts the result to 8-bit.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array.\n\n##### Keyword Arguments\n- **alpha**: `double`.\n\n  optional scale factor.\n\n- **beta**: `double`.\n\n  optional delta added to the scaled values.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array.\n\nOn each element of the input array, the function convertScaleAbs\nperforms three operations sequentially: scaling, taking an absolute\nvalue, conversion to an unsigned 8-bit type:\n\\f[\\texttt{dst} (I)= \\texttt{saturate\\\\_cast } (| \\texttt{src} (I)\\* \\texttt{alpha} +  \\texttt{beta} |)\\f]\nIn case of multi-channel arrays, the function processes each channel\nindependently. When the output is not 8-bit, the operation can be\nemulated by calling the Mat::convertTo method (or by using matrix\nexpressions) and then by calculating an absolute value of the result.\nFor example:\n```cpp\nMat_  A(30,30);\nrandu(A, Scalar(-100), Scalar(100));\nMat_  B = A*5 + 3;\nB = abs(B);\n// Mat_  B = abs(A*5+3) will also do the job,\n// but it will allocate a temporary matrix\n```\n@sa  Mat::convertTo, cv::abs(const Mat&)\n\nPython prototype (for reference only):\n```python3\nconvertScaleAbs(src[, dst[, alpha[, beta]]]) -> dst\n```","ref":"Evision.html#convertScaleAbs/2"},{"type":"function","title":"Evision.convexHull/1","doc":"Finds the convex hull of a point set.\n\n##### Positional Arguments\n- **points**: `Evision.Mat`.\n\n  Input 2D point set, stored in std::vector or Mat.\n\n##### Keyword Arguments\n- **clockwise**: `bool`.\n\n  Orientation flag. If it is true, the output convex hull is oriented clockwise.\n  Otherwise, it is oriented counter-clockwise. The assumed coordinate system has its X axis pointing\n  to the right, and its Y axis pointing upwards.\n\n- **returnPoints**: `bool`.\n\n  Operation flag. In case of a matrix, when the flag is true, the function\n  returns convex hull points. Otherwise, it returns indices of the convex hull points. When the\n  output array is std::vector, the flag is ignored, and the output depends on the type of the\n  vector: std::vector\\  implies returnPoints=false, std::vector\\  implies\n  returnPoints=true.\n\n##### Return\n- **hull**: `Evision.Mat.t()`.\n\n  Output convex hull. It is either an integer vector of indices or vector of points. In\n  the first case, the hull elements are 0-based indices of the convex hull points in the original\n  array (since the set of convex hull points is a subset of the original point set). In the second\n  case, hull elements are the convex hull points themselves.\n\nThe function cv::convexHull finds the convex hull of a 2D point set using the Sklansky's algorithm @cite Sklansky82\nthat has *O(N logN)* complexity in the current implementation.\n\n**Note**: `points` and `hull` should be different arrays, inplace processing isn't supported.\nCheck @ref tutorial_hull \"the corresponding tutorial\" for more details.\nuseful links:\nhttps://www.learnopencv.com/convex-hull-using-opencv-in-python-and-c/\n\nPython prototype (for reference only):\n```python3\nconvexHull(points[, hull[, clockwise[, returnPoints]]]) -> hull\n```","ref":"Evision.html#convexHull/1"},{"type":"function","title":"Evision.convexHull/2","doc":"Finds the convex hull of a point set.\n\n##### Positional Arguments\n- **points**: `Evision.Mat`.\n\n  Input 2D point set, stored in std::vector or Mat.\n\n##### Keyword Arguments\n- **clockwise**: `bool`.\n\n  Orientation flag. If it is true, the output convex hull is oriented clockwise.\n  Otherwise, it is oriented counter-clockwise. The assumed coordinate system has its X axis pointing\n  to the right, and its Y axis pointing upwards.\n\n- **returnPoints**: `bool`.\n\n  Operation flag. In case of a matrix, when the flag is true, the function\n  returns convex hull points. Otherwise, it returns indices of the convex hull points. When the\n  output array is std::vector, the flag is ignored, and the output depends on the type of the\n  vector: std::vector\\  implies returnPoints=false, std::vector\\  implies\n  returnPoints=true.\n\n##### Return\n- **hull**: `Evision.Mat.t()`.\n\n  Output convex hull. It is either an integer vector of indices or vector of points. In\n  the first case, the hull elements are 0-based indices of the convex hull points in the original\n  array (since the set of convex hull points is a subset of the original point set). In the second\n  case, hull elements are the convex hull points themselves.\n\nThe function cv::convexHull finds the convex hull of a 2D point set using the Sklansky's algorithm @cite Sklansky82\nthat has *O(N logN)* complexity in the current implementation.\n\n**Note**: `points` and `hull` should be different arrays, inplace processing isn't supported.\nCheck @ref tutorial_hull \"the corresponding tutorial\" for more details.\nuseful links:\nhttps://www.learnopencv.com/convex-hull-using-opencv-in-python-and-c/\n\nPython prototype (for reference only):\n```python3\nconvexHull(points[, hull[, clockwise[, returnPoints]]]) -> hull\n```","ref":"Evision.html#convexHull/2"},{"type":"function","title":"Evision.convexityDefects/1","doc":"","ref":"Evision.html#convexityDefects/1"},{"type":"function","title":"Evision.convexityDefects/2","doc":"Finds the convexity defects of a contour.\n\n##### Positional Arguments\n- **contour**: `Evision.Mat`.\n\n  Input contour.\n\n- **convexhull**: `Evision.Mat`.\n\n  Convex hull obtained using convexHull that should contain indices of the contour\n  points that make the hull.\n\n##### Return\n- **convexityDefects**: `Evision.Mat.t()`.\n\n  The output vector of convexity defects. In C++ and the new Python/Java\n  interface each convexity defect is represented as 4-element integer vector (a.k.a. #Vec4i):\n  (start_index, end_index, farthest_pt_index, fixpt_depth), where indices are 0-based indices\n  in the original contour of the convexity defect beginning, end and the farthest point, and\n  fixpt_depth is fixed-point approximation (with 8 fractional bits) of the distance between the\n  farthest contour point and the hull. That is, to get the floating-point value of the depth will be\n  fixpt_depth/256.0.\n\nThe figure below displays convexity defects of a hand contour:\n![image](pics/defects.png)\n\nPython prototype (for reference only):\n```python3\nconvexityDefects(contour, convexhull[, convexityDefects]) -> convexityDefects\n```","ref":"Evision.html#convexityDefects/2"},{"type":"function","title":"Evision.convexityDefects/3","doc":"Finds the convexity defects of a contour.\n\n##### Positional Arguments\n- **contour**: `Evision.Mat`.\n\n  Input contour.\n\n- **convexhull**: `Evision.Mat`.\n\n  Convex hull obtained using convexHull that should contain indices of the contour\n  points that make the hull.\n\n##### Return\n- **convexityDefects**: `Evision.Mat.t()`.\n\n  The output vector of convexity defects. In C++ and the new Python/Java\n  interface each convexity defect is represented as 4-element integer vector (a.k.a. #Vec4i):\n  (start_index, end_index, farthest_pt_index, fixpt_depth), where indices are 0-based indices\n  in the original contour of the convexity defect beginning, end and the farthest point, and\n  fixpt_depth is fixed-point approximation (with 8 fractional bits) of the distance between the\n  farthest contour point and the hull. That is, to get the floating-point value of the depth will be\n  fixpt_depth/256.0.\n\nThe figure below displays convexity defects of a hand contour:\n![image](pics/defects.png)\n\nPython prototype (for reference only):\n```python3\nconvexityDefects(contour, convexhull[, convexityDefects]) -> convexityDefects\n```","ref":"Evision.html#convexityDefects/3"},{"type":"function","title":"Evision.copyMakeBorder/1","doc":"","ref":"Evision.html#copyMakeBorder/1"},{"type":"function","title":"Evision.copyMakeBorder/6","doc":"Forms a border around an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image.\n\n- **top**: `integer()`.\n\n  the top pixels\n\n- **bottom**: `integer()`.\n\n  the bottom pixels\n\n- **left**: `integer()`.\n\n  the left pixels\n\n- **right**: `integer()`.\n\n  Parameter specifying how many pixels in each direction from the source image rectangle\n  to extrapolate. For example, top=1, bottom=1, left=1, right=1 mean that 1 pixel-wide border needs\n  to be built.\n\n- **borderType**: `integer()`.\n\n  Border type. See borderInterpolate for details.\n\n##### Keyword Arguments\n- **value**: `Evision.scalar()`.\n\n  Border value if borderType==BORDER_CONSTANT .\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same type as src and the size Size(src.cols+left+right,\n  src.rows+top+bottom) .\n\nThe function copies the source image into the middle of the destination image. The areas to the\nleft, to the right, above and below the copied source image will be filled with extrapolated\npixels. This is not what filtering functions based on it do (they extrapolate pixels on-fly), but\nwhat other more complex functions, including your own, may do to simplify image boundary handling.\nThe function supports the mode when src is already in the middle of dst . In this case, the\nfunction does not copy src itself but simply constructs the border, for example:\n```cpp\n// let border be the same in all directions\nint border=2;\n// constructs a larger image to fit both the image and the border\nMat gray_buf(rgb.rows + border*2, rgb.cols + border*2, rgb.depth());\n// select the middle part of it w/o copying data\nMat gray(gray_canvas, Rect(border, border, rgb.cols, rgb.rows));\n// convert image from RGB to grayscale\ncvtColor(rgb, gray, COLOR_RGB2GRAY);\n// form a border in-place\ncopyMakeBorder(gray, gray_buf, border, border,\nborder, border, BORDER_REPLICATE);\n// now do some custom filtering ...\n...\n```\n**Note**: When the source image is a part (ROI) of a bigger image, the function will try to use the\npixels outside of the ROI to form a border. To disable this feature and always do extrapolation, as\nif src was not a ROI, use borderType | #BORDER_ISOLATED.\n\n@sa  borderInterpolate\n\nPython prototype (for reference only):\n```python3\ncopyMakeBorder(src, top, bottom, left, right, borderType[, dst[, value]]) -> dst\n```","ref":"Evision.html#copyMakeBorder/6"},{"type":"function","title":"Evision.copyMakeBorder/7","doc":"Forms a border around an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image.\n\n- **top**: `integer()`.\n\n  the top pixels\n\n- **bottom**: `integer()`.\n\n  the bottom pixels\n\n- **left**: `integer()`.\n\n  the left pixels\n\n- **right**: `integer()`.\n\n  Parameter specifying how many pixels in each direction from the source image rectangle\n  to extrapolate. For example, top=1, bottom=1, left=1, right=1 mean that 1 pixel-wide border needs\n  to be built.\n\n- **borderType**: `integer()`.\n\n  Border type. See borderInterpolate for details.\n\n##### Keyword Arguments\n- **value**: `Evision.scalar()`.\n\n  Border value if borderType==BORDER_CONSTANT .\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same type as src and the size Size(src.cols+left+right,\n  src.rows+top+bottom) .\n\nThe function copies the source image into the middle of the destination image. The areas to the\nleft, to the right, above and below the copied source image will be filled with extrapolated\npixels. This is not what filtering functions based on it do (they extrapolate pixels on-fly), but\nwhat other more complex functions, including your own, may do to simplify image boundary handling.\nThe function supports the mode when src is already in the middle of dst . In this case, the\nfunction does not copy src itself but simply constructs the border, for example:\n```cpp\n// let border be the same in all directions\nint border=2;\n// constructs a larger image to fit both the image and the border\nMat gray_buf(rgb.rows + border*2, rgb.cols + border*2, rgb.depth());\n// select the middle part of it w/o copying data\nMat gray(gray_canvas, Rect(border, border, rgb.cols, rgb.rows));\n// convert image from RGB to grayscale\ncvtColor(rgb, gray, COLOR_RGB2GRAY);\n// form a border in-place\ncopyMakeBorder(gray, gray_buf, border, border,\nborder, border, BORDER_REPLICATE);\n// now do some custom filtering ...\n...\n```\n**Note**: When the source image is a part (ROI) of a bigger image, the function will try to use the\npixels outside of the ROI to form a border. To disable this feature and always do extrapolation, as\nif src was not a ROI, use borderType | #BORDER_ISOLATED.\n\n@sa  borderInterpolate\n\nPython prototype (for reference only):\n```python3\ncopyMakeBorder(src, top, bottom, left, right, borderType[, dst[, value]]) -> dst\n```","ref":"Evision.html#copyMakeBorder/7"},{"type":"function","title":"Evision.copyTo/1","doc":"","ref":"Evision.html#copyTo/1"},{"type":"function","title":"Evision.copyTo/2","doc":"This is an overloaded member function, provided for convenience (python)\nCopies the matrix to another one.\nWhen the operation mask is specified, if the Mat::create call shown above reallocates the matrix, the newly allocated matrix is initialized with all zeros before copying the data.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  source matrix.\n\n- **mask**: `Evision.Mat`.\n\n  Operation mask of the same size as \\*this. Its non-zero elements indicate which matrix\n  elements need to be copied. The mask has to be of type CV_8U and can have 1 or multiple channels.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix. If it does not have a proper size or type before the operation, it is\n  reallocated.\n\nPython prototype (for reference only):\n```python3\ncopyTo(src, mask[, dst]) -> dst\n```","ref":"Evision.html#copyTo/2"},{"type":"function","title":"Evision.copyTo/3","doc":"This is an overloaded member function, provided for convenience (python)\nCopies the matrix to another one.\nWhen the operation mask is specified, if the Mat::create call shown above reallocates the matrix, the newly allocated matrix is initialized with all zeros before copying the data.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  source matrix.\n\n- **mask**: `Evision.Mat`.\n\n  Operation mask of the same size as \\*this. Its non-zero elements indicate which matrix\n  elements need to be copied. The mask has to be of type CV_8U and can have 1 or multiple channels.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix. If it does not have a proper size or type before the operation, it is\n  reallocated.\n\nPython prototype (for reference only):\n```python3\ncopyTo(src, mask[, dst]) -> dst\n```","ref":"Evision.html#copyTo/3"},{"type":"function","title":"Evision.cornerEigenValsAndVecs/1","doc":"","ref":"Evision.html#cornerEigenValsAndVecs/1"},{"type":"function","title":"Evision.cornerEigenValsAndVecs/3","doc":"Calculates eigenvalues and eigenvectors of image blocks for corner detection.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input single-channel 8-bit or floating-point image.\n\n- **blockSize**: `integer()`.\n\n  Neighborhood size (see details below).\n\n- **ksize**: `integer()`.\n\n  Aperture parameter for the Sobel operator.\n\n##### Keyword Arguments\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method. See #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Image to store the results. It has the same size as src and the type CV_32FC(6) .\n\nFor every pixel \\f$p\\f$ , the function cornerEigenValsAndVecs considers a blockSize \\f$\\times\\f$ blockSize\nneighborhood \\f$S(p)\\f$ . It calculates the covariation matrix of derivatives over the neighborhood as:\n\\f[M =  \\begin{bmatrix} \\sum \\_{S(p)}(dI/dx)^2 &  \\sum \\_{S(p)}dI/dx dI/dy  \\\\\\\\ \\sum \\_{S(p)}dI/dx dI/dy &  \\sum \\_{S(p)}(dI/dy)^2 \\end{bmatrix}\\f]\nwhere the derivatives are computed using the Sobel operator.\nAfter that, it finds eigenvectors and eigenvalues of \\f$M\\f$ and stores them in the destination image as\n\\f$(\\lambda\\_1, \\lambda\\_2, x\\_1, y\\_1, x\\_2, y\\_2)\\f$ where\n- \\f$\\lambda\\_1, \\lambda\\_2\\f$ are the non-sorted eigenvalues of \\f$M\\f$\n- \\f$x\\_1, y\\_1\\f$ are the eigenvectors corresponding to \\f$\\lambda\\_1\\f$\n- \\f$x\\_2, y\\_2\\f$ are the eigenvectors corresponding to \\f$\\lambda\\_2\\f$\n\nThe output of the function can be used for robust edge or corner detection.\n\n@sa  cornerMinEigenVal, cornerHarris, preCornerDetect\n\nPython prototype (for reference only):\n```python3\ncornerEigenValsAndVecs(src, blockSize, ksize[, dst[, borderType]]) -> dst\n```","ref":"Evision.html#cornerEigenValsAndVecs/3"},{"type":"function","title":"Evision.cornerEigenValsAndVecs/4","doc":"Calculates eigenvalues and eigenvectors of image blocks for corner detection.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input single-channel 8-bit or floating-point image.\n\n- **blockSize**: `integer()`.\n\n  Neighborhood size (see details below).\n\n- **ksize**: `integer()`.\n\n  Aperture parameter for the Sobel operator.\n\n##### Keyword Arguments\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method. See #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Image to store the results. It has the same size as src and the type CV_32FC(6) .\n\nFor every pixel \\f$p\\f$ , the function cornerEigenValsAndVecs considers a blockSize \\f$\\times\\f$ blockSize\nneighborhood \\f$S(p)\\f$ . It calculates the covariation matrix of derivatives over the neighborhood as:\n\\f[M =  \\begin{bmatrix} \\sum \\_{S(p)}(dI/dx)^2 &  \\sum \\_{S(p)}dI/dx dI/dy  \\\\\\\\ \\sum \\_{S(p)}dI/dx dI/dy &  \\sum \\_{S(p)}(dI/dy)^2 \\end{bmatrix}\\f]\nwhere the derivatives are computed using the Sobel operator.\nAfter that, it finds eigenvectors and eigenvalues of \\f$M\\f$ and stores them in the destination image as\n\\f$(\\lambda\\_1, \\lambda\\_2, x\\_1, y\\_1, x\\_2, y\\_2)\\f$ where\n- \\f$\\lambda\\_1, \\lambda\\_2\\f$ are the non-sorted eigenvalues of \\f$M\\f$\n- \\f$x\\_1, y\\_1\\f$ are the eigenvectors corresponding to \\f$\\lambda\\_1\\f$\n- \\f$x\\_2, y\\_2\\f$ are the eigenvectors corresponding to \\f$\\lambda\\_2\\f$\n\nThe output of the function can be used for robust edge or corner detection.\n\n@sa  cornerMinEigenVal, cornerHarris, preCornerDetect\n\nPython prototype (for reference only):\n```python3\ncornerEigenValsAndVecs(src, blockSize, ksize[, dst[, borderType]]) -> dst\n```","ref":"Evision.html#cornerEigenValsAndVecs/4"},{"type":"function","title":"Evision.cornerHarris/1","doc":"","ref":"Evision.html#cornerHarris/1"},{"type":"function","title":"Evision.cornerHarris/4","doc":"Harris corner detector.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input single-channel 8-bit or floating-point image.\n\n- **blockSize**: `integer()`.\n\n  Neighborhood size (see the details on #cornerEigenValsAndVecs ).\n\n- **ksize**: `integer()`.\n\n  Aperture parameter for the Sobel operator.\n\n- **k**: `double`.\n\n  Harris detector free parameter. See the formula above.\n\n##### Keyword Arguments\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method. See #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Image to store the Harris detector responses. It has the type CV_32FC1 and the same\n  size as src .\n\nThe function runs the Harris corner detector on the image. Similarly to cornerMinEigenVal and\ncornerEigenValsAndVecs , for each pixel \\f$(x, y)\\f$ it calculates a \\f$2\\times2\\f$ gradient covariance\nmatrix \\f$M^{(x,y)}\\f$ over a \\f$\\texttt{blockSize} \\times \\texttt{blockSize}\\f$ neighborhood. Then, it\ncomputes the following characteristic:\n\\f[\\texttt{dst} (x,y) =  \\mathrm{det} M^{(x,y)} - k  \\cdot \\left ( \\mathrm{tr} M^{(x,y)} \\right )^2\\f]\nCorners in the image can be found as the local maxima of this response map.\n\nPython prototype (for reference only):\n```python3\ncornerHarris(src, blockSize, ksize, k[, dst[, borderType]]) -> dst\n```","ref":"Evision.html#cornerHarris/4"},{"type":"function","title":"Evision.cornerHarris/5","doc":"Harris corner detector.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input single-channel 8-bit or floating-point image.\n\n- **blockSize**: `integer()`.\n\n  Neighborhood size (see the details on #cornerEigenValsAndVecs ).\n\n- **ksize**: `integer()`.\n\n  Aperture parameter for the Sobel operator.\n\n- **k**: `double`.\n\n  Harris detector free parameter. See the formula above.\n\n##### Keyword Arguments\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method. See #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Image to store the Harris detector responses. It has the type CV_32FC1 and the same\n  size as src .\n\nThe function runs the Harris corner detector on the image. Similarly to cornerMinEigenVal and\ncornerEigenValsAndVecs , for each pixel \\f$(x, y)\\f$ it calculates a \\f$2\\times2\\f$ gradient covariance\nmatrix \\f$M^{(x,y)}\\f$ over a \\f$\\texttt{blockSize} \\times \\texttt{blockSize}\\f$ neighborhood. Then, it\ncomputes the following characteristic:\n\\f[\\texttt{dst} (x,y) =  \\mathrm{det} M^{(x,y)} - k  \\cdot \\left ( \\mathrm{tr} M^{(x,y)} \\right )^2\\f]\nCorners in the image can be found as the local maxima of this response map.\n\nPython prototype (for reference only):\n```python3\ncornerHarris(src, blockSize, ksize, k[, dst[, borderType]]) -> dst\n```","ref":"Evision.html#cornerHarris/5"},{"type":"function","title":"Evision.cornerMinEigenVal/1","doc":"","ref":"Evision.html#cornerMinEigenVal/1"},{"type":"function","title":"Evision.cornerMinEigenVal/2","doc":"Calculates the minimal eigenvalue of gradient matrices for corner detection.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input single-channel 8-bit or floating-point image.\n\n- **blockSize**: `integer()`.\n\n  Neighborhood size (see the details on #cornerEigenValsAndVecs ).\n\n##### Keyword Arguments\n- **ksize**: `integer()`.\n\n  Aperture parameter for the Sobel operator.\n\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method. See #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Image to store the minimal eigenvalues. It has the type CV_32FC1 and the same size as\n  src .\n\nThe function is similar to cornerEigenValsAndVecs but it calculates and stores only the minimal\neigenvalue of the covariance matrix of derivatives, that is, \\f$\\min(\\lambda\\_1, \\lambda\\_2)\\f$ in terms\nof the formulae in the cornerEigenValsAndVecs description.\n\nPython prototype (for reference only):\n```python3\ncornerMinEigenVal(src, blockSize[, dst[, ksize[, borderType]]]) -> dst\n```","ref":"Evision.html#cornerMinEigenVal/2"},{"type":"function","title":"Evision.cornerMinEigenVal/3","doc":"Calculates the minimal eigenvalue of gradient matrices for corner detection.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input single-channel 8-bit or floating-point image.\n\n- **blockSize**: `integer()`.\n\n  Neighborhood size (see the details on #cornerEigenValsAndVecs ).\n\n##### Keyword Arguments\n- **ksize**: `integer()`.\n\n  Aperture parameter for the Sobel operator.\n\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method. See #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Image to store the minimal eigenvalues. It has the type CV_32FC1 and the same size as\n  src .\n\nThe function is similar to cornerEigenValsAndVecs but it calculates and stores only the minimal\neigenvalue of the covariance matrix of derivatives, that is, \\f$\\min(\\lambda\\_1, \\lambda\\_2)\\f$ in terms\nof the formulae in the cornerEigenValsAndVecs description.\n\nPython prototype (for reference only):\n```python3\ncornerMinEigenVal(src, blockSize[, dst[, ksize[, borderType]]]) -> dst\n```","ref":"Evision.html#cornerMinEigenVal/3"},{"type":"function","title":"Evision.cornerSubPix/1","doc":"","ref":"Evision.html#cornerSubPix/1"},{"type":"function","title":"Evision.cornerSubPix/5","doc":"Refines the corner locations.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Input single-channel, 8-bit or float image.\n\n- **winSize**: `Size`.\n\n  Half of the side length of the search window. For example, if winSize=Size(5,5) ,\n  then a \\f$(5*2+1) \\times (5*2+1) = 11 \\times 11\\f$ search window is used.\n\n- **zeroZone**: `Size`.\n\n  Half of the size of the dead region in the middle of the search zone over which\n  the summation in the formula below is not done. It is used sometimes to avoid possible\n  singularities of the autocorrelation matrix. The value of (-1,-1) indicates that there is no such\n  a size.\n\n- **criteria**: `TermCriteria`.\n\n  Criteria for termination of the iterative process of corner refinement. That is,\n  the process of corner position refinement stops either after criteria.maxCount iterations or when\n  the corner position moves by less than criteria.epsilon on some iteration.\n\n##### Return\n- **corners**: `Evision.Mat.t()`.\n\n  Initial coordinates of the input corners and refined coordinates provided for\n  output.\n\nThe function iterates to find the sub-pixel accurate location of corners or radial saddle\npoints as described in @cite forstner1987fast, and as shown on the figure below.\n![image](pics/cornersubpix.png)\nSub-pixel accurate corner locator is based on the observation that every vector from the center \\f$q\\f$\nto a point \\f$p\\f$ located within a neighborhood of \\f$q\\f$ is orthogonal to the image gradient at \\f$p\\f$\nsubject to image and measurement noise. Consider the expression:\n\\f[\\epsilon \\_i = {DI\\_{p\\_i}}^T  \\cdot (q - p\\_i)\\f]\nwhere \\f${DI\\_{p\\_i}}\\f$ is an image gradient at one of the points \\f$p\\_i\\f$ in a neighborhood of \\f$q\\f$ . The\nvalue of \\f$q\\f$ is to be found so that \\f$\\epsilon\\_i\\f$ is minimized. A system of equations may be set up\nwith \\f$\\epsilon\\_i\\f$ set to zero:\n\\f[\\sum \\_i(DI\\_{p\\_i}  \\cdot {DI\\_{p\\_i}}^T) \\cdot q -  \\sum \\_i(DI\\_{p\\_i}  \\cdot {DI\\_{p\\_i}}^T  \\cdot p\\_i)\\f]\nwhere the gradients are summed within a neighborhood (\"search window\") of \\f$q\\f$ . Calling the first\ngradient term \\f$G\\f$ and the second gradient term \\f$b\\f$ gives:\n\\f[q = G^{-1}  \\cdot b\\f]\nThe algorithm sets the center of the neighborhood window at this new center \\f$q\\f$ and then iterates\nuntil the center stays within a set threshold.\n\nPython prototype (for reference only):\n```python3\ncornerSubPix(image, corners, winSize, zeroZone, criteria) -> corners\n```","ref":"Evision.html#cornerSubPix/5"},{"type":"function","title":"Evision.correctMatches/1","doc":"","ref":"Evision.html#correctMatches/1"},{"type":"function","title":"Evision.correctMatches/3","doc":"Refines coordinates of corresponding points.\n\n##### Positional Arguments\n- **f**: `Evision.Mat`.\n\n  3x3 fundamental matrix.\n\n- **points1**: `Evision.Mat`.\n\n  1xN array containing the first set of points.\n\n- **points2**: `Evision.Mat`.\n\n  1xN array containing the second set of points.\n\n##### Return\n- **newPoints1**: `Evision.Mat.t()`.\n\n  The optimized points1.\n\n- **newPoints2**: `Evision.Mat.t()`.\n\n  The optimized points2.\n\nThe function implements the Optimal Triangulation Method (see Multiple View Geometry @cite HartleyZ00 for details).\nFor each given point correspondence points1[i] \\<-\\> points2[i], and a fundamental matrix F, it\ncomputes the corrected correspondences newPoints1[i] \\<-\\> newPoints2[i] that minimize the geometric\nerror \\f$d(points1\\[i], newPoints1\\[i])^2 + d(points2\\[i],newPoints2\\[i])^2\\f$ (where \\f$d(a,b)\\f$ is the\ngeometric distance between points \\f$a\\f$ and \\f$b\\f$ ) subject to the epipolar constraint\n\\f$newPoints2^T \\cdot F \\cdot newPoints1 = 0\\f$ .\n\nPython prototype (for reference only):\n```python3\ncorrectMatches(F, points1, points2[, newPoints1[, newPoints2]]) -> newPoints1, newPoints2\n```","ref":"Evision.html#correctMatches/3"},{"type":"function","title":"Evision.correctMatches/4","doc":"Refines coordinates of corresponding points.\n\n##### Positional Arguments\n- **f**: `Evision.Mat`.\n\n  3x3 fundamental matrix.\n\n- **points1**: `Evision.Mat`.\n\n  1xN array containing the first set of points.\n\n- **points2**: `Evision.Mat`.\n\n  1xN array containing the second set of points.\n\n##### Return\n- **newPoints1**: `Evision.Mat.t()`.\n\n  The optimized points1.\n\n- **newPoints2**: `Evision.Mat.t()`.\n\n  The optimized points2.\n\nThe function implements the Optimal Triangulation Method (see Multiple View Geometry @cite HartleyZ00 for details).\nFor each given point correspondence points1[i] \\<-\\> points2[i], and a fundamental matrix F, it\ncomputes the corrected correspondences newPoints1[i] \\<-\\> newPoints2[i] that minimize the geometric\nerror \\f$d(points1\\[i], newPoints1\\[i])^2 + d(points2\\[i],newPoints2\\[i])^2\\f$ (where \\f$d(a,b)\\f$ is the\ngeometric distance between points \\f$a\\f$ and \\f$b\\f$ ) subject to the epipolar constraint\n\\f$newPoints2^T \\cdot F \\cdot newPoints1 = 0\\f$ .\n\nPython prototype (for reference only):\n```python3\ncorrectMatches(F, points1, points2[, newPoints1[, newPoints2]]) -> newPoints1, newPoints2\n```","ref":"Evision.html#correctMatches/4"},{"type":"function","title":"Evision.countNonZero/1","doc":"Counts non-zero array elements.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  single-channel array.\n\n##### Return\n- **retval**: `integer()`\n\nThe function returns the number of non-zero elements in src :\n\\f[\\sum \\_{I: \\; \\texttt{src} (I) \\ne0 } 1\\f]\nThe function do not work with multi-channel arrays. If you need to count non-zero array\nelements across all the channels, use Mat::reshape first to reinterpret the array as\nsingle-channel. Or you may extract the particular channel using either extractImageCOI, or\nmixChannels, or split.\n**Note**: \n- If only whether there are non-zero elements is important, @ref hasNonZero is helpful.\n- If the location of non-zero array elements is important, @ref findNonZero is helpful.\n@sa  mean, meanStdDev, norm, minMaxLoc, calcCovarMatrix\n@sa  findNonZero, hasNonZero\n\nPython prototype (for reference only):\n```python3\ncountNonZero(src) -> retval\n```","ref":"Evision.html#countNonZero/1"},{"type":"function","title":"Evision.createAffineTransformer/1","doc":"createAffineTransformer\n\n##### Positional Arguments\n- **fullAffine**: `bool`\n\n##### Return\n- **retval**: `Evision.AffineTransformer.t()`\n\nComplete constructor\n\nPython prototype (for reference only):\n```python3\ncreateAffineTransformer(fullAffine) -> retval\n```","ref":"Evision.html#createAffineTransformer/1"},{"type":"function","title":"Evision.createAlignMTB/0","doc":"Creates AlignMTB object\n##### Keyword Arguments\n- **max_bits**: `integer()`.\n\n  logarithm to the base 2 of maximal shift in each dimension. Values of 5 and 6 are\n  usually good enough (31 and 63 pixels shift respectively).\n\n- **exclude_range**: `integer()`.\n\n  range for exclusion bitmap that is constructed to suppress noise around the\n  median value.\n\n- **cut**: `bool`.\n\n  if true cuts images, otherwise fills the new regions with zeros.\n\n##### Return\n- **retval**: `Evision.AlignMTB.t()`\n\nPython prototype (for reference only):\n```python3\ncreateAlignMTB([, max_bits[, exclude_range[, cut]]]) -> retval\n```","ref":"Evision.html#createAlignMTB/0"},{"type":"function","title":"Evision.createAlignMTB/1","doc":"Creates AlignMTB object\n##### Keyword Arguments\n- **max_bits**: `integer()`.\n\n  logarithm to the base 2 of maximal shift in each dimension. Values of 5 and 6 are\n  usually good enough (31 and 63 pixels shift respectively).\n\n- **exclude_range**: `integer()`.\n\n  range for exclusion bitmap that is constructed to suppress noise around the\n  median value.\n\n- **cut**: `bool`.\n\n  if true cuts images, otherwise fills the new regions with zeros.\n\n##### Return\n- **retval**: `Evision.AlignMTB.t()`\n\nPython prototype (for reference only):\n```python3\ncreateAlignMTB([, max_bits[, exclude_range[, cut]]]) -> retval\n```","ref":"Evision.html#createAlignMTB/1"},{"type":"function","title":"Evision.createBackgroundSubtractorKNN/0","doc":"Creates KNN Background Subtractor\n##### Keyword Arguments\n- **history**: `integer()`.\n\n  Length of the history.\n\n- **dist2Threshold**: `double`.\n\n  Threshold on the squared distance between the pixel and the sample to decide\n  whether a pixel is close to that sample. This parameter does not affect the background update.\n\n- **detectShadows**: `bool`.\n\n  If true, the algorithm will detect shadows and mark them. It decreases the\n  speed a bit, so if you do not need this feature, set the parameter to false.\n\n##### Return\n- **retval**: `Evision.BackgroundSubtractorKNN.t()`\n\nPython prototype (for reference only):\n```python3\ncreateBackgroundSubtractorKNN([, history[, dist2Threshold[, detectShadows]]]) -> retval\n```","ref":"Evision.html#createBackgroundSubtractorKNN/0"},{"type":"function","title":"Evision.createBackgroundSubtractorKNN/1","doc":"Creates KNN Background Subtractor\n##### Keyword Arguments\n- **history**: `integer()`.\n\n  Length of the history.\n\n- **dist2Threshold**: `double`.\n\n  Threshold on the squared distance between the pixel and the sample to decide\n  whether a pixel is close to that sample. This parameter does not affect the background update.\n\n- **detectShadows**: `bool`.\n\n  If true, the algorithm will detect shadows and mark them. It decreases the\n  speed a bit, so if you do not need this feature, set the parameter to false.\n\n##### Return\n- **retval**: `Evision.BackgroundSubtractorKNN.t()`\n\nPython prototype (for reference only):\n```python3\ncreateBackgroundSubtractorKNN([, history[, dist2Threshold[, detectShadows]]]) -> retval\n```","ref":"Evision.html#createBackgroundSubtractorKNN/1"},{"type":"function","title":"Evision.createBackgroundSubtractorMOG2/0","doc":"Creates MOG2 Background Subtractor\n##### Keyword Arguments\n- **history**: `integer()`.\n\n  Length of the history.\n\n- **varThreshold**: `double`.\n\n  Threshold on the squared Mahalanobis distance between the pixel and the model\n  to decide whether a pixel is well described by the background model. This parameter does not\n  affect the background update.\n\n- **detectShadows**: `bool`.\n\n  If true, the algorithm will detect shadows and mark them. It decreases the\n  speed a bit, so if you do not need this feature, set the parameter to false.\n\n##### Return\n- **retval**: `Evision.BackgroundSubtractorMOG2.t()`\n\nPython prototype (for reference only):\n```python3\ncreateBackgroundSubtractorMOG2([, history[, varThreshold[, detectShadows]]]) -> retval\n```","ref":"Evision.html#createBackgroundSubtractorMOG2/0"},{"type":"function","title":"Evision.createBackgroundSubtractorMOG2/1","doc":"Creates MOG2 Background Subtractor\n##### Keyword Arguments\n- **history**: `integer()`.\n\n  Length of the history.\n\n- **varThreshold**: `double`.\n\n  Threshold on the squared Mahalanobis distance between the pixel and the model\n  to decide whether a pixel is well described by the background model. This parameter does not\n  affect the background update.\n\n- **detectShadows**: `bool`.\n\n  If true, the algorithm will detect shadows and mark them. It decreases the\n  speed a bit, so if you do not need this feature, set the parameter to false.\n\n##### Return\n- **retval**: `Evision.BackgroundSubtractorMOG2.t()`\n\nPython prototype (for reference only):\n```python3\ncreateBackgroundSubtractorMOG2([, history[, varThreshold[, detectShadows]]]) -> retval\n```","ref":"Evision.html#createBackgroundSubtractorMOG2/1"},{"type":"function","title":"Evision.createCalibrateDebevec/0","doc":"Creates CalibrateDebevec object\n##### Keyword Arguments\n- **samples**: `integer()`.\n\n  number of pixel locations to use\n\n- **lambda**: `float`.\n\n  smoothness term weight. Greater values produce smoother results, but can alter the\n  response.\n\n- **random**: `bool`.\n\n  if true sample pixel locations are chosen at random, otherwise they form a\n  rectangular grid.\n\n##### Return\n- **retval**: `Evision.CalibrateDebevec.t()`\n\nPython prototype (for reference only):\n```python3\ncreateCalibrateDebevec([, samples[, lambda[, random]]]) -> retval\n```","ref":"Evision.html#createCalibrateDebevec/0"},{"type":"function","title":"Evision.createCalibrateDebevec/1","doc":"Creates CalibrateDebevec object\n##### Keyword Arguments\n- **samples**: `integer()`.\n\n  number of pixel locations to use\n\n- **lambda**: `float`.\n\n  smoothness term weight. Greater values produce smoother results, but can alter the\n  response.\n\n- **random**: `bool`.\n\n  if true sample pixel locations are chosen at random, otherwise they form a\n  rectangular grid.\n\n##### Return\n- **retval**: `Evision.CalibrateDebevec.t()`\n\nPython prototype (for reference only):\n```python3\ncreateCalibrateDebevec([, samples[, lambda[, random]]]) -> retval\n```","ref":"Evision.html#createCalibrateDebevec/1"},{"type":"function","title":"Evision.createCalibrateRobertson/0","doc":"Creates CalibrateRobertson object\n##### Keyword Arguments\n- **max_iter**: `integer()`.\n\n  maximal number of Gauss-Seidel solver iterations.\n\n- **threshold**: `float`.\n\n  target difference between results of two successive steps of the minimization.\n\n##### Return\n- **retval**: `Evision.CalibrateRobertson.t()`\n\nPython prototype (for reference only):\n```python3\ncreateCalibrateRobertson([, max_iter[, threshold]]) -> retval\n```","ref":"Evision.html#createCalibrateRobertson/0"},{"type":"function","title":"Evision.createCalibrateRobertson/1","doc":"Creates CalibrateRobertson object\n##### Keyword Arguments\n- **max_iter**: `integer()`.\n\n  maximal number of Gauss-Seidel solver iterations.\n\n- **threshold**: `float`.\n\n  target difference between results of two successive steps of the minimization.\n\n##### Return\n- **retval**: `Evision.CalibrateRobertson.t()`\n\nPython prototype (for reference only):\n```python3\ncreateCalibrateRobertson([, max_iter[, threshold]]) -> retval\n```","ref":"Evision.html#createCalibrateRobertson/1"},{"type":"function","title":"Evision.createChiHistogramCostExtractor/0","doc":"createChiHistogramCostExtractor\n##### Keyword Arguments\n- **nDummies**: `integer()`.\n- **defaultCost**: `float`.\n\n##### Return\n- **retval**: `Evision.HistogramCostExtractor.t()`\n\nPython prototype (for reference only):\n```python3\ncreateChiHistogramCostExtractor([, nDummies[, defaultCost]]) -> retval\n```","ref":"Evision.html#createChiHistogramCostExtractor/0"},{"type":"function","title":"Evision.createChiHistogramCostExtractor/1","doc":"createChiHistogramCostExtractor\n##### Keyword Arguments\n- **nDummies**: `integer()`.\n- **defaultCost**: `float`.\n\n##### Return\n- **retval**: `Evision.HistogramCostExtractor.t()`\n\nPython prototype (for reference only):\n```python3\ncreateChiHistogramCostExtractor([, nDummies[, defaultCost]]) -> retval\n```","ref":"Evision.html#createChiHistogramCostExtractor/1"},{"type":"function","title":"Evision.createCLAHE/0","doc":"Creates a smart pointer to a cv::CLAHE class and initializes it.\n##### Keyword Arguments\n- **clipLimit**: `double`.\n\n  Threshold for contrast limiting.\n\n- **tileGridSize**: `Size`.\n\n  Size of grid for histogram equalization. Input image will be divided into\n  equally sized rectangular tiles. tileGridSize defines the number of tiles in row and column.\n\n##### Return\n- **retval**: `Evision.CLAHE.t()`\n\nPython prototype (for reference only):\n```python3\ncreateCLAHE([, clipLimit[, tileGridSize]]) -> retval\n```","ref":"Evision.html#createCLAHE/0"},{"type":"function","title":"Evision.createCLAHE/1","doc":"Creates a smart pointer to a cv::CLAHE class and initializes it.\n##### Keyword Arguments\n- **clipLimit**: `double`.\n\n  Threshold for contrast limiting.\n\n- **tileGridSize**: `Size`.\n\n  Size of grid for histogram equalization. Input image will be divided into\n  equally sized rectangular tiles. tileGridSize defines the number of tiles in row and column.\n\n##### Return\n- **retval**: `Evision.CLAHE.t()`\n\nPython prototype (for reference only):\n```python3\ncreateCLAHE([, clipLimit[, tileGridSize]]) -> retval\n```","ref":"Evision.html#createCLAHE/1"},{"type":"function","title":"Evision.createEMDHistogramCostExtractor/0","doc":"createEMDHistogramCostExtractor\n##### Keyword Arguments\n- **flag**: `integer()`.\n- **nDummies**: `integer()`.\n- **defaultCost**: `float`.\n\n##### Return\n- **retval**: `Evision.HistogramCostExtractor.t()`\n\nPython prototype (for reference only):\n```python3\ncreateEMDHistogramCostExtractor([, flag[, nDummies[, defaultCost]]]) -> retval\n```","ref":"Evision.html#createEMDHistogramCostExtractor/0"},{"type":"function","title":"Evision.createEMDHistogramCostExtractor/1","doc":"createEMDHistogramCostExtractor\n##### Keyword Arguments\n- **flag**: `integer()`.\n- **nDummies**: `integer()`.\n- **defaultCost**: `float`.\n\n##### Return\n- **retval**: `Evision.HistogramCostExtractor.t()`\n\nPython prototype (for reference only):\n```python3\ncreateEMDHistogramCostExtractor([, flag[, nDummies[, defaultCost]]]) -> retval\n```","ref":"Evision.html#createEMDHistogramCostExtractor/1"},{"type":"function","title":"Evision.createEMDL1HistogramCostExtractor/0","doc":"createEMDL1HistogramCostExtractor\n##### Keyword Arguments\n- **nDummies**: `integer()`.\n- **defaultCost**: `float`.\n\n##### Return\n- **retval**: `Evision.HistogramCostExtractor.t()`\n\nPython prototype (for reference only):\n```python3\ncreateEMDL1HistogramCostExtractor([, nDummies[, defaultCost]]) -> retval\n```","ref":"Evision.html#createEMDL1HistogramCostExtractor/0"},{"type":"function","title":"Evision.createEMDL1HistogramCostExtractor/1","doc":"createEMDL1HistogramCostExtractor\n##### Keyword Arguments\n- **nDummies**: `integer()`.\n- **defaultCost**: `float`.\n\n##### Return\n- **retval**: `Evision.HistogramCostExtractor.t()`\n\nPython prototype (for reference only):\n```python3\ncreateEMDL1HistogramCostExtractor([, nDummies[, defaultCost]]) -> retval\n```","ref":"Evision.html#createEMDL1HistogramCostExtractor/1"},{"type":"function","title":"Evision.createGeneralizedHoughBallard/0","doc":"Creates a smart pointer to a cv::GeneralizedHoughBallard class and initializes it.\n##### Return\n- **retval**: `Evision.GeneralizedHoughBallard.t()`\n\nPython prototype (for reference only):\n```python3\ncreateGeneralizedHoughBallard() -> retval\n```","ref":"Evision.html#createGeneralizedHoughBallard/0"},{"type":"function","title":"Evision.createGeneralizedHoughBallard/1","doc":"","ref":"Evision.html#createGeneralizedHoughBallard/1"},{"type":"function","title":"Evision.createGeneralizedHoughGuil/0","doc":"Creates a smart pointer to a cv::GeneralizedHoughGuil class and initializes it.\n##### Return\n- **retval**: `Evision.GeneralizedHoughGuil.t()`\n\nPython prototype (for reference only):\n```python3\ncreateGeneralizedHoughGuil() -> retval\n```","ref":"Evision.html#createGeneralizedHoughGuil/0"},{"type":"function","title":"Evision.createGeneralizedHoughGuil/1","doc":"","ref":"Evision.html#createGeneralizedHoughGuil/1"},{"type":"function","title":"Evision.createHanningWindow/1","doc":"","ref":"Evision.html#createHanningWindow/1"},{"type":"function","title":"Evision.createHanningWindow/2","doc":"This function computes a Hanning window coefficients in two dimensions.\n\n##### Positional Arguments\n- **winSize**: `Size`.\n\n  The window size specifications (both width and height must be > 1)\n\n- **type**: `integer()`.\n\n  Created array type\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination array to place Hann coefficients in\n\nSee (http://en.wikipedia.org/wiki/Hann_function) and (http://en.wikipedia.org/wiki/Window_function)\nfor more information.\nAn example is shown below:\n```\n// create hanning window of size 100x100 and type CV_32F\nMat hann;\ncreateHanningWindow(hann, Size(100, 100), CV_32F);\n```\n\nPython prototype (for reference only):\n```python3\ncreateHanningWindow(winSize, type[, dst]) -> dst\n```","ref":"Evision.html#createHanningWindow/2"},{"type":"function","title":"Evision.createHanningWindow/3","doc":"This function computes a Hanning window coefficients in two dimensions.\n\n##### Positional Arguments\n- **winSize**: `Size`.\n\n  The window size specifications (both width and height must be > 1)\n\n- **type**: `integer()`.\n\n  Created array type\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination array to place Hann coefficients in\n\nSee (http://en.wikipedia.org/wiki/Hann_function) and (http://en.wikipedia.org/wiki/Window_function)\nfor more information.\nAn example is shown below:\n```\n// create hanning window of size 100x100 and type CV_32F\nMat hann;\ncreateHanningWindow(hann, Size(100, 100), CV_32F);\n```\n\nPython prototype (for reference only):\n```python3\ncreateHanningWindow(winSize, type[, dst]) -> dst\n```","ref":"Evision.html#createHanningWindow/3"},{"type":"function","title":"Evision.createHausdorffDistanceExtractor/0","doc":"createHausdorffDistanceExtractor\n##### Keyword Arguments\n- **distanceFlag**: `integer()`.\n- **rankProp**: `float`.\n\n##### Return\n- **retval**: `Evision.HausdorffDistanceExtractor.t()`\n\nPython prototype (for reference only):\n```python3\ncreateHausdorffDistanceExtractor([, distanceFlag[, rankProp]]) -> retval\n```","ref":"Evision.html#createHausdorffDistanceExtractor/0"},{"type":"function","title":"Evision.createHausdorffDistanceExtractor/1","doc":"createHausdorffDistanceExtractor\n##### Keyword Arguments\n- **distanceFlag**: `integer()`.\n- **rankProp**: `float`.\n\n##### Return\n- **retval**: `Evision.HausdorffDistanceExtractor.t()`\n\nPython prototype (for reference only):\n```python3\ncreateHausdorffDistanceExtractor([, distanceFlag[, rankProp]]) -> retval\n```","ref":"Evision.html#createHausdorffDistanceExtractor/1"},{"type":"function","title":"Evision.createLineSegmentDetector/0","doc":"Creates a smart pointer to a LineSegmentDetector object and initializes it.\n##### Keyword Arguments\n- **refine**: `integer()`.\n\n  The way found lines will be refined, see #LineSegmentDetectorModes\n\n- **scale**: `double`.\n\n  The scale of the image that will be used to find the lines. Range (0..1].\n\n- **sigma_scale**: `double`.\n\n  Sigma for Gaussian filter. It is computed as sigma = sigma_scale/scale.\n\n- **quant**: `double`.\n\n  Bound to the quantization error on the gradient norm.\n\n- **ang_th**: `double`.\n\n  Gradient angle tolerance in degrees.\n\n- **log_eps**: `double`.\n\n  Detection threshold: -log10(NFA) \\> log_eps. Used only when advance refinement is chosen.\n\n- **density_th**: `double`.\n\n  Minimal density of aligned region points in the enclosing rectangle.\n\n- **n_bins**: `integer()`.\n\n  Number of bins in pseudo-ordering of gradient modulus.\n\n##### Return\n- **retval**: `Evision.LineSegmentDetector.t()`\n\nThe LineSegmentDetector algorithm is defined using the standard values. Only advanced users may want\nto edit those, as to tailor it for their own application.\n\nPython prototype (for reference only):\n```python3\ncreateLineSegmentDetector([, refine[, scale[, sigma_scale[, quant[, ang_th[, log_eps[, density_th[, n_bins]]]]]]]]) -> retval\n```","ref":"Evision.html#createLineSegmentDetector/0"},{"type":"function","title":"Evision.createLineSegmentDetector/1","doc":"Creates a smart pointer to a LineSegmentDetector object and initializes it.\n##### Keyword Arguments\n- **refine**: `integer()`.\n\n  The way found lines will be refined, see #LineSegmentDetectorModes\n\n- **scale**: `double`.\n\n  The scale of the image that will be used to find the lines. Range (0..1].\n\n- **sigma_scale**: `double`.\n\n  Sigma for Gaussian filter. It is computed as sigma = sigma_scale/scale.\n\n- **quant**: `double`.\n\n  Bound to the quantization error on the gradient norm.\n\n- **ang_th**: `double`.\n\n  Gradient angle tolerance in degrees.\n\n- **log_eps**: `double`.\n\n  Detection threshold: -log10(NFA) \\> log_eps. Used only when advance refinement is chosen.\n\n- **density_th**: `double`.\n\n  Minimal density of aligned region points in the enclosing rectangle.\n\n- **n_bins**: `integer()`.\n\n  Number of bins in pseudo-ordering of gradient modulus.\n\n##### Return\n- **retval**: `Evision.LineSegmentDetector.t()`\n\nThe LineSegmentDetector algorithm is defined using the standard values. Only advanced users may want\nto edit those, as to tailor it for their own application.\n\nPython prototype (for reference only):\n```python3\ncreateLineSegmentDetector([, refine[, scale[, sigma_scale[, quant[, ang_th[, log_eps[, density_th[, n_bins]]]]]]]]) -> retval\n```","ref":"Evision.html#createLineSegmentDetector/1"},{"type":"function","title":"Evision.createMergeDebevec/0","doc":"Creates MergeDebevec object\n##### Return\n- **retval**: `Evision.MergeDebevec.t()`\n\nPython prototype (for reference only):\n```python3\ncreateMergeDebevec() -> retval\n```","ref":"Evision.html#createMergeDebevec/0"},{"type":"function","title":"Evision.createMergeDebevec/1","doc":"","ref":"Evision.html#createMergeDebevec/1"},{"type":"function","title":"Evision.createMergeMertens/0","doc":"Creates MergeMertens object\n##### Keyword Arguments\n- **contrast_weight**: `float`.\n\n  contrast measure weight. See MergeMertens.\n\n- **saturation_weight**: `float`.\n\n  saturation measure weight\n\n- **exposure_weight**: `float`.\n\n  well-exposedness measure weight\n\n##### Return\n- **retval**: `Evision.MergeMertens.t()`\n\nPython prototype (for reference only):\n```python3\ncreateMergeMertens([, contrast_weight[, saturation_weight[, exposure_weight]]]) -> retval\n```","ref":"Evision.html#createMergeMertens/0"},{"type":"function","title":"Evision.createMergeMertens/1","doc":"Creates MergeMertens object\n##### Keyword Arguments\n- **contrast_weight**: `float`.\n\n  contrast measure weight. See MergeMertens.\n\n- **saturation_weight**: `float`.\n\n  saturation measure weight\n\n- **exposure_weight**: `float`.\n\n  well-exposedness measure weight\n\n##### Return\n- **retval**: `Evision.MergeMertens.t()`\n\nPython prototype (for reference only):\n```python3\ncreateMergeMertens([, contrast_weight[, saturation_weight[, exposure_weight]]]) -> retval\n```","ref":"Evision.html#createMergeMertens/1"},{"type":"function","title":"Evision.createMergeRobertson/0","doc":"Creates MergeRobertson object\n##### Return\n- **retval**: `Evision.MergeRobertson.t()`\n\nPython prototype (for reference only):\n```python3\ncreateMergeRobertson() -> retval\n```","ref":"Evision.html#createMergeRobertson/0"},{"type":"function","title":"Evision.createMergeRobertson/1","doc":"","ref":"Evision.html#createMergeRobertson/1"},{"type":"function","title":"Evision.createNormHistogramCostExtractor/0","doc":"createNormHistogramCostExtractor\n##### Keyword Arguments\n- **flag**: `integer()`.\n- **nDummies**: `integer()`.\n- **defaultCost**: `float`.\n\n##### Return\n- **retval**: `Evision.HistogramCostExtractor.t()`\n\nPython prototype (for reference only):\n```python3\ncreateNormHistogramCostExtractor([, flag[, nDummies[, defaultCost]]]) -> retval\n```","ref":"Evision.html#createNormHistogramCostExtractor/0"},{"type":"function","title":"Evision.createNormHistogramCostExtractor/1","doc":"createNormHistogramCostExtractor\n##### Keyword Arguments\n- **flag**: `integer()`.\n- **nDummies**: `integer()`.\n- **defaultCost**: `float`.\n\n##### Return\n- **retval**: `Evision.HistogramCostExtractor.t()`\n\nPython prototype (for reference only):\n```python3\ncreateNormHistogramCostExtractor([, flag[, nDummies[, defaultCost]]]) -> retval\n```","ref":"Evision.html#createNormHistogramCostExtractor/1"},{"type":"function","title":"Evision.createShapeContextDistanceExtractor/0","doc":"createShapeContextDistanceExtractor\n##### Keyword Arguments\n- **nAngularBins**: `integer()`.\n- **nRadialBins**: `integer()`.\n- **innerRadius**: `float`.\n- **outerRadius**: `float`.\n- **iterations**: `integer()`.\n- **comparer**: `Evision.HistogramCostExtractor`.\n- **transformer**: `Evision.ShapeTransformer`.\n\n##### Return\n- **retval**: `Evision.ShapeContextDistanceExtractor.t()`\n\nPython prototype (for reference only):\n```python3\ncreateShapeContextDistanceExtractor([, nAngularBins[, nRadialBins[, innerRadius[, outerRadius[, iterations[, comparer[, transformer]]]]]]]) -> retval\n```","ref":"Evision.html#createShapeContextDistanceExtractor/0"},{"type":"function","title":"Evision.createShapeContextDistanceExtractor/1","doc":"createShapeContextDistanceExtractor\n##### Keyword Arguments\n- **nAngularBins**: `integer()`.\n- **nRadialBins**: `integer()`.\n- **innerRadius**: `float`.\n- **outerRadius**: `float`.\n- **iterations**: `integer()`.\n- **comparer**: `Evision.HistogramCostExtractor`.\n- **transformer**: `Evision.ShapeTransformer`.\n\n##### Return\n- **retval**: `Evision.ShapeContextDistanceExtractor.t()`\n\nPython prototype (for reference only):\n```python3\ncreateShapeContextDistanceExtractor([, nAngularBins[, nRadialBins[, innerRadius[, outerRadius[, iterations[, comparer[, transformer]]]]]]]) -> retval\n```","ref":"Evision.html#createShapeContextDistanceExtractor/1"},{"type":"function","title":"Evision.createThinPlateSplineShapeTransformer/0","doc":"createThinPlateSplineShapeTransformer\n##### Keyword Arguments\n- **regularizationParameter**: `double`.\n\n##### Return\n- **retval**: `Evision.ThinPlateSplineShapeTransformer.t()`\n\nComplete constructor\n\nPython prototype (for reference only):\n```python3\ncreateThinPlateSplineShapeTransformer([, regularizationParameter]) -> retval\n```","ref":"Evision.html#createThinPlateSplineShapeTransformer/0"},{"type":"function","title":"Evision.createThinPlateSplineShapeTransformer/1","doc":"createThinPlateSplineShapeTransformer\n##### Keyword Arguments\n- **regularizationParameter**: `double`.\n\n##### Return\n- **retval**: `Evision.ThinPlateSplineShapeTransformer.t()`\n\nComplete constructor\n\nPython prototype (for reference only):\n```python3\ncreateThinPlateSplineShapeTransformer([, regularizationParameter]) -> retval\n```","ref":"Evision.html#createThinPlateSplineShapeTransformer/1"},{"type":"function","title":"Evision.createTonemap/0","doc":"Creates simple linear mapper with gamma correction\n##### Keyword Arguments\n- **gamma**: `float`.\n\n  positive value for gamma correction. Gamma value of 1.0 implies no correction, gamma\n  equal to 2.2f is suitable for most displays.\n  Generally gamma \\> 1 brightens the image and gamma \\< 1 darkens it.\n\n##### Return\n- **retval**: `Evision.Tonemap.t()`\n\nPython prototype (for reference only):\n```python3\ncreateTonemap([, gamma]) -> retval\n```","ref":"Evision.html#createTonemap/0"},{"type":"function","title":"Evision.createTonemap/1","doc":"Creates simple linear mapper with gamma correction\n##### Keyword Arguments\n- **gamma**: `float`.\n\n  positive value for gamma correction. Gamma value of 1.0 implies no correction, gamma\n  equal to 2.2f is suitable for most displays.\n  Generally gamma \\> 1 brightens the image and gamma \\< 1 darkens it.\n\n##### Return\n- **retval**: `Evision.Tonemap.t()`\n\nPython prototype (for reference only):\n```python3\ncreateTonemap([, gamma]) -> retval\n```","ref":"Evision.html#createTonemap/1"},{"type":"function","title":"Evision.createTonemapDrago/0","doc":"Creates TonemapDrago object\n##### Keyword Arguments\n- **gamma**: `float`.\n\n  gamma value for gamma correction. See createTonemap\n\n- **saturation**: `float`.\n\n  positive saturation enhancement value. 1.0 preserves saturation, values greater\n  than 1 increase saturation and values less than 1 decrease it.\n\n- **bias**: `float`.\n\n  value for bias function in [0, 1] range. Values from 0.7 to 0.9 usually give best\n  results, default value is 0.85.\n\n##### Return\n- **retval**: `Evision.TonemapDrago.t()`\n\nPython prototype (for reference only):\n```python3\ncreateTonemapDrago([, gamma[, saturation[, bias]]]) -> retval\n```","ref":"Evision.html#createTonemapDrago/0"},{"type":"function","title":"Evision.createTonemapDrago/1","doc":"Creates TonemapDrago object\n##### Keyword Arguments\n- **gamma**: `float`.\n\n  gamma value for gamma correction. See createTonemap\n\n- **saturation**: `float`.\n\n  positive saturation enhancement value. 1.0 preserves saturation, values greater\n  than 1 increase saturation and values less than 1 decrease it.\n\n- **bias**: `float`.\n\n  value for bias function in [0, 1] range. Values from 0.7 to 0.9 usually give best\n  results, default value is 0.85.\n\n##### Return\n- **retval**: `Evision.TonemapDrago.t()`\n\nPython prototype (for reference only):\n```python3\ncreateTonemapDrago([, gamma[, saturation[, bias]]]) -> retval\n```","ref":"Evision.html#createTonemapDrago/1"},{"type":"function","title":"Evision.createTonemapMantiuk/0","doc":"Creates TonemapMantiuk object\n##### Keyword Arguments\n- **gamma**: `float`.\n\n  gamma value for gamma correction. See createTonemap\n\n- **scale**: `float`.\n\n  contrast scale factor. HVS response is multiplied by this parameter, thus compressing\n  dynamic range. Values from 0.6 to 0.9 produce best results.\n\n- **saturation**: `float`.\n\n  saturation enhancement value. See createTonemapDrago\n\n##### Return\n- **retval**: `Evision.TonemapMantiuk.t()`\n\nPython prototype (for reference only):\n```python3\ncreateTonemapMantiuk([, gamma[, scale[, saturation]]]) -> retval\n```","ref":"Evision.html#createTonemapMantiuk/0"},{"type":"function","title":"Evision.createTonemapMantiuk/1","doc":"Creates TonemapMantiuk object\n##### Keyword Arguments\n- **gamma**: `float`.\n\n  gamma value for gamma correction. See createTonemap\n\n- **scale**: `float`.\n\n  contrast scale factor. HVS response is multiplied by this parameter, thus compressing\n  dynamic range. Values from 0.6 to 0.9 produce best results.\n\n- **saturation**: `float`.\n\n  saturation enhancement value. See createTonemapDrago\n\n##### Return\n- **retval**: `Evision.TonemapMantiuk.t()`\n\nPython prototype (for reference only):\n```python3\ncreateTonemapMantiuk([, gamma[, scale[, saturation]]]) -> retval\n```","ref":"Evision.html#createTonemapMantiuk/1"},{"type":"function","title":"Evision.createTonemapReinhard/0","doc":"Creates TonemapReinhard object\n##### Keyword Arguments\n- **gamma**: `float`.\n\n  gamma value for gamma correction. See createTonemap\n\n- **intensity**: `float`.\n\n  result intensity in [-8, 8] range. Greater intensity produces brighter results.\n\n- **light_adapt**: `float`.\n\n  light adaptation in [0, 1] range. If 1 adaptation is based only on pixel\n  value, if 0 it's global, otherwise it's a weighted mean of this two cases.\n\n- **color_adapt**: `float`.\n\n  chromatic adaptation in [0, 1] range. If 1 channels are treated independently,\n  if 0 adaptation level is the same for each channel.\n\n##### Return\n- **retval**: `Evision.TonemapReinhard.t()`\n\nPython prototype (for reference only):\n```python3\ncreateTonemapReinhard([, gamma[, intensity[, light_adapt[, color_adapt]]]]) -> retval\n```","ref":"Evision.html#createTonemapReinhard/0"},{"type":"function","title":"Evision.createTonemapReinhard/1","doc":"Creates TonemapReinhard object\n##### Keyword Arguments\n- **gamma**: `float`.\n\n  gamma value for gamma correction. See createTonemap\n\n- **intensity**: `float`.\n\n  result intensity in [-8, 8] range. Greater intensity produces brighter results.\n\n- **light_adapt**: `float`.\n\n  light adaptation in [0, 1] range. If 1 adaptation is based only on pixel\n  value, if 0 it's global, otherwise it's a weighted mean of this two cases.\n\n- **color_adapt**: `float`.\n\n  chromatic adaptation in [0, 1] range. If 1 channels are treated independently,\n  if 0 adaptation level is the same for each channel.\n\n##### Return\n- **retval**: `Evision.TonemapReinhard.t()`\n\nPython prototype (for reference only):\n```python3\ncreateTonemapReinhard([, gamma[, intensity[, light_adapt[, color_adapt]]]]) -> retval\n```","ref":"Evision.html#createTonemapReinhard/1"},{"type":"function","title":"Evision.cubeRoot/1","doc":"Computes the cube root of an argument.\n\n##### Positional Arguments\n- **val**: `float`.\n\n  A function argument.\n\n##### Return\n- **retval**: `float`\n\nThe function cubeRoot computes \\f$\\sqrt\\[3]{\\texttt{val}}\\f$. Negative arguments are handled correctly.\nNaN and Inf are not handled. The accuracy approaches the maximum possible accuracy for\nsingle-precision data.\n\nPython prototype (for reference only):\n```python3\ncubeRoot(val) -> retval\n```","ref":"Evision.html#cubeRoot/1"},{"type":"function","title":"Evision.currentUIFramework/0","doc":"HighGUI backend used.\n##### Return\n- **retval**: `string`\n\nThe function returns HighGUI backend name used: could be COCOA, GTK2/3, QT, WAYLAND or WIN32.\nReturns empty string if there is no available UI backend.\n\nPython prototype (for reference only):\n```python3\ncurrentUIFramework() -> retval\n```","ref":"Evision.html#currentUIFramework/0"},{"type":"function","title":"Evision.currentUIFramework/1","doc":"","ref":"Evision.html#currentUIFramework/1"},{"type":"function","title":"Evision.cv_CALIB_CB_ACCURACY/0","doc":"","ref":"Evision.html#cv_CALIB_CB_ACCURACY/0"},{"type":"function","title":"Evision.cv_CALIB_CB_ADAPTIVE_THRESH/0","doc":"","ref":"Evision.html#cv_CALIB_CB_ADAPTIVE_THRESH/0"},{"type":"function","title":"Evision.cv_CALIB_CB_ASYMMETRIC_GRID/0","doc":"","ref":"Evision.html#cv_CALIB_CB_ASYMMETRIC_GRID/0"},{"type":"function","title":"Evision.cv_CALIB_CB_CLUSTERING/0","doc":"","ref":"Evision.html#cv_CALIB_CB_CLUSTERING/0"},{"type":"function","title":"Evision.cv_CALIB_CB_EXHAUSTIVE/0","doc":"","ref":"Evision.html#cv_CALIB_CB_EXHAUSTIVE/0"},{"type":"function","title":"Evision.cv_CALIB_CB_FAST_CHECK/0","doc":"","ref":"Evision.html#cv_CALIB_CB_FAST_CHECK/0"},{"type":"function","title":"Evision.cv_CALIB_CB_FILTER_QUADS/0","doc":"","ref":"Evision.html#cv_CALIB_CB_FILTER_QUADS/0"},{"type":"function","title":"Evision.cv_CALIB_CB_LARGER/0","doc":"","ref":"Evision.html#cv_CALIB_CB_LARGER/0"},{"type":"function","title":"Evision.cv_CALIB_CB_MARKER/0","doc":"","ref":"Evision.html#cv_CALIB_CB_MARKER/0"},{"type":"function","title":"Evision.cv_CALIB_CB_NORMALIZE_IMAGE/0","doc":"","ref":"Evision.html#cv_CALIB_CB_NORMALIZE_IMAGE/0"},{"type":"function","title":"Evision.cv_CALIB_CB_PLAIN/0","doc":"","ref":"Evision.html#cv_CALIB_CB_PLAIN/0"},{"type":"function","title":"Evision.cv_CALIB_CB_SYMMETRIC_GRID/0","doc":"","ref":"Evision.html#cv_CALIB_CB_SYMMETRIC_GRID/0"},{"type":"function","title":"Evision.cv_CALIB_FIX_ASPECT_RATIO/0","doc":"","ref":"Evision.html#cv_CALIB_FIX_ASPECT_RATIO/0"},{"type":"function","title":"Evision.cv_CALIB_FIX_FOCAL_LENGTH/0","doc":"","ref":"Evision.html#cv_CALIB_FIX_FOCAL_LENGTH/0"},{"type":"function","title":"Evision.cv_CALIB_FIX_INTRINSIC/0","doc":"","ref":"Evision.html#cv_CALIB_FIX_INTRINSIC/0"},{"type":"function","title":"Evision.cv_CALIB_FIX_K1/0","doc":"","ref":"Evision.html#cv_CALIB_FIX_K1/0"},{"type":"function","title":"Evision.cv_CALIB_FIX_K2/0","doc":"","ref":"Evision.html#cv_CALIB_FIX_K2/0"},{"type":"function","title":"Evision.cv_CALIB_FIX_K3/0","doc":"","ref":"Evision.html#cv_CALIB_FIX_K3/0"},{"type":"function","title":"Evision.cv_CALIB_FIX_K4/0","doc":"","ref":"Evision.html#cv_CALIB_FIX_K4/0"},{"type":"function","title":"Evision.cv_CALIB_FIX_K5/0","doc":"","ref":"Evision.html#cv_CALIB_FIX_K5/0"},{"type":"function","title":"Evision.cv_CALIB_FIX_K6/0","doc":"","ref":"Evision.html#cv_CALIB_FIX_K6/0"},{"type":"function","title":"Evision.cv_CALIB_FIX_PRINCIPAL_POINT/0","doc":"","ref":"Evision.html#cv_CALIB_FIX_PRINCIPAL_POINT/0"},{"type":"function","title":"Evision.cv_CALIB_FIX_S1_S2_S3_S4/0","doc":"","ref":"Evision.html#cv_CALIB_FIX_S1_S2_S3_S4/0"},{"type":"function","title":"Evision.cv_CALIB_FIX_TANGENT_DIST/0","doc":"","ref":"Evision.html#cv_CALIB_FIX_TANGENT_DIST/0"},{"type":"function","title":"Evision.cv_CALIB_FIX_TAUX_TAUY/0","doc":"","ref":"Evision.html#cv_CALIB_FIX_TAUX_TAUY/0"},{"type":"function","title":"Evision.cv_CALIB_NINTRINSIC/0","doc":"","ref":"Evision.html#cv_CALIB_NINTRINSIC/0"},{"type":"function","title":"Evision.cv_CALIB_RATIONAL_MODEL/0","doc":"","ref":"Evision.html#cv_CALIB_RATIONAL_MODEL/0"},{"type":"function","title":"Evision.cv_CALIB_SAME_FOCAL_LENGTH/0","doc":"","ref":"Evision.html#cv_CALIB_SAME_FOCAL_LENGTH/0"},{"type":"function","title":"Evision.cv_CALIB_THIN_PRISM_MODEL/0","doc":"","ref":"Evision.html#cv_CALIB_THIN_PRISM_MODEL/0"},{"type":"function","title":"Evision.cv_CALIB_TILTED_MODEL/0","doc":"","ref":"Evision.html#cv_CALIB_TILTED_MODEL/0"},{"type":"function","title":"Evision.cv_CALIB_USE_EXTRINSIC_GUESS/0","doc":"","ref":"Evision.html#cv_CALIB_USE_EXTRINSIC_GUESS/0"},{"type":"function","title":"Evision.cv_CALIB_USE_INTRINSIC_GUESS/0","doc":"","ref":"Evision.html#cv_CALIB_USE_INTRINSIC_GUESS/0"},{"type":"function","title":"Evision.cv_CALIB_USE_LU/0","doc":"","ref":"Evision.html#cv_CALIB_USE_LU/0"},{"type":"function","title":"Evision.cv_CALIB_USE_QR/0","doc":"","ref":"Evision.html#cv_CALIB_USE_QR/0"},{"type":"function","title":"Evision.cv_CALIB_ZERO_DISPARITY/0","doc":"","ref":"Evision.html#cv_CALIB_ZERO_DISPARITY/0"},{"type":"function","title":"Evision.cv_CALIB_ZERO_TANGENT_DIST/0","doc":"","ref":"Evision.html#cv_CALIB_ZERO_TANGENT_DIST/0"},{"type":"function","title":"Evision.cv_CAP_INTELPERC_DEPTH_GENERATOR/0","doc":"","ref":"Evision.html#cv_CAP_INTELPERC_DEPTH_GENERATOR/0"},{"type":"function","title":"Evision.cv_CAP_INTELPERC_DEPTH_MAP/0","doc":"","ref":"Evision.html#cv_CAP_INTELPERC_DEPTH_MAP/0"},{"type":"function","title":"Evision.cv_CAP_INTELPERC_GENERATORS_MASK/0","doc":"","ref":"Evision.html#cv_CAP_INTELPERC_GENERATORS_MASK/0"},{"type":"function","title":"Evision.cv_CAP_INTELPERC_IMAGE/0","doc":"","ref":"Evision.html#cv_CAP_INTELPERC_IMAGE/0"},{"type":"function","title":"Evision.cv_CAP_INTELPERC_IMAGE_GENERATOR/0","doc":"","ref":"Evision.html#cv_CAP_INTELPERC_IMAGE_GENERATOR/0"},{"type":"function","title":"Evision.cv_CAP_INTELPERC_IR_GENERATOR/0","doc":"","ref":"Evision.html#cv_CAP_INTELPERC_IR_GENERATOR/0"},{"type":"function","title":"Evision.cv_CAP_INTELPERC_IR_MAP/0","doc":"","ref":"Evision.html#cv_CAP_INTELPERC_IR_MAP/0"},{"type":"function","title":"Evision.cv_CAP_INTELPERC_UVDEPTH_MAP/0","doc":"","ref":"Evision.html#cv_CAP_INTELPERC_UVDEPTH_MAP/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_BGR_IMAGE/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_BGR_IMAGE/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_DEPTH_GENERATOR/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_DEPTH_GENERATOR/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_DEPTH_GENERATOR_BASELINE/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_DEPTH_GENERATOR_BASELINE/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_DEPTH_GENERATOR_FOCAL_LENGTH/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_DEPTH_GENERATOR_FOCAL_LENGTH/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_DEPTH_GENERATOR_PRESENT/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_DEPTH_GENERATOR_PRESENT/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_DEPTH_GENERATOR_REGISTRATION/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_DEPTH_GENERATOR_REGISTRATION/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_DEPTH_GENERATOR_REGISTRATION_ON/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_DEPTH_GENERATOR_REGISTRATION_ON/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_DEPTH_MAP/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_DEPTH_MAP/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_DISPARITY_MAP/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_DISPARITY_MAP/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_DISPARITY_MAP_32F/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_DISPARITY_MAP_32F/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_GENERATORS_MASK/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_GENERATORS_MASK/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_GRAY_IMAGE/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_GRAY_IMAGE/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_IMAGE_GENERATOR/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_IMAGE_GENERATOR/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_IMAGE_GENERATOR_OUTPUT_MODE/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_IMAGE_GENERATOR_OUTPUT_MODE/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_IMAGE_GENERATOR_PRESENT/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_IMAGE_GENERATOR_PRESENT/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_IR_GENERATOR/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_IR_GENERATOR/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_IR_GENERATOR_PRESENT/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_IR_GENERATOR_PRESENT/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_IR_IMAGE/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_IR_IMAGE/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_POINT_CLOUD_MAP/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_POINT_CLOUD_MAP/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_QVGA_30HZ/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_QVGA_30HZ/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_QVGA_60HZ/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_QVGA_60HZ/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_SXGA_15HZ/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_SXGA_15HZ/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_SXGA_30HZ/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_SXGA_30HZ/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_VALID_DEPTH_MASK/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_VALID_DEPTH_MASK/0"},{"type":"function","title":"Evision.cv_CAP_OPENNI_VGA_30HZ/0","doc":"","ref":"Evision.html#cv_CAP_OPENNI_VGA_30HZ/0"},{"type":"function","title":"Evision.cv_CAP_PROP_APERTURE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_APERTURE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_ARAVIS_AUTOTRIGGER/0","doc":"","ref":"Evision.html#cv_CAP_PROP_ARAVIS_AUTOTRIGGER/0"},{"type":"function","title":"Evision.cv_CAP_PROP_DC1394_MAX/0","doc":"","ref":"Evision.html#cv_CAP_PROP_DC1394_MAX/0"},{"type":"function","title":"Evision.cv_CAP_PROP_DC1394_MODE_AUTO/0","doc":"","ref":"Evision.html#cv_CAP_PROP_DC1394_MODE_AUTO/0"},{"type":"function","title":"Evision.cv_CAP_PROP_DC1394_MODE_MANUAL/0","doc":"","ref":"Evision.html#cv_CAP_PROP_DC1394_MODE_MANUAL/0"},{"type":"function","title":"Evision.cv_CAP_PROP_DC1394_MODE_ONE_PUSH_AUTO/0","doc":"","ref":"Evision.html#cv_CAP_PROP_DC1394_MODE_ONE_PUSH_AUTO/0"},{"type":"function","title":"Evision.cv_CAP_PROP_DC1394_OFF/0","doc":"","ref":"Evision.html#cv_CAP_PROP_DC1394_OFF/0"},{"type":"function","title":"Evision.cv_CAP_PROP_EXPOSUREPROGRAM/0","doc":"","ref":"Evision.html#cv_CAP_PROP_EXPOSUREPROGRAM/0"},{"type":"function","title":"Evision.cv_CAP_PROP_GIGA_FRAME_HEIGH_MAX/0","doc":"","ref":"Evision.html#cv_CAP_PROP_GIGA_FRAME_HEIGH_MAX/0"},{"type":"function","title":"Evision.cv_CAP_PROP_GIGA_FRAME_OFFSET_X/0","doc":"","ref":"Evision.html#cv_CAP_PROP_GIGA_FRAME_OFFSET_X/0"},{"type":"function","title":"Evision.cv_CAP_PROP_GIGA_FRAME_OFFSET_Y/0","doc":"","ref":"Evision.html#cv_CAP_PROP_GIGA_FRAME_OFFSET_Y/0"},{"type":"function","title":"Evision.cv_CAP_PROP_GIGA_FRAME_SENS_HEIGH/0","doc":"","ref":"Evision.html#cv_CAP_PROP_GIGA_FRAME_SENS_HEIGH/0"},{"type":"function","title":"Evision.cv_CAP_PROP_GIGA_FRAME_SENS_WIDTH/0","doc":"","ref":"Evision.html#cv_CAP_PROP_GIGA_FRAME_SENS_WIDTH/0"},{"type":"function","title":"Evision.cv_CAP_PROP_GIGA_FRAME_WIDTH_MAX/0","doc":"","ref":"Evision.html#cv_CAP_PROP_GIGA_FRAME_WIDTH_MAX/0"},{"type":"function","title":"Evision.cv_CAP_PROP_GPHOTO2_COLLECT_MSGS/0","doc":"","ref":"Evision.html#cv_CAP_PROP_GPHOTO2_COLLECT_MSGS/0"},{"type":"function","title":"Evision.cv_CAP_PROP_GPHOTO2_FLUSH_MSGS/0","doc":"","ref":"Evision.html#cv_CAP_PROP_GPHOTO2_FLUSH_MSGS/0"},{"type":"function","title":"Evision.cv_CAP_PROP_GPHOTO2_PREVIEW/0","doc":"","ref":"Evision.html#cv_CAP_PROP_GPHOTO2_PREVIEW/0"},{"type":"function","title":"Evision.cv_CAP_PROP_GPHOTO2_RELOAD_CONFIG/0","doc":"","ref":"Evision.html#cv_CAP_PROP_GPHOTO2_RELOAD_CONFIG/0"},{"type":"function","title":"Evision.cv_CAP_PROP_GPHOTO2_RELOAD_ON_CHANGE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_GPHOTO2_RELOAD_ON_CHANGE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_GPHOTO2_WIDGET_ENUMERATE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_GPHOTO2_WIDGET_ENUMERATE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_GSTREAMER_QUEUE_LENGTH/0","doc":"","ref":"Evision.html#cv_CAP_PROP_GSTREAMER_QUEUE_LENGTH/0"},{"type":"function","title":"Evision.cv_CAP_PROP_IMAGES_BASE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_IMAGES_BASE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_IMAGES_LAST/0","doc":"","ref":"Evision.html#cv_CAP_PROP_IMAGES_LAST/0"},{"type":"function","title":"Evision.cv_CAP_PROP_INTELPERC_DEPTH_CONFIDENCE_THRESHOLD/0","doc":"","ref":"Evision.html#cv_CAP_PROP_INTELPERC_DEPTH_CONFIDENCE_THRESHOLD/0"},{"type":"function","title":"Evision.cv_CAP_PROP_INTELPERC_DEPTH_FOCAL_LENGTH_HORZ/0","doc":"","ref":"Evision.html#cv_CAP_PROP_INTELPERC_DEPTH_FOCAL_LENGTH_HORZ/0"},{"type":"function","title":"Evision.cv_CAP_PROP_INTELPERC_DEPTH_FOCAL_LENGTH_VERT/0","doc":"","ref":"Evision.html#cv_CAP_PROP_INTELPERC_DEPTH_FOCAL_LENGTH_VERT/0"},{"type":"function","title":"Evision.cv_CAP_PROP_INTELPERC_DEPTH_LOW_CONFIDENCE_VALUE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_INTELPERC_DEPTH_LOW_CONFIDENCE_VALUE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_INTELPERC_DEPTH_SATURATION_VALUE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_INTELPERC_DEPTH_SATURATION_VALUE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_INTELPERC_PROFILE_COUNT/0","doc":"","ref":"Evision.html#cv_CAP_PROP_INTELPERC_PROFILE_COUNT/0"},{"type":"function","title":"Evision.cv_CAP_PROP_INTELPERC_PROFILE_IDX/0","doc":"","ref":"Evision.html#cv_CAP_PROP_INTELPERC_PROFILE_IDX/0"},{"type":"function","title":"Evision.cv_CAP_PROP_IOS_DEVICE_EXPOSURE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_IOS_DEVICE_EXPOSURE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_IOS_DEVICE_FLASH/0","doc":"","ref":"Evision.html#cv_CAP_PROP_IOS_DEVICE_FLASH/0"},{"type":"function","title":"Evision.cv_CAP_PROP_IOS_DEVICE_FOCUS/0","doc":"","ref":"Evision.html#cv_CAP_PROP_IOS_DEVICE_FOCUS/0"},{"type":"function","title":"Evision.cv_CAP_PROP_IOS_DEVICE_TORCH/0","doc":"","ref":"Evision.html#cv_CAP_PROP_IOS_DEVICE_TORCH/0"},{"type":"function","title":"Evision.cv_CAP_PROP_IOS_DEVICE_WHITEBALANCE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_IOS_DEVICE_WHITEBALANCE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_OPENNI2_MIRROR/0","doc":"","ref":"Evision.html#cv_CAP_PROP_OPENNI2_MIRROR/0"},{"type":"function","title":"Evision.cv_CAP_PROP_OPENNI2_SYNC/0","doc":"","ref":"Evision.html#cv_CAP_PROP_OPENNI2_SYNC/0"},{"type":"function","title":"Evision.cv_CAP_PROP_OPENNI_APPROX_FRAME_SYNC/0","doc":"","ref":"Evision.html#cv_CAP_PROP_OPENNI_APPROX_FRAME_SYNC/0"},{"type":"function","title":"Evision.cv_CAP_PROP_OPENNI_BASELINE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_OPENNI_BASELINE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_OPENNI_CIRCLE_BUFFER/0","doc":"","ref":"Evision.html#cv_CAP_PROP_OPENNI_CIRCLE_BUFFER/0"},{"type":"function","title":"Evision.cv_CAP_PROP_OPENNI_FOCAL_LENGTH/0","doc":"","ref":"Evision.html#cv_CAP_PROP_OPENNI_FOCAL_LENGTH/0"},{"type":"function","title":"Evision.cv_CAP_PROP_OPENNI_FRAME_MAX_DEPTH/0","doc":"","ref":"Evision.html#cv_CAP_PROP_OPENNI_FRAME_MAX_DEPTH/0"},{"type":"function","title":"Evision.cv_CAP_PROP_OPENNI_GENERATOR_PRESENT/0","doc":"","ref":"Evision.html#cv_CAP_PROP_OPENNI_GENERATOR_PRESENT/0"},{"type":"function","title":"Evision.cv_CAP_PROP_OPENNI_MAX_BUFFER_SIZE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_OPENNI_MAX_BUFFER_SIZE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_OPENNI_MAX_TIME_DURATION/0","doc":"","ref":"Evision.html#cv_CAP_PROP_OPENNI_MAX_TIME_DURATION/0"},{"type":"function","title":"Evision.cv_CAP_PROP_OPENNI_OUTPUT_MODE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_OPENNI_OUTPUT_MODE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_OPENNI_REGISTRATION/0","doc":"","ref":"Evision.html#cv_CAP_PROP_OPENNI_REGISTRATION/0"},{"type":"function","title":"Evision.cv_CAP_PROP_OPENNI_REGISTRATION_ON/0","doc":"","ref":"Evision.html#cv_CAP_PROP_OPENNI_REGISTRATION_ON/0"},{"type":"function","title":"Evision.cv_CAP_PROP_PVAPI_BINNINGX/0","doc":"","ref":"Evision.html#cv_CAP_PROP_PVAPI_BINNINGX/0"},{"type":"function","title":"Evision.cv_CAP_PROP_PVAPI_BINNINGY/0","doc":"","ref":"Evision.html#cv_CAP_PROP_PVAPI_BINNINGY/0"},{"type":"function","title":"Evision.cv_CAP_PROP_PVAPI_DECIMATIONHORIZONTAL/0","doc":"","ref":"Evision.html#cv_CAP_PROP_PVAPI_DECIMATIONHORIZONTAL/0"},{"type":"function","title":"Evision.cv_CAP_PROP_PVAPI_DECIMATIONVERTICAL/0","doc":"","ref":"Evision.html#cv_CAP_PROP_PVAPI_DECIMATIONVERTICAL/0"},{"type":"function","title":"Evision.cv_CAP_PROP_PVAPI_FRAMESTARTTRIGGERMODE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_PVAPI_FRAMESTARTTRIGGERMODE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_PVAPI_MULTICASTIP/0","doc":"","ref":"Evision.html#cv_CAP_PROP_PVAPI_MULTICASTIP/0"},{"type":"function","title":"Evision.cv_CAP_PROP_PVAPI_PIXELFORMAT/0","doc":"","ref":"Evision.html#cv_CAP_PROP_PVAPI_PIXELFORMAT/0"},{"type":"function","title":"Evision.cv_CAP_PROP_SPEED/0","doc":"","ref":"Evision.html#cv_CAP_PROP_SPEED/0"},{"type":"function","title":"Evision.cv_CAP_PROP_VIEWFINDER/0","doc":"","ref":"Evision.html#cv_CAP_PROP_VIEWFINDER/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_ACQ_BUFFER_SIZE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_ACQ_BUFFER_SIZE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_ACQ_BUFFER_SIZE_UNIT/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_ACQ_BUFFER_SIZE_UNIT/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_ACQ_FRAME_BURST_COUNT/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_ACQ_FRAME_BURST_COUNT/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_ACQ_TIMING_MODE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_ACQ_TIMING_MODE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_ACQ_TRANSPORT_BUFFER_COMMIT/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_ACQ_TRANSPORT_BUFFER_COMMIT/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_ACQ_TRANSPORT_BUFFER_SIZE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_ACQ_TRANSPORT_BUFFER_SIZE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_AE_MAX_LIMIT/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_AE_MAX_LIMIT/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_AEAG/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_AEAG/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_AEAG_LEVEL/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_AEAG_LEVEL/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_AEAG_ROI_HEIGHT/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_AEAG_ROI_HEIGHT/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_AEAG_ROI_OFFSET_X/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_AEAG_ROI_OFFSET_X/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_AEAG_ROI_OFFSET_Y/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_AEAG_ROI_OFFSET_Y/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_AEAG_ROI_WIDTH/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_AEAG_ROI_WIDTH/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_AG_MAX_LIMIT/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_AG_MAX_LIMIT/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_APPLY_CMS/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_APPLY_CMS/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_AUTO_BANDWIDTH_CALCULATION/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_AUTO_BANDWIDTH_CALCULATION/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_AUTO_WB/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_AUTO_WB/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_AVAILABLE_BANDWIDTH/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_AVAILABLE_BANDWIDTH/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_BINNING_HORIZONTAL/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_BINNING_HORIZONTAL/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_BINNING_PATTERN/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_BINNING_PATTERN/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_BINNING_SELECTOR/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_BINNING_SELECTOR/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_BINNING_VERTICAL/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_BINNING_VERTICAL/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_BPC/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_BPC/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_BUFFER_POLICY/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_BUFFER_POLICY/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_BUFFERS_QUEUE_SIZE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_BUFFERS_QUEUE_SIZE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_CC_MATRIX_00/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_CC_MATRIX_00/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_CC_MATRIX_01/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_CC_MATRIX_01/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_CC_MATRIX_02/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_CC_MATRIX_02/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_CC_MATRIX_03/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_CC_MATRIX_03/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_CC_MATRIX_10/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_CC_MATRIX_10/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_CC_MATRIX_11/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_CC_MATRIX_11/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_CC_MATRIX_12/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_CC_MATRIX_12/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_CC_MATRIX_13/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_CC_MATRIX_13/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_CC_MATRIX_20/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_CC_MATRIX_20/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_CC_MATRIX_21/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_CC_MATRIX_21/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_CC_MATRIX_22/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_CC_MATRIX_22/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_CC_MATRIX_23/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_CC_MATRIX_23/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_CC_MATRIX_30/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_CC_MATRIX_30/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_CC_MATRIX_31/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_CC_MATRIX_31/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_CC_MATRIX_32/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_CC_MATRIX_32/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_CC_MATRIX_33/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_CC_MATRIX_33/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_CHIP_TEMP/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_CHIP_TEMP/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_CMS/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_CMS/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_COLOR_FILTER_ARRAY/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_COLOR_FILTER_ARRAY/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_COLUMN_FPN_CORRECTION/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_COLUMN_FPN_CORRECTION/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_COOLING/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_COOLING/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_COUNTER_SELECTOR/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_COUNTER_SELECTOR/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_COUNTER_VALUE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_COUNTER_VALUE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_DATA_FORMAT/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_DATA_FORMAT/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_DEBOUNCE_EN/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_DEBOUNCE_EN/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_DEBOUNCE_POL/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_DEBOUNCE_POL/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_DEBOUNCE_T0/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_DEBOUNCE_T0/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_DEBOUNCE_T1/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_DEBOUNCE_T1/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_DEBUG_LEVEL/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_DEBUG_LEVEL/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_DECIMATION_HORIZONTAL/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_DECIMATION_HORIZONTAL/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_DECIMATION_PATTERN/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_DECIMATION_PATTERN/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_DECIMATION_SELECTOR/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_DECIMATION_SELECTOR/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_DECIMATION_VERTICAL/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_DECIMATION_VERTICAL/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_DEFAULT_CC_MATRIX/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_DEFAULT_CC_MATRIX/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_DEVICE_MODEL_ID/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_DEVICE_MODEL_ID/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_DEVICE_RESET/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_DEVICE_RESET/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_DEVICE_SN/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_DEVICE_SN/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_DOWNSAMPLING/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_DOWNSAMPLING/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_DOWNSAMPLING_TYPE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_DOWNSAMPLING_TYPE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_EXP_PRIORITY/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_EXP_PRIORITY/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_EXPOSURE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_EXPOSURE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_EXPOSURE_BURST_COUNT/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_EXPOSURE_BURST_COUNT/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_FFS_ACCESS_KEY/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_FFS_ACCESS_KEY/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_FFS_FILE_ID/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_FFS_FILE_ID/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_FFS_FILE_SIZE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_FFS_FILE_SIZE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_FRAMERATE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_FRAMERATE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_FREE_FFS_SIZE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_FREE_FFS_SIZE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_GAIN/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_GAIN/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_GAIN_SELECTOR/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_GAIN_SELECTOR/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_GAMMAC/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_GAMMAC/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_GAMMAY/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_GAMMAY/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_GPI_LEVEL/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_GPI_LEVEL/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_GPI_MODE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_GPI_MODE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_GPI_SELECTOR/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_GPI_SELECTOR/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_GPO_MODE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_GPO_MODE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_GPO_SELECTOR/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_GPO_SELECTOR/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_HDR/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_HDR/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_HDR_KNEEPOINT_COUNT/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_HDR_KNEEPOINT_COUNT/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_HDR_T1/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_HDR_T1/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_HDR_T2/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_HDR_T2/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_HEIGHT/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_HEIGHT/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_HOUS_BACK_SIDE_TEMP/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_HOUS_BACK_SIDE_TEMP/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_HOUS_TEMP/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_HOUS_TEMP/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_HW_REVISION/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_HW_REVISION/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_IMAGE_BLACK_LEVEL/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_IMAGE_BLACK_LEVEL/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_IMAGE_DATA_BIT_DEPTH/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_IMAGE_DATA_BIT_DEPTH/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_IMAGE_DATA_FORMAT/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_IMAGE_DATA_FORMAT/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_IMAGE_DATA_FORMAT_RGB32_ALPHA/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_IMAGE_DATA_FORMAT_RGB32_ALPHA/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_IMAGE_IS_COLOR/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_IMAGE_IS_COLOR/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_IMAGE_PAYLOAD_SIZE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_IMAGE_PAYLOAD_SIZE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_IS_COOLED/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_IS_COOLED/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_IS_DEVICE_EXIST/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_IS_DEVICE_EXIST/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_KNEEPOINT1/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_KNEEPOINT1/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_KNEEPOINT2/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_KNEEPOINT2/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_LED_MODE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_LED_MODE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_LED_SELECTOR/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_LED_SELECTOR/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_LENS_APERTURE_VALUE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_LENS_APERTURE_VALUE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_LENS_FEATURE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_LENS_FEATURE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_LENS_FEATURE_SELECTOR/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_LENS_FEATURE_SELECTOR/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_LENS_FOCAL_LENGTH/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_LENS_FOCAL_LENGTH/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_LENS_FOCUS_DISTANCE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_LENS_FOCUS_DISTANCE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_LENS_FOCUS_MOVE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_LENS_FOCUS_MOVE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_LENS_FOCUS_MOVEMENT_VALUE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_LENS_FOCUS_MOVEMENT_VALUE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_LENS_MODE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_LENS_MODE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_LIMIT_BANDWIDTH/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_LIMIT_BANDWIDTH/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_LUT_EN/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_LUT_EN/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_LUT_INDEX/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_LUT_INDEX/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_LUT_VALUE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_LUT_VALUE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_MANUAL_WB/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_MANUAL_WB/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_OFFSET_X/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_OFFSET_X/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_OFFSET_Y/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_OFFSET_Y/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_OUTPUT_DATA_BIT_DEPTH/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_OUTPUT_DATA_BIT_DEPTH/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_OUTPUT_DATA_PACKING/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_OUTPUT_DATA_PACKING/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_OUTPUT_DATA_PACKING_TYPE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_OUTPUT_DATA_PACKING_TYPE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_RECENT_FRAME/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_RECENT_FRAME/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_REGION_MODE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_REGION_MODE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_REGION_SELECTOR/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_REGION_SELECTOR/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_ROW_FPN_CORRECTION/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_ROW_FPN_CORRECTION/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_SENSOR_BOARD_TEMP/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_SENSOR_BOARD_TEMP/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_SENSOR_CLOCK_FREQ_HZ/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_SENSOR_CLOCK_FREQ_HZ/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_SENSOR_CLOCK_FREQ_INDEX/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_SENSOR_CLOCK_FREQ_INDEX/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_SENSOR_DATA_BIT_DEPTH/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_SENSOR_DATA_BIT_DEPTH/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_SENSOR_FEATURE_SELECTOR/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_SENSOR_FEATURE_SELECTOR/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_SENSOR_FEATURE_VALUE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_SENSOR_FEATURE_VALUE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_SENSOR_MODE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_SENSOR_MODE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_SENSOR_OUTPUT_CHANNEL_COUNT/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_SENSOR_OUTPUT_CHANNEL_COUNT/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_SENSOR_TAPS/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_SENSOR_TAPS/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_SHARPNESS/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_SHARPNESS/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_SHUTTER_TYPE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_SHUTTER_TYPE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_TARGET_TEMP/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_TARGET_TEMP/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_TEST_PATTERN/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_TEST_PATTERN/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_TEST_PATTERN_GENERATOR_SELECTOR/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_TEST_PATTERN_GENERATOR_SELECTOR/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_TIMEOUT/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_TIMEOUT/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_TRANSPORT_PIXEL_FORMAT/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_TRANSPORT_PIXEL_FORMAT/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_TRG_DELAY/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_TRG_DELAY/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_TRG_SELECTOR/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_TRG_SELECTOR/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_TRG_SOFTWARE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_TRG_SOFTWARE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_TRG_SOURCE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_TRG_SOURCE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_TS_RST_MODE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_TS_RST_MODE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_TS_RST_SOURCE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_TS_RST_SOURCE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_USED_FFS_SIZE/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_USED_FFS_SIZE/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_WB_KB/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_WB_KB/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_WB_KG/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_WB_KG/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_WB_KR/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_WB_KR/0"},{"type":"function","title":"Evision.cv_CAP_PROP_XI_WIDTH/0","doc":"","ref":"Evision.html#cv_CAP_PROP_XI_WIDTH/0"},{"type":"function","title":"Evision.cv_CAP_PVAPI_DECIMATION_2OUTOF4/0","doc":"","ref":"Evision.html#cv_CAP_PVAPI_DECIMATION_2OUTOF4/0"},{"type":"function","title":"Evision.cv_CAP_PVAPI_DECIMATION_2OUTOF8/0","doc":"","ref":"Evision.html#cv_CAP_PVAPI_DECIMATION_2OUTOF8/0"},{"type":"function","title":"Evision.cv_CAP_PVAPI_DECIMATION_2OUTOF16/0","doc":"","ref":"Evision.html#cv_CAP_PVAPI_DECIMATION_2OUTOF16/0"},{"type":"function","title":"Evision.cv_CAP_PVAPI_DECIMATION_OFF/0","doc":"","ref":"Evision.html#cv_CAP_PVAPI_DECIMATION_OFF/0"},{"type":"function","title":"Evision.cv_CAP_PVAPI_FSTRIGMODE_FIXEDRATE/0","doc":"","ref":"Evision.html#cv_CAP_PVAPI_FSTRIGMODE_FIXEDRATE/0"},{"type":"function","title":"Evision.cv_CAP_PVAPI_FSTRIGMODE_FREERUN/0","doc":"","ref":"Evision.html#cv_CAP_PVAPI_FSTRIGMODE_FREERUN/0"},{"type":"function","title":"Evision.cv_CAP_PVAPI_FSTRIGMODE_SOFTWARE/0","doc":"","ref":"Evision.html#cv_CAP_PVAPI_FSTRIGMODE_SOFTWARE/0"},{"type":"function","title":"Evision.cv_CAP_PVAPI_FSTRIGMODE_SYNCIN1/0","doc":"","ref":"Evision.html#cv_CAP_PVAPI_FSTRIGMODE_SYNCIN1/0"},{"type":"function","title":"Evision.cv_CAP_PVAPI_FSTRIGMODE_SYNCIN2/0","doc":"","ref":"Evision.html#cv_CAP_PVAPI_FSTRIGMODE_SYNCIN2/0"},{"type":"function","title":"Evision.cv_CAP_PVAPI_PIXELFORMAT_BAYER8/0","doc":"","ref":"Evision.html#cv_CAP_PVAPI_PIXELFORMAT_BAYER8/0"},{"type":"function","title":"Evision.cv_CAP_PVAPI_PIXELFORMAT_BAYER16/0","doc":"","ref":"Evision.html#cv_CAP_PVAPI_PIXELFORMAT_BAYER16/0"},{"type":"function","title":"Evision.cv_CAP_PVAPI_PIXELFORMAT_BGR24/0","doc":"","ref":"Evision.html#cv_CAP_PVAPI_PIXELFORMAT_BGR24/0"},{"type":"function","title":"Evision.cv_CAP_PVAPI_PIXELFORMAT_BGRA32/0","doc":"","ref":"Evision.html#cv_CAP_PVAPI_PIXELFORMAT_BGRA32/0"},{"type":"function","title":"Evision.cv_CAP_PVAPI_PIXELFORMAT_MONO8/0","doc":"","ref":"Evision.html#cv_CAP_PVAPI_PIXELFORMAT_MONO8/0"},{"type":"function","title":"Evision.cv_CAP_PVAPI_PIXELFORMAT_MONO16/0","doc":"","ref":"Evision.html#cv_CAP_PVAPI_PIXELFORMAT_MONO16/0"},{"type":"function","title":"Evision.cv_CAP_PVAPI_PIXELFORMAT_RGB24/0","doc":"","ref":"Evision.html#cv_CAP_PVAPI_PIXELFORMAT_RGB24/0"},{"type":"function","title":"Evision.cv_CAP_PVAPI_PIXELFORMAT_RGBA32/0","doc":"","ref":"Evision.html#cv_CAP_PVAPI_PIXELFORMAT_RGBA32/0"},{"type":"function","title":"Evision.cv_CASCADE_DO_CANNY_PRUNING/0","doc":"","ref":"Evision.html#cv_CASCADE_DO_CANNY_PRUNING/0"},{"type":"function","title":"Evision.cv_CASCADE_DO_ROUGH_SEARCH/0","doc":"","ref":"Evision.html#cv_CASCADE_DO_ROUGH_SEARCH/0"},{"type":"function","title":"Evision.cv_CASCADE_FIND_BIGGEST_OBJECT/0","doc":"","ref":"Evision.html#cv_CASCADE_FIND_BIGGEST_OBJECT/0"},{"type":"function","title":"Evision.cv_CASCADE_SCALE_IMAGE/0","doc":"","ref":"Evision.html#cv_CASCADE_SCALE_IMAGE/0"},{"type":"function","title":"Evision.cv_FM_7POINT/0","doc":"","ref":"Evision.html#cv_FM_7POINT/0"},{"type":"function","title":"Evision.cv_FM_8POINT/0","doc":"","ref":"Evision.html#cv_FM_8POINT/0"},{"type":"function","title":"Evision.cv_FM_LMEDS/0","doc":"","ref":"Evision.html#cv_FM_LMEDS/0"},{"type":"function","title":"Evision.cv_FM_RANSAC/0","doc":"","ref":"Evision.html#cv_FM_RANSAC/0"},{"type":"function","title":"Evision.cv_INPAINT_NS/0","doc":"","ref":"Evision.html#cv_INPAINT_NS/0"},{"type":"function","title":"Evision.cv_INPAINT_TELEA/0","doc":"","ref":"Evision.html#cv_INPAINT_TELEA/0"},{"type":"function","title":"Evision.cv_LDR_SIZE/0","doc":"","ref":"Evision.html#cv_LDR_SIZE/0"},{"type":"function","title":"Evision.cv_LMEDS/0","doc":"","ref":"Evision.html#cv_LMEDS/0"},{"type":"function","title":"Evision.cv_MIXED_CLONE/0","doc":"","ref":"Evision.html#cv_MIXED_CLONE/0"},{"type":"function","title":"Evision.cv_MONOCHROME_TRANSFER/0","doc":"","ref":"Evision.html#cv_MONOCHROME_TRANSFER/0"},{"type":"function","title":"Evision.cv_MOTION_AFFINE/0","doc":"","ref":"Evision.html#cv_MOTION_AFFINE/0"},{"type":"function","title":"Evision.cv_MOTION_EUCLIDEAN/0","doc":"","ref":"Evision.html#cv_MOTION_EUCLIDEAN/0"},{"type":"function","title":"Evision.cv_MOTION_HOMOGRAPHY/0","doc":"","ref":"Evision.html#cv_MOTION_HOMOGRAPHY/0"},{"type":"function","title":"Evision.cv_MOTION_TRANSLATION/0","doc":"","ref":"Evision.html#cv_MOTION_TRANSLATION/0"},{"type":"function","title":"Evision.cv_NORMAL_CLONE/0","doc":"","ref":"Evision.html#cv_NORMAL_CLONE/0"},{"type":"function","title":"Evision.cv_NORMCONV_FILTER/0","doc":"","ref":"Evision.html#cv_NORMCONV_FILTER/0"},{"type":"function","title":"Evision.cv_OPTFLOW_FARNEBACK_GAUSSIAN/0","doc":"","ref":"Evision.html#cv_OPTFLOW_FARNEBACK_GAUSSIAN/0"},{"type":"function","title":"Evision.cv_OPTFLOW_LK_GET_MIN_EIGENVALS/0","doc":"","ref":"Evision.html#cv_OPTFLOW_LK_GET_MIN_EIGENVALS/0"},{"type":"function","title":"Evision.cv_OPTFLOW_USE_INITIAL_FLOW/0","doc":"","ref":"Evision.html#cv_OPTFLOW_USE_INITIAL_FLOW/0"},{"type":"function","title":"Evision.cv_RANSAC/0","doc":"","ref":"Evision.html#cv_RANSAC/0"},{"type":"function","title":"Evision.cv_RECURS_FILTER/0","doc":"","ref":"Evision.html#cv_RECURS_FILTER/0"},{"type":"function","title":"Evision.cv_RHO/0","doc":"","ref":"Evision.html#cv_RHO/0"},{"type":"function","title":"Evision.cv_USAC_ACCURATE/0","doc":"","ref":"Evision.html#cv_USAC_ACCURATE/0"},{"type":"function","title":"Evision.cv_USAC_DEFAULT/0","doc":"","ref":"Evision.html#cv_USAC_DEFAULT/0"},{"type":"function","title":"Evision.cv_USAC_FAST/0","doc":"","ref":"Evision.html#cv_USAC_FAST/0"},{"type":"function","title":"Evision.cv_USAC_FM_8PTS/0","doc":"","ref":"Evision.html#cv_USAC_FM_8PTS/0"},{"type":"function","title":"Evision.cv_USAC_MAGSAC/0","doc":"","ref":"Evision.html#cv_USAC_MAGSAC/0"},{"type":"function","title":"Evision.cv_USAC_PARALLEL/0","doc":"","ref":"Evision.html#cv_USAC_PARALLEL/0"},{"type":"function","title":"Evision.cv_USAC_PROSAC/0","doc":"","ref":"Evision.html#cv_USAC_PROSAC/0"},{"type":"function","title":"Evision.cvtColor/1","doc":"","ref":"Evision.html#cvtColor/1"},{"type":"function","title":"Evision.cvtColor/2","doc":"Converts an image from one color space to another.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image: 8-bit unsigned, 16-bit unsigned ( CV_16UC... ), or single-precision\n  floating-point.\n\n- **code**: `integer()`.\n\n  color space conversion code (see #ColorConversionCodes).\n\n##### Keyword Arguments\n- **dstCn**: `integer()`.\n\n  number of channels in the destination image; if the parameter is 0, the number of the\n  channels is derived automatically from src and code.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and depth as src.\n\nThe function converts an input image from one color space to another. In case of a transformation\nto-from RGB color space, the order of the channels should be specified explicitly (RGB or BGR). Note\nthat the default color format in OpenCV is often referred to as RGB but it is actually BGR (the\nbytes are reversed). So the first byte in a standard (24-bit) color image will be an 8-bit Blue\ncomponent, the second byte will be Green, and the third byte will be Red. The fourth, fifth, and\nsixth bytes would then be the second pixel (Blue, then Green, then Red), and so on.\nThe conventional ranges for R, G, and B channel values are:\n- 0 to 255 for CV_8U images\n- 0 to 65535 for CV_16U images\n- 0 to 1 for CV_32F images\n\nIn case of linear transformations, the range does not matter. But in case of a non-linear\ntransformation, an input RGB image should be normalized to the proper value range to get the correct\nresults, for example, for RGB \\f$\\rightarrow\\f$ L\\*u\\*v\\* transformation. For example, if you have a\n32-bit floating-point image directly converted from an 8-bit image without any scaling, then it will\nhave the 0..255 value range instead of 0..1 assumed by the function. So, before calling #cvtColor ,\nyou need first to scale the image down:\n```\nimg *= 1./255;\ncvtColor(img, img, COLOR_BGR2Luv);\n```\nIf you use #cvtColor with 8-bit images, the conversion will have some information lost. For many\napplications, this will not be noticeable but it is recommended to use 32-bit images in applications\nthat need the full range of colors or that convert an image before an operation and then convert\nback.\nIf conversion adds the alpha channel, its value will set to the maximum of corresponding channel\nrange: 255 for CV_8U, 65535 for CV_16U, 1 for CV_32F.\n\n@see @ref imgproc_color_conversions\n\nPython prototype (for reference only):\n```python3\ncvtColor(src, code[, dst[, dstCn]]) -> dst\n```","ref":"Evision.html#cvtColor/2"},{"type":"function","title":"Evision.cvtColor/3","doc":"Converts an image from one color space to another.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image: 8-bit unsigned, 16-bit unsigned ( CV_16UC... ), or single-precision\n  floating-point.\n\n- **code**: `integer()`.\n\n  color space conversion code (see #ColorConversionCodes).\n\n##### Keyword Arguments\n- **dstCn**: `integer()`.\n\n  number of channels in the destination image; if the parameter is 0, the number of the\n  channels is derived automatically from src and code.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and depth as src.\n\nThe function converts an input image from one color space to another. In case of a transformation\nto-from RGB color space, the order of the channels should be specified explicitly (RGB or BGR). Note\nthat the default color format in OpenCV is often referred to as RGB but it is actually BGR (the\nbytes are reversed). So the first byte in a standard (24-bit) color image will be an 8-bit Blue\ncomponent, the second byte will be Green, and the third byte will be Red. The fourth, fifth, and\nsixth bytes would then be the second pixel (Blue, then Green, then Red), and so on.\nThe conventional ranges for R, G, and B channel values are:\n- 0 to 255 for CV_8U images\n- 0 to 65535 for CV_16U images\n- 0 to 1 for CV_32F images\n\nIn case of linear transformations, the range does not matter. But in case of a non-linear\ntransformation, an input RGB image should be normalized to the proper value range to get the correct\nresults, for example, for RGB \\f$\\rightarrow\\f$ L\\*u\\*v\\* transformation. For example, if you have a\n32-bit floating-point image directly converted from an 8-bit image without any scaling, then it will\nhave the 0..255 value range instead of 0..1 assumed by the function. So, before calling #cvtColor ,\nyou need first to scale the image down:\n```\nimg *= 1./255;\ncvtColor(img, img, COLOR_BGR2Luv);\n```\nIf you use #cvtColor with 8-bit images, the conversion will have some information lost. For many\napplications, this will not be noticeable but it is recommended to use 32-bit images in applications\nthat need the full range of colors or that convert an image before an operation and then convert\nback.\nIf conversion adds the alpha channel, its value will set to the maximum of corresponding channel\nrange: 255 for CV_8U, 65535 for CV_16U, 1 for CV_32F.\n\n@see @ref imgproc_color_conversions\n\nPython prototype (for reference only):\n```python3\ncvtColor(src, code[, dst[, dstCn]]) -> dst\n```","ref":"Evision.html#cvtColor/3"},{"type":"function","title":"Evision.cvtColorTwoPlane/1","doc":"","ref":"Evision.html#cvtColorTwoPlane/1"},{"type":"function","title":"Evision.cvtColorTwoPlane/3","doc":"Converts an image from one color space to another where the source image is\nstored in two planes.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  8-bit image (#CV_8U) of the Y plane.\n\n- **src2**: `Evision.Mat`.\n\n  image containing interleaved U/V plane.\n\n- **code**: `integer()`.\n\n  Specifies the type of conversion. It can take any of the following values:\n  - #COLOR_YUV2BGR_NV12\n  - #COLOR_YUV2RGB_NV12\n  - #COLOR_YUV2BGRA_NV12\n  - #COLOR_YUV2RGBA_NV12\n  - #COLOR_YUV2BGR_NV21\n  - #COLOR_YUV2RGB_NV21\n  - #COLOR_YUV2BGRA_NV21\n  - #COLOR_YUV2RGBA_NV21\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image.\n\nThis function only supports YUV420 to RGB conversion as of now.\n\nPython prototype (for reference only):\n```python3\ncvtColorTwoPlane(src1, src2, code[, dst]) -> dst\n```","ref":"Evision.html#cvtColorTwoPlane/3"},{"type":"function","title":"Evision.cvtColorTwoPlane/4","doc":"Converts an image from one color space to another where the source image is\nstored in two planes.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  8-bit image (#CV_8U) of the Y plane.\n\n- **src2**: `Evision.Mat`.\n\n  image containing interleaved U/V plane.\n\n- **code**: `integer()`.\n\n  Specifies the type of conversion. It can take any of the following values:\n  - #COLOR_YUV2BGR_NV12\n  - #COLOR_YUV2RGB_NV12\n  - #COLOR_YUV2BGRA_NV12\n  - #COLOR_YUV2RGBA_NV12\n  - #COLOR_YUV2BGR_NV21\n  - #COLOR_YUV2RGB_NV21\n  - #COLOR_YUV2BGRA_NV21\n  - #COLOR_YUV2RGBA_NV21\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image.\n\nThis function only supports YUV420 to RGB conversion as of now.\n\nPython prototype (for reference only):\n```python3\ncvtColorTwoPlane(src1, src2, code[, dst]) -> dst\n```","ref":"Evision.html#cvtColorTwoPlane/4"},{"type":"function","title":"Evision.dct/1","doc":"Performs a forward or inverse discrete Cosine transform of 1D or 2D array.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input floating-point array.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  transformation flags as a combination of cv::DftFlags (DCT_*)\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src .\n\nThe function cv::dct performs a forward or inverse discrete Cosine transform (DCT) of a 1D or 2D\nfloating-point array:\n- Forward Cosine transform of a 1D vector of N elements:\n  \\f[Y = C^{(N)}  \\cdot X\\f]\n  where\n  \\f[C^{(N)}\\_{jk}= \\sqrt{\\alpha\\_j/N} \\cos \\left ( \\frac{\\pi(2k+1)j}{2N} \\right )\\f]\n  and\n  \\f$\\alpha\\_0=1\\f$, \\f$\\alpha\\_j=2\\f$ for *j \\> 0*.\n\n- Inverse Cosine transform of a 1D vector of N elements:\n  \\f[X =  \\left (C^{(N)} \\right )^{-1}  \\cdot Y =  \\left (C^{(N)} \\right )^T  \\cdot Y\\f]\n  (since \\f$C^{(N)}\\f$ is an orthogonal matrix, \\f$C^{(N)} \\cdot \\left(C^{(N)}\\right)^T = I\\f$ )\n\n- Forward 2D Cosine transform of M x N matrix:\n  \\f[Y = C^{(N)}  \\cdot X  \\cdot \\left (C^{(N)} \\right )^T\\f]\n\n- Inverse 2D Cosine transform of M x N matrix:\n  \\f[X =  \\left (C^{(N)} \\right )^T  \\cdot X  \\cdot C^{(N)}\\f]\n\nThe function chooses the mode of operation by looking at the flags and size of the input array:\n- If (flags & #DCT_INVERSE) == 0, the function does a forward 1D or 2D transform. Otherwise, it\n  is an inverse 1D or 2D transform.\n\n- If (flags & #DCT_ROWS) != 0, the function performs a 1D transform of each row.\n- If the array is a single column or a single row, the function performs a 1D transform.\n- If none of the above is true, the function performs a 2D transform.\n\n**Note**: Currently dct supports even-size arrays (2, 4, 6 ...). For data analysis and approximation, you\ncan pad the array when necessary.\nAlso, the function performance depends very much, and not monotonically, on the array size (see\ngetOptimalDFTSize ). In the current implementation DCT of a vector of size N is calculated via DFT\nof a vector of size N/2 . Thus, the optimal DCT size N1 \\>= N can be calculated as:\n```\nsize_t getOptimalDCTSize(size_t N) { return 2*getOptimalDFTSize((N+1)/2); }\nN1 = getOptimalDCTSize(N);\n```\n@sa dft, getOptimalDFTSize, idct\n\nPython prototype (for reference only):\n```python3\ndct(src[, dst[, flags]]) -> dst\n```","ref":"Evision.html#dct/1"},{"type":"function","title":"Evision.dct/2","doc":"Performs a forward or inverse discrete Cosine transform of 1D or 2D array.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input floating-point array.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  transformation flags as a combination of cv::DftFlags (DCT_*)\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src .\n\nThe function cv::dct performs a forward or inverse discrete Cosine transform (DCT) of a 1D or 2D\nfloating-point array:\n- Forward Cosine transform of a 1D vector of N elements:\n  \\f[Y = C^{(N)}  \\cdot X\\f]\n  where\n  \\f[C^{(N)}\\_{jk}= \\sqrt{\\alpha\\_j/N} \\cos \\left ( \\frac{\\pi(2k+1)j}{2N} \\right )\\f]\n  and\n  \\f$\\alpha\\_0=1\\f$, \\f$\\alpha\\_j=2\\f$ for *j \\> 0*.\n\n- Inverse Cosine transform of a 1D vector of N elements:\n  \\f[X =  \\left (C^{(N)} \\right )^{-1}  \\cdot Y =  \\left (C^{(N)} \\right )^T  \\cdot Y\\f]\n  (since \\f$C^{(N)}\\f$ is an orthogonal matrix, \\f$C^{(N)} \\cdot \\left(C^{(N)}\\right)^T = I\\f$ )\n\n- Forward 2D Cosine transform of M x N matrix:\n  \\f[Y = C^{(N)}  \\cdot X  \\cdot \\left (C^{(N)} \\right )^T\\f]\n\n- Inverse 2D Cosine transform of M x N matrix:\n  \\f[X =  \\left (C^{(N)} \\right )^T  \\cdot X  \\cdot C^{(N)}\\f]\n\nThe function chooses the mode of operation by looking at the flags and size of the input array:\n- If (flags & #DCT_INVERSE) == 0, the function does a forward 1D or 2D transform. Otherwise, it\n  is an inverse 1D or 2D transform.\n\n- If (flags & #DCT_ROWS) != 0, the function performs a 1D transform of each row.\n- If the array is a single column or a single row, the function performs a 1D transform.\n- If none of the above is true, the function performs a 2D transform.\n\n**Note**: Currently dct supports even-size arrays (2, 4, 6 ...). For data analysis and approximation, you\ncan pad the array when necessary.\nAlso, the function performance depends very much, and not monotonically, on the array size (see\ngetOptimalDFTSize ). In the current implementation DCT of a vector of size N is calculated via DFT\nof a vector of size N/2 . Thus, the optimal DCT size N1 \\>= N can be calculated as:\n```\nsize_t getOptimalDCTSize(size_t N) { return 2*getOptimalDFTSize((N+1)/2); }\nN1 = getOptimalDCTSize(N);\n```\n@sa dft, getOptimalDFTSize, idct\n\nPython prototype (for reference only):\n```python3\ndct(src[, dst[, flags]]) -> dst\n```","ref":"Evision.html#dct/2"},{"type":"function","title":"Evision.decolor/1","doc":"Transforms a color image to a grayscale image. It is a basic tool in digital printing, stylized\nblack-and-white photograph rendering, and in many single channel image processing applications\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n##### Return\n- **grayscale**: `Evision.Mat.t()`.\n\n  Output 8-bit 1-channel image.\n\n- **color_boost**: `Evision.Mat.t()`.\n\n  Output 8-bit 3-channel image.\n\n@cite CL12 .\n\nThis function is to be applied on color images.\n\nPython prototype (for reference only):\n```python3\ndecolor(src[, grayscale[, color_boost]]) -> grayscale, color_boost\n```","ref":"Evision.html#decolor/1"},{"type":"function","title":"Evision.decolor/2","doc":"Transforms a color image to a grayscale image. It is a basic tool in digital printing, stylized\nblack-and-white photograph rendering, and in many single channel image processing applications\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n##### Return\n- **grayscale**: `Evision.Mat.t()`.\n\n  Output 8-bit 1-channel image.\n\n- **color_boost**: `Evision.Mat.t()`.\n\n  Output 8-bit 3-channel image.\n\n@cite CL12 .\n\nThis function is to be applied on color images.\n\nPython prototype (for reference only):\n```python3\ndecolor(src[, grayscale[, color_boost]]) -> grayscale, color_boost\n```","ref":"Evision.html#decolor/2"},{"type":"function","title":"Evision.decomposeEssentialMat/1","doc":"Decompose an essential matrix to possible rotations and translation.\n\n##### Positional Arguments\n- **e**: `Evision.Mat`.\n\n  The input essential matrix.\n\n##### Return\n- **r1**: `Evision.Mat.t()`.\n\n  One possible rotation matrix.\n\n- **r2**: `Evision.Mat.t()`.\n\n  Another possible rotation matrix.\n\n- **t**: `Evision.Mat.t()`.\n\n  One possible translation.\n\nThis function decomposes the essential matrix E using svd decomposition @cite HartleyZ00. In\ngeneral, four possible poses exist for the decomposition of E. They are \\f$\\[R\\_1, t]\\f$,\n\\f$\\[R\\_1, -t]\\f$, \\f$\\[R\\_2, t]\\f$, \\f$\\[R\\_2, -t]\\f$.\nIf E gives the epipolar constraint \\f$\\[p\\_2; 1]^T A^{-T} E A^{-1} \\[p\\_1; 1] = 0\\f$ between the image\npoints \\f$p\\_1\\f$ in the first image and \\f$p\\_2\\f$ in second image, then any of the tuples\n\\f$\\[R\\_1, t]\\f$, \\f$\\[R\\_1, -t]\\f$, \\f$\\[R\\_2, t]\\f$, \\f$\\[R\\_2, -t]\\f$ is a change of basis from the first\ncamera's coordinate system to the second camera's coordinate system. However, by decomposing E, one\ncan only get the direction of the translation. For this reason, the translation t is returned with\nunit length.\n\nPython prototype (for reference only):\n```python3\ndecomposeEssentialMat(E[, R1[, R2[, t]]]) -> R1, R2, t\n```","ref":"Evision.html#decomposeEssentialMat/1"},{"type":"function","title":"Evision.decomposeEssentialMat/2","doc":"Decompose an essential matrix to possible rotations and translation.\n\n##### Positional Arguments\n- **e**: `Evision.Mat`.\n\n  The input essential matrix.\n\n##### Return\n- **r1**: `Evision.Mat.t()`.\n\n  One possible rotation matrix.\n\n- **r2**: `Evision.Mat.t()`.\n\n  Another possible rotation matrix.\n\n- **t**: `Evision.Mat.t()`.\n\n  One possible translation.\n\nThis function decomposes the essential matrix E using svd decomposition @cite HartleyZ00. In\ngeneral, four possible poses exist for the decomposition of E. They are \\f$\\[R\\_1, t]\\f$,\n\\f$\\[R\\_1, -t]\\f$, \\f$\\[R\\_2, t]\\f$, \\f$\\[R\\_2, -t]\\f$.\nIf E gives the epipolar constraint \\f$\\[p\\_2; 1]^T A^{-T} E A^{-1} \\[p\\_1; 1] = 0\\f$ between the image\npoints \\f$p\\_1\\f$ in the first image and \\f$p\\_2\\f$ in second image, then any of the tuples\n\\f$\\[R\\_1, t]\\f$, \\f$\\[R\\_1, -t]\\f$, \\f$\\[R\\_2, t]\\f$, \\f$\\[R\\_2, -t]\\f$ is a change of basis from the first\ncamera's coordinate system to the second camera's coordinate system. However, by decomposing E, one\ncan only get the direction of the translation. For this reason, the translation t is returned with\nunit length.\n\nPython prototype (for reference only):\n```python3\ndecomposeEssentialMat(E[, R1[, R2[, t]]]) -> R1, R2, t\n```","ref":"Evision.html#decomposeEssentialMat/2"},{"type":"function","title":"Evision.decomposeHomographyMat/1","doc":"","ref":"Evision.html#decomposeHomographyMat/1"},{"type":"function","title":"Evision.decomposeHomographyMat/2","doc":"Decompose a homography matrix to rotation(s), translation(s) and plane normal(s).\n\n##### Positional Arguments\n- **h**: `Evision.Mat`.\n\n  The input homography matrix between two images.\n\n- **k**: `Evision.Mat`.\n\n  The input camera intrinsic matrix.\n\n##### Return\n- **retval**: `integer()`\n- **rotations**: `[Evision.Mat]`.\n\n  Array of rotation matrices.\n\n- **translations**: `[Evision.Mat]`.\n\n  Array of translation matrices.\n\n- **normals**: `[Evision.Mat]`.\n\n  Array of plane normal matrices.\n\nThis function extracts relative camera motion between two views of a planar object and returns up to\nfour mathematical solution tuples of rotation, translation, and plane normal. The decomposition of\nthe homography matrix H is described in detail in @cite Malis2007.\nIf the homography H, induced by the plane, gives the constraint\n\\f[s\\_i \\vecthree{x'\\_i}{y'\\_i}{1} \\sim H \\vecthree{x\\_i}{y\\_i}{1}\\f] on the source image points\n\\f$p\\_i\\f$ and the destination image points \\f$p'\\_i\\f$, then the tuple of rotations[k] and\ntranslations[k] is a change of basis from the source camera's coordinate system to the destination\ncamera's coordinate system. However, by decomposing H, one can only get the translation normalized\nby the (typically unknown) depth of the scene, i.e. its direction but with normalized length.\nIf point correspondences are available, at least two solutions may further be invalidated, by\napplying positive depth constraint, i.e. all points must be in front of the camera.\n\nPython prototype (for reference only):\n```python3\ndecomposeHomographyMat(H, K[, rotations[, translations[, normals]]]) -> retval, rotations, translations, normals\n```","ref":"Evision.html#decomposeHomographyMat/2"},{"type":"function","title":"Evision.decomposeHomographyMat/3","doc":"Decompose a homography matrix to rotation(s), translation(s) and plane normal(s).\n\n##### Positional Arguments\n- **h**: `Evision.Mat`.\n\n  The input homography matrix between two images.\n\n- **k**: `Evision.Mat`.\n\n  The input camera intrinsic matrix.\n\n##### Return\n- **retval**: `integer()`\n- **rotations**: `[Evision.Mat]`.\n\n  Array of rotation matrices.\n\n- **translations**: `[Evision.Mat]`.\n\n  Array of translation matrices.\n\n- **normals**: `[Evision.Mat]`.\n\n  Array of plane normal matrices.\n\nThis function extracts relative camera motion between two views of a planar object and returns up to\nfour mathematical solution tuples of rotation, translation, and plane normal. The decomposition of\nthe homography matrix H is described in detail in @cite Malis2007.\nIf the homography H, induced by the plane, gives the constraint\n\\f[s\\_i \\vecthree{x'\\_i}{y'\\_i}{1} \\sim H \\vecthree{x\\_i}{y\\_i}{1}\\f] on the source image points\n\\f$p\\_i\\f$ and the destination image points \\f$p'\\_i\\f$, then the tuple of rotations[k] and\ntranslations[k] is a change of basis from the source camera's coordinate system to the destination\ncamera's coordinate system. However, by decomposing H, one can only get the translation normalized\nby the (typically unknown) depth of the scene, i.e. its direction but with normalized length.\nIf point correspondences are available, at least two solutions may further be invalidated, by\napplying positive depth constraint, i.e. all points must be in front of the camera.\n\nPython prototype (for reference only):\n```python3\ndecomposeHomographyMat(H, K[, rotations[, translations[, normals]]]) -> retval, rotations, translations, normals\n```","ref":"Evision.html#decomposeHomographyMat/3"},{"type":"function","title":"Evision.decomposeProjectionMatrix/1","doc":"Decomposes a projection matrix into a rotation matrix and a camera intrinsic matrix.\n\n##### Positional Arguments\n- **projMatrix**: `Evision.Mat`.\n\n  3x4 input projection matrix P.\n\n##### Return\n- **cameraMatrix**: `Evision.Mat.t()`.\n\n  Output 3x3 camera intrinsic matrix \\f$\\cameramatrix{A}\\f$.\n\n- **rotMatrix**: `Evision.Mat.t()`.\n\n  Output 3x3 external rotation matrix R.\n\n- **transVect**: `Evision.Mat.t()`.\n\n  Output 4x1 translation vector T.\n\n- **rotMatrixX**: `Evision.Mat.t()`.\n\n  Optional 3x3 rotation matrix around x-axis.\n\n- **rotMatrixY**: `Evision.Mat.t()`.\n\n  Optional 3x3 rotation matrix around y-axis.\n\n- **rotMatrixZ**: `Evision.Mat.t()`.\n\n  Optional 3x3 rotation matrix around z-axis.\n\n- **eulerAngles**: `Evision.Mat.t()`.\n\n  Optional three-element vector containing three Euler angles of rotation in\n  degrees.\n\nThe function computes a decomposition of a projection matrix into a calibration and a rotation\nmatrix and the position of a camera.\nIt optionally returns three rotation matrices, one for each axis, and three Euler angles that could\nbe used in OpenGL. Note, there is always more than one sequence of rotations about the three\nprincipal axes that results in the same orientation of an object, e.g. see @cite Slabaugh . Returned\nthree rotation matrices and corresponding three Euler angles are only one of the possible solutions.\nThe function is based on #RQDecomp3x3 .\n\nPython prototype (for reference only):\n```python3\ndecomposeProjectionMatrix(projMatrix[, cameraMatrix[, rotMatrix[, transVect[, rotMatrixX[, rotMatrixY[, rotMatrixZ[, eulerAngles]]]]]]]) -> cameraMatrix, rotMatrix, transVect, rotMatrixX, rotMatrixY, rotMatrixZ, eulerAngles\n```","ref":"Evision.html#decomposeProjectionMatrix/1"},{"type":"function","title":"Evision.decomposeProjectionMatrix/2","doc":"Decomposes a projection matrix into a rotation matrix and a camera intrinsic matrix.\n\n##### Positional Arguments\n- **projMatrix**: `Evision.Mat`.\n\n  3x4 input projection matrix P.\n\n##### Return\n- **cameraMatrix**: `Evision.Mat.t()`.\n\n  Output 3x3 camera intrinsic matrix \\f$\\cameramatrix{A}\\f$.\n\n- **rotMatrix**: `Evision.Mat.t()`.\n\n  Output 3x3 external rotation matrix R.\n\n- **transVect**: `Evision.Mat.t()`.\n\n  Output 4x1 translation vector T.\n\n- **rotMatrixX**: `Evision.Mat.t()`.\n\n  Optional 3x3 rotation matrix around x-axis.\n\n- **rotMatrixY**: `Evision.Mat.t()`.\n\n  Optional 3x3 rotation matrix around y-axis.\n\n- **rotMatrixZ**: `Evision.Mat.t()`.\n\n  Optional 3x3 rotation matrix around z-axis.\n\n- **eulerAngles**: `Evision.Mat.t()`.\n\n  Optional three-element vector containing three Euler angles of rotation in\n  degrees.\n\nThe function computes a decomposition of a projection matrix into a calibration and a rotation\nmatrix and the position of a camera.\nIt optionally returns three rotation matrices, one for each axis, and three Euler angles that could\nbe used in OpenGL. Note, there is always more than one sequence of rotations about the three\nprincipal axes that results in the same orientation of an object, e.g. see @cite Slabaugh . Returned\nthree rotation matrices and corresponding three Euler angles are only one of the possible solutions.\nThe function is based on #RQDecomp3x3 .\n\nPython prototype (for reference only):\n```python3\ndecomposeProjectionMatrix(projMatrix[, cameraMatrix[, rotMatrix[, transVect[, rotMatrixX[, rotMatrixY[, rotMatrixZ[, eulerAngles]]]]]]]) -> cameraMatrix, rotMatrix, transVect, rotMatrixX, rotMatrixY, rotMatrixZ, eulerAngles\n```","ref":"Evision.html#decomposeProjectionMatrix/2"},{"type":"function","title":"Evision.demosaicing/1","doc":"","ref":"Evision.html#demosaicing/1"},{"type":"function","title":"Evision.demosaicing/2","doc":"main function for all demosaicing processes\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image: 8-bit unsigned or 16-bit unsigned.\n\n- **code**: `integer()`.\n\n  Color space conversion code (see the description below).\n\n##### Keyword Arguments\n- **dstCn**: `integer()`.\n\n  number of channels in the destination image; if the parameter is 0, the number of the\n  channels is derived automatically from src and code.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and depth as src.\n\nThe function can do the following transformations:\n- Demosaicing using bilinear interpolation\n\n#COLOR_BayerBG2BGR , #COLOR_BayerGB2BGR , #COLOR_BayerRG2BGR , #COLOR_BayerGR2BGR\n#COLOR_BayerBG2GRAY , #COLOR_BayerGB2GRAY , #COLOR_BayerRG2GRAY , #COLOR_BayerGR2GRAY\n- Demosaicing using Variable Number of Gradients.\n\n#COLOR_BayerBG2BGR_VNG , #COLOR_BayerGB2BGR_VNG , #COLOR_BayerRG2BGR_VNG , #COLOR_BayerGR2BGR_VNG\n- Edge-Aware Demosaicing.\n\n#COLOR_BayerBG2BGR_EA , #COLOR_BayerGB2BGR_EA , #COLOR_BayerRG2BGR_EA , #COLOR_BayerGR2BGR_EA\n- Demosaicing with alpha channel\n\n#COLOR_BayerBG2BGRA , #COLOR_BayerGB2BGRA , #COLOR_BayerRG2BGRA , #COLOR_BayerGR2BGRA\n@sa cvtColor\n\nPython prototype (for reference only):\n```python3\ndemosaicing(src, code[, dst[, dstCn]]) -> dst\n```","ref":"Evision.html#demosaicing/2"},{"type":"function","title":"Evision.demosaicing/3","doc":"main function for all demosaicing processes\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image: 8-bit unsigned or 16-bit unsigned.\n\n- **code**: `integer()`.\n\n  Color space conversion code (see the description below).\n\n##### Keyword Arguments\n- **dstCn**: `integer()`.\n\n  number of channels in the destination image; if the parameter is 0, the number of the\n  channels is derived automatically from src and code.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and depth as src.\n\nThe function can do the following transformations:\n- Demosaicing using bilinear interpolation\n\n#COLOR_BayerBG2BGR , #COLOR_BayerGB2BGR , #COLOR_BayerRG2BGR , #COLOR_BayerGR2BGR\n#COLOR_BayerBG2GRAY , #COLOR_BayerGB2GRAY , #COLOR_BayerRG2GRAY , #COLOR_BayerGR2GRAY\n- Demosaicing using Variable Number of Gradients.\n\n#COLOR_BayerBG2BGR_VNG , #COLOR_BayerGB2BGR_VNG , #COLOR_BayerRG2BGR_VNG , #COLOR_BayerGR2BGR_VNG\n- Edge-Aware Demosaicing.\n\n#COLOR_BayerBG2BGR_EA , #COLOR_BayerGB2BGR_EA , #COLOR_BayerRG2BGR_EA , #COLOR_BayerGR2BGR_EA\n- Demosaicing with alpha channel\n\n#COLOR_BayerBG2BGRA , #COLOR_BayerGB2BGRA , #COLOR_BayerRG2BGRA , #COLOR_BayerGR2BGRA\n@sa cvtColor\n\nPython prototype (for reference only):\n```python3\ndemosaicing(src, code[, dst[, dstCn]]) -> dst\n```","ref":"Evision.html#demosaicing/3"},{"type":"function","title":"Evision.detailEnhance/1","doc":"This filter enhances the details of a particular image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n##### Keyword Arguments\n- **sigma_s**: `float`.\n\n  %Range between 0 to 200.\n\n- **sigma_r**: `float`.\n\n  %Range between 0 to 1.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as src.\n\nPython prototype (for reference only):\n```python3\ndetailEnhance(src[, dst[, sigma_s[, sigma_r]]]) -> dst\n```","ref":"Evision.html#detailEnhance/1"},{"type":"function","title":"Evision.detailEnhance/2","doc":"This filter enhances the details of a particular image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n##### Keyword Arguments\n- **sigma_s**: `float`.\n\n  %Range between 0 to 200.\n\n- **sigma_r**: `float`.\n\n  %Range between 0 to 1.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as src.\n\nPython prototype (for reference only):\n```python3\ndetailEnhance(src[, dst[, sigma_s[, sigma_r]]]) -> dst\n```","ref":"Evision.html#detailEnhance/2"},{"type":"function","title":"Evision.determinant/1","doc":"Returns the determinant of a square floating-point matrix.\n\n##### Positional Arguments\n- **mtx**: `Evision.Mat`.\n\n  input matrix that must have CV_32FC1 or CV_64FC1 type and\n  square size.\n\n##### Return\n- **retval**: `double`\n\nThe function cv::determinant calculates and returns the determinant of the\nspecified matrix. For small matrices ( mtx.cols=mtx.rows\\<=3 ), the\ndirect method is used. For larger matrices, the function uses LU\nfactorization with partial pivoting.\nFor symmetric positively-determined matrices, it is also possible to use\neigen decomposition to calculate the determinant.\n@sa trace, invert, solve, eigen, @ref MatrixExpressions\n\nPython prototype (for reference only):\n```python3\ndeterminant(mtx) -> retval\n```","ref":"Evision.html#determinant/1"},{"type":"function","title":"Evision.dft/1","doc":"Performs a forward or inverse Discrete Fourier transform of a 1D or 2D floating-point array.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array that could be real or complex.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  transformation flags, representing a combination of the #DftFlags\n\n- **nonzeroRows**: `integer()`.\n\n  when the parameter is not zero, the function assumes that only the first\n  nonzeroRows rows of the input array (#DFT_INVERSE is not set) or only the first nonzeroRows of the\n  output array (#DFT_INVERSE is set) contain non-zeros, thus, the function can handle the rest of the\n  rows more efficiently and save some time; this technique is very useful for calculating array\n  cross-correlation or convolution using DFT.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array whose size and type depends on the flags .\n\nThe function cv::dft performs one of the following:\n- Forward the Fourier transform of a 1D vector of N elements:\n  \\f[Y = F^{(N)}  \\cdot X,\\f]\n  where \\f$F^{(N)}\\_{jk}=\\exp(-2\\pi i j k/N)\\f$ and \\f$i=\\sqrt{-1}\\f$\n\n- Inverse the Fourier transform of a 1D vector of N elements:\n  \\f[\\begin{array}{l} X'=  \\left (F^{(N)} \\right )^{-1}  \\cdot Y =  \\left (F^{(N)} \\right )^\\*  \\cdot y  \\\\\\\\ X = (1/N)  \\cdot X, \\end{array}\\f]\n  where \\f$F^\\*=\\left(\\textrm{Re}(F^{(N)})-\\textrm{Im}(F^{(N)})\\right)^T\\f$\n\n- Forward the 2D Fourier transform of a M x N matrix:\n  \\f[Y = F^{(M)}  \\cdot X  \\cdot F^{(N)}\\f]\n\n- Inverse the 2D Fourier transform of a M x N matrix:\n  \\f[\\begin{array}{l} X'=  \\left (F^{(M)} \\right )^\\*  \\cdot Y  \\cdot \\left (F^{(N)} \\right )^\\* \\\\\\\\ X =  \\frac{1}{M \\cdot N} \\cdot X' \\end{array}\\f]\n\nIn case of real (single-channel) data, the output spectrum of the forward Fourier transform or input\nspectrum of the inverse Fourier transform can be represented in a packed format called *CCS*\n(complex-conjugate-symmetrical). It was borrowed from IPL (Intel\\* Image Processing Library). Here\nis how 2D *CCS* spectrum looks:\n\\f[\\begin{bmatrix} Re Y\\_{0,0} & Re Y\\_{0,1} & Im Y\\_{0,1} & Re Y\\_{0,2} & Im Y\\_{0,2} &  \\cdots & Re Y\\_{0,N/2-1} & Im Y\\_{0,N/2-1} & Re Y\\_{0,N/2}  \\\\\\\\ Re Y\\_{1,0} & Re Y\\_{1,1} & Im Y\\_{1,1} & Re Y\\_{1,2} & Im Y\\_{1,2} &  \\cdots & Re Y\\_{1,N/2-1} & Im Y\\_{1,N/2-1} & Re Y\\_{1,N/2}  \\\\\\\\ Im Y\\_{1,0} & Re Y\\_{2,1} & Im Y\\_{2,1} & Re Y\\_{2,2} & Im Y\\_{2,2} &  \\cdots & Re Y\\_{2,N/2-1} & Im Y\\_{2,N/2-1} & Im Y\\_{1,N/2}  \\\\\\\\ \\hdotsfor{9} \\\\\\\\ Re Y\\_{M/2-1,0} &  Re Y\\_{M-3,1}  & Im Y\\_{M-3,1} &  \\hdotsfor{3} & Re Y\\_{M-3,N/2-1} & Im Y\\_{M-3,N/2-1}& Re Y\\_{M/2-1,N/2}  \\\\\\\\ Im Y\\_{M/2-1,0} &  Re Y\\_{M-2,1}  & Im Y\\_{M-2,1} &  \\hdotsfor{3} & Re Y\\_{M-2,N/2-1} & Im Y\\_{M-2,N/2-1}& Im Y\\_{M/2-1,N/2}  \\\\\\\\ Re Y\\_{M/2,0}  &  Re Y\\_{M-1,1} &  Im Y\\_{M-1,1} &  \\hdotsfor{3} & Re Y\\_{M-1,N/2-1} & Im Y\\_{M-1,N/2-1}& Re Y\\_{M/2,N/2} \\end{bmatrix}\\f]\nIn case of 1D transform of a real vector, the output looks like the first row of the matrix above.\nSo, the function chooses an operation mode depending on the flags and size of the input array:\n- If #DFT_ROWS is set or the input array has a single row or single column, the function\n  performs a 1D forward or inverse transform of each row of a matrix when #DFT_ROWS is set.\n  Otherwise, it performs a 2D transform.\n\n- If the input array is real and #DFT_INVERSE is not set, the function performs a forward 1D or\n  2D transform:\n\n- When #DFT_COMPLEX_OUTPUT is set, the output is a complex matrix of the same size as\n  input.\n\n- When #DFT_COMPLEX_OUTPUT is not set, the output is a real matrix of the same size as\n  input. In case of 2D transform, it uses the packed format as shown above. In case of a\n  single 1D transform, it looks like the first row of the matrix above. In case of\n  multiple 1D transforms (when using the #DFT_ROWS flag), each row of the output matrix\n  looks like the first row of the matrix above.\n\n- If the input array is complex and either #DFT_INVERSE or #DFT_REAL_OUTPUT are not set, the\n  output is a complex array of the same size as input. The function performs a forward or\n  inverse 1D or 2D transform of the whole input array or each row of the input array\n  independently, depending on the flags DFT_INVERSE and DFT_ROWS.\n\n- When #DFT_INVERSE is set and the input array is real, or it is complex but #DFT_REAL_OUTPUT\n  is set, the output is a real array of the same size as input. The function performs a 1D or 2D\n  inverse transformation of the whole input array or each individual row, depending on the flags\n  #DFT_INVERSE and #DFT_ROWS.\n\nIf #DFT_SCALE is set, the scaling is done after the transformation.\nUnlike dct, the function supports arrays of arbitrary size. But only those arrays are processed\nefficiently, whose sizes can be factorized in a product of small prime numbers (2, 3, and 5 in the\ncurrent implementation). Such an efficient DFT size can be calculated using the getOptimalDFTSize\nmethod.\nThe sample below illustrates how to calculate a DFT-based convolution of two 2D real arrays:\n```\nvoid convolveDFT(InputArray A, InputArray B, OutputArray C)\n{\n// reallocate the output array if needed\nC.create(abs(A.rows - B.rows)+1, abs(A.cols - B.cols)+1, A.type());\nSize dftSize;\n// calculate the size of DFT transform\ndftSize.width = getOptimalDFTSize(A.cols + B.cols - 1);\ndftSize.height = getOptimalDFTSize(A.rows + B.rows - 1);\n// allocate temporary buffers and initialize them with 0's\nMat tempA(dftSize, A.type(), Scalar::all(0));\nMat tempB(dftSize, B.type(), Scalar::all(0));\n// copy A and B to the top-left corners of tempA and tempB, respectively\nMat roiA(tempA, Rect(0,0,A.cols,A.rows));\nA.copyTo(roiA);\nMat roiB(tempB, Rect(0,0,B.cols,B.rows));\nB.copyTo(roiB);\n// now transform the padded A & B in-place;\n// use \"nonzeroRows\" hint for faster processing\ndft(tempA, tempA, 0, A.rows);\ndft(tempB, tempB, 0, B.rows);\n// multiply the spectrums;\n// the function handles packed spectrum representations well\nmulSpectrums(tempA, tempB, tempA);\n// transform the product back from the frequency domain.\n// Even though all the result rows will be non-zero,\n// you need only the first C.rows of them, and thus you\n// pass nonzeroRows == C.rows\ndft(tempA, tempA, DFT_INVERSE + DFT_SCALE, C.rows);\n// now copy the result back to C.\ntempA(Rect(0, 0, C.cols, C.rows)).copyTo(C);\n// all the temporary buffers will be deallocated automatically\n}\n```\nTo optimize this sample, consider the following approaches:\n- Since nonzeroRows != 0 is passed to the forward transform calls and since A and B are copied to\n  the top-left corners of tempA and tempB, respectively, it is not necessary to clear the whole\n  tempA and tempB. It is only necessary to clear the tempA.cols - A.cols ( tempB.cols - B.cols)\n  rightmost columns of the matrices.\n\n- This DFT-based convolution does not have to be applied to the whole big arrays, especially if B\n  is significantly smaller than A or vice versa. Instead, you can calculate convolution by parts.\n  To do this, you need to split the output array C into multiple tiles. For each tile, estimate\n  which parts of A and B are required to calculate convolution in this tile. If the tiles in C are\n  too small, the speed will decrease a lot because of repeated work. In the ultimate case, when\n  each tile in C is a single pixel, the algorithm becomes equivalent to the naive convolution\n  algorithm. If the tiles are too big, the temporary arrays tempA and tempB become too big and\n  there is also a slowdown because of bad cache locality. So, there is an optimal tile size\n  somewhere in the middle.\n\n- If different tiles in C can be calculated in parallel and, thus, the convolution is done by\n  parts, the loop can be threaded.\n\nAll of the above improvements have been implemented in #matchTemplate and #filter2D . Therefore, by\nusing them, you can get the performance even better than with the above theoretically optimal\nimplementation. Though, those two functions actually calculate cross-correlation, not convolution,\nso you need to \"flip\" the second convolution operand B vertically and horizontally using flip .\n**Note**: \n- An example using the discrete fourier transform can be found at\n  opencv_source_code/samples/cpp/dft.cpp\n\n- (Python) An example using the dft functionality to perform Wiener deconvolution can be found\n  at opencv_source/samples/python/deconvolution.py\n\n- (Python) An example rearranging the quadrants of a Fourier image can be found at\n  opencv_source/samples/python/dft.py\n\n@sa dct, getOptimalDFTSize, mulSpectrums, filter2D, matchTemplate, flip, cartToPolar,\nmagnitude, phase\n\nPython prototype (for reference only):\n```python3\ndft(src[, dst[, flags[, nonzeroRows]]]) -> dst\n```","ref":"Evision.html#dft/1"},{"type":"function","title":"Evision.dft/2","doc":"Performs a forward or inverse Discrete Fourier transform of a 1D or 2D floating-point array.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array that could be real or complex.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  transformation flags, representing a combination of the #DftFlags\n\n- **nonzeroRows**: `integer()`.\n\n  when the parameter is not zero, the function assumes that only the first\n  nonzeroRows rows of the input array (#DFT_INVERSE is not set) or only the first nonzeroRows of the\n  output array (#DFT_INVERSE is set) contain non-zeros, thus, the function can handle the rest of the\n  rows more efficiently and save some time; this technique is very useful for calculating array\n  cross-correlation or convolution using DFT.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array whose size and type depends on the flags .\n\nThe function cv::dft performs one of the following:\n- Forward the Fourier transform of a 1D vector of N elements:\n  \\f[Y = F^{(N)}  \\cdot X,\\f]\n  where \\f$F^{(N)}\\_{jk}=\\exp(-2\\pi i j k/N)\\f$ and \\f$i=\\sqrt{-1}\\f$\n\n- Inverse the Fourier transform of a 1D vector of N elements:\n  \\f[\\begin{array}{l} X'=  \\left (F^{(N)} \\right )^{-1}  \\cdot Y =  \\left (F^{(N)} \\right )^\\*  \\cdot y  \\\\\\\\ X = (1/N)  \\cdot X, \\end{array}\\f]\n  where \\f$F^\\*=\\left(\\textrm{Re}(F^{(N)})-\\textrm{Im}(F^{(N)})\\right)^T\\f$\n\n- Forward the 2D Fourier transform of a M x N matrix:\n  \\f[Y = F^{(M)}  \\cdot X  \\cdot F^{(N)}\\f]\n\n- Inverse the 2D Fourier transform of a M x N matrix:\n  \\f[\\begin{array}{l} X'=  \\left (F^{(M)} \\right )^\\*  \\cdot Y  \\cdot \\left (F^{(N)} \\right )^\\* \\\\\\\\ X =  \\frac{1}{M \\cdot N} \\cdot X' \\end{array}\\f]\n\nIn case of real (single-channel) data, the output spectrum of the forward Fourier transform or input\nspectrum of the inverse Fourier transform can be represented in a packed format called *CCS*\n(complex-conjugate-symmetrical). It was borrowed from IPL (Intel\\* Image Processing Library). Here\nis how 2D *CCS* spectrum looks:\n\\f[\\begin{bmatrix} Re Y\\_{0,0} & Re Y\\_{0,1} & Im Y\\_{0,1} & Re Y\\_{0,2} & Im Y\\_{0,2} &  \\cdots & Re Y\\_{0,N/2-1} & Im Y\\_{0,N/2-1} & Re Y\\_{0,N/2}  \\\\\\\\ Re Y\\_{1,0} & Re Y\\_{1,1} & Im Y\\_{1,1} & Re Y\\_{1,2} & Im Y\\_{1,2} &  \\cdots & Re Y\\_{1,N/2-1} & Im Y\\_{1,N/2-1} & Re Y\\_{1,N/2}  \\\\\\\\ Im Y\\_{1,0} & Re Y\\_{2,1} & Im Y\\_{2,1} & Re Y\\_{2,2} & Im Y\\_{2,2} &  \\cdots & Re Y\\_{2,N/2-1} & Im Y\\_{2,N/2-1} & Im Y\\_{1,N/2}  \\\\\\\\ \\hdotsfor{9} \\\\\\\\ Re Y\\_{M/2-1,0} &  Re Y\\_{M-3,1}  & Im Y\\_{M-3,1} &  \\hdotsfor{3} & Re Y\\_{M-3,N/2-1} & Im Y\\_{M-3,N/2-1}& Re Y\\_{M/2-1,N/2}  \\\\\\\\ Im Y\\_{M/2-1,0} &  Re Y\\_{M-2,1}  & Im Y\\_{M-2,1} &  \\hdotsfor{3} & Re Y\\_{M-2,N/2-1} & Im Y\\_{M-2,N/2-1}& Im Y\\_{M/2-1,N/2}  \\\\\\\\ Re Y\\_{M/2,0}  &  Re Y\\_{M-1,1} &  Im Y\\_{M-1,1} &  \\hdotsfor{3} & Re Y\\_{M-1,N/2-1} & Im Y\\_{M-1,N/2-1}& Re Y\\_{M/2,N/2} \\end{bmatrix}\\f]\nIn case of 1D transform of a real vector, the output looks like the first row of the matrix above.\nSo, the function chooses an operation mode depending on the flags and size of the input array:\n- If #DFT_ROWS is set or the input array has a single row or single column, the function\n  performs a 1D forward or inverse transform of each row of a matrix when #DFT_ROWS is set.\n  Otherwise, it performs a 2D transform.\n\n- If the input array is real and #DFT_INVERSE is not set, the function performs a forward 1D or\n  2D transform:\n\n- When #DFT_COMPLEX_OUTPUT is set, the output is a complex matrix of the same size as\n  input.\n\n- When #DFT_COMPLEX_OUTPUT is not set, the output is a real matrix of the same size as\n  input. In case of 2D transform, it uses the packed format as shown above. In case of a\n  single 1D transform, it looks like the first row of the matrix above. In case of\n  multiple 1D transforms (when using the #DFT_ROWS flag), each row of the output matrix\n  looks like the first row of the matrix above.\n\n- If the input array is complex and either #DFT_INVERSE or #DFT_REAL_OUTPUT are not set, the\n  output is a complex array of the same size as input. The function performs a forward or\n  inverse 1D or 2D transform of the whole input array or each row of the input array\n  independently, depending on the flags DFT_INVERSE and DFT_ROWS.\n\n- When #DFT_INVERSE is set and the input array is real, or it is complex but #DFT_REAL_OUTPUT\n  is set, the output is a real array of the same size as input. The function performs a 1D or 2D\n  inverse transformation of the whole input array or each individual row, depending on the flags\n  #DFT_INVERSE and #DFT_ROWS.\n\nIf #DFT_SCALE is set, the scaling is done after the transformation.\nUnlike dct, the function supports arrays of arbitrary size. But only those arrays are processed\nefficiently, whose sizes can be factorized in a product of small prime numbers (2, 3, and 5 in the\ncurrent implementation). Such an efficient DFT size can be calculated using the getOptimalDFTSize\nmethod.\nThe sample below illustrates how to calculate a DFT-based convolution of two 2D real arrays:\n```\nvoid convolveDFT(InputArray A, InputArray B, OutputArray C)\n{\n// reallocate the output array if needed\nC.create(abs(A.rows - B.rows)+1, abs(A.cols - B.cols)+1, A.type());\nSize dftSize;\n// calculate the size of DFT transform\ndftSize.width = getOptimalDFTSize(A.cols + B.cols - 1);\ndftSize.height = getOptimalDFTSize(A.rows + B.rows - 1);\n// allocate temporary buffers and initialize them with 0's\nMat tempA(dftSize, A.type(), Scalar::all(0));\nMat tempB(dftSize, B.type(), Scalar::all(0));\n// copy A and B to the top-left corners of tempA and tempB, respectively\nMat roiA(tempA, Rect(0,0,A.cols,A.rows));\nA.copyTo(roiA);\nMat roiB(tempB, Rect(0,0,B.cols,B.rows));\nB.copyTo(roiB);\n// now transform the padded A & B in-place;\n// use \"nonzeroRows\" hint for faster processing\ndft(tempA, tempA, 0, A.rows);\ndft(tempB, tempB, 0, B.rows);\n// multiply the spectrums;\n// the function handles packed spectrum representations well\nmulSpectrums(tempA, tempB, tempA);\n// transform the product back from the frequency domain.\n// Even though all the result rows will be non-zero,\n// you need only the first C.rows of them, and thus you\n// pass nonzeroRows == C.rows\ndft(tempA, tempA, DFT_INVERSE + DFT_SCALE, C.rows);\n// now copy the result back to C.\ntempA(Rect(0, 0, C.cols, C.rows)).copyTo(C);\n// all the temporary buffers will be deallocated automatically\n}\n```\nTo optimize this sample, consider the following approaches:\n- Since nonzeroRows != 0 is passed to the forward transform calls and since A and B are copied to\n  the top-left corners of tempA and tempB, respectively, it is not necessary to clear the whole\n  tempA and tempB. It is only necessary to clear the tempA.cols - A.cols ( tempB.cols - B.cols)\n  rightmost columns of the matrices.\n\n- This DFT-based convolution does not have to be applied to the whole big arrays, especially if B\n  is significantly smaller than A or vice versa. Instead, you can calculate convolution by parts.\n  To do this, you need to split the output array C into multiple tiles. For each tile, estimate\n  which parts of A and B are required to calculate convolution in this tile. If the tiles in C are\n  too small, the speed will decrease a lot because of repeated work. In the ultimate case, when\n  each tile in C is a single pixel, the algorithm becomes equivalent to the naive convolution\n  algorithm. If the tiles are too big, the temporary arrays tempA and tempB become too big and\n  there is also a slowdown because of bad cache locality. So, there is an optimal tile size\n  somewhere in the middle.\n\n- If different tiles in C can be calculated in parallel and, thus, the convolution is done by\n  parts, the loop can be threaded.\n\nAll of the above improvements have been implemented in #matchTemplate and #filter2D . Therefore, by\nusing them, you can get the performance even better than with the above theoretically optimal\nimplementation. Though, those two functions actually calculate cross-correlation, not convolution,\nso you need to \"flip\" the second convolution operand B vertically and horizontally using flip .\n**Note**: \n- An example using the discrete fourier transform can be found at\n  opencv_source_code/samples/cpp/dft.cpp\n\n- (Python) An example using the dft functionality to perform Wiener deconvolution can be found\n  at opencv_source/samples/python/deconvolution.py\n\n- (Python) An example rearranging the quadrants of a Fourier image can be found at\n  opencv_source/samples/python/dft.py\n\n@sa dct, getOptimalDFTSize, mulSpectrums, filter2D, matchTemplate, flip, cartToPolar,\nmagnitude, phase\n\nPython prototype (for reference only):\n```python3\ndft(src[, dst[, flags[, nonzeroRows]]]) -> dst\n```","ref":"Evision.html#dft/2"},{"type":"function","title":"Evision.dilate/1","doc":"","ref":"Evision.html#dilate/1"},{"type":"function","title":"Evision.dilate/2","doc":"Dilates an image by using a specific structuring element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image; the number of channels can be arbitrary, but the depth should be one of\n  CV_8U, CV_16U, CV_16S, CV_32F or CV_64F.\n\n- **kernel**: `Evision.Mat`.\n\n  structuring element used for dilation; if element=Mat(), a 3 x 3 rectangular\n  structuring element is used. Kernel can be created using #getStructuringElement\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  position of the anchor within the element; default value (-1, -1) means that the\n  anchor is at the element center.\n\n- **iterations**: `integer()`.\n\n  number of times dilation is applied.\n\n- **borderType**: `integer()`.\n\n  pixel extrapolation method, see #BorderTypes. #BORDER_WRAP is not suported.\n\n- **borderValue**: `Evision.scalar()`.\n\n  border value in case of a constant border\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and type as src.\n\nThe function dilates the source image using the specified structuring element that determines the\nshape of a pixel neighborhood over which the maximum is taken:\n\\f[\\texttt{dst} (x,y) =  \\max \\_{(x',y'):  \\, \\texttt{element} (x',y') \\ne0 } \\texttt{src} (x+x',y+y')\\f]\nThe function supports the in-place mode. Dilation can be applied several ( iterations ) times. In\ncase of multi-channel images, each channel is processed independently.\n@sa  erode, morphologyEx, getStructuringElement\n\nPython prototype (for reference only):\n```python3\ndilate(src, kernel[, dst[, anchor[, iterations[, borderType[, borderValue]]]]]) -> dst\n```","ref":"Evision.html#dilate/2"},{"type":"function","title":"Evision.dilate/3","doc":"Dilates an image by using a specific structuring element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image; the number of channels can be arbitrary, but the depth should be one of\n  CV_8U, CV_16U, CV_16S, CV_32F or CV_64F.\n\n- **kernel**: `Evision.Mat`.\n\n  structuring element used for dilation; if element=Mat(), a 3 x 3 rectangular\n  structuring element is used. Kernel can be created using #getStructuringElement\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  position of the anchor within the element; default value (-1, -1) means that the\n  anchor is at the element center.\n\n- **iterations**: `integer()`.\n\n  number of times dilation is applied.\n\n- **borderType**: `integer()`.\n\n  pixel extrapolation method, see #BorderTypes. #BORDER_WRAP is not suported.\n\n- **borderValue**: `Evision.scalar()`.\n\n  border value in case of a constant border\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and type as src.\n\nThe function dilates the source image using the specified structuring element that determines the\nshape of a pixel neighborhood over which the maximum is taken:\n\\f[\\texttt{dst} (x,y) =  \\max \\_{(x',y'):  \\, \\texttt{element} (x',y') \\ne0 } \\texttt{src} (x+x',y+y')\\f]\nThe function supports the in-place mode. Dilation can be applied several ( iterations ) times. In\ncase of multi-channel images, each channel is processed independently.\n@sa  erode, morphologyEx, getStructuringElement\n\nPython prototype (for reference only):\n```python3\ndilate(src, kernel[, dst[, anchor[, iterations[, borderType[, borderValue]]]]]) -> dst\n```","ref":"Evision.html#dilate/3"},{"type":"function","title":"Evision.displayOverlay/1","doc":"","ref":"Evision.html#displayOverlay/1"},{"type":"function","title":"Evision.displayOverlay/2","doc":"Displays a text on a window image as an overlay for a specified duration.\n\n##### Positional Arguments\n- **winname**: `String`.\n\n  Name of the window.\n\n- **text**: `String`.\n\n  Overlay text to write on a window image.\n\n##### Keyword Arguments\n- **delayms**: `integer()`.\n\n  The period (in milliseconds), during which the overlay text is displayed. If this\n  function is called before the previous overlay text timed out, the timer is restarted and the text\n  is updated. If this value is zero, the text never disappears.\n\nThe function displayOverlay displays useful information/tips on top of the window for a certain\namount of time *delayms*. The function does not modify the image, displayed in the window, that is,\nafter the specified delay the original content of the window is restored.\n\nPython prototype (for reference only):\n```python3\ndisplayOverlay(winname, text[, delayms]) -> None\n```","ref":"Evision.html#displayOverlay/2"},{"type":"function","title":"Evision.displayOverlay/3","doc":"Displays a text on a window image as an overlay for a specified duration.\n\n##### Positional Arguments\n- **winname**: `String`.\n\n  Name of the window.\n\n- **text**: `String`.\n\n  Overlay text to write on a window image.\n\n##### Keyword Arguments\n- **delayms**: `integer()`.\n\n  The period (in milliseconds), during which the overlay text is displayed. If this\n  function is called before the previous overlay text timed out, the timer is restarted and the text\n  is updated. If this value is zero, the text never disappears.\n\nThe function displayOverlay displays useful information/tips on top of the window for a certain\namount of time *delayms*. The function does not modify the image, displayed in the window, that is,\nafter the specified delay the original content of the window is restored.\n\nPython prototype (for reference only):\n```python3\ndisplayOverlay(winname, text[, delayms]) -> None\n```","ref":"Evision.html#displayOverlay/3"},{"type":"function","title":"Evision.displayStatusBar/1","doc":"","ref":"Evision.html#displayStatusBar/1"},{"type":"function","title":"Evision.displayStatusBar/2","doc":"Displays a text on the window statusbar during the specified period of time.\n\n##### Positional Arguments\n- **winname**: `String`.\n\n  Name of the window.\n\n- **text**: `String`.\n\n  Text to write on the window statusbar.\n\n##### Keyword Arguments\n- **delayms**: `integer()`.\n\n  Duration (in milliseconds) to display the text. If this function is called before\n  the previous text timed out, the timer is restarted and the text is updated. If this value is\n  zero, the text never disappears.\n\nThe function displayStatusBar displays useful information/tips on top of the window for a certain\namount of time *delayms* . This information is displayed on the window statusbar (the window must be\ncreated with the CV_GUI_EXPANDED flags).\n\nPython prototype (for reference only):\n```python3\ndisplayStatusBar(winname, text[, delayms]) -> None\n```","ref":"Evision.html#displayStatusBar/2"},{"type":"function","title":"Evision.displayStatusBar/3","doc":"Displays a text on the window statusbar during the specified period of time.\n\n##### Positional Arguments\n- **winname**: `String`.\n\n  Name of the window.\n\n- **text**: `String`.\n\n  Text to write on the window statusbar.\n\n##### Keyword Arguments\n- **delayms**: `integer()`.\n\n  Duration (in milliseconds) to display the text. If this function is called before\n  the previous text timed out, the timer is restarted and the text is updated. If this value is\n  zero, the text never disappears.\n\nThe function displayStatusBar displays useful information/tips on top of the window for a certain\namount of time *delayms* . This information is displayed on the window statusbar (the window must be\ncreated with the CV_GUI_EXPANDED flags).\n\nPython prototype (for reference only):\n```python3\ndisplayStatusBar(winname, text[, delayms]) -> None\n```","ref":"Evision.html#displayStatusBar/3"},{"type":"function","title":"Evision.distanceTransform/1","doc":"","ref":"Evision.html#distanceTransform/1"},{"type":"function","title":"Evision.distanceTransform/3","doc":"distanceTransform\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  8-bit, single-channel (binary) source image.\n\n- **distanceType**: `integer()`.\n\n  Type of distance, see #DistanceTypes\n\n- **maskSize**: `integer()`.\n\n  Size of the distance transform mask, see #DistanceTransformMasks. In case of the\n  #DIST_L1 or #DIST_C distance type, the parameter is forced to 3 because a \\f$3\\times 3\\f$ mask gives\n  the same result as \\f$5\\times 5\\f$ or any larger aperture.\n\n##### Keyword Arguments\n- **dstType**: `integer()`.\n\n  Type of output image. It can be CV_8U or CV_32F. Type CV_8U can be used only for\n  the first variant of the function and distanceType == #DIST_L1.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with calculated distances. It is a 8-bit or 32-bit floating-point,\n  single-channel image of the same size as src .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndistanceTransform(src, distanceType, maskSize[, dst[, dstType]]) -> dst\n```","ref":"Evision.html#distanceTransform/3"},{"type":"function","title":"Evision.distanceTransform/4","doc":"distanceTransform\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  8-bit, single-channel (binary) source image.\n\n- **distanceType**: `integer()`.\n\n  Type of distance, see #DistanceTypes\n\n- **maskSize**: `integer()`.\n\n  Size of the distance transform mask, see #DistanceTransformMasks. In case of the\n  #DIST_L1 or #DIST_C distance type, the parameter is forced to 3 because a \\f$3\\times 3\\f$ mask gives\n  the same result as \\f$5\\times 5\\f$ or any larger aperture.\n\n##### Keyword Arguments\n- **dstType**: `integer()`.\n\n  Type of output image. It can be CV_8U or CV_32F. Type CV_8U can be used only for\n  the first variant of the function and distanceType == #DIST_L1.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with calculated distances. It is a 8-bit or 32-bit floating-point,\n  single-channel image of the same size as src .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndistanceTransform(src, distanceType, maskSize[, dst[, dstType]]) -> dst\n```","ref":"Evision.html#distanceTransform/4"},{"type":"function","title":"Evision.distanceTransformWithLabels/1","doc":"","ref":"Evision.html#distanceTransformWithLabels/1"},{"type":"function","title":"Evision.distanceTransformWithLabels/3","doc":"Calculates the distance to the closest zero pixel for each pixel of the source image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  8-bit, single-channel (binary) source image.\n\n- **distanceType**: `integer()`.\n\n  Type of distance, see #DistanceTypes\n\n- **maskSize**: `integer()`.\n\n  Size of the distance transform mask, see #DistanceTransformMasks.\n  #DIST_MASK_PRECISE is not supported by this variant. In case of the #DIST_L1 or #DIST_C distance type,\n  the parameter is forced to 3 because a \\f$3\\times 3\\f$ mask gives the same result as \\f$5\\times\n  5\\f$ or any larger aperture.\n\n##### Keyword Arguments\n- **labelType**: `integer()`.\n\n  Type of the label array to build, see #DistanceTransformLabelTypes.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with calculated distances. It is a 8-bit or 32-bit floating-point,\n  single-channel image of the same size as src.\n\n- **labels**: `Evision.Mat.t()`.\n\n  Output 2D array of labels (the discrete Voronoi diagram). It has the type\n  CV_32SC1 and the same size as src.\n\nThe function cv::distanceTransform calculates the approximate or precise distance from every binary\nimage pixel to the nearest zero pixel. For zero image pixels, the distance will obviously be zero.\nWhen maskSize == #DIST_MASK_PRECISE and distanceType == #DIST_L2 , the function runs the\nalgorithm described in @cite Felzenszwalb04 . This algorithm is parallelized with the TBB library.\nIn other cases, the algorithm @cite Borgefors86 is used. This means that for a pixel the function\nfinds the shortest path to the nearest zero pixel consisting of basic shifts: horizontal, vertical,\ndiagonal, or knight's move (the latest is available for a \\f$5\\times 5\\f$ mask). The overall\ndistance is calculated as a sum of these basic distances. Since the distance function should be\nsymmetric, all of the horizontal and vertical shifts must have the same cost (denoted as a ), all\nthe diagonal shifts must have the same cost (denoted as `b`), and all knight's moves must have the\nsame cost (denoted as `c`). For the #DIST_C and #DIST_L1 types, the distance is calculated\nprecisely, whereas for #DIST_L2 (Euclidean distance) the distance can be calculated only with a\nrelative error (a \\f$5\\times 5\\f$ mask gives more accurate results). For `a`,`b`, and `c`, OpenCV\nuses the values suggested in the original paper:\n- DIST_L1: `a = 1, b = 2`\n- DIST_L2:\n- `3 x 3`: `a=0.955, b=1.3693`\n- `5 x 5`: `a=1, b=1.4, c=2.1969`\n- DIST_C: `a = 1, b = 1`\n\nTypically, for a fast, coarse distance estimation #DIST_L2, a \\f$3\\times 3\\f$ mask is used. For a\nmore accurate distance estimation #DIST_L2, a \\f$5\\times 5\\f$ mask or the precise algorithm is used.\nNote that both the precise and the approximate algorithms are linear on the number of pixels.\nThis variant of the function does not only compute the minimum distance for each pixel \\f$(x, y)\\f$\nbut also identifies the nearest connected component consisting of zero pixels\n(labelType==#DIST_LABEL_CCOMP) or the nearest zero pixel (labelType==#DIST_LABEL_PIXEL). Index of the\ncomponent/pixel is stored in `labels(x, y)`. When labelType==#DIST_LABEL_CCOMP, the function\nautomatically finds connected components of zero pixels in the input image and marks them with\ndistinct labels. When labelType==#DIST_LABEL_PIXEL, the function scans through the input image and\nmarks all the zero pixels with distinct labels.\nIn this mode, the complexity is still linear. That is, the function provides a very fast way to\ncompute the Voronoi diagram for a binary image. Currently, the second variant can use only the\napproximate distance transform algorithm, i.e. maskSize=#DIST_MASK_PRECISE is not supported\nyet.\n\nPython prototype (for reference only):\n```python3\ndistanceTransformWithLabels(src, distanceType, maskSize[, dst[, labels[, labelType]]]) -> dst, labels\n```","ref":"Evision.html#distanceTransformWithLabels/3"},{"type":"function","title":"Evision.distanceTransformWithLabels/4","doc":"Calculates the distance to the closest zero pixel for each pixel of the source image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  8-bit, single-channel (binary) source image.\n\n- **distanceType**: `integer()`.\n\n  Type of distance, see #DistanceTypes\n\n- **maskSize**: `integer()`.\n\n  Size of the distance transform mask, see #DistanceTransformMasks.\n  #DIST_MASK_PRECISE is not supported by this variant. In case of the #DIST_L1 or #DIST_C distance type,\n  the parameter is forced to 3 because a \\f$3\\times 3\\f$ mask gives the same result as \\f$5\\times\n  5\\f$ or any larger aperture.\n\n##### Keyword Arguments\n- **labelType**: `integer()`.\n\n  Type of the label array to build, see #DistanceTransformLabelTypes.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with calculated distances. It is a 8-bit or 32-bit floating-point,\n  single-channel image of the same size as src.\n\n- **labels**: `Evision.Mat.t()`.\n\n  Output 2D array of labels (the discrete Voronoi diagram). It has the type\n  CV_32SC1 and the same size as src.\n\nThe function cv::distanceTransform calculates the approximate or precise distance from every binary\nimage pixel to the nearest zero pixel. For zero image pixels, the distance will obviously be zero.\nWhen maskSize == #DIST_MASK_PRECISE and distanceType == #DIST_L2 , the function runs the\nalgorithm described in @cite Felzenszwalb04 . This algorithm is parallelized with the TBB library.\nIn other cases, the algorithm @cite Borgefors86 is used. This means that for a pixel the function\nfinds the shortest path to the nearest zero pixel consisting of basic shifts: horizontal, vertical,\ndiagonal, or knight's move (the latest is available for a \\f$5\\times 5\\f$ mask). The overall\ndistance is calculated as a sum of these basic distances. Since the distance function should be\nsymmetric, all of the horizontal and vertical shifts must have the same cost (denoted as a ), all\nthe diagonal shifts must have the same cost (denoted as `b`), and all knight's moves must have the\nsame cost (denoted as `c`). For the #DIST_C and #DIST_L1 types, the distance is calculated\nprecisely, whereas for #DIST_L2 (Euclidean distance) the distance can be calculated only with a\nrelative error (a \\f$5\\times 5\\f$ mask gives more accurate results). For `a`,`b`, and `c`, OpenCV\nuses the values suggested in the original paper:\n- DIST_L1: `a = 1, b = 2`\n- DIST_L2:\n- `3 x 3`: `a=0.955, b=1.3693`\n- `5 x 5`: `a=1, b=1.4, c=2.1969`\n- DIST_C: `a = 1, b = 1`\n\nTypically, for a fast, coarse distance estimation #DIST_L2, a \\f$3\\times 3\\f$ mask is used. For a\nmore accurate distance estimation #DIST_L2, a \\f$5\\times 5\\f$ mask or the precise algorithm is used.\nNote that both the precise and the approximate algorithms are linear on the number of pixels.\nThis variant of the function does not only compute the minimum distance for each pixel \\f$(x, y)\\f$\nbut also identifies the nearest connected component consisting of zero pixels\n(labelType==#DIST_LABEL_CCOMP) or the nearest zero pixel (labelType==#DIST_LABEL_PIXEL). Index of the\ncomponent/pixel is stored in `labels(x, y)`. When labelType==#DIST_LABEL_CCOMP, the function\nautomatically finds connected components of zero pixels in the input image and marks them with\ndistinct labels. When labelType==#DIST_LABEL_PIXEL, the function scans through the input image and\nmarks all the zero pixels with distinct labels.\nIn this mode, the complexity is still linear. That is, the function provides a very fast way to\ncompute the Voronoi diagram for a binary image. Currently, the second variant can use only the\napproximate distance transform algorithm, i.e. maskSize=#DIST_MASK_PRECISE is not supported\nyet.\n\nPython prototype (for reference only):\n```python3\ndistanceTransformWithLabels(src, distanceType, maskSize[, dst[, labels[, labelType]]]) -> dst, labels\n```","ref":"Evision.html#distanceTransformWithLabels/4"},{"type":"function","title":"Evision.divide/1","doc":"","ref":"Evision.html#divide/1"},{"type":"function","title":"Evision.divide/2","doc":"#### Variant 1:\ndivide\n\n##### Positional Arguments\n- **scale**: `double`\n- **src2**: `Evision.Mat`\n\n##### Keyword Arguments\n- **dtype**: `integer()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndivide(scale, src2[, dst[, dtype]]) -> dst\n```\n#### Variant 2:\nPerforms per-element division of two arrays or a scalar by an array.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array.\n\n- **src2**: `Evision.Mat`.\n\n  second input array of the same size and type as src1.\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  scalar factor.\n\n- **dtype**: `integer()`.\n\n  optional depth of the output array; if -1, dst will have depth src2.depth(), but in\n  case of an array-by-array division, you can only pass -1 when src1.depth()==src2.depth().\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src2.\n\nThe function cv::divide divides one array by another:\n\\f[\\texttt{dst(I) = saturate(src1(I)\\*scale/src2(I))}\\f]\nor a scalar by an array when there is no src1 :\n\\f[\\texttt{dst(I) = saturate(scale/src2(I))}\\f]\nDifferent channels of multi-channel arrays are processed independently.\nFor integer types when src2(I) is zero, dst(I) will also be zero.\n**Note**: In case of floating point data there is no special defined behavior for zero src2(I) values.\nRegular floating-point division is used.\nExpect correct IEEE-754 behaviour for floating-point data (with NaN, Inf result values).\n**Note**: Saturation is not applied when the output array has the depth CV_32S. You may even get\nresult of an incorrect sign in the case of overflow.\n**Note**: (Python) Be careful to difference behaviour between src1/src2 are single number and they are tuple/array.\n`divide(src,X)` means `divide(src,(X,X,X,X))`.\n`divide(src,(X,))` means `divide(src,(X,0,0,0))`.\n@sa  multiply, add, subtract\n\nPython prototype (for reference only):\n```python3\ndivide(src1, src2[, dst[, scale[, dtype]]]) -> dst\n```","ref":"Evision.html#divide/2"},{"type":"function","title":"Evision.divide/3","doc":"#### Variant 1:\ndivide\n\n##### Positional Arguments\n- **scale**: `double`\n- **src2**: `Evision.Mat`\n\n##### Keyword Arguments\n- **dtype**: `integer()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndivide(scale, src2[, dst[, dtype]]) -> dst\n```\n#### Variant 2:\nPerforms per-element division of two arrays or a scalar by an array.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array.\n\n- **src2**: `Evision.Mat`.\n\n  second input array of the same size and type as src1.\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  scalar factor.\n\n- **dtype**: `integer()`.\n\n  optional depth of the output array; if -1, dst will have depth src2.depth(), but in\n  case of an array-by-array division, you can only pass -1 when src1.depth()==src2.depth().\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src2.\n\nThe function cv::divide divides one array by another:\n\\f[\\texttt{dst(I) = saturate(src1(I)\\*scale/src2(I))}\\f]\nor a scalar by an array when there is no src1 :\n\\f[\\texttt{dst(I) = saturate(scale/src2(I))}\\f]\nDifferent channels of multi-channel arrays are processed independently.\nFor integer types when src2(I) is zero, dst(I) will also be zero.\n**Note**: In case of floating point data there is no special defined behavior for zero src2(I) values.\nRegular floating-point division is used.\nExpect correct IEEE-754 behaviour for floating-point data (with NaN, Inf result values).\n**Note**: Saturation is not applied when the output array has the depth CV_32S. You may even get\nresult of an incorrect sign in the case of overflow.\n**Note**: (Python) Be careful to difference behaviour between src1/src2 are single number and they are tuple/array.\n`divide(src,X)` means `divide(src,(X,X,X,X))`.\n`divide(src,(X,))` means `divide(src,(X,0,0,0))`.\n@sa  multiply, add, subtract\n\nPython prototype (for reference only):\n```python3\ndivide(src1, src2[, dst[, scale[, dtype]]]) -> dst\n```","ref":"Evision.html#divide/3"},{"type":"function","title":"Evision.divSpectrums/1","doc":"","ref":"Evision.html#divSpectrums/1"},{"type":"function","title":"Evision.divSpectrums/3","doc":"Performs the per-element division of the first Fourier spectrum by the second Fourier spectrum.\n\n##### Positional Arguments\n- **a**: `Evision.Mat`.\n\n  first input array.\n\n- **b**: `Evision.Mat`.\n\n  second input array of the same size and type as src1 .\n\n- **flags**: `integer()`.\n\n  operation flags; currently, the only supported flag is cv::DFT_ROWS, which indicates that\n  each row of src1 and src2 is an independent 1D Fourier spectrum. If you do not want to use this flag, then simply add a `0` as value.\n\n##### Keyword Arguments\n- **conjB**: `bool`.\n\n  optional flag that conjugates the second input array before the multiplication (true)\n  or not (false).\n\n##### Return\n- **c**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src1 .\n\nThe function cv::divSpectrums performs the per-element division of the first array by the second array.\nThe arrays are CCS-packed or complex matrices that are results of a real or complex Fourier transform.\n\nPython prototype (for reference only):\n```python3\ndivSpectrums(a, b, flags[, c[, conjB]]) -> c\n```","ref":"Evision.html#divSpectrums/3"},{"type":"function","title":"Evision.divSpectrums/4","doc":"Performs the per-element division of the first Fourier spectrum by the second Fourier spectrum.\n\n##### Positional Arguments\n- **a**: `Evision.Mat`.\n\n  first input array.\n\n- **b**: `Evision.Mat`.\n\n  second input array of the same size and type as src1 .\n\n- **flags**: `integer()`.\n\n  operation flags; currently, the only supported flag is cv::DFT_ROWS, which indicates that\n  each row of src1 and src2 is an independent 1D Fourier spectrum. If you do not want to use this flag, then simply add a `0` as value.\n\n##### Keyword Arguments\n- **conjB**: `bool`.\n\n  optional flag that conjugates the second input array before the multiplication (true)\n  or not (false).\n\n##### Return\n- **c**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src1 .\n\nThe function cv::divSpectrums performs the per-element division of the first array by the second array.\nThe arrays are CCS-packed or complex matrices that are results of a real or complex Fourier transform.\n\nPython prototype (for reference only):\n```python3\ndivSpectrums(a, b, flags[, c[, conjB]]) -> c\n```","ref":"Evision.html#divSpectrums/4"},{"type":"function","title":"Evision.drawChessboardCorners/1","doc":"","ref":"Evision.html#drawChessboardCorners/1"},{"type":"function","title":"Evision.drawChessboardCorners/4","doc":"Renders the detected chessboard corners.\n\n##### Positional Arguments\n- **patternSize**: `Size`.\n\n  Number of inner corners per a chessboard row and column\n  (patternSize = cv::Size(points_per_row,points_per_column)).\n\n- **corners**: `Evision.Mat`.\n\n  Array of detected corners, the output of #findChessboardCorners.\n\n- **patternWasFound**: `bool`.\n\n  Parameter indicating whether the complete board was found or not. The\n  return value of #findChessboardCorners should be passed here.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  Destination image. It must be an 8-bit color image.\n\nThe function draws individual chessboard corners detected either as red circles if the board was not\nfound, or as colored corners connected with lines if the board was found.\n\nPython prototype (for reference only):\n```python3\ndrawChessboardCorners(image, patternSize, corners, patternWasFound) -> image\n```","ref":"Evision.html#drawChessboardCorners/4"},{"type":"function","title":"Evision.drawContours/1","doc":"","ref":"Evision.html#drawContours/1"},{"type":"function","title":"Evision.drawContours/4","doc":"Draws contours outlines or filled contours.\n\n##### Positional Arguments\n- **contours**: `[Evision.Mat]`.\n\n  All the input contours. Each contour is stored as a point vector.\n\n- **contourIdx**: `integer()`.\n\n  Parameter indicating a contour to draw. If it is negative, all the contours are drawn.\n\n- **color**: `Evision.scalar()`.\n\n  Color of the contours.\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n\n  Thickness of lines the contours are drawn with. If it is negative (for example,\n  thickness=#FILLED ), the contour interiors are drawn.\n\n- **lineType**: `integer()`.\n\n  Line connectivity. See #LineTypes\n\n- **hierarchy**: `Evision.Mat`.\n\n  Optional information about hierarchy. It is only needed if you want to draw only\n  some of the contours (see maxLevel ).\n\n- **maxLevel**: `integer()`.\n\n  Maximal level for drawn contours. If it is 0, only the specified contour is drawn.\n  If it is 1, the function draws the contour(s) and all the nested contours. If it is 2, the function\n  draws the contours, all the nested contours, all the nested-to-nested contours, and so on. This\n  parameter is only taken into account when there is hierarchy available.\n\n- **offset**: `Point`.\n\n  Optional contour shift parameter. Shift all the drawn contours by the specified\n  \\f$\\texttt{offset}=(dx,dy)\\f$ .\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  Destination image.\n\nThe function draws contour outlines in the image if \\f$\\texttt{thickness} \\ge 0\\f$ or fills the area\nbounded by the contours if \\f$\\texttt{thickness}<0\\f$ . The example below shows how to retrieve\nconnected components from the binary image and label them: :\n@include snippets/imgproc_drawContours.cpp\n**Note**: When thickness=#FILLED, the function is designed to handle connected components with holes correctly\neven when no hierarchy data is provided. This is done by analyzing all the outlines together\nusing even-odd rule. This may give incorrect results if you have a joint collection of separately retrieved\ncontours. In order to solve this problem, you need to call #drawContours separately for each sub-group\nof contours, or iterate over the collection using contourIdx parameter.\n\nPython prototype (for reference only):\n```python3\ndrawContours(image, contours, contourIdx, color[, thickness[, lineType[, hierarchy[, maxLevel[, offset]]]]]) -> image\n```","ref":"Evision.html#drawContours/4"},{"type":"function","title":"Evision.drawContours/5","doc":"Draws contours outlines or filled contours.\n\n##### Positional Arguments\n- **contours**: `[Evision.Mat]`.\n\n  All the input contours. Each contour is stored as a point vector.\n\n- **contourIdx**: `integer()`.\n\n  Parameter indicating a contour to draw. If it is negative, all the contours are drawn.\n\n- **color**: `Evision.scalar()`.\n\n  Color of the contours.\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n\n  Thickness of lines the contours are drawn with. If it is negative (for example,\n  thickness=#FILLED ), the contour interiors are drawn.\n\n- **lineType**: `integer()`.\n\n  Line connectivity. See #LineTypes\n\n- **hierarchy**: `Evision.Mat`.\n\n  Optional information about hierarchy. It is only needed if you want to draw only\n  some of the contours (see maxLevel ).\n\n- **maxLevel**: `integer()`.\n\n  Maximal level for drawn contours. If it is 0, only the specified contour is drawn.\n  If it is 1, the function draws the contour(s) and all the nested contours. If it is 2, the function\n  draws the contours, all the nested contours, all the nested-to-nested contours, and so on. This\n  parameter is only taken into account when there is hierarchy available.\n\n- **offset**: `Point`.\n\n  Optional contour shift parameter. Shift all the drawn contours by the specified\n  \\f$\\texttt{offset}=(dx,dy)\\f$ .\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  Destination image.\n\nThe function draws contour outlines in the image if \\f$\\texttt{thickness} \\ge 0\\f$ or fills the area\nbounded by the contours if \\f$\\texttt{thickness}<0\\f$ . The example below shows how to retrieve\nconnected components from the binary image and label them: :\n@include snippets/imgproc_drawContours.cpp\n**Note**: When thickness=#FILLED, the function is designed to handle connected components with holes correctly\neven when no hierarchy data is provided. This is done by analyzing all the outlines together\nusing even-odd rule. This may give incorrect results if you have a joint collection of separately retrieved\ncontours. In order to solve this problem, you need to call #drawContours separately for each sub-group\nof contours, or iterate over the collection using contourIdx parameter.\n\nPython prototype (for reference only):\n```python3\ndrawContours(image, contours, contourIdx, color[, thickness[, lineType[, hierarchy[, maxLevel[, offset]]]]]) -> image\n```","ref":"Evision.html#drawContours/5"},{"type":"function","title":"Evision.drawFrameAxes/1","doc":"","ref":"Evision.html#drawFrameAxes/1"},{"type":"function","title":"Evision.drawFrameAxes/6","doc":"Draw axes of the world/object coordinate system from pose estimation. @sa solvePnP\n\n##### Positional Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input 3x3 floating-point matrix of camera intrinsic parameters.\n  \\f$\\cameramatrix{A}\\f$\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$\\distcoeffs\\f$. If the vector is empty, the zero distortion coefficients are assumed.\n\n- **rvec**: `Evision.Mat`.\n\n  Rotation vector (see @ref Rodrigues ) that, together with tvec, brings points from\n  the model coordinate system to the camera coordinate system.\n\n- **tvec**: `Evision.Mat`.\n\n  Translation vector.\n\n- **length**: `float`.\n\n  Length of the painted axes in the same unit than tvec (usually in meters).\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n\n  Line thickness of the painted axes.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  Input/output image. It must have 1 or 3 channels. The number of channels is not altered.\n\nThis function draws the axes of the world/object coordinate system w.r.t. to the camera frame.\nOX is drawn in red, OY in green and OZ in blue.\n\nPython prototype (for reference only):\n```python3\ndrawFrameAxes(image, cameraMatrix, distCoeffs, rvec, tvec, length[, thickness]) -> image\n```","ref":"Evision.html#drawFrameAxes/6"},{"type":"function","title":"Evision.drawFrameAxes/7","doc":"Draw axes of the world/object coordinate system from pose estimation. @sa solvePnP\n\n##### Positional Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input 3x3 floating-point matrix of camera intrinsic parameters.\n  \\f$\\cameramatrix{A}\\f$\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$\\distcoeffs\\f$. If the vector is empty, the zero distortion coefficients are assumed.\n\n- **rvec**: `Evision.Mat`.\n\n  Rotation vector (see @ref Rodrigues ) that, together with tvec, brings points from\n  the model coordinate system to the camera coordinate system.\n\n- **tvec**: `Evision.Mat`.\n\n  Translation vector.\n\n- **length**: `float`.\n\n  Length of the painted axes in the same unit than tvec (usually in meters).\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n\n  Line thickness of the painted axes.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  Input/output image. It must have 1 or 3 channels. The number of channels is not altered.\n\nThis function draws the axes of the world/object coordinate system w.r.t. to the camera frame.\nOX is drawn in red, OY in green and OZ in blue.\n\nPython prototype (for reference only):\n```python3\ndrawFrameAxes(image, cameraMatrix, distCoeffs, rvec, tvec, length[, thickness]) -> image\n```","ref":"Evision.html#drawFrameAxes/7"},{"type":"function","title":"Evision.drawKeypoints/1","doc":"","ref":"Evision.html#drawKeypoints/1"},{"type":"function","title":"Evision.drawKeypoints/3","doc":"Draws keypoints.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Source image.\n\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Keypoints from the source image.\n\n##### Keyword Arguments\n- **color**: `Evision.scalar()`.\n\n  Color of keypoints.\n\n- **flags**: `DrawMatchesFlags`.\n\n  Flags setting drawing features. Possible flags bit values are defined by\n  DrawMatchesFlags. See details above in drawMatches .\n\n##### Return\n- **outImage**: `Evision.Mat.t()`.\n\n  Output image. Its content depends on the flags value defining what is drawn in the\n  output image. See possible flags bit values below.\n\n**Note**: \nFor Python API, flags are modified as cv.DRAW_MATCHES_FLAGS_DEFAULT,\ncv.DRAW_MATCHES_FLAGS_DRAW_RICH_KEYPOINTS, cv.DRAW_MATCHES_FLAGS_DRAW_OVER_OUTIMG,\ncv.DRAW_MATCHES_FLAGS_NOT_DRAW_SINGLE_POINTS\n\nPython prototype (for reference only):\n```python3\ndrawKeypoints(image, keypoints, outImage[, color[, flags]]) -> outImage\n```","ref":"Evision.html#drawKeypoints/3"},{"type":"function","title":"Evision.drawKeypoints/4","doc":"Draws keypoints.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Source image.\n\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Keypoints from the source image.\n\n##### Keyword Arguments\n- **color**: `Evision.scalar()`.\n\n  Color of keypoints.\n\n- **flags**: `DrawMatchesFlags`.\n\n  Flags setting drawing features. Possible flags bit values are defined by\n  DrawMatchesFlags. See details above in drawMatches .\n\n##### Return\n- **outImage**: `Evision.Mat.t()`.\n\n  Output image. Its content depends on the flags value defining what is drawn in the\n  output image. See possible flags bit values below.\n\n**Note**: \nFor Python API, flags are modified as cv.DRAW_MATCHES_FLAGS_DEFAULT,\ncv.DRAW_MATCHES_FLAGS_DRAW_RICH_KEYPOINTS, cv.DRAW_MATCHES_FLAGS_DRAW_OVER_OUTIMG,\ncv.DRAW_MATCHES_FLAGS_NOT_DRAW_SINGLE_POINTS\n\nPython prototype (for reference only):\n```python3\ndrawKeypoints(image, keypoints, outImage[, color[, flags]]) -> outImage\n```","ref":"Evision.html#drawKeypoints/4"},{"type":"function","title":"Evision.drawMarker/1","doc":"","ref":"Evision.html#drawMarker/1"},{"type":"function","title":"Evision.drawMarker/3","doc":"Draws a marker on a predefined position in an image.\n\n##### Positional Arguments\n- **position**: `Point`.\n\n  The point where the crosshair is positioned.\n\n- **color**: `Evision.scalar()`.\n\n  Line color.\n\n##### Keyword Arguments\n- **markerType**: `integer()`.\n\n  The specific type of marker you want to use, see #MarkerTypes\n\n- **markerSize**: `integer()`.\n\n  The length of the marker axis [default = 20 pixels]\n\n- **thickness**: `integer()`.\n\n  Line thickness.\n\n- **line_type**: `integer()`.\n\n  Type of the line, See #LineTypes\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  Image.\n\nThe function cv::drawMarker draws a marker on a given position in the image. For the moment several\nmarker types are supported, see #MarkerTypes for more information.\n\nPython prototype (for reference only):\n```python3\ndrawMarker(img, position, color[, markerType[, markerSize[, thickness[, line_type]]]]) -> img\n```","ref":"Evision.html#drawMarker/3"},{"type":"function","title":"Evision.drawMarker/4","doc":"Draws a marker on a predefined position in an image.\n\n##### Positional Arguments\n- **position**: `Point`.\n\n  The point where the crosshair is positioned.\n\n- **color**: `Evision.scalar()`.\n\n  Line color.\n\n##### Keyword Arguments\n- **markerType**: `integer()`.\n\n  The specific type of marker you want to use, see #MarkerTypes\n\n- **markerSize**: `integer()`.\n\n  The length of the marker axis [default = 20 pixels]\n\n- **thickness**: `integer()`.\n\n  Line thickness.\n\n- **line_type**: `integer()`.\n\n  Type of the line, See #LineTypes\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  Image.\n\nThe function cv::drawMarker draws a marker on a given position in the image. For the moment several\nmarker types are supported, see #MarkerTypes for more information.\n\nPython prototype (for reference only):\n```python3\ndrawMarker(img, position, color[, markerType[, markerSize[, thickness[, line_type]]]]) -> img\n```","ref":"Evision.html#drawMarker/4"},{"type":"function","title":"Evision.drawMatches/1","doc":"","ref":"Evision.html#drawMatches/1"},{"type":"function","title":"Evision.drawMatches/6","doc":"Draws the found matches of keypoints from two images.\n\n##### Positional Arguments\n- **img1**: `Evision.Mat`.\n\n  First source image.\n\n- **keypoints1**: `[Evision.KeyPoint]`.\n\n  Keypoints from the first source image.\n\n- **img2**: `Evision.Mat`.\n\n  Second source image.\n\n- **keypoints2**: `[Evision.KeyPoint]`.\n\n  Keypoints from the second source image.\n\n- **matches1to2**: `[Evision.DMatch]`.\n\n  Matches from the first image to the second one, which means that keypoints1[i]\n  has a corresponding point in keypoints2[matches[i]] .\n\n##### Keyword Arguments\n- **matchColor**: `Evision.scalar()`.\n\n  Color of matches (lines and connected keypoints). If matchColor==Scalar::all(-1)\n  , the color is generated randomly.\n\n- **singlePointColor**: `Evision.scalar()`.\n\n  Color of single keypoints (circles), which means that keypoints do not\n  have the matches. If singlePointColor==Scalar::all(-1) , the color is generated randomly.\n\n- **matchesMask**: `[char]`.\n\n  Mask determining which matches are drawn. If the mask is empty, all matches are\n  drawn.\n\n- **flags**: `DrawMatchesFlags`.\n\n  Flags setting drawing features. Possible flags bit values are defined by\n  DrawMatchesFlags.\n\n##### Return\n- **outImg**: `Evision.Mat.t()`.\n\n  Output image. Its content depends on the flags value defining what is drawn in the\n  output image. See possible flags bit values below.\n\nThis function draws matches of keypoints from two images in the output image. Match is a line\nconnecting two keypoints (circles). See cv::DrawMatchesFlags.\n\nPython prototype (for reference only):\n```python3\ndrawMatches(img1, keypoints1, img2, keypoints2, matches1to2, outImg[, matchColor[, singlePointColor[, matchesMask[, flags]]]]) -> outImg\n```","ref":"Evision.html#drawMatches/6"},{"type":"function","title":"Evision.drawMatches/7","doc":"#### Variant 1:\ndrawMatches\n\n##### Positional Arguments\n- **img1**: `Evision.Mat`\n- **keypoints1**: `[Evision.KeyPoint]`\n- **img2**: `Evision.Mat`\n- **keypoints2**: `[Evision.KeyPoint]`\n- **matches1to2**: `[Evision.DMatch]`\n- **matchesThickness**: `integer()`\n\n##### Keyword Arguments\n- **matchColor**: `Evision.scalar()`.\n- **singlePointColor**: `Evision.scalar()`.\n- **matchesMask**: `[char]`.\n- **flags**: `DrawMatchesFlags`.\n\n##### Return\n- **outImg**: `Evision.Mat.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndrawMatches(img1, keypoints1, img2, keypoints2, matches1to2, outImg, matchesThickness[, matchColor[, singlePointColor[, matchesMask[, flags]]]]) -> outImg\n```\n#### Variant 2:\nDraws the found matches of keypoints from two images.\n\n##### Positional Arguments\n- **img1**: `Evision.Mat`.\n\n  First source image.\n\n- **keypoints1**: `[Evision.KeyPoint]`.\n\n  Keypoints from the first source image.\n\n- **img2**: `Evision.Mat`.\n\n  Second source image.\n\n- **keypoints2**: `[Evision.KeyPoint]`.\n\n  Keypoints from the second source image.\n\n- **matches1to2**: `[Evision.DMatch]`.\n\n  Matches from the first image to the second one, which means that keypoints1[i]\n  has a corresponding point in keypoints2[matches[i]] .\n\n##### Keyword Arguments\n- **matchColor**: `Evision.scalar()`.\n\n  Color of matches (lines and connected keypoints). If matchColor==Scalar::all(-1)\n  , the color is generated randomly.\n\n- **singlePointColor**: `Evision.scalar()`.\n\n  Color of single keypoints (circles), which means that keypoints do not\n  have the matches. If singlePointColor==Scalar::all(-1) , the color is generated randomly.\n\n- **matchesMask**: `[char]`.\n\n  Mask determining which matches are drawn. If the mask is empty, all matches are\n  drawn.\n\n- **flags**: `DrawMatchesFlags`.\n\n  Flags setting drawing features. Possible flags bit values are defined by\n  DrawMatchesFlags.\n\n##### Return\n- **outImg**: `Evision.Mat.t()`.\n\n  Output image. Its content depends on the flags value defining what is drawn in the\n  output image. See possible flags bit values below.\n\nThis function draws matches of keypoints from two images in the output image. Match is a line\nconnecting two keypoints (circles). See cv::DrawMatchesFlags.\n\nPython prototype (for reference only):\n```python3\ndrawMatches(img1, keypoints1, img2, keypoints2, matches1to2, outImg[, matchColor[, singlePointColor[, matchesMask[, flags]]]]) -> outImg\n```","ref":"Evision.html#drawMatches/7"},{"type":"function","title":"Evision.drawMatches/8","doc":"drawMatches\n\n##### Positional Arguments\n- **img1**: `Evision.Mat`\n- **keypoints1**: `[Evision.KeyPoint]`\n- **img2**: `Evision.Mat`\n- **keypoints2**: `[Evision.KeyPoint]`\n- **matches1to2**: `[Evision.DMatch]`\n- **matchesThickness**: `integer()`\n\n##### Keyword Arguments\n- **matchColor**: `Evision.scalar()`.\n- **singlePointColor**: `Evision.scalar()`.\n- **matchesMask**: `[char]`.\n- **flags**: `DrawMatchesFlags`.\n\n##### Return\n- **outImg**: `Evision.Mat.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndrawMatches(img1, keypoints1, img2, keypoints2, matches1to2, outImg, matchesThickness[, matchColor[, singlePointColor[, matchesMask[, flags]]]]) -> outImg\n```","ref":"Evision.html#drawMatches/8"},{"type":"function","title":"Evision.drawMatchesKnn/1","doc":"","ref":"Evision.html#drawMatchesKnn/1"},{"type":"function","title":"Evision.drawMatchesKnn/6","doc":"drawMatchesKnn\n\n##### Positional Arguments\n- **img1**: `Evision.Mat`\n- **keypoints1**: `[Evision.KeyPoint]`\n- **img2**: `Evision.Mat`\n- **keypoints2**: `[Evision.KeyPoint]`\n- **matches1to2**: `[[Evision.DMatch]]`\n\n##### Keyword Arguments\n- **matchColor**: `Evision.scalar()`.\n- **singlePointColor**: `Evision.scalar()`.\n- **matchesMask**: `[[char]]`.\n- **flags**: `DrawMatchesFlags`.\n\n##### Return\n- **outImg**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ndrawMatchesKnn(img1, keypoints1, img2, keypoints2, matches1to2, outImg[, matchColor[, singlePointColor[, matchesMask[, flags]]]]) -> outImg\n```","ref":"Evision.html#drawMatchesKnn/6"},{"type":"function","title":"Evision.drawMatchesKnn/7","doc":"drawMatchesKnn\n\n##### Positional Arguments\n- **img1**: `Evision.Mat`\n- **keypoints1**: `[Evision.KeyPoint]`\n- **img2**: `Evision.Mat`\n- **keypoints2**: `[Evision.KeyPoint]`\n- **matches1to2**: `[[Evision.DMatch]]`\n\n##### Keyword Arguments\n- **matchColor**: `Evision.scalar()`.\n- **singlePointColor**: `Evision.scalar()`.\n- **matchesMask**: `[[char]]`.\n- **flags**: `DrawMatchesFlags`.\n\n##### Return\n- **outImg**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ndrawMatchesKnn(img1, keypoints1, img2, keypoints2, matches1to2, outImg[, matchColor[, singlePointColor[, matchesMask[, flags]]]]) -> outImg\n```","ref":"Evision.html#drawMatchesKnn/7"},{"type":"function","title":"Evision.edgePreservingFilter/1","doc":"Filtering is the fundamental operation in image and video processing. Edge-preserving smoothing\nfilters are used in many different applications @cite EM11 .\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Edge preserving filters: cv::RECURS_FILTER or cv::NORMCONV_FILTER\n\n- **sigma_s**: `float`.\n\n  %Range between 0 to 200.\n\n- **sigma_r**: `float`.\n\n  %Range between 0 to 1.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output 8-bit 3-channel image.\n\nPython prototype (for reference only):\n```python3\nedgePreservingFilter(src[, dst[, flags[, sigma_s[, sigma_r]]]]) -> dst\n```","ref":"Evision.html#edgePreservingFilter/1"},{"type":"function","title":"Evision.edgePreservingFilter/2","doc":"Filtering is the fundamental operation in image and video processing. Edge-preserving smoothing\nfilters are used in many different applications @cite EM11 .\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Edge preserving filters: cv::RECURS_FILTER or cv::NORMCONV_FILTER\n\n- **sigma_s**: `float`.\n\n  %Range between 0 to 200.\n\n- **sigma_r**: `float`.\n\n  %Range between 0 to 1.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output 8-bit 3-channel image.\n\nPython prototype (for reference only):\n```python3\nedgePreservingFilter(src[, dst[, flags[, sigma_s[, sigma_r]]]]) -> dst\n```","ref":"Evision.html#edgePreservingFilter/2"},{"type":"function","title":"Evision.eigen/1","doc":"Calculates eigenvalues and eigenvectors of a symmetric matrix.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input matrix that must have CV_32FC1 or CV_64FC1 type, square size and be symmetrical\n  (src ^T^ == src).\n\n##### Return\n- **retval**: `bool`\n- **eigenvalues**: `Evision.Mat.t()`.\n\n  output vector of eigenvalues of the same type as src; the eigenvalues are stored\n  in the descending order.\n\n- **eigenvectors**: `Evision.Mat.t()`.\n\n  output matrix of eigenvectors; it has the same size and type as src; the\n  eigenvectors are stored as subsequent matrix rows, in the same order as the corresponding\n  eigenvalues.\n\nThe function cv::eigen calculates just eigenvalues, or eigenvalues and eigenvectors of the symmetric\nmatrix src:\n```\nsrc*eigenvectors.row(i).t() = eigenvalues.at (i)*eigenvectors.row(i).t()\n```\n**Note**: Use cv::eigenNonSymmetric for calculation of real eigenvalues and eigenvectors of non-symmetric matrix.\n@sa eigenNonSymmetric, completeSymm, PCA\n\nPython prototype (for reference only):\n```python3\neigen(src[, eigenvalues[, eigenvectors]]) -> retval, eigenvalues, eigenvectors\n```","ref":"Evision.html#eigen/1"},{"type":"function","title":"Evision.eigen/2","doc":"Calculates eigenvalues and eigenvectors of a symmetric matrix.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input matrix that must have CV_32FC1 or CV_64FC1 type, square size and be symmetrical\n  (src ^T^ == src).\n\n##### Return\n- **retval**: `bool`\n- **eigenvalues**: `Evision.Mat.t()`.\n\n  output vector of eigenvalues of the same type as src; the eigenvalues are stored\n  in the descending order.\n\n- **eigenvectors**: `Evision.Mat.t()`.\n\n  output matrix of eigenvectors; it has the same size and type as src; the\n  eigenvectors are stored as subsequent matrix rows, in the same order as the corresponding\n  eigenvalues.\n\nThe function cv::eigen calculates just eigenvalues, or eigenvalues and eigenvectors of the symmetric\nmatrix src:\n```\nsrc*eigenvectors.row(i).t() = eigenvalues.at (i)*eigenvectors.row(i).t()\n```\n**Note**: Use cv::eigenNonSymmetric for calculation of real eigenvalues and eigenvectors of non-symmetric matrix.\n@sa eigenNonSymmetric, completeSymm, PCA\n\nPython prototype (for reference only):\n```python3\neigen(src[, eigenvalues[, eigenvectors]]) -> retval, eigenvalues, eigenvectors\n```","ref":"Evision.html#eigen/2"},{"type":"function","title":"Evision.eigenNonSymmetric/1","doc":"Calculates eigenvalues and eigenvectors of a non-symmetric matrix (real eigenvalues only).\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input matrix (CV_32FC1 or CV_64FC1 type).\n\n##### Return\n- **eigenvalues**: `Evision.Mat.t()`.\n\n  output vector of eigenvalues (type is the same type as src).\n\n- **eigenvectors**: `Evision.Mat.t()`.\n\n  output matrix of eigenvectors (type is the same type as src). The eigenvectors are stored as subsequent matrix rows, in the same order as the corresponding eigenvalues.\n\n**Note**: Assumes real eigenvalues.\nThe function calculates eigenvalues and eigenvectors (optional) of the square matrix src:\n```\nsrc*eigenvectors.row(i).t() = eigenvalues.at (i)*eigenvectors.row(i).t()\n```\n@sa eigen\n\nPython prototype (for reference only):\n```python3\neigenNonSymmetric(src[, eigenvalues[, eigenvectors]]) -> eigenvalues, eigenvectors\n```","ref":"Evision.html#eigenNonSymmetric/1"},{"type":"function","title":"Evision.eigenNonSymmetric/2","doc":"Calculates eigenvalues and eigenvectors of a non-symmetric matrix (real eigenvalues only).\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input matrix (CV_32FC1 or CV_64FC1 type).\n\n##### Return\n- **eigenvalues**: `Evision.Mat.t()`.\n\n  output vector of eigenvalues (type is the same type as src).\n\n- **eigenvectors**: `Evision.Mat.t()`.\n\n  output matrix of eigenvectors (type is the same type as src). The eigenvectors are stored as subsequent matrix rows, in the same order as the corresponding eigenvalues.\n\n**Note**: Assumes real eigenvalues.\nThe function calculates eigenvalues and eigenvectors (optional) of the square matrix src:\n```\nsrc*eigenvectors.row(i).t() = eigenvalues.at (i)*eigenvectors.row(i).t()\n```\n@sa eigen\n\nPython prototype (for reference only):\n```python3\neigenNonSymmetric(src[, eigenvalues[, eigenvectors]]) -> eigenvalues, eigenvectors\n```","ref":"Evision.html#eigenNonSymmetric/2"},{"type":"function","title":"Evision.ellipse2Poly/1","doc":"","ref":"Evision.html#ellipse2Poly/1"},{"type":"function","title":"Evision.ellipse2Poly/6","doc":"Approximates an elliptic arc with a polyline.\n\n##### Positional Arguments\n- **center**: `Point`.\n\n  Center of the arc.\n\n- **axes**: `Size`.\n\n  Half of the size of the ellipse main axes. See #ellipse for details.\n\n- **angle**: `integer()`.\n\n  Rotation angle of the ellipse in degrees. See #ellipse for details.\n\n- **arcStart**: `integer()`.\n\n  Starting angle of the elliptic arc in degrees.\n\n- **arcEnd**: `integer()`.\n\n  Ending angle of the elliptic arc in degrees.\n\n- **delta**: `integer()`.\n\n  Angle between the subsequent polyline vertices. It defines the approximation\n  accuracy.\n\n##### Return\n- **pts**: `[Point]`.\n\n  Output vector of polyline vertices.\n\nThe function ellipse2Poly computes the vertices of a polyline that approximates the specified\nelliptic arc. It is used by #ellipse. If `arcStart` is greater than `arcEnd`, they are swapped.\n\nPython prototype (for reference only):\n```python3\nellipse2Poly(center, axes, angle, arcStart, arcEnd, delta) -> pts\n```","ref":"Evision.html#ellipse2Poly/6"},{"type":"function","title":"Evision.ellipse/1","doc":"","ref":"Evision.html#ellipse/1"},{"type":"function","title":"Evision.ellipse/3","doc":"ellipse\n\n##### Positional Arguments\n- **box**: `{centre={x, y}, size={s1, s2}, angle}`.\n\n  Alternative ellipse representation via RotatedRect. This means that the function draws\n  an ellipse inscribed in the rotated rectangle.\n\n- **color**: `Evision.scalar()`.\n\n  Ellipse color.\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n\n  Thickness of the ellipse arc outline, if positive. Otherwise, this indicates that\n  a filled ellipse sector is to be drawn.\n\n- **lineType**: `integer()`.\n\n  Type of the ellipse boundary. See #LineTypes\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  Image.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nellipse(img, box, color[, thickness[, lineType]]) -> img\n```","ref":"Evision.html#ellipse/3"},{"type":"function","title":"Evision.ellipse/4","doc":"ellipse\n\n##### Positional Arguments\n- **box**: `{centre={x, y}, size={s1, s2}, angle}`.\n\n  Alternative ellipse representation via RotatedRect. This means that the function draws\n  an ellipse inscribed in the rotated rectangle.\n\n- **color**: `Evision.scalar()`.\n\n  Ellipse color.\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n\n  Thickness of the ellipse arc outline, if positive. Otherwise, this indicates that\n  a filled ellipse sector is to be drawn.\n\n- **lineType**: `integer()`.\n\n  Type of the ellipse boundary. See #LineTypes\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  Image.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nellipse(img, box, color[, thickness[, lineType]]) -> img\n```","ref":"Evision.html#ellipse/4"},{"type":"function","title":"Evision.ellipse/7","doc":"Draws a simple or thick elliptic arc or fills an ellipse sector.\n\n##### Positional Arguments\n- **center**: `Point`.\n\n  Center of the ellipse.\n\n- **axes**: `Size`.\n\n  Half of the size of the ellipse main axes.\n\n- **angle**: `double`.\n\n  Ellipse rotation angle in degrees.\n\n- **startAngle**: `double`.\n\n  Starting angle of the elliptic arc in degrees.\n\n- **endAngle**: `double`.\n\n  Ending angle of the elliptic arc in degrees.\n\n- **color**: `Evision.scalar()`.\n\n  Ellipse color.\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n\n  Thickness of the ellipse arc outline, if positive. Otherwise, this indicates that\n  a filled ellipse sector is to be drawn.\n\n- **lineType**: `integer()`.\n\n  Type of the ellipse boundary. See #LineTypes\n\n- **shift**: `integer()`.\n\n  Number of fractional bits in the coordinates of the center and values of axes.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  Image.\n\nThe function cv::ellipse with more parameters draws an ellipse outline, a filled ellipse, an elliptic\narc, or a filled ellipse sector. The drawing code uses general parametric form.\nA piecewise-linear curve is used to approximate the elliptic arc\nboundary. If you need more control of the ellipse rendering, you can retrieve the curve using\n#ellipse2Poly and then render it with #polylines or fill it with #fillPoly. If you use the first\nvariant of the function and want to draw the whole ellipse, not an arc, pass `startAngle=0` and\n`endAngle=360`. If `startAngle` is greater than `endAngle`, they are swapped. The figure below explains\nthe meaning of the parameters to draw the blue arc.\n![Parameters of Elliptic Arc](pics/ellipse.svg)\n\nPython prototype (for reference only):\n```python3\nellipse(img, center, axes, angle, startAngle, endAngle, color[, thickness[, lineType[, shift]]]) -> img\n```","ref":"Evision.html#ellipse/7"},{"type":"function","title":"Evision.ellipse/8","doc":"Draws a simple or thick elliptic arc or fills an ellipse sector.\n\n##### Positional Arguments\n- **center**: `Point`.\n\n  Center of the ellipse.\n\n- **axes**: `Size`.\n\n  Half of the size of the ellipse main axes.\n\n- **angle**: `double`.\n\n  Ellipse rotation angle in degrees.\n\n- **startAngle**: `double`.\n\n  Starting angle of the elliptic arc in degrees.\n\n- **endAngle**: `double`.\n\n  Ending angle of the elliptic arc in degrees.\n\n- **color**: `Evision.scalar()`.\n\n  Ellipse color.\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n\n  Thickness of the ellipse arc outline, if positive. Otherwise, this indicates that\n  a filled ellipse sector is to be drawn.\n\n- **lineType**: `integer()`.\n\n  Type of the ellipse boundary. See #LineTypes\n\n- **shift**: `integer()`.\n\n  Number of fractional bits in the coordinates of the center and values of axes.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  Image.\n\nThe function cv::ellipse with more parameters draws an ellipse outline, a filled ellipse, an elliptic\narc, or a filled ellipse sector. The drawing code uses general parametric form.\nA piecewise-linear curve is used to approximate the elliptic arc\nboundary. If you need more control of the ellipse rendering, you can retrieve the curve using\n#ellipse2Poly and then render it with #polylines or fill it with #fillPoly. If you use the first\nvariant of the function and want to draw the whole ellipse, not an arc, pass `startAngle=0` and\n`endAngle=360`. If `startAngle` is greater than `endAngle`, they are swapped. The figure below explains\nthe meaning of the parameters to draw the blue arc.\n![Parameters of Elliptic Arc](pics/ellipse.svg)\n\nPython prototype (for reference only):\n```python3\nellipse(img, center, axes, angle, startAngle, endAngle, color[, thickness[, lineType[, shift]]]) -> img\n```","ref":"Evision.html#ellipse/8"},{"type":"function","title":"Evision.emd/1","doc":"","ref":"Evision.html#emd/1"},{"type":"function","title":"Evision.emd/3","doc":"Computes the \"minimal work\" distance between two weighted point configurations.\n\n##### Positional Arguments\n- **signature1**: `Evision.Mat`.\n\n  First signature, a \\f$\\texttt{size1}\\times \\texttt{dims}+1\\f$ floating-point matrix.\n  Each row stores the point weight followed by the point coordinates. The matrix is allowed to have\n  a single column (weights only) if the user-defined cost matrix is used. The weights must be\n  non-negative and have at least one non-zero value.\n\n- **signature2**: `Evision.Mat`.\n\n  Second signature of the same format as signature1 , though the number of rows\n  may be different. The total weights may be different. In this case an extra \"dummy\" point is added\n  to either signature1 or signature2. The weights must be non-negative and have at least one non-zero\n  value.\n\n- **distType**: `integer()`.\n\n  Used metric. See #DistanceTypes.\n\n##### Keyword Arguments\n- **cost**: `Evision.Mat`.\n\n  User-defined \\f$\\texttt{size1}\\times \\texttt{size2}\\f$ cost matrix. Also, if a cost matrix\n  is used, lower boundary lowerBound cannot be calculated because it needs a metric function.\n\n##### Return\n- **retval**: `float`\n- **lowerBound**: `float`.\n\n  Optional input/output parameter: lower boundary of a distance between the two\n  signatures that is a distance between mass centers. The lower boundary may not be calculated if\n  the user-defined cost matrix is used, the total weights of point configurations are not equal, or\n  if the signatures consist of weights only (the signature matrices have a single column). You\n  * must** initialize \\*lowerBound . If the calculated distance between mass centers is greater or\n    equal to \\*lowerBound (it means that the signatures are far enough), the function does not\n    calculate EMD. In any case \\*lowerBound is set to the calculated distance between mass centers on\n    return. Thus, if you want to calculate both distance between mass centers and EMD, \\*lowerBound\n    should be set to 0.\n\n- **flow**: `Evision.Mat.t()`.\n\n  Resultant \\f$\\texttt{size1} \\times \\texttt{size2}\\f$ flow matrix: \\f$\\texttt{flow}_{i,j}\\f$ is\n  a flow from \\f$i\\f$ -th point of signature1 to \\f$j\\f$ -th point of signature2 .\n\nThe function computes the earth mover distance and/or a lower boundary of the distance between the\ntwo weighted point configurations. One of the applications described in @cite RubnerSept98,\n@cite Rubner2000 is multi-dimensional histogram comparison for image retrieval. EMD is a transportation\nproblem that is solved using some modification of a simplex algorithm, thus the complexity is\nexponential in the worst case, though, on average it is much faster. In the case of a real metric\nthe lower boundary can be calculated even faster (using linear-time algorithm) and it can be used\nto determine roughly whether the two signatures are far enough so that they cannot relate to the\nsame object.\n\nPython prototype (for reference only):\n```python3\nEMD(signature1, signature2, distType[, cost[, lowerBound[, flow]]]) -> retval, lowerBound, flow\n```","ref":"Evision.html#emd/3"},{"type":"function","title":"Evision.emd/4","doc":"Computes the \"minimal work\" distance between two weighted point configurations.\n\n##### Positional Arguments\n- **signature1**: `Evision.Mat`.\n\n  First signature, a \\f$\\texttt{size1}\\times \\texttt{dims}+1\\f$ floating-point matrix.\n  Each row stores the point weight followed by the point coordinates. The matrix is allowed to have\n  a single column (weights only) if the user-defined cost matrix is used. The weights must be\n  non-negative and have at least one non-zero value.\n\n- **signature2**: `Evision.Mat`.\n\n  Second signature of the same format as signature1 , though the number of rows\n  may be different. The total weights may be different. In this case an extra \"dummy\" point is added\n  to either signature1 or signature2. The weights must be non-negative and have at least one non-zero\n  value.\n\n- **distType**: `integer()`.\n\n  Used metric. See #DistanceTypes.\n\n##### Keyword Arguments\n- **cost**: `Evision.Mat`.\n\n  User-defined \\f$\\texttt{size1}\\times \\texttt{size2}\\f$ cost matrix. Also, if a cost matrix\n  is used, lower boundary lowerBound cannot be calculated because it needs a metric function.\n\n##### Return\n- **retval**: `float`\n- **lowerBound**: `float`.\n\n  Optional input/output parameter: lower boundary of a distance between the two\n  signatures that is a distance between mass centers. The lower boundary may not be calculated if\n  the user-defined cost matrix is used, the total weights of point configurations are not equal, or\n  if the signatures consist of weights only (the signature matrices have a single column). You\n  * must** initialize \\*lowerBound . If the calculated distance between mass centers is greater or\n    equal to \\*lowerBound (it means that the signatures are far enough), the function does not\n    calculate EMD. In any case \\*lowerBound is set to the calculated distance between mass centers on\n    return. Thus, if you want to calculate both distance between mass centers and EMD, \\*lowerBound\n    should be set to 0.\n\n- **flow**: `Evision.Mat.t()`.\n\n  Resultant \\f$\\texttt{size1} \\times \\texttt{size2}\\f$ flow matrix: \\f$\\texttt{flow}_{i,j}\\f$ is\n  a flow from \\f$i\\f$ -th point of signature1 to \\f$j\\f$ -th point of signature2 .\n\nThe function computes the earth mover distance and/or a lower boundary of the distance between the\ntwo weighted point configurations. One of the applications described in @cite RubnerSept98,\n@cite Rubner2000 is multi-dimensional histogram comparison for image retrieval. EMD is a transportation\nproblem that is solved using some modification of a simplex algorithm, thus the complexity is\nexponential in the worst case, though, on average it is much faster. In the case of a real metric\nthe lower boundary can be calculated even faster (using linear-time algorithm) and it can be used\nto determine roughly whether the two signatures are far enough so that they cannot relate to the\nsame object.\n\nPython prototype (for reference only):\n```python3\nEMD(signature1, signature2, distType[, cost[, lowerBound[, flow]]]) -> retval, lowerBound, flow\n```","ref":"Evision.html#emd/4"},{"type":"function","title":"Evision.enabled_modules/0","doc":"return a list of enabled modules in this build","ref":"Evision.html#enabled_modules/0"},{"type":"function","title":"Evision.equalizeHist/1","doc":"Equalizes the histogram of a grayscale image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source 8-bit single channel image.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and type as src .\n\nThe function equalizes the histogram of the input image using the following algorithm:\n- Calculate the histogram \\f$H\\f$ for src .\n- Normalize the histogram so that the sum of histogram bins is 255.\n- Compute the integral of the histogram:\n  \\f[H'\\_i =  \\sum \\_{0  \\le j   dst\n```","ref":"Evision.html#equalizeHist/1"},{"type":"function","title":"Evision.equalizeHist/2","doc":"Equalizes the histogram of a grayscale image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source 8-bit single channel image.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and type as src .\n\nThe function equalizes the histogram of the input image using the following algorithm:\n- Calculate the histogram \\f$H\\f$ for src .\n- Normalize the histogram so that the sum of histogram bins is 255.\n- Compute the integral of the histogram:\n  \\f[H'\\_i =  \\sum \\_{0  \\le j   dst\n```","ref":"Evision.html#equalizeHist/2"},{"type":"function","title":"Evision.erode/1","doc":"","ref":"Evision.html#erode/1"},{"type":"function","title":"Evision.erode/2","doc":"Erodes an image by using a specific structuring element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image; the number of channels can be arbitrary, but the depth should be one of\n  CV_8U, CV_16U, CV_16S, CV_32F or CV_64F.\n\n- **kernel**: `Evision.Mat`.\n\n  structuring element used for erosion; if `element=Mat()`, a `3 x 3` rectangular\n  structuring element is used. Kernel can be created using #getStructuringElement.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  position of the anchor within the element; default value (-1, -1) means that the\n  anchor is at the element center.\n\n- **iterations**: `integer()`.\n\n  number of times erosion is applied.\n\n- **borderType**: `integer()`.\n\n  pixel extrapolation method, see #BorderTypes. #BORDER_WRAP is not supported.\n\n- **borderValue**: `Evision.scalar()`.\n\n  border value in case of a constant border\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and type as src.\n\nThe function erodes the source image using the specified structuring element that determines the\nshape of a pixel neighborhood over which the minimum is taken:\n\\f[\\texttt{dst} (x,y) =  \\min \\_{(x',y'):  \\, \\texttt{element} (x',y') \\ne0 } \\texttt{src} (x+x',y+y')\\f]\nThe function supports the in-place mode. Erosion can be applied several ( iterations ) times. In\ncase of multi-channel images, each channel is processed independently.\n@sa  dilate, morphologyEx, getStructuringElement\n\nPython prototype (for reference only):\n```python3\nerode(src, kernel[, dst[, anchor[, iterations[, borderType[, borderValue]]]]]) -> dst\n```","ref":"Evision.html#erode/2"},{"type":"function","title":"Evision.erode/3","doc":"Erodes an image by using a specific structuring element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image; the number of channels can be arbitrary, but the depth should be one of\n  CV_8U, CV_16U, CV_16S, CV_32F or CV_64F.\n\n- **kernel**: `Evision.Mat`.\n\n  structuring element used for erosion; if `element=Mat()`, a `3 x 3` rectangular\n  structuring element is used. Kernel can be created using #getStructuringElement.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  position of the anchor within the element; default value (-1, -1) means that the\n  anchor is at the element center.\n\n- **iterations**: `integer()`.\n\n  number of times erosion is applied.\n\n- **borderType**: `integer()`.\n\n  pixel extrapolation method, see #BorderTypes. #BORDER_WRAP is not supported.\n\n- **borderValue**: `Evision.scalar()`.\n\n  border value in case of a constant border\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and type as src.\n\nThe function erodes the source image using the specified structuring element that determines the\nshape of a pixel neighborhood over which the minimum is taken:\n\\f[\\texttt{dst} (x,y) =  \\min \\_{(x',y'):  \\, \\texttt{element} (x',y') \\ne0 } \\texttt{src} (x+x',y+y')\\f]\nThe function supports the in-place mode. Erosion can be applied several ( iterations ) times. In\ncase of multi-channel images, each channel is processed independently.\n@sa  dilate, morphologyEx, getStructuringElement\n\nPython prototype (for reference only):\n```python3\nerode(src, kernel[, dst[, anchor[, iterations[, borderType[, borderValue]]]]]) -> dst\n```","ref":"Evision.html#erode/3"},{"type":"function","title":"Evision.estimateAffine2D/1","doc":"","ref":"Evision.html#estimateAffine2D/1"},{"type":"function","title":"Evision.estimateAffine2D/2","doc":"Computes an optimal affine transformation between two 2D point sets.\n\n##### Positional Arguments\n- **from**: `Evision.Mat`.\n\n  First input 2D point set containing \\f$(X,Y)\\f$.\n\n- **to**: `Evision.Mat`.\n\n  Second input 2D point set containing \\f$(x,y)\\f$.\n\n##### Keyword Arguments\n- **method**: `integer()`.\n\n  Robust method used to compute transformation. The following methods are possible:\n  - @ref RANSAC - RANSAC-based robust method\n  - @ref LMEDS - Least-Median robust method\n    RANSAC is the default method.\n\n- **ransacReprojThreshold**: `double`.\n\n  Maximum reprojection error in the RANSAC algorithm to consider\n  a point as an inlier. Applies only to RANSAC.\n\n- **maxIters**: `size_t`.\n\n  The maximum number of robust method iterations.\n\n- **confidence**: `double`.\n\n  Confidence level, between 0 and 1, for the estimated transformation. Anything\n  between 0.95 and 0.99 is usually good enough. Values too close to 1 can slow down the estimation\n  significantly. Values lower than 0.8-0.9 can result in an incorrectly estimated transformation.\n\n- **refineIters**: `size_t`.\n\n  Maximum number of iterations of refining algorithm (Levenberg-Marquardt).\n  Passing 0 will disable refining, so the output matrix will be output of robust method.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **inliers**: `Evision.Mat.t()`.\n\n  Output vector indicating which points are inliers (1-inlier, 0-outlier).\n\nIt computes\n\\f[\n\\begin{bmatrix}\nx\\\\\\\\\ny\\\\\\\\\n\\end{bmatrix}\n\\begin{bmatrix}\na\\_{11} & a\\_{12}\\\\\\\\\na\\_{21} & a\\_{22}\\\\\\\\\n\\end{bmatrix}\n\\begin{bmatrix}\nX\\\\\\\\\nY\\\\\\\\\n\\end{bmatrix}\n+\n\\begin{bmatrix}\nb\\_1\\\\\\\\\nb\\_2\\\\\\\\\n\\end{bmatrix}\n\\f]\n\n@return Output 2D affine transformation matrix \\f$2 \\times 3\\f$ or empty matrix if transformation\ncould not be estimated. The returned matrix has the following form:\n\\f[\n\\begin{bmatrix}\na\\_{11} & a\\_{12} & b\\_1\\\\\\\\\na\\_{21} & a\\_{22} & b\\_2\\\\\\\\\n\\end{bmatrix}\n\\f]\nThe function estimates an optimal 2D affine transformation between two 2D point sets using the\nselected robust algorithm.\nThe computed transformation is then refined further (using only inliers) with the\nLevenberg-Marquardt method to reduce the re-projection error even more.\n**Note**: \nThe RANSAC method can handle practically any ratio of outliers but needs a threshold to\ndistinguish inliers from outliers. The method LMeDS does not need any threshold but it works\ncorrectly only when there are more than 50% of inliers.\n@sa estimateAffinePartial2D, getAffineTransform\n\nPython prototype (for reference only):\n```python3\nestimateAffine2D(from, to[, inliers[, method[, ransacReprojThreshold[, maxIters[, confidence[, refineIters]]]]]]) -> retval, inliers\n```","ref":"Evision.html#estimateAffine2D/2"},{"type":"function","title":"Evision.estimateAffine2D/3","doc":"#### Variant 1:\nestimateAffine2D\n\n##### Positional Arguments\n- **pts1**: `Evision.Mat`\n- **pts2**: `Evision.Mat`\n- **params**: `Evision.UsacParams`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **inliers**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nestimateAffine2D(pts1, pts2, params[, inliers]) -> retval, inliers\n```\n#### Variant 2:\nComputes an optimal affine transformation between two 2D point sets.\n\n##### Positional Arguments\n- **from**: `Evision.Mat`.\n\n  First input 2D point set containing \\f$(X,Y)\\f$.\n\n- **to**: `Evision.Mat`.\n\n  Second input 2D point set containing \\f$(x,y)\\f$.\n\n##### Keyword Arguments\n- **method**: `integer()`.\n\n  Robust method used to compute transformation. The following methods are possible:\n  - @ref RANSAC - RANSAC-based robust method\n  - @ref LMEDS - Least-Median robust method\n    RANSAC is the default method.\n\n- **ransacReprojThreshold**: `double`.\n\n  Maximum reprojection error in the RANSAC algorithm to consider\n  a point as an inlier. Applies only to RANSAC.\n\n- **maxIters**: `size_t`.\n\n  The maximum number of robust method iterations.\n\n- **confidence**: `double`.\n\n  Confidence level, between 0 and 1, for the estimated transformation. Anything\n  between 0.95 and 0.99 is usually good enough. Values too close to 1 can slow down the estimation\n  significantly. Values lower than 0.8-0.9 can result in an incorrectly estimated transformation.\n\n- **refineIters**: `size_t`.\n\n  Maximum number of iterations of refining algorithm (Levenberg-Marquardt).\n  Passing 0 will disable refining, so the output matrix will be output of robust method.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **inliers**: `Evision.Mat.t()`.\n\n  Output vector indicating which points are inliers (1-inlier, 0-outlier).\n\nIt computes\n\\f[\n\\begin{bmatrix}\nx\\\\\\\\\ny\\\\\\\\\n\\end{bmatrix}\n\\begin{bmatrix}\na\\_{11} & a\\_{12}\\\\\\\\\na\\_{21} & a\\_{22}\\\\\\\\\n\\end{bmatrix}\n\\begin{bmatrix}\nX\\\\\\\\\nY\\\\\\\\\n\\end{bmatrix}\n+\n\\begin{bmatrix}\nb\\_1\\\\\\\\\nb\\_2\\\\\\\\\n\\end{bmatrix}\n\\f]\n\n@return Output 2D affine transformation matrix \\f$2 \\times 3\\f$ or empty matrix if transformation\ncould not be estimated. The returned matrix has the following form:\n\\f[\n\\begin{bmatrix}\na\\_{11} & a\\_{12} & b\\_1\\\\\\\\\na\\_{21} & a\\_{22} & b\\_2\\\\\\\\\n\\end{bmatrix}\n\\f]\nThe function estimates an optimal 2D affine transformation between two 2D point sets using the\nselected robust algorithm.\nThe computed transformation is then refined further (using only inliers) with the\nLevenberg-Marquardt method to reduce the re-projection error even more.\n**Note**: \nThe RANSAC method can handle practically any ratio of outliers but needs a threshold to\ndistinguish inliers from outliers. The method LMeDS does not need any threshold but it works\ncorrectly only when there are more than 50% of inliers.\n@sa estimateAffinePartial2D, getAffineTransform\n\nPython prototype (for reference only):\n```python3\nestimateAffine2D(from, to[, inliers[, method[, ransacReprojThreshold[, maxIters[, confidence[, refineIters]]]]]]) -> retval, inliers\n```","ref":"Evision.html#estimateAffine2D/3"},{"type":"function","title":"Evision.estimateAffine2D/4","doc":"estimateAffine2D\n\n##### Positional Arguments\n- **pts1**: `Evision.Mat`\n- **pts2**: `Evision.Mat`\n- **params**: `Evision.UsacParams`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **inliers**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nestimateAffine2D(pts1, pts2, params[, inliers]) -> retval, inliers\n```","ref":"Evision.html#estimateAffine2D/4"},{"type":"function","title":"Evision.estimateAffine3D/1","doc":"","ref":"Evision.html#estimateAffine3D/1"},{"type":"function","title":"Evision.estimateAffine3D/2","doc":"Computes an optimal affine transformation between two 3D point sets.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  First input 3D point set.\n\n- **dst**: `Evision.Mat`.\n\n  Second input 3D point set.\n\n##### Keyword Arguments\n- **force_rotation**: `bool`.\n\n  If true, the returned rotation will never be a reflection.\n  This might be unwanted, e.g. when optimizing a transform between a right- and a\n  left-handed coordinate system.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **scale**: `double*`.\n\n  If null is passed, the scale parameter c will be assumed to be 1.0.\n  Else the pointed-to variable will be set to the optimal scale.\n\nIt computes \\f$R,s,t\\f$ minimizing \\f$\\sum{i} dst\\_i - c \\cdot R \\cdot src\\_i \\f$\nwhere \\f$R\\f$ is a 3x3 rotation matrix, \\f$t\\f$ is a 3x1 translation vector and \\f$s\\f$ is a\nscalar size value. This is an implementation of the algorithm by Umeyama \\cite umeyama1991least .\nThe estimated affine transform has a homogeneous scale which is a subclass of affine\ntransformations with 7 degrees of freedom. The paired point sets need to comprise at least 3\npoints each.\n@return 3D affine transformation matrix \\f$3 \\times 4\\f$ of the form\n\\f[T =\n\\begin{bmatrix}\nR & t\\\\\\\\\n\\end{bmatrix}\n\\f]\n\nPython prototype (for reference only):\n```python3\nestimateAffine3D(src, dst[, force_rotation]) -> retval, scale\n```","ref":"Evision.html#estimateAffine3D/2"},{"type":"function","title":"Evision.estimateAffine3D/3","doc":"Computes an optimal affine transformation between two 3D point sets.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  First input 3D point set.\n\n- **dst**: `Evision.Mat`.\n\n  Second input 3D point set.\n\n##### Keyword Arguments\n- **force_rotation**: `bool`.\n\n  If true, the returned rotation will never be a reflection.\n  This might be unwanted, e.g. when optimizing a transform between a right- and a\n  left-handed coordinate system.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **scale**: `double*`.\n\n  If null is passed, the scale parameter c will be assumed to be 1.0.\n  Else the pointed-to variable will be set to the optimal scale.\n\nIt computes \\f$R,s,t\\f$ minimizing \\f$\\sum{i} dst\\_i - c \\cdot R \\cdot src\\_i \\f$\nwhere \\f$R\\f$ is a 3x3 rotation matrix, \\f$t\\f$ is a 3x1 translation vector and \\f$s\\f$ is a\nscalar size value. This is an implementation of the algorithm by Umeyama \\cite umeyama1991least .\nThe estimated affine transform has a homogeneous scale which is a subclass of affine\ntransformations with 7 degrees of freedom. The paired point sets need to comprise at least 3\npoints each.\n@return 3D affine transformation matrix \\f$3 \\times 4\\f$ of the form\n\\f[T =\n\\begin{bmatrix}\nR & t\\\\\\\\\n\\end{bmatrix}\n\\f]\n\nPython prototype (for reference only):\n```python3\nestimateAffine3D(src, dst[, force_rotation]) -> retval, scale\n```","ref":"Evision.html#estimateAffine3D/3"},{"type":"function","title":"Evision.estimateAffinePartial2D/1","doc":"","ref":"Evision.html#estimateAffinePartial2D/1"},{"type":"function","title":"Evision.estimateAffinePartial2D/2","doc":"Computes an optimal limited affine transformation with 4 degrees of freedom between\ntwo 2D point sets.\n\n##### Positional Arguments\n- **from**: `Evision.Mat`.\n\n  First input 2D point set.\n\n- **to**: `Evision.Mat`.\n\n  Second input 2D point set.\n\n##### Keyword Arguments\n- **method**: `integer()`.\n\n  Robust method used to compute transformation. The following methods are possible:\n  - @ref RANSAC - RANSAC-based robust method\n  - @ref LMEDS - Least-Median robust method\n    RANSAC is the default method.\n\n- **ransacReprojThreshold**: `double`.\n\n  Maximum reprojection error in the RANSAC algorithm to consider\n  a point as an inlier. Applies only to RANSAC.\n\n- **maxIters**: `size_t`.\n\n  The maximum number of robust method iterations.\n\n- **confidence**: `double`.\n\n  Confidence level, between 0 and 1, for the estimated transformation. Anything\n  between 0.95 and 0.99 is usually good enough. Values too close to 1 can slow down the estimation\n  significantly. Values lower than 0.8-0.9 can result in an incorrectly estimated transformation.\n\n- **refineIters**: `size_t`.\n\n  Maximum number of iterations of refining algorithm (Levenberg-Marquardt).\n  Passing 0 will disable refining, so the output matrix will be output of robust method.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **inliers**: `Evision.Mat.t()`.\n\n  Output vector indicating which points are inliers.\n\n@return Output 2D affine transformation (4 degrees of freedom) matrix \\f$2 \\times 3\\f$ or\nempty matrix if transformation could not be estimated.\nThe function estimates an optimal 2D affine transformation with 4 degrees of freedom limited to\ncombinations of translation, rotation, and uniform scaling. Uses the selected algorithm for robust\nestimation.\nThe computed transformation is then refined further (using only inliers) with the\nLevenberg-Marquardt method to reduce the re-projection error even more.\nEstimated transformation matrix is:\n\\f[ \\begin{bmatrix} \\cos(\\theta) \\cdot s & -\\sin(\\theta) \\cdot s & t\\_x \\\\\\\\\n\\sin(\\theta) \\cdot s & \\cos(\\theta) \\cdot s & t\\_y\n\\end{bmatrix} \\f]\nWhere \\f$ \\theta \\f$ is the rotation angle, \\f$ s \\f$ the scaling factor and \\f$ t\\_x, t\\_y \\f$ are\ntranslations in \\f$ x, y \\f$ axes respectively.\n**Note**: \nThe RANSAC method can handle practically any ratio of outliers but need a threshold to\ndistinguish inliers from outliers. The method LMeDS does not need any threshold but it works\ncorrectly only when there are more than 50% of inliers.\n@sa estimateAffine2D, getAffineTransform\n\nPython prototype (for reference only):\n```python3\nestimateAffinePartial2D(from, to[, inliers[, method[, ransacReprojThreshold[, maxIters[, confidence[, refineIters]]]]]]) -> retval, inliers\n```","ref":"Evision.html#estimateAffinePartial2D/2"},{"type":"function","title":"Evision.estimateAffinePartial2D/3","doc":"Computes an optimal limited affine transformation with 4 degrees of freedom between\ntwo 2D point sets.\n\n##### Positional Arguments\n- **from**: `Evision.Mat`.\n\n  First input 2D point set.\n\n- **to**: `Evision.Mat`.\n\n  Second input 2D point set.\n\n##### Keyword Arguments\n- **method**: `integer()`.\n\n  Robust method used to compute transformation. The following methods are possible:\n  - @ref RANSAC - RANSAC-based robust method\n  - @ref LMEDS - Least-Median robust method\n    RANSAC is the default method.\n\n- **ransacReprojThreshold**: `double`.\n\n  Maximum reprojection error in the RANSAC algorithm to consider\n  a point as an inlier. Applies only to RANSAC.\n\n- **maxIters**: `size_t`.\n\n  The maximum number of robust method iterations.\n\n- **confidence**: `double`.\n\n  Confidence level, between 0 and 1, for the estimated transformation. Anything\n  between 0.95 and 0.99 is usually good enough. Values too close to 1 can slow down the estimation\n  significantly. Values lower than 0.8-0.9 can result in an incorrectly estimated transformation.\n\n- **refineIters**: `size_t`.\n\n  Maximum number of iterations of refining algorithm (Levenberg-Marquardt).\n  Passing 0 will disable refining, so the output matrix will be output of robust method.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **inliers**: `Evision.Mat.t()`.\n\n  Output vector indicating which points are inliers.\n\n@return Output 2D affine transformation (4 degrees of freedom) matrix \\f$2 \\times 3\\f$ or\nempty matrix if transformation could not be estimated.\nThe function estimates an optimal 2D affine transformation with 4 degrees of freedom limited to\ncombinations of translation, rotation, and uniform scaling. Uses the selected algorithm for robust\nestimation.\nThe computed transformation is then refined further (using only inliers) with the\nLevenberg-Marquardt method to reduce the re-projection error even more.\nEstimated transformation matrix is:\n\\f[ \\begin{bmatrix} \\cos(\\theta) \\cdot s & -\\sin(\\theta) \\cdot s & t\\_x \\\\\\\\\n\\sin(\\theta) \\cdot s & \\cos(\\theta) \\cdot s & t\\_y\n\\end{bmatrix} \\f]\nWhere \\f$ \\theta \\f$ is the rotation angle, \\f$ s \\f$ the scaling factor and \\f$ t\\_x, t\\_y \\f$ are\ntranslations in \\f$ x, y \\f$ axes respectively.\n**Note**: \nThe RANSAC method can handle practically any ratio of outliers but need a threshold to\ndistinguish inliers from outliers. The method LMeDS does not need any threshold but it works\ncorrectly only when there are more than 50% of inliers.\n@sa estimateAffine2D, getAffineTransform\n\nPython prototype (for reference only):\n```python3\nestimateAffinePartial2D(from, to[, inliers[, method[, ransacReprojThreshold[, maxIters[, confidence[, refineIters]]]]]]) -> retval, inliers\n```","ref":"Evision.html#estimateAffinePartial2D/3"},{"type":"function","title":"Evision.estimateChessboardSharpness/1","doc":"","ref":"Evision.html#estimateChessboardSharpness/1"},{"type":"function","title":"Evision.estimateChessboardSharpness/3","doc":"Estimates the sharpness of a detected chessboard.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Gray image used to find chessboard corners\n\n- **patternSize**: `Size`.\n\n  Size of a found chessboard pattern\n\n- **corners**: `Evision.Mat`.\n\n  Corners found by #findChessboardCornersSB\n\n##### Keyword Arguments\n- **rise_distance**: `float`.\n\n  Rise distance 0.8 means 10% ... 90% of the final signal strength\n\n- **vertical**: `bool`.\n\n  By default edge responses for horizontal lines are calculated\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n- **sharpness**: `Evision.Mat.t()`.\n\n  Optional output array with a sharpness value for calculated edge responses (see description)\n\nImage sharpness, as well as brightness, are a critical parameter for accuracte\ncamera calibration. For accessing these parameters for filtering out\nproblematic calibraiton images, this method calculates edge profiles by traveling from\nblack to white chessboard cell centers. Based on this, the number of pixels is\ncalculated required to transit from black to white. This width of the\ntransition area is a good indication of how sharp the chessboard is imaged\nand should be below ~3.0 pixels.\n\nThe optional sharpness array is of type CV_32FC1 and has for each calculated\nprofile one row with the following five entries:\n 0 = x coordinate of the underlying edge in the image\n 1 = y coordinate of the underlying edge in the image\n 2 = width of the transition area (sharpness)\n 3 = signal strength in the black cell (min brightness)\n 4 = signal strength in the white cell (max brightness)\n@return Scalar(average sharpness, average min brightness, average max brightness,0)\n\nPython prototype (for reference only):\n```python3\nestimateChessboardSharpness(image, patternSize, corners[, rise_distance[, vertical[, sharpness]]]) -> retval, sharpness\n```","ref":"Evision.html#estimateChessboardSharpness/3"},{"type":"function","title":"Evision.estimateChessboardSharpness/4","doc":"Estimates the sharpness of a detected chessboard.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Gray image used to find chessboard corners\n\n- **patternSize**: `Size`.\n\n  Size of a found chessboard pattern\n\n- **corners**: `Evision.Mat`.\n\n  Corners found by #findChessboardCornersSB\n\n##### Keyword Arguments\n- **rise_distance**: `float`.\n\n  Rise distance 0.8 means 10% ... 90% of the final signal strength\n\n- **vertical**: `bool`.\n\n  By default edge responses for horizontal lines are calculated\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n- **sharpness**: `Evision.Mat.t()`.\n\n  Optional output array with a sharpness value for calculated edge responses (see description)\n\nImage sharpness, as well as brightness, are a critical parameter for accuracte\ncamera calibration. For accessing these parameters for filtering out\nproblematic calibraiton images, this method calculates edge profiles by traveling from\nblack to white chessboard cell centers. Based on this, the number of pixels is\ncalculated required to transit from black to white. This width of the\ntransition area is a good indication of how sharp the chessboard is imaged\nand should be below ~3.0 pixels.\n\nThe optional sharpness array is of type CV_32FC1 and has for each calculated\nprofile one row with the following five entries:\n 0 = x coordinate of the underlying edge in the image\n 1 = y coordinate of the underlying edge in the image\n 2 = width of the transition area (sharpness)\n 3 = signal strength in the black cell (min brightness)\n 4 = signal strength in the white cell (max brightness)\n@return Scalar(average sharpness, average min brightness, average max brightness,0)\n\nPython prototype (for reference only):\n```python3\nestimateChessboardSharpness(image, patternSize, corners[, rise_distance[, vertical[, sharpness]]]) -> retval, sharpness\n```","ref":"Evision.html#estimateChessboardSharpness/4"},{"type":"function","title":"Evision.estimateTranslation3D/1","doc":"","ref":"Evision.html#estimateTranslation3D/1"},{"type":"function","title":"Evision.estimateTranslation3D/2","doc":"Computes an optimal translation between two 3D point sets.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  First input 3D point set containing \\f$(X,Y,Z)\\f$.\n\n- **dst**: `Evision.Mat`.\n\n  Second input 3D point set containing \\f$(x,y,z)\\f$.\n\n##### Keyword Arguments\n- **ransacThreshold**: `double`.\n\n  Maximum reprojection error in the RANSAC algorithm to consider a point as\n  an inlier.\n\n- **confidence**: `double`.\n\n  Confidence level, between 0 and 1, for the estimated transformation. Anything\n  between 0.95 and 0.99 is usually good enough. Values too close to 1 can slow down the estimation\n  significantly. Values lower than 0.8-0.9 can result in an incorrectly estimated transformation.\n\n##### Return\n- **retval**: `integer()`\n- **out**: `Evision.Mat.t()`.\n\n  Output 3D translation vector \\f$3 \\times 1\\f$ of the form\n  \\f[\n  \\begin{bmatrix}\n  b_1 \\\\\\\\\n  b_2 \\\\\\\\\n  b_3 \\\\\\\\\n  \\end{bmatrix}\n  \\f]\n\n- **inliers**: `Evision.Mat.t()`.\n\n  Output vector indicating which points are inliers (1-inlier, 0-outlier).\n\n It computes\n \\f[\n \\begin{bmatrix}\n x\\\\\\\\\n y\\\\\\\\\n z\\\\\\\\\n \\end{bmatrix}\n \\begin{bmatrix}\n X\\\\\\\\\n Y\\\\\\\\\n Z\\\\\\\\\n \\end{bmatrix}\n +\n \\begin{bmatrix}\n b\\_1\\\\\\\\\n b\\_2\\\\\\\\\n b\\_3\\\\\\\\\n \\end{bmatrix}\n \\f]\n\n The function estimates an optimal 3D translation between two 3D point sets using the\n RANSAC algorithm.\n\nPython prototype (for reference only):\n```python3\nestimateTranslation3D(src, dst[, out[, inliers[, ransacThreshold[, confidence]]]]) -> retval, out, inliers\n```","ref":"Evision.html#estimateTranslation3D/2"},{"type":"function","title":"Evision.estimateTranslation3D/3","doc":"Computes an optimal translation between two 3D point sets.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  First input 3D point set containing \\f$(X,Y,Z)\\f$.\n\n- **dst**: `Evision.Mat`.\n\n  Second input 3D point set containing \\f$(x,y,z)\\f$.\n\n##### Keyword Arguments\n- **ransacThreshold**: `double`.\n\n  Maximum reprojection error in the RANSAC algorithm to consider a point as\n  an inlier.\n\n- **confidence**: `double`.\n\n  Confidence level, between 0 and 1, for the estimated transformation. Anything\n  between 0.95 and 0.99 is usually good enough. Values too close to 1 can slow down the estimation\n  significantly. Values lower than 0.8-0.9 can result in an incorrectly estimated transformation.\n\n##### Return\n- **retval**: `integer()`\n- **out**: `Evision.Mat.t()`.\n\n  Output 3D translation vector \\f$3 \\times 1\\f$ of the form\n  \\f[\n  \\begin{bmatrix}\n  b_1 \\\\\\\\\n  b_2 \\\\\\\\\n  b_3 \\\\\\\\\n  \\end{bmatrix}\n  \\f]\n\n- **inliers**: `Evision.Mat.t()`.\n\n  Output vector indicating which points are inliers (1-inlier, 0-outlier).\n\n It computes\n \\f[\n \\begin{bmatrix}\n x\\\\\\\\\n y\\\\\\\\\n z\\\\\\\\\n \\end{bmatrix}\n \\begin{bmatrix}\n X\\\\\\\\\n Y\\\\\\\\\n Z\\\\\\\\\n \\end{bmatrix}\n +\n \\begin{bmatrix}\n b\\_1\\\\\\\\\n b\\_2\\\\\\\\\n b\\_3\\\\\\\\\n \\end{bmatrix}\n \\f]\n\n The function estimates an optimal 3D translation between two 3D point sets using the\n RANSAC algorithm.\n\nPython prototype (for reference only):\n```python3\nestimateTranslation3D(src, dst[, out[, inliers[, ransacThreshold[, confidence]]]]) -> retval, out, inliers\n```","ref":"Evision.html#estimateTranslation3D/3"},{"type":"function","title":"Evision.exp/1","doc":"Calculates the exponent of every array element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src.\n\nThe function cv::exp calculates the exponent of every element of the input\narray:\n\\f[\\texttt{dst} \\[I] = e^{ src(I) }\\f]\nThe maximum relative error is about 7e-6 for single-precision input and\nless than 1e-10 for double-precision input. Currently, the function\nconverts denormalized values to zeros on output. Special values (NaN,\nInf) are not handled.\n@sa log, cartToPolar, polarToCart, phase, pow, sqrt, magnitude\n\nPython prototype (for reference only):\n```python3\nexp(src[, dst]) -> dst\n```","ref":"Evision.html#exp/1"},{"type":"function","title":"Evision.exp/2","doc":"Calculates the exponent of every array element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src.\n\nThe function cv::exp calculates the exponent of every element of the input\narray:\n\\f[\\texttt{dst} \\[I] = e^{ src(I) }\\f]\nThe maximum relative error is about 7e-6 for single-precision input and\nless than 1e-10 for double-precision input. Currently, the function\nconverts denormalized values to zeros on output. Special values (NaN,\nInf) are not handled.\n@sa log, cartToPolar, polarToCart, phase, pow, sqrt, magnitude\n\nPython prototype (for reference only):\n```python3\nexp(src[, dst]) -> dst\n```","ref":"Evision.html#exp/2"},{"type":"function","title":"Evision.extractChannel/1","doc":"","ref":"Evision.html#extractChannel/1"},{"type":"function","title":"Evision.extractChannel/2","doc":"Extracts a single channel from src (coi is 0-based index)\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array\n\n- **coi**: `integer()`.\n\n  index of channel to extract\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array\n\n@sa mixChannels, split\n\nPython prototype (for reference only):\n```python3\nextractChannel(src, coi[, dst]) -> dst\n```","ref":"Evision.html#extractChannel/2"},{"type":"function","title":"Evision.extractChannel/3","doc":"Extracts a single channel from src (coi is 0-based index)\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array\n\n- **coi**: `integer()`.\n\n  index of channel to extract\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array\n\n@sa mixChannels, split\n\nPython prototype (for reference only):\n```python3\nextractChannel(src, coi[, dst]) -> dst\n```","ref":"Evision.html#extractChannel/3"},{"type":"function","title":"Evision.fastAtan2/1","doc":"","ref":"Evision.html#fastAtan2/1"},{"type":"function","title":"Evision.fastAtan2/2","doc":"Calculates the angle of a 2D vector in degrees.\n\n##### Positional Arguments\n- **y**: `float`.\n\n  y-coordinate of the vector.\n\n- **x**: `float`.\n\n  x-coordinate of the vector.\n\n##### Return\n- **retval**: `float`\n\nThe function fastAtan2 calculates the full-range angle of an input 2D vector. The angle is measured\nin degrees and varies from 0 to 360 degrees. The accuracy is about 0.3 degrees.\n\nPython prototype (for reference only):\n```python3\nfastAtan2(y, x) -> retval\n```","ref":"Evision.html#fastAtan2/2"},{"type":"function","title":"Evision.fastNlMeansDenoising/1","doc":"Perform image denoising using Non-local Means Denoising algorithm\n  with several computational\noptimizations. Noise expected to be a gaussian white noise\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit 1-channel, 2-channel, 3-channel or 4-channel image.\n\n##### Keyword Arguments\n- **h**: `float`.\n\n  Parameter regulating filter strength. Big h value perfectly removes noise but also\n  removes image details, smaller h value preserves details but also preserves some noise\n\n- **templateWindowSize**: `integer()`.\n\n  Size in pixels of the template patch that is used to compute weights.\n  Should be odd. Recommended value 7 pixels\n\n- **searchWindowSize**: `integer()`.\n\n  Size in pixels of the window that is used to compute weighted average for\n  given pixel. Should be odd. Affect performance linearly: greater searchWindowsSize - greater\n  denoising time. Recommended value 21 pixels\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as src .\n\nThis function expected to be applied to grayscale images. For colored images look at\nfastNlMeansDenoisingColored. Advanced usage of this functions can be manual denoising of colored\nimage in different colorspaces. Such approach is used in fastNlMeansDenoisingColored by converting\nimage to CIELAB colorspace and then separately denoise L and AB components with different h\nparameter.\n\nPython prototype (for reference only):\n```python3\nfastNlMeansDenoising(src[, dst[, h[, templateWindowSize[, searchWindowSize]]]]) -> dst\n```","ref":"Evision.html#fastNlMeansDenoising/1"},{"type":"function","title":"Evision.fastNlMeansDenoising/2","doc":"#### Variant 1:\nPerform image denoising using Non-local Means Denoising algorithm\n  with several computational\noptimizations. Noise expected to be a gaussian white noise\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit or 16-bit (only with NORM_L1) 1-channel,\n  2-channel, 3-channel or 4-channel image.\n\n- **h**: `[float]`.\n\n  Array of parameters regulating filter strength, either one\n  parameter applied to all channels or one per channel in dst. Big h value\n  perfectly removes noise but also removes image details, smaller h\n  value preserves details but also preserves some noise\n\n##### Keyword Arguments\n- **templateWindowSize**: `integer()`.\n\n  Size in pixels of the template patch that is used to compute weights.\n  Should be odd. Recommended value 7 pixels\n\n- **searchWindowSize**: `integer()`.\n\n  Size in pixels of the window that is used to compute weighted average for\n  given pixel. Should be odd. Affect performance linearly: greater searchWindowsSize - greater\n  denoising time. Recommended value 21 pixels\n\n- **normType**: `integer()`.\n\n  Type of norm used for weight calculation. Can be either NORM_L2 or NORM_L1\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as src .\n\nThis function expected to be applied to grayscale images. For colored images look at\nfastNlMeansDenoisingColored. Advanced usage of this functions can be manual denoising of colored\nimage in different colorspaces. Such approach is used in fastNlMeansDenoisingColored by converting\nimage to CIELAB colorspace and then separately denoise L and AB components with different h\nparameter.\n\nPython prototype (for reference only):\n```python3\nfastNlMeansDenoising(src, h[, dst[, templateWindowSize[, searchWindowSize[, normType]]]]) -> dst\n```\n#### Variant 2:\nPerform image denoising using Non-local Means Denoising algorithm\n  with several computational\noptimizations. Noise expected to be a gaussian white noise\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit 1-channel, 2-channel, 3-channel or 4-channel image.\n\n##### Keyword Arguments\n- **h**: `float`.\n\n  Parameter regulating filter strength. Big h value perfectly removes noise but also\n  removes image details, smaller h value preserves details but also preserves some noise\n\n- **templateWindowSize**: `integer()`.\n\n  Size in pixels of the template patch that is used to compute weights.\n  Should be odd. Recommended value 7 pixels\n\n- **searchWindowSize**: `integer()`.\n\n  Size in pixels of the window that is used to compute weighted average for\n  given pixel. Should be odd. Affect performance linearly: greater searchWindowsSize - greater\n  denoising time. Recommended value 21 pixels\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as src .\n\nThis function expected to be applied to grayscale images. For colored images look at\nfastNlMeansDenoisingColored. Advanced usage of this functions can be manual denoising of colored\nimage in different colorspaces. Such approach is used in fastNlMeansDenoisingColored by converting\nimage to CIELAB colorspace and then separately denoise L and AB components with different h\nparameter.\n\nPython prototype (for reference only):\n```python3\nfastNlMeansDenoising(src[, dst[, h[, templateWindowSize[, searchWindowSize]]]]) -> dst\n```","ref":"Evision.html#fastNlMeansDenoising/2"},{"type":"function","title":"Evision.fastNlMeansDenoising/3","doc":"Perform image denoising using Non-local Means Denoising algorithm\n  with several computational\noptimizations. Noise expected to be a gaussian white noise\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit or 16-bit (only with NORM_L1) 1-channel,\n  2-channel, 3-channel or 4-channel image.\n\n- **h**: `[float]`.\n\n  Array of parameters regulating filter strength, either one\n  parameter applied to all channels or one per channel in dst. Big h value\n  perfectly removes noise but also removes image details, smaller h\n  value preserves details but also preserves some noise\n\n##### Keyword Arguments\n- **templateWindowSize**: `integer()`.\n\n  Size in pixels of the template patch that is used to compute weights.\n  Should be odd. Recommended value 7 pixels\n\n- **searchWindowSize**: `integer()`.\n\n  Size in pixels of the window that is used to compute weighted average for\n  given pixel. Should be odd. Affect performance linearly: greater searchWindowsSize - greater\n  denoising time. Recommended value 21 pixels\n\n- **normType**: `integer()`.\n\n  Type of norm used for weight calculation. Can be either NORM_L2 or NORM_L1\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as src .\n\nThis function expected to be applied to grayscale images. For colored images look at\nfastNlMeansDenoisingColored. Advanced usage of this functions can be manual denoising of colored\nimage in different colorspaces. Such approach is used in fastNlMeansDenoisingColored by converting\nimage to CIELAB colorspace and then separately denoise L and AB components with different h\nparameter.\n\nPython prototype (for reference only):\n```python3\nfastNlMeansDenoising(src, h[, dst[, templateWindowSize[, searchWindowSize[, normType]]]]) -> dst\n```","ref":"Evision.html#fastNlMeansDenoising/3"},{"type":"function","title":"Evision.fastNlMeansDenoisingColored/1","doc":"Modification of fastNlMeansDenoising function for colored images\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n##### Keyword Arguments\n- **h**: `float`.\n\n  Parameter regulating filter strength for luminance component. Bigger h value perfectly\n  removes noise but also removes image details, smaller h value preserves details but also preserves\n  some noise\n\n- **hColor**: `float`.\n\n  The same as h but for color components. For most images value equals 10\n  will be enough to remove colored noise and do not distort colors\n\n- **templateWindowSize**: `integer()`.\n\n  Size in pixels of the template patch that is used to compute weights.\n  Should be odd. Recommended value 7 pixels\n\n- **searchWindowSize**: `integer()`.\n\n  Size in pixels of the window that is used to compute weighted average for\n  given pixel. Should be odd. Affect performance linearly: greater searchWindowsSize - greater\n  denoising time. Recommended value 21 pixels\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as src .\n\nThe function converts image to CIELAB colorspace and then separately denoise L and AB components\nwith given h parameters using fastNlMeansDenoising function.\n\nPython prototype (for reference only):\n```python3\nfastNlMeansDenoisingColored(src[, dst[, h[, hColor[, templateWindowSize[, searchWindowSize]]]]]) -> dst\n```","ref":"Evision.html#fastNlMeansDenoisingColored/1"},{"type":"function","title":"Evision.fastNlMeansDenoisingColored/2","doc":"Modification of fastNlMeansDenoising function for colored images\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n##### Keyword Arguments\n- **h**: `float`.\n\n  Parameter regulating filter strength for luminance component. Bigger h value perfectly\n  removes noise but also removes image details, smaller h value preserves details but also preserves\n  some noise\n\n- **hColor**: `float`.\n\n  The same as h but for color components. For most images value equals 10\n  will be enough to remove colored noise and do not distort colors\n\n- **templateWindowSize**: `integer()`.\n\n  Size in pixels of the template patch that is used to compute weights.\n  Should be odd. Recommended value 7 pixels\n\n- **searchWindowSize**: `integer()`.\n\n  Size in pixels of the window that is used to compute weighted average for\n  given pixel. Should be odd. Affect performance linearly: greater searchWindowsSize - greater\n  denoising time. Recommended value 21 pixels\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as src .\n\nThe function converts image to CIELAB colorspace and then separately denoise L and AB components\nwith given h parameters using fastNlMeansDenoising function.\n\nPython prototype (for reference only):\n```python3\nfastNlMeansDenoisingColored(src[, dst[, h[, hColor[, templateWindowSize[, searchWindowSize]]]]]) -> dst\n```","ref":"Evision.html#fastNlMeansDenoisingColored/2"},{"type":"function","title":"Evision.fastNlMeansDenoisingColoredMulti/1","doc":"","ref":"Evision.html#fastNlMeansDenoisingColoredMulti/1"},{"type":"function","title":"Evision.fastNlMeansDenoisingColoredMulti/3","doc":"Modification of fastNlMeansDenoisingMulti function for colored images sequences\n\n##### Positional Arguments\n- **srcImgs**: `[Evision.Mat]`.\n\n  Input 8-bit 3-channel images sequence. All images should have the same type and\n  size.\n\n- **imgToDenoiseIndex**: `integer()`.\n\n  Target image to denoise index in srcImgs sequence\n\n- **temporalWindowSize**: `integer()`.\n\n  Number of surrounding images to use for target image denoising. Should\n  be odd. Images from imgToDenoiseIndex - temporalWindowSize / 2 to\n  imgToDenoiseIndex - temporalWindowSize / 2 from srcImgs will be used to denoise\n  srcImgs[imgToDenoiseIndex] image.\n\n##### Keyword Arguments\n- **h**: `float`.\n\n  Parameter regulating filter strength for luminance component. Bigger h value perfectly\n  removes noise but also removes image details, smaller h value preserves details but also preserves\n  some noise.\n\n- **hColor**: `float`.\n\n  The same as h but for color components.\n\n- **templateWindowSize**: `integer()`.\n\n  Size in pixels of the template patch that is used to compute weights.\n  Should be odd. Recommended value 7 pixels\n\n- **searchWindowSize**: `integer()`.\n\n  Size in pixels of the window that is used to compute weighted average for\n  given pixel. Should be odd. Affect performance linearly: greater searchWindowsSize - greater\n  denoising time. Recommended value 21 pixels\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as srcImgs images.\n\nThe function converts images to CIELAB colorspace and then separately denoise L and AB components\nwith given h parameters using fastNlMeansDenoisingMulti function.\n\nPython prototype (for reference only):\n```python3\nfastNlMeansDenoisingColoredMulti(srcImgs, imgToDenoiseIndex, temporalWindowSize[, dst[, h[, hColor[, templateWindowSize[, searchWindowSize]]]]]) -> dst\n```","ref":"Evision.html#fastNlMeansDenoisingColoredMulti/3"},{"type":"function","title":"Evision.fastNlMeansDenoisingColoredMulti/4","doc":"Modification of fastNlMeansDenoisingMulti function for colored images sequences\n\n##### Positional Arguments\n- **srcImgs**: `[Evision.Mat]`.\n\n  Input 8-bit 3-channel images sequence. All images should have the same type and\n  size.\n\n- **imgToDenoiseIndex**: `integer()`.\n\n  Target image to denoise index in srcImgs sequence\n\n- **temporalWindowSize**: `integer()`.\n\n  Number of surrounding images to use for target image denoising. Should\n  be odd. Images from imgToDenoiseIndex - temporalWindowSize / 2 to\n  imgToDenoiseIndex - temporalWindowSize / 2 from srcImgs will be used to denoise\n  srcImgs[imgToDenoiseIndex] image.\n\n##### Keyword Arguments\n- **h**: `float`.\n\n  Parameter regulating filter strength for luminance component. Bigger h value perfectly\n  removes noise but also removes image details, smaller h value preserves details but also preserves\n  some noise.\n\n- **hColor**: `float`.\n\n  The same as h but for color components.\n\n- **templateWindowSize**: `integer()`.\n\n  Size in pixels of the template patch that is used to compute weights.\n  Should be odd. Recommended value 7 pixels\n\n- **searchWindowSize**: `integer()`.\n\n  Size in pixels of the window that is used to compute weighted average for\n  given pixel. Should be odd. Affect performance linearly: greater searchWindowsSize - greater\n  denoising time. Recommended value 21 pixels\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as srcImgs images.\n\nThe function converts images to CIELAB colorspace and then separately denoise L and AB components\nwith given h parameters using fastNlMeansDenoisingMulti function.\n\nPython prototype (for reference only):\n```python3\nfastNlMeansDenoisingColoredMulti(srcImgs, imgToDenoiseIndex, temporalWindowSize[, dst[, h[, hColor[, templateWindowSize[, searchWindowSize]]]]]) -> dst\n```","ref":"Evision.html#fastNlMeansDenoisingColoredMulti/4"},{"type":"function","title":"Evision.fastNlMeansDenoisingMulti/1","doc":"","ref":"Evision.html#fastNlMeansDenoisingMulti/1"},{"type":"function","title":"Evision.fastNlMeansDenoisingMulti/3","doc":"Modification of fastNlMeansDenoising function for images sequence where consecutive images have been\ncaptured in small period of time. For example video. This version of the function is for grayscale\nimages or for manual manipulation with colorspaces. See @cite Buades2005DenoisingIS for more details\n(open access [here](https://static.aminer.org/pdf/PDF/000/317/196/spatio_temporal_wiener_filtering_of_image_sequences_using_a_parametric.pdf)).\n\n##### Positional Arguments\n- **srcImgs**: `[Evision.Mat]`.\n\n  Input 8-bit 1-channel, 2-channel, 3-channel or\n  4-channel images sequence. All images should have the same type and\n  size.\n\n- **imgToDenoiseIndex**: `integer()`.\n\n  Target image to denoise index in srcImgs sequence\n\n- **temporalWindowSize**: `integer()`.\n\n  Number of surrounding images to use for target image denoising. Should\n  be odd. Images from imgToDenoiseIndex - temporalWindowSize / 2 to\n  imgToDenoiseIndex - temporalWindowSize / 2 from srcImgs will be used to denoise\n  srcImgs[imgToDenoiseIndex] image.\n\n##### Keyword Arguments\n- **h**: `float`.\n\n  Parameter regulating filter strength. Bigger h value\n  perfectly removes noise but also removes image details, smaller h\n  value preserves details but also preserves some noise\n\n- **templateWindowSize**: `integer()`.\n\n  Size in pixels of the template patch that is used to compute weights.\n  Should be odd. Recommended value 7 pixels\n\n- **searchWindowSize**: `integer()`.\n\n  Size in pixels of the window that is used to compute weighted average for\n  given pixel. Should be odd. Affect performance linearly: greater searchWindowsSize - greater\n  denoising time. Recommended value 21 pixels\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as srcImgs images.\n\nPython prototype (for reference only):\n```python3\nfastNlMeansDenoisingMulti(srcImgs, imgToDenoiseIndex, temporalWindowSize[, dst[, h[, templateWindowSize[, searchWindowSize]]]]) -> dst\n```","ref":"Evision.html#fastNlMeansDenoisingMulti/3"},{"type":"function","title":"Evision.fastNlMeansDenoisingMulti/4","doc":"#### Variant 1:\nModification of fastNlMeansDenoising function for images sequence where consecutive images have been\ncaptured in small period of time. For example video. This version of the function is for grayscale\nimages or for manual manipulation with colorspaces. See @cite Buades2005DenoisingIS for more details\n(open access [here](https://static.aminer.org/pdf/PDF/000/317/196/spatio_temporal_wiener_filtering_of_image_sequences_using_a_parametric.pdf)).\n\n##### Positional Arguments\n- **srcImgs**: `[Evision.Mat]`.\n\n  Input 8-bit or 16-bit (only with NORM_L1) 1-channel,\n  2-channel, 3-channel or 4-channel images sequence. All images should\n  have the same type and size.\n\n- **imgToDenoiseIndex**: `integer()`.\n\n  Target image to denoise index in srcImgs sequence\n\n- **temporalWindowSize**: `integer()`.\n\n  Number of surrounding images to use for target image denoising. Should\n  be odd. Images from imgToDenoiseIndex - temporalWindowSize / 2 to\n  imgToDenoiseIndex - temporalWindowSize / 2 from srcImgs will be used to denoise\n  srcImgs[imgToDenoiseIndex] image.\n\n- **h**: `[float]`.\n\n  Array of parameters regulating filter strength, either one\n  parameter applied to all channels or one per channel in dst. Big h value\n  perfectly removes noise but also removes image details, smaller h\n  value preserves details but also preserves some noise\n\n##### Keyword Arguments\n- **templateWindowSize**: `integer()`.\n\n  Size in pixels of the template patch that is used to compute weights.\n  Should be odd. Recommended value 7 pixels\n\n- **searchWindowSize**: `integer()`.\n\n  Size in pixels of the window that is used to compute weighted average for\n  given pixel. Should be odd. Affect performance linearly: greater searchWindowsSize - greater\n  denoising time. Recommended value 21 pixels\n\n- **normType**: `integer()`.\n\n  Type of norm used for weight calculation. Can be either NORM_L2 or NORM_L1\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as srcImgs images.\n\nPython prototype (for reference only):\n```python3\nfastNlMeansDenoisingMulti(srcImgs, imgToDenoiseIndex, temporalWindowSize, h[, dst[, templateWindowSize[, searchWindowSize[, normType]]]]) -> dst\n```\n#### Variant 2:\nModification of fastNlMeansDenoising function for images sequence where consecutive images have been\ncaptured in small period of time. For example video. This version of the function is for grayscale\nimages or for manual manipulation with colorspaces. See @cite Buades2005DenoisingIS for more details\n(open access [here](https://static.aminer.org/pdf/PDF/000/317/196/spatio_temporal_wiener_filtering_of_image_sequences_using_a_parametric.pdf)).\n\n##### Positional Arguments\n- **srcImgs**: `[Evision.Mat]`.\n\n  Input 8-bit 1-channel, 2-channel, 3-channel or\n  4-channel images sequence. All images should have the same type and\n  size.\n\n- **imgToDenoiseIndex**: `integer()`.\n\n  Target image to denoise index in srcImgs sequence\n\n- **temporalWindowSize**: `integer()`.\n\n  Number of surrounding images to use for target image denoising. Should\n  be odd. Images from imgToDenoiseIndex - temporalWindowSize / 2 to\n  imgToDenoiseIndex - temporalWindowSize / 2 from srcImgs will be used to denoise\n  srcImgs[imgToDenoiseIndex] image.\n\n##### Keyword Arguments\n- **h**: `float`.\n\n  Parameter regulating filter strength. Bigger h value\n  perfectly removes noise but also removes image details, smaller h\n  value preserves details but also preserves some noise\n\n- **templateWindowSize**: `integer()`.\n\n  Size in pixels of the template patch that is used to compute weights.\n  Should be odd. Recommended value 7 pixels\n\n- **searchWindowSize**: `integer()`.\n\n  Size in pixels of the window that is used to compute weighted average for\n  given pixel. Should be odd. Affect performance linearly: greater searchWindowsSize - greater\n  denoising time. Recommended value 21 pixels\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as srcImgs images.\n\nPython prototype (for reference only):\n```python3\nfastNlMeansDenoisingMulti(srcImgs, imgToDenoiseIndex, temporalWindowSize[, dst[, h[, templateWindowSize[, searchWindowSize]]]]) -> dst\n```","ref":"Evision.html#fastNlMeansDenoisingMulti/4"},{"type":"function","title":"Evision.fastNlMeansDenoisingMulti/5","doc":"Modification of fastNlMeansDenoising function for images sequence where consecutive images have been\ncaptured in small period of time. For example video. This version of the function is for grayscale\nimages or for manual manipulation with colorspaces. See @cite Buades2005DenoisingIS for more details\n(open access [here](https://static.aminer.org/pdf/PDF/000/317/196/spatio_temporal_wiener_filtering_of_image_sequences_using_a_parametric.pdf)).\n\n##### Positional Arguments\n- **srcImgs**: `[Evision.Mat]`.\n\n  Input 8-bit or 16-bit (only with NORM_L1) 1-channel,\n  2-channel, 3-channel or 4-channel images sequence. All images should\n  have the same type and size.\n\n- **imgToDenoiseIndex**: `integer()`.\n\n  Target image to denoise index in srcImgs sequence\n\n- **temporalWindowSize**: `integer()`.\n\n  Number of surrounding images to use for target image denoising. Should\n  be odd. Images from imgToDenoiseIndex - temporalWindowSize / 2 to\n  imgToDenoiseIndex - temporalWindowSize / 2 from srcImgs will be used to denoise\n  srcImgs[imgToDenoiseIndex] image.\n\n- **h**: `[float]`.\n\n  Array of parameters regulating filter strength, either one\n  parameter applied to all channels or one per channel in dst. Big h value\n  perfectly removes noise but also removes image details, smaller h\n  value preserves details but also preserves some noise\n\n##### Keyword Arguments\n- **templateWindowSize**: `integer()`.\n\n  Size in pixels of the template patch that is used to compute weights.\n  Should be odd. Recommended value 7 pixels\n\n- **searchWindowSize**: `integer()`.\n\n  Size in pixels of the window that is used to compute weighted average for\n  given pixel. Should be odd. Affect performance linearly: greater searchWindowsSize - greater\n  denoising time. Recommended value 21 pixels\n\n- **normType**: `integer()`.\n\n  Type of norm used for weight calculation. Can be either NORM_L2 or NORM_L1\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as srcImgs images.\n\nPython prototype (for reference only):\n```python3\nfastNlMeansDenoisingMulti(srcImgs, imgToDenoiseIndex, temporalWindowSize, h[, dst[, templateWindowSize[, searchWindowSize[, normType]]]]) -> dst\n```","ref":"Evision.html#fastNlMeansDenoisingMulti/5"},{"type":"function","title":"Evision.fillConvexPoly/1","doc":"","ref":"Evision.html#fillConvexPoly/1"},{"type":"function","title":"Evision.fillConvexPoly/3","doc":"Fills a convex polygon.\n\n##### Positional Arguments\n- **points**: `Evision.Mat`.\n\n  Polygon vertices.\n\n- **color**: `Evision.scalar()`.\n\n  Polygon color.\n\n##### Keyword Arguments\n- **lineType**: `integer()`.\n\n  Type of the polygon boundaries. See #LineTypes\n\n- **shift**: `integer()`.\n\n  Number of fractional bits in the vertex coordinates.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  Image.\n\nThe function cv::fillConvexPoly draws a filled convex polygon. This function is much faster than the\nfunction #fillPoly . It can fill not only convex polygons but any monotonic polygon without\nself-intersections, that is, a polygon whose contour intersects every horizontal line (scan line)\ntwice at the most (though, its top-most and/or the bottom edge could be horizontal).\n\nPython prototype (for reference only):\n```python3\nfillConvexPoly(img, points, color[, lineType[, shift]]) -> img\n```","ref":"Evision.html#fillConvexPoly/3"},{"type":"function","title":"Evision.fillConvexPoly/4","doc":"Fills a convex polygon.\n\n##### Positional Arguments\n- **points**: `Evision.Mat`.\n\n  Polygon vertices.\n\n- **color**: `Evision.scalar()`.\n\n  Polygon color.\n\n##### Keyword Arguments\n- **lineType**: `integer()`.\n\n  Type of the polygon boundaries. See #LineTypes\n\n- **shift**: `integer()`.\n\n  Number of fractional bits in the vertex coordinates.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  Image.\n\nThe function cv::fillConvexPoly draws a filled convex polygon. This function is much faster than the\nfunction #fillPoly . It can fill not only convex polygons but any monotonic polygon without\nself-intersections, that is, a polygon whose contour intersects every horizontal line (scan line)\ntwice at the most (though, its top-most and/or the bottom edge could be horizontal).\n\nPython prototype (for reference only):\n```python3\nfillConvexPoly(img, points, color[, lineType[, shift]]) -> img\n```","ref":"Evision.html#fillConvexPoly/4"},{"type":"function","title":"Evision.fillPoly/1","doc":"","ref":"Evision.html#fillPoly/1"},{"type":"function","title":"Evision.fillPoly/3","doc":"Fills the area bounded by one or more polygons.\n\n##### Positional Arguments\n- **pts**: `[Evision.Mat]`.\n\n  Array of polygons where each polygon is represented as an array of points.\n\n- **color**: `Evision.scalar()`.\n\n  Polygon color.\n\n##### Keyword Arguments\n- **lineType**: `integer()`.\n\n  Type of the polygon boundaries. See #LineTypes\n\n- **shift**: `integer()`.\n\n  Number of fractional bits in the vertex coordinates.\n\n- **offset**: `Point`.\n\n  Optional offset of all points of the contours.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  Image.\n\nThe function cv::fillPoly fills an area bounded by several polygonal contours. The function can fill\ncomplex areas, for example, areas with holes, contours with self-intersections (some of their\nparts), and so forth.\n\nPython prototype (for reference only):\n```python3\nfillPoly(img, pts, color[, lineType[, shift[, offset]]]) -> img\n```","ref":"Evision.html#fillPoly/3"},{"type":"function","title":"Evision.fillPoly/4","doc":"Fills the area bounded by one or more polygons.\n\n##### Positional Arguments\n- **pts**: `[Evision.Mat]`.\n\n  Array of polygons where each polygon is represented as an array of points.\n\n- **color**: `Evision.scalar()`.\n\n  Polygon color.\n\n##### Keyword Arguments\n- **lineType**: `integer()`.\n\n  Type of the polygon boundaries. See #LineTypes\n\n- **shift**: `integer()`.\n\n  Number of fractional bits in the vertex coordinates.\n\n- **offset**: `Point`.\n\n  Optional offset of all points of the contours.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  Image.\n\nThe function cv::fillPoly fills an area bounded by several polygonal contours. The function can fill\ncomplex areas, for example, areas with holes, contours with self-intersections (some of their\nparts), and so forth.\n\nPython prototype (for reference only):\n```python3\nfillPoly(img, pts, color[, lineType[, shift[, offset]]]) -> img\n```","ref":"Evision.html#fillPoly/4"},{"type":"function","title":"Evision.filter2D/1","doc":"","ref":"Evision.html#filter2D/1"},{"type":"function","title":"Evision.filter2D/3","doc":"Convolves an image with the kernel.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image.\n\n- **ddepth**: `integer()`.\n\n  desired depth of the destination image, see @ref filter_depths \"combinations\"\n\n- **kernel**: `Evision.Mat`.\n\n  convolution kernel (or rather a correlation kernel), a single-channel floating point\n  matrix; if you want to apply different kernels to different channels, split the image into\n  separate color planes using split and process them individually.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  anchor of the kernel that indicates the relative position of a filtered point within\n  the kernel; the anchor should lie within the kernel; default value (-1,-1) means that the anchor\n  is at the kernel center.\n\n- **delta**: `double`.\n\n  optional value added to the filtered pixels before storing them in dst.\n\n- **borderType**: `integer()`.\n\n  pixel extrapolation method, see #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and the same number of channels as src.\n\nThe function applies an arbitrary linear filter to an image. In-place operation is supported. When\nthe aperture is partially outside the image, the function interpolates outlier pixel values\naccording to the specified border mode.\nThe function does actually compute correlation, not the convolution:\n\\f[\\texttt{dst} (x,y) =  \\sum \\_{ \\substack{0\\leq x' < \\texttt{kernel.cols}\\\\\\\\\\{0\\leq y' < \\texttt{kernel.rows}}}}  \\texttt{kernel} (x',y')\\* \\texttt{src} (x+x'- \\texttt{anchor.x} ,y+y'- \\texttt{anchor.y} )\\f]\nThat is, the kernel is not mirrored around the anchor point. If you need a real convolution, flip\nthe kernel using #flip and set the new anchor to `(kernel.cols - anchor.x - 1, kernel.rows -\nanchor.y - 1)`.\nThe function uses the DFT-based algorithm in case of sufficiently large kernels (~`11 x 11` or\nlarger) and the direct algorithm for small kernels.\n@sa  sepFilter2D, dft, matchTemplate\n\nPython prototype (for reference only):\n```python3\nfilter2D(src, ddepth, kernel[, dst[, anchor[, delta[, borderType]]]]) -> dst\n```","ref":"Evision.html#filter2D/3"},{"type":"function","title":"Evision.filter2D/4","doc":"Convolves an image with the kernel.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image.\n\n- **ddepth**: `integer()`.\n\n  desired depth of the destination image, see @ref filter_depths \"combinations\"\n\n- **kernel**: `Evision.Mat`.\n\n  convolution kernel (or rather a correlation kernel), a single-channel floating point\n  matrix; if you want to apply different kernels to different channels, split the image into\n  separate color planes using split and process them individually.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  anchor of the kernel that indicates the relative position of a filtered point within\n  the kernel; the anchor should lie within the kernel; default value (-1,-1) means that the anchor\n  is at the kernel center.\n\n- **delta**: `double`.\n\n  optional value added to the filtered pixels before storing them in dst.\n\n- **borderType**: `integer()`.\n\n  pixel extrapolation method, see #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and the same number of channels as src.\n\nThe function applies an arbitrary linear filter to an image. In-place operation is supported. When\nthe aperture is partially outside the image, the function interpolates outlier pixel values\naccording to the specified border mode.\nThe function does actually compute correlation, not the convolution:\n\\f[\\texttt{dst} (x,y) =  \\sum \\_{ \\substack{0\\leq x' < \\texttt{kernel.cols}\\\\\\\\\\{0\\leq y' < \\texttt{kernel.rows}}}}  \\texttt{kernel} (x',y')\\* \\texttt{src} (x+x'- \\texttt{anchor.x} ,y+y'- \\texttt{anchor.y} )\\f]\nThat is, the kernel is not mirrored around the anchor point. If you need a real convolution, flip\nthe kernel using #flip and set the new anchor to `(kernel.cols - anchor.x - 1, kernel.rows -\nanchor.y - 1)`.\nThe function uses the DFT-based algorithm in case of sufficiently large kernels (~`11 x 11` or\nlarger) and the direct algorithm for small kernels.\n@sa  sepFilter2D, dft, matchTemplate\n\nPython prototype (for reference only):\n```python3\nfilter2D(src, ddepth, kernel[, dst[, anchor[, delta[, borderType]]]]) -> dst\n```","ref":"Evision.html#filter2D/4"},{"type":"function","title":"Evision.filterHomographyDecompByVisibleRefpoints/1","doc":"","ref":"Evision.html#filterHomographyDecompByVisibleRefpoints/1"},{"type":"function","title":"Evision.filterHomographyDecompByVisibleRefpoints/4","doc":"Filters homography decompositions based on additional information.\n\n##### Positional Arguments\n- **rotations**: `[Evision.Mat]`.\n\n  Vector of rotation matrices.\n\n- **normals**: `[Evision.Mat]`.\n\n  Vector of plane normal matrices.\n\n- **beforePoints**: `Evision.Mat`.\n\n  Vector of (rectified) visible reference points before the homography is applied\n\n- **afterPoints**: `Evision.Mat`.\n\n  Vector of (rectified) visible reference points after the homography is applied\n\n##### Keyword Arguments\n- **pointsMask**: `Evision.Mat`.\n\n  optional Mat/Vector of 8u type representing the mask for the inliers as given by the #findHomography function\n\n##### Return\n- **possibleSolutions**: `Evision.Mat.t()`.\n\n  Vector of int indices representing the viable solution set after filtering\n\nThis function is intended to filter the output of the #decomposeHomographyMat based on additional\ninformation as described in @cite Malis2007 . The summary of the method: the #decomposeHomographyMat function\nreturns 2 unique solutions and their \"opposites\" for a total of 4 solutions. If we have access to the\nsets of points visible in the camera frame before and after the homography transformation is applied,\nwe can determine which are the true potential solutions and which are the opposites by verifying which\nhomographies are consistent with all visible reference points being in front of the camera. The inputs\nare left unchanged; the filtered solution set is returned as indices into the existing one.\n\nPython prototype (for reference only):\n```python3\nfilterHomographyDecompByVisibleRefpoints(rotations, normals, beforePoints, afterPoints[, possibleSolutions[, pointsMask]]) -> possibleSolutions\n```","ref":"Evision.html#filterHomographyDecompByVisibleRefpoints/4"},{"type":"function","title":"Evision.filterHomographyDecompByVisibleRefpoints/5","doc":"Filters homography decompositions based on additional information.\n\n##### Positional Arguments\n- **rotations**: `[Evision.Mat]`.\n\n  Vector of rotation matrices.\n\n- **normals**: `[Evision.Mat]`.\n\n  Vector of plane normal matrices.\n\n- **beforePoints**: `Evision.Mat`.\n\n  Vector of (rectified) visible reference points before the homography is applied\n\n- **afterPoints**: `Evision.Mat`.\n\n  Vector of (rectified) visible reference points after the homography is applied\n\n##### Keyword Arguments\n- **pointsMask**: `Evision.Mat`.\n\n  optional Mat/Vector of 8u type representing the mask for the inliers as given by the #findHomography function\n\n##### Return\n- **possibleSolutions**: `Evision.Mat.t()`.\n\n  Vector of int indices representing the viable solution set after filtering\n\nThis function is intended to filter the output of the #decomposeHomographyMat based on additional\ninformation as described in @cite Malis2007 . The summary of the method: the #decomposeHomographyMat function\nreturns 2 unique solutions and their \"opposites\" for a total of 4 solutions. If we have access to the\nsets of points visible in the camera frame before and after the homography transformation is applied,\nwe can determine which are the true potential solutions and which are the opposites by verifying which\nhomographies are consistent with all visible reference points being in front of the camera. The inputs\nare left unchanged; the filtered solution set is returned as indices into the existing one.\n\nPython prototype (for reference only):\n```python3\nfilterHomographyDecompByVisibleRefpoints(rotations, normals, beforePoints, afterPoints[, possibleSolutions[, pointsMask]]) -> possibleSolutions\n```","ref":"Evision.html#filterHomographyDecompByVisibleRefpoints/5"},{"type":"function","title":"Evision.filterSpeckles/1","doc":"","ref":"Evision.html#filterSpeckles/1"},{"type":"function","title":"Evision.filterSpeckles/4","doc":"Filters off small noise blobs (speckles) in the disparity map\n\n##### Positional Arguments\n- **newVal**: `double`.\n\n  The disparity value used to paint-off the speckles\n\n- **maxSpeckleSize**: `integer()`.\n\n  The maximum speckle size to consider it a speckle. Larger blobs are not\n  affected by the algorithm\n\n- **maxDiff**: `double`.\n\n  Maximum difference between neighbor disparity pixels to put them into the same\n  blob. Note that since StereoBM, StereoSGBM and may be other algorithms return a fixed-point\n  disparity map, where disparity values are multiplied by 16, this scale factor should be taken into\n  account when specifying this parameter value.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  The input 16-bit signed disparity image\n\n- **buf**: `Evision.Mat.t()`.\n\n  The optional temporary buffer to avoid memory allocation within the function.\n\nPython prototype (for reference only):\n```python3\nfilterSpeckles(img, newVal, maxSpeckleSize, maxDiff[, buf]) -> img, buf\n```","ref":"Evision.html#filterSpeckles/4"},{"type":"function","title":"Evision.filterSpeckles/5","doc":"Filters off small noise blobs (speckles) in the disparity map\n\n##### Positional Arguments\n- **newVal**: `double`.\n\n  The disparity value used to paint-off the speckles\n\n- **maxSpeckleSize**: `integer()`.\n\n  The maximum speckle size to consider it a speckle. Larger blobs are not\n  affected by the algorithm\n\n- **maxDiff**: `double`.\n\n  Maximum difference between neighbor disparity pixels to put them into the same\n  blob. Note that since StereoBM, StereoSGBM and may be other algorithms return a fixed-point\n  disparity map, where disparity values are multiplied by 16, this scale factor should be taken into\n  account when specifying this parameter value.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  The input 16-bit signed disparity image\n\n- **buf**: `Evision.Mat.t()`.\n\n  The optional temporary buffer to avoid memory allocation within the function.\n\nPython prototype (for reference only):\n```python3\nfilterSpeckles(img, newVal, maxSpeckleSize, maxDiff[, buf]) -> img, buf\n```","ref":"Evision.html#filterSpeckles/5"},{"type":"function","title":"Evision.find4QuadCornerSubpix/1","doc":"","ref":"Evision.html#find4QuadCornerSubpix/1"},{"type":"function","title":"Evision.find4QuadCornerSubpix/3","doc":"find4QuadCornerSubpix\n\n##### Positional Arguments\n- **img**: `Evision.Mat`\n- **region_size**: `Size`\n\n##### Return\n- **retval**: `bool`\n- **corners**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nfind4QuadCornerSubpix(img, corners, region_size) -> retval, corners\n```","ref":"Evision.html#find4QuadCornerSubpix/3"},{"type":"function","title":"Evision.findChessboardCorners/1","doc":"","ref":"Evision.html#findChessboardCorners/1"},{"type":"function","title":"Evision.findChessboardCorners/2","doc":"Finds the positions of internal corners of the chessboard.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Source chessboard view. It must be an 8-bit grayscale or color image.\n\n- **patternSize**: `Size`.\n\n  Number of inner corners per a chessboard row and column\n  ( patternSize = cv::Size(points_per_row,points_per_colum) = cv::Size(columns,rows) ).\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Various operation flags that can be zero or a combination of the following values:\n  - @ref CALIB_CB_ADAPTIVE_THRESH Use adaptive thresholding to convert the image to black\n    and white, rather than a fixed threshold level (computed from the average image brightness).\n  - @ref CALIB_CB_NORMALIZE_IMAGE Normalize the image gamma with #equalizeHist before\n    applying fixed or adaptive thresholding.\n  - @ref CALIB_CB_FILTER_QUADS Use additional criteria (like contour area, perimeter,\n    square-like shape) to filter out false quads extracted at the contour retrieval stage.\n  - @ref CALIB_CB_FAST_CHECK Run a fast check on the image that looks for chessboard corners,\n    and shortcut the call if none is found. This can drastically speed up the call in the\n    degenerate condition when no chessboard is observed.\n  - @ref CALIB_CB_PLAIN All other flags are ignored. The input image is taken as is.\n    No image processing is done to improve to find the checkerboard. This has the effect of speeding up the\n    execution of the function but could lead to not recognizing the checkerboard if the image\n    is not previously binarized in the appropriate manner.\n\n##### Return\n- **retval**: `bool`\n- **corners**: `Evision.Mat.t()`.\n\n  Output array of detected corners.\n\nThe function attempts to determine whether the input image is a view of the chessboard pattern and\nlocate the internal chessboard corners. The function returns a non-zero value if all of the corners\nare found and they are placed in a certain order (row by row, left to right in every row).\nOtherwise, if the function fails to find all the corners or reorder them, it returns 0. For example,\na regular chessboard has 8 x 8 squares and 7 x 7 internal corners, that is, points where the black\nsquares touch each other. The detected coordinates are approximate, and to determine their positions\nmore accurately, the function calls #cornerSubPix. You also may use the function #cornerSubPix with\ndifferent parameters if returned coordinates are not accurate enough.\nSample usage of detecting and drawing chessboard corners: :\n```\nSize patternsize(8,6); //interior number of corners\nMat gray = ....; //source image\nvector  corners; //this will be filled by the detected corners\n//CALIB_CB_FAST_CHECK saves a lot of time on images\n//that do not contain any chessboard corners\nbool patternfound = findChessboardCorners(gray, patternsize, corners,\nCALIB_CB_ADAPTIVE_THRESH + CALIB_CB_NORMALIZE_IMAGE\n+ CALIB_CB_FAST_CHECK);\nif(patternfound)\ncornerSubPix(gray, corners, Size(11, 11), Size(-1, -1),\nTermCriteria(CV_TERMCRIT_EPS + CV_TERMCRIT_ITER, 30, 0.1));\ndrawChessboardCorners(img, patternsize, Mat(corners), patternfound);\n```\n**Note**: The function requires white space (like a square-thick border, the wider the better) around\nthe board to make the detection more robust in various environments. Otherwise, if there is no\nborder and the background is dark, the outer black squares cannot be segmented properly and so the\nsquare grouping and ordering algorithm fails.\nUse gen_pattern.py (@ref tutorial_camera_calibration_pattern) to create checkerboard.\n\nPython prototype (for reference only):\n```python3\nfindChessboardCorners(image, patternSize[, corners[, flags]]) -> retval, corners\n```","ref":"Evision.html#findChessboardCorners/2"},{"type":"function","title":"Evision.findChessboardCorners/3","doc":"Finds the positions of internal corners of the chessboard.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Source chessboard view. It must be an 8-bit grayscale or color image.\n\n- **patternSize**: `Size`.\n\n  Number of inner corners per a chessboard row and column\n  ( patternSize = cv::Size(points_per_row,points_per_colum) = cv::Size(columns,rows) ).\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Various operation flags that can be zero or a combination of the following values:\n  - @ref CALIB_CB_ADAPTIVE_THRESH Use adaptive thresholding to convert the image to black\n    and white, rather than a fixed threshold level (computed from the average image brightness).\n  - @ref CALIB_CB_NORMALIZE_IMAGE Normalize the image gamma with #equalizeHist before\n    applying fixed or adaptive thresholding.\n  - @ref CALIB_CB_FILTER_QUADS Use additional criteria (like contour area, perimeter,\n    square-like shape) to filter out false quads extracted at the contour retrieval stage.\n  - @ref CALIB_CB_FAST_CHECK Run a fast check on the image that looks for chessboard corners,\n    and shortcut the call if none is found. This can drastically speed up the call in the\n    degenerate condition when no chessboard is observed.\n  - @ref CALIB_CB_PLAIN All other flags are ignored. The input image is taken as is.\n    No image processing is done to improve to find the checkerboard. This has the effect of speeding up the\n    execution of the function but could lead to not recognizing the checkerboard if the image\n    is not previously binarized in the appropriate manner.\n\n##### Return\n- **retval**: `bool`\n- **corners**: `Evision.Mat.t()`.\n\n  Output array of detected corners.\n\nThe function attempts to determine whether the input image is a view of the chessboard pattern and\nlocate the internal chessboard corners. The function returns a non-zero value if all of the corners\nare found and they are placed in a certain order (row by row, left to right in every row).\nOtherwise, if the function fails to find all the corners or reorder them, it returns 0. For example,\na regular chessboard has 8 x 8 squares and 7 x 7 internal corners, that is, points where the black\nsquares touch each other. The detected coordinates are approximate, and to determine their positions\nmore accurately, the function calls #cornerSubPix. You also may use the function #cornerSubPix with\ndifferent parameters if returned coordinates are not accurate enough.\nSample usage of detecting and drawing chessboard corners: :\n```\nSize patternsize(8,6); //interior number of corners\nMat gray = ....; //source image\nvector  corners; //this will be filled by the detected corners\n//CALIB_CB_FAST_CHECK saves a lot of time on images\n//that do not contain any chessboard corners\nbool patternfound = findChessboardCorners(gray, patternsize, corners,\nCALIB_CB_ADAPTIVE_THRESH + CALIB_CB_NORMALIZE_IMAGE\n+ CALIB_CB_FAST_CHECK);\nif(patternfound)\ncornerSubPix(gray, corners, Size(11, 11), Size(-1, -1),\nTermCriteria(CV_TERMCRIT_EPS + CV_TERMCRIT_ITER, 30, 0.1));\ndrawChessboardCorners(img, patternsize, Mat(corners), patternfound);\n```\n**Note**: The function requires white space (like a square-thick border, the wider the better) around\nthe board to make the detection more robust in various environments. Otherwise, if there is no\nborder and the background is dark, the outer black squares cannot be segmented properly and so the\nsquare grouping and ordering algorithm fails.\nUse gen_pattern.py (@ref tutorial_camera_calibration_pattern) to create checkerboard.\n\nPython prototype (for reference only):\n```python3\nfindChessboardCorners(image, patternSize[, corners[, flags]]) -> retval, corners\n```","ref":"Evision.html#findChessboardCorners/3"},{"type":"function","title":"Evision.findChessboardCornersSB/1","doc":"","ref":"Evision.html#findChessboardCornersSB/1"},{"type":"function","title":"Evision.findChessboardCornersSB/2","doc":"findChessboardCornersSB\n\n##### Positional Arguments\n- **image**: `Evision.Mat`\n- **patternSize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n##### Return\n- **retval**: `bool`\n- **corners**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nfindChessboardCornersSB(image, patternSize[, corners[, flags]]) -> retval, corners\n```","ref":"Evision.html#findChessboardCornersSB/2"},{"type":"function","title":"Evision.findChessboardCornersSB/3","doc":"findChessboardCornersSB\n\n##### Positional Arguments\n- **image**: `Evision.Mat`\n- **patternSize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n##### Return\n- **retval**: `bool`\n- **corners**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nfindChessboardCornersSB(image, patternSize[, corners[, flags]]) -> retval, corners\n```","ref":"Evision.html#findChessboardCornersSB/3"},{"type":"function","title":"Evision.findChessboardCornersSBWithMeta/1","doc":"","ref":"Evision.html#findChessboardCornersSBWithMeta/1"},{"type":"function","title":"Evision.findChessboardCornersSBWithMeta/3","doc":"Finds the positions of internal corners of the chessboard using a sector based approach.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Source chessboard view. It must be an 8-bit grayscale or color image.\n\n- **patternSize**: `Size`.\n\n  Number of inner corners per a chessboard row and column\n  ( patternSize = cv::Size(points_per_row,points_per_colum) = cv::Size(columns,rows) ).\n\n- **flags**: `integer()`.\n\n  Various operation flags that can be zero or a combination of the following values:\n  - @ref CALIB_CB_NORMALIZE_IMAGE Normalize the image gamma with equalizeHist before detection.\n  - @ref CALIB_CB_EXHAUSTIVE Run an exhaustive search to improve detection rate.\n  - @ref CALIB_CB_ACCURACY Up sample input image to improve sub-pixel accuracy due to aliasing effects.\n  - @ref CALIB_CB_LARGER The detected pattern is allowed to be larger than patternSize (see description).\n  - @ref CALIB_CB_MARKER The detected pattern must have a marker (see description).\n    This should be used if an accurate camera calibration is required.\n\n##### Return\n- **retval**: `bool`\n- **corners**: `Evision.Mat.t()`.\n\n  Output array of detected corners.\n\n- **meta**: `Evision.Mat.t()`.\n\n  Optional output arrray of detected corners (CV_8UC1 and size = cv::Size(columns,rows)).\n  Each entry stands for one corner of the pattern and can have one of the following values:\n  - 0 = no meta data attached\n  - 1 = left-top corner of a black cell\n  - 2 = left-top corner of a white cell\n  - 3 = left-top corner of a black cell with a white marker dot\n  - 4 = left-top corner of a white cell with a black marker dot (pattern origin in case of markers otherwise first corner)\n\nThe function is analog to #findChessboardCorners but uses a localized radon\ntransformation approximated by box filters being more robust to all sort of\nnoise, faster on larger images and is able to directly return the sub-pixel\nposition of the internal chessboard corners. The Method is based on the paper\n@cite duda2018 \"Accurate Detection and Localization of Checkerboard Corners for\nCalibration\" demonstrating that the returned sub-pixel positions are more\naccurate than the one returned by cornerSubPix allowing a precise camera\ncalibration for demanding applications.\nIn the case, the flags @ref CALIB_CB_LARGER or @ref CALIB_CB_MARKER are given,\nthe result can be recovered from the optional meta array. Both flags are\nhelpful to use calibration patterns exceeding the field of view of the camera.\nThese oversized patterns allow more accurate calibrations as corners can be\nutilized, which are as close as possible to the image borders.  For a\nconsistent coordinate system across all images, the optional marker (see image\nbelow) can be used to move the origin of the board to the location where the\nblack circle is located.\n**Note**: The function requires a white boarder with roughly the same width as one\nof the checkerboard fields around the whole board to improve the detection in\nvarious environments. In addition, because of the localized radon\ntransformation it is beneficial to use round corners for the field corners\nwhich are located on the outside of the board. The following figure illustrates\na sample checkerboard optimized for the detection. However, any other checkerboard\ncan be used as well.\nUse gen_pattern.py (@ref tutorial_camera_calibration_pattern) to create checkerboard.\n![Checkerboard](pics/checkerboard_radon.png)\n\nPython prototype (for reference only):\n```python3\nfindChessboardCornersSBWithMeta(image, patternSize, flags[, corners[, meta]]) -> retval, corners, meta\n```","ref":"Evision.html#findChessboardCornersSBWithMeta/3"},{"type":"function","title":"Evision.findChessboardCornersSBWithMeta/4","doc":"Finds the positions of internal corners of the chessboard using a sector based approach.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Source chessboard view. It must be an 8-bit grayscale or color image.\n\n- **patternSize**: `Size`.\n\n  Number of inner corners per a chessboard row and column\n  ( patternSize = cv::Size(points_per_row,points_per_colum) = cv::Size(columns,rows) ).\n\n- **flags**: `integer()`.\n\n  Various operation flags that can be zero or a combination of the following values:\n  - @ref CALIB_CB_NORMALIZE_IMAGE Normalize the image gamma with equalizeHist before detection.\n  - @ref CALIB_CB_EXHAUSTIVE Run an exhaustive search to improve detection rate.\n  - @ref CALIB_CB_ACCURACY Up sample input image to improve sub-pixel accuracy due to aliasing effects.\n  - @ref CALIB_CB_LARGER The detected pattern is allowed to be larger than patternSize (see description).\n  - @ref CALIB_CB_MARKER The detected pattern must have a marker (see description).\n    This should be used if an accurate camera calibration is required.\n\n##### Return\n- **retval**: `bool`\n- **corners**: `Evision.Mat.t()`.\n\n  Output array of detected corners.\n\n- **meta**: `Evision.Mat.t()`.\n\n  Optional output arrray of detected corners (CV_8UC1 and size = cv::Size(columns,rows)).\n  Each entry stands for one corner of the pattern and can have one of the following values:\n  - 0 = no meta data attached\n  - 1 = left-top corner of a black cell\n  - 2 = left-top corner of a white cell\n  - 3 = left-top corner of a black cell with a white marker dot\n  - 4 = left-top corner of a white cell with a black marker dot (pattern origin in case of markers otherwise first corner)\n\nThe function is analog to #findChessboardCorners but uses a localized radon\ntransformation approximated by box filters being more robust to all sort of\nnoise, faster on larger images and is able to directly return the sub-pixel\nposition of the internal chessboard corners. The Method is based on the paper\n@cite duda2018 \"Accurate Detection and Localization of Checkerboard Corners for\nCalibration\" demonstrating that the returned sub-pixel positions are more\naccurate than the one returned by cornerSubPix allowing a precise camera\ncalibration for demanding applications.\nIn the case, the flags @ref CALIB_CB_LARGER or @ref CALIB_CB_MARKER are given,\nthe result can be recovered from the optional meta array. Both flags are\nhelpful to use calibration patterns exceeding the field of view of the camera.\nThese oversized patterns allow more accurate calibrations as corners can be\nutilized, which are as close as possible to the image borders.  For a\nconsistent coordinate system across all images, the optional marker (see image\nbelow) can be used to move the origin of the board to the location where the\nblack circle is located.\n**Note**: The function requires a white boarder with roughly the same width as one\nof the checkerboard fields around the whole board to improve the detection in\nvarious environments. In addition, because of the localized radon\ntransformation it is beneficial to use round corners for the field corners\nwhich are located on the outside of the board. The following figure illustrates\na sample checkerboard optimized for the detection. However, any other checkerboard\ncan be used as well.\nUse gen_pattern.py (@ref tutorial_camera_calibration_pattern) to create checkerboard.\n![Checkerboard](pics/checkerboard_radon.png)\n\nPython prototype (for reference only):\n```python3\nfindChessboardCornersSBWithMeta(image, patternSize, flags[, corners[, meta]]) -> retval, corners, meta\n```","ref":"Evision.html#findChessboardCornersSBWithMeta/4"},{"type":"function","title":"Evision.findCirclesGrid/1","doc":"","ref":"Evision.html#findCirclesGrid/1"},{"type":"function","title":"Evision.findCirclesGrid/2","doc":"findCirclesGrid\n\n##### Positional Arguments\n- **image**: `Evision.Mat`\n- **patternSize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **blobDetector**: `FeatureDetector`.\n\n##### Return\n- **retval**: `bool`\n- **centers**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nfindCirclesGrid(image, patternSize[, centers[, flags[, blobDetector]]]) -> retval, centers\n```","ref":"Evision.html#findCirclesGrid/2"},{"type":"function","title":"Evision.findCirclesGrid/3","doc":"findCirclesGrid\n\n##### Positional Arguments\n- **image**: `Evision.Mat`\n- **patternSize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **blobDetector**: `FeatureDetector`.\n\n##### Return\n- **retval**: `bool`\n- **centers**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nfindCirclesGrid(image, patternSize[, centers[, flags[, blobDetector]]]) -> retval, centers\n```","ref":"Evision.html#findCirclesGrid/3"},{"type":"function","title":"Evision.findCirclesGrid/5","doc":"Finds centers in the grid of circles.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  grid view of input circles; it must be an 8-bit grayscale or color image.\n\n- **patternSize**: `Size`.\n\n  number of circles per row and column\n  ( patternSize = Size(points_per_row, points_per_colum) ).\n\n- **flags**: `integer()`.\n\n  various operation flags that can be one of the following values:\n  - @ref CALIB_CB_SYMMETRIC_GRID uses symmetric pattern of circles.\n  - @ref CALIB_CB_ASYMMETRIC_GRID uses asymmetric pattern of circles.\n  - @ref CALIB_CB_CLUSTERING uses a special algorithm for grid detection. It is more robust to\n    perspective distortions but much more sensitive to background clutter.\n\n- **blobDetector**: `FeatureDetector`.\n\n  feature detector that finds blobs like dark circles on light background.\n  If `blobDetector` is NULL then `image` represents Point2f array of candidates.\n\n- **parameters**: `Evision.CirclesGridFinderParameters`.\n\n  struct for finding circles in a grid pattern.\n\n##### Return\n- **retval**: `bool`\n- **centers**: `Evision.Mat.t()`.\n\n  output array of detected centers.\n\nThe function attempts to determine whether the input image contains a grid of circles. If it is, the\nfunction locates centers of the circles. The function returns a non-zero value if all of the centers\nhave been found and they have been placed in a certain order (row by row, left to right in every\nrow). Otherwise, if the function fails to find all the corners or reorder them, it returns 0.\nSample usage of detecting and drawing the centers of circles: :\n```\nSize patternsize(7,7); //number of centers\nMat gray = ...; //source image\nvector  centers; //this will be filled by the detected centers\nbool patternfound = findCirclesGrid(gray, patternsize, centers);\ndrawChessboardCorners(img, patternsize, Mat(centers), patternfound);\n```\n**Note**: The function requires white space (like a square-thick border, the wider the better) around\nthe board to make the detection more robust in various environments.\n\nPython prototype (for reference only):\n```python3\nfindCirclesGrid(image, patternSize, flags, blobDetector, parameters[, centers]) -> retval, centers\n```","ref":"Evision.html#findCirclesGrid/5"},{"type":"function","title":"Evision.findCirclesGrid/6","doc":"Finds centers in the grid of circles.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  grid view of input circles; it must be an 8-bit grayscale or color image.\n\n- **patternSize**: `Size`.\n\n  number of circles per row and column\n  ( patternSize = Size(points_per_row, points_per_colum) ).\n\n- **flags**: `integer()`.\n\n  various operation flags that can be one of the following values:\n  - @ref CALIB_CB_SYMMETRIC_GRID uses symmetric pattern of circles.\n  - @ref CALIB_CB_ASYMMETRIC_GRID uses asymmetric pattern of circles.\n  - @ref CALIB_CB_CLUSTERING uses a special algorithm for grid detection. It is more robust to\n    perspective distortions but much more sensitive to background clutter.\n\n- **blobDetector**: `FeatureDetector`.\n\n  feature detector that finds blobs like dark circles on light background.\n  If `blobDetector` is NULL then `image` represents Point2f array of candidates.\n\n- **parameters**: `Evision.CirclesGridFinderParameters`.\n\n  struct for finding circles in a grid pattern.\n\n##### Return\n- **retval**: `bool`\n- **centers**: `Evision.Mat.t()`.\n\n  output array of detected centers.\n\nThe function attempts to determine whether the input image contains a grid of circles. If it is, the\nfunction locates centers of the circles. The function returns a non-zero value if all of the centers\nhave been found and they have been placed in a certain order (row by row, left to right in every\nrow). Otherwise, if the function fails to find all the corners or reorder them, it returns 0.\nSample usage of detecting and drawing the centers of circles: :\n```\nSize patternsize(7,7); //number of centers\nMat gray = ...; //source image\nvector  centers; //this will be filled by the detected centers\nbool patternfound = findCirclesGrid(gray, patternsize, centers);\ndrawChessboardCorners(img, patternsize, Mat(centers), patternfound);\n```\n**Note**: The function requires white space (like a square-thick border, the wider the better) around\nthe board to make the detection more robust in various environments.\n\nPython prototype (for reference only):\n```python3\nfindCirclesGrid(image, patternSize, flags, blobDetector, parameters[, centers]) -> retval, centers\n```","ref":"Evision.html#findCirclesGrid/6"},{"type":"function","title":"Evision.findContours/1","doc":"","ref":"Evision.html#findContours/1"},{"type":"function","title":"Evision.findContours/3","doc":"Finds contours in a binary image.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Source, an 8-bit single-channel image. Non-zero pixels are treated as 1's. Zero\n  pixels remain 0's, so the image is treated as binary . You can use #compare, #inRange, #threshold ,\n  #adaptiveThreshold, #Canny, and others to create a binary image out of a grayscale or color one.\n  If mode equals to #RETR_CCOMP or #RETR_FLOODFILL, the input can also be a 32-bit integer image of labels (CV_32SC1).\n\n- **mode**: `integer()`.\n\n  Contour retrieval mode, see #RetrievalModes\n\n- **method**: `integer()`.\n\n  Contour approximation method, see #ContourApproximationModes\n\n##### Keyword Arguments\n- **offset**: `Point`.\n\n  Optional offset by which every contour point is shifted. This is useful if the\n  contours are extracted from the image ROI and then they should be analyzed in the whole image\n  context.\n\n##### Return\n- **contours**: `[Evision.Mat]`.\n\n  Detected contours. Each contour is stored as a vector of points (e.g.\n  std::vector  >).\n\n- **hierarchy**: `Evision.Mat.t()`.\n\n  Optional output vector (e.g. std::vector ), containing information about the image topology. It has\n  as many elements as the number of contours. For each i-th contour contours[i], the elements\n  hierarchy[i][0] , hierarchy[i][1] , hierarchy[i][2] , and hierarchy[i][3] are set to 0-based indices\n  in contours of the next and previous contours at the same hierarchical level, the first child\n  contour and the parent contour, respectively. If for the contour i there are no next, previous,\n  parent, or nested contours, the corresponding elements of hierarchy[i] will be negative.\n\nThe function retrieves contours from the binary image using the algorithm @cite Suzuki85 . The contours\nare a useful tool for shape analysis and object detection and recognition. See squares.cpp in the\nOpenCV sample directory.\n**Note**: Since opencv 3.2 source image is not modified by this function.\n**Note**: In Python, hierarchy is nested inside a top level array. Use hierarchy[0][i] to access hierarchical elements of i-th contour.\n\nPython prototype (for reference only):\n```python3\nfindContours(image, mode, method[, contours[, hierarchy[, offset]]]) -> contours, hierarchy\n```","ref":"Evision.html#findContours/3"},{"type":"function","title":"Evision.findContours/4","doc":"Finds contours in a binary image.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Source, an 8-bit single-channel image. Non-zero pixels are treated as 1's. Zero\n  pixels remain 0's, so the image is treated as binary . You can use #compare, #inRange, #threshold ,\n  #adaptiveThreshold, #Canny, and others to create a binary image out of a grayscale or color one.\n  If mode equals to #RETR_CCOMP or #RETR_FLOODFILL, the input can also be a 32-bit integer image of labels (CV_32SC1).\n\n- **mode**: `integer()`.\n\n  Contour retrieval mode, see #RetrievalModes\n\n- **method**: `integer()`.\n\n  Contour approximation method, see #ContourApproximationModes\n\n##### Keyword Arguments\n- **offset**: `Point`.\n\n  Optional offset by which every contour point is shifted. This is useful if the\n  contours are extracted from the image ROI and then they should be analyzed in the whole image\n  context.\n\n##### Return\n- **contours**: `[Evision.Mat]`.\n\n  Detected contours. Each contour is stored as a vector of points (e.g.\n  std::vector  >).\n\n- **hierarchy**: `Evision.Mat.t()`.\n\n  Optional output vector (e.g. std::vector ), containing information about the image topology. It has\n  as many elements as the number of contours. For each i-th contour contours[i], the elements\n  hierarchy[i][0] , hierarchy[i][1] , hierarchy[i][2] , and hierarchy[i][3] are set to 0-based indices\n  in contours of the next and previous contours at the same hierarchical level, the first child\n  contour and the parent contour, respectively. If for the contour i there are no next, previous,\n  parent, or nested contours, the corresponding elements of hierarchy[i] will be negative.\n\nThe function retrieves contours from the binary image using the algorithm @cite Suzuki85 . The contours\nare a useful tool for shape analysis and object detection and recognition. See squares.cpp in the\nOpenCV sample directory.\n**Note**: Since opencv 3.2 source image is not modified by this function.\n**Note**: In Python, hierarchy is nested inside a top level array. Use hierarchy[0][i] to access hierarchical elements of i-th contour.\n\nPython prototype (for reference only):\n```python3\nfindContours(image, mode, method[, contours[, hierarchy[, offset]]]) -> contours, hierarchy\n```","ref":"Evision.html#findContours/4"},{"type":"function","title":"Evision.findContoursLinkRuns/1","doc":"findContoursLinkRuns\n\n##### Positional Arguments\n- **image**: `Evision.Mat`\n\n##### Return\n- **contours**: `[Evision.Mat]`.\n\nPython prototype (for reference only):\n```python3\nfindContoursLinkRuns(image[, contours]) -> contours\n```","ref":"Evision.html#findContoursLinkRuns/1"},{"type":"function","title":"Evision.findContoursLinkRuns/2","doc":"findContoursLinkRuns\n\n##### Positional Arguments\n- **image**: `Evision.Mat`\n\n##### Return\n- **contours**: `[Evision.Mat]`.\n\nPython prototype (for reference only):\n```python3\nfindContoursLinkRuns(image[, contours]) -> contours\n```","ref":"Evision.html#findContoursLinkRuns/2"},{"type":"function","title":"Evision.findEssentialMat/1","doc":"","ref":"Evision.html#findEssentialMat/1"},{"type":"function","title":"Evision.findEssentialMat/2","doc":"findEssentialMat\n\n##### Positional Arguments\n- **points1**: `Evision.Mat`.\n\n  Array of N (N \\>= 5) 2D points from the first image. The point coordinates should\n  be floating-point (single or double precision).\n\n- **points2**: `Evision.Mat`.\n\n  Array of the second image points of the same size and format as points1 .\n\n##### Keyword Arguments\n- **focal**: `double`.\n\n  focal length of the camera. Note that this function assumes that points1 and points2\n  are feature points from cameras with same focal length and principal point.\n\n- **pp**: `Point2d`.\n\n  principal point of the camera.\n\n- **method**: `integer()`.\n\n  Method for computing a fundamental matrix.\n  - @ref RANSAC for the RANSAC algorithm.\n  - @ref LMEDS for the LMedS algorithm.\n\n- **prob**: `double`.\n\n  Parameter used for the RANSAC or LMedS methods only. It specifies a desirable level of\n  confidence (probability) that the estimated matrix is correct.\n\n- **threshold**: `double`.\n\n  Parameter used for RANSAC. It is the maximum distance from a point to an epipolar\n  line in pixels, beyond which the point is considered an outlier and is not used for computing the\n  final fundamental matrix. It can be set to something like 1-3, depending on the accuracy of the\n  point localization, image resolution, and the image noise.\n\n- **maxIters**: `integer()`.\n\n  The maximum number of robust method iterations.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **mask**: `Evision.Mat.t()`.\n\n  Output array of N elements, every element of which is set to 0 for outliers and to 1\n  for the other points. The array is computed only in the RANSAC and LMedS methods.\n\nHas overloading in C++\n\nThis function differs from the one above that it computes camera intrinsic matrix from focal length and\nprincipal point:\n\\f[A =\n\\begin{bmatrix}\nf & 0 & x\\_{pp}  \\\\\\\\\n0 & f & y\\_{pp}  \\\\\\\\\n0 & 0 & 1\n\\end{bmatrix}\\f]\n\nPython prototype (for reference only):\n```python3\nfindEssentialMat(points1, points2[, focal[, pp[, method[, prob[, threshold[, maxIters[, mask]]]]]]]) -> retval, mask\n```","ref":"Evision.html#findEssentialMat/2"},{"type":"function","title":"Evision.findEssentialMat/3","doc":"#### Variant 1:\nCalculates an essential matrix from the corresponding points in two images.\n\n##### Positional Arguments\n- **points1**: `Evision.Mat`.\n\n  Array of N (N \\>= 5) 2D points from the first image. The point coordinates should\n  be floating-point (single or double precision).\n\n- **points2**: `Evision.Mat`.\n\n  Array of the second image points of the same size and format as points1.\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Camera intrinsic matrix \\f$\\cameramatrix{A}\\f$ .\n  Note that this function assumes that points1 and points2 are feature points from cameras with the\n  same camera intrinsic matrix. If this assumption does not hold for your use case, use another\n  function overload or #undistortPoints with `P = cv::NoArray()` for both cameras to transform image\n  points to normalized image coordinates, which are valid for the identity camera intrinsic matrix.\n  When passing these coordinates, pass the identity matrix for this parameter.\n\n##### Keyword Arguments\n- **method**: `integer()`.\n\n  Method for computing an essential matrix.\n  - @ref RANSAC for the RANSAC algorithm.\n  - @ref LMEDS for the LMedS algorithm.\n\n- **prob**: `double`.\n\n  Parameter used for the RANSAC or LMedS methods only. It specifies a desirable level of\n  confidence (probability) that the estimated matrix is correct.\n\n- **threshold**: `double`.\n\n  Parameter used for RANSAC. It is the maximum distance from a point to an epipolar\n  line in pixels, beyond which the point is considered an outlier and is not used for computing the\n  final fundamental matrix. It can be set to something like 1-3, depending on the accuracy of the\n  point localization, image resolution, and the image noise.\n\n- **maxIters**: `integer()`.\n\n  The maximum number of robust method iterations.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **mask**: `Evision.Mat.t()`.\n\n  Output array of N elements, every element of which is set to 0 for outliers and to 1\n  for the other points. The array is computed only in the RANSAC and LMedS methods.\n\nThis function estimates essential matrix based on the five-point algorithm solver in @cite Nister03 .\n@cite SteweniusCFS is also a related. The epipolar geometry is described by the following equation:\n\\f[\\[p\\_2; 1]^T K^{-T} E K^{-1} \\[p\\_1; 1] = 0\\f]\nwhere \\f$E\\f$ is an essential matrix, \\f$p\\_1\\f$ and \\f$p\\_2\\f$ are corresponding points in the first and the\nsecond images, respectively. The result of this function may be passed further to\n#decomposeEssentialMat or #recoverPose to recover the relative pose between cameras.\n\nPython prototype (for reference only):\n```python3\nfindEssentialMat(points1, points2, cameraMatrix[, method[, prob[, threshold[, maxIters[, mask]]]]]) -> retval, mask\n```\n#### Variant 2:\nfindEssentialMat\n\n##### Positional Arguments\n- **points1**: `Evision.Mat`.\n\n  Array of N (N \\>= 5) 2D points from the first image. The point coordinates should\n  be floating-point (single or double precision).\n\n- **points2**: `Evision.Mat`.\n\n  Array of the second image points of the same size and format as points1 .\n\n##### Keyword Arguments\n- **focal**: `double`.\n\n  focal length of the camera. Note that this function assumes that points1 and points2\n  are feature points from cameras with same focal length and principal point.\n\n- **pp**: `Point2d`.\n\n  principal point of the camera.\n\n- **method**: `integer()`.\n\n  Method for computing a fundamental matrix.\n  - @ref RANSAC for the RANSAC algorithm.\n  - @ref LMEDS for the LMedS algorithm.\n\n- **prob**: `double`.\n\n  Parameter used for the RANSAC or LMedS methods only. It specifies a desirable level of\n  confidence (probability) that the estimated matrix is correct.\n\n- **threshold**: `double`.\n\n  Parameter used for RANSAC. It is the maximum distance from a point to an epipolar\n  line in pixels, beyond which the point is considered an outlier and is not used for computing the\n  final fundamental matrix. It can be set to something like 1-3, depending on the accuracy of the\n  point localization, image resolution, and the image noise.\n\n- **maxIters**: `integer()`.\n\n  The maximum number of robust method iterations.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **mask**: `Evision.Mat.t()`.\n\n  Output array of N elements, every element of which is set to 0 for outliers and to 1\n  for the other points. The array is computed only in the RANSAC and LMedS methods.\n\nHas overloading in C++\n\nThis function differs from the one above that it computes camera intrinsic matrix from focal length and\nprincipal point:\n\\f[A =\n\\begin{bmatrix}\nf & 0 & x\\_{pp}  \\\\\\\\\n0 & f & y\\_{pp}  \\\\\\\\\n0 & 0 & 1\n\\end{bmatrix}\\f]\n\nPython prototype (for reference only):\n```python3\nfindEssentialMat(points1, points2[, focal[, pp[, method[, prob[, threshold[, maxIters[, mask]]]]]]]) -> retval, mask\n```","ref":"Evision.html#findEssentialMat/3"},{"type":"function","title":"Evision.findEssentialMat/4","doc":"Calculates an essential matrix from the corresponding points in two images.\n\n##### Positional Arguments\n- **points1**: `Evision.Mat`.\n\n  Array of N (N \\>= 5) 2D points from the first image. The point coordinates should\n  be floating-point (single or double precision).\n\n- **points2**: `Evision.Mat`.\n\n  Array of the second image points of the same size and format as points1.\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Camera intrinsic matrix \\f$\\cameramatrix{A}\\f$ .\n  Note that this function assumes that points1 and points2 are feature points from cameras with the\n  same camera intrinsic matrix. If this assumption does not hold for your use case, use another\n  function overload or #undistortPoints with `P = cv::NoArray()` for both cameras to transform image\n  points to normalized image coordinates, which are valid for the identity camera intrinsic matrix.\n  When passing these coordinates, pass the identity matrix for this parameter.\n\n##### Keyword Arguments\n- **method**: `integer()`.\n\n  Method for computing an essential matrix.\n  - @ref RANSAC for the RANSAC algorithm.\n  - @ref LMEDS for the LMedS algorithm.\n\n- **prob**: `double`.\n\n  Parameter used for the RANSAC or LMedS methods only. It specifies a desirable level of\n  confidence (probability) that the estimated matrix is correct.\n\n- **threshold**: `double`.\n\n  Parameter used for RANSAC. It is the maximum distance from a point to an epipolar\n  line in pixels, beyond which the point is considered an outlier and is not used for computing the\n  final fundamental matrix. It can be set to something like 1-3, depending on the accuracy of the\n  point localization, image resolution, and the image noise.\n\n- **maxIters**: `integer()`.\n\n  The maximum number of robust method iterations.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **mask**: `Evision.Mat.t()`.\n\n  Output array of N elements, every element of which is set to 0 for outliers and to 1\n  for the other points. The array is computed only in the RANSAC and LMedS methods.\n\nThis function estimates essential matrix based on the five-point algorithm solver in @cite Nister03 .\n@cite SteweniusCFS is also a related. The epipolar geometry is described by the following equation:\n\\f[\\[p\\_2; 1]^T K^{-T} E K^{-1} \\[p\\_1; 1] = 0\\f]\nwhere \\f$E\\f$ is an essential matrix, \\f$p\\_1\\f$ and \\f$p\\_2\\f$ are corresponding points in the first and the\nsecond images, respectively. The result of this function may be passed further to\n#decomposeEssentialMat or #recoverPose to recover the relative pose between cameras.\n\nPython prototype (for reference only):\n```python3\nfindEssentialMat(points1, points2, cameraMatrix[, method[, prob[, threshold[, maxIters[, mask]]]]]) -> retval, mask\n```","ref":"Evision.html#findEssentialMat/4"},{"type":"function","title":"Evision.findEssentialMat/6","doc":"Calculates an essential matrix from the corresponding points in two images from potentially two different cameras.\n\n##### Positional Arguments\n- **points1**: `Evision.Mat`.\n\n  Array of N (N \\>= 5) 2D points from the first image. The point coordinates should\n  be floating-point (single or double precision).\n\n- **points2**: `Evision.Mat`.\n\n  Array of the second image points of the same size and format as points1.\n\n- **cameraMatrix1**: `Evision.Mat`.\n\n  Camera matrix for the first camera \\f$K = \\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$ .\n\n- **distCoeffs1**: `Evision.Mat`.\n\n  Input vector of distortion coefficients for the first camera\n  \\f$(k_1, k_2, p_1, p_2[, k_3[, k_4, k_5, k_6[, s_1, s_2, s_3, s_4[, \\tau_x, \\tau_y]]]])\\f$\n  of 4, 5, 8, 12 or 14 elements. If the vector is NULL/empty, the zero distortion coefficients are assumed.\n\n- **cameraMatrix2**: `Evision.Mat`.\n\n  Camera matrix for the second camera \\f$K = \\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$ .\n\n- **distCoeffs2**: `Evision.Mat`.\n\n  Input vector of distortion coefficients for the second camera\n  \\f$(k_1, k_2, p_1, p_2[, k_3[, k_4, k_5, k_6[, s_1, s_2, s_3, s_4[, \\tau_x, \\tau_y]]]])\\f$\n  of 4, 5, 8, 12 or 14 elements. If the vector is NULL/empty, the zero distortion coefficients are assumed.\n\n##### Keyword Arguments\n- **method**: `integer()`.\n\n  Method for computing an essential matrix.\n  - @ref RANSAC for the RANSAC algorithm.\n  - @ref LMEDS for the LMedS algorithm.\n\n- **prob**: `double`.\n\n  Parameter used for the RANSAC or LMedS methods only. It specifies a desirable level of\n  confidence (probability) that the estimated matrix is correct.\n\n- **threshold**: `double`.\n\n  Parameter used for RANSAC. It is the maximum distance from a point to an epipolar\n  line in pixels, beyond which the point is considered an outlier and is not used for computing the\n  final fundamental matrix. It can be set to something like 1-3, depending on the accuracy of the\n  point localization, image resolution, and the image noise.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **mask**: `Evision.Mat.t()`.\n\n  Output array of N elements, every element of which is set to 0 for outliers and to 1\n  for the other points. The array is computed only in the RANSAC and LMedS methods.\n\nThis function estimates essential matrix based on the five-point algorithm solver in @cite Nister03 .\n@cite SteweniusCFS is also a related. The epipolar geometry is described by the following equation:\n\\f[\\[p\\_2; 1]^T K^{-T} E K^{-1} \\[p\\_1; 1] = 0\\f]\nwhere \\f$E\\f$ is an essential matrix, \\f$p\\_1\\f$ and \\f$p\\_2\\f$ are corresponding points in the first and the\nsecond images, respectively. The result of this function may be passed further to\n#decomposeEssentialMat or  #recoverPose to recover the relative pose between cameras.\n\nPython prototype (for reference only):\n```python3\nfindEssentialMat(points1, points2, cameraMatrix1, distCoeffs1, cameraMatrix2, distCoeffs2[, method[, prob[, threshold[, mask]]]]) -> retval, mask\n```","ref":"Evision.html#findEssentialMat/6"},{"type":"function","title":"Evision.findEssentialMat/7","doc":"#### Variant 1:\nfindEssentialMat\n\n##### Positional Arguments\n- **points1**: `Evision.Mat`\n- **points2**: `Evision.Mat`\n- **cameraMatrix1**: `Evision.Mat`\n- **cameraMatrix2**: `Evision.Mat`\n- **dist_coeff1**: `Evision.Mat`\n- **dist_coeff2**: `Evision.Mat`\n- **params**: `Evision.UsacParams`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **mask**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nfindEssentialMat(points1, points2, cameraMatrix1, cameraMatrix2, dist_coeff1, dist_coeff2, params[, mask]) -> retval, mask\n```\n#### Variant 2:\nCalculates an essential matrix from the corresponding points in two images from potentially two different cameras.\n\n##### Positional Arguments\n- **points1**: `Evision.Mat`.\n\n  Array of N (N \\>= 5) 2D points from the first image. The point coordinates should\n  be floating-point (single or double precision).\n\n- **points2**: `Evision.Mat`.\n\n  Array of the second image points of the same size and format as points1.\n\n- **cameraMatrix1**: `Evision.Mat`.\n\n  Camera matrix for the first camera \\f$K = \\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$ .\n\n- **distCoeffs1**: `Evision.Mat`.\n\n  Input vector of distortion coefficients for the first camera\n  \\f$(k_1, k_2, p_1, p_2[, k_3[, k_4, k_5, k_6[, s_1, s_2, s_3, s_4[, \\tau_x, \\tau_y]]]])\\f$\n  of 4, 5, 8, 12 or 14 elements. If the vector is NULL/empty, the zero distortion coefficients are assumed.\n\n- **cameraMatrix2**: `Evision.Mat`.\n\n  Camera matrix for the second camera \\f$K = \\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$ .\n\n- **distCoeffs2**: `Evision.Mat`.\n\n  Input vector of distortion coefficients for the second camera\n  \\f$(k_1, k_2, p_1, p_2[, k_3[, k_4, k_5, k_6[, s_1, s_2, s_3, s_4[, \\tau_x, \\tau_y]]]])\\f$\n  of 4, 5, 8, 12 or 14 elements. If the vector is NULL/empty, the zero distortion coefficients are assumed.\n\n##### Keyword Arguments\n- **method**: `integer()`.\n\n  Method for computing an essential matrix.\n  - @ref RANSAC for the RANSAC algorithm.\n  - @ref LMEDS for the LMedS algorithm.\n\n- **prob**: `double`.\n\n  Parameter used for the RANSAC or LMedS methods only. It specifies a desirable level of\n  confidence (probability) that the estimated matrix is correct.\n\n- **threshold**: `double`.\n\n  Parameter used for RANSAC. It is the maximum distance from a point to an epipolar\n  line in pixels, beyond which the point is considered an outlier and is not used for computing the\n  final fundamental matrix. It can be set to something like 1-3, depending on the accuracy of the\n  point localization, image resolution, and the image noise.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **mask**: `Evision.Mat.t()`.\n\n  Output array of N elements, every element of which is set to 0 for outliers and to 1\n  for the other points. The array is computed only in the RANSAC and LMedS methods.\n\nThis function estimates essential matrix based on the five-point algorithm solver in @cite Nister03 .\n@cite SteweniusCFS is also a related. The epipolar geometry is described by the following equation:\n\\f[\\[p\\_2; 1]^T K^{-T} E K^{-1} \\[p\\_1; 1] = 0\\f]\nwhere \\f$E\\f$ is an essential matrix, \\f$p\\_1\\f$ and \\f$p\\_2\\f$ are corresponding points in the first and the\nsecond images, respectively. The result of this function may be passed further to\n#decomposeEssentialMat or  #recoverPose to recover the relative pose between cameras.\n\nPython prototype (for reference only):\n```python3\nfindEssentialMat(points1, points2, cameraMatrix1, distCoeffs1, cameraMatrix2, distCoeffs2[, method[, prob[, threshold[, mask]]]]) -> retval, mask\n```","ref":"Evision.html#findEssentialMat/7"},{"type":"function","title":"Evision.findEssentialMat/8","doc":"findEssentialMat\n\n##### Positional Arguments\n- **points1**: `Evision.Mat`\n- **points2**: `Evision.Mat`\n- **cameraMatrix1**: `Evision.Mat`\n- **cameraMatrix2**: `Evision.Mat`\n- **dist_coeff1**: `Evision.Mat`\n- **dist_coeff2**: `Evision.Mat`\n- **params**: `Evision.UsacParams`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **mask**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nfindEssentialMat(points1, points2, cameraMatrix1, cameraMatrix2, dist_coeff1, dist_coeff2, params[, mask]) -> retval, mask\n```","ref":"Evision.html#findEssentialMat/8"},{"type":"function","title":"Evision.findFundamentalMat/1","doc":"","ref":"Evision.html#findFundamentalMat/1"},{"type":"function","title":"Evision.findFundamentalMat/2","doc":"findFundamentalMat\n\n##### Positional Arguments\n- **points1**: `Evision.Mat`\n- **points2**: `Evision.Mat`\n\n##### Keyword Arguments\n- **method**: `integer()`.\n- **ransacReprojThreshold**: `double`.\n- **confidence**: `double`.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **mask**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nfindFundamentalMat(points1, points2[, method[, ransacReprojThreshold[, confidence[, mask]]]]) -> retval, mask\n```","ref":"Evision.html#findFundamentalMat/2"},{"type":"function","title":"Evision.findFundamentalMat/3","doc":"#### Variant 1:\nfindFundamentalMat\n\n##### Positional Arguments\n- **points1**: `Evision.Mat`\n- **points2**: `Evision.Mat`\n- **params**: `Evision.UsacParams`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **mask**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nfindFundamentalMat(points1, points2, params[, mask]) -> retval, mask\n```\n#### Variant 2:\nfindFundamentalMat\n\n##### Positional Arguments\n- **points1**: `Evision.Mat`\n- **points2**: `Evision.Mat`\n\n##### Keyword Arguments\n- **method**: `integer()`.\n- **ransacReprojThreshold**: `double`.\n- **confidence**: `double`.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **mask**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nfindFundamentalMat(points1, points2[, method[, ransacReprojThreshold[, confidence[, mask]]]]) -> retval, mask\n```","ref":"Evision.html#findFundamentalMat/3"},{"type":"function","title":"Evision.findFundamentalMat/4","doc":"findFundamentalMat\n\n##### Positional Arguments\n- **points1**: `Evision.Mat`\n- **points2**: `Evision.Mat`\n- **params**: `Evision.UsacParams`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **mask**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nfindFundamentalMat(points1, points2, params[, mask]) -> retval, mask\n```","ref":"Evision.html#findFundamentalMat/4"},{"type":"function","title":"Evision.findFundamentalMat/6","doc":"Calculates a fundamental matrix from the corresponding points in two images.\n\n##### Positional Arguments\n- **points1**: `Evision.Mat`.\n\n  Array of N points from the first image. The point coordinates should be\n  floating-point (single or double precision).\n\n- **points2**: `Evision.Mat`.\n\n  Array of the second image points of the same size and format as points1 .\n\n- **method**: `integer()`.\n\n  Method for computing a fundamental matrix.\n  - @ref FM_7POINT for a 7-point algorithm. \\f$N = 7\\f$\n  - @ref FM_8POINT for an 8-point algorithm. \\f$N \\ge 8\\f$\n  - @ref FM_RANSAC for the RANSAC algorithm. \\f$N \\ge 8\\f$\n  - @ref FM_LMEDS for the LMedS algorithm. \\f$N \\ge 8\\f$\n\n- **ransacReprojThreshold**: `double`.\n\n  Parameter used only for RANSAC. It is the maximum distance from a point to an epipolar\n  line in pixels, beyond which the point is considered an outlier and is not used for computing the\n  final fundamental matrix. It can be set to something like 1-3, depending on the accuracy of the\n  point localization, image resolution, and the image noise.\n\n- **confidence**: `double`.\n\n  Parameter used for the RANSAC and LMedS methods only. It specifies a desirable level\n  of confidence (probability) that the estimated matrix is correct.\n\n- **maxIters**: `integer()`.\n\n  The maximum number of robust method iterations.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **mask**: `Evision.Mat.t()`.\n\n  optional output mask\n\nThe epipolar geometry is described by the following equation:\n\\f[\\[p\\_2; 1]^T F \\[p\\_1; 1] = 0\\f]\nwhere \\f$F\\f$ is a fundamental matrix, \\f$p\\_1\\f$ and \\f$p\\_2\\f$ are corresponding points in the first and the\nsecond images, respectively.\nThe function calculates the fundamental matrix using one of four methods listed above and returns\nthe found fundamental matrix. Normally just one matrix is found. But in case of the 7-point\nalgorithm, the function may return up to 3 solutions ( \\f$9 \\times 3\\f$ matrix that stores all 3\nmatrices sequentially).\nThe calculated fundamental matrix may be passed further to #computeCorrespondEpilines that finds the\nepipolar lines corresponding to the specified points. It can also be passed to\n#stereoRectifyUncalibrated to compute the rectification transformation. :\n```\n// Example. Estimation of fundamental matrix using the RANSAC algorithm\nint point_count = 100;\nvector  points1(point_count);\nvector  points2(point_count);\n// initialize the points here ...\nfor( int i = 0; i   retval, mask\n```","ref":"Evision.html#findFundamentalMat/6"},{"type":"function","title":"Evision.findFundamentalMat/7","doc":"Calculates a fundamental matrix from the corresponding points in two images.\n\n##### Positional Arguments\n- **points1**: `Evision.Mat`.\n\n  Array of N points from the first image. The point coordinates should be\n  floating-point (single or double precision).\n\n- **points2**: `Evision.Mat`.\n\n  Array of the second image points of the same size and format as points1 .\n\n- **method**: `integer()`.\n\n  Method for computing a fundamental matrix.\n  - @ref FM_7POINT for a 7-point algorithm. \\f$N = 7\\f$\n  - @ref FM_8POINT for an 8-point algorithm. \\f$N \\ge 8\\f$\n  - @ref FM_RANSAC for the RANSAC algorithm. \\f$N \\ge 8\\f$\n  - @ref FM_LMEDS for the LMedS algorithm. \\f$N \\ge 8\\f$\n\n- **ransacReprojThreshold**: `double`.\n\n  Parameter used only for RANSAC. It is the maximum distance from a point to an epipolar\n  line in pixels, beyond which the point is considered an outlier and is not used for computing the\n  final fundamental matrix. It can be set to something like 1-3, depending on the accuracy of the\n  point localization, image resolution, and the image noise.\n\n- **confidence**: `double`.\n\n  Parameter used for the RANSAC and LMedS methods only. It specifies a desirable level\n  of confidence (probability) that the estimated matrix is correct.\n\n- **maxIters**: `integer()`.\n\n  The maximum number of robust method iterations.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **mask**: `Evision.Mat.t()`.\n\n  optional output mask\n\nThe epipolar geometry is described by the following equation:\n\\f[\\[p\\_2; 1]^T F \\[p\\_1; 1] = 0\\f]\nwhere \\f$F\\f$ is a fundamental matrix, \\f$p\\_1\\f$ and \\f$p\\_2\\f$ are corresponding points in the first and the\nsecond images, respectively.\nThe function calculates the fundamental matrix using one of four methods listed above and returns\nthe found fundamental matrix. Normally just one matrix is found. But in case of the 7-point\nalgorithm, the function may return up to 3 solutions ( \\f$9 \\times 3\\f$ matrix that stores all 3\nmatrices sequentially).\nThe calculated fundamental matrix may be passed further to #computeCorrespondEpilines that finds the\nepipolar lines corresponding to the specified points. It can also be passed to\n#stereoRectifyUncalibrated to compute the rectification transformation. :\n```\n// Example. Estimation of fundamental matrix using the RANSAC algorithm\nint point_count = 100;\nvector  points1(point_count);\nvector  points2(point_count);\n// initialize the points here ...\nfor( int i = 0; i   retval, mask\n```","ref":"Evision.html#findFundamentalMat/7"},{"type":"function","title":"Evision.findHomography/1","doc":"","ref":"Evision.html#findHomography/1"},{"type":"function","title":"Evision.findHomography/2","doc":"Finds a perspective transformation between two planes.\n\n##### Positional Arguments\n- **srcPoints**: `Evision.Mat`.\n\n  Coordinates of the points in the original plane, a matrix of the type CV_32FC2\n  or vector\\  .\n\n- **dstPoints**: `Evision.Mat`.\n\n  Coordinates of the points in the target plane, a matrix of the type CV_32FC2 or\n  a vector\\  .\n\n##### Keyword Arguments\n- **method**: `integer()`.\n\n  Method used to compute a homography matrix. The following methods are possible:\n  - **0** - a regular method using all the points, i.e., the least squares method\n  - @ref RANSAC - RANSAC-based robust method\n  - @ref LMEDS - Least-Median robust method\n  - @ref RHO - PROSAC-based robust method\n\n- **ransacReprojThreshold**: `double`.\n\n  Maximum allowed reprojection error to treat a point pair as an inlier\n  (used in the RANSAC and RHO methods only). That is, if\n  \\f[\\| \\texttt{dstPoints} _i -  \\texttt{convertPointsHomogeneous} ( \\texttt{H} \\cdot \\texttt{srcPoints} _i) \\|_2  >  \\texttt{ransacReprojThreshold}\\f]\n  then the point \\f$i\\f$ is considered as an outlier. If srcPoints and dstPoints are measured in pixels,\n  it usually makes sense to set this parameter somewhere in the range of 1 to 10.\n\n- **maxIters**: `integer()`.\n\n  The maximum number of RANSAC iterations.\n\n- **confidence**: `double`.\n\n  Confidence level, between 0 and 1.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **mask**: `Evision.Mat.t()`.\n\n  Optional output mask set by a robust method ( RANSAC or LMeDS ). Note that the input\n  mask values are ignored.\n\nThe function finds and returns the perspective transformation \\f$H\\f$ between the source and the\ndestination planes:\n\\f[s\\_i  \\vecthree{x'\\_i}{y'\\_i}{1} \\sim H  \\vecthree{x\\_i}{y\\_i}{1}\\f]\nso that the back-projection error\n\\f[\\sum \\_i \\left ( x'\\_i- \\frac{h\\_{11} x\\_i + h\\_{12} y\\_i + h\\_{13}}{h\\_{31} x\\_i + h\\_{32} y\\_i + h\\_{33}} \\right )^2+ \\left ( y'\\_i- \\frac{h\\_{21} x\\_i + h\\_{22} y\\_i + h\\_{23}}{h\\_{31} x\\_i + h\\_{32} y\\_i + h\\_{33}} \\right )^2\\f]\nis minimized. If the parameter method is set to the default value 0, the function uses all the point\npairs to compute an initial homography estimate with a simple least-squares scheme.\nHowever, if not all of the point pairs ( \\f$srcPoints\\_i\\f$, \\f$dstPoints\\_i\\f$ ) fit the rigid perspective\ntransformation (that is, there are some outliers), this initial estimate will be poor. In this case,\nyou can use one of the three robust methods. The methods RANSAC, LMeDS and RHO try many different\nrandom subsets of the corresponding point pairs (of four pairs each, collinear pairs are discarded), estimate the homography matrix\nusing this subset and a simple least-squares algorithm, and then compute the quality/goodness of the\ncomputed homography (which is the number of inliers for RANSAC or the least median re-projection error for\nLMeDS). The best subset is then used to produce the initial estimate of the homography matrix and\nthe mask of inliers/outliers.\nRegardless of the method, robust or not, the computed homography matrix is refined further (using\ninliers only in case of a robust method) with the Levenberg-Marquardt method to reduce the\nre-projection error even more.\nThe methods RANSAC and RHO can handle practically any ratio of outliers but need a threshold to\ndistinguish inliers from outliers. The method LMeDS does not need any threshold but it works\ncorrectly only when there are more than 50% of inliers. Finally, if there are no outliers and the\nnoise is rather small, use the default method (method=0).\nThe function is used to find initial intrinsic and extrinsic matrices. Homography matrix is\ndetermined up to a scale. If \\f$h\\_{33}\\f$ is non-zero, the matrix is normalized so that \\f$h\\_{33}=1\\f$.\n**Note**: Whenever an \\f$H\\f$ matrix cannot be estimated, an empty one will be returned.\n@sa\ngetAffineTransform, estimateAffine2D, estimateAffinePartial2D, getPerspectiveTransform, warpPerspective,\nperspectiveTransform\n\nPython prototype (for reference only):\n```python3\nfindHomography(srcPoints, dstPoints[, method[, ransacReprojThreshold[, mask[, maxIters[, confidence]]]]]) -> retval, mask\n```","ref":"Evision.html#findHomography/2"},{"type":"function","title":"Evision.findHomography/3","doc":"#### Variant 1:\nfindHomography\n\n##### Positional Arguments\n- **srcPoints**: `Evision.Mat`\n- **dstPoints**: `Evision.Mat`\n- **params**: `Evision.UsacParams`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **mask**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nfindHomography(srcPoints, dstPoints, params[, mask]) -> retval, mask\n```\n#### Variant 2:\nFinds a perspective transformation between two planes.\n\n##### Positional Arguments\n- **srcPoints**: `Evision.Mat`.\n\n  Coordinates of the points in the original plane, a matrix of the type CV_32FC2\n  or vector\\  .\n\n- **dstPoints**: `Evision.Mat`.\n\n  Coordinates of the points in the target plane, a matrix of the type CV_32FC2 or\n  a vector\\  .\n\n##### Keyword Arguments\n- **method**: `integer()`.\n\n  Method used to compute a homography matrix. The following methods are possible:\n  - **0** - a regular method using all the points, i.e., the least squares method\n  - @ref RANSAC - RANSAC-based robust method\n  - @ref LMEDS - Least-Median robust method\n  - @ref RHO - PROSAC-based robust method\n\n- **ransacReprojThreshold**: `double`.\n\n  Maximum allowed reprojection error to treat a point pair as an inlier\n  (used in the RANSAC and RHO methods only). That is, if\n  \\f[\\| \\texttt{dstPoints} _i -  \\texttt{convertPointsHomogeneous} ( \\texttt{H} \\cdot \\texttt{srcPoints} _i) \\|_2  >  \\texttt{ransacReprojThreshold}\\f]\n  then the point \\f$i\\f$ is considered as an outlier. If srcPoints and dstPoints are measured in pixels,\n  it usually makes sense to set this parameter somewhere in the range of 1 to 10.\n\n- **maxIters**: `integer()`.\n\n  The maximum number of RANSAC iterations.\n\n- **confidence**: `double`.\n\n  Confidence level, between 0 and 1.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **mask**: `Evision.Mat.t()`.\n\n  Optional output mask set by a robust method ( RANSAC or LMeDS ). Note that the input\n  mask values are ignored.\n\nThe function finds and returns the perspective transformation \\f$H\\f$ between the source and the\ndestination planes:\n\\f[s\\_i  \\vecthree{x'\\_i}{y'\\_i}{1} \\sim H  \\vecthree{x\\_i}{y\\_i}{1}\\f]\nso that the back-projection error\n\\f[\\sum \\_i \\left ( x'\\_i- \\frac{h\\_{11} x\\_i + h\\_{12} y\\_i + h\\_{13}}{h\\_{31} x\\_i + h\\_{32} y\\_i + h\\_{33}} \\right )^2+ \\left ( y'\\_i- \\frac{h\\_{21} x\\_i + h\\_{22} y\\_i + h\\_{23}}{h\\_{31} x\\_i + h\\_{32} y\\_i + h\\_{33}} \\right )^2\\f]\nis minimized. If the parameter method is set to the default value 0, the function uses all the point\npairs to compute an initial homography estimate with a simple least-squares scheme.\nHowever, if not all of the point pairs ( \\f$srcPoints\\_i\\f$, \\f$dstPoints\\_i\\f$ ) fit the rigid perspective\ntransformation (that is, there are some outliers), this initial estimate will be poor. In this case,\nyou can use one of the three robust methods. The methods RANSAC, LMeDS and RHO try many different\nrandom subsets of the corresponding point pairs (of four pairs each, collinear pairs are discarded), estimate the homography matrix\nusing this subset and a simple least-squares algorithm, and then compute the quality/goodness of the\ncomputed homography (which is the number of inliers for RANSAC or the least median re-projection error for\nLMeDS). The best subset is then used to produce the initial estimate of the homography matrix and\nthe mask of inliers/outliers.\nRegardless of the method, robust or not, the computed homography matrix is refined further (using\ninliers only in case of a robust method) with the Levenberg-Marquardt method to reduce the\nre-projection error even more.\nThe methods RANSAC and RHO can handle practically any ratio of outliers but need a threshold to\ndistinguish inliers from outliers. The method LMeDS does not need any threshold but it works\ncorrectly only when there are more than 50% of inliers. Finally, if there are no outliers and the\nnoise is rather small, use the default method (method=0).\nThe function is used to find initial intrinsic and extrinsic matrices. Homography matrix is\ndetermined up to a scale. If \\f$h\\_{33}\\f$ is non-zero, the matrix is normalized so that \\f$h\\_{33}=1\\f$.\n**Note**: Whenever an \\f$H\\f$ matrix cannot be estimated, an empty one will be returned.\n@sa\ngetAffineTransform, estimateAffine2D, estimateAffinePartial2D, getPerspectiveTransform, warpPerspective,\nperspectiveTransform\n\nPython prototype (for reference only):\n```python3\nfindHomography(srcPoints, dstPoints[, method[, ransacReprojThreshold[, mask[, maxIters[, confidence]]]]]) -> retval, mask\n```","ref":"Evision.html#findHomography/3"},{"type":"function","title":"Evision.findHomography/4","doc":"findHomography\n\n##### Positional Arguments\n- **srcPoints**: `Evision.Mat`\n- **dstPoints**: `Evision.Mat`\n- **params**: `Evision.UsacParams`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **mask**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nfindHomography(srcPoints, dstPoints, params[, mask]) -> retval, mask\n```","ref":"Evision.html#findHomography/4"},{"type":"function","title":"Evision.findNonZero/1","doc":"Returns the list of locations of non-zero pixels\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  single-channel array\n\n##### Return\n- **idx**: `Evision.Mat.t()`.\n\n  the output array, type of cv::Mat or std::vector , corresponding to non-zero indices in the input\n\nGiven a binary matrix (likely returned from an operation such\nas threshold(), compare(), >, ==, etc, return all of\nthe non-zero indices as a cv::Mat or std::vector  (x,y)\nFor example:\n```cpp\ncv::Mat binaryImage; // input, binary image\ncv::Mat locations;   // output, locations of non-zero pixels\ncv::findNonZero(binaryImage, locations);\n// access pixel coordinates\nPoint pnt = locations.at (i);\n```\nor\n```cpp\ncv::Mat binaryImage; // input, binary image\nvector  locations;   // output, locations of non-zero pixels\ncv::findNonZero(binaryImage, locations);\n// access pixel coordinates\nPoint pnt = locations[i];\n```\nThe function do not work with multi-channel arrays. If you need to find non-zero\nelements across all the channels, use Mat::reshape first to reinterpret the array as\nsingle-channel. Or you may extract the particular channel using either extractImageCOI, or\nmixChannels, or split.\n**Note**: \n- If only count of non-zero array elements is important, @ref countNonZero is helpful.\n- If only whether there are non-zero elements is important, @ref hasNonZero is helpful.\n@sa  countNonZero, hasNonZero\n\nPython prototype (for reference only):\n```python3\nfindNonZero(src[, idx]) -> idx\n```","ref":"Evision.html#findNonZero/1"},{"type":"function","title":"Evision.findNonZero/2","doc":"Returns the list of locations of non-zero pixels\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  single-channel array\n\n##### Return\n- **idx**: `Evision.Mat.t()`.\n\n  the output array, type of cv::Mat or std::vector , corresponding to non-zero indices in the input\n\nGiven a binary matrix (likely returned from an operation such\nas threshold(), compare(), >, ==, etc, return all of\nthe non-zero indices as a cv::Mat or std::vector  (x,y)\nFor example:\n```cpp\ncv::Mat binaryImage; // input, binary image\ncv::Mat locations;   // output, locations of non-zero pixels\ncv::findNonZero(binaryImage, locations);\n// access pixel coordinates\nPoint pnt = locations.at (i);\n```\nor\n```cpp\ncv::Mat binaryImage; // input, binary image\nvector  locations;   // output, locations of non-zero pixels\ncv::findNonZero(binaryImage, locations);\n// access pixel coordinates\nPoint pnt = locations[i];\n```\nThe function do not work with multi-channel arrays. If you need to find non-zero\nelements across all the channels, use Mat::reshape first to reinterpret the array as\nsingle-channel. Or you may extract the particular channel using either extractImageCOI, or\nmixChannels, or split.\n**Note**: \n- If only count of non-zero array elements is important, @ref countNonZero is helpful.\n- If only whether there are non-zero elements is important, @ref hasNonZero is helpful.\n@sa  countNonZero, hasNonZero\n\nPython prototype (for reference only):\n```python3\nfindNonZero(src[, idx]) -> idx\n```","ref":"Evision.html#findNonZero/2"},{"type":"function","title":"Evision.findTransformECC/1","doc":"","ref":"Evision.html#findTransformECC/1"},{"type":"function","title":"Evision.findTransformECC/3","doc":"findTransformECC\n\n##### Positional Arguments\n- **templateImage**: `Evision.Mat`\n- **inputImage**: `Evision.Mat`\n\n##### Keyword Arguments\n- **motionType**: `integer()`.\n- **criteria**: `TermCriteria`.\n- **inputMask**: `Evision.Mat`.\n\n##### Return\n- **retval**: `double`\n- **warpMatrix**: `Evision.Mat.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nfindTransformECC(templateImage, inputImage, warpMatrix[, motionType[, criteria[, inputMask]]]) -> retval, warpMatrix\n```","ref":"Evision.html#findTransformECC/3"},{"type":"function","title":"Evision.findTransformECC/4","doc":"findTransformECC\n\n##### Positional Arguments\n- **templateImage**: `Evision.Mat`\n- **inputImage**: `Evision.Mat`\n\n##### Keyword Arguments\n- **motionType**: `integer()`.\n- **criteria**: `TermCriteria`.\n- **inputMask**: `Evision.Mat`.\n\n##### Return\n- **retval**: `double`\n- **warpMatrix**: `Evision.Mat.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nfindTransformECC(templateImage, inputImage, warpMatrix[, motionType[, criteria[, inputMask]]]) -> retval, warpMatrix\n```","ref":"Evision.html#findTransformECC/4"},{"type":"function","title":"Evision.findTransformECC/7","doc":"Finds the geometric transform (warp) between two images in terms of the ECC criterion @cite EP08 .\n\n##### Positional Arguments\n- **templateImage**: `Evision.Mat`.\n\n  single-channel template image; CV_8U or CV_32F array.\n\n- **inputImage**: `Evision.Mat`.\n\n  single-channel input image which should be warped with the final warpMatrix in\n  order to provide an image similar to templateImage, same type as templateImage.\n\n- **motionType**: `integer()`.\n\n  parameter, specifying the type of motion:\n  - **MOTION_TRANSLATION** sets a translational motion model; warpMatrix is \\f$2\\times 3\\f$ with\n    the first \\f$2\\times 2\\f$ part being the unity matrix and the rest two parameters being\n    estimated.\n  - **MOTION_EUCLIDEAN** sets a Euclidean (rigid) transformation as motion model; three\n    parameters are estimated; warpMatrix is \\f$2\\times 3\\f$.\n  - **MOTION_AFFINE** sets an affine motion model (DEFAULT); six parameters are estimated;\n    warpMatrix is \\f$2\\times 3\\f$.\n  - **MOTION_HOMOGRAPHY** sets a homography as a motion model; eight parameters are\n    estimated;\\`warpMatrix\\` is \\f$3\\times 3\\f$.\n\n- **criteria**: `TermCriteria`.\n\n  parameter, specifying the termination criteria of the ECC algorithm;\n  criteria.epsilon defines the threshold of the increment in the correlation coefficient between two\n  iterations (a negative criteria.epsilon makes criteria.maxcount the only termination criterion).\n  Default values are shown in the declaration above.\n\n- **inputMask**: `Evision.Mat`.\n\n  An optional mask to indicate valid values of inputImage.\n\n- **gaussFiltSize**: `integer()`.\n\n  An optional value indicating size of gaussian blur filter; (DEFAULT: 5)\n\n##### Return\n- **retval**: `double`\n- **warpMatrix**: `Evision.Mat.t()`.\n\n  floating-point \\f$2\\times 3\\f$ or \\f$3\\times 3\\f$ mapping matrix (warp).\n\nThe function estimates the optimum transformation (warpMatrix) with respect to ECC criterion\n(@cite EP08), that is\n\\f[\\texttt{warpMatrix} = \\arg\\max\\_{W} \\texttt{ECC}(\\texttt{templateImage}(x,y),\\texttt{inputImage}(x',y'))\\f]\nwhere\n\\f[\\begin{bmatrix} x' \\\\\\\\ y' \\end{bmatrix} = W \\cdot \\begin{bmatrix} x \\\\\\\\ y \\\\\\\\ 1 \\end{bmatrix}\\f]\n(the equation holds with homogeneous coordinates for homography). It returns the final enhanced\ncorrelation coefficient, that is the correlation coefficient between the template image and the\nfinal warped input image. When a \\f$3\\times 3\\f$ matrix is given with motionType =0, 1 or 2, the third\nrow is ignored.\nUnlike findHomography and estimateRigidTransform, the function findTransformECC implements an\narea-based alignment that builds on intensity similarities. In essence, the function updates the\ninitial transformation that roughly aligns the images. If this information is missing, the identity\nwarp (unity matrix) is used as an initialization. Note that if images undergo strong\ndisplacements/rotations, an initial transformation that roughly aligns the images is necessary\n(e.g., a simple euclidean/similarity transform that allows for the images showing the same image\ncontent approximately). Use inverse warping in the second image to take an image close to the first\none, i.e. use the flag WARP_INVERSE_MAP with warpAffine or warpPerspective. See also the OpenCV\nsample image_alignment.cpp that demonstrates the use of the function. Note that the function throws\nan exception if algorithm does not converges.\n@sa\ncomputeECC, estimateAffine2D, estimateAffinePartial2D, findHomography\n\nPython prototype (for reference only):\n```python3\nfindTransformECC(templateImage, inputImage, warpMatrix, motionType, criteria, inputMask, gaussFiltSize) -> retval, warpMatrix\n```","ref":"Evision.html#findTransformECC/7"},{"type":"function","title":"Evision.fitEllipse/1","doc":"Fits an ellipse around a set of 2D points.\n\n##### Positional Arguments\n- **points**: `Evision.Mat`.\n\n  Input 2D point set, stored in std::vector\\<\\> or Mat\n\n##### Return\n- **retval**: `{centre={x, y}, size={s1, s2}, angle}`\n\nThe function calculates the ellipse that fits (in a least-squares sense) a set of 2D points best of\nall. It returns the rotated rectangle in which the ellipse is inscribed. The first algorithm described by @cite Fitzgibbon95\nis used. Developer should keep in mind that it is possible that the returned\nellipse/rotatedRect data contains negative indices, due to the data points being close to the\nborder of the containing Mat element.\n\nPython prototype (for reference only):\n```python3\nfitEllipse(points) -> retval\n```","ref":"Evision.html#fitEllipse/1"},{"type":"function","title":"Evision.fitEllipseAMS/1","doc":"Fits an ellipse around a set of 2D points.\n\n##### Positional Arguments\n- **points**: `Evision.Mat`.\n\n  Input 2D point set, stored in std::vector\\<\\> or Mat\n\n##### Return\n- **retval**: `{centre={x, y}, size={s1, s2}, angle}`\n\nThe function calculates the ellipse that fits a set of 2D points.\nIt returns the rotated rectangle in which the ellipse is inscribed.\nThe Approximate Mean Square (AMS) proposed by @cite Taubin1991 is used.\nFor an ellipse, this basis set is \\f$ \\chi= \\left(x^2, x y, y^2, x, y, 1\\right) \\f$,\nwhich is a set of six free coefficients \\f$ A^T=\\left\\\\{A\\_{\\text{xx}},A\\_{\\text{xy}},A\\_{\\text{yy}},A\\_x,A\\_y,A\\_0\\right\\\\} \\f$.\nHowever, to specify an ellipse, all that is needed is five numbers; the major and minor axes lengths \\f$ (a,b) \\f$,\nthe position \\f$ (x\\_0,y\\_0) \\f$, and the orientation \\f$ \\theta \\f$. This is because the basis set includes lines,\nquadratics, parabolic and hyperbolic functions as well as elliptical functions as possible fits.\nIf the fit is found to be a parabolic or hyperbolic function then the standard #fitEllipse method is used.\nThe AMS method restricts the fit to parabolic, hyperbolic and elliptical curves\nby imposing the condition that \\f$ A^T ( D\\_x^T D\\_x  +   D\\_y^T D\\_y) A = 1 \\f$ where\nthe matrices \\f$ Dx \\f$ and \\f$ Dy \\f$ are the partial derivatives of the design matrix \\f$ D \\f$ with\nrespect to x and y. The matrices are formed row by row applying the following to\neach of the points in the set:\n\\f{align*}{\nD(i,:)&=\\left\\{x_i^2, x_i y_i, y_i^2, x_i, y_i, 1\\right\\} &\nD_x(i,:)&=\\left\\{2 x_i,y_i,0,1,0,0\\right\\} &\nD_y(i,:)&=\\left\\{0,x_i,2 y_i,0,1,0\\right\\}\n\\f}\nThe AMS method minimizes the cost function\n\\f{equation*}{\n\\epsilon ^2=\\frac{ A^T D^T D A }{ A^T (D_x^T D_x +  D_y^T D_y) A^T }\n\\f}\nThe minimum cost is found by solving the generalized eigenvalue problem.\n\\f{equation*}{\nD^T D A = \\lambda  \\left( D_x^T D_x +  D_y^T D_y\\right) A\n\\f}\n\nPython prototype (for reference only):\n```python3\nfitEllipseAMS(points) -> retval\n```","ref":"Evision.html#fitEllipseAMS/1"},{"type":"function","title":"Evision.fitEllipseDirect/1","doc":"Fits an ellipse around a set of 2D points.\n\n##### Positional Arguments\n- **points**: `Evision.Mat`.\n\n  Input 2D point set, stored in std::vector\\<\\> or Mat\n\n##### Return\n- **retval**: `{centre={x, y}, size={s1, s2}, angle}`\n\nThe function calculates the ellipse that fits a set of 2D points.\nIt returns the rotated rectangle in which the ellipse is inscribed.\nThe Direct least square (Direct) method by @cite Fitzgibbon1999 is used.\nFor an ellipse, this basis set is \\f$ \\chi= \\left(x^2, x y, y^2, x, y, 1\\right) \\f$,\nwhich is a set of six free coefficients \\f$ A^T=\\left\\\\{A\\_{\\text{xx}},A\\_{\\text{xy}},A\\_{\\text{yy}},A\\_x,A\\_y,A\\_0\\right\\\\} \\f$.\nHowever, to specify an ellipse, all that is needed is five numbers; the major and minor axes lengths \\f$ (a,b) \\f$,\nthe position \\f$ (x\\_0,y\\_0) \\f$, and the orientation \\f$ \\theta \\f$. This is because the basis set includes lines,\nquadratics, parabolic and hyperbolic functions as well as elliptical functions as possible fits.\nThe Direct method confines the fit to ellipses by ensuring that \\f$ 4 A\\_{xx} A\\_{yy}- A\\_{xy}^2 > 0 \\f$.\nThe condition imposed is that \\f$ 4 A\\_{xx} A\\_{yy}- A\\_{xy}^2=1 \\f$ which satisfies the inequality\nand as the coefficients can be arbitrarily scaled is not overly restrictive.\n\\f{equation*}{\n\\epsilon ^2= A^T D^T D A \\quad \\text{with} \\quad A^T C A =1 \\quad \\text{and} \\quad C=\\left(\\begin{matrix}\n0 & 0  & 2  & 0  & 0  &  0  \\\\\\\\\n0 & -1  & 0  & 0  & 0  &  0 \\\\\\\\\n2 & 0  & 0  & 0  & 0  &  0 \\\\\\\\\n0 & 0  & 0  & 0  & 0  &  0 \\\\\\\\\n0 & 0  & 0  & 0  & 0  &  0 \\\\\\\\\n0 & 0  & 0  & 0  & 0  &  0\n\\end{matrix} \\right)\n\\f}\nThe minimum cost is found by solving the generalized eigenvalue problem.\n\\f{equation*}{\nD^T D A = \\lambda  \\left( C\\right) A\n\\f}\nThe system produces only one positive eigenvalue \\f$ \\lambda\\f$ which is chosen as the solution\nwith its eigenvector \\f$\\mathbf{u}\\f$. These are used to find the coefficients\n\\f{equation*}{\nA = \\sqrt{\\frac{1}{\\mathbf{u}^T C \\mathbf{u}}}  \\mathbf{u}\n\\f}\nThe scaling factor guarantees that  \\f$A^T C A =1\\f$.\n\nPython prototype (for reference only):\n```python3\nfitEllipseDirect(points) -> retval\n```","ref":"Evision.html#fitEllipseDirect/1"},{"type":"function","title":"Evision.fitLine/1","doc":"","ref":"Evision.html#fitLine/1"},{"type":"function","title":"Evision.fitLine/5","doc":"Fits a line to a 2D or 3D point set.\n\n##### Positional Arguments\n- **points**: `Evision.Mat`.\n\n  Input vector of 2D or 3D points, stored in std::vector\\<\\> or Mat.\n\n- **distType**: `integer()`.\n\n  Distance used by the M-estimator, see #DistanceTypes\n\n- **param**: `double`.\n\n  Numerical parameter ( C ) for some types of distances. If it is 0, an optimal value\n  is chosen.\n\n- **reps**: `double`.\n\n  Sufficient accuracy for the radius (distance between the coordinate origin and the line).\n\n- **aeps**: `double`.\n\n  Sufficient accuracy for the angle. 0.01 would be a good default value for reps and aeps.\n\n##### Return\n- **line**: `Evision.Mat.t()`.\n\n  Output line parameters. In case of 2D fitting, it should be a vector of 4 elements\n  (like Vec4f) - (vx, vy, x0, y0), where (vx, vy) is a normalized vector collinear to the line and\n  (x0, y0) is a point on the line. In case of 3D fitting, it should be a vector of 6 elements (like\n  Vec6f) - (vx, vy, vz, x0, y0, z0), where (vx, vy, vz) is a normalized vector collinear to the line\n  and (x0, y0, z0) is a point on the line.\n\nThe function fitLine fits a line to a 2D or 3D point set by minimizing \\f$\\sum\\_i \\rho(r\\_i)\\f$ where\n\\f$r\\_i\\f$ is a distance between the \\f$i^{th}\\f$ point, the line and \\f$\\rho(r)\\f$ is a distance function, one\nof the following:\n- DIST_L2\n  \\f[\\rho (r) = r^2/2  \\quad \\text{(the simplest and the fastest least-squares method)}\\f]\n\n- DIST_L1\n  \\f[\\rho (r) = r\\f]\n\n- DIST_L12\n  \\f[\\rho (r) = 2  \\cdot ( \\sqrt{1 + \\frac{r^2}{2}} - 1)\\f]\n\n- DIST_FAIR\n  \\f[\\rho \\left (r \\right ) = C^2  \\cdot \\left (  \\frac{r}{C} -  \\log{\\left(1 + \\frac{r}{C}\\right)} \\right )  \\quad \\text{where} \\quad C=1.3998\\f]\n\n- DIST_WELSCH\n  \\f[\\rho \\left (r \\right ) =  \\frac{C^2}{2} \\cdot \\left ( 1 -  \\exp{\\left(-\\left(\\frac{r}{C}\\right)^2\\right)} \\right )  \\quad \\text{where} \\quad C=2.9846\\f]\n\n- DIST_HUBER\n  \\f[\\rho (r) =  \\fork{r^2/2}{if \\(r   ) technique\nthat iteratively fits the line using the weighted least-squares algorithm. After each iteration the\nweights \\f$w\\_i\\f$ are adjusted to be inversely proportional to \\f$\\rho(r\\_i)\\f$ .\n\nPython prototype (for reference only):\n```python3\nfitLine(points, distType, param, reps, aeps[, line]) -> line\n```","ref":"Evision.html#fitLine/5"},{"type":"function","title":"Evision.fitLine/6","doc":"Fits a line to a 2D or 3D point set.\n\n##### Positional Arguments\n- **points**: `Evision.Mat`.\n\n  Input vector of 2D or 3D points, stored in std::vector\\<\\> or Mat.\n\n- **distType**: `integer()`.\n\n  Distance used by the M-estimator, see #DistanceTypes\n\n- **param**: `double`.\n\n  Numerical parameter ( C ) for some types of distances. If it is 0, an optimal value\n  is chosen.\n\n- **reps**: `double`.\n\n  Sufficient accuracy for the radius (distance between the coordinate origin and the line).\n\n- **aeps**: `double`.\n\n  Sufficient accuracy for the angle. 0.01 would be a good default value for reps and aeps.\n\n##### Return\n- **line**: `Evision.Mat.t()`.\n\n  Output line parameters. In case of 2D fitting, it should be a vector of 4 elements\n  (like Vec4f) - (vx, vy, x0, y0), where (vx, vy) is a normalized vector collinear to the line and\n  (x0, y0) is a point on the line. In case of 3D fitting, it should be a vector of 6 elements (like\n  Vec6f) - (vx, vy, vz, x0, y0, z0), where (vx, vy, vz) is a normalized vector collinear to the line\n  and (x0, y0, z0) is a point on the line.\n\nThe function fitLine fits a line to a 2D or 3D point set by minimizing \\f$\\sum\\_i \\rho(r\\_i)\\f$ where\n\\f$r\\_i\\f$ is a distance between the \\f$i^{th}\\f$ point, the line and \\f$\\rho(r)\\f$ is a distance function, one\nof the following:\n- DIST_L2\n  \\f[\\rho (r) = r^2/2  \\quad \\text{(the simplest and the fastest least-squares method)}\\f]\n\n- DIST_L1\n  \\f[\\rho (r) = r\\f]\n\n- DIST_L12\n  \\f[\\rho (r) = 2  \\cdot ( \\sqrt{1 + \\frac{r^2}{2}} - 1)\\f]\n\n- DIST_FAIR\n  \\f[\\rho \\left (r \\right ) = C^2  \\cdot \\left (  \\frac{r}{C} -  \\log{\\left(1 + \\frac{r}{C}\\right)} \\right )  \\quad \\text{where} \\quad C=1.3998\\f]\n\n- DIST_WELSCH\n  \\f[\\rho \\left (r \\right ) =  \\frac{C^2}{2} \\cdot \\left ( 1 -  \\exp{\\left(-\\left(\\frac{r}{C}\\right)^2\\right)} \\right )  \\quad \\text{where} \\quad C=2.9846\\f]\n\n- DIST_HUBER\n  \\f[\\rho (r) =  \\fork{r^2/2}{if \\(r   ) technique\nthat iteratively fits the line using the weighted least-squares algorithm. After each iteration the\nweights \\f$w\\_i\\f$ are adjusted to be inversely proportional to \\f$\\rho(r\\_i)\\f$ .\n\nPython prototype (for reference only):\n```python3\nfitLine(points, distType, param, reps, aeps[, line]) -> line\n```","ref":"Evision.html#fitLine/6"},{"type":"function","title":"Evision.flip/1","doc":"","ref":"Evision.html#flip/1"},{"type":"function","title":"Evision.flip/2","doc":"Flips a 2D array around vertical, horizontal, or both axes.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array.\n\n- **flipCode**: `integer()`.\n\n  a flag to specify how to flip the array; 0 means\n  flipping around the x-axis and positive value (for example, 1) means\n  flipping around y-axis. Negative value (for example, -1) means flipping\n  around both axes.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src.\n\nThe function cv::flip flips the array in one of three different ways (row\nand column indices are 0-based):\n\\f[\\texttt{dst} \\_{ij} =\n\\left\\\\{\n\\begin{array}{l l}\n\\texttt{src} \\_{\\texttt{src.rows}-i-1,j} & if\\;  \\texttt{flipCode} = 0 \\\\\\\\\n\\texttt{src} \\_{i, \\texttt{src.cols} -j-1} & if\\;  \\texttt{flipCode} > 0 \\\\\\\\\n\\texttt{src} \\_{ \\texttt{src.rows} -i-1, \\texttt{src.cols} -j-1} & if\\; \\texttt{flipCode} < 0 \\\\\\\\\n\\end{array}\n\\right.\\f]\nThe example scenarios of using the function are the following:\n   Vertical flipping of the image (flipCode == 0) to switch between\ntop-left and bottom-left image origin. This is a typical operation\nin video processing on Microsoft Windows\\* OS.\n   Horizontal flipping of the image with the subsequent horizontal\nshift and absolute difference calculation to check for a\nvertical-axis symmetry (flipCode \\> 0).\n   Simultaneous horizontal and vertical flipping of the image with\nthe subsequent shift and absolute difference calculation to check\nfor a central symmetry (flipCode \\< 0).\n   Reversing the order of point arrays (flipCode \\> 0 or\nflipCode == 0).\n@sa transpose, repeat, completeSymm\n\nPython prototype (for reference only):\n```python3\nflip(src, flipCode[, dst]) -> dst\n```","ref":"Evision.html#flip/2"},{"type":"function","title":"Evision.flip/3","doc":"Flips a 2D array around vertical, horizontal, or both axes.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array.\n\n- **flipCode**: `integer()`.\n\n  a flag to specify how to flip the array; 0 means\n  flipping around the x-axis and positive value (for example, 1) means\n  flipping around y-axis. Negative value (for example, -1) means flipping\n  around both axes.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src.\n\nThe function cv::flip flips the array in one of three different ways (row\nand column indices are 0-based):\n\\f[\\texttt{dst} \\_{ij} =\n\\left\\\\{\n\\begin{array}{l l}\n\\texttt{src} \\_{\\texttt{src.rows}-i-1,j} & if\\;  \\texttt{flipCode} = 0 \\\\\\\\\n\\texttt{src} \\_{i, \\texttt{src.cols} -j-1} & if\\;  \\texttt{flipCode} > 0 \\\\\\\\\n\\texttt{src} \\_{ \\texttt{src.rows} -i-1, \\texttt{src.cols} -j-1} & if\\; \\texttt{flipCode} < 0 \\\\\\\\\n\\end{array}\n\\right.\\f]\nThe example scenarios of using the function are the following:\n   Vertical flipping of the image (flipCode == 0) to switch between\ntop-left and bottom-left image origin. This is a typical operation\nin video processing on Microsoft Windows\\* OS.\n   Horizontal flipping of the image with the subsequent horizontal\nshift and absolute difference calculation to check for a\nvertical-axis symmetry (flipCode \\> 0).\n   Simultaneous horizontal and vertical flipping of the image with\nthe subsequent shift and absolute difference calculation to check\nfor a central symmetry (flipCode \\< 0).\n   Reversing the order of point arrays (flipCode \\> 0 or\nflipCode == 0).\n@sa transpose, repeat, completeSymm\n\nPython prototype (for reference only):\n```python3\nflip(src, flipCode[, dst]) -> dst\n```","ref":"Evision.html#flip/3"},{"type":"function","title":"Evision.flipND/1","doc":"","ref":"Evision.html#flipND/1"},{"type":"function","title":"Evision.flipND/2","doc":"Flips a n-dimensional at given axis\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array\n\n- **axis**: `integer()`.\n\n  axis that performs a flip on. 0 <= axis   dst\n```","ref":"Evision.html#flipND/2"},{"type":"function","title":"Evision.flipND/3","doc":"Flips a n-dimensional at given axis\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array\n\n- **axis**: `integer()`.\n\n  axis that performs a flip on. 0 <= axis   dst\n```","ref":"Evision.html#flipND/3"},{"type":"function","title":"Evision.floodFill/1","doc":"","ref":"Evision.html#floodFill/1"},{"type":"function","title":"Evision.floodFill/4","doc":"Fills a connected component with the given color.\n\n##### Positional Arguments\n- **seedPoint**: `Point`.\n\n  Starting point.\n\n- **newVal**: `Evision.scalar()`.\n\n  New value of the repainted domain pixels.\n\n##### Keyword Arguments\n- **loDiff**: `Evision.scalar()`.\n\n  Maximal lower brightness/color difference between the currently observed pixel and\n  one of its neighbors belonging to the component, or a seed pixel being added to the component.\n\n- **upDiff**: `Evision.scalar()`.\n\n  Maximal upper brightness/color difference between the currently observed pixel and\n  one of its neighbors belonging to the component, or a seed pixel being added to the component.\n\n- **flags**: `integer()`.\n\n  Operation flags. The first 8 bits contain a connectivity value. The default value of\n  4 means that only the four nearest neighbor pixels (those that share an edge) are considered. A\n  connectivity value of 8 means that the eight nearest neighbor pixels (those that share a corner)\n  will be considered. The next 8 bits (8-16) contain a value between 1 and 255 with which to fill\n  the mask (the default value is 1). For example, 4 | ( 255 \\<\\< 8 ) will consider 4 nearest\n  neighbours and fill the mask with a value of 255. The following additional options occupy higher\n  bits and therefore may be further combined with the connectivity and mask fill values using\n  bit-wise or (|), see #FloodFillFlags.\n\n##### Return\n- **retval**: `integer()`\n- **image**: `Evision.Mat.t()`.\n\n  Input/output 1- or 3-channel, 8-bit, or floating-point image. It is modified by the\n  function unless the #FLOODFILL_MASK_ONLY flag is set in the second variant of the function. See\n  the details below.\n\n- **mask**: `Evision.Mat.t()`.\n\n  Operation mask that should be a single-channel 8-bit image, 2 pixels wider and 2 pixels\n  taller than image. If an empty Mat is passed it will be created automatically. Since this is both an\n  input and output parameter, you must take responsibility of initializing it.\n  Flood-filling cannot go across non-zero pixels in the input mask. For example,\n  an edge detector output can be used as a mask to stop filling at edges. On output, pixels in the\n  mask corresponding to filled pixels in the image are set to 1 or to the specified value in flags\n  as described below. Additionally, the function fills the border of the mask with ones to simplify\n  internal processing. It is therefore possible to use the same mask in multiple calls to the function\n  to make sure the filled areas do not overlap.\n\n- **rect**: `Rect*`.\n\n  Optional output parameter set by the function to the minimum bounding rectangle of the\n  repainted domain.\n\nThe function cv::floodFill fills a connected component starting from the seed point with the specified\ncolor. The connectivity is determined by the color/brightness closeness of the neighbor pixels. The\npixel at \\f$(x,y)\\f$ is considered to belong to the repainted domain if:\n- in case of a grayscale image and floating range\n  \\f[\\texttt{src} (x',y')- \\texttt{loDiff} \\leq \\texttt{src} (x,y)  \\leq \\texttt{src} (x',y')+ \\texttt{upDiff}\\f]\n\n- in case of a grayscale image and fixed range\n  \\f[\\texttt{src} ( \\texttt{seedPoint} .x, \\texttt{seedPoint} .y)- \\texttt{loDiff} \\leq \\texttt{src} (x,y)  \\leq \\texttt{src} ( \\texttt{seedPoint} .x, \\texttt{seedPoint} .y)+ \\texttt{upDiff}\\f]\n\n- in case of a color image and floating range\n  \\f[\\texttt{src} (x',y')\\_r- \\texttt{loDiff} \\_r \\leq \\texttt{src} (x,y)\\_r \\leq \\texttt{src} (x',y')\\_r+ \\texttt{upDiff} \\_r,\\f]\n  \\f[\\texttt{src} (x',y')\\_g- \\texttt{loDiff} \\_g \\leq \\texttt{src} (x,y)\\_g \\leq \\texttt{src} (x',y')\\_g+ \\texttt{upDiff} \\_g\\f]\n  and\n  \\f[\\texttt{src} (x',y')\\_b- \\texttt{loDiff} \\_b \\leq \\texttt{src} (x,y)\\_b \\leq \\texttt{src} (x',y')\\_b+ \\texttt{upDiff} \\_b\\f]\n\n- in case of a color image and fixed range\n  \\f[\\texttt{src} ( \\texttt{seedPoint} .x, \\texttt{seedPoint} .y)\\_r- \\texttt{loDiff} \\_r \\leq \\texttt{src} (x,y)\\_r \\leq \\texttt{src} ( \\texttt{seedPoint} .x, \\texttt{seedPoint} .y)\\_r+ \\texttt{upDiff} \\_r,\\f]\n  \\f[\\texttt{src} ( \\texttt{seedPoint} .x, \\texttt{seedPoint} .y)\\_g- \\texttt{loDiff} \\_g \\leq \\texttt{src} (x,y)\\_g \\leq \\texttt{src} ( \\texttt{seedPoint} .x, \\texttt{seedPoint} .y)\\_g+ \\texttt{upDiff} \\_g\\f]\n  and\n  \\f[\\texttt{src} ( \\texttt{seedPoint} .x, \\texttt{seedPoint} .y)\\_b- \\texttt{loDiff} \\_b \\leq \\texttt{src} (x,y)\\_b \\leq \\texttt{src} ( \\texttt{seedPoint} .x, \\texttt{seedPoint} .y)\\_b+ \\texttt{upDiff} \\_b\\f]\n\nwhere \\f$src(x',y')\\f$ is the value of one of pixel neighbors that is already known to belong to the\ncomponent. That is, to be added to the connected component, a color/brightness of the pixel should\nbe close enough to:\n- Color/brightness of one of its neighbors that already belong to the connected component in case\n  of a floating range.\n\n- Color/brightness of the seed point in case of a fixed range.\n\nUse these functions to either mark a connected component with the specified color in-place, or build\na mask and then extract the contour, or copy the region to another image, and so on.\n\n**Note**: Since the mask is larger than the filled image, a pixel \\f$(x, y)\\f$ in image corresponds to the\npixel \\f$(x+1, y+1)\\f$ in the mask .\n@sa findContours\n\nPython prototype (for reference only):\n```python3\nfloodFill(image, mask, seedPoint, newVal[, loDiff[, upDiff[, flags]]]) -> retval, image, mask, rect\n```","ref":"Evision.html#floodFill/4"},{"type":"function","title":"Evision.floodFill/5","doc":"Fills a connected component with the given color.\n\n##### Positional Arguments\n- **seedPoint**: `Point`.\n\n  Starting point.\n\n- **newVal**: `Evision.scalar()`.\n\n  New value of the repainted domain pixels.\n\n##### Keyword Arguments\n- **loDiff**: `Evision.scalar()`.\n\n  Maximal lower brightness/color difference between the currently observed pixel and\n  one of its neighbors belonging to the component, or a seed pixel being added to the component.\n\n- **upDiff**: `Evision.scalar()`.\n\n  Maximal upper brightness/color difference between the currently observed pixel and\n  one of its neighbors belonging to the component, or a seed pixel being added to the component.\n\n- **flags**: `integer()`.\n\n  Operation flags. The first 8 bits contain a connectivity value. The default value of\n  4 means that only the four nearest neighbor pixels (those that share an edge) are considered. A\n  connectivity value of 8 means that the eight nearest neighbor pixels (those that share a corner)\n  will be considered. The next 8 bits (8-16) contain a value between 1 and 255 with which to fill\n  the mask (the default value is 1). For example, 4 | ( 255 \\<\\< 8 ) will consider 4 nearest\n  neighbours and fill the mask with a value of 255. The following additional options occupy higher\n  bits and therefore may be further combined with the connectivity and mask fill values using\n  bit-wise or (|), see #FloodFillFlags.\n\n##### Return\n- **retval**: `integer()`\n- **image**: `Evision.Mat.t()`.\n\n  Input/output 1- or 3-channel, 8-bit, or floating-point image. It is modified by the\n  function unless the #FLOODFILL_MASK_ONLY flag is set in the second variant of the function. See\n  the details below.\n\n- **mask**: `Evision.Mat.t()`.\n\n  Operation mask that should be a single-channel 8-bit image, 2 pixels wider and 2 pixels\n  taller than image. If an empty Mat is passed it will be created automatically. Since this is both an\n  input and output parameter, you must take responsibility of initializing it.\n  Flood-filling cannot go across non-zero pixels in the input mask. For example,\n  an edge detector output can be used as a mask to stop filling at edges. On output, pixels in the\n  mask corresponding to filled pixels in the image are set to 1 or to the specified value in flags\n  as described below. Additionally, the function fills the border of the mask with ones to simplify\n  internal processing. It is therefore possible to use the same mask in multiple calls to the function\n  to make sure the filled areas do not overlap.\n\n- **rect**: `Rect*`.\n\n  Optional output parameter set by the function to the minimum bounding rectangle of the\n  repainted domain.\n\nThe function cv::floodFill fills a connected component starting from the seed point with the specified\ncolor. The connectivity is determined by the color/brightness closeness of the neighbor pixels. The\npixel at \\f$(x,y)\\f$ is considered to belong to the repainted domain if:\n- in case of a grayscale image and floating range\n  \\f[\\texttt{src} (x',y')- \\texttt{loDiff} \\leq \\texttt{src} (x,y)  \\leq \\texttt{src} (x',y')+ \\texttt{upDiff}\\f]\n\n- in case of a grayscale image and fixed range\n  \\f[\\texttt{src} ( \\texttt{seedPoint} .x, \\texttt{seedPoint} .y)- \\texttt{loDiff} \\leq \\texttt{src} (x,y)  \\leq \\texttt{src} ( \\texttt{seedPoint} .x, \\texttt{seedPoint} .y)+ \\texttt{upDiff}\\f]\n\n- in case of a color image and floating range\n  \\f[\\texttt{src} (x',y')\\_r- \\texttt{loDiff} \\_r \\leq \\texttt{src} (x,y)\\_r \\leq \\texttt{src} (x',y')\\_r+ \\texttt{upDiff} \\_r,\\f]\n  \\f[\\texttt{src} (x',y')\\_g- \\texttt{loDiff} \\_g \\leq \\texttt{src} (x,y)\\_g \\leq \\texttt{src} (x',y')\\_g+ \\texttt{upDiff} \\_g\\f]\n  and\n  \\f[\\texttt{src} (x',y')\\_b- \\texttt{loDiff} \\_b \\leq \\texttt{src} (x,y)\\_b \\leq \\texttt{src} (x',y')\\_b+ \\texttt{upDiff} \\_b\\f]\n\n- in case of a color image and fixed range\n  \\f[\\texttt{src} ( \\texttt{seedPoint} .x, \\texttt{seedPoint} .y)\\_r- \\texttt{loDiff} \\_r \\leq \\texttt{src} (x,y)\\_r \\leq \\texttt{src} ( \\texttt{seedPoint} .x, \\texttt{seedPoint} .y)\\_r+ \\texttt{upDiff} \\_r,\\f]\n  \\f[\\texttt{src} ( \\texttt{seedPoint} .x, \\texttt{seedPoint} .y)\\_g- \\texttt{loDiff} \\_g \\leq \\texttt{src} (x,y)\\_g \\leq \\texttt{src} ( \\texttt{seedPoint} .x, \\texttt{seedPoint} .y)\\_g+ \\texttt{upDiff} \\_g\\f]\n  and\n  \\f[\\texttt{src} ( \\texttt{seedPoint} .x, \\texttt{seedPoint} .y)\\_b- \\texttt{loDiff} \\_b \\leq \\texttt{src} (x,y)\\_b \\leq \\texttt{src} ( \\texttt{seedPoint} .x, \\texttt{seedPoint} .y)\\_b+ \\texttt{upDiff} \\_b\\f]\n\nwhere \\f$src(x',y')\\f$ is the value of one of pixel neighbors that is already known to belong to the\ncomponent. That is, to be added to the connected component, a color/brightness of the pixel should\nbe close enough to:\n- Color/brightness of one of its neighbors that already belong to the connected component in case\n  of a floating range.\n\n- Color/brightness of the seed point in case of a fixed range.\n\nUse these functions to either mark a connected component with the specified color in-place, or build\na mask and then extract the contour, or copy the region to another image, and so on.\n\n**Note**: Since the mask is larger than the filled image, a pixel \\f$(x, y)\\f$ in image corresponds to the\npixel \\f$(x+1, y+1)\\f$ in the mask .\n@sa findContours\n\nPython prototype (for reference only):\n```python3\nfloodFill(image, mask, seedPoint, newVal[, loDiff[, upDiff[, flags]]]) -> retval, image, mask, rect\n```","ref":"Evision.html#floodFill/5"},{"type":"function","title":"Evision.gaussianBlur/1","doc":"","ref":"Evision.html#gaussianBlur/1"},{"type":"function","title":"Evision.gaussianBlur/3","doc":"Blurs an image using a Gaussian filter.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image; the image can have any number of channels, which are processed\n  independently, but the depth should be CV_8U, CV_16U, CV_16S, CV_32F or CV_64F.\n\n- **ksize**: `Size`.\n\n  Gaussian kernel size. ksize.width and ksize.height can differ but they both must be\n  positive and odd. Or, they can be zero's and then they are computed from sigma.\n\n- **sigmaX**: `double`.\n\n  Gaussian kernel standard deviation in X direction.\n\n##### Keyword Arguments\n- **sigmaY**: `double`.\n\n  Gaussian kernel standard deviation in Y direction; if sigmaY is zero, it is set to be\n  equal to sigmaX, if both sigmas are zeros, they are computed from ksize.width and ksize.height,\n  respectively (see #getGaussianKernel for details); to fully control the result regardless of\n  possible future modifications of all this semantics, it is recommended to specify all of ksize,\n  sigmaX, and sigmaY.\n\n- **borderType**: `integer()`.\n\n  pixel extrapolation method, see #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and type as src.\n\nThe function convolves the source image with the specified Gaussian kernel. In-place filtering is\nsupported.\n\n@sa  sepFilter2D, filter2D, blur, boxFilter, bilateralFilter, medianBlur\n\nPython prototype (for reference only):\n```python3\nGaussianBlur(src, ksize, sigmaX[, dst[, sigmaY[, borderType]]]) -> dst\n```","ref":"Evision.html#gaussianBlur/3"},{"type":"function","title":"Evision.gaussianBlur/4","doc":"Blurs an image using a Gaussian filter.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image; the image can have any number of channels, which are processed\n  independently, but the depth should be CV_8U, CV_16U, CV_16S, CV_32F or CV_64F.\n\n- **ksize**: `Size`.\n\n  Gaussian kernel size. ksize.width and ksize.height can differ but they both must be\n  positive and odd. Or, they can be zero's and then they are computed from sigma.\n\n- **sigmaX**: `double`.\n\n  Gaussian kernel standard deviation in X direction.\n\n##### Keyword Arguments\n- **sigmaY**: `double`.\n\n  Gaussian kernel standard deviation in Y direction; if sigmaY is zero, it is set to be\n  equal to sigmaX, if both sigmas are zeros, they are computed from ksize.width and ksize.height,\n  respectively (see #getGaussianKernel for details); to fully control the result regardless of\n  possible future modifications of all this semantics, it is recommended to specify all of ksize,\n  sigmaX, and sigmaY.\n\n- **borderType**: `integer()`.\n\n  pixel extrapolation method, see #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and type as src.\n\nThe function convolves the source image with the specified Gaussian kernel. In-place filtering is\nsupported.\n\n@sa  sepFilter2D, filter2D, blur, boxFilter, bilateralFilter, medianBlur\n\nPython prototype (for reference only):\n```python3\nGaussianBlur(src, ksize, sigmaX[, dst[, sigmaY[, borderType]]]) -> dst\n```","ref":"Evision.html#gaussianBlur/4"},{"type":"function","title":"Evision.gemm/1","doc":"","ref":"Evision.html#gemm/1"},{"type":"function","title":"Evision.gemm/5","doc":"Performs generalized matrix multiplication.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first multiplied input matrix that could be real(CV_32FC1,\n  CV_64FC1) or complex(CV_32FC2, CV_64FC2).\n\n- **src2**: `Evision.Mat`.\n\n  second multiplied input matrix of the same type as src1.\n\n- **alpha**: `double`.\n\n  weight of the matrix product.\n\n- **src3**: `Evision.Mat`.\n\n  third optional delta matrix added to the matrix product; it\n  should have the same type as src1 and src2.\n\n- **beta**: `double`.\n\n  weight of src3.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  operation flags (cv::GemmFlags)\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output matrix; it has the proper size and the same type as\n  input matrices.\n\nThe function cv::gemm performs generalized matrix multiplication similar to the\ngemm functions in BLAS level 3. For example,\n`gemm(src1, src2, alpha, src3, beta, dst, GEMM_1_T + GEMM_3_T)`\ncorresponds to\n\\f[\\texttt{dst} =  \\texttt{alpha} \\cdot \\texttt{src1} ^T  \\cdot \\texttt{src2} +  \\texttt{beta} \\cdot \\texttt{src3} ^T\\f]\nIn case of complex (two-channel) data, performed a complex matrix\nmultiplication.\nThe function can be replaced with a matrix expression. For example, the\nabove call can be replaced with:\n```cpp\ndst = alpha*src1.t()*src2 + beta*src3.t();\n```\n@sa mulTransposed, transform\n\nPython prototype (for reference only):\n```python3\ngemm(src1, src2, alpha, src3, beta[, dst[, flags]]) -> dst\n```","ref":"Evision.html#gemm/5"},{"type":"function","title":"Evision.gemm/6","doc":"Performs generalized matrix multiplication.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first multiplied input matrix that could be real(CV_32FC1,\n  CV_64FC1) or complex(CV_32FC2, CV_64FC2).\n\n- **src2**: `Evision.Mat`.\n\n  second multiplied input matrix of the same type as src1.\n\n- **alpha**: `double`.\n\n  weight of the matrix product.\n\n- **src3**: `Evision.Mat`.\n\n  third optional delta matrix added to the matrix product; it\n  should have the same type as src1 and src2.\n\n- **beta**: `double`.\n\n  weight of src3.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  operation flags (cv::GemmFlags)\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output matrix; it has the proper size and the same type as\n  input matrices.\n\nThe function cv::gemm performs generalized matrix multiplication similar to the\ngemm functions in BLAS level 3. For example,\n`gemm(src1, src2, alpha, src3, beta, dst, GEMM_1_T + GEMM_3_T)`\ncorresponds to\n\\f[\\texttt{dst} =  \\texttt{alpha} \\cdot \\texttt{src1} ^T  \\cdot \\texttt{src2} +  \\texttt{beta} \\cdot \\texttt{src3} ^T\\f]\nIn case of complex (two-channel) data, performed a complex matrix\nmultiplication.\nThe function can be replaced with a matrix expression. For example, the\nabove call can be replaced with:\n```cpp\ndst = alpha*src1.t()*src2 + beta*src3.t();\n```\n@sa mulTransposed, transform\n\nPython prototype (for reference only):\n```python3\ngemm(src1, src2, alpha, src3, beta[, dst[, flags]]) -> dst\n```","ref":"Evision.html#gemm/6"},{"type":"function","title":"Evision.getAffineTransform/1","doc":"","ref":"Evision.html#getAffineTransform/1"},{"type":"function","title":"Evision.getAffineTransform/2","doc":"getAffineTransform\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n- **dst**: `Evision.Mat`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ngetAffineTransform(src, dst) -> retval\n```","ref":"Evision.html#getAffineTransform/2"},{"type":"function","title":"Evision.getBuildInformation/0","doc":"Returns full configuration time cmake output.\n##### Return\n- **retval**: `String`\n\nReturned value is raw cmake output including version control system revision, compiler version,\ncompiler flags, enabled modules and third party libraries, etc. Output format depends on target\narchitecture.\n\nPython prototype (for reference only):\n```python3\ngetBuildInformation() -> retval\n```","ref":"Evision.html#getBuildInformation/0"},{"type":"function","title":"Evision.getBuildInformation/1","doc":"","ref":"Evision.html#getBuildInformation/1"},{"type":"function","title":"Evision.getCPUFeaturesLine/0","doc":"Returns list of CPU features enabled during compilation.\n##### Return\n- **retval**: `string`\n\nReturned value is a string containing space separated list of CPU features with following markers:\n- no markers - baseline features\n- prefix `*` - features enabled in dispatcher\n- suffix `?` - features enabled but not available in HW\n\nExample: `SSE SSE2 SSE3 *SSE4.1 *SSE4.2 *FP16 *AVX *AVX2 *AVX512-SKX?`\n\nPython prototype (for reference only):\n```python3\ngetCPUFeaturesLine() -> retval\n```","ref":"Evision.html#getCPUFeaturesLine/0"},{"type":"function","title":"Evision.getCPUFeaturesLine/1","doc":"","ref":"Evision.html#getCPUFeaturesLine/1"},{"type":"function","title":"Evision.getCPUTickCount/0","doc":"Returns the number of CPU ticks.\n##### Return\n- **retval**: `int64`\n\nThe function returns the current number of CPU ticks on some architectures (such as x86, x64,\nPowerPC). On other platforms the function is equivalent to getTickCount. It can also be used for\nvery accurate time measurements, as well as for RNG initialization. Note that in case of multi-CPU\nsystems a thread, from which getCPUTickCount is called, can be suspended and resumed at another CPU\nwith its own counter. So, theoretically (and practically) the subsequent calls to the function do\nnot necessary return the monotonously increasing values. Also, since a modern CPU varies the CPU\nfrequency depending on the load, the number of CPU clocks spent in some code cannot be directly\nconverted to time units. Therefore, getTickCount is generally a preferable solution for measuring\nexecution time.\n\nPython prototype (for reference only):\n```python3\ngetCPUTickCount() -> retval\n```","ref":"Evision.html#getCPUTickCount/0"},{"type":"function","title":"Evision.getCPUTickCount/1","doc":"","ref":"Evision.html#getCPUTickCount/1"},{"type":"function","title":"Evision.getDefaultNewCameraMatrix/1","doc":"Returns the default new camera matrix.\n\n##### Positional Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input camera matrix.\n\n##### Keyword Arguments\n- **imgsize**: `Size`.\n\n  Camera view image size in pixels.\n\n- **centerPrincipalPoint**: `bool`.\n\n  Location of the principal point in the new camera matrix. The\n  parameter indicates whether this location should be at the image center or not.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nThe function returns the camera matrix that is either an exact copy of the input cameraMatrix (when\ncenterPrinicipalPoint=false ), or the modified one (when centerPrincipalPoint=true).\nIn the latter case, the new camera matrix will be:\n\\f[\\begin{bmatrix} f\\_x && 0 && ( \\texttt{imgSize.width} -1)\\*0.5  \\\\\\\\ 0 && f\\_y && ( \\texttt{imgSize.height} -1)\\*0.5  \\\\\\\\ 0 && 0 && 1 \\end{bmatrix} ,\\f]\nwhere \\f$f\\_x\\f$ and \\f$f\\_y\\f$ are \\f$(0,0)\\f$ and \\f$(1,1)\\f$ elements of cameraMatrix, respectively.\nBy default, the undistortion functions in OpenCV (see #initUndistortRectifyMap, #undistort) do not\nmove the principal point. However, when you work with stereo, it is important to move the principal\npoints in both views to the same y-coordinate (which is required by most of stereo correspondence\nalgorithms), and may be to the same x-coordinate too. So, you can form the new camera matrix for\neach view where the principal points are located at the center.\n\nPython prototype (for reference only):\n```python3\ngetDefaultNewCameraMatrix(cameraMatrix[, imgsize[, centerPrincipalPoint]]) -> retval\n```","ref":"Evision.html#getDefaultNewCameraMatrix/1"},{"type":"function","title":"Evision.getDefaultNewCameraMatrix/2","doc":"Returns the default new camera matrix.\n\n##### Positional Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input camera matrix.\n\n##### Keyword Arguments\n- **imgsize**: `Size`.\n\n  Camera view image size in pixels.\n\n- **centerPrincipalPoint**: `bool`.\n\n  Location of the principal point in the new camera matrix. The\n  parameter indicates whether this location should be at the image center or not.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nThe function returns the camera matrix that is either an exact copy of the input cameraMatrix (when\ncenterPrinicipalPoint=false ), or the modified one (when centerPrincipalPoint=true).\nIn the latter case, the new camera matrix will be:\n\\f[\\begin{bmatrix} f\\_x && 0 && ( \\texttt{imgSize.width} -1)\\*0.5  \\\\\\\\ 0 && f\\_y && ( \\texttt{imgSize.height} -1)\\*0.5  \\\\\\\\ 0 && 0 && 1 \\end{bmatrix} ,\\f]\nwhere \\f$f\\_x\\f$ and \\f$f\\_y\\f$ are \\f$(0,0)\\f$ and \\f$(1,1)\\f$ elements of cameraMatrix, respectively.\nBy default, the undistortion functions in OpenCV (see #initUndistortRectifyMap, #undistort) do not\nmove the principal point. However, when you work with stereo, it is important to move the principal\npoints in both views to the same y-coordinate (which is required by most of stereo correspondence\nalgorithms), and may be to the same x-coordinate too. So, you can form the new camera matrix for\neach view where the principal points are located at the center.\n\nPython prototype (for reference only):\n```python3\ngetDefaultNewCameraMatrix(cameraMatrix[, imgsize[, centerPrincipalPoint]]) -> retval\n```","ref":"Evision.html#getDefaultNewCameraMatrix/2"},{"type":"function","title":"Evision.getDerivKernels/1","doc":"","ref":"Evision.html#getDerivKernels/1"},{"type":"function","title":"Evision.getDerivKernels/3","doc":"Returns filter coefficients for computing spatial image derivatives.\n\n##### Positional Arguments\n- **dx**: `integer()`.\n\n  Derivative order in respect of x.\n\n- **dy**: `integer()`.\n\n  Derivative order in respect of y.\n\n- **ksize**: `integer()`.\n\n  Aperture size. It can be FILTER_SCHARR, 1, 3, 5, or 7.\n\n##### Keyword Arguments\n- **normalize**: `bool`.\n\n  Flag indicating whether to normalize (scale down) the filter coefficients or not.\n  Theoretically, the coefficients should have the denominator \\f$=2^{ksize*2-dx-dy-2}\\f$. If you are\n  going to filter floating-point images, you are likely to use the normalized kernels. But if you\n  compute derivatives of an 8-bit image, store the results in a 16-bit image, and wish to preserve\n  all the fractional bits, you may want to set normalize=false .\n\n- **ktype**: `integer()`.\n\n  Type of filter coefficients. It can be CV_32f or CV_64F .\n\n##### Return\n- **kx**: `Evision.Mat.t()`.\n\n  Output matrix of row filter coefficients. It has the type ktype .\n\n- **ky**: `Evision.Mat.t()`.\n\n  Output matrix of column filter coefficients. It has the type ktype .\n\nThe function computes and returns the filter coefficients for spatial image derivatives. When\n`ksize=FILTER_SCHARR`, the Scharr \\f$3 \\times 3\\f$ kernels are generated (see #Scharr). Otherwise, Sobel\nkernels are generated (see #Sobel). The filters are normally passed to #sepFilter2D or to\n\nPython prototype (for reference only):\n```python3\ngetDerivKernels(dx, dy, ksize[, kx[, ky[, normalize[, ktype]]]]) -> kx, ky\n```","ref":"Evision.html#getDerivKernels/3"},{"type":"function","title":"Evision.getDerivKernels/4","doc":"Returns filter coefficients for computing spatial image derivatives.\n\n##### Positional Arguments\n- **dx**: `integer()`.\n\n  Derivative order in respect of x.\n\n- **dy**: `integer()`.\n\n  Derivative order in respect of y.\n\n- **ksize**: `integer()`.\n\n  Aperture size. It can be FILTER_SCHARR, 1, 3, 5, or 7.\n\n##### Keyword Arguments\n- **normalize**: `bool`.\n\n  Flag indicating whether to normalize (scale down) the filter coefficients or not.\n  Theoretically, the coefficients should have the denominator \\f$=2^{ksize*2-dx-dy-2}\\f$. If you are\n  going to filter floating-point images, you are likely to use the normalized kernels. But if you\n  compute derivatives of an 8-bit image, store the results in a 16-bit image, and wish to preserve\n  all the fractional bits, you may want to set normalize=false .\n\n- **ktype**: `integer()`.\n\n  Type of filter coefficients. It can be CV_32f or CV_64F .\n\n##### Return\n- **kx**: `Evision.Mat.t()`.\n\n  Output matrix of row filter coefficients. It has the type ktype .\n\n- **ky**: `Evision.Mat.t()`.\n\n  Output matrix of column filter coefficients. It has the type ktype .\n\nThe function computes and returns the filter coefficients for spatial image derivatives. When\n`ksize=FILTER_SCHARR`, the Scharr \\f$3 \\times 3\\f$ kernels are generated (see #Scharr). Otherwise, Sobel\nkernels are generated (see #Sobel). The filters are normally passed to #sepFilter2D or to\n\nPython prototype (for reference only):\n```python3\ngetDerivKernels(dx, dy, ksize[, kx[, ky[, normalize[, ktype]]]]) -> kx, ky\n```","ref":"Evision.html#getDerivKernels/4"},{"type":"function","title":"Evision.getFontScaleFromHeight/1","doc":"","ref":"Evision.html#getFontScaleFromHeight/1"},{"type":"function","title":"Evision.getFontScaleFromHeight/2","doc":"Calculates the font-specific size to use to achieve a given height in pixels.\n\n##### Positional Arguments\n- **fontFace**: `integer()`.\n\n  Font to use, see cv::HersheyFonts.\n\n- **pixelHeight**: `integer()`.\n\n  Pixel height to compute the fontScale for\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n\n  Thickness of lines used to render the text.See putText for details.\n\n##### Return\n- **retval**: `double`\n\n@return The fontSize to use for cv::putText\n@see cv::putText\n\nPython prototype (for reference only):\n```python3\ngetFontScaleFromHeight(fontFace, pixelHeight[, thickness]) -> retval\n```","ref":"Evision.html#getFontScaleFromHeight/2"},{"type":"function","title":"Evision.getFontScaleFromHeight/3","doc":"Calculates the font-specific size to use to achieve a given height in pixels.\n\n##### Positional Arguments\n- **fontFace**: `integer()`.\n\n  Font to use, see cv::HersheyFonts.\n\n- **pixelHeight**: `integer()`.\n\n  Pixel height to compute the fontScale for\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n\n  Thickness of lines used to render the text.See putText for details.\n\n##### Return\n- **retval**: `double`\n\n@return The fontSize to use for cv::putText\n@see cv::putText\n\nPython prototype (for reference only):\n```python3\ngetFontScaleFromHeight(fontFace, pixelHeight[, thickness]) -> retval\n```","ref":"Evision.html#getFontScaleFromHeight/3"},{"type":"function","title":"Evision.getGaborKernel/1","doc":"","ref":"Evision.html#getGaborKernel/1"},{"type":"function","title":"Evision.getGaborKernel/5","doc":"Returns Gabor filter coefficients.\n\n##### Positional Arguments\n- **ksize**: `Size`.\n\n  Size of the filter returned.\n\n- **sigma**: `double`.\n\n  Standard deviation of the gaussian envelope.\n\n- **theta**: `double`.\n\n  Orientation of the normal to the parallel stripes of a Gabor function.\n\n- **lambd**: `double`.\n\n  Wavelength of the sinusoidal factor.\n\n- **gamma**: `double`.\n\n  Spatial aspect ratio.\n\n##### Keyword Arguments\n- **psi**: `double`.\n\n  Phase offset.\n\n- **ktype**: `integer()`.\n\n  Type of filter coefficients. It can be CV_32F or CV_64F .\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nFor more details about gabor filter equations and parameters, see: [Gabor\nFilter](http://en.wikipedia.org/wiki/Gabor_filter).\n\nPython prototype (for reference only):\n```python3\ngetGaborKernel(ksize, sigma, theta, lambd, gamma[, psi[, ktype]]) -> retval\n```","ref":"Evision.html#getGaborKernel/5"},{"type":"function","title":"Evision.getGaborKernel/6","doc":"Returns Gabor filter coefficients.\n\n##### Positional Arguments\n- **ksize**: `Size`.\n\n  Size of the filter returned.\n\n- **sigma**: `double`.\n\n  Standard deviation of the gaussian envelope.\n\n- **theta**: `double`.\n\n  Orientation of the normal to the parallel stripes of a Gabor function.\n\n- **lambd**: `double`.\n\n  Wavelength of the sinusoidal factor.\n\n- **gamma**: `double`.\n\n  Spatial aspect ratio.\n\n##### Keyword Arguments\n- **psi**: `double`.\n\n  Phase offset.\n\n- **ktype**: `integer()`.\n\n  Type of filter coefficients. It can be CV_32F or CV_64F .\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nFor more details about gabor filter equations and parameters, see: [Gabor\nFilter](http://en.wikipedia.org/wiki/Gabor_filter).\n\nPython prototype (for reference only):\n```python3\ngetGaborKernel(ksize, sigma, theta, lambd, gamma[, psi[, ktype]]) -> retval\n```","ref":"Evision.html#getGaborKernel/6"},{"type":"function","title":"Evision.getGaussianKernel/1","doc":"","ref":"Evision.html#getGaussianKernel/1"},{"type":"function","title":"Evision.getGaussianKernel/2","doc":"Returns Gaussian filter coefficients.\n\n##### Positional Arguments\n- **ksize**: `integer()`.\n\n  Aperture size. It should be odd ( \\f$\\texttt{ksize} \\mod 2 = 1\\f$ ) and positive.\n\n- **sigma**: `double`.\n\n  Gaussian standard deviation. If it is non-positive, it is computed from ksize as\n  `sigma = 0.3*((ksize-1)*0.5 - 1) + 0.8`.\n\n##### Keyword Arguments\n- **ktype**: `integer()`.\n\n  Type of filter coefficients. It can be CV_32F or CV_64F .\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nThe function computes and returns the \\f$\\texttt{ksize} \\times 1\\f$ matrix of Gaussian filter\ncoefficients:\n\\f[G\\_i= \\alpha \\*e^{-(i-( \\texttt{ksize} -1)/2)^2/(2\\* \\texttt{sigma}^2)},\\f]\nwhere \\f$i=0..\\texttt{ksize}-1\\f$ and \\f$\\alpha\\f$ is the scale factor chosen so that \\f$\\sum\\_i G\\_i=1\\f$.\nTwo of such generated kernels can be passed to sepFilter2D. Those functions automatically recognize\nsmoothing kernels (a symmetrical kernel with sum of weights equal to 1) and handle them accordingly.\nYou may also use the higher-level GaussianBlur.\n@sa  sepFilter2D, getDerivKernels, getStructuringElement, GaussianBlur\n\nPython prototype (for reference only):\n```python3\ngetGaussianKernel(ksize, sigma[, ktype]) -> retval\n```","ref":"Evision.html#getGaussianKernel/2"},{"type":"function","title":"Evision.getGaussianKernel/3","doc":"Returns Gaussian filter coefficients.\n\n##### Positional Arguments\n- **ksize**: `integer()`.\n\n  Aperture size. It should be odd ( \\f$\\texttt{ksize} \\mod 2 = 1\\f$ ) and positive.\n\n- **sigma**: `double`.\n\n  Gaussian standard deviation. If it is non-positive, it is computed from ksize as\n  `sigma = 0.3*((ksize-1)*0.5 - 1) + 0.8`.\n\n##### Keyword Arguments\n- **ktype**: `integer()`.\n\n  Type of filter coefficients. It can be CV_32F or CV_64F .\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nThe function computes and returns the \\f$\\texttt{ksize} \\times 1\\f$ matrix of Gaussian filter\ncoefficients:\n\\f[G\\_i= \\alpha \\*e^{-(i-( \\texttt{ksize} -1)/2)^2/(2\\* \\texttt{sigma}^2)},\\f]\nwhere \\f$i=0..\\texttt{ksize}-1\\f$ and \\f$\\alpha\\f$ is the scale factor chosen so that \\f$\\sum\\_i G\\_i=1\\f$.\nTwo of such generated kernels can be passed to sepFilter2D. Those functions automatically recognize\nsmoothing kernels (a symmetrical kernel with sum of weights equal to 1) and handle them accordingly.\nYou may also use the higher-level GaussianBlur.\n@sa  sepFilter2D, getDerivKernels, getStructuringElement, GaussianBlur\n\nPython prototype (for reference only):\n```python3\ngetGaussianKernel(ksize, sigma[, ktype]) -> retval\n```","ref":"Evision.html#getGaussianKernel/3"},{"type":"function","title":"Evision.getHardwareFeatureName/1","doc":"Returns feature name by ID\n\n##### Positional Arguments\n- **feature**: `integer()`\n\n##### Return\n- **retval**: `String`\n\nReturns empty string if feature is not defined\n\nPython prototype (for reference only):\n```python3\ngetHardwareFeatureName(feature) -> retval\n```","ref":"Evision.html#getHardwareFeatureName/1"},{"type":"function","title":"Evision.getLogLevel/0","doc":"getLogLevel\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetLogLevel() -> retval\n```","ref":"Evision.html#getLogLevel/0"},{"type":"function","title":"Evision.getLogLevel/1","doc":"","ref":"Evision.html#getLogLevel/1"},{"type":"function","title":"Evision.getNumberOfCPUs/0","doc":"Returns the number of logical CPUs available for the process.\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNumberOfCPUs() -> retval\n```","ref":"Evision.html#getNumberOfCPUs/0"},{"type":"function","title":"Evision.getNumberOfCPUs/1","doc":"","ref":"Evision.html#getNumberOfCPUs/1"},{"type":"function","title":"Evision.getNumThreads/0","doc":"Returns the number of threads used by OpenCV for parallel regions.\n##### Return\n- **retval**: `integer()`\n\nAlways returns 1 if OpenCV is built without threading support.\nThe exact meaning of return value depends on the threading framework used by OpenCV library:\n- `TBB` - The number of threads, that OpenCV will try to use for parallel regions. If there is\n  any tbb::thread_scheduler_init in user code conflicting with OpenCV, then function returns\n  default number of threads used by TBB library.\n\n- `OpenMP` - An upper bound on the number of threads that could be used to form a new team.\n- `Concurrency` - The number of threads, that OpenCV will try to use for parallel regions.\n- `GCD` - Unsupported; returns the GCD thread pool limit (512) for compatibility.\n- `C=` - The number of threads, that OpenCV will try to use for parallel regions, if before\n  called setNumThreads with threads \\> 0, otherwise returns the number of logical CPUs,\n  available for the process.\n\n@sa setNumThreads, getThreadNum\n\nPython prototype (for reference only):\n```python3\ngetNumThreads() -> retval\n```","ref":"Evision.html#getNumThreads/0"},{"type":"function","title":"Evision.getNumThreads/1","doc":"","ref":"Evision.html#getNumThreads/1"},{"type":"function","title":"Evision.getOptimalDFTSize/1","doc":"Returns the optimal DFT size for a given vector size.\n\n##### Positional Arguments\n- **vecsize**: `integer()`.\n\n  vector size.\n\n##### Return\n- **retval**: `integer()`\n\nDFT performance is not a monotonic function of a vector size. Therefore, when you calculate\nconvolution of two arrays or perform the spectral analysis of an array, it usually makes sense to\npad the input data with zeros to get a bit larger array that can be transformed much faster than the\noriginal one. Arrays whose size is a power-of-two (2, 4, 8, 16, 32, ...) are the fastest to process.\nThough, the arrays whose size is a product of 2's, 3's, and 5's (for example, 300 = 5\\*5\\*3\\*2\\*2)\nare also processed quite efficiently.\nThe function cv::getOptimalDFTSize returns the minimum number N that is greater than or equal to vecsize\nso that the DFT of a vector of size N can be processed efficiently. In the current implementation N\n= 2 ^p^ \\* 3 ^q^ \\* 5 ^r^ for some integer p, q, r.\nThe function returns a negative number if vecsize is too large (very close to INT_MAX ).\nWhile the function cannot be used directly to estimate the optimal vector size for DCT transform\n(since the current DCT implementation supports only even-size vectors), it can be easily processed\nas getOptimalDFTSize((vecsize+1)/2)\\*2.\n@sa dft, dct, idft, idct, mulSpectrums\n\nPython prototype (for reference only):\n```python3\ngetOptimalDFTSize(vecsize) -> retval\n```","ref":"Evision.html#getOptimalDFTSize/1"},{"type":"function","title":"Evision.getOptimalNewCameraMatrix/1","doc":"","ref":"Evision.html#getOptimalNewCameraMatrix/1"},{"type":"function","title":"Evision.getOptimalNewCameraMatrix/4","doc":"Returns the new camera intrinsic matrix based on the free scaling parameter.\n\n##### Positional Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input camera intrinsic matrix.\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$\\distcoeffs\\f$. If the vector is NULL/empty, the zero distortion coefficients are\n  assumed.\n\n- **imageSize**: `Size`.\n\n  Original image size.\n\n- **alpha**: `double`.\n\n  Free scaling parameter between 0 (when all the pixels in the undistorted image are\n  valid) and 1 (when all the source image pixels are retained in the undistorted image). See\n  #stereoRectify for details.\n\n##### Keyword Arguments\n- **newImgSize**: `Size`.\n\n  Image size after rectification. By default, it is set to imageSize .\n\n- **centerPrincipalPoint**: `bool`.\n\n  Optional flag that indicates whether in the new camera intrinsic matrix the\n  principal point should be at the image center or not. By default, the principal point is chosen to\n  best fit a subset of the source image (determined by alpha) to the corrected image.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **validPixROI**: `Rect*`.\n\n  Optional output rectangle that outlines all-good-pixels region in the\n  undistorted image. See roi1, roi2 description in #stereoRectify .\n\n@return new_camera_matrix Output new camera intrinsic matrix.\nThe function computes and returns the optimal new camera intrinsic matrix based on the free scaling parameter.\nBy varying this parameter, you may retrieve only sensible pixels alpha=0 , keep all the original\nimage pixels if there is valuable information in the corners alpha=1 , or get something in between.\nWhen alpha\\>0 , the undistorted result is likely to have some black pixels corresponding to\n\"virtual\" pixels outside of the captured distorted image. The original camera intrinsic matrix, distortion\ncoefficients, the computed new camera intrinsic matrix, and newImageSize should be passed to\n#initUndistortRectifyMap to produce the maps for #remap .\n\nPython prototype (for reference only):\n```python3\ngetOptimalNewCameraMatrix(cameraMatrix, distCoeffs, imageSize, alpha[, newImgSize[, centerPrincipalPoint]]) -> retval, validPixROI\n```","ref":"Evision.html#getOptimalNewCameraMatrix/4"},{"type":"function","title":"Evision.getOptimalNewCameraMatrix/5","doc":"Returns the new camera intrinsic matrix based on the free scaling parameter.\n\n##### Positional Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input camera intrinsic matrix.\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$\\distcoeffs\\f$. If the vector is NULL/empty, the zero distortion coefficients are\n  assumed.\n\n- **imageSize**: `Size`.\n\n  Original image size.\n\n- **alpha**: `double`.\n\n  Free scaling parameter between 0 (when all the pixels in the undistorted image are\n  valid) and 1 (when all the source image pixels are retained in the undistorted image). See\n  #stereoRectify for details.\n\n##### Keyword Arguments\n- **newImgSize**: `Size`.\n\n  Image size after rectification. By default, it is set to imageSize .\n\n- **centerPrincipalPoint**: `bool`.\n\n  Optional flag that indicates whether in the new camera intrinsic matrix the\n  principal point should be at the image center or not. By default, the principal point is chosen to\n  best fit a subset of the source image (determined by alpha) to the corrected image.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n- **validPixROI**: `Rect*`.\n\n  Optional output rectangle that outlines all-good-pixels region in the\n  undistorted image. See roi1, roi2 description in #stereoRectify .\n\n@return new_camera_matrix Output new camera intrinsic matrix.\nThe function computes and returns the optimal new camera intrinsic matrix based on the free scaling parameter.\nBy varying this parameter, you may retrieve only sensible pixels alpha=0 , keep all the original\nimage pixels if there is valuable information in the corners alpha=1 , or get something in between.\nWhen alpha\\>0 , the undistorted result is likely to have some black pixels corresponding to\n\"virtual\" pixels outside of the captured distorted image. The original camera intrinsic matrix, distortion\ncoefficients, the computed new camera intrinsic matrix, and newImageSize should be passed to\n#initUndistortRectifyMap to produce the maps for #remap .\n\nPython prototype (for reference only):\n```python3\ngetOptimalNewCameraMatrix(cameraMatrix, distCoeffs, imageSize, alpha[, newImgSize[, centerPrincipalPoint]]) -> retval, validPixROI\n```","ref":"Evision.html#getOptimalNewCameraMatrix/5"},{"type":"function","title":"Evision.getPerspectiveTransform/1","doc":"","ref":"Evision.html#getPerspectiveTransform/1"},{"type":"function","title":"Evision.getPerspectiveTransform/2","doc":"Calculates a perspective transform from four pairs of the corresponding points.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Coordinates of quadrangle vertices in the source image.\n\n- **dst**: `Evision.Mat`.\n\n  Coordinates of the corresponding quadrangle vertices in the destination image.\n\n##### Keyword Arguments\n- **solveMethod**: `integer()`.\n\n  method passed to cv::solve (#DecompTypes)\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nThe function calculates the \\f$3 \\times 3\\f$ matrix of a perspective transform so that:\n\\f[\\begin{bmatrix} t\\_i x'\\_i \\\\\\\\ t\\_i y'\\_i \\\\\\\\ t\\_i \\end{bmatrix} = \\texttt{map\\_matrix} \\cdot \\begin{bmatrix} x\\_i \\\\\\\\ y\\_i \\\\\\\\ 1 \\end{bmatrix}\\f]\nwhere\n\\f[dst(i)=(x'\\_i,y'\\_i), src(i)=(x\\_i, y\\_i), i=0,1,2,3\\f]\n\n@sa  findHomography, warpPerspective, perspectiveTransform\n\nPython prototype (for reference only):\n```python3\ngetPerspectiveTransform(src, dst[, solveMethod]) -> retval\n```","ref":"Evision.html#getPerspectiveTransform/2"},{"type":"function","title":"Evision.getPerspectiveTransform/3","doc":"Calculates a perspective transform from four pairs of the corresponding points.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Coordinates of quadrangle vertices in the source image.\n\n- **dst**: `Evision.Mat`.\n\n  Coordinates of the corresponding quadrangle vertices in the destination image.\n\n##### Keyword Arguments\n- **solveMethod**: `integer()`.\n\n  method passed to cv::solve (#DecompTypes)\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nThe function calculates the \\f$3 \\times 3\\f$ matrix of a perspective transform so that:\n\\f[\\begin{bmatrix} t\\_i x'\\_i \\\\\\\\ t\\_i y'\\_i \\\\\\\\ t\\_i \\end{bmatrix} = \\texttt{map\\_matrix} \\cdot \\begin{bmatrix} x\\_i \\\\\\\\ y\\_i \\\\\\\\ 1 \\end{bmatrix}\\f]\nwhere\n\\f[dst(i)=(x'\\_i,y'\\_i), src(i)=(x\\_i, y\\_i), i=0,1,2,3\\f]\n\n@sa  findHomography, warpPerspective, perspectiveTransform\n\nPython prototype (for reference only):\n```python3\ngetPerspectiveTransform(src, dst[, solveMethod]) -> retval\n```","ref":"Evision.html#getPerspectiveTransform/3"},{"type":"function","title":"Evision.getRectSubPix/1","doc":"","ref":"Evision.html#getRectSubPix/1"},{"type":"function","title":"Evision.getRectSubPix/3","doc":"Retrieves a pixel rectangle from an image with sub-pixel accuracy.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Source image.\n\n- **patchSize**: `Size`.\n\n  Size of the extracted patch.\n\n- **center**: `Point2f`.\n\n  Floating point coordinates of the center of the extracted rectangle within the\n  source image. The center must be inside the image.\n\n##### Keyword Arguments\n- **patchType**: `integer()`.\n\n  Depth of the extracted pixels. By default, they have the same depth as src .\n\n##### Return\n- **patch**: `Evision.Mat.t()`.\n\n  Extracted patch that has the size patchSize and the same number of channels as src .\n\nThe function getRectSubPix extracts pixels from src:\n\\f[patch(x, y) = src(x +  \\texttt{center.x} - ( \\texttt{dst.cols} -1)\\*0.5, y +  \\texttt{center.y} - ( \\texttt{dst.rows} -1)\\*0.5)\\f]\nwhere the values of the pixels at non-integer coordinates are retrieved using bilinear\ninterpolation. Every channel of multi-channel images is processed independently. Also\nthe image should be a single channel or three channel image. While the center of the\nrectangle must be inside the image, parts of the rectangle may be outside.\n\n@sa  warpAffine, warpPerspective\n\nPython prototype (for reference only):\n```python3\ngetRectSubPix(image, patchSize, center[, patch[, patchType]]) -> patch\n```","ref":"Evision.html#getRectSubPix/3"},{"type":"function","title":"Evision.getRectSubPix/4","doc":"Retrieves a pixel rectangle from an image with sub-pixel accuracy.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Source image.\n\n- **patchSize**: `Size`.\n\n  Size of the extracted patch.\n\n- **center**: `Point2f`.\n\n  Floating point coordinates of the center of the extracted rectangle within the\n  source image. The center must be inside the image.\n\n##### Keyword Arguments\n- **patchType**: `integer()`.\n\n  Depth of the extracted pixels. By default, they have the same depth as src .\n\n##### Return\n- **patch**: `Evision.Mat.t()`.\n\n  Extracted patch that has the size patchSize and the same number of channels as src .\n\nThe function getRectSubPix extracts pixels from src:\n\\f[patch(x, y) = src(x +  \\texttt{center.x} - ( \\texttt{dst.cols} -1)\\*0.5, y +  \\texttt{center.y} - ( \\texttt{dst.rows} -1)\\*0.5)\\f]\nwhere the values of the pixels at non-integer coordinates are retrieved using bilinear\ninterpolation. Every channel of multi-channel images is processed independently. Also\nthe image should be a single channel or three channel image. While the center of the\nrectangle must be inside the image, parts of the rectangle may be outside.\n\n@sa  warpAffine, warpPerspective\n\nPython prototype (for reference only):\n```python3\ngetRectSubPix(image, patchSize, center[, patch[, patchType]]) -> patch\n```","ref":"Evision.html#getRectSubPix/4"},{"type":"function","title":"Evision.getRotationMatrix2D/1","doc":"","ref":"Evision.html#getRotationMatrix2D/1"},{"type":"function","title":"Evision.getRotationMatrix2D/3","doc":"Calculates an affine matrix of 2D rotation.\n\n##### Positional Arguments\n- **center**: `Point2f`.\n\n  Center of the rotation in the source image.\n\n- **angle**: `double`.\n\n  Rotation angle in degrees. Positive values mean counter-clockwise rotation (the\n  coordinate origin is assumed to be the top-left corner).\n\n- **scale**: `double`.\n\n  Isotropic scale factor.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nThe function calculates the following matrix:\n\\f[\\begin{bmatrix} \\alpha &  \\beta & (1- \\alpha )  \\cdot \\texttt{center.x} -  \\beta \\cdot \\texttt{center.y} \\\\\\\\ - \\beta &  \\alpha &  \\beta \\cdot \\texttt{center.x} + (1- \\alpha )  \\cdot \\texttt{center.y} \\end{bmatrix}\\f]\nwhere\n\\f[\\begin{array}{l} \\alpha =  \\texttt{scale} \\cdot \\cos \\texttt{angle} , \\\\\\\\ \\beta =  \\texttt{scale} \\cdot \\sin \\texttt{angle} \\end{array}\\f]\nThe transformation maps the rotation center to itself. If this is not the target, adjust the shift.\n\n@sa  getAffineTransform, warpAffine, transform\n\nPython prototype (for reference only):\n```python3\ngetRotationMatrix2D(center, angle, scale) -> retval\n```","ref":"Evision.html#getRotationMatrix2D/3"},{"type":"function","title":"Evision.getStructuringElement/1","doc":"","ref":"Evision.html#getStructuringElement/1"},{"type":"function","title":"Evision.getStructuringElement/2","doc":"Returns a structuring element of the specified size and shape for morphological operations.\n\n##### Positional Arguments\n- **shape**: `integer()`.\n\n  Element shape that could be one of #MorphShapes\n\n- **ksize**: `Size`.\n\n  Size of the structuring element.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor position within the element. The default value \\f$(-1, -1)\\f$ means that the\n  anchor is at the center. Note that only the shape of a cross-shaped element depends on the anchor\n  position. In other cases the anchor just regulates how much the result of the morphological\n  operation is shifted.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nThe function constructs and returns the structuring element that can be further passed to #erode,\n#dilate or #morphologyEx. But you can also construct an arbitrary binary mask yourself and use it as\nthe structuring element.\n\nPython prototype (for reference only):\n```python3\ngetStructuringElement(shape, ksize[, anchor]) -> retval\n```","ref":"Evision.html#getStructuringElement/2"},{"type":"function","title":"Evision.getStructuringElement/3","doc":"Returns a structuring element of the specified size and shape for morphological operations.\n\n##### Positional Arguments\n- **shape**: `integer()`.\n\n  Element shape that could be one of #MorphShapes\n\n- **ksize**: `Size`.\n\n  Size of the structuring element.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor position within the element. The default value \\f$(-1, -1)\\f$ means that the\n  anchor is at the center. Note that only the shape of a cross-shaped element depends on the anchor\n  position. In other cases the anchor just regulates how much the result of the morphological\n  operation is shifted.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nThe function constructs and returns the structuring element that can be further passed to #erode,\n#dilate or #morphologyEx. But you can also construct an arbitrary binary mask yourself and use it as\nthe structuring element.\n\nPython prototype (for reference only):\n```python3\ngetStructuringElement(shape, ksize[, anchor]) -> retval\n```","ref":"Evision.html#getStructuringElement/3"},{"type":"function","title":"Evision.getTextSize/1","doc":"","ref":"Evision.html#getTextSize/1"},{"type":"function","title":"Evision.getTextSize/4","doc":"Calculates the width and height of a text string.\n\n##### Positional Arguments\n- **text**: `String`.\n\n  Input text string.\n\n- **fontFace**: `integer()`.\n\n  Font to use, see #HersheyFonts.\n\n- **fontScale**: `double`.\n\n  Font scale factor that is multiplied by the font-specific base size.\n\n- **thickness**: `integer()`.\n\n  Thickness of lines used to render the text. See #putText for details.\n\n##### Return\n- **retval**: `Size`\n- **baseLine**: `int*`.\n\n  y-coordinate of the baseline relative to the bottom-most text\n  point.\n\nThe function cv::getTextSize calculates and returns the size of a box that contains the specified text.\nThat is, the following code renders some text, the tight box surrounding it, and the baseline: :\n```\nString text = \"Funny text inside the box\";\nint fontFace = FONT_HERSHEY_SCRIPT_SIMPLEX;\ndouble fontScale = 2;\nint thickness = 3;\nMat img(600, 800, CV_8UC3, Scalar::all(0));\nint baseline=0;\nSize textSize = getTextSize(text, fontFace,\nfontScale, thickness, &baseline);\nbaseline += thickness;\n// center the text\nPoint textOrg((img.cols - textSize.width)/2,\n(img.rows + textSize.height)/2);\n// draw the box\nrectangle(img, textOrg + Point(0, baseline),\ntextOrg + Point(textSize.width, -textSize.height),\nScalar(0,0,255));\n// ... and the baseline first\nline(img, textOrg + Point(0, thickness),\ntextOrg + Point(textSize.width, thickness),\nScalar(0, 0, 255));\n// then put the text itself\nputText(img, text, textOrg, fontFace, fontScale,\nScalar::all(255), thickness, 8);\n```\n@return The size of a box that contains the specified text.\n@see putText\n\nPython prototype (for reference only):\n```python3\ngetTextSize(text, fontFace, fontScale, thickness) -> retval, baseLine\n```","ref":"Evision.html#getTextSize/4"},{"type":"function","title":"Evision.getThreadNum/0","doc":"Returns the index of the currently executed thread within the current parallel region. Always\nreturns 0 if called outside of parallel region.\n\n##### Return\n- **retval**: `integer()`\n\n@deprecated Current implementation doesn't corresponding to this documentation.\nThe exact meaning of the return value depends on the threading framework used by OpenCV library:\n- `TBB` - Unsupported with current 4.1 TBB release. Maybe will be supported in future.\n- `OpenMP` - The thread number, within the current team, of the calling thread.\n- `Concurrency` - An ID for the virtual processor that the current context is executing on (0\n  for master thread and unique number for others, but not necessary 1,2,3,...).\n\n- `GCD` - System calling thread's ID. Never returns 0 inside parallel region.\n- `C=` - The index of the current parallel task.\n@sa setNumThreads, getNumThreads\n\nPython prototype (for reference only):\n```python3\ngetThreadNum() -> retval\n```","ref":"Evision.html#getThreadNum/0"},{"type":"function","title":"Evision.getThreadNum/1","doc":"","ref":"Evision.html#getThreadNum/1"},{"type":"function","title":"Evision.getTickCount/0","doc":"Returns the number of ticks.\n##### Return\n- **retval**: `int64`\n\nThe function returns the number of ticks after the certain event (for example, when the machine was\nturned on). It can be used to initialize RNG or to measure a function execution time by reading the\ntick count before and after the function call.\n@sa getTickFrequency, TickMeter\n\nPython prototype (for reference only):\n```python3\ngetTickCount() -> retval\n```","ref":"Evision.html#getTickCount/0"},{"type":"function","title":"Evision.getTickCount/1","doc":"","ref":"Evision.html#getTickCount/1"},{"type":"function","title":"Evision.getTickFrequency/0","doc":"Returns the number of ticks per second.\n##### Return\n- **retval**: `double`\n\nThe function returns the number of ticks per second. That is, the following code computes the\nexecution time in seconds:\n```\ndouble t = (double)getTickCount();\n// do something ...\nt = ((double)getTickCount() - t)/getTickFrequency();\n```\n@sa getTickCount, TickMeter\n\nPython prototype (for reference only):\n```python3\ngetTickFrequency() -> retval\n```","ref":"Evision.html#getTickFrequency/0"},{"type":"function","title":"Evision.getTickFrequency/1","doc":"","ref":"Evision.html#getTickFrequency/1"},{"type":"function","title":"Evision.getTrackbarPos/1","doc":"","ref":"Evision.html#getTrackbarPos/1"},{"type":"function","title":"Evision.getTrackbarPos/2","doc":"Returns the trackbar position.\n\n##### Positional Arguments\n- **trackbarname**: `String`.\n\n  Name of the trackbar.\n\n- **winname**: `String`.\n\n  Name of the window that is the parent of the trackbar.\n\n##### Return\n- **retval**: `integer()`\n\nThe function returns the current position of the specified trackbar.\n**Note**: [__Qt Backend Only__] winname can be empty if the trackbar is attached to the control\npanel.\n\nPython prototype (for reference only):\n```python3\ngetTrackbarPos(trackbarname, winname) -> retval\n```","ref":"Evision.html#getTrackbarPos/2"},{"type":"function","title":"Evision.getValidDisparityROI/1","doc":"","ref":"Evision.html#getValidDisparityROI/1"},{"type":"function","title":"Evision.getValidDisparityROI/5","doc":"getValidDisparityROI\n\n##### Positional Arguments\n- **roi1**: `Rect`\n- **roi2**: `Rect`\n- **minDisparity**: `integer()`\n- **numberOfDisparities**: `integer()`\n- **blockSize**: `integer()`\n\n##### Return\n- **retval**: `Rect`\n\nPython prototype (for reference only):\n```python3\ngetValidDisparityROI(roi1, roi2, minDisparity, numberOfDisparities, blockSize) -> retval\n```","ref":"Evision.html#getValidDisparityROI/5"},{"type":"function","title":"Evision.getVersionMajor/0","doc":"Returns major library version\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetVersionMajor() -> retval\n```","ref":"Evision.html#getVersionMajor/0"},{"type":"function","title":"Evision.getVersionMajor/1","doc":"","ref":"Evision.html#getVersionMajor/1"},{"type":"function","title":"Evision.getVersionMinor/0","doc":"Returns minor library version\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetVersionMinor() -> retval\n```","ref":"Evision.html#getVersionMinor/0"},{"type":"function","title":"Evision.getVersionMinor/1","doc":"","ref":"Evision.html#getVersionMinor/1"},{"type":"function","title":"Evision.getVersionRevision/0","doc":"Returns revision field of the library version\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetVersionRevision() -> retval\n```","ref":"Evision.html#getVersionRevision/0"},{"type":"function","title":"Evision.getVersionRevision/1","doc":"","ref":"Evision.html#getVersionRevision/1"},{"type":"function","title":"Evision.getVersionString/0","doc":"Returns library version string\n##### Return\n- **retval**: `String`\n\nFor example \"3.4.1-dev\".\n@sa getMajorVersion, getMinorVersion, getRevisionVersion\n\nPython prototype (for reference only):\n```python3\ngetVersionString() -> retval\n```","ref":"Evision.html#getVersionString/0"},{"type":"function","title":"Evision.getVersionString/1","doc":"","ref":"Evision.html#getVersionString/1"},{"type":"function","title":"Evision.getWindowImageRect/1","doc":"Provides rectangle of image in the window.\n\n##### Positional Arguments\n- **winname**: `String`.\n\n  Name of the window.\n\n##### Return\n- **retval**: `Rect`\n\nThe function getWindowImageRect returns the client screen coordinates, width and height of the image rendering area.\n\n@sa resizeWindow moveWindow\n**Note**: [__Wayland Backend Only__] This function is not supported by the Wayland protocol limitation.\n\nPython prototype (for reference only):\n```python3\ngetWindowImageRect(winname) -> retval\n```","ref":"Evision.html#getWindowImageRect/1"},{"type":"function","title":"Evision.getWindowProperty/1","doc":"","ref":"Evision.html#getWindowProperty/1"},{"type":"function","title":"Evision.getWindowProperty/2","doc":"Provides parameters of a window.\n\n##### Positional Arguments\n- **winname**: `String`.\n\n  Name of the window.\n\n- **prop_id**: `integer()`.\n\n  Window property to retrieve. The following operation flags are available: (cv::WindowPropertyFlags)\n\n##### Return\n- **retval**: `double`\n\nThe function getWindowProperty returns properties of a window.\n\n@sa setWindowProperty\n**Note**: [__Wayland Backend Only__] This function is not supported.\n\nPython prototype (for reference only):\n```python3\ngetWindowProperty(winname, prop_id) -> retval\n```","ref":"Evision.html#getWindowProperty/2"},{"type":"function","title":"Evision.goodFeaturesToTrack/1","doc":"","ref":"Evision.html#goodFeaturesToTrack/1"},{"type":"function","title":"Evision.goodFeaturesToTrack/4","doc":"Determines strong corners on an image.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Input 8-bit or floating-point 32-bit, single-channel image.\n\n- **maxCorners**: `integer()`.\n\n  Maximum number of corners to return. If there are more corners than are found,\n  the strongest of them is returned. `maxCorners <= 0` implies that no limit on the maximum is set\n  and all detected corners are returned.\n\n- **qualityLevel**: `double`.\n\n  Parameter characterizing the minimal accepted quality of image corners. The\n  parameter value is multiplied by the best corner quality measure, which is the minimal eigenvalue\n  (see #cornerMinEigenVal ) or the Harris function response (see #cornerHarris ). The corners with the\n  quality measure less than the product are rejected. For example, if the best corner has the\n  quality measure = 1500, and the qualityLevel=0.01 , then all the corners with the quality measure\n  less than 15 are rejected.\n\n- **minDistance**: `double`.\n\n  Minimum possible Euclidean distance between the returned corners.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional region of interest. If the image is not empty (it needs to have the type\n  CV_8UC1 and the same size as image ), it specifies the region in which the corners are detected.\n\n- **blockSize**: `integer()`.\n\n  Size of an average block for computing a derivative covariation matrix over each\n  pixel neighborhood. See cornerEigenValsAndVecs .\n\n- **useHarrisDetector**: `bool`.\n\n  Parameter indicating whether to use a Harris detector (see #cornerHarris)\n  or #cornerMinEigenVal.\n\n- **k**: `double`.\n\n  Free parameter of the Harris detector.\n\n##### Return\n- **corners**: `Evision.Mat.t()`.\n\n  Output vector of detected corners.\n\nThe function finds the most prominent corners in the image or in the specified image region, as\ndescribed in @cite Shi94\n- Function calculates the corner quality measure at every source image pixel using the\n  #cornerMinEigenVal or #cornerHarris .\n\n- Function performs a non-maximum suppression (the local maximums in *3 x 3* neighborhood are\n  retained).\n\n- The corners with the minimal eigenvalue less than\n  \\f$\\texttt{qualityLevel} \\cdot \\max\\_{x,y} qualityMeasureMap(x,y)\\f$ are rejected.\n\n- The remaining corners are sorted by the quality measure in the descending order.\n- Function throws away each corner for which there is a stronger corner at a distance less than\n  maxDistance.\n\nThe function can be used to initialize a point-based tracker of an object.\n**Note**: If the function is called with different values A and B of the parameter qualityLevel , and\nA \\> B, the vector of returned corners with qualityLevel=A will be the prefix of the output vector\nwith qualityLevel=B .\n\n@sa  cornerMinEigenVal, cornerHarris, calcOpticalFlowPyrLK, estimateRigidTransform,\n\nPython prototype (for reference only):\n```python3\ngoodFeaturesToTrack(image, maxCorners, qualityLevel, minDistance[, corners[, mask[, blockSize[, useHarrisDetector[, k]]]]]) -> corners\n```","ref":"Evision.html#goodFeaturesToTrack/4"},{"type":"function","title":"Evision.goodFeaturesToTrack/5","doc":"Determines strong corners on an image.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Input 8-bit or floating-point 32-bit, single-channel image.\n\n- **maxCorners**: `integer()`.\n\n  Maximum number of corners to return. If there are more corners than are found,\n  the strongest of them is returned. `maxCorners <= 0` implies that no limit on the maximum is set\n  and all detected corners are returned.\n\n- **qualityLevel**: `double`.\n\n  Parameter characterizing the minimal accepted quality of image corners. The\n  parameter value is multiplied by the best corner quality measure, which is the minimal eigenvalue\n  (see #cornerMinEigenVal ) or the Harris function response (see #cornerHarris ). The corners with the\n  quality measure less than the product are rejected. For example, if the best corner has the\n  quality measure = 1500, and the qualityLevel=0.01 , then all the corners with the quality measure\n  less than 15 are rejected.\n\n- **minDistance**: `double`.\n\n  Minimum possible Euclidean distance between the returned corners.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional region of interest. If the image is not empty (it needs to have the type\n  CV_8UC1 and the same size as image ), it specifies the region in which the corners are detected.\n\n- **blockSize**: `integer()`.\n\n  Size of an average block for computing a derivative covariation matrix over each\n  pixel neighborhood. See cornerEigenValsAndVecs .\n\n- **useHarrisDetector**: `bool`.\n\n  Parameter indicating whether to use a Harris detector (see #cornerHarris)\n  or #cornerMinEigenVal.\n\n- **k**: `double`.\n\n  Free parameter of the Harris detector.\n\n##### Return\n- **corners**: `Evision.Mat.t()`.\n\n  Output vector of detected corners.\n\nThe function finds the most prominent corners in the image or in the specified image region, as\ndescribed in @cite Shi94\n- Function calculates the corner quality measure at every source image pixel using the\n  #cornerMinEigenVal or #cornerHarris .\n\n- Function performs a non-maximum suppression (the local maximums in *3 x 3* neighborhood are\n  retained).\n\n- The corners with the minimal eigenvalue less than\n  \\f$\\texttt{qualityLevel} \\cdot \\max\\_{x,y} qualityMeasureMap(x,y)\\f$ are rejected.\n\n- The remaining corners are sorted by the quality measure in the descending order.\n- Function throws away each corner for which there is a stronger corner at a distance less than\n  maxDistance.\n\nThe function can be used to initialize a point-based tracker of an object.\n**Note**: If the function is called with different values A and B of the parameter qualityLevel , and\nA \\> B, the vector of returned corners with qualityLevel=A will be the prefix of the output vector\nwith qualityLevel=B .\n\n@sa  cornerMinEigenVal, cornerHarris, calcOpticalFlowPyrLK, estimateRigidTransform,\n\nPython prototype (for reference only):\n```python3\ngoodFeaturesToTrack(image, maxCorners, qualityLevel, minDistance[, corners[, mask[, blockSize[, useHarrisDetector[, k]]]]]) -> corners\n```","ref":"Evision.html#goodFeaturesToTrack/5"},{"type":"function","title":"Evision.goodFeaturesToTrack/7","doc":"goodFeaturesToTrack\n\n##### Positional Arguments\n- **image**: `Evision.Mat`\n- **maxCorners**: `integer()`\n- **qualityLevel**: `double`\n- **minDistance**: `double`\n- **mask**: `Evision.Mat`\n- **blockSize**: `integer()`\n- **gradientSize**: `integer()`\n\n##### Keyword Arguments\n- **useHarrisDetector**: `bool`.\n- **k**: `double`.\n\n##### Return\n- **corners**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngoodFeaturesToTrack(image, maxCorners, qualityLevel, minDistance, mask, blockSize, gradientSize[, corners[, useHarrisDetector[, k]]]) -> corners\n```","ref":"Evision.html#goodFeaturesToTrack/7"},{"type":"function","title":"Evision.goodFeaturesToTrack/8","doc":"goodFeaturesToTrack\n\n##### Positional Arguments\n- **image**: `Evision.Mat`\n- **maxCorners**: `integer()`\n- **qualityLevel**: `double`\n- **minDistance**: `double`\n- **mask**: `Evision.Mat`\n- **blockSize**: `integer()`\n- **gradientSize**: `integer()`\n\n##### Keyword Arguments\n- **useHarrisDetector**: `bool`.\n- **k**: `double`.\n\n##### Return\n- **corners**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngoodFeaturesToTrack(image, maxCorners, qualityLevel, minDistance, mask, blockSize, gradientSize[, corners[, useHarrisDetector[, k]]]) -> corners\n```","ref":"Evision.html#goodFeaturesToTrack/8"},{"type":"function","title":"Evision.goodFeaturesToTrackWithQuality/1","doc":"","ref":"Evision.html#goodFeaturesToTrackWithQuality/1"},{"type":"function","title":"Evision.goodFeaturesToTrackWithQuality/5","doc":"Same as above, but returns also quality measure of the detected corners.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Input 8-bit or floating-point 32-bit, single-channel image.\n\n- **maxCorners**: `integer()`.\n\n  Maximum number of corners to return. If there are more corners than are found,\n  the strongest of them is returned. `maxCorners <= 0` implies that no limit on the maximum is set\n  and all detected corners are returned.\n\n- **qualityLevel**: `double`.\n\n  Parameter characterizing the minimal accepted quality of image corners. The\n  parameter value is multiplied by the best corner quality measure, which is the minimal eigenvalue\n  (see #cornerMinEigenVal ) or the Harris function response (see #cornerHarris ). The corners with the\n  quality measure less than the product are rejected. For example, if the best corner has the\n  quality measure = 1500, and the qualityLevel=0.01 , then all the corners with the quality measure\n  less than 15 are rejected.\n\n- **minDistance**: `double`.\n\n  Minimum possible Euclidean distance between the returned corners.\n\n- **mask**: `Evision.Mat`.\n\n  Region of interest. If the image is not empty (it needs to have the type\n  CV_8UC1 and the same size as image ), it specifies the region in which the corners are detected.\n\n##### Keyword Arguments\n- **blockSize**: `integer()`.\n\n  Size of an average block for computing a derivative covariation matrix over each\n  pixel neighborhood. See cornerEigenValsAndVecs .\n\n- **gradientSize**: `integer()`.\n\n  Aperture parameter for the Sobel operator used for derivatives computation.\n  See cornerEigenValsAndVecs .\n\n- **useHarrisDetector**: `bool`.\n\n  Parameter indicating whether to use a Harris detector (see #cornerHarris)\n  or #cornerMinEigenVal.\n\n- **k**: `double`.\n\n  Free parameter of the Harris detector.\n\n##### Return\n- **corners**: `Evision.Mat.t()`.\n\n  Output vector of detected corners.\n\n- **cornersQuality**: `Evision.Mat.t()`.\n\n  Output vector of quality measure of the detected corners.\n\nPython prototype (for reference only):\n```python3\ngoodFeaturesToTrackWithQuality(image, maxCorners, qualityLevel, minDistance, mask[, corners[, cornersQuality[, blockSize[, gradientSize[, useHarrisDetector[, k]]]]]]) -> corners, cornersQuality\n```","ref":"Evision.html#goodFeaturesToTrackWithQuality/5"},{"type":"function","title":"Evision.goodFeaturesToTrackWithQuality/6","doc":"Same as above, but returns also quality measure of the detected corners.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Input 8-bit or floating-point 32-bit, single-channel image.\n\n- **maxCorners**: `integer()`.\n\n  Maximum number of corners to return. If there are more corners than are found,\n  the strongest of them is returned. `maxCorners <= 0` implies that no limit on the maximum is set\n  and all detected corners are returned.\n\n- **qualityLevel**: `double`.\n\n  Parameter characterizing the minimal accepted quality of image corners. The\n  parameter value is multiplied by the best corner quality measure, which is the minimal eigenvalue\n  (see #cornerMinEigenVal ) or the Harris function response (see #cornerHarris ). The corners with the\n  quality measure less than the product are rejected. For example, if the best corner has the\n  quality measure = 1500, and the qualityLevel=0.01 , then all the corners with the quality measure\n  less than 15 are rejected.\n\n- **minDistance**: `double`.\n\n  Minimum possible Euclidean distance between the returned corners.\n\n- **mask**: `Evision.Mat`.\n\n  Region of interest. If the image is not empty (it needs to have the type\n  CV_8UC1 and the same size as image ), it specifies the region in which the corners are detected.\n\n##### Keyword Arguments\n- **blockSize**: `integer()`.\n\n  Size of an average block for computing a derivative covariation matrix over each\n  pixel neighborhood. See cornerEigenValsAndVecs .\n\n- **gradientSize**: `integer()`.\n\n  Aperture parameter for the Sobel operator used for derivatives computation.\n  See cornerEigenValsAndVecs .\n\n- **useHarrisDetector**: `bool`.\n\n  Parameter indicating whether to use a Harris detector (see #cornerHarris)\n  or #cornerMinEigenVal.\n\n- **k**: `double`.\n\n  Free parameter of the Harris detector.\n\n##### Return\n- **corners**: `Evision.Mat.t()`.\n\n  Output vector of detected corners.\n\n- **cornersQuality**: `Evision.Mat.t()`.\n\n  Output vector of quality measure of the detected corners.\n\nPython prototype (for reference only):\n```python3\ngoodFeaturesToTrackWithQuality(image, maxCorners, qualityLevel, minDistance, mask[, corners[, cornersQuality[, blockSize[, gradientSize[, useHarrisDetector[, k]]]]]]) -> corners, cornersQuality\n```","ref":"Evision.html#goodFeaturesToTrackWithQuality/6"},{"type":"function","title":"Evision.grabCut/1","doc":"","ref":"Evision.html#grabCut/1"},{"type":"function","title":"Evision.grabCut/6","doc":"Runs the GrabCut algorithm.\n\n##### Positional Arguments\n- **img**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n- **rect**: `Rect`.\n\n  ROI containing a segmented object. The pixels outside of the ROI are marked as\n  \"obvious background\". The parameter is only used when mode==#GC_INIT_WITH_RECT .\n\n- **iterCount**: `integer()`.\n\n  Number of iterations the algorithm should make before returning the result. Note\n  that the result can be refined with further calls with mode==#GC_INIT_WITH_MASK or\n  mode==GC_EVAL .\n\n##### Keyword Arguments\n- **mode**: `integer()`.\n\n  Operation mode that could be one of the #GrabCutModes\n\n##### Return\n- **mask**: `Evision.Mat.t()`.\n\n  Input/output 8-bit single-channel mask. The mask is initialized by the function when\n  mode is set to #GC_INIT_WITH_RECT. Its elements may have one of the #GrabCutClasses.\n\n- **bgdModel**: `Evision.Mat.t()`.\n\n  Temporary array for the background model. Do not modify it while you are\n  processing the same image.\n\n- **fgdModel**: `Evision.Mat.t()`.\n\n  Temporary arrays for the foreground model. Do not modify it while you are\n  processing the same image.\n\nThe function implements the [GrabCut image segmentation algorithm](http://en.wikipedia.org/wiki/GrabCut).\n\nPython prototype (for reference only):\n```python3\ngrabCut(img, mask, rect, bgdModel, fgdModel, iterCount[, mode]) -> mask, bgdModel, fgdModel\n```","ref":"Evision.html#grabCut/6"},{"type":"function","title":"Evision.grabCut/7","doc":"Runs the GrabCut algorithm.\n\n##### Positional Arguments\n- **img**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n- **rect**: `Rect`.\n\n  ROI containing a segmented object. The pixels outside of the ROI are marked as\n  \"obvious background\". The parameter is only used when mode==#GC_INIT_WITH_RECT .\n\n- **iterCount**: `integer()`.\n\n  Number of iterations the algorithm should make before returning the result. Note\n  that the result can be refined with further calls with mode==#GC_INIT_WITH_MASK or\n  mode==GC_EVAL .\n\n##### Keyword Arguments\n- **mode**: `integer()`.\n\n  Operation mode that could be one of the #GrabCutModes\n\n##### Return\n- **mask**: `Evision.Mat.t()`.\n\n  Input/output 8-bit single-channel mask. The mask is initialized by the function when\n  mode is set to #GC_INIT_WITH_RECT. Its elements may have one of the #GrabCutClasses.\n\n- **bgdModel**: `Evision.Mat.t()`.\n\n  Temporary array for the background model. Do not modify it while you are\n  processing the same image.\n\n- **fgdModel**: `Evision.Mat.t()`.\n\n  Temporary arrays for the foreground model. Do not modify it while you are\n  processing the same image.\n\nThe function implements the [GrabCut image segmentation algorithm](http://en.wikipedia.org/wiki/GrabCut).\n\nPython prototype (for reference only):\n```python3\ngrabCut(img, mask, rect, bgdModel, fgdModel, iterCount[, mode]) -> mask, bgdModel, fgdModel\n```","ref":"Evision.html#grabCut/7"},{"type":"function","title":"Evision.groupRectangles/1","doc":"","ref":"Evision.html#groupRectangles/1"},{"type":"function","title":"Evision.groupRectangles/2","doc":"groupRectangles\n\n##### Positional Arguments\n- **groupThreshold**: `integer()`\n\n##### Keyword Arguments\n- **eps**: `double`.\n\n##### Return\n- **rectList**: `[Rect]`\n- **weights**: `[integer()]`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ngroupRectangles(rectList, groupThreshold[, eps]) -> rectList, weights\n```","ref":"Evision.html#groupRectangles/2"},{"type":"function","title":"Evision.groupRectangles/3","doc":"groupRectangles\n\n##### Positional Arguments\n- **groupThreshold**: `integer()`\n\n##### Keyword Arguments\n- **eps**: `double`.\n\n##### Return\n- **rectList**: `[Rect]`\n- **weights**: `[integer()]`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ngroupRectangles(rectList, groupThreshold[, eps]) -> rectList, weights\n```","ref":"Evision.html#groupRectangles/3"},{"type":"function","title":"Evision.hasNonZero/1","doc":"Checks for the presence of at least one non-zero array element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  single-channel array.\n\n##### Return\n- **retval**: `bool`\n\nThe function returns whether there are non-zero elements in src\nThe function do not work with multi-channel arrays. If you need to check non-zero array\nelements across all the channels, use Mat::reshape first to reinterpret the array as\nsingle-channel. Or you may extract the particular channel using either extractImageCOI, or\nmixChannels, or split.\n**Note**: \n- If the location of non-zero array elements is important, @ref findNonZero is helpful.\n- If the count of non-zero array elements is important, @ref countNonZero is helpful.\n@sa  mean, meanStdDev, norm, minMaxLoc, calcCovarMatrix\n@sa  findNonZero, countNonZero\n\nPython prototype (for reference only):\n```python3\nhasNonZero(src) -> retval\n```","ref":"Evision.html#hasNonZero/1"},{"type":"function","title":"Evision.haveImageReader/1","doc":"Returns true if the specified image can be decoded by OpenCV\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  File name of the image\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nhaveImageReader(filename) -> retval\n```","ref":"Evision.html#haveImageReader/1"},{"type":"function","title":"Evision.haveImageWriter/1","doc":"Returns true if an image with the specified filename can be encoded by OpenCV\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  File name of the image\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nhaveImageWriter(filename) -> retval\n```","ref":"Evision.html#haveImageWriter/1"},{"type":"function","title":"Evision.haveOpenVX/0","doc":"haveOpenVX\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nhaveOpenVX() -> retval\n```","ref":"Evision.html#haveOpenVX/0"},{"type":"function","title":"Evision.haveOpenVX/1","doc":"","ref":"Evision.html#haveOpenVX/1"},{"type":"function","title":"Evision.hconcat/1","doc":"hconcat\n\n##### Positional Arguments\n- **src**: `[Evision.Mat]`.\n\n  input array or vector of matrices. all of the matrices must have the same number of rows and the same depth.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array. It has the same number of rows and depth as the src, and the sum of cols of the src.\n  same depth.\n\nHas overloading in C++\n\n```cpp\nstd::vector  matrices = { cv::Mat(4, 1, CV_8UC1, cv::Scalar(1)),\ncv::Mat(4, 1, CV_8UC1, cv::Scalar(2)),\ncv::Mat(4, 1, CV_8UC1, cv::Scalar(3)),};\ncv::Mat out;\ncv::hconcat( matrices, out );\n//out:\n//[1, 2, 3;\n// 1, 2, 3;\n// 1, 2, 3;\n// 1, 2, 3]\n```\n\nPython prototype (for reference only):\n```python3\nhconcat(src[, dst]) -> dst\n```","ref":"Evision.html#hconcat/1"},{"type":"function","title":"Evision.hconcat/2","doc":"hconcat\n\n##### Positional Arguments\n- **src**: `[Evision.Mat]`.\n\n  input array or vector of matrices. all of the matrices must have the same number of rows and the same depth.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array. It has the same number of rows and depth as the src, and the sum of cols of the src.\n  same depth.\n\nHas overloading in C++\n\n```cpp\nstd::vector  matrices = { cv::Mat(4, 1, CV_8UC1, cv::Scalar(1)),\ncv::Mat(4, 1, CV_8UC1, cv::Scalar(2)),\ncv::Mat(4, 1, CV_8UC1, cv::Scalar(3)),};\ncv::Mat out;\ncv::hconcat( matrices, out );\n//out:\n//[1, 2, 3;\n// 1, 2, 3;\n// 1, 2, 3;\n// 1, 2, 3]\n```\n\nPython prototype (for reference only):\n```python3\nhconcat(src[, dst]) -> dst\n```","ref":"Evision.html#hconcat/2"},{"type":"function","title":"Evision.houghCircles/1","doc":"","ref":"Evision.html#houghCircles/1"},{"type":"function","title":"Evision.houghCircles/4","doc":"Finds circles in a grayscale image using the Hough transform.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  8-bit, single-channel, grayscale input image.\n\n- **method**: `integer()`.\n\n  Detection method, see #HoughModes. The available methods are #HOUGH_GRADIENT and #HOUGH_GRADIENT_ALT.\n\n- **dp**: `double`.\n\n  Inverse ratio of the accumulator resolution to the image resolution. For example, if\n  dp=1 , the accumulator has the same resolution as the input image. If dp=2 , the accumulator has\n  half as big width and height. For #HOUGH_GRADIENT_ALT the recommended value is dp=1.5,\n  unless some small very circles need to be detected.\n\n- **minDist**: `double`.\n\n  Minimum distance between the centers of the detected circles. If the parameter is\n  too small, multiple neighbor circles may be falsely detected in addition to a true one. If it is\n  too large, some circles may be missed.\n\n##### Keyword Arguments\n- **param1**: `double`.\n\n  First method-specific parameter. In case of #HOUGH_GRADIENT and #HOUGH_GRADIENT_ALT,\n  it is the higher threshold of the two passed to the Canny edge detector (the lower one is twice smaller).\n  Note that #HOUGH_GRADIENT_ALT uses #Scharr algorithm to compute image derivatives, so the threshold value\n  should normally be higher, such as 300 or normally exposed and contrasty images.\n\n- **param2**: `double`.\n\n  Second method-specific parameter. In case of #HOUGH_GRADIENT, it is the\n  accumulator threshold for the circle centers at the detection stage. The smaller it is, the more\n  false circles may be detected. Circles, corresponding to the larger accumulator values, will be\n  returned first. In the case of #HOUGH_GRADIENT_ALT algorithm, this is the circle \"perfectness\" measure.\n  The closer it to 1, the better shaped circles algorithm selects. In most cases 0.9 should be fine.\n  If you want get better detection of small circles, you may decrease it to 0.85, 0.8 or even less.\n  But then also try to limit the search range [minRadius, maxRadius] to avoid many false circles.\n\n- **minRadius**: `integer()`.\n\n  Minimum circle radius.\n\n- **maxRadius**: `integer()`.\n\n  Maximum circle radius. If <= 0, uses the maximum image dimension. If < 0, #HOUGH_GRADIENT returns\n  centers without finding the radius. #HOUGH_GRADIENT_ALT always computes circle radiuses.\n\n##### Return\n- **circles**: `Evision.Mat.t()`.\n\n  Output vector of found circles. Each vector is encoded as  3 or 4 element\n  floating-point vector \\f$(x, y, radius)\\f$ or \\f$(x, y, radius, votes)\\f$ .\n\nThe function finds circles in a grayscale image using a modification of the Hough transform.\nExample: :\n@include snippets/imgproc_HoughLinesCircles.cpp\n**Note**: Usually the function detects the centers of circles well. However, it may fail to find correct\nradii. You can assist to the function by specifying the radius range ( minRadius and maxRadius ) if\nyou know it. Or, in the case of #HOUGH_GRADIENT method you may set maxRadius to a negative number\nto return centers only without radius search, and find the correct radius using an additional procedure.\nIt also helps to smooth image a bit unless it's already soft. For example,\nGaussianBlur() with 7x7 kernel and 1.5x1.5 sigma or similar blurring may help.\n\n@sa fitEllipse, minEnclosingCircle\n\nPython prototype (for reference only):\n```python3\nHoughCircles(image, method, dp, minDist[, circles[, param1[, param2[, minRadius[, maxRadius]]]]]) -> circles\n```","ref":"Evision.html#houghCircles/4"},{"type":"function","title":"Evision.houghCircles/5","doc":"Finds circles in a grayscale image using the Hough transform.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  8-bit, single-channel, grayscale input image.\n\n- **method**: `integer()`.\n\n  Detection method, see #HoughModes. The available methods are #HOUGH_GRADIENT and #HOUGH_GRADIENT_ALT.\n\n- **dp**: `double`.\n\n  Inverse ratio of the accumulator resolution to the image resolution. For example, if\n  dp=1 , the accumulator has the same resolution as the input image. If dp=2 , the accumulator has\n  half as big width and height. For #HOUGH_GRADIENT_ALT the recommended value is dp=1.5,\n  unless some small very circles need to be detected.\n\n- **minDist**: `double`.\n\n  Minimum distance between the centers of the detected circles. If the parameter is\n  too small, multiple neighbor circles may be falsely detected in addition to a true one. If it is\n  too large, some circles may be missed.\n\n##### Keyword Arguments\n- **param1**: `double`.\n\n  First method-specific parameter. In case of #HOUGH_GRADIENT and #HOUGH_GRADIENT_ALT,\n  it is the higher threshold of the two passed to the Canny edge detector (the lower one is twice smaller).\n  Note that #HOUGH_GRADIENT_ALT uses #Scharr algorithm to compute image derivatives, so the threshold value\n  should normally be higher, such as 300 or normally exposed and contrasty images.\n\n- **param2**: `double`.\n\n  Second method-specific parameter. In case of #HOUGH_GRADIENT, it is the\n  accumulator threshold for the circle centers at the detection stage. The smaller it is, the more\n  false circles may be detected. Circles, corresponding to the larger accumulator values, will be\n  returned first. In the case of #HOUGH_GRADIENT_ALT algorithm, this is the circle \"perfectness\" measure.\n  The closer it to 1, the better shaped circles algorithm selects. In most cases 0.9 should be fine.\n  If you want get better detection of small circles, you may decrease it to 0.85, 0.8 or even less.\n  But then also try to limit the search range [minRadius, maxRadius] to avoid many false circles.\n\n- **minRadius**: `integer()`.\n\n  Minimum circle radius.\n\n- **maxRadius**: `integer()`.\n\n  Maximum circle radius. If <= 0, uses the maximum image dimension. If < 0, #HOUGH_GRADIENT returns\n  centers without finding the radius. #HOUGH_GRADIENT_ALT always computes circle radiuses.\n\n##### Return\n- **circles**: `Evision.Mat.t()`.\n\n  Output vector of found circles. Each vector is encoded as  3 or 4 element\n  floating-point vector \\f$(x, y, radius)\\f$ or \\f$(x, y, radius, votes)\\f$ .\n\nThe function finds circles in a grayscale image using a modification of the Hough transform.\nExample: :\n@include snippets/imgproc_HoughLinesCircles.cpp\n**Note**: Usually the function detects the centers of circles well. However, it may fail to find correct\nradii. You can assist to the function by specifying the radius range ( minRadius and maxRadius ) if\nyou know it. Or, in the case of #HOUGH_GRADIENT method you may set maxRadius to a negative number\nto return centers only without radius search, and find the correct radius using an additional procedure.\nIt also helps to smooth image a bit unless it's already soft. For example,\nGaussianBlur() with 7x7 kernel and 1.5x1.5 sigma or similar blurring may help.\n\n@sa fitEllipse, minEnclosingCircle\n\nPython prototype (for reference only):\n```python3\nHoughCircles(image, method, dp, minDist[, circles[, param1[, param2[, minRadius[, maxRadius]]]]]) -> circles\n```","ref":"Evision.html#houghCircles/5"},{"type":"function","title":"Evision.houghLines/1","doc":"","ref":"Evision.html#houghLines/1"},{"type":"function","title":"Evision.houghLines/4","doc":"Finds lines in a binary image using the standard Hough transform.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  8-bit, single-channel binary source image. The image may be modified by the function.\n\n- **rho**: `double`.\n\n  Distance resolution of the accumulator in pixels.\n\n- **theta**: `double`.\n\n  Angle resolution of the accumulator in radians.\n\n- **threshold**: `integer()`.\n\n  %Accumulator threshold parameter. Only those lines are returned that get enough\n  votes ( \\f$>\\texttt{threshold}\\f$ ).\n\n##### Keyword Arguments\n- **srn**: `double`.\n\n  For the multi-scale Hough transform, it is a divisor for the distance resolution rho.\n  The coarse accumulator distance resolution is rho and the accurate accumulator resolution is\n  rho/srn. If both srn=0 and stn=0, the classical Hough transform is used. Otherwise, both these\n  parameters should be positive.\n\n- **stn**: `double`.\n\n  For the multi-scale Hough transform, it is a divisor for the distance resolution theta.\n\n- **min_theta**: `double`.\n\n  For standard and multi-scale Hough transform, minimum angle to check for lines.\n  Must fall between 0 and max_theta.\n\n- **max_theta**: `double`.\n\n  For standard and multi-scale Hough transform, an upper bound for the angle.\n  Must fall between min_theta and CV_PI. The actual maximum angle in the accumulator may be slightly\n  less than max_theta, depending on the parameters min_theta and theta.\n\n##### Return\n- **lines**: `Evision.Mat.t()`.\n\n  Output vector of lines. Each line is represented by a 2 or 3 element vector\n  \\f$(\\rho, \\theta)\\f$ or \\f$(\\rho, \\theta, \\textrm{votes})\\f$, where \\f$\\rho\\f$ is the distance from\n  the coordinate origin \\f$(0,0)\\f$ (top-left corner of the image), \\f$\\theta\\f$ is the line rotation\n  angle in radians ( \\f$0 \\sim \\textrm{vertical line}, \\pi/2 \\sim \\textrm{horizontal line}\\f$ ), and\n  \\f$\\textrm{votes}\\f$ is the value of accumulator.\n\nThe function implements the standard or standard multi-scale Hough transform algorithm for line\ndetection. See   for a good explanation of Hough\ntransform.\n\nPython prototype (for reference only):\n```python3\nHoughLines(image, rho, theta, threshold[, lines[, srn[, stn[, min_theta[, max_theta]]]]]) -> lines\n```","ref":"Evision.html#houghLines/4"},{"type":"function","title":"Evision.houghLines/5","doc":"Finds lines in a binary image using the standard Hough transform.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  8-bit, single-channel binary source image. The image may be modified by the function.\n\n- **rho**: `double`.\n\n  Distance resolution of the accumulator in pixels.\n\n- **theta**: `double`.\n\n  Angle resolution of the accumulator in radians.\n\n- **threshold**: `integer()`.\n\n  %Accumulator threshold parameter. Only those lines are returned that get enough\n  votes ( \\f$>\\texttt{threshold}\\f$ ).\n\n##### Keyword Arguments\n- **srn**: `double`.\n\n  For the multi-scale Hough transform, it is a divisor for the distance resolution rho.\n  The coarse accumulator distance resolution is rho and the accurate accumulator resolution is\n  rho/srn. If both srn=0 and stn=0, the classical Hough transform is used. Otherwise, both these\n  parameters should be positive.\n\n- **stn**: `double`.\n\n  For the multi-scale Hough transform, it is a divisor for the distance resolution theta.\n\n- **min_theta**: `double`.\n\n  For standard and multi-scale Hough transform, minimum angle to check for lines.\n  Must fall between 0 and max_theta.\n\n- **max_theta**: `double`.\n\n  For standard and multi-scale Hough transform, an upper bound for the angle.\n  Must fall between min_theta and CV_PI. The actual maximum angle in the accumulator may be slightly\n  less than max_theta, depending on the parameters min_theta and theta.\n\n##### Return\n- **lines**: `Evision.Mat.t()`.\n\n  Output vector of lines. Each line is represented by a 2 or 3 element vector\n  \\f$(\\rho, \\theta)\\f$ or \\f$(\\rho, \\theta, \\textrm{votes})\\f$, where \\f$\\rho\\f$ is the distance from\n  the coordinate origin \\f$(0,0)\\f$ (top-left corner of the image), \\f$\\theta\\f$ is the line rotation\n  angle in radians ( \\f$0 \\sim \\textrm{vertical line}, \\pi/2 \\sim \\textrm{horizontal line}\\f$ ), and\n  \\f$\\textrm{votes}\\f$ is the value of accumulator.\n\nThe function implements the standard or standard multi-scale Hough transform algorithm for line\ndetection. See   for a good explanation of Hough\ntransform.\n\nPython prototype (for reference only):\n```python3\nHoughLines(image, rho, theta, threshold[, lines[, srn[, stn[, min_theta[, max_theta]]]]]) -> lines\n```","ref":"Evision.html#houghLines/5"},{"type":"function","title":"Evision.houghLinesP/1","doc":"","ref":"Evision.html#houghLinesP/1"},{"type":"function","title":"Evision.houghLinesP/4","doc":"Finds line segments in a binary image using the probabilistic Hough transform.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  8-bit, single-channel binary source image. The image may be modified by the function.\n\n- **rho**: `double`.\n\n  Distance resolution of the accumulator in pixels.\n\n- **theta**: `double`.\n\n  Angle resolution of the accumulator in radians.\n\n- **threshold**: `integer()`.\n\n  %Accumulator threshold parameter. Only those lines are returned that get enough\n  votes ( \\f$>\\texttt{threshold}\\f$ ).\n\n##### Keyword Arguments\n- **minLineLength**: `double`.\n\n  Minimum line length. Line segments shorter than that are rejected.\n\n- **maxLineGap**: `double`.\n\n  Maximum allowed gap between points on the same line to link them.\n\n##### Return\n- **lines**: `Evision.Mat.t()`.\n\n  Output vector of lines. Each line is represented by a 4-element vector\n  \\f$(x_1, y_1, x_2, y_2)\\f$ , where \\f$(x_1,y_1)\\f$ and \\f$(x_2, y_2)\\f$ are the ending points of each detected\n  line segment.\n\nThe function implements the probabilistic Hough transform algorithm for line detection, described\nin @cite Matas00\nSee the line detection example below:\n@include snippets/imgproc_HoughLinesP.cpp\nThis is a sample picture the function parameters have been tuned for:\n![image](pics/building.jpg)\nAnd this is the output of the above program in case of the probabilistic Hough transform:\n![image](pics/houghp.png)\n\n@sa LineSegmentDetector\n\nPython prototype (for reference only):\n```python3\nHoughLinesP(image, rho, theta, threshold[, lines[, minLineLength[, maxLineGap]]]) -> lines\n```","ref":"Evision.html#houghLinesP/4"},{"type":"function","title":"Evision.houghLinesP/5","doc":"Finds line segments in a binary image using the probabilistic Hough transform.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  8-bit, single-channel binary source image. The image may be modified by the function.\n\n- **rho**: `double`.\n\n  Distance resolution of the accumulator in pixels.\n\n- **theta**: `double`.\n\n  Angle resolution of the accumulator in radians.\n\n- **threshold**: `integer()`.\n\n  %Accumulator threshold parameter. Only those lines are returned that get enough\n  votes ( \\f$>\\texttt{threshold}\\f$ ).\n\n##### Keyword Arguments\n- **minLineLength**: `double`.\n\n  Minimum line length. Line segments shorter than that are rejected.\n\n- **maxLineGap**: `double`.\n\n  Maximum allowed gap between points on the same line to link them.\n\n##### Return\n- **lines**: `Evision.Mat.t()`.\n\n  Output vector of lines. Each line is represented by a 4-element vector\n  \\f$(x_1, y_1, x_2, y_2)\\f$ , where \\f$(x_1,y_1)\\f$ and \\f$(x_2, y_2)\\f$ are the ending points of each detected\n  line segment.\n\nThe function implements the probabilistic Hough transform algorithm for line detection, described\nin @cite Matas00\nSee the line detection example below:\n@include snippets/imgproc_HoughLinesP.cpp\nThis is a sample picture the function parameters have been tuned for:\n![image](pics/building.jpg)\nAnd this is the output of the above program in case of the probabilistic Hough transform:\n![image](pics/houghp.png)\n\n@sa LineSegmentDetector\n\nPython prototype (for reference only):\n```python3\nHoughLinesP(image, rho, theta, threshold[, lines[, minLineLength[, maxLineGap]]]) -> lines\n```","ref":"Evision.html#houghLinesP/5"},{"type":"function","title":"Evision.houghLinesPointSet/1","doc":"","ref":"Evision.html#houghLinesPointSet/1"},{"type":"function","title":"Evision.houghLinesPointSet/9","doc":"Finds lines in a set of points using the standard Hough transform.\n\n##### Positional Arguments\n- **point**: `Evision.Mat`.\n\n  Input vector of points. Each vector must be encoded as a Point vector \\f$(x,y)\\f$. Type must be CV_32FC2 or CV_32SC2.\n\n- **lines_max**: `integer()`.\n\n  Max count of Hough lines.\n\n- **threshold**: `integer()`.\n\n  %Accumulator threshold parameter. Only those lines are returned that get enough\n  votes ( \\f$>\\texttt{threshold}\\f$ ).\n\n- **min_rho**: `double`.\n\n  Minimum value for \\f$\\rho\\f$ for the accumulator (Note: \\f$\\rho\\f$ can be negative. The absolute value \\f$|\\rho|\\f$ is the distance of a line to the origin.).\n\n- **max_rho**: `double`.\n\n  Maximum value for \\f$\\rho\\f$ for the accumulator.\n\n- **rho_step**: `double`.\n\n  Distance resolution of the accumulator.\n\n- **min_theta**: `double`.\n\n  Minimum angle value of the accumulator in radians.\n\n- **max_theta**: `double`.\n\n  Upper bound for the angle value of the accumulator in radians. The actual maximum\n  angle may be slightly less than max_theta, depending on the parameters min_theta and theta_step.\n\n- **theta_step**: `double`.\n\n  Angle resolution of the accumulator in radians.\n\n##### Return\n- **lines**: `Evision.Mat.t()`.\n\n  Output vector of found lines. Each vector is encoded as a vector  \\f$(votes, rho, theta)\\f$.\n  The larger the value of 'votes', the higher the reliability of the Hough line.\n\nThe function finds lines in a set of points using a modification of the Hough transform.\n@include snippets/imgproc_HoughLinesPointSet.cpp\n\nPython prototype (for reference only):\n```python3\nHoughLinesPointSet(point, lines_max, threshold, min_rho, max_rho, rho_step, min_theta, max_theta, theta_step[, lines]) -> lines\n```","ref":"Evision.html#houghLinesPointSet/9"},{"type":"function","title":"Evision.houghLinesPointSet/10","doc":"Finds lines in a set of points using the standard Hough transform.\n\n##### Positional Arguments\n- **point**: `Evision.Mat`.\n\n  Input vector of points. Each vector must be encoded as a Point vector \\f$(x,y)\\f$. Type must be CV_32FC2 or CV_32SC2.\n\n- **lines_max**: `integer()`.\n\n  Max count of Hough lines.\n\n- **threshold**: `integer()`.\n\n  %Accumulator threshold parameter. Only those lines are returned that get enough\n  votes ( \\f$>\\texttt{threshold}\\f$ ).\n\n- **min_rho**: `double`.\n\n  Minimum value for \\f$\\rho\\f$ for the accumulator (Note: \\f$\\rho\\f$ can be negative. The absolute value \\f$|\\rho|\\f$ is the distance of a line to the origin.).\n\n- **max_rho**: `double`.\n\n  Maximum value for \\f$\\rho\\f$ for the accumulator.\n\n- **rho_step**: `double`.\n\n  Distance resolution of the accumulator.\n\n- **min_theta**: `double`.\n\n  Minimum angle value of the accumulator in radians.\n\n- **max_theta**: `double`.\n\n  Upper bound for the angle value of the accumulator in radians. The actual maximum\n  angle may be slightly less than max_theta, depending on the parameters min_theta and theta_step.\n\n- **theta_step**: `double`.\n\n  Angle resolution of the accumulator in radians.\n\n##### Return\n- **lines**: `Evision.Mat.t()`.\n\n  Output vector of found lines. Each vector is encoded as a vector  \\f$(votes, rho, theta)\\f$.\n  The larger the value of 'votes', the higher the reliability of the Hough line.\n\nThe function finds lines in a set of points using a modification of the Hough transform.\n@include snippets/imgproc_HoughLinesPointSet.cpp\n\nPython prototype (for reference only):\n```python3\nHoughLinesPointSet(point, lines_max, threshold, min_rho, max_rho, rho_step, min_theta, max_theta, theta_step[, lines]) -> lines\n```","ref":"Evision.html#houghLinesPointSet/10"},{"type":"function","title":"Evision.houghLinesWithAccumulator/1","doc":"","ref":"Evision.html#houghLinesWithAccumulator/1"},{"type":"function","title":"Evision.houghLinesWithAccumulator/4","doc":"Finds lines in a binary image using the standard Hough transform and get accumulator.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`\n- **rho**: `double`\n- **theta**: `double`\n- **threshold**: `integer()`\n\n##### Keyword Arguments\n- **srn**: `double`.\n- **stn**: `double`.\n- **min_theta**: `double`.\n- **max_theta**: `double`.\n\n##### Return\n- **lines**: `Evision.Mat.t()`.\n\n**Note**: This function is for bindings use only. Use original function in C++ code\n@sa HoughLines\n\nPython prototype (for reference only):\n```python3\nHoughLinesWithAccumulator(image, rho, theta, threshold[, lines[, srn[, stn[, min_theta[, max_theta]]]]]) -> lines\n```","ref":"Evision.html#houghLinesWithAccumulator/4"},{"type":"function","title":"Evision.houghLinesWithAccumulator/5","doc":"Finds lines in a binary image using the standard Hough transform and get accumulator.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`\n- **rho**: `double`\n- **theta**: `double`\n- **threshold**: `integer()`\n\n##### Keyword Arguments\n- **srn**: `double`.\n- **stn**: `double`.\n- **min_theta**: `double`.\n- **max_theta**: `double`.\n\n##### Return\n- **lines**: `Evision.Mat.t()`.\n\n**Note**: This function is for bindings use only. Use original function in C++ code\n@sa HoughLines\n\nPython prototype (for reference only):\n```python3\nHoughLinesWithAccumulator(image, rho, theta, threshold[, lines[, srn[, stn[, min_theta[, max_theta]]]]]) -> lines\n```","ref":"Evision.html#houghLinesWithAccumulator/5"},{"type":"function","title":"Evision.huMoments/1","doc":"HuMoments\n\n##### Positional Arguments\n- **m**: `Moments`\n\n##### Return\n- **hu**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nHuMoments(m[, hu]) -> hu\n```","ref":"Evision.html#huMoments/1"},{"type":"function","title":"Evision.huMoments/2","doc":"HuMoments\n\n##### Positional Arguments\n- **m**: `Moments`\n\n##### Return\n- **hu**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nHuMoments(m[, hu]) -> hu\n```","ref":"Evision.html#huMoments/2"},{"type":"function","title":"Evision.idct/1","doc":"Calculates the inverse Discrete Cosine Transform of a 1D or 2D array.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input floating-point single-channel array.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  operation flags.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src.\n\nidct(src, dst, flags) is equivalent to dct(src, dst, flags | DCT_INVERSE).\n@sa  dct, dft, idft, getOptimalDFTSize\n\nPython prototype (for reference only):\n```python3\nidct(src[, dst[, flags]]) -> dst\n```","ref":"Evision.html#idct/1"},{"type":"function","title":"Evision.idct/2","doc":"Calculates the inverse Discrete Cosine Transform of a 1D or 2D array.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input floating-point single-channel array.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  operation flags.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src.\n\nidct(src, dst, flags) is equivalent to dct(src, dst, flags | DCT_INVERSE).\n@sa  dct, dft, idft, getOptimalDFTSize\n\nPython prototype (for reference only):\n```python3\nidct(src[, dst[, flags]]) -> dst\n```","ref":"Evision.html#idct/2"},{"type":"function","title":"Evision.idft/1","doc":"Calculates the inverse Discrete Fourier Transform of a 1D or 2D array.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input floating-point real or complex array.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  operation flags (see dft and #DftFlags).\n\n- **nonzeroRows**: `integer()`.\n\n  number of dst rows to process; the rest of the rows have undefined content (see\n  the convolution sample in dft description.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array whose size and type depend on the flags.\n\nidft(src, dst, flags) is equivalent to dft(src, dst, flags | #DFT_INVERSE) .\n**Note**: None of dft and idft scales the result by default. So, you should pass #DFT_SCALE to one of\ndft or idft explicitly to make these transforms mutually inverse.\n@sa dft, dct, idct, mulSpectrums, getOptimalDFTSize\n\nPython prototype (for reference only):\n```python3\nidft(src[, dst[, flags[, nonzeroRows]]]) -> dst\n```","ref":"Evision.html#idft/1"},{"type":"function","title":"Evision.idft/2","doc":"Calculates the inverse Discrete Fourier Transform of a 1D or 2D array.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input floating-point real or complex array.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  operation flags (see dft and #DftFlags).\n\n- **nonzeroRows**: `integer()`.\n\n  number of dst rows to process; the rest of the rows have undefined content (see\n  the convolution sample in dft description.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array whose size and type depend on the flags.\n\nidft(src, dst, flags) is equivalent to dft(src, dst, flags | #DFT_INVERSE) .\n**Note**: None of dft and idft scales the result by default. So, you should pass #DFT_SCALE to one of\ndft or idft explicitly to make these transforms mutually inverse.\n@sa dft, dct, idct, mulSpectrums, getOptimalDFTSize\n\nPython prototype (for reference only):\n```python3\nidft(src[, dst[, flags[, nonzeroRows]]]) -> dst\n```","ref":"Evision.html#idft/2"},{"type":"function","title":"Evision.illuminationChange/1","doc":"","ref":"Evision.html#illuminationChange/1"},{"type":"function","title":"Evision.illuminationChange/2","doc":"Applying an appropriate non-linear transformation to the gradient field inside the selection and\nthen integrating back with a Poisson solver, modifies locally the apparent illumination of an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n- **mask**: `Evision.Mat`.\n\n  Input 8-bit 1 or 3-channel image.\n\n##### Keyword Arguments\n- **alpha**: `float`.\n\n  Value ranges between 0-2.\n\n- **beta**: `float`.\n\n  Value ranges between 0-2.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as src.\n\nThis is useful to highlight under-exposed foreground objects or to reduce specular reflections.\n\nPython prototype (for reference only):\n```python3\nilluminationChange(src, mask[, dst[, alpha[, beta]]]) -> dst\n```","ref":"Evision.html#illuminationChange/2"},{"type":"function","title":"Evision.illuminationChange/3","doc":"Applying an appropriate non-linear transformation to the gradient field inside the selection and\nthen integrating back with a Poisson solver, modifies locally the apparent illumination of an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n- **mask**: `Evision.Mat`.\n\n  Input 8-bit 1 or 3-channel image.\n\n##### Keyword Arguments\n- **alpha**: `float`.\n\n  Value ranges between 0-2.\n\n- **beta**: `float`.\n\n  Value ranges between 0-2.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as src.\n\nThis is useful to highlight under-exposed foreground objects or to reduce specular reflections.\n\nPython prototype (for reference only):\n```python3\nilluminationChange(src, mask[, dst[, alpha[, beta]]]) -> dst\n```","ref":"Evision.html#illuminationChange/3"},{"type":"function","title":"Evision.imcount/1","doc":"Returns the number of images inside the give file\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  Name of file to be loaded.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Flag that can take values of cv::ImreadModes, default with cv::IMREAD_ANYCOLOR.\n\n##### Return\n- **retval**: `size_t`\n\nThe function imcount will return the number of pages in a multi-page image, or 1 for single-page images\n\nPython prototype (for reference only):\n```python3\nimcount(filename[, flags]) -> retval\n```","ref":"Evision.html#imcount/1"},{"type":"function","title":"Evision.imcount/2","doc":"Returns the number of images inside the give file\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  Name of file to be loaded.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Flag that can take values of cv::ImreadModes, default with cv::IMREAD_ANYCOLOR.\n\n##### Return\n- **retval**: `size_t`\n\nThe function imcount will return the number of pages in a multi-page image, or 1 for single-page images\n\nPython prototype (for reference only):\n```python3\nimcount(filename[, flags]) -> retval\n```","ref":"Evision.html#imcount/2"},{"type":"function","title":"Evision.imdecode/2","doc":"","ref":"Evision.html#imdecode/2"},{"type":"function","title":"Evision.imdecodemulti/1","doc":"","ref":"Evision.html#imdecodemulti/1"},{"type":"function","title":"Evision.imdecodemulti/2","doc":"Reads a multi-page image from a buffer in memory.\n\n##### Positional Arguments\n- **buf**: `Evision.Mat`.\n\n  Input array or vector of bytes.\n\n- **flags**: `integer()`.\n\n  The same flags as in cv::imread, see cv::ImreadModes.\n\n##### Keyword Arguments\n- **range**: `Range`.\n\n  A continuous selection of pages.\n\n##### Return\n- **retval**: `bool`\n- **mats**: `[Evision.Mat]`.\n\n  A vector of Mat objects holding each page, if more than one.\n\nThe function imdecodemulti reads a multi-page image from the specified buffer in the memory. If the buffer is too short or\ncontains invalid data, the function returns false.\nSee cv::imreadmulti for the list of supported formats and flags description.\n**Note**: In the case of color images, the decoded images will have the channels stored in **B G R** order.\n\nPython prototype (for reference only):\n```python3\nimdecodemulti(buf, flags[, mats[, range]]) -> retval, mats\n```","ref":"Evision.html#imdecodemulti/2"},{"type":"function","title":"Evision.imdecodemulti/3","doc":"Reads a multi-page image from a buffer in memory.\n\n##### Positional Arguments\n- **buf**: `Evision.Mat`.\n\n  Input array or vector of bytes.\n\n- **flags**: `integer()`.\n\n  The same flags as in cv::imread, see cv::ImreadModes.\n\n##### Keyword Arguments\n- **range**: `Range`.\n\n  A continuous selection of pages.\n\n##### Return\n- **retval**: `bool`\n- **mats**: `[Evision.Mat]`.\n\n  A vector of Mat objects holding each page, if more than one.\n\nThe function imdecodemulti reads a multi-page image from the specified buffer in the memory. If the buffer is too short or\ncontains invalid data, the function returns false.\nSee cv::imreadmulti for the list of supported formats and flags description.\n**Note**: In the case of color images, the decoded images will have the channels stored in **B G R** order.\n\nPython prototype (for reference only):\n```python3\nimdecodemulti(buf, flags[, mats[, range]]) -> retval, mats\n```","ref":"Evision.html#imdecodemulti/3"},{"type":"function","title":"Evision.imencode/1","doc":"","ref":"Evision.html#imencode/1"},{"type":"function","title":"Evision.imencode/2","doc":"Encodes an image into a memory buffer.\n\n##### Positional Arguments\n- **ext**: `String`.\n\n  File extension that defines the output format. Must include a leading period.\n\n- **img**: `Evision.Mat`.\n\n  Image to be written.\n\n##### Keyword Arguments\n- **params**: `[integer()]`.\n\n  Format-specific parameters. See cv::imwrite and cv::ImwriteFlags.\n\n##### Return\n- **retval**: `bool`\n- **buf**: `[uchar]`.\n\n  Output buffer resized to fit the compressed image.\n\nThe function imencode compresses the image and stores it in the memory buffer that is resized to fit the\nresult. See cv::imwrite for the list of supported formats and flags description.\n\nPython prototype (for reference only):\n```python3\nimencode(ext, img[, params]) -> retval, buf\n```","ref":"Evision.html#imencode/2"},{"type":"function","title":"Evision.imencode/3","doc":"Encodes an image into a memory buffer.\n\n##### Positional Arguments\n- **ext**: `String`.\n\n  File extension that defines the output format. Must include a leading period.\n\n- **img**: `Evision.Mat`.\n\n  Image to be written.\n\n##### Keyword Arguments\n- **params**: `[integer()]`.\n\n  Format-specific parameters. See cv::imwrite and cv::ImwriteFlags.\n\n##### Return\n- **retval**: `bool`\n- **buf**: `[uchar]`.\n\n  Output buffer resized to fit the compressed image.\n\nThe function imencode compresses the image and stores it in the memory buffer that is resized to fit the\nresult. See cv::imwrite for the list of supported formats and flags description.\n\nPython prototype (for reference only):\n```python3\nimencode(ext, img[, params]) -> retval, buf\n```","ref":"Evision.html#imencode/3"},{"type":"function","title":"Evision.imread/1","doc":"Loads an image from a file.\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  Name of file to be loaded.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Flag that can take values of cv::ImreadModes\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  object in which the image will be loaded.\n\nThis is an overloaded member function, provided for convenience. It differs from the above function only in what argument(s) it accepts and the return value.\n**Note**: \nThe image passing through the img parameter can be pre-allocated. The memory is reused if the shape and the type match with the load image.\n\nPython prototype (for reference only):\n```python3\nimread(filename[, dst[, flags]]) -> dst\n```","ref":"Evision.html#imread/1"},{"type":"function","title":"Evision.imread/2","doc":"Loads an image from a file.\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  Name of file to be loaded.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Flag that can take values of cv::ImreadModes\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  object in which the image will be loaded.\n\nThis is an overloaded member function, provided for convenience. It differs from the above function only in what argument(s) it accepts and the return value.\n**Note**: \nThe image passing through the img parameter can be pre-allocated. The memory is reused if the shape and the type match with the load image.\n\nPython prototype (for reference only):\n```python3\nimread(filename[, dst[, flags]]) -> dst\n```","ref":"Evision.html#imread/2"},{"type":"function","title":"Evision.imreadmulti/1","doc":"Loads a multi-page image from a file.\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  Name of file to be loaded.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Flag that can take values of cv::ImreadModes, default with cv::IMREAD_ANYCOLOR.\n\n##### Return\n- **retval**: `bool`\n- **mats**: `[Evision.Mat]`.\n\n  A vector of Mat objects holding each page.\n\nThe function imreadmulti loads a multi-page image from the specified file into a vector of Mat objects.\n@sa cv::imread\n\nPython prototype (for reference only):\n```python3\nimreadmulti(filename[, mats[, flags]]) -> retval, mats\n```","ref":"Evision.html#imreadmulti/1"},{"type":"function","title":"Evision.imreadmulti/2","doc":"Loads a multi-page image from a file.\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  Name of file to be loaded.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Flag that can take values of cv::ImreadModes, default with cv::IMREAD_ANYCOLOR.\n\n##### Return\n- **retval**: `bool`\n- **mats**: `[Evision.Mat]`.\n\n  A vector of Mat objects holding each page.\n\nThe function imreadmulti loads a multi-page image from the specified file into a vector of Mat objects.\n@sa cv::imread\n\nPython prototype (for reference only):\n```python3\nimreadmulti(filename[, mats[, flags]]) -> retval, mats\n```","ref":"Evision.html#imreadmulti/2"},{"type":"function","title":"Evision.imreadmulti/3","doc":"Loads a of images of a multi-page image from a file.\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  Name of file to be loaded.\n\n- **start**: `integer()`.\n\n  Start index of the image to load\n\n- **count**: `integer()`.\n\n  Count number of images to load\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Flag that can take values of cv::ImreadModes, default with cv::IMREAD_ANYCOLOR.\n\n##### Return\n- **retval**: `bool`\n- **mats**: `[Evision.Mat]`.\n\n  A vector of Mat objects holding each page.\n\nThe function imreadmulti loads a specified range from a multi-page image from the specified file into a vector of Mat objects.\n@sa cv::imread\n\nPython prototype (for reference only):\n```python3\nimreadmulti(filename, start, count[, mats[, flags]]) -> retval, mats\n```","ref":"Evision.html#imreadmulti/3"},{"type":"function","title":"Evision.imreadmulti/4","doc":"Loads a of images of a multi-page image from a file.\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  Name of file to be loaded.\n\n- **start**: `integer()`.\n\n  Start index of the image to load\n\n- **count**: `integer()`.\n\n  Count number of images to load\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Flag that can take values of cv::ImreadModes, default with cv::IMREAD_ANYCOLOR.\n\n##### Return\n- **retval**: `bool`\n- **mats**: `[Evision.Mat]`.\n\n  A vector of Mat objects holding each page.\n\nThe function imreadmulti loads a specified range from a multi-page image from the specified file into a vector of Mat objects.\n@sa cv::imread\n\nPython prototype (for reference only):\n```python3\nimreadmulti(filename, start, count[, mats[, flags]]) -> retval, mats\n```","ref":"Evision.html#imreadmulti/4"},{"type":"function","title":"Evision.imwrite/1","doc":"","ref":"Evision.html#imwrite/1"},{"type":"function","title":"Evision.imwrite/2","doc":"Saves an image to a specified file.\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  Name of the file.\n\n- **img**: `Evision.Mat`.\n\n  (Mat or vector of Mat) Image or Images to be saved.\n\n##### Keyword Arguments\n- **params**: `[integer()]`.\n\n  Format-specific parameters encoded as pairs (paramId_1, paramValue_1, paramId_2, paramValue_2, ... .) see cv::ImwriteFlags\n\n##### Return\n- **retval**: `bool`\n\nThe function imwrite saves the image to the specified file. The image format is chosen based on the\nfilename extension (see cv::imread for the list of extensions). In general, only 8-bit unsigned (CV_8U)\nsingle-channel or 3-channel (with 'BGR' channel order) images\ncan be saved using this function, with these exceptions:\n- With OpenEXR encoder, only 32-bit float (CV_32F) images can be saved.\n- 8-bit unsigned (CV_8U) images are not supported.\n- With Radiance HDR encoder, non 64-bit float (CV_64F) images can be saved.\n- All images will be converted to 32-bit float (CV_32F).\n- With JPEG 2000 encoder, 8-bit unsigned (CV_8U) and 16-bit unsigned (CV_16U) images can be saved.\n- With PAM encoder, 8-bit unsigned (CV_8U) and 16-bit unsigned (CV_16U) images can be saved.\n- With PNG encoder, 8-bit unsigned (CV_8U) and 16-bit unsigned (CV_16U) images can be saved.\n- PNG images with an alpha channel can be saved using this function. To do this, create\n  8-bit (or 16-bit) 4-channel image BGRA, where the alpha channel goes last. Fully transparent pixels\n  should have alpha set to 0, fully opaque pixels should have alpha set to 255/65535 (see the code sample below).\n\n- With PGM/PPM encoder, 8-bit unsigned (CV_8U) and 16-bit unsigned (CV_16U) images can be saved.\n- With TIFF encoder, 8-bit unsigned (CV_8U), 16-bit unsigned (CV_16U),\n  32-bit float (CV_32F) and 64-bit float (CV_64F) images can be saved.\n\n- Multiple images (vector of Mat) can be saved in TIFF format (see the code sample below).\n- 32-bit float 3-channel (CV_32FC3) TIFF images will be saved\n  using the LogLuv high dynamic range encoding (4 bytes per pixel)\n\nIf the image format is not supported, the image will be converted to 8-bit unsigned (CV_8U) and saved that way.\nIf the format, depth or channel order is different, use\nMat::convertTo and cv::cvtColor to convert it before saving. Or, use the universal FileStorage I/O\nfunctions to save the image to XML or YAML format.\nThe sample below shows how to create a BGRA image, how to set custom compression parameters and save it to a PNG file.\nIt also demonstrates how to save multiple images in a TIFF file:\n@include snippets/imgcodecs_imwrite.cpp\n\nPython prototype (for reference only):\n```python3\nimwrite(filename, img[, params]) -> retval\n```","ref":"Evision.html#imwrite/2"},{"type":"function","title":"Evision.imwrite/3","doc":"Saves an image to a specified file.\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  Name of the file.\n\n- **img**: `Evision.Mat`.\n\n  (Mat or vector of Mat) Image or Images to be saved.\n\n##### Keyword Arguments\n- **params**: `[integer()]`.\n\n  Format-specific parameters encoded as pairs (paramId_1, paramValue_1, paramId_2, paramValue_2, ... .) see cv::ImwriteFlags\n\n##### Return\n- **retval**: `bool`\n\nThe function imwrite saves the image to the specified file. The image format is chosen based on the\nfilename extension (see cv::imread for the list of extensions). In general, only 8-bit unsigned (CV_8U)\nsingle-channel or 3-channel (with 'BGR' channel order) images\ncan be saved using this function, with these exceptions:\n- With OpenEXR encoder, only 32-bit float (CV_32F) images can be saved.\n- 8-bit unsigned (CV_8U) images are not supported.\n- With Radiance HDR encoder, non 64-bit float (CV_64F) images can be saved.\n- All images will be converted to 32-bit float (CV_32F).\n- With JPEG 2000 encoder, 8-bit unsigned (CV_8U) and 16-bit unsigned (CV_16U) images can be saved.\n- With PAM encoder, 8-bit unsigned (CV_8U) and 16-bit unsigned (CV_16U) images can be saved.\n- With PNG encoder, 8-bit unsigned (CV_8U) and 16-bit unsigned (CV_16U) images can be saved.\n- PNG images with an alpha channel can be saved using this function. To do this, create\n  8-bit (or 16-bit) 4-channel image BGRA, where the alpha channel goes last. Fully transparent pixels\n  should have alpha set to 0, fully opaque pixels should have alpha set to 255/65535 (see the code sample below).\n\n- With PGM/PPM encoder, 8-bit unsigned (CV_8U) and 16-bit unsigned (CV_16U) images can be saved.\n- With TIFF encoder, 8-bit unsigned (CV_8U), 16-bit unsigned (CV_16U),\n  32-bit float (CV_32F) and 64-bit float (CV_64F) images can be saved.\n\n- Multiple images (vector of Mat) can be saved in TIFF format (see the code sample below).\n- 32-bit float 3-channel (CV_32FC3) TIFF images will be saved\n  using the LogLuv high dynamic range encoding (4 bytes per pixel)\n\nIf the image format is not supported, the image will be converted to 8-bit unsigned (CV_8U) and saved that way.\nIf the format, depth or channel order is different, use\nMat::convertTo and cv::cvtColor to convert it before saving. Or, use the universal FileStorage I/O\nfunctions to save the image to XML or YAML format.\nThe sample below shows how to create a BGRA image, how to set custom compression parameters and save it to a PNG file.\nIt also demonstrates how to save multiple images in a TIFF file:\n@include snippets/imgcodecs_imwrite.cpp\n\nPython prototype (for reference only):\n```python3\nimwrite(filename, img[, params]) -> retval\n```","ref":"Evision.html#imwrite/3"},{"type":"function","title":"Evision.imwritemulti/1","doc":"","ref":"Evision.html#imwritemulti/1"},{"type":"function","title":"Evision.imwritemulti/2","doc":"imwritemulti\n\n##### Positional Arguments\n- **filename**: `String`\n- **img**: `[Evision.Mat]`\n\n##### Keyword Arguments\n- **params**: `[integer()]`.\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nimwritemulti(filename, img[, params]) -> retval\n```","ref":"Evision.html#imwritemulti/2"},{"type":"function","title":"Evision.imwritemulti/3","doc":"imwritemulti\n\n##### Positional Arguments\n- **filename**: `String`\n- **img**: `[Evision.Mat]`\n\n##### Keyword Arguments\n- **params**: `[integer()]`.\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nimwritemulti(filename, img[, params]) -> retval\n```","ref":"Evision.html#imwritemulti/3"},{"type":"function","title":"Evision.initCameraMatrix2D/1","doc":"","ref":"Evision.html#initCameraMatrix2D/1"},{"type":"function","title":"Evision.initCameraMatrix2D/3","doc":"Finds an initial camera intrinsic matrix from 3D-2D point correspondences.\n\n##### Positional Arguments\n- **objectPoints**: `[Evision.Mat]`.\n\n  Vector of vectors of the calibration pattern points in the calibration pattern\n  coordinate space. In the old interface all the per-view vectors are concatenated. See\n  #calibrateCamera for details.\n\n- **imagePoints**: `[Evision.Mat]`.\n\n  Vector of vectors of the projections of the calibration pattern points. In the\n  old interface all the per-view vectors are concatenated.\n\n- **imageSize**: `Size`.\n\n  Image size in pixels used to initialize the principal point.\n\n##### Keyword Arguments\n- **aspectRatio**: `double`.\n\n  If it is zero or negative, both \\f$f_x\\f$ and \\f$f_y\\f$ are estimated independently.\n  Otherwise, \\f$f_x = f_y \\cdot \\texttt{aspectRatio}\\f$ .\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nThe function estimates and returns an initial camera intrinsic matrix for the camera calibration process.\nCurrently, the function only supports planar calibration patterns, which are patterns where each\nobject point has z-coordinate =0.\n\nPython prototype (for reference only):\n```python3\ninitCameraMatrix2D(objectPoints, imagePoints, imageSize[, aspectRatio]) -> retval\n```","ref":"Evision.html#initCameraMatrix2D/3"},{"type":"function","title":"Evision.initCameraMatrix2D/4","doc":"Finds an initial camera intrinsic matrix from 3D-2D point correspondences.\n\n##### Positional Arguments\n- **objectPoints**: `[Evision.Mat]`.\n\n  Vector of vectors of the calibration pattern points in the calibration pattern\n  coordinate space. In the old interface all the per-view vectors are concatenated. See\n  #calibrateCamera for details.\n\n- **imagePoints**: `[Evision.Mat]`.\n\n  Vector of vectors of the projections of the calibration pattern points. In the\n  old interface all the per-view vectors are concatenated.\n\n- **imageSize**: `Size`.\n\n  Image size in pixels used to initialize the principal point.\n\n##### Keyword Arguments\n- **aspectRatio**: `double`.\n\n  If it is zero or negative, both \\f$f_x\\f$ and \\f$f_y\\f$ are estimated independently.\n  Otherwise, \\f$f_x = f_y \\cdot \\texttt{aspectRatio}\\f$ .\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nThe function estimates and returns an initial camera intrinsic matrix for the camera calibration process.\nCurrently, the function only supports planar calibration patterns, which are patterns where each\nobject point has z-coordinate =0.\n\nPython prototype (for reference only):\n```python3\ninitCameraMatrix2D(objectPoints, imagePoints, imageSize[, aspectRatio]) -> retval\n```","ref":"Evision.html#initCameraMatrix2D/4"},{"type":"function","title":"Evision.initInverseRectificationMap/1","doc":"","ref":"Evision.html#initInverseRectificationMap/1"},{"type":"function","title":"Evision.initInverseRectificationMap/6","doc":"Computes the projection and inverse-rectification transformation map. In essense, this is the inverse of\n#initUndistortRectifyMap to accomodate stereo-rectification of projectors ('inverse-cameras') in projector-camera pairs.\n\n##### Positional Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input camera matrix \\f$A=\\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$(k_1, k_2, p_1, p_2[, k_3[, k_4, k_5, k_6[, s_1, s_2, s_3, s_4[, \\tau_x, \\tau_y]]]])\\f$\n  of 4, 5, 8, 12 or 14 elements. If the vector is NULL/empty, the zero distortion coefficients are assumed.\n\n- **r**: `Evision.Mat`.\n\n  Optional rectification transformation in the object space (3x3 matrix). R1 or R2,\n  computed by #stereoRectify can be passed here. If the matrix is empty, the identity transformation\n  is assumed.\n\n- **newCameraMatrix**: `Evision.Mat`.\n\n  New camera matrix \\f$A'=\\vecthreethree{f_x'}{0}{c_x'}{0}{f_y'}{c_y'}{0}{0}{1}\\f$.\n\n- **size**: `Size`.\n\n  Distorted image size.\n\n- **m1type**: `integer()`.\n\n  Type of the first output map. Can be CV_32FC1, CV_32FC2 or CV_16SC2, see #convertMaps\n\n##### Return\n- **map1**: `Evision.Mat.t()`.\n\n  The first output map for #remap.\n\n- **map2**: `Evision.Mat.t()`.\n\n  The second output map for #remap.\n\nThe function computes the joint projection and inverse rectification transformation and represents the\nresult in the form of maps for #remap. The projected image looks like a distorted version of the original which,\nonce projected by a projector, should visually match the original. In case of a monocular camera, newCameraMatrix\nis usually equal to cameraMatrix, or it can be computed by\n#getOptimalNewCameraMatrix for a better control over scaling. In case of a projector-camera pair,\nnewCameraMatrix is normally set to P1 or P2 computed by #stereoRectify .\nThe projector is oriented differently in the coordinate space, according to R. In case of projector-camera pairs,\nthis helps align the projector (in the same manner as #initUndistortRectifyMap for the camera) to create a stereo-rectified pair. This\nallows epipolar lines on both images to become horizontal and have the same y-coordinate (in case of a horizontally aligned projector-camera pair).\nThe function builds the maps for the inverse mapping algorithm that is used by #remap. That\nis, for each pixel \\f$(u, v)\\f$ in the destination (projected and inverse-rectified) image, the function\ncomputes the corresponding coordinates in the source image (that is, in the original digital image). The following process is applied:\n\\f[\n\\begin{array}{l}\n\\text{newCameraMatrix}\\\\\\\\\nx  \\leftarrow (u - {c'}\\_x)/{f'}\\_x  \\\\\\\\\ny  \\leftarrow (v - {c'}\\_y)/{f'}\\_y  \\\\\\\\\n\\\\\\\\\\text{Undistortion}\n\\\\\\\\\\scriptsize{\\textit{though equation shown is for radial undistortion, function implements cv::undistortPoints()}}\\\\\\\\\nr^2  \\leftarrow x^2 + y^2 \\\\\\\\\n\\theta \\leftarrow \\frac{1 + k\\_1 r^2 + k\\_2 r^4 + k\\_3 r^6}{1 + k\\_4 r^2 + k\\_5 r^4 + k\\_6 r^6}\\\\\\\\\nx' \\leftarrow \\frac{x}{\\theta} \\\\\\\\\ny'  \\leftarrow \\frac{y}{\\theta} \\\\\\\\\n\\\\\\\\\\text{Rectification}\\\\\\\\\n{\\[X\\,Y\\,W]} ^T  \\leftarrow R\\*\\[x' \\, y' \\, 1]^T  \\\\\\\\\nx''  \\leftarrow X/W  \\\\\\\\\ny''  \\leftarrow Y/W  \\\\\\\\\n\\\\\\\\\\text{cameraMatrix}\\\\\\\\\nmap\\_x(u,v)  \\leftarrow x'' f\\_x + c\\_x  \\\\\\\\\nmap\\_y(u,v)  \\leftarrow y'' f\\_y + c\\_y\n\\end{array}\n\\f]\nwhere \\f$(k\\_1, k\\_2, p\\_1, p\\_2\\[, k\\_3\\[, k\\_4, k\\_5, k\\_6\\[, s\\_1, s\\_2, s\\_3, s\\_4\\[, \\tau\\_x, \\tau\\_y]]]])\\f$\nare the distortion coefficients vector distCoeffs.\nIn case of a stereo-rectified projector-camera pair, this function is called for the projector while #initUndistortRectifyMap is called for the camera head.\nThis is done after #stereoRectify, which in turn is called after #stereoCalibrate. If the projector-camera pair\nis not calibrated, it is still possible to compute the rectification transformations directly from\nthe fundamental matrix using #stereoRectifyUncalibrated. For the projector and camera, the function computes\nhomography H as the rectification transformation in a pixel domain, not a rotation matrix R in 3D\nspace. R can be computed from H as\n\\f[\\texttt{R} = \\texttt{cameraMatrix} ^{-1} \\cdot \\texttt{H} \\cdot \\texttt{cameraMatrix}\\f]\nwhere cameraMatrix can be chosen arbitrarily.\n\nPython prototype (for reference only):\n```python3\ninitInverseRectificationMap(cameraMatrix, distCoeffs, R, newCameraMatrix, size, m1type[, map1[, map2]]) -> map1, map2\n```","ref":"Evision.html#initInverseRectificationMap/6"},{"type":"function","title":"Evision.initInverseRectificationMap/7","doc":"Computes the projection and inverse-rectification transformation map. In essense, this is the inverse of\n#initUndistortRectifyMap to accomodate stereo-rectification of projectors ('inverse-cameras') in projector-camera pairs.\n\n##### Positional Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input camera matrix \\f$A=\\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$(k_1, k_2, p_1, p_2[, k_3[, k_4, k_5, k_6[, s_1, s_2, s_3, s_4[, \\tau_x, \\tau_y]]]])\\f$\n  of 4, 5, 8, 12 or 14 elements. If the vector is NULL/empty, the zero distortion coefficients are assumed.\n\n- **r**: `Evision.Mat`.\n\n  Optional rectification transformation in the object space (3x3 matrix). R1 or R2,\n  computed by #stereoRectify can be passed here. If the matrix is empty, the identity transformation\n  is assumed.\n\n- **newCameraMatrix**: `Evision.Mat`.\n\n  New camera matrix \\f$A'=\\vecthreethree{f_x'}{0}{c_x'}{0}{f_y'}{c_y'}{0}{0}{1}\\f$.\n\n- **size**: `Size`.\n\n  Distorted image size.\n\n- **m1type**: `integer()`.\n\n  Type of the first output map. Can be CV_32FC1, CV_32FC2 or CV_16SC2, see #convertMaps\n\n##### Return\n- **map1**: `Evision.Mat.t()`.\n\n  The first output map for #remap.\n\n- **map2**: `Evision.Mat.t()`.\n\n  The second output map for #remap.\n\nThe function computes the joint projection and inverse rectification transformation and represents the\nresult in the form of maps for #remap. The projected image looks like a distorted version of the original which,\nonce projected by a projector, should visually match the original. In case of a monocular camera, newCameraMatrix\nis usually equal to cameraMatrix, or it can be computed by\n#getOptimalNewCameraMatrix for a better control over scaling. In case of a projector-camera pair,\nnewCameraMatrix is normally set to P1 or P2 computed by #stereoRectify .\nThe projector is oriented differently in the coordinate space, according to R. In case of projector-camera pairs,\nthis helps align the projector (in the same manner as #initUndistortRectifyMap for the camera) to create a stereo-rectified pair. This\nallows epipolar lines on both images to become horizontal and have the same y-coordinate (in case of a horizontally aligned projector-camera pair).\nThe function builds the maps for the inverse mapping algorithm that is used by #remap. That\nis, for each pixel \\f$(u, v)\\f$ in the destination (projected and inverse-rectified) image, the function\ncomputes the corresponding coordinates in the source image (that is, in the original digital image). The following process is applied:\n\\f[\n\\begin{array}{l}\n\\text{newCameraMatrix}\\\\\\\\\nx  \\leftarrow (u - {c'}\\_x)/{f'}\\_x  \\\\\\\\\ny  \\leftarrow (v - {c'}\\_y)/{f'}\\_y  \\\\\\\\\n\\\\\\\\\\text{Undistortion}\n\\\\\\\\\\scriptsize{\\textit{though equation shown is for radial undistortion, function implements cv::undistortPoints()}}\\\\\\\\\nr^2  \\leftarrow x^2 + y^2 \\\\\\\\\n\\theta \\leftarrow \\frac{1 + k\\_1 r^2 + k\\_2 r^4 + k\\_3 r^6}{1 + k\\_4 r^2 + k\\_5 r^4 + k\\_6 r^6}\\\\\\\\\nx' \\leftarrow \\frac{x}{\\theta} \\\\\\\\\ny'  \\leftarrow \\frac{y}{\\theta} \\\\\\\\\n\\\\\\\\\\text{Rectification}\\\\\\\\\n{\\[X\\,Y\\,W]} ^T  \\leftarrow R\\*\\[x' \\, y' \\, 1]^T  \\\\\\\\\nx''  \\leftarrow X/W  \\\\\\\\\ny''  \\leftarrow Y/W  \\\\\\\\\n\\\\\\\\\\text{cameraMatrix}\\\\\\\\\nmap\\_x(u,v)  \\leftarrow x'' f\\_x + c\\_x  \\\\\\\\\nmap\\_y(u,v)  \\leftarrow y'' f\\_y + c\\_y\n\\end{array}\n\\f]\nwhere \\f$(k\\_1, k\\_2, p\\_1, p\\_2\\[, k\\_3\\[, k\\_4, k\\_5, k\\_6\\[, s\\_1, s\\_2, s\\_3, s\\_4\\[, \\tau\\_x, \\tau\\_y]]]])\\f$\nare the distortion coefficients vector distCoeffs.\nIn case of a stereo-rectified projector-camera pair, this function is called for the projector while #initUndistortRectifyMap is called for the camera head.\nThis is done after #stereoRectify, which in turn is called after #stereoCalibrate. If the projector-camera pair\nis not calibrated, it is still possible to compute the rectification transformations directly from\nthe fundamental matrix using #stereoRectifyUncalibrated. For the projector and camera, the function computes\nhomography H as the rectification transformation in a pixel domain, not a rotation matrix R in 3D\nspace. R can be computed from H as\n\\f[\\texttt{R} = \\texttt{cameraMatrix} ^{-1} \\cdot \\texttt{H} \\cdot \\texttt{cameraMatrix}\\f]\nwhere cameraMatrix can be chosen arbitrarily.\n\nPython prototype (for reference only):\n```python3\ninitInverseRectificationMap(cameraMatrix, distCoeffs, R, newCameraMatrix, size, m1type[, map1[, map2]]) -> map1, map2\n```","ref":"Evision.html#initInverseRectificationMap/7"},{"type":"function","title":"Evision.initUndistortRectifyMap/1","doc":"","ref":"Evision.html#initUndistortRectifyMap/1"},{"type":"function","title":"Evision.initUndistortRectifyMap/6","doc":"Computes the undistortion and rectification transformation map.\n\n##### Positional Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input camera matrix \\f$A=\\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$(k_1, k_2, p_1, p_2[, k_3[, k_4, k_5, k_6[, s_1, s_2, s_3, s_4[, \\tau_x, \\tau_y]]]])\\f$\n  of 4, 5, 8, 12 or 14 elements. If the vector is NULL/empty, the zero distortion coefficients are assumed.\n\n- **r**: `Evision.Mat`.\n\n  Optional rectification transformation in the object space (3x3 matrix). R1 or R2 ,\n  computed by #stereoRectify can be passed here. If the matrix is empty, the identity transformation\n  is assumed. In #initUndistortRectifyMap R assumed to be an identity matrix.\n\n- **newCameraMatrix**: `Evision.Mat`.\n\n  New camera matrix \\f$A'=\\vecthreethree{f_x'}{0}{c_x'}{0}{f_y'}{c_y'}{0}{0}{1}\\f$.\n\n- **size**: `Size`.\n\n  Undistorted image size.\n\n- **m1type**: `integer()`.\n\n  Type of the first output map that can be CV_32FC1, CV_32FC2 or CV_16SC2, see #convertMaps\n\n##### Return\n- **map1**: `Evision.Mat.t()`.\n\n  The first output map.\n\n- **map2**: `Evision.Mat.t()`.\n\n  The second output map.\n\nThe function computes the joint undistortion and rectification transformation and represents the\nresult in the form of maps for #remap. The undistorted image looks like original, as if it is\ncaptured with a camera using the camera matrix =newCameraMatrix and zero distortion. In case of a\nmonocular camera, newCameraMatrix is usually equal to cameraMatrix, or it can be computed by\n#getOptimalNewCameraMatrix for a better control over scaling. In case of a stereo camera,\nnewCameraMatrix is normally set to P1 or P2 computed by #stereoRectify .\nAlso, this new camera is oriented differently in the coordinate space, according to R. That, for\nexample, helps to align two heads of a stereo camera so that the epipolar lines on both images\nbecome horizontal and have the same y- coordinate (in case of a horizontally aligned stereo camera).\nThe function actually builds the maps for the inverse mapping algorithm that is used by #remap. That\nis, for each pixel \\f$(u, v)\\f$ in the destination (corrected and rectified) image, the function\ncomputes the corresponding coordinates in the source image (that is, in the original image from\ncamera). The following process is applied:\n\\f[\n\\begin{array}{l}\nx  \\leftarrow (u - {c'}\\_x)/{f'}\\_x  \\\\\\\\\ny  \\leftarrow (v - {c'}\\_y)/{f'}\\_y  \\\\\\\\\n{\\[X\\,Y\\,W]} ^T  \\leftarrow R^{-1}\\*\\[x \\, y \\, 1]^T  \\\\\\\\\nx'  \\leftarrow X/W  \\\\\\\\\ny'  \\leftarrow Y/W  \\\\\\\\\nr^2  \\leftarrow x'^2 + y'^2 \\\\\\\\\nx''  \\leftarrow x' \\frac{1 + k\\_1 r^2 + k\\_2 r^4 + k\\_3 r^6}{1 + k\\_4 r^2 + k\\_5 r^4 + k\\_6 r^6}\n\\+ 2p\\_1 x' y' + p\\_2(r^2 + 2 x'^2)  + s\\_1 r^2 + s\\_2 r^4\\\\\\\\\ny''  \\leftarrow y' \\frac{1 + k\\_1 r^2 + k\\_2 r^4 + k\\_3 r^6}{1 + k\\_4 r^2 + k\\_5 r^4 + k\\_6 r^6}\n\\+ p\\_1 (r^2 + 2 y'^2) + 2 p\\_2 x' y' + s\\_3 r^2 + s\\_4 r^4 \\\\\\\\\ns\\vecthree{x'''}{y'''}{1} =\n\\vecthreethree{R\\_{33}(\\tau\\_x, \\tau\\_y)}{0}{-R\\_{13}((\\tau\\_x, \\tau\\_y)}\n{0}{R\\_{33}(\\tau\\_x, \\tau\\_y)}{-R\\_{23}(\\tau\\_x, \\tau\\_y)}\n{0}{0}{1} R(\\tau\\_x, \\tau\\_y) \\vecthree{x''}{y''}{1}\\\\\\\\\nmap\\_x(u,v)  \\leftarrow x''' f\\_x + c\\_x  \\\\\\\\\nmap\\_y(u,v)  \\leftarrow y''' f\\_y + c\\_y\n\\end{array}\n\\f]\nwhere \\f$(k\\_1, k\\_2, p\\_1, p\\_2\\[, k\\_3\\[, k\\_4, k\\_5, k\\_6\\[, s\\_1, s\\_2, s\\_3, s\\_4\\[, \\tau\\_x, \\tau\\_y]]]])\\f$\nare the distortion coefficients.\nIn case of a stereo camera, this function is called twice: once for each camera head, after\n#stereoRectify, which in its turn is called after #stereoCalibrate. But if the stereo camera\nwas not calibrated, it is still possible to compute the rectification transformations directly from\nthe fundamental matrix using #stereoRectifyUncalibrated. For each camera, the function computes\nhomography H as the rectification transformation in a pixel domain, not a rotation matrix R in 3D\nspace. R can be computed from H as\n\\f[\\texttt{R} = \\texttt{cameraMatrix} ^{-1} \\cdot \\texttt{H} \\cdot \\texttt{cameraMatrix}\\f]\nwhere cameraMatrix can be chosen arbitrarily.\n\nPython prototype (for reference only):\n```python3\ninitUndistortRectifyMap(cameraMatrix, distCoeffs, R, newCameraMatrix, size, m1type[, map1[, map2]]) -> map1, map2\n```","ref":"Evision.html#initUndistortRectifyMap/6"},{"type":"function","title":"Evision.initUndistortRectifyMap/7","doc":"Computes the undistortion and rectification transformation map.\n\n##### Positional Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input camera matrix \\f$A=\\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$(k_1, k_2, p_1, p_2[, k_3[, k_4, k_5, k_6[, s_1, s_2, s_3, s_4[, \\tau_x, \\tau_y]]]])\\f$\n  of 4, 5, 8, 12 or 14 elements. If the vector is NULL/empty, the zero distortion coefficients are assumed.\n\n- **r**: `Evision.Mat`.\n\n  Optional rectification transformation in the object space (3x3 matrix). R1 or R2 ,\n  computed by #stereoRectify can be passed here. If the matrix is empty, the identity transformation\n  is assumed. In #initUndistortRectifyMap R assumed to be an identity matrix.\n\n- **newCameraMatrix**: `Evision.Mat`.\n\n  New camera matrix \\f$A'=\\vecthreethree{f_x'}{0}{c_x'}{0}{f_y'}{c_y'}{0}{0}{1}\\f$.\n\n- **size**: `Size`.\n\n  Undistorted image size.\n\n- **m1type**: `integer()`.\n\n  Type of the first output map that can be CV_32FC1, CV_32FC2 or CV_16SC2, see #convertMaps\n\n##### Return\n- **map1**: `Evision.Mat.t()`.\n\n  The first output map.\n\n- **map2**: `Evision.Mat.t()`.\n\n  The second output map.\n\nThe function computes the joint undistortion and rectification transformation and represents the\nresult in the form of maps for #remap. The undistorted image looks like original, as if it is\ncaptured with a camera using the camera matrix =newCameraMatrix and zero distortion. In case of a\nmonocular camera, newCameraMatrix is usually equal to cameraMatrix, or it can be computed by\n#getOptimalNewCameraMatrix for a better control over scaling. In case of a stereo camera,\nnewCameraMatrix is normally set to P1 or P2 computed by #stereoRectify .\nAlso, this new camera is oriented differently in the coordinate space, according to R. That, for\nexample, helps to align two heads of a stereo camera so that the epipolar lines on both images\nbecome horizontal and have the same y- coordinate (in case of a horizontally aligned stereo camera).\nThe function actually builds the maps for the inverse mapping algorithm that is used by #remap. That\nis, for each pixel \\f$(u, v)\\f$ in the destination (corrected and rectified) image, the function\ncomputes the corresponding coordinates in the source image (that is, in the original image from\ncamera). The following process is applied:\n\\f[\n\\begin{array}{l}\nx  \\leftarrow (u - {c'}\\_x)/{f'}\\_x  \\\\\\\\\ny  \\leftarrow (v - {c'}\\_y)/{f'}\\_y  \\\\\\\\\n{\\[X\\,Y\\,W]} ^T  \\leftarrow R^{-1}\\*\\[x \\, y \\, 1]^T  \\\\\\\\\nx'  \\leftarrow X/W  \\\\\\\\\ny'  \\leftarrow Y/W  \\\\\\\\\nr^2  \\leftarrow x'^2 + y'^2 \\\\\\\\\nx''  \\leftarrow x' \\frac{1 + k\\_1 r^2 + k\\_2 r^4 + k\\_3 r^6}{1 + k\\_4 r^2 + k\\_5 r^4 + k\\_6 r^6}\n\\+ 2p\\_1 x' y' + p\\_2(r^2 + 2 x'^2)  + s\\_1 r^2 + s\\_2 r^4\\\\\\\\\ny''  \\leftarrow y' \\frac{1 + k\\_1 r^2 + k\\_2 r^4 + k\\_3 r^6}{1 + k\\_4 r^2 + k\\_5 r^4 + k\\_6 r^6}\n\\+ p\\_1 (r^2 + 2 y'^2) + 2 p\\_2 x' y' + s\\_3 r^2 + s\\_4 r^4 \\\\\\\\\ns\\vecthree{x'''}{y'''}{1} =\n\\vecthreethree{R\\_{33}(\\tau\\_x, \\tau\\_y)}{0}{-R\\_{13}((\\tau\\_x, \\tau\\_y)}\n{0}{R\\_{33}(\\tau\\_x, \\tau\\_y)}{-R\\_{23}(\\tau\\_x, \\tau\\_y)}\n{0}{0}{1} R(\\tau\\_x, \\tau\\_y) \\vecthree{x''}{y''}{1}\\\\\\\\\nmap\\_x(u,v)  \\leftarrow x''' f\\_x + c\\_x  \\\\\\\\\nmap\\_y(u,v)  \\leftarrow y''' f\\_y + c\\_y\n\\end{array}\n\\f]\nwhere \\f$(k\\_1, k\\_2, p\\_1, p\\_2\\[, k\\_3\\[, k\\_4, k\\_5, k\\_6\\[, s\\_1, s\\_2, s\\_3, s\\_4\\[, \\tau\\_x, \\tau\\_y]]]])\\f$\nare the distortion coefficients.\nIn case of a stereo camera, this function is called twice: once for each camera head, after\n#stereoRectify, which in its turn is called after #stereoCalibrate. But if the stereo camera\nwas not calibrated, it is still possible to compute the rectification transformations directly from\nthe fundamental matrix using #stereoRectifyUncalibrated. For each camera, the function computes\nhomography H as the rectification transformation in a pixel domain, not a rotation matrix R in 3D\nspace. R can be computed from H as\n\\f[\\texttt{R} = \\texttt{cameraMatrix} ^{-1} \\cdot \\texttt{H} \\cdot \\texttt{cameraMatrix}\\f]\nwhere cameraMatrix can be chosen arbitrarily.\n\nPython prototype (for reference only):\n```python3\ninitUndistortRectifyMap(cameraMatrix, distCoeffs, R, newCameraMatrix, size, m1type[, map1[, map2]]) -> map1, map2\n```","ref":"Evision.html#initUndistortRectifyMap/7"},{"type":"function","title":"Evision.inpaint/1","doc":"","ref":"Evision.html#inpaint/1"},{"type":"function","title":"Evision.inpaint/4","doc":"Restores the selected region in an image using the region neighborhood.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit, 16-bit unsigned or 32-bit float 1-channel or 8-bit 3-channel image.\n\n- **inpaintMask**: `Evision.Mat`.\n\n  Inpainting mask, 8-bit 1-channel image. Non-zero pixels indicate the area that\n  needs to be inpainted.\n\n- **inpaintRadius**: `double`.\n\n  Radius of a circular neighborhood of each point inpainted that is considered\n  by the algorithm.\n\n- **flags**: `integer()`.\n\n  Inpainting method that could be cv::INPAINT_NS or cv::INPAINT_TELEA\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as src .\n\nThe function reconstructs the selected image area from the pixel near the area boundary. The\nfunction may be used to remove dust and scratches from a scanned photo, or to remove undesirable\nobjects from still images or video. See   for more details.\n**Note**: \n- An example using the inpainting technique can be found at\n  opencv_source_code/samples/cpp/inpaint.cpp\n\n- (Python) An example using the inpainting technique can be found at\n  opencv_source_code/samples/python/inpaint.py\n\nPython prototype (for reference only):\n```python3\ninpaint(src, inpaintMask, inpaintRadius, flags[, dst]) -> dst\n```","ref":"Evision.html#inpaint/4"},{"type":"function","title":"Evision.inpaint/5","doc":"Restores the selected region in an image using the region neighborhood.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit, 16-bit unsigned or 32-bit float 1-channel or 8-bit 3-channel image.\n\n- **inpaintMask**: `Evision.Mat`.\n\n  Inpainting mask, 8-bit 1-channel image. Non-zero pixels indicate the area that\n  needs to be inpainted.\n\n- **inpaintRadius**: `double`.\n\n  Radius of a circular neighborhood of each point inpainted that is considered\n  by the algorithm.\n\n- **flags**: `integer()`.\n\n  Inpainting method that could be cv::INPAINT_NS or cv::INPAINT_TELEA\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as src .\n\nThe function reconstructs the selected image area from the pixel near the area boundary. The\nfunction may be used to remove dust and scratches from a scanned photo, or to remove undesirable\nobjects from still images or video. See   for more details.\n**Note**: \n- An example using the inpainting technique can be found at\n  opencv_source_code/samples/cpp/inpaint.cpp\n\n- (Python) An example using the inpainting technique can be found at\n  opencv_source_code/samples/python/inpaint.py\n\nPython prototype (for reference only):\n```python3\ninpaint(src, inpaintMask, inpaintRadius, flags[, dst]) -> dst\n```","ref":"Evision.html#inpaint/5"},{"type":"function","title":"Evision.inRange/1","doc":"","ref":"Evision.html#inRange/1"},{"type":"function","title":"Evision.inRange/3","doc":"Checks if array elements lie between the elements of two other arrays.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  first input array.\n\n- **lowerb**: `Evision.Mat`.\n\n  inclusive lower boundary array or a scalar.\n\n- **upperb**: `Evision.Mat`.\n\n  inclusive upper boundary array or a scalar.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size as src and CV_8U type.\n\nThe function checks the range as follows:\n- For every element of a single-channel input array:\n  \\f[\\texttt{dst} (I)= \\texttt{lowerb} (I)\\_0  \\leq \\texttt{src} (I)\\_0 \\leq  \\texttt{upperb} (I)\\_0\\f]\n\n- For two-channel arrays:\n  \\f[\\texttt{dst} (I)= \\texttt{lowerb} (I)\\_0  \\leq \\texttt{src} (I)\\_0 \\leq  \\texttt{upperb} (I)\\_0  \\land \\texttt{lowerb} (I)\\_1  \\leq \\texttt{src} (I)\\_1 \\leq  \\texttt{upperb} (I)\\_1\\f]\n\n- and so forth.\n\nThat is, dst (I) is set to 255 (all 1 -bits) if src (I) is within the\nspecified 1D, 2D, 3D, ... box and 0 otherwise.\nWhen the lower and/or upper boundary parameters are scalars, the indexes\n(I) at lowerb and upperb in the above formulas should be omitted.\n\nPython prototype (for reference only):\n```python3\ninRange(src, lowerb, upperb[, dst]) -> dst\n```","ref":"Evision.html#inRange/3"},{"type":"function","title":"Evision.inRange/4","doc":"Checks if array elements lie between the elements of two other arrays.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  first input array.\n\n- **lowerb**: `Evision.Mat`.\n\n  inclusive lower boundary array or a scalar.\n\n- **upperb**: `Evision.Mat`.\n\n  inclusive upper boundary array or a scalar.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size as src and CV_8U type.\n\nThe function checks the range as follows:\n- For every element of a single-channel input array:\n  \\f[\\texttt{dst} (I)= \\texttt{lowerb} (I)\\_0  \\leq \\texttt{src} (I)\\_0 \\leq  \\texttt{upperb} (I)\\_0\\f]\n\n- For two-channel arrays:\n  \\f[\\texttt{dst} (I)= \\texttt{lowerb} (I)\\_0  \\leq \\texttt{src} (I)\\_0 \\leq  \\texttt{upperb} (I)\\_0  \\land \\texttt{lowerb} (I)\\_1  \\leq \\texttt{src} (I)\\_1 \\leq  \\texttt{upperb} (I)\\_1\\f]\n\n- and so forth.\n\nThat is, dst (I) is set to 255 (all 1 -bits) if src (I) is within the\nspecified 1D, 2D, 3D, ... box and 0 otherwise.\nWhen the lower and/or upper boundary parameters are scalars, the indexes\n(I) at lowerb and upperb in the above formulas should be omitted.\n\nPython prototype (for reference only):\n```python3\ninRange(src, lowerb, upperb[, dst]) -> dst\n```","ref":"Evision.html#inRange/4"},{"type":"function","title":"Evision.insertChannel/1","doc":"","ref":"Evision.html#insertChannel/1"},{"type":"function","title":"Evision.insertChannel/3","doc":"Inserts a single channel to dst (coi is 0-based index)\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array\n\n- **coi**: `integer()`.\n\n  index of channel for insertion\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array\n\n@sa mixChannels, merge\n\nPython prototype (for reference only):\n```python3\ninsertChannel(src, dst, coi) -> dst\n```","ref":"Evision.html#insertChannel/3"},{"type":"function","title":"Evision.integral2/1","doc":"integral2\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **sdepth**: `integer()`.\n- **sqdepth**: `integer()`.\n\n##### Return\n- **sum**: `Evision.Mat.t()`.\n- **sqsum**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nintegral2(src[, sum[, sqsum[, sdepth[, sqdepth]]]]) -> sum, sqsum\n```","ref":"Evision.html#integral2/1"},{"type":"function","title":"Evision.integral2/2","doc":"integral2\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **sdepth**: `integer()`.\n- **sqdepth**: `integer()`.\n\n##### Return\n- **sum**: `Evision.Mat.t()`.\n- **sqsum**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nintegral2(src[, sum[, sqsum[, sdepth[, sqdepth]]]]) -> sum, sqsum\n```","ref":"Evision.html#integral2/2"},{"type":"function","title":"Evision.integral3/1","doc":"Calculates the integral of an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image as \\f$W \\times H\\f$, 8-bit or floating-point (32f or 64f).\n\n##### Keyword Arguments\n- **sdepth**: `integer()`.\n\n  desired depth of the integral and the tilted integral images, CV_32S, CV_32F, or\n  CV_64F.\n\n- **sqdepth**: `integer()`.\n\n  desired depth of the integral image of squared pixel values, CV_32F or CV_64F.\n\n##### Return\n- **sum**: `Evision.Mat.t()`.\n\n  integral image as \\f$(W+1)\\times (H+1)\\f$ , 32-bit integer or floating-point (32f or 64f).\n\n- **sqsum**: `Evision.Mat.t()`.\n\n  integral image for squared pixel values; it is \\f$(W+1)\\times (H+1)\\f$, double-precision\n  floating-point (64f) array.\n\n- **tilted**: `Evision.Mat.t()`.\n\n  integral for the image rotated by 45 degrees; it is \\f$(W+1)\\times (H+1)\\f$ array with\n  the same data type as sum.\n\nThe function calculates one or more integral images for the source image as follows:\n\\f[\\texttt{sum} (X,Y) =  \\sum \\_{x  sum, sqsum, tilted\n```","ref":"Evision.html#integral3/1"},{"type":"function","title":"Evision.integral3/2","doc":"Calculates the integral of an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image as \\f$W \\times H\\f$, 8-bit or floating-point (32f or 64f).\n\n##### Keyword Arguments\n- **sdepth**: `integer()`.\n\n  desired depth of the integral and the tilted integral images, CV_32S, CV_32F, or\n  CV_64F.\n\n- **sqdepth**: `integer()`.\n\n  desired depth of the integral image of squared pixel values, CV_32F or CV_64F.\n\n##### Return\n- **sum**: `Evision.Mat.t()`.\n\n  integral image as \\f$(W+1)\\times (H+1)\\f$ , 32-bit integer or floating-point (32f or 64f).\n\n- **sqsum**: `Evision.Mat.t()`.\n\n  integral image for squared pixel values; it is \\f$(W+1)\\times (H+1)\\f$, double-precision\n  floating-point (64f) array.\n\n- **tilted**: `Evision.Mat.t()`.\n\n  integral for the image rotated by 45 degrees; it is \\f$(W+1)\\times (H+1)\\f$ array with\n  the same data type as sum.\n\nThe function calculates one or more integral images for the source image as follows:\n\\f[\\texttt{sum} (X,Y) =  \\sum \\_{x  sum, sqsum, tilted\n```","ref":"Evision.html#integral3/2"},{"type":"function","title":"Evision.integral/1","doc":"integral\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **sdepth**: `integer()`.\n\n##### Return\n- **sum**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nintegral(src[, sum[, sdepth]]) -> sum\n```","ref":"Evision.html#integral/1"},{"type":"function","title":"Evision.integral/2","doc":"integral\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **sdepth**: `integer()`.\n\n##### Return\n- **sum**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nintegral(src[, sum[, sdepth]]) -> sum\n```","ref":"Evision.html#integral/2"},{"type":"function","title":"Evision.intersectConvexConvex/1","doc":"","ref":"Evision.html#intersectConvexConvex/1"},{"type":"function","title":"Evision.intersectConvexConvex/2","doc":"Finds intersection of two convex polygons\n\n##### Positional Arguments\n- **p1**: `Evision.Mat`.\n\n  First polygon\n\n- **p2**: `Evision.Mat`.\n\n  Second polygon\n\n##### Keyword Arguments\n- **handleNested**: `bool`.\n\n  When true, an intersection is found if one of the polygons is fully enclosed in the other.\n  When false, no intersection is found. If the polygons share a side or the vertex of one polygon lies on an edge\n  of the other, they are not considered nested and an intersection will be found regardless of the value of handleNested.\n\n##### Return\n- **retval**: `float`\n- **p12**: `Evision.Mat.t()`.\n\n  Output polygon describing the intersecting area\n\n@returns Absolute value of area of intersecting polygon\n**Note**: intersectConvexConvex doesn't confirm that both polygons are convex and will return invalid results if they aren't.\n\nPython prototype (for reference only):\n```python3\nintersectConvexConvex(p1, p2[, p12[, handleNested]]) -> retval, p12\n```","ref":"Evision.html#intersectConvexConvex/2"},{"type":"function","title":"Evision.intersectConvexConvex/3","doc":"Finds intersection of two convex polygons\n\n##### Positional Arguments\n- **p1**: `Evision.Mat`.\n\n  First polygon\n\n- **p2**: `Evision.Mat`.\n\n  Second polygon\n\n##### Keyword Arguments\n- **handleNested**: `bool`.\n\n  When true, an intersection is found if one of the polygons is fully enclosed in the other.\n  When false, no intersection is found. If the polygons share a side or the vertex of one polygon lies on an edge\n  of the other, they are not considered nested and an intersection will be found regardless of the value of handleNested.\n\n##### Return\n- **retval**: `float`\n- **p12**: `Evision.Mat.t()`.\n\n  Output polygon describing the intersecting area\n\n@returns Absolute value of area of intersecting polygon\n**Note**: intersectConvexConvex doesn't confirm that both polygons are convex and will return invalid results if they aren't.\n\nPython prototype (for reference only):\n```python3\nintersectConvexConvex(p1, p2[, p12[, handleNested]]) -> retval, p12\n```","ref":"Evision.html#intersectConvexConvex/3"},{"type":"function","title":"Evision.invert/1","doc":"Finds the inverse or pseudo-inverse of a matrix.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input floating-point M x N matrix.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  inversion method (cv::DecompTypes)\n\n##### Return\n- **retval**: `double`\n- **dst**: `Evision.Mat.t()`.\n\n  output matrix of N x M size and the same type as src.\n\nThe function cv::invert inverts the matrix src and stores the result in dst\n. When the matrix src is singular or non-square, the function calculates\nthe pseudo-inverse matrix (the dst matrix) so that norm(src\\*dst - I) is\nminimal, where I is an identity matrix.\nIn case of the #DECOMP_LU method, the function returns non-zero value if\nthe inverse has been successfully calculated and 0 if src is singular.\nIn case of the #DECOMP_SVD method, the function returns the inverse\ncondition number of src (the ratio of the smallest singular value to the\nlargest singular value) and 0 if src is singular. The SVD method\ncalculates a pseudo-inverse matrix if src is singular.\nSimilarly to #DECOMP_LU, the method #DECOMP_CHOLESKY works only with\nnon-singular square matrices that should also be symmetrical and\npositively defined. In this case, the function stores the inverted\nmatrix in dst and returns non-zero. Otherwise, it returns 0.\n@sa solve, SVD\n\nPython prototype (for reference only):\n```python3\ninvert(src[, dst[, flags]]) -> retval, dst\n```","ref":"Evision.html#invert/1"},{"type":"function","title":"Evision.invert/2","doc":"Finds the inverse or pseudo-inverse of a matrix.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input floating-point M x N matrix.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  inversion method (cv::DecompTypes)\n\n##### Return\n- **retval**: `double`\n- **dst**: `Evision.Mat.t()`.\n\n  output matrix of N x M size and the same type as src.\n\nThe function cv::invert inverts the matrix src and stores the result in dst\n. When the matrix src is singular or non-square, the function calculates\nthe pseudo-inverse matrix (the dst matrix) so that norm(src\\*dst - I) is\nminimal, where I is an identity matrix.\nIn case of the #DECOMP_LU method, the function returns non-zero value if\nthe inverse has been successfully calculated and 0 if src is singular.\nIn case of the #DECOMP_SVD method, the function returns the inverse\ncondition number of src (the ratio of the smallest singular value to the\nlargest singular value) and 0 if src is singular. The SVD method\ncalculates a pseudo-inverse matrix if src is singular.\nSimilarly to #DECOMP_LU, the method #DECOMP_CHOLESKY works only with\nnon-singular square matrices that should also be symmetrical and\npositively defined. In this case, the function stores the inverted\nmatrix in dst and returns non-zero. Otherwise, it returns 0.\n@sa solve, SVD\n\nPython prototype (for reference only):\n```python3\ninvert(src[, dst[, flags]]) -> retval, dst\n```","ref":"Evision.html#invert/2"},{"type":"function","title":"Evision.invertAffineTransform/1","doc":"Inverts an affine transformation.\n\n##### Positional Arguments\n- **m**: `Evision.Mat`.\n\n  Original affine transformation.\n\n##### Return\n- **iM**: `Evision.Mat.t()`.\n\n  Output reverse affine transformation.\n\nThe function computes an inverse affine transformation represented by \\f$2 \\times 3\\f$ matrix M:\n\\f[\\begin{bmatrix} a\\_{11} & a\\_{12} & b\\_1  \\\\\\\\ a\\_{21} & a\\_{22} & b\\_2 \\end{bmatrix}\\f]\nThe result is also a \\f$2 \\times 3\\f$ matrix of the same type as M.\n\nPython prototype (for reference only):\n```python3\ninvertAffineTransform(M[, iM]) -> iM\n```","ref":"Evision.html#invertAffineTransform/1"},{"type":"function","title":"Evision.invertAffineTransform/2","doc":"Inverts an affine transformation.\n\n##### Positional Arguments\n- **m**: `Evision.Mat`.\n\n  Original affine transformation.\n\n##### Return\n- **iM**: `Evision.Mat.t()`.\n\n  Output reverse affine transformation.\n\nThe function computes an inverse affine transformation represented by \\f$2 \\times 3\\f$ matrix M:\n\\f[\\begin{bmatrix} a\\_{11} & a\\_{12} & b\\_1  \\\\\\\\ a\\_{21} & a\\_{22} & b\\_2 \\end{bmatrix}\\f]\nThe result is also a \\f$2 \\times 3\\f$ matrix of the same type as M.\n\nPython prototype (for reference only):\n```python3\ninvertAffineTransform(M[, iM]) -> iM\n```","ref":"Evision.html#invertAffineTransform/2"},{"type":"function","title":"Evision.isContourConvex/1","doc":"Tests a contour convexity.\n\n##### Positional Arguments\n- **contour**: `Evision.Mat`.\n\n  Input vector of 2D points, stored in std::vector\\<\\> or Mat\n\n##### Return\n- **retval**: `bool`\n\nThe function tests whether the input contour is convex or not. The contour must be simple, that is,\nwithout self-intersections. Otherwise, the function output is undefined.\n\nPython prototype (for reference only):\n```python3\nisContourConvex(contour) -> retval\n```","ref":"Evision.html#isContourConvex/1"},{"type":"function","title":"Evision.kmeans/1","doc":"","ref":"Evision.html#kmeans/1"},{"type":"function","title":"Evision.kmeans/6","doc":"Finds centers of clusters and groups input samples around the clusters.\n\n##### Positional Arguments\n- **data**: `Evision.Mat`.\n\n  Data for clustering. An array of N-Dimensional points with float coordinates is needed.\n  Examples of this array can be:\n  - Mat points(count, 2, CV_32F);\n  - Mat points(count, 1, CV_32FC2);\n  - Mat points(1, count, CV_32FC2);\n  - std::vector\\  points(sampleCount);\n\n- **k**: `integer()`.\n\n  Number of clusters to split the set by.\n\n- **criteria**: `TermCriteria`.\n\n  The algorithm termination criteria, that is, the maximum number of iterations and/or\n  the desired accuracy. The accuracy is specified as criteria.epsilon. As soon as each of the cluster\n  centers moves by less than criteria.epsilon on some iteration, the algorithm stops.\n\n- **attempts**: `integer()`.\n\n  Flag to specify the number of times the algorithm is executed using different\n  initial labellings. The algorithm returns the labels that yield the best compactness (see the last\n  function parameter).\n\n- **flags**: `integer()`.\n\n  Flag that can take values of cv::KmeansFlags\n\n##### Return\n- **retval**: `double`\n- **bestLabels**: `Evision.Mat.t()`.\n\n  Input/output integer array that stores the cluster indices for every sample.\n\n- **centers**: `Evision.Mat.t()`.\n\n  Output matrix of the cluster centers, one row per each cluster center.\n\nThe function kmeans implements a k-means algorithm that finds the centers of cluster_count clusters\nand groups the input samples around the clusters. As an output, \\f$\\texttt{bestLabels}\\_i\\f$ contains a\n0-based cluster index for the sample stored in the \\f$i^{th}\\f$ row of the samples matrix.\n**Note**: \n- (Python) An example on K-means clustering can be found at\n  opencv_source_code/samples/python/kmeans.py\n\n@return The function returns the compactness measure that is computed as\n\\f[\\sum \\_i  \\| \\texttt{samples} \\_i -  \\texttt{centers} \\_{ \\texttt{labels} \\_i} \\| ^2\\f]\nafter every attempt. The best (minimum) value is chosen and the corresponding labels and the\ncompactness value are returned by the function. Basically, you can use only the core of the\nfunction, set the number of attempts to 1, initialize labels each time using a custom algorithm,\npass them with the ( flags = #KMEANS_USE_INITIAL_LABELS ) flag, and then choose the best\n(most-compact) clustering.\n\nPython prototype (for reference only):\n```python3\nkmeans(data, K, bestLabels, criteria, attempts, flags[, centers]) -> retval, bestLabels, centers\n```","ref":"Evision.html#kmeans/6"},{"type":"function","title":"Evision.kmeans/7","doc":"Finds centers of clusters and groups input samples around the clusters.\n\n##### Positional Arguments\n- **data**: `Evision.Mat`.\n\n  Data for clustering. An array of N-Dimensional points with float coordinates is needed.\n  Examples of this array can be:\n  - Mat points(count, 2, CV_32F);\n  - Mat points(count, 1, CV_32FC2);\n  - Mat points(1, count, CV_32FC2);\n  - std::vector\\  points(sampleCount);\n\n- **k**: `integer()`.\n\n  Number of clusters to split the set by.\n\n- **criteria**: `TermCriteria`.\n\n  The algorithm termination criteria, that is, the maximum number of iterations and/or\n  the desired accuracy. The accuracy is specified as criteria.epsilon. As soon as each of the cluster\n  centers moves by less than criteria.epsilon on some iteration, the algorithm stops.\n\n- **attempts**: `integer()`.\n\n  Flag to specify the number of times the algorithm is executed using different\n  initial labellings. The algorithm returns the labels that yield the best compactness (see the last\n  function parameter).\n\n- **flags**: `integer()`.\n\n  Flag that can take values of cv::KmeansFlags\n\n##### Return\n- **retval**: `double`\n- **bestLabels**: `Evision.Mat.t()`.\n\n  Input/output integer array that stores the cluster indices for every sample.\n\n- **centers**: `Evision.Mat.t()`.\n\n  Output matrix of the cluster centers, one row per each cluster center.\n\nThe function kmeans implements a k-means algorithm that finds the centers of cluster_count clusters\nand groups the input samples around the clusters. As an output, \\f$\\texttt{bestLabels}\\_i\\f$ contains a\n0-based cluster index for the sample stored in the \\f$i^{th}\\f$ row of the samples matrix.\n**Note**: \n- (Python) An example on K-means clustering can be found at\n  opencv_source_code/samples/python/kmeans.py\n\n@return The function returns the compactness measure that is computed as\n\\f[\\sum \\_i  \\| \\texttt{samples} \\_i -  \\texttt{centers} \\_{ \\texttt{labels} \\_i} \\| ^2\\f]\nafter every attempt. The best (minimum) value is chosen and the corresponding labels and the\ncompactness value are returned by the function. Basically, you can use only the core of the\nfunction, set the number of attempts to 1, initialize labels each time using a custom algorithm,\npass them with the ( flags = #KMEANS_USE_INITIAL_LABELS ) flag, and then choose the best\n(most-compact) clustering.\n\nPython prototype (for reference only):\n```python3\nkmeans(data, K, bestLabels, criteria, attempts, flags[, centers]) -> retval, bestLabels, centers\n```","ref":"Evision.html#kmeans/7"},{"type":"function","title":"Evision.laplacian/1","doc":"","ref":"Evision.html#laplacian/1"},{"type":"function","title":"Evision.laplacian/2","doc":"Calculates the Laplacian of an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image.\n\n- **ddepth**: `integer()`.\n\n  Desired depth of the destination image, see @ref filter_depths \"combinations\".\n\n##### Keyword Arguments\n- **ksize**: `integer()`.\n\n  Aperture size used to compute the second-derivative filters. See #getDerivKernels for\n  details. The size must be positive and odd.\n\n- **scale**: `double`.\n\n  Optional scale factor for the computed Laplacian values. By default, no scaling is\n  applied. See #getDerivKernels for details.\n\n- **delta**: `double`.\n\n  Optional delta value that is added to the results prior to storing them in dst .\n\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method, see #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and the same number of channels as src .\n\nThe function calculates the Laplacian of the source image by adding up the second x and y\nderivatives calculated using the Sobel operator:\n\\f[\\texttt{dst} =  \\Delta \\texttt{src} =  \\frac{\\partial^2 \\texttt{src}}{\\partial x^2} +  \\frac{\\partial^2 \\texttt{src}}{\\partial y^2}\\f]\nThis is done when `ksize > 1`. When `ksize == 1`, the Laplacian is computed by filtering the image\nwith the following \\f$3 \\times 3\\f$ aperture:\n\\f[\\vecthreethree {0}{1}{0}{1}{-4}{1}{0}{1}{0}\\f]\n@sa  Sobel, Scharr\n\nPython prototype (for reference only):\n```python3\nLaplacian(src, ddepth[, dst[, ksize[, scale[, delta[, borderType]]]]]) -> dst\n```","ref":"Evision.html#laplacian/2"},{"type":"function","title":"Evision.laplacian/3","doc":"Calculates the Laplacian of an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image.\n\n- **ddepth**: `integer()`.\n\n  Desired depth of the destination image, see @ref filter_depths \"combinations\".\n\n##### Keyword Arguments\n- **ksize**: `integer()`.\n\n  Aperture size used to compute the second-derivative filters. See #getDerivKernels for\n  details. The size must be positive and odd.\n\n- **scale**: `double`.\n\n  Optional scale factor for the computed Laplacian values. By default, no scaling is\n  applied. See #getDerivKernels for details.\n\n- **delta**: `double`.\n\n  Optional delta value that is added to the results prior to storing them in dst .\n\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method, see #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and the same number of channels as src .\n\nThe function calculates the Laplacian of the source image by adding up the second x and y\nderivatives calculated using the Sobel operator:\n\\f[\\texttt{dst} =  \\Delta \\texttt{src} =  \\frac{\\partial^2 \\texttt{src}}{\\partial x^2} +  \\frac{\\partial^2 \\texttt{src}}{\\partial y^2}\\f]\nThis is done when `ksize > 1`. When `ksize == 1`, the Laplacian is computed by filtering the image\nwith the following \\f$3 \\times 3\\f$ aperture:\n\\f[\\vecthreethree {0}{1}{0}{1}{-4}{1}{0}{1}{0}\\f]\n@sa  Sobel, Scharr\n\nPython prototype (for reference only):\n```python3\nLaplacian(src, ddepth[, dst[, ksize[, scale[, delta[, borderType]]]]]) -> dst\n```","ref":"Evision.html#laplacian/3"},{"type":"function","title":"Evision.line/1","doc":"","ref":"Evision.html#line/1"},{"type":"function","title":"Evision.line/4","doc":"Draws a line segment connecting two points.\n\n##### Positional Arguments\n- **pt1**: `Point`.\n\n  First point of the line segment.\n\n- **pt2**: `Point`.\n\n  Second point of the line segment.\n\n- **color**: `Evision.scalar()`.\n\n  Line color.\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n\n  Line thickness.\n\n- **lineType**: `integer()`.\n\n  Type of the line. See #LineTypes.\n\n- **shift**: `integer()`.\n\n  Number of fractional bits in the point coordinates.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  Image.\n\nThe function line draws the line segment between pt1 and pt2 points in the image. The line is\nclipped by the image boundaries. For non-antialiased lines with integer coordinates, the 8-connected\nor 4-connected Bresenham algorithm is used. Thick lines are drawn with rounding endings. Antialiased\nlines are drawn using Gaussian filtering.\n\nPython prototype (for reference only):\n```python3\nline(img, pt1, pt2, color[, thickness[, lineType[, shift]]]) -> img\n```","ref":"Evision.html#line/4"},{"type":"function","title":"Evision.line/5","doc":"Draws a line segment connecting two points.\n\n##### Positional Arguments\n- **pt1**: `Point`.\n\n  First point of the line segment.\n\n- **pt2**: `Point`.\n\n  Second point of the line segment.\n\n- **color**: `Evision.scalar()`.\n\n  Line color.\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n\n  Line thickness.\n\n- **lineType**: `integer()`.\n\n  Type of the line. See #LineTypes.\n\n- **shift**: `integer()`.\n\n  Number of fractional bits in the point coordinates.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  Image.\n\nThe function line draws the line segment between pt1 and pt2 points in the image. The line is\nclipped by the image boundaries. For non-antialiased lines with integer coordinates, the 8-connected\nor 4-connected Bresenham algorithm is used. Thick lines are drawn with rounding endings. Antialiased\nlines are drawn using Gaussian filtering.\n\nPython prototype (for reference only):\n```python3\nline(img, pt1, pt2, color[, thickness[, lineType[, shift]]]) -> img\n```","ref":"Evision.html#line/5"},{"type":"function","title":"Evision.linearPolar/1","doc":"","ref":"Evision.html#linearPolar/1"},{"type":"function","title":"Evision.linearPolar/4","doc":"Remaps an image to polar coordinates space.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image\n\n- **center**: `Point2f`.\n\n  The transformation center;\n\n- **maxRadius**: `double`.\n\n  The radius of the bounding circle to transform. It determines the inverse magnitude scale parameter too.\n\n- **flags**: `integer()`.\n\n  A combination of interpolation methods, see #InterpolationFlags\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image. It will have same size and type as src.\n\n@deprecated This function produces same result as cv::warpPolar(src, dst, src.size(), center, maxRadius, flags)\n@internal\nTransform the source image using the following transformation (See @ref polar_remaps_reference_image \"Polar remaps reference image c)\"):\n\\f[\\begin{array}{l}\ndst( \\rho , \\phi ) = src(x,y) \\\\\\\\\ndst.size() \\leftarrow src.size()\n\\end{array}\\f]\nwhere\n\\f[\\begin{array}{l}\nI = (dx,dy) = (x - center.x,y - center.y) \\\\\\\\\n\\rho = Kmag \\cdot \\texttt{magnitude} (I) ,\\\\\\\\\n\\phi = angle \\cdot \\texttt{angle} (I)\n\\end{array}\\f]\nand\n\\f[\\begin{array}{l}\nKx = src.cols / maxRadius \\\\\\\\\nKy = src.rows / 2\\Pi\n\\end{array}\\f]\n\n**Note**: \n- The function can not operate in-place.\n- To calculate magnitude and angle in degrees #cartToPolar is used internally thus angles are measured from 0 to 360 with accuracy about 0.3 degrees.\n\n@sa cv::logPolar\n@endinternal\n\nPython prototype (for reference only):\n```python3\nlinearPolar(src, center, maxRadius, flags[, dst]) -> dst\n```","ref":"Evision.html#linearPolar/4"},{"type":"function","title":"Evision.linearPolar/5","doc":"Remaps an image to polar coordinates space.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image\n\n- **center**: `Point2f`.\n\n  The transformation center;\n\n- **maxRadius**: `double`.\n\n  The radius of the bounding circle to transform. It determines the inverse magnitude scale parameter too.\n\n- **flags**: `integer()`.\n\n  A combination of interpolation methods, see #InterpolationFlags\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image. It will have same size and type as src.\n\n@deprecated This function produces same result as cv::warpPolar(src, dst, src.size(), center, maxRadius, flags)\n@internal\nTransform the source image using the following transformation (See @ref polar_remaps_reference_image \"Polar remaps reference image c)\"):\n\\f[\\begin{array}{l}\ndst( \\rho , \\phi ) = src(x,y) \\\\\\\\\ndst.size() \\leftarrow src.size()\n\\end{array}\\f]\nwhere\n\\f[\\begin{array}{l}\nI = (dx,dy) = (x - center.x,y - center.y) \\\\\\\\\n\\rho = Kmag \\cdot \\texttt{magnitude} (I) ,\\\\\\\\\n\\phi = angle \\cdot \\texttt{angle} (I)\n\\end{array}\\f]\nand\n\\f[\\begin{array}{l}\nKx = src.cols / maxRadius \\\\\\\\\nKy = src.rows / 2\\Pi\n\\end{array}\\f]\n\n**Note**: \n- The function can not operate in-place.\n- To calculate magnitude and angle in degrees #cartToPolar is used internally thus angles are measured from 0 to 360 with accuracy about 0.3 degrees.\n\n@sa cv::logPolar\n@endinternal\n\nPython prototype (for reference only):\n```python3\nlinearPolar(src, center, maxRadius, flags[, dst]) -> dst\n```","ref":"Evision.html#linearPolar/5"},{"type":"function","title":"Evision.log/1","doc":"Calculates the natural logarithm of every array element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src .\n\nThe function cv::log calculates the natural logarithm of every element of the input array:\n\\f[\\texttt{dst} (I) =  \\log (\\texttt{src}(I)) \\f]\nOutput on zero, negative and special (NaN, Inf) values is undefined.\n@sa exp, cartToPolar, polarToCart, phase, pow, sqrt, magnitude\n\nPython prototype (for reference only):\n```python3\nlog(src[, dst]) -> dst\n```","ref":"Evision.html#log/1"},{"type":"function","title":"Evision.log/2","doc":"Calculates the natural logarithm of every array element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src .\n\nThe function cv::log calculates the natural logarithm of every element of the input array:\n\\f[\\texttt{dst} (I) =  \\log (\\texttt{src}(I)) \\f]\nOutput on zero, negative and special (NaN, Inf) values is undefined.\n@sa exp, cartToPolar, polarToCart, phase, pow, sqrt, magnitude\n\nPython prototype (for reference only):\n```python3\nlog(src[, dst]) -> dst\n```","ref":"Evision.html#log/2"},{"type":"function","title":"Evision.logPolar/1","doc":"","ref":"Evision.html#logPolar/1"},{"type":"function","title":"Evision.logPolar/4","doc":"Remaps an image to semilog-polar coordinates space.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image\n\n- **center**: `Point2f`.\n\n  The transformation center; where the output precision is maximal\n\n- **m**: `double`.\n\n  Magnitude scale parameter. It determines the radius of the bounding circle to transform too.\n\n- **flags**: `integer()`.\n\n  A combination of interpolation methods, see #InterpolationFlags\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image. It will have same size and type as src.\n\n@deprecated This function produces same result as cv::warpPolar(src, dst, src.size(), center, maxRadius, flags+WARP_POLAR_LOG);\n@internal\nTransform the source image using the following transformation (See @ref polar_remaps_reference_image \"Polar remaps reference image d)\"):\n\\f[\\begin{array}{l}\ndst( \\rho , \\phi ) = src(x,y) \\\\\\\\\ndst.size() \\leftarrow src.size()\n\\end{array}\\f]\nwhere\n\\f[\\begin{array}{l}\nI = (dx,dy) = (x - center.x,y - center.y) \\\\\\\\\n\\rho = M \\cdot log\\_e(\\texttt{magnitude} (I)) ,\\\\\\\\\n\\phi = Kangle \\cdot \\texttt{angle} (I) \\\\\\\\\n\\end{array}\\f]\nand\n\\f[\\begin{array}{l}\nM = src.cols / log\\_e(maxRadius) \\\\\\\\\nKangle = src.rows / 2\\Pi \\\\\\\\\n\\end{array}\\f]\nThe function emulates the human \"foveal\" vision and can be used for fast scale and\nrotation-invariant template matching, for object tracking and so forth.\n\n**Note**: \n- The function can not operate in-place.\n- To calculate magnitude and angle in degrees #cartToPolar is used internally thus angles are measured from 0 to 360 with accuracy about 0.3 degrees.\n\n@sa cv::linearPolar\n@endinternal\n\nPython prototype (for reference only):\n```python3\nlogPolar(src, center, M, flags[, dst]) -> dst\n```","ref":"Evision.html#logPolar/4"},{"type":"function","title":"Evision.logPolar/5","doc":"Remaps an image to semilog-polar coordinates space.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image\n\n- **center**: `Point2f`.\n\n  The transformation center; where the output precision is maximal\n\n- **m**: `double`.\n\n  Magnitude scale parameter. It determines the radius of the bounding circle to transform too.\n\n- **flags**: `integer()`.\n\n  A combination of interpolation methods, see #InterpolationFlags\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image. It will have same size and type as src.\n\n@deprecated This function produces same result as cv::warpPolar(src, dst, src.size(), center, maxRadius, flags+WARP_POLAR_LOG);\n@internal\nTransform the source image using the following transformation (See @ref polar_remaps_reference_image \"Polar remaps reference image d)\"):\n\\f[\\begin{array}{l}\ndst( \\rho , \\phi ) = src(x,y) \\\\\\\\\ndst.size() \\leftarrow src.size()\n\\end{array}\\f]\nwhere\n\\f[\\begin{array}{l}\nI = (dx,dy) = (x - center.x,y - center.y) \\\\\\\\\n\\rho = M \\cdot log\\_e(\\texttt{magnitude} (I)) ,\\\\\\\\\n\\phi = Kangle \\cdot \\texttt{angle} (I) \\\\\\\\\n\\end{array}\\f]\nand\n\\f[\\begin{array}{l}\nM = src.cols / log\\_e(maxRadius) \\\\\\\\\nKangle = src.rows / 2\\Pi \\\\\\\\\n\\end{array}\\f]\nThe function emulates the human \"foveal\" vision and can be used for fast scale and\nrotation-invariant template matching, for object tracking and so forth.\n\n**Note**: \n- The function can not operate in-place.\n- To calculate magnitude and angle in degrees #cartToPolar is used internally thus angles are measured from 0 to 360 with accuracy about 0.3 degrees.\n\n@sa cv::linearPolar\n@endinternal\n\nPython prototype (for reference only):\n```python3\nlogPolar(src, center, M, flags[, dst]) -> dst\n```","ref":"Evision.html#logPolar/5"},{"type":"function","title":"Evision.lut/1","doc":"","ref":"Evision.html#lut/1"},{"type":"function","title":"Evision.lut/2","doc":"Performs a look-up table transform of an array.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array of 8-bit elements.\n\n- **lut**: `Evision.Mat`.\n\n  look-up table of 256 elements; in case of multi-channel input array, the table should\n  either have a single channel (in this case the same table is used for all channels) or the same\n  number of channels as in the input array.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and number of channels as src, and the same depth as lut.\n\nThe function LUT fills the output array with values from the look-up table. Indices of the entries\nare taken from the input array. That is, the function processes each element of src as follows:\n\\f[\\texttt{dst} (I)  \\leftarrow \\texttt{lut(src(I) + d)}\\f]\nwhere\n\\f[d =  \\fork{0}{if \\(\\texttt{src}\\) has depth \\(\\texttt{CV\\_8U}\\)}{128}{if \\(\\texttt{src}\\) has depth \\(\\texttt{CV\\_8S}\\)}\\f]\n@sa  convertScaleAbs, Mat::convertTo\n\nPython prototype (for reference only):\n```python3\nLUT(src, lut[, dst]) -> dst\n```","ref":"Evision.html#lut/2"},{"type":"function","title":"Evision.lut/3","doc":"Performs a look-up table transform of an array.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array of 8-bit elements.\n\n- **lut**: `Evision.Mat`.\n\n  look-up table of 256 elements; in case of multi-channel input array, the table should\n  either have a single channel (in this case the same table is used for all channels) or the same\n  number of channels as in the input array.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and number of channels as src, and the same depth as lut.\n\nThe function LUT fills the output array with values from the look-up table. Indices of the entries\nare taken from the input array. That is, the function processes each element of src as follows:\n\\f[\\texttt{dst} (I)  \\leftarrow \\texttt{lut(src(I) + d)}\\f]\nwhere\n\\f[d =  \\fork{0}{if \\(\\texttt{src}\\) has depth \\(\\texttt{CV\\_8U}\\)}{128}{if \\(\\texttt{src}\\) has depth \\(\\texttt{CV\\_8S}\\)}\\f]\n@sa  convertScaleAbs, Mat::convertTo\n\nPython prototype (for reference only):\n```python3\nLUT(src, lut[, dst]) -> dst\n```","ref":"Evision.html#lut/3"},{"type":"function","title":"Evision.magnitude/1","doc":"","ref":"Evision.html#magnitude/1"},{"type":"function","title":"Evision.magnitude/2","doc":"Calculates the magnitude of 2D vectors.\n\n##### Positional Arguments\n- **x**: `Evision.Mat`.\n\n  floating-point array of x-coordinates of the vectors.\n\n- **y**: `Evision.Mat`.\n\n  floating-point array of y-coordinates of the vectors; it must\n  have the same size as x.\n\n##### Return\n- **magnitude**: `Evision.Mat.t()`.\n\n  output array of the same size and type as x.\n\nThe function cv::magnitude calculates the magnitude of 2D vectors formed\nfrom the corresponding elements of x and y arrays:\n\\f[\\texttt{dst} (I) =  \\sqrt{\\texttt{x}(I)^2 + \\texttt{y}(I)^2}\\f]\n@sa cartToPolar, polarToCart, phase, sqrt\n\nPython prototype (for reference only):\n```python3\nmagnitude(x, y[, magnitude]) -> magnitude\n```","ref":"Evision.html#magnitude/2"},{"type":"function","title":"Evision.magnitude/3","doc":"Calculates the magnitude of 2D vectors.\n\n##### Positional Arguments\n- **x**: `Evision.Mat`.\n\n  floating-point array of x-coordinates of the vectors.\n\n- **y**: `Evision.Mat`.\n\n  floating-point array of y-coordinates of the vectors; it must\n  have the same size as x.\n\n##### Return\n- **magnitude**: `Evision.Mat.t()`.\n\n  output array of the same size and type as x.\n\nThe function cv::magnitude calculates the magnitude of 2D vectors formed\nfrom the corresponding elements of x and y arrays:\n\\f[\\texttt{dst} (I) =  \\sqrt{\\texttt{x}(I)^2 + \\texttt{y}(I)^2}\\f]\n@sa cartToPolar, polarToCart, phase, sqrt\n\nPython prototype (for reference only):\n```python3\nmagnitude(x, y[, magnitude]) -> magnitude\n```","ref":"Evision.html#magnitude/3"},{"type":"function","title":"Evision.mahalanobis/1","doc":"","ref":"Evision.html#mahalanobis/1"},{"type":"function","title":"Evision.mahalanobis/3","doc":"Calculates the Mahalanobis distance between two vectors.\n\n##### Positional Arguments\n- **v1**: `Evision.Mat`.\n\n  first 1D input vector.\n\n- **v2**: `Evision.Mat`.\n\n  second 1D input vector.\n\n- **icovar**: `Evision.Mat`.\n\n  inverse covariance matrix.\n\n##### Return\n- **retval**: `double`\n\nThe function cv::Mahalanobis calculates and returns the weighted distance between two vectors:\n\\f[d( \\texttt{vec1} , \\texttt{vec2} )= \\sqrt{\\sum\\_{i,j}{\\texttt{icovar(i,j)}\\cdot(\\texttt{vec1}(I)-\\texttt{vec2}(I))\\cdot(\\texttt{vec1(j)}-\\texttt{vec2(j)})} }\\f]\nThe covariance matrix may be calculated using the #calcCovarMatrix function and then inverted using\nthe invert function (preferably using the #DECOMP_SVD method, as the most accurate).\n\nPython prototype (for reference only):\n```python3\nMahalanobis(v1, v2, icovar) -> retval\n```","ref":"Evision.html#mahalanobis/3"},{"type":"function","title":"Evision.matchShapes/1","doc":"","ref":"Evision.html#matchShapes/1"},{"type":"function","title":"Evision.matchShapes/4","doc":"Compares two shapes.\n\n##### Positional Arguments\n- **contour1**: `Evision.Mat`.\n\n  First contour or grayscale image.\n\n- **contour2**: `Evision.Mat`.\n\n  Second contour or grayscale image.\n\n- **method**: `integer()`.\n\n  Comparison method, see #ShapeMatchModes\n\n- **parameter**: `double`.\n\n  Method-specific parameter (not supported now).\n\n##### Return\n- **retval**: `double`\n\nThe function compares two shapes. All three implemented methods use the Hu invariants (see #HuMoments)\n\nPython prototype (for reference only):\n```python3\nmatchShapes(contour1, contour2, method, parameter) -> retval\n```","ref":"Evision.html#matchShapes/4"},{"type":"function","title":"Evision.matchTemplate/1","doc":"","ref":"Evision.html#matchTemplate/1"},{"type":"function","title":"Evision.matchTemplate/3","doc":"Compares a template against overlapped image regions.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Image where the search is running. It must be 8-bit or 32-bit floating-point.\n\n- **templ**: `Evision.Mat`.\n\n  Searched template. It must be not greater than the source image and have the same\n  data type.\n\n- **method**: `integer()`.\n\n  Parameter specifying the comparison method, see #TemplateMatchModes\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional mask. It must have the same size as templ. It must either have the same number\n  of channels as template or only one channel, which is then used for all template and\n  image channels. If the data type is #CV_8U, the mask is interpreted as a binary mask,\n  meaning only elements where mask is nonzero are used and are kept unchanged independent\n  of the actual mask value (weight equals 1). For data tpye #CV_32F, the mask values are\n  used as weights. The exact formulas are documented in #TemplateMatchModes.\n\n##### Return\n- **result**: `Evision.Mat.t()`.\n\n  Map of comparison results. It must be single-channel 32-bit floating-point. If image\n  is \\f$W \\times H\\f$ and templ is \\f$w \\times h\\f$ , then result is \\f$(W-w+1) \\times (H-h+1)\\f$ .\n\nThe function slides through image , compares the overlapped patches of size \\f$w \\times h\\f$ against\ntempl using the specified method and stores the comparison results in result . #TemplateMatchModes\ndescribes the formulae for the available comparison methods ( \\f$I\\f$ denotes image, \\f$T\\f$\ntemplate, \\f$R\\f$ result, \\f$M\\f$ the optional mask ). The summation is done over template and/or\nthe image patch: \\f$x' = 0...w-1, y' = 0...h-1\\f$\nAfter the function finishes the comparison, the best matches can be found as global minimums (when\n#TM_SQDIFF was used) or maximums (when #TM_CCORR or #TM_CCOEFF was used) using the\n#minMaxLoc function. In case of a color image, template summation in the numerator and each sum in\nthe denominator is done over all of the channels and separate mean values are used for each channel.\nThat is, the function can take a color template and a color image. The result will still be a\nsingle-channel image, which is easier to analyze.\n\nPython prototype (for reference only):\n```python3\nmatchTemplate(image, templ, method[, result[, mask]]) -> result\n```","ref":"Evision.html#matchTemplate/3"},{"type":"function","title":"Evision.matchTemplate/4","doc":"Compares a template against overlapped image regions.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Image where the search is running. It must be 8-bit or 32-bit floating-point.\n\n- **templ**: `Evision.Mat`.\n\n  Searched template. It must be not greater than the source image and have the same\n  data type.\n\n- **method**: `integer()`.\n\n  Parameter specifying the comparison method, see #TemplateMatchModes\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional mask. It must have the same size as templ. It must either have the same number\n  of channels as template or only one channel, which is then used for all template and\n  image channels. If the data type is #CV_8U, the mask is interpreted as a binary mask,\n  meaning only elements where mask is nonzero are used and are kept unchanged independent\n  of the actual mask value (weight equals 1). For data tpye #CV_32F, the mask values are\n  used as weights. The exact formulas are documented in #TemplateMatchModes.\n\n##### Return\n- **result**: `Evision.Mat.t()`.\n\n  Map of comparison results. It must be single-channel 32-bit floating-point. If image\n  is \\f$W \\times H\\f$ and templ is \\f$w \\times h\\f$ , then result is \\f$(W-w+1) \\times (H-h+1)\\f$ .\n\nThe function slides through image , compares the overlapped patches of size \\f$w \\times h\\f$ against\ntempl using the specified method and stores the comparison results in result . #TemplateMatchModes\ndescribes the formulae for the available comparison methods ( \\f$I\\f$ denotes image, \\f$T\\f$\ntemplate, \\f$R\\f$ result, \\f$M\\f$ the optional mask ). The summation is done over template and/or\nthe image patch: \\f$x' = 0...w-1, y' = 0...h-1\\f$\nAfter the function finishes the comparison, the best matches can be found as global minimums (when\n#TM_SQDIFF was used) or maximums (when #TM_CCORR or #TM_CCOEFF was used) using the\n#minMaxLoc function. In case of a color image, template summation in the numerator and each sum in\nthe denominator is done over all of the channels and separate mean values are used for each channel.\nThat is, the function can take a color template and a color image. The result will still be a\nsingle-channel image, which is easier to analyze.\n\nPython prototype (for reference only):\n```python3\nmatchTemplate(image, templ, method[, result[, mask]]) -> result\n```","ref":"Evision.html#matchTemplate/4"},{"type":"function","title":"Evision.matMulDeriv/1","doc":"","ref":"Evision.html#matMulDeriv/1"},{"type":"function","title":"Evision.matMulDeriv/2","doc":"Computes partial derivatives of the matrix product for each multiplied matrix.\n\n##### Positional Arguments\n- **a**: `Evision.Mat`.\n\n  First multiplied matrix.\n\n- **b**: `Evision.Mat`.\n\n  Second multiplied matrix.\n\n##### Return\n- **dABdA**: `Evision.Mat.t()`.\n\n  First output derivative matrix d(A\\*B)/dA of size\n  \\f$\\texttt{A.rows*B.cols} \\times {A.rows*A.cols}\\f$ .\n\n- **dABdB**: `Evision.Mat.t()`.\n\n  Second output derivative matrix d(A\\*B)/dB of size\n  \\f$\\texttt{A.rows*B.cols} \\times {B.rows*B.cols}\\f$ .\n\nThe function computes partial derivatives of the elements of the matrix product \\f$A\\*B\\f$ with regard to\nthe elements of each of the two input matrices. The function is used to compute the Jacobian\nmatrices in #stereoCalibrate but can also be used in any other similar optimization function.\n\nPython prototype (for reference only):\n```python3\nmatMulDeriv(A, B[, dABdA[, dABdB]]) -> dABdA, dABdB\n```","ref":"Evision.html#matMulDeriv/2"},{"type":"function","title":"Evision.matMulDeriv/3","doc":"Computes partial derivatives of the matrix product for each multiplied matrix.\n\n##### Positional Arguments\n- **a**: `Evision.Mat`.\n\n  First multiplied matrix.\n\n- **b**: `Evision.Mat`.\n\n  Second multiplied matrix.\n\n##### Return\n- **dABdA**: `Evision.Mat.t()`.\n\n  First output derivative matrix d(A\\*B)/dA of size\n  \\f$\\texttt{A.rows*B.cols} \\times {A.rows*A.cols}\\f$ .\n\n- **dABdB**: `Evision.Mat.t()`.\n\n  Second output derivative matrix d(A\\*B)/dB of size\n  \\f$\\texttt{A.rows*B.cols} \\times {B.rows*B.cols}\\f$ .\n\nThe function computes partial derivatives of the elements of the matrix product \\f$A\\*B\\f$ with regard to\nthe elements of each of the two input matrices. The function is used to compute the Jacobian\nmatrices in #stereoCalibrate but can also be used in any other similar optimization function.\n\nPython prototype (for reference only):\n```python3\nmatMulDeriv(A, B[, dABdA[, dABdB]]) -> dABdA, dABdB\n```","ref":"Evision.html#matMulDeriv/3"},{"type":"function","title":"Evision.max/1","doc":"","ref":"Evision.html#max/1"},{"type":"function","title":"Evision.max/2","doc":"Calculates per-element maximum of two arrays or an array and a scalar.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array.\n\n- **src2**: `Evision.Mat`.\n\n  second input array of the same size and type as src1 .\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src1.\n\nThe function cv::max calculates the per-element maximum of two arrays:\n\\f[\\texttt{dst} (I)= \\max ( \\texttt{src1} (I), \\texttt{src2} (I))\\f]\nor array and a scalar:\n\\f[\\texttt{dst} (I)= \\max ( \\texttt{src1} (I), \\texttt{value} )\\f]\n@sa  min, compare, inRange, minMaxLoc, @ref MatrixExpressions\n\nPython prototype (for reference only):\n```python3\nmax(src1, src2[, dst]) -> dst\n```","ref":"Evision.html#max/2"},{"type":"function","title":"Evision.max/3","doc":"Calculates per-element maximum of two arrays or an array and a scalar.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array.\n\n- **src2**: `Evision.Mat`.\n\n  second input array of the same size and type as src1 .\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src1.\n\nThe function cv::max calculates the per-element maximum of two arrays:\n\\f[\\texttt{dst} (I)= \\max ( \\texttt{src1} (I), \\texttt{src2} (I))\\f]\nor array and a scalar:\n\\f[\\texttt{dst} (I)= \\max ( \\texttt{src1} (I), \\texttt{value} )\\f]\n@sa  min, compare, inRange, minMaxLoc, @ref MatrixExpressions\n\nPython prototype (for reference only):\n```python3\nmax(src1, src2[, dst]) -> dst\n```","ref":"Evision.html#max/3"},{"type":"function","title":"Evision.mean/1","doc":"Calculates an average (mean) of array elements.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array that should have from 1 to 4 channels so that the result can be stored in\n  Scalar_ .\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  optional operation mask.\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n\nThe function cv::mean calculates the mean value M of array elements,\nindependently for each channel, and return it:\n\\f[\\begin{array}{l} N =  \\sum \\_{I: \\; \\texttt{mask} (I) \\ne 0} 1 \\\\\\\\ M\\_c =  \\left ( \\sum \\_{I: \\; \\texttt{mask} (I) \\ne 0}{ \\texttt{mtx} (I)\\_c} \\right )/N \\end{array}\\f]\nWhen all the mask elements are 0's, the function returns Scalar::all(0)\n@sa  countNonZero, meanStdDev, norm, minMaxLoc\n\nPython prototype (for reference only):\n```python3\nmean(src[, mask]) -> retval\n```","ref":"Evision.html#mean/1"},{"type":"function","title":"Evision.mean/2","doc":"Calculates an average (mean) of array elements.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array that should have from 1 to 4 channels so that the result can be stored in\n  Scalar_ .\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  optional operation mask.\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n\nThe function cv::mean calculates the mean value M of array elements,\nindependently for each channel, and return it:\n\\f[\\begin{array}{l} N =  \\sum \\_{I: \\; \\texttt{mask} (I) \\ne 0} 1 \\\\\\\\ M\\_c =  \\left ( \\sum \\_{I: \\; \\texttt{mask} (I) \\ne 0}{ \\texttt{mtx} (I)\\_c} \\right )/N \\end{array}\\f]\nWhen all the mask elements are 0's, the function returns Scalar::all(0)\n@sa  countNonZero, meanStdDev, norm, minMaxLoc\n\nPython prototype (for reference only):\n```python3\nmean(src[, mask]) -> retval\n```","ref":"Evision.html#mean/2"},{"type":"function","title":"Evision.meanShift/1","doc":"","ref":"Evision.html#meanShift/1"},{"type":"function","title":"Evision.meanShift/3","doc":"Finds an object on a back projection image.\n\n##### Positional Arguments\n- **probImage**: `Evision.Mat`.\n\n  Back projection of the object histogram. See calcBackProject for details.\n\n- **criteria**: `TermCriteria`.\n\n  Stop criteria for the iterative search algorithm.\n  returns\n  :   Number of iterations CAMSHIFT took to converge.\n  The function implements the iterative object search algorithm. It takes the input back projection of\n  an object and the initial position. The mass center in window of the back projection image is\n  computed and the search window center shifts to the mass center. The procedure is repeated until the\n  specified number of iterations criteria.maxCount is done or until the window center shifts by less\n  than criteria.epsilon. The algorithm is used inside CamShift and, unlike CamShift , the search\n  window size or orientation do not change during the search. You can simply pass the output of\n  calcBackProject to this function. But better results can be obtained if you pre-filter the back\n  projection and remove the noise. For example, you can do this by retrieving connected components\n  with findContours , throwing away contours with small area ( contourArea ), and rendering the\n  remaining contours with drawContours.\n\n##### Return\n- **retval**: `integer()`\n- **window**: `Rect`.\n\n  Initial search window.\n\nPython prototype (for reference only):\n```python3\nmeanShift(probImage, window, criteria) -> retval, window\n```","ref":"Evision.html#meanShift/3"},{"type":"function","title":"Evision.meanStdDev/1","doc":"meanStdDev\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array that should have from 1 to 4 channels so that the results can be stored in\n  Scalar_ 's.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  optional operation mask.\n\n##### Return\n- **mean**: `Evision.Mat.t()`.\n\n  output parameter: calculated mean value.\n\n- **stddev**: `Evision.Mat.t()`.\n\n  output parameter: calculated standard deviation.\n\nCalculates a mean and standard deviation of array elements.\nThe function cv::meanStdDev calculates the mean and the standard deviation M\nof array elements independently for each channel and returns it via the\noutput parameters:\n\\f[\\begin{array}{l} N =  \\sum \\_{I, \\texttt{mask} (I)  \\ne 0} 1 \\\\\\\\ \\texttt{mean} \\_c =  \\frac{\\sum\\_{ I: \\; \\texttt{mask}(I) \\ne 0} \\texttt{src} (I)\\_c}{N} \\\\\\\\ \\texttt{stddev} \\_c =  \\sqrt{\\frac{\\sum\\_{ I: \\; \\texttt{mask}(I) \\ne 0} \\left ( \\texttt{src} (I)\\_c -  \\texttt{mean} \\_c \\right )^2}{N}} \\end{array}\\f]\nWhen all the mask elements are 0's, the function returns\nmean=stddev=Scalar::all(0).\n**Note**: The calculated standard deviation is only the diagonal of the\ncomplete normalized covariance matrix. If the full matrix is needed, you\ncan reshape the multi-channel array M x N to the single-channel array\nM\\*N x mtx.channels() (only possible when the matrix is continuous) and\nthen pass the matrix to calcCovarMatrix .\n@sa  countNonZero, mean, norm, minMaxLoc, calcCovarMatrix\n\nPython prototype (for reference only):\n```python3\nmeanStdDev(src[, mean[, stddev[, mask]]]) -> mean, stddev\n```","ref":"Evision.html#meanStdDev/1"},{"type":"function","title":"Evision.meanStdDev/2","doc":"meanStdDev\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array that should have from 1 to 4 channels so that the results can be stored in\n  Scalar_ 's.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  optional operation mask.\n\n##### Return\n- **mean**: `Evision.Mat.t()`.\n\n  output parameter: calculated mean value.\n\n- **stddev**: `Evision.Mat.t()`.\n\n  output parameter: calculated standard deviation.\n\nCalculates a mean and standard deviation of array elements.\nThe function cv::meanStdDev calculates the mean and the standard deviation M\nof array elements independently for each channel and returns it via the\noutput parameters:\n\\f[\\begin{array}{l} N =  \\sum \\_{I, \\texttt{mask} (I)  \\ne 0} 1 \\\\\\\\ \\texttt{mean} \\_c =  \\frac{\\sum\\_{ I: \\; \\texttt{mask}(I) \\ne 0} \\texttt{src} (I)\\_c}{N} \\\\\\\\ \\texttt{stddev} \\_c =  \\sqrt{\\frac{\\sum\\_{ I: \\; \\texttt{mask}(I) \\ne 0} \\left ( \\texttt{src} (I)\\_c -  \\texttt{mean} \\_c \\right )^2}{N}} \\end{array}\\f]\nWhen all the mask elements are 0's, the function returns\nmean=stddev=Scalar::all(0).\n**Note**: The calculated standard deviation is only the diagonal of the\ncomplete normalized covariance matrix. If the full matrix is needed, you\ncan reshape the multi-channel array M x N to the single-channel array\nM\\*N x mtx.channels() (only possible when the matrix is continuous) and\nthen pass the matrix to calcCovarMatrix .\n@sa  countNonZero, mean, norm, minMaxLoc, calcCovarMatrix\n\nPython prototype (for reference only):\n```python3\nmeanStdDev(src[, mean[, stddev[, mask]]]) -> mean, stddev\n```","ref":"Evision.html#meanStdDev/2"},{"type":"function","title":"Evision.medianBlur/1","doc":"","ref":"Evision.html#medianBlur/1"},{"type":"function","title":"Evision.medianBlur/2","doc":"Blurs an image using the median filter.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input 1-, 3-, or 4-channel image; when ksize is 3 or 5, the image depth should be\n  CV_8U, CV_16U, or CV_32F, for larger aperture sizes, it can only be CV_8U.\n\n- **ksize**: `integer()`.\n\n  aperture linear size; it must be odd and greater than 1, for example: 3, 5, 7 ...\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  destination array of the same size and type as src.\n\nThe function smoothes an image using the median filter with the \\f$\\texttt{ksize} \\times\n\\texttt{ksize}\\f$ aperture. Each channel of a multi-channel image is processed independently.\nIn-place operation is supported.\n**Note**: The median filter uses #BORDER_REPLICATE internally to cope with border pixels, see #BorderTypes\n@sa  bilateralFilter, blur, boxFilter, GaussianBlur\n\nPython prototype (for reference only):\n```python3\nmedianBlur(src, ksize[, dst]) -> dst\n```","ref":"Evision.html#medianBlur/2"},{"type":"function","title":"Evision.medianBlur/3","doc":"Blurs an image using the median filter.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input 1-, 3-, or 4-channel image; when ksize is 3 or 5, the image depth should be\n  CV_8U, CV_16U, or CV_32F, for larger aperture sizes, it can only be CV_8U.\n\n- **ksize**: `integer()`.\n\n  aperture linear size; it must be odd and greater than 1, for example: 3, 5, 7 ...\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  destination array of the same size and type as src.\n\nThe function smoothes an image using the median filter with the \\f$\\texttt{ksize} \\times\n\\texttt{ksize}\\f$ aperture. Each channel of a multi-channel image is processed independently.\nIn-place operation is supported.\n**Note**: The median filter uses #BORDER_REPLICATE internally to cope with border pixels, see #BorderTypes\n@sa  bilateralFilter, blur, boxFilter, GaussianBlur\n\nPython prototype (for reference only):\n```python3\nmedianBlur(src, ksize[, dst]) -> dst\n```","ref":"Evision.html#medianBlur/3"},{"type":"function","title":"Evision.merge/1","doc":"merge\n\n##### Positional Arguments\n- **mv**: `[Evision.Mat]`.\n\n  input vector of matrices to be merged; all the matrices in mv must have the same\n  size and the same depth.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and the same depth as mv[0]; The number of channels will\n  be the total number of channels in the matrix array.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmerge(mv[, dst]) -> dst\n```","ref":"Evision.html#merge/1"},{"type":"function","title":"Evision.merge/2","doc":"merge\n\n##### Positional Arguments\n- **mv**: `[Evision.Mat]`.\n\n  input vector of matrices to be merged; all the matrices in mv must have the same\n  size and the same depth.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and the same depth as mv[0]; The number of channels will\n  be the total number of channels in the matrix array.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmerge(mv[, dst]) -> dst\n```","ref":"Evision.html#merge/2"},{"type":"function","title":"Evision.min/1","doc":"","ref":"Evision.html#min/1"},{"type":"function","title":"Evision.min/2","doc":"Calculates per-element minimum of two arrays or an array and a scalar.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array.\n\n- **src2**: `Evision.Mat`.\n\n  second input array of the same size and type as src1.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src1.\n\nThe function cv::min calculates the per-element minimum of two arrays:\n\\f[\\texttt{dst} (I)= \\min ( \\texttt{src1} (I), \\texttt{src2} (I))\\f]\nor array and a scalar:\n\\f[\\texttt{dst} (I)= \\min ( \\texttt{src1} (I), \\texttt{value} )\\f]\n@sa max, compare, inRange, minMaxLoc\n\nPython prototype (for reference only):\n```python3\nmin(src1, src2[, dst]) -> dst\n```","ref":"Evision.html#min/2"},{"type":"function","title":"Evision.min/3","doc":"Calculates per-element minimum of two arrays or an array and a scalar.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array.\n\n- **src2**: `Evision.Mat`.\n\n  second input array of the same size and type as src1.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src1.\n\nThe function cv::min calculates the per-element minimum of two arrays:\n\\f[\\texttt{dst} (I)= \\min ( \\texttt{src1} (I), \\texttt{src2} (I))\\f]\nor array and a scalar:\n\\f[\\texttt{dst} (I)= \\min ( \\texttt{src1} (I), \\texttt{value} )\\f]\n@sa max, compare, inRange, minMaxLoc\n\nPython prototype (for reference only):\n```python3\nmin(src1, src2[, dst]) -> dst\n```","ref":"Evision.html#min/3"},{"type":"function","title":"Evision.minAreaRect/1","doc":"Finds a rotated rectangle of the minimum area enclosing the input 2D point set.\n\n##### Positional Arguments\n- **points**: `Evision.Mat`.\n\n  Input vector of 2D points, stored in std::vector\\<\\> or Mat\n\n##### Return\n- **retval**: `{centre={x, y}, size={s1, s2}, angle}`\n\nThe function calculates and returns the minimum-area bounding rectangle (possibly rotated) for a\nspecified point set. Developer should keep in mind that the returned RotatedRect can contain negative\nindices when data is close to the containing Mat element boundary.\n\nPython prototype (for reference only):\n```python3\nminAreaRect(points) -> retval\n```","ref":"Evision.html#minAreaRect/1"},{"type":"function","title":"Evision.minEnclosingCircle/1","doc":"Finds a circle of the minimum area enclosing a 2D point set.\n\n##### Positional Arguments\n- **points**: `Evision.Mat`.\n\n  Input vector of 2D points, stored in std::vector\\<\\> or Mat\n\n##### Return\n- **center**: `Point2f`.\n\n  Output center of the circle.\n\n- **radius**: `float`.\n\n  Output radius of the circle.\n\nThe function finds the minimal enclosing circle of a 2D point set using an iterative algorithm.\n\nPython prototype (for reference only):\n```python3\nminEnclosingCircle(points) -> center, radius\n```","ref":"Evision.html#minEnclosingCircle/1"},{"type":"function","title":"Evision.minEnclosingTriangle/1","doc":"Finds a triangle of minimum area enclosing a 2D point set and returns its area.\n\n##### Positional Arguments\n- **points**: `Evision.Mat`.\n\n  Input vector of 2D points with depth CV_32S or CV_32F, stored in std::vector\\<\\> or Mat\n\n##### Return\n- **retval**: `double`\n- **triangle**: `Evision.Mat.t()`.\n\n  Output vector of three 2D points defining the vertices of the triangle. The depth\n  of the OutputArray must be CV_32F.\n\nThe function finds a triangle of minimum area enclosing the given set of 2D points and returns its\narea. The output for a given 2D point set is shown in the image below. 2D points are depicted in\nred* and the enclosing triangle in *yellow*.\n![Sample output of the minimum enclosing triangle function](pics/minenclosingtriangle.png)\nThe implementation of the algorithm is based on O'Rourke's @cite ORourke86 and Klee and Laskowski's\n@cite KleeLaskowski85 papers. O'Rourke provides a \\f$\\theta(n)\\f$ algorithm for finding the minimal\nenclosing triangle of a 2D convex polygon with n vertices. Since the #minEnclosingTriangle function\ntakes a 2D point set as input an additional preprocessing step of computing the convex hull of the\n2D point set is required. The complexity of the #convexHull function is \\f$O(n log(n))\\f$ which is higher\nthan \\f$\\theta(n)\\f$. Thus the overall complexity of the function is \\f$O(n log(n))\\f$.\n\nPython prototype (for reference only):\n```python3\nminEnclosingTriangle(points[, triangle]) -> retval, triangle\n```","ref":"Evision.html#minEnclosingTriangle/1"},{"type":"function","title":"Evision.minEnclosingTriangle/2","doc":"Finds a triangle of minimum area enclosing a 2D point set and returns its area.\n\n##### Positional Arguments\n- **points**: `Evision.Mat`.\n\n  Input vector of 2D points with depth CV_32S or CV_32F, stored in std::vector\\<\\> or Mat\n\n##### Return\n- **retval**: `double`\n- **triangle**: `Evision.Mat.t()`.\n\n  Output vector of three 2D points defining the vertices of the triangle. The depth\n  of the OutputArray must be CV_32F.\n\nThe function finds a triangle of minimum area enclosing the given set of 2D points and returns its\narea. The output for a given 2D point set is shown in the image below. 2D points are depicted in\nred* and the enclosing triangle in *yellow*.\n![Sample output of the minimum enclosing triangle function](pics/minenclosingtriangle.png)\nThe implementation of the algorithm is based on O'Rourke's @cite ORourke86 and Klee and Laskowski's\n@cite KleeLaskowski85 papers. O'Rourke provides a \\f$\\theta(n)\\f$ algorithm for finding the minimal\nenclosing triangle of a 2D convex polygon with n vertices. Since the #minEnclosingTriangle function\ntakes a 2D point set as input an additional preprocessing step of computing the convex hull of the\n2D point set is required. The complexity of the #convexHull function is \\f$O(n log(n))\\f$ which is higher\nthan \\f$\\theta(n)\\f$. Thus the overall complexity of the function is \\f$O(n log(n))\\f$.\n\nPython prototype (for reference only):\n```python3\nminEnclosingTriangle(points[, triangle]) -> retval, triangle\n```","ref":"Evision.html#minEnclosingTriangle/2"},{"type":"function","title":"Evision.minMaxLoc/1","doc":"Finds the global minimum and maximum in an array.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input single-channel array.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  optional mask used to select a sub-array.\n\n##### Return\n- **minVal**: `double*`.\n\n  pointer to the returned minimum value; NULL is used if not required.\n\n- **maxVal**: `double*`.\n\n  pointer to the returned maximum value; NULL is used if not required.\n\n- **minLoc**: `Point*`.\n\n  pointer to the returned minimum location (in 2D case); NULL is used if not required.\n\n- **maxLoc**: `Point*`.\n\n  pointer to the returned maximum location (in 2D case); NULL is used if not required.\n\nThe function cv::minMaxLoc finds the minimum and maximum element values and their positions. The\nextremums are searched across the whole array or, if mask is not an empty array, in the specified\narray region.\nThe function do not work with multi-channel arrays. If you need to find minimum or maximum\nelements across all the channels, use Mat::reshape first to reinterpret the array as\nsingle-channel. Or you may extract the particular channel using either extractImageCOI, or\nmixChannels, or split.\n@sa max, min, reduceArgMin, reduceArgMax, compare, inRange, extractImageCOI, mixChannels, split, Mat::reshape\n\nPython prototype (for reference only):\n```python3\nminMaxLoc(src[, mask]) -> minVal, maxVal, minLoc, maxLoc\n```","ref":"Evision.html#minMaxLoc/1"},{"type":"function","title":"Evision.minMaxLoc/2","doc":"Finds the global minimum and maximum in an array.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input single-channel array.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  optional mask used to select a sub-array.\n\n##### Return\n- **minVal**: `double*`.\n\n  pointer to the returned minimum value; NULL is used if not required.\n\n- **maxVal**: `double*`.\n\n  pointer to the returned maximum value; NULL is used if not required.\n\n- **minLoc**: `Point*`.\n\n  pointer to the returned minimum location (in 2D case); NULL is used if not required.\n\n- **maxLoc**: `Point*`.\n\n  pointer to the returned maximum location (in 2D case); NULL is used if not required.\n\nThe function cv::minMaxLoc finds the minimum and maximum element values and their positions. The\nextremums are searched across the whole array or, if mask is not an empty array, in the specified\narray region.\nThe function do not work with multi-channel arrays. If you need to find minimum or maximum\nelements across all the channels, use Mat::reshape first to reinterpret the array as\nsingle-channel. Or you may extract the particular channel using either extractImageCOI, or\nmixChannels, or split.\n@sa max, min, reduceArgMin, reduceArgMax, compare, inRange, extractImageCOI, mixChannels, split, Mat::reshape\n\nPython prototype (for reference only):\n```python3\nminMaxLoc(src[, mask]) -> minVal, maxVal, minLoc, maxLoc\n```","ref":"Evision.html#minMaxLoc/2"},{"type":"function","title":"Evision.mixChannels/1","doc":"","ref":"Evision.html#mixChannels/1"},{"type":"function","title":"Evision.mixChannels/3","doc":"mixChannels\n\n##### Positional Arguments\n- **src**: `[Evision.Mat]`.\n\n  input array or vector of matrices; all of the matrices must have the same size and the\n  same depth.\n\n- **fromTo**: `[integer()]`.\n\n  array of index pairs specifying which channels are copied and where; fromTo[k\\*2] is\n  a 0-based index of the input channel in src, fromTo[k\\*2+1] is an index of the output channel in\n  dst; the continuous channel numbering is used: the first input image channels are indexed from 0 to\n  src[0].channels()-1, the second input image channels are indexed from src[0].channels() to\n  src[0].channels() + src[1].channels()-1, and so on, the same scheme is used for the output image\n  channels; as a special case, when fromTo[k\\*2] is negative, the corresponding output channel is\n  filled with zero .\n\n##### Return\n- **dst**: `[Evision.Mat]`.\n\n  output array or vector of matrices; all the matrices **must be allocated**; their size and\n  depth must be the same as in src[0].\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmixChannels(src, dst, fromTo) -> dst\n```","ref":"Evision.html#mixChannels/3"},{"type":"function","title":"Evision.moments/1","doc":"Calculates all of the moments up to the third order of a polygon or rasterized shape.\n\n##### Positional Arguments\n- **array**: `Evision.Mat`.\n\n  Single chanel raster image (CV_8U, CV_16U, CV_16S, CV_32F, CV_64F) or an array (\n  \\f$1 \\times N\\f$ or \\f$N \\times 1\\f$ ) of 2D points (Point or Point2f).\n\n##### Keyword Arguments\n- **binaryImage**: `bool`.\n\n  If it is true, all non-zero image pixels are treated as 1's. The parameter is\n  used for images only.\n\n##### Return\n- **retval**: `Moments`\n\nThe function computes moments, up to the 3rd order, of a vector shape or a rasterized shape. The\nresults are returned in the structure cv::Moments.\n@returns moments.\n**Note**: Only applicable to contour moments calculations from Python bindings: Note that the numpy\ntype for the input array should be either np.int32 or np.float32.\n@sa  contourArea, arcLength\n\nPython prototype (for reference only):\n```python3\nmoments(array[, binaryImage]) -> retval\n```","ref":"Evision.html#moments/1"},{"type":"function","title":"Evision.moments/2","doc":"Calculates all of the moments up to the third order of a polygon or rasterized shape.\n\n##### Positional Arguments\n- **array**: `Evision.Mat`.\n\n  Single chanel raster image (CV_8U, CV_16U, CV_16S, CV_32F, CV_64F) or an array (\n  \\f$1 \\times N\\f$ or \\f$N \\times 1\\f$ ) of 2D points (Point or Point2f).\n\n##### Keyword Arguments\n- **binaryImage**: `bool`.\n\n  If it is true, all non-zero image pixels are treated as 1's. The parameter is\n  used for images only.\n\n##### Return\n- **retval**: `Moments`\n\nThe function computes moments, up to the 3rd order, of a vector shape or a rasterized shape. The\nresults are returned in the structure cv::Moments.\n@returns moments.\n**Note**: Only applicable to contour moments calculations from Python bindings: Note that the numpy\ntype for the input array should be either np.int32 or np.float32.\n@sa  contourArea, arcLength\n\nPython prototype (for reference only):\n```python3\nmoments(array[, binaryImage]) -> retval\n```","ref":"Evision.html#moments/2"},{"type":"function","title":"Evision.morphologyEx/1","doc":"","ref":"Evision.html#morphologyEx/1"},{"type":"function","title":"Evision.morphologyEx/3","doc":"Performs advanced morphological transformations.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. The number of channels can be arbitrary. The depth should be one of\n  CV_8U, CV_16U, CV_16S, CV_32F or CV_64F.\n\n- **op**: `integer()`.\n\n  Type of a morphological operation, see #MorphTypes\n\n- **kernel**: `Evision.Mat`.\n\n  Structuring element. It can be created using #getStructuringElement.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor position with the kernel. Negative values mean that the anchor is at the\n  kernel center.\n\n- **iterations**: `integer()`.\n\n  Number of times erosion and dilation are applied.\n\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method, see #BorderTypes. #BORDER_WRAP is not supported.\n\n- **borderValue**: `Evision.scalar()`.\n\n  Border value in case of a constant border. The default value has a special\n  meaning.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and type as source image.\n\nThe function cv::morphologyEx can perform advanced morphological transformations using an erosion and dilation as\nbasic operations.\nAny of the operations can be done in-place. In case of multi-channel images, each channel is\nprocessed independently.\n@sa  dilate, erode, getStructuringElement\n**Note**: The number of iterations is the number of times erosion or dilatation operation will be applied.\nFor instance, an opening operation (#MORPH_OPEN) with two iterations is equivalent to apply\nsuccessively: erode -> erode -> dilate -> dilate (and not erode -> dilate -> erode -> dilate).\n\nPython prototype (for reference only):\n```python3\nmorphologyEx(src, op, kernel[, dst[, anchor[, iterations[, borderType[, borderValue]]]]]) -> dst\n```","ref":"Evision.html#morphologyEx/3"},{"type":"function","title":"Evision.morphologyEx/4","doc":"Performs advanced morphological transformations.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. The number of channels can be arbitrary. The depth should be one of\n  CV_8U, CV_16U, CV_16S, CV_32F or CV_64F.\n\n- **op**: `integer()`.\n\n  Type of a morphological operation, see #MorphTypes\n\n- **kernel**: `Evision.Mat`.\n\n  Structuring element. It can be created using #getStructuringElement.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor position with the kernel. Negative values mean that the anchor is at the\n  kernel center.\n\n- **iterations**: `integer()`.\n\n  Number of times erosion and dilation are applied.\n\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method, see #BorderTypes. #BORDER_WRAP is not supported.\n\n- **borderValue**: `Evision.scalar()`.\n\n  Border value in case of a constant border. The default value has a special\n  meaning.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and type as source image.\n\nThe function cv::morphologyEx can perform advanced morphological transformations using an erosion and dilation as\nbasic operations.\nAny of the operations can be done in-place. In case of multi-channel images, each channel is\nprocessed independently.\n@sa  dilate, erode, getStructuringElement\n**Note**: The number of iterations is the number of times erosion or dilatation operation will be applied.\nFor instance, an opening operation (#MORPH_OPEN) with two iterations is equivalent to apply\nsuccessively: erode -> erode -> dilate -> dilate (and not erode -> dilate -> erode -> dilate).\n\nPython prototype (for reference only):\n```python3\nmorphologyEx(src, op, kernel[, dst[, anchor[, iterations[, borderType[, borderValue]]]]]) -> dst\n```","ref":"Evision.html#morphologyEx/4"},{"type":"function","title":"Evision.moveWindow/1","doc":"","ref":"Evision.html#moveWindow/1"},{"type":"function","title":"Evision.moveWindow/3","doc":"Moves the window to the specified position\n\n##### Positional Arguments\n- **winname**: `String`.\n\n  Name of the window.\n\n- **x**: `integer()`.\n\n  The new x-coordinate of the window.\n\n- **y**: `integer()`.\n\n  The new y-coordinate of the window.\n\n**Note**: [__Wayland Backend Only__] This function is not supported by the Wayland protocol limitation.\n\nPython prototype (for reference only):\n```python3\nmoveWindow(winname, x, y) -> None\n```","ref":"Evision.html#moveWindow/3"},{"type":"function","title":"Evision.mulSpectrums/1","doc":"","ref":"Evision.html#mulSpectrums/1"},{"type":"function","title":"Evision.mulSpectrums/3","doc":"Performs the per-element multiplication of two Fourier spectrums.\n\n##### Positional Arguments\n- **a**: `Evision.Mat`.\n\n  first input array.\n\n- **b**: `Evision.Mat`.\n\n  second input array of the same size and type as src1 .\n\n- **flags**: `integer()`.\n\n  operation flags; currently, the only supported flag is cv::DFT_ROWS, which indicates that\n  each row of src1 and src2 is an independent 1D Fourier spectrum. If you do not want to use this flag, then simply add a `0` as value.\n\n##### Keyword Arguments\n- **conjB**: `bool`.\n\n  optional flag that conjugates the second input array before the multiplication (true)\n  or not (false).\n\n##### Return\n- **c**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src1 .\n\nThe function cv::mulSpectrums performs the per-element multiplication of the two CCS-packed or complex\nmatrices that are results of a real or complex Fourier transform.\nThe function, together with dft and idft, may be used to calculate convolution (pass conjB=false )\nor correlation (pass conjB=true ) of two arrays rapidly. When the arrays are complex, they are\nsimply multiplied (per element) with an optional conjugation of the second-array elements. When the\narrays are real, they are assumed to be CCS-packed (see dft for details).\n\nPython prototype (for reference only):\n```python3\nmulSpectrums(a, b, flags[, c[, conjB]]) -> c\n```","ref":"Evision.html#mulSpectrums/3"},{"type":"function","title":"Evision.mulSpectrums/4","doc":"Performs the per-element multiplication of two Fourier spectrums.\n\n##### Positional Arguments\n- **a**: `Evision.Mat`.\n\n  first input array.\n\n- **b**: `Evision.Mat`.\n\n  second input array of the same size and type as src1 .\n\n- **flags**: `integer()`.\n\n  operation flags; currently, the only supported flag is cv::DFT_ROWS, which indicates that\n  each row of src1 and src2 is an independent 1D Fourier spectrum. If you do not want to use this flag, then simply add a `0` as value.\n\n##### Keyword Arguments\n- **conjB**: `bool`.\n\n  optional flag that conjugates the second input array before the multiplication (true)\n  or not (false).\n\n##### Return\n- **c**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src1 .\n\nThe function cv::mulSpectrums performs the per-element multiplication of the two CCS-packed or complex\nmatrices that are results of a real or complex Fourier transform.\nThe function, together with dft and idft, may be used to calculate convolution (pass conjB=false )\nor correlation (pass conjB=true ) of two arrays rapidly. When the arrays are complex, they are\nsimply multiplied (per element) with an optional conjugation of the second-array elements. When the\narrays are real, they are assumed to be CCS-packed (see dft for details).\n\nPython prototype (for reference only):\n```python3\nmulSpectrums(a, b, flags[, c[, conjB]]) -> c\n```","ref":"Evision.html#mulSpectrums/4"},{"type":"function","title":"Evision.mulTransposed/1","doc":"","ref":"Evision.html#mulTransposed/1"},{"type":"function","title":"Evision.mulTransposed/2","doc":"Calculates the product of a matrix and its transposition.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input single-channel matrix. Note that unlike gemm, the\n  function can multiply not only floating-point matrices.\n\n- **aTa**: `bool`.\n\n  Flag specifying the multiplication ordering. See the\n  description below.\n\n##### Keyword Arguments\n- **delta**: `Evision.Mat`.\n\n  Optional delta matrix subtracted from src before the\n  multiplication. When the matrix is empty ( delta=noArray() ), it is\n  assumed to be zero, that is, nothing is subtracted. If it has the same\n  size as src, it is simply subtracted. Otherwise, it is \"repeated\" (see\n  repeat ) to cover the full src and then subtracted. Type of the delta\n  matrix, when it is not empty, must be the same as the type of created\n  output matrix. See the dtype parameter description below.\n\n- **scale**: `double`.\n\n  Optional scale factor for the matrix product.\n\n- **dtype**: `integer()`.\n\n  Optional type of the output matrix. When it is negative,\n  the output matrix will have the same type as src . Otherwise, it will be\n  type=CV_MAT_DEPTH(dtype) that should be either CV_32F or CV_64F .\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output square matrix.\n\nThe function cv::mulTransposed calculates the product of src and its\ntransposition:\n\\f[\\texttt{dst} = \\texttt{scale} ( \\texttt{src} - \\texttt{delta} )^T ( \\texttt{src} - \\texttt{delta} )\\f]\nif aTa=true, and\n\\f[\\texttt{dst} = \\texttt{scale} ( \\texttt{src} - \\texttt{delta} ) ( \\texttt{src} - \\texttt{delta} )^T\\f]\notherwise. The function is used to calculate the covariance matrix. With\nzero delta, it can be used as a faster substitute for general matrix\nproduct A\\*B when B=A'\n@sa calcCovarMatrix, gemm, repeat, reduce\n\nPython prototype (for reference only):\n```python3\nmulTransposed(src, aTa[, dst[, delta[, scale[, dtype]]]]) -> dst\n```","ref":"Evision.html#mulTransposed/2"},{"type":"function","title":"Evision.mulTransposed/3","doc":"Calculates the product of a matrix and its transposition.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input single-channel matrix. Note that unlike gemm, the\n  function can multiply not only floating-point matrices.\n\n- **aTa**: `bool`.\n\n  Flag specifying the multiplication ordering. See the\n  description below.\n\n##### Keyword Arguments\n- **delta**: `Evision.Mat`.\n\n  Optional delta matrix subtracted from src before the\n  multiplication. When the matrix is empty ( delta=noArray() ), it is\n  assumed to be zero, that is, nothing is subtracted. If it has the same\n  size as src, it is simply subtracted. Otherwise, it is \"repeated\" (see\n  repeat ) to cover the full src and then subtracted. Type of the delta\n  matrix, when it is not empty, must be the same as the type of created\n  output matrix. See the dtype parameter description below.\n\n- **scale**: `double`.\n\n  Optional scale factor for the matrix product.\n\n- **dtype**: `integer()`.\n\n  Optional type of the output matrix. When it is negative,\n  the output matrix will have the same type as src . Otherwise, it will be\n  type=CV_MAT_DEPTH(dtype) that should be either CV_32F or CV_64F .\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output square matrix.\n\nThe function cv::mulTransposed calculates the product of src and its\ntransposition:\n\\f[\\texttt{dst} = \\texttt{scale} ( \\texttt{src} - \\texttt{delta} )^T ( \\texttt{src} - \\texttt{delta} )\\f]\nif aTa=true, and\n\\f[\\texttt{dst} = \\texttt{scale} ( \\texttt{src} - \\texttt{delta} ) ( \\texttt{src} - \\texttt{delta} )^T\\f]\notherwise. The function is used to calculate the covariance matrix. With\nzero delta, it can be used as a faster substitute for general matrix\nproduct A\\*B when B=A'\n@sa calcCovarMatrix, gemm, repeat, reduce\n\nPython prototype (for reference only):\n```python3\nmulTransposed(src, aTa[, dst[, delta[, scale[, dtype]]]]) -> dst\n```","ref":"Evision.html#mulTransposed/3"},{"type":"function","title":"Evision.multiply/1","doc":"","ref":"Evision.html#multiply/1"},{"type":"function","title":"Evision.multiply/2","doc":"Calculates the per-element scaled product of two arrays.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array.\n\n- **src2**: `Evision.Mat`.\n\n  second input array of the same size and the same type as src1.\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  optional scale factor.\n\n- **dtype**: `integer()`.\n\n  optional depth of the output array\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src1.\n\nThe function multiply calculates the per-element product of two arrays:\n\\f[\\texttt{dst} (I)= \\texttt{saturate} ( \\texttt{scale} \\cdot \\texttt{src1} (I)  \\cdot \\texttt{src2} (I))\\f]\nThere is also a @ref MatrixExpressions -friendly variant of the first function. See Mat::mul .\nFor a not-per-element matrix product, see gemm .\n**Note**: Saturation is not applied when the output array has the depth\nCV_32S. You may even get result of an incorrect sign in the case of\noverflow.\n**Note**: (Python) Be careful to difference behaviour between src1/src2 are single number and they are tuple/array.\n`multiply(src,X)` means `multiply(src,(X,X,X,X))`.\n`multiply(src,(X,))` means `multiply(src,(X,0,0,0))`.\n@sa add, subtract, divide, scaleAdd, addWeighted, accumulate, accumulateProduct, accumulateSquare,\nMat::convertTo\n\nPython prototype (for reference only):\n```python3\nmultiply(src1, src2[, dst[, scale[, dtype]]]) -> dst\n```","ref":"Evision.html#multiply/2"},{"type":"function","title":"Evision.multiply/3","doc":"Calculates the per-element scaled product of two arrays.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array.\n\n- **src2**: `Evision.Mat`.\n\n  second input array of the same size and the same type as src1.\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  optional scale factor.\n\n- **dtype**: `integer()`.\n\n  optional depth of the output array\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src1.\n\nThe function multiply calculates the per-element product of two arrays:\n\\f[\\texttt{dst} (I)= \\texttt{saturate} ( \\texttt{scale} \\cdot \\texttt{src1} (I)  \\cdot \\texttt{src2} (I))\\f]\nThere is also a @ref MatrixExpressions -friendly variant of the first function. See Mat::mul .\nFor a not-per-element matrix product, see gemm .\n**Note**: Saturation is not applied when the output array has the depth\nCV_32S. You may even get result of an incorrect sign in the case of\noverflow.\n**Note**: (Python) Be careful to difference behaviour between src1/src2 are single number and they are tuple/array.\n`multiply(src,X)` means `multiply(src,(X,X,X,X))`.\n`multiply(src,(X,))` means `multiply(src,(X,0,0,0))`.\n@sa add, subtract, divide, scaleAdd, addWeighted, accumulate, accumulateProduct, accumulateSquare,\nMat::convertTo\n\nPython prototype (for reference only):\n```python3\nmultiply(src1, src2[, dst[, scale[, dtype]]]) -> dst\n```","ref":"Evision.html#multiply/3"},{"type":"function","title":"Evision.namedWindow/1","doc":"Creates a window.\n\n##### Positional Arguments\n- **winname**: `String`.\n\n  Name of the window in the window caption that may be used as a window identifier.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Flags of the window. The supported flags are: (cv::WindowFlags)\n\nThe function namedWindow creates a window that can be used as a placeholder for images and\ntrackbars. Created windows are referred to by their names.\nIf a window with the same name already exists, the function does nothing.\nYou can call cv::destroyWindow or cv::destroyAllWindows to close the window and de-allocate any associated\nmemory usage. For a simple program, you do not really have to call these functions because all the\nresources and windows of the application are closed automatically by the operating system upon exit.\n**Note**: Qt backend supports additional flags:\n- **WINDOW_NORMAL or WINDOW_AUTOSIZE:** WINDOW_NORMAL enables you to resize the\n  window, whereas WINDOW_AUTOSIZE adjusts automatically the window size to fit the\n  displayed image (see imshow ), and you cannot change the window size manually.\n\n- **WINDOW_FREERATIO or WINDOW_KEEPRATIO:** WINDOW_FREERATIO adjusts the image\n  with no respect to its ratio, whereas WINDOW_KEEPRATIO keeps the image ratio.\n\n- **WINDOW_GUI_NORMAL or WINDOW_GUI_EXPANDED:** WINDOW_GUI_NORMAL is the old way to draw the window\n  without statusbar and toolbar, whereas WINDOW_GUI_EXPANDED is a new enhanced GUI.\n  By default, flags == WINDOW_AUTOSIZE | WINDOW_KEEPRATIO | WINDOW_GUI_EXPANDED\n\nPython prototype (for reference only):\n```python3\nnamedWindow(winname[, flags]) -> None\n```","ref":"Evision.html#namedWindow/1"},{"type":"function","title":"Evision.namedWindow/2","doc":"Creates a window.\n\n##### Positional Arguments\n- **winname**: `String`.\n\n  Name of the window in the window caption that may be used as a window identifier.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Flags of the window. The supported flags are: (cv::WindowFlags)\n\nThe function namedWindow creates a window that can be used as a placeholder for images and\ntrackbars. Created windows are referred to by their names.\nIf a window with the same name already exists, the function does nothing.\nYou can call cv::destroyWindow or cv::destroyAllWindows to close the window and de-allocate any associated\nmemory usage. For a simple program, you do not really have to call these functions because all the\nresources and windows of the application are closed automatically by the operating system upon exit.\n**Note**: Qt backend supports additional flags:\n- **WINDOW_NORMAL or WINDOW_AUTOSIZE:** WINDOW_NORMAL enables you to resize the\n  window, whereas WINDOW_AUTOSIZE adjusts automatically the window size to fit the\n  displayed image (see imshow ), and you cannot change the window size manually.\n\n- **WINDOW_FREERATIO or WINDOW_KEEPRATIO:** WINDOW_FREERATIO adjusts the image\n  with no respect to its ratio, whereas WINDOW_KEEPRATIO keeps the image ratio.\n\n- **WINDOW_GUI_NORMAL or WINDOW_GUI_EXPANDED:** WINDOW_GUI_NORMAL is the old way to draw the window\n  without statusbar and toolbar, whereas WINDOW_GUI_EXPANDED is a new enhanced GUI.\n  By default, flags == WINDOW_AUTOSIZE | WINDOW_KEEPRATIO | WINDOW_GUI_EXPANDED\n\nPython prototype (for reference only):\n```python3\nnamedWindow(winname[, flags]) -> None\n```","ref":"Evision.html#namedWindow/2"},{"type":"function","title":"Evision.norm/1","doc":"Calculates the  absolute norm of an array.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array.\n\n##### Keyword Arguments\n- **normType**: `integer()`.\n\n  type of the norm (see #NormTypes).\n\n- **mask**: `Evision.Mat`.\n\n  optional operation mask; it must have the same size as src1 and CV_8UC1 type.\n\n##### Return\n- **retval**: `double`\n\nThis version of #norm calculates the absolute norm of src1. The type of norm to calculate is specified using #NormTypes.\nAs example for one array consider the function \\f$r(x)= \\begin{pmatrix} x \\\\\\\\ 1-x \\end{pmatrix}, x \\in \\[-1;1]\\f$.\nThe \\f$ L\\_{1}, L\\_{2} \\f$ and \\f$ L\\_{\\infty} \\f$ norm for the sample value \\f$r(-1) = \\begin{pmatrix} -1 \\\\\\\\ 2 \\end{pmatrix}\\f$\nis calculated as follows\n\\f{align*}\n\\| r(-1) \\|_{L_1} &= |-1| + |2| = 3 \\\\\\\\\n\\| r(-1) \\|_{L_2} &= \\sqrt{(-1)^{2} + (2)^{2}} = \\sqrt{5} \\\\\\\\\n\\| r(-1) \\|_{L_\\infty} &= \\max(|-1|,|2|) = 2\n\\f}\nand for \\f$r(0.5) = \\begin{pmatrix} 0.5 \\\\\\\\ 0.5 \\end{pmatrix}\\f$ the calculation is\n\\f{align*}\n\\| r(0.5) \\|_{L_1} &= |0.5| + |0.5| = 1 \\\\\\\\\n\\| r(0.5) \\|_{L_2} &= \\sqrt{(0.5)^{2} + (0.5)^{2}} = \\sqrt{0.5} \\\\\\\\\n\\| r(0.5) \\|_{L_\\infty} &= \\max(|0.5|,|0.5|) = 0.5.\n\\f}\nThe following graphic shows all values for the three norm functions \\f$\\| r(x) \\|\\_{L\\_1}, \\| r(x) \\|\\_{L\\_2}\\f$ and \\f$\\| r(x) \\|\\_{L\\_\\infty}\\f$.\nIt is notable that the \\f$ L\\_{1} \\f$ norm forms the upper and the \\f$ L\\_{\\infty} \\f$ norm forms the lower border for the example function \\f$ r(x) \\f$.\n![Graphs for the different norm functions from the above example](pics/NormTypes_OneArray_1-2-INF.png)\nWhen the mask parameter is specified and it is not empty, the norm is\nIf normType is not specified, #NORM_L2 is used.\ncalculated only over the region specified by the mask.\nMulti-channel input arrays are treated as single-channel arrays, that is,\nthe results for all channels are combined.\nHamming norms can only be calculated with CV_8U depth arrays.\n\nPython prototype (for reference only):\n```python3\nnorm(src1[, normType[, mask]]) -> retval\n```","ref":"Evision.html#norm/1"},{"type":"function","title":"Evision.norm/2","doc":"#### Variant 1:\nCalculates an absolute difference norm or a relative difference norm.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array.\n\n- **src2**: `Evision.Mat`.\n\n  second input array of the same size and the same type as src1.\n\n##### Keyword Arguments\n- **normType**: `integer()`.\n\n  type of the norm (see #NormTypes).\n\n- **mask**: `Evision.Mat`.\n\n  optional operation mask; it must have the same size as src1 and CV_8UC1 type.\n\n##### Return\n- **retval**: `double`\n\nThis version of cv::norm calculates the absolute difference norm\nor the relative difference norm of arrays src1 and src2.\nThe type of norm to calculate is specified using #NormTypes.\n\nPython prototype (for reference only):\n```python3\nnorm(src1, src2[, normType[, mask]]) -> retval\n```\n#### Variant 2:\nCalculates the  absolute norm of an array.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array.\n\n##### Keyword Arguments\n- **normType**: `integer()`.\n\n  type of the norm (see #NormTypes).\n\n- **mask**: `Evision.Mat`.\n\n  optional operation mask; it must have the same size as src1 and CV_8UC1 type.\n\n##### Return\n- **retval**: `double`\n\nThis version of #norm calculates the absolute norm of src1. The type of norm to calculate is specified using #NormTypes.\nAs example for one array consider the function \\f$r(x)= \\begin{pmatrix} x \\\\\\\\ 1-x \\end{pmatrix}, x \\in \\[-1;1]\\f$.\nThe \\f$ L\\_{1}, L\\_{2} \\f$ and \\f$ L\\_{\\infty} \\f$ norm for the sample value \\f$r(-1) = \\begin{pmatrix} -1 \\\\\\\\ 2 \\end{pmatrix}\\f$\nis calculated as follows\n\\f{align*}\n\\| r(-1) \\|_{L_1} &= |-1| + |2| = 3 \\\\\\\\\n\\| r(-1) \\|_{L_2} &= \\sqrt{(-1)^{2} + (2)^{2}} = \\sqrt{5} \\\\\\\\\n\\| r(-1) \\|_{L_\\infty} &= \\max(|-1|,|2|) = 2\n\\f}\nand for \\f$r(0.5) = \\begin{pmatrix} 0.5 \\\\\\\\ 0.5 \\end{pmatrix}\\f$ the calculation is\n\\f{align*}\n\\| r(0.5) \\|_{L_1} &= |0.5| + |0.5| = 1 \\\\\\\\\n\\| r(0.5) \\|_{L_2} &= \\sqrt{(0.5)^{2} + (0.5)^{2}} = \\sqrt{0.5} \\\\\\\\\n\\| r(0.5) \\|_{L_\\infty} &= \\max(|0.5|,|0.5|) = 0.5.\n\\f}\nThe following graphic shows all values for the three norm functions \\f$\\| r(x) \\|\\_{L\\_1}, \\| r(x) \\|\\_{L\\_2}\\f$ and \\f$\\| r(x) \\|\\_{L\\_\\infty}\\f$.\nIt is notable that the \\f$ L\\_{1} \\f$ norm forms the upper and the \\f$ L\\_{\\infty} \\f$ norm forms the lower border for the example function \\f$ r(x) \\f$.\n![Graphs for the different norm functions from the above example](pics/NormTypes_OneArray_1-2-INF.png)\nWhen the mask parameter is specified and it is not empty, the norm is\nIf normType is not specified, #NORM_L2 is used.\ncalculated only over the region specified by the mask.\nMulti-channel input arrays are treated as single-channel arrays, that is,\nthe results for all channels are combined.\nHamming norms can only be calculated with CV_8U depth arrays.\n\nPython prototype (for reference only):\n```python3\nnorm(src1[, normType[, mask]]) -> retval\n```","ref":"Evision.html#norm/2"},{"type":"function","title":"Evision.norm/3","doc":"Calculates an absolute difference norm or a relative difference norm.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array.\n\n- **src2**: `Evision.Mat`.\n\n  second input array of the same size and the same type as src1.\n\n##### Keyword Arguments\n- **normType**: `integer()`.\n\n  type of the norm (see #NormTypes).\n\n- **mask**: `Evision.Mat`.\n\n  optional operation mask; it must have the same size as src1 and CV_8UC1 type.\n\n##### Return\n- **retval**: `double`\n\nThis version of cv::norm calculates the absolute difference norm\nor the relative difference norm of arrays src1 and src2.\nThe type of norm to calculate is specified using #NormTypes.\n\nPython prototype (for reference only):\n```python3\nnorm(src1, src2[, normType[, mask]]) -> retval\n```","ref":"Evision.html#norm/3"},{"type":"function","title":"Evision.normalize/1","doc":"","ref":"Evision.html#normalize/1"},{"type":"function","title":"Evision.normalize/2","doc":"Normalizes the norm or value range of an array.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array.\n\n##### Keyword Arguments\n- **alpha**: `double`.\n\n  norm value to normalize to or the lower range boundary in case of the range\n  normalization.\n\n- **beta**: `double`.\n\n  upper range boundary in case of the range normalization; it is not used for the norm\n  normalization.\n\n- **norm_type**: `integer()`.\n\n  normalization type (see cv::NormTypes).\n\n- **dtype**: `integer()`.\n\n  when negative, the output array has the same type as src; otherwise, it has the same\n  number of channels as src and the depth =CV_MAT_DEPTH(dtype).\n\n- **mask**: `Evision.Mat`.\n\n  optional operation mask.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size as src .\n\nThe function cv::normalize normalizes scale and shift the input array elements so that\n\\f[\\| \\texttt{dst} \\| \\_{L\\_p}= \\texttt{alpha}\\f]\n(where p=Inf, 1 or 2) when normType=NORM_INF, NORM_L1, or NORM_L2, respectively; or so that\n\\f[\\min \\_I  \\texttt{dst} (I)= \\texttt{alpha} , \\, \\, \\max \\_I  \\texttt{dst} (I)= \\texttt{beta}\\f]\nwhen normType=NORM_MINMAX (for dense arrays only). The optional mask specifies a sub-array to be\nnormalized. This means that the norm or min-n-max are calculated over the sub-array, and then this\nsub-array is modified to be normalized. If you want to only use the mask to calculate the norm or\nmin-max but modify the whole array, you can use norm and Mat::convertTo.\nIn case of sparse matrices, only the non-zero values are analyzed and transformed. Because of this,\nthe range transformation for sparse matrices is not allowed since it can shift the zero level.\nPossible usage with some positive example data:\n```cpp\nvector  positiveData = { 2.0, 8.0, 10.0 };\nvector  normalizedData_l1, normalizedData_l2, normalizedData_inf, normalizedData_minmax;\n// Norm to probability (total count)\n// sum(numbers) = 20.0\n// 2.0      0.1     (2.0/20.0)\n// 8.0      0.4     (8.0/20.0)\n// 10.0     0.5     (10.0/20.0)\nnormalize(positiveData, normalizedData_l1, 1.0, 0.0, NORM_L1);\n// Norm to unit vector: ||positiveData|| = 1.0\n// 2.0      0.15\n// 8.0      0.62\n// 10.0     0.77\nnormalize(positiveData, normalizedData_l2, 1.0, 0.0, NORM_L2);\n// Norm to max element\n// 2.0      0.2     (2.0/10.0)\n// 8.0      0.8     (8.0/10.0)\n// 10.0     1.0     (10.0/10.0)\nnormalize(positiveData, normalizedData_inf, 1.0, 0.0, NORM_INF);\n// Norm to range [0.0;1.0]\n// 2.0      0.0     (shift to left border)\n// 8.0      0.75    (6.0/8.0)\n// 10.0     1.0     (shift to right border)\nnormalize(positiveData, normalizedData_minmax, 1.0, 0.0, NORM_MINMAX);\n```\n@sa norm, Mat::convertTo, SparseMat::convertTo\n\nPython prototype (for reference only):\n```python3\nnormalize(src, dst[, alpha[, beta[, norm_type[, dtype[, mask]]]]]) -> dst\n```","ref":"Evision.html#normalize/2"},{"type":"function","title":"Evision.normalize/3","doc":"Normalizes the norm or value range of an array.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array.\n\n##### Keyword Arguments\n- **alpha**: `double`.\n\n  norm value to normalize to or the lower range boundary in case of the range\n  normalization.\n\n- **beta**: `double`.\n\n  upper range boundary in case of the range normalization; it is not used for the norm\n  normalization.\n\n- **norm_type**: `integer()`.\n\n  normalization type (see cv::NormTypes).\n\n- **dtype**: `integer()`.\n\n  when negative, the output array has the same type as src; otherwise, it has the same\n  number of channels as src and the depth =CV_MAT_DEPTH(dtype).\n\n- **mask**: `Evision.Mat`.\n\n  optional operation mask.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size as src .\n\nThe function cv::normalize normalizes scale and shift the input array elements so that\n\\f[\\| \\texttt{dst} \\| \\_{L\\_p}= \\texttt{alpha}\\f]\n(where p=Inf, 1 or 2) when normType=NORM_INF, NORM_L1, or NORM_L2, respectively; or so that\n\\f[\\min \\_I  \\texttt{dst} (I)= \\texttt{alpha} , \\, \\, \\max \\_I  \\texttt{dst} (I)= \\texttt{beta}\\f]\nwhen normType=NORM_MINMAX (for dense arrays only). The optional mask specifies a sub-array to be\nnormalized. This means that the norm or min-n-max are calculated over the sub-array, and then this\nsub-array is modified to be normalized. If you want to only use the mask to calculate the norm or\nmin-max but modify the whole array, you can use norm and Mat::convertTo.\nIn case of sparse matrices, only the non-zero values are analyzed and transformed. Because of this,\nthe range transformation for sparse matrices is not allowed since it can shift the zero level.\nPossible usage with some positive example data:\n```cpp\nvector  positiveData = { 2.0, 8.0, 10.0 };\nvector  normalizedData_l1, normalizedData_l2, normalizedData_inf, normalizedData_minmax;\n// Norm to probability (total count)\n// sum(numbers) = 20.0\n// 2.0      0.1     (2.0/20.0)\n// 8.0      0.4     (8.0/20.0)\n// 10.0     0.5     (10.0/20.0)\nnormalize(positiveData, normalizedData_l1, 1.0, 0.0, NORM_L1);\n// Norm to unit vector: ||positiveData|| = 1.0\n// 2.0      0.15\n// 8.0      0.62\n// 10.0     0.77\nnormalize(positiveData, normalizedData_l2, 1.0, 0.0, NORM_L2);\n// Norm to max element\n// 2.0      0.2     (2.0/10.0)\n// 8.0      0.8     (8.0/10.0)\n// 10.0     1.0     (10.0/10.0)\nnormalize(positiveData, normalizedData_inf, 1.0, 0.0, NORM_INF);\n// Norm to range [0.0;1.0]\n// 2.0      0.0     (shift to left border)\n// 8.0      0.75    (6.0/8.0)\n// 10.0     1.0     (shift to right border)\nnormalize(positiveData, normalizedData_minmax, 1.0, 0.0, NORM_MINMAX);\n```\n@sa norm, Mat::convertTo, SparseMat::convertTo\n\nPython prototype (for reference only):\n```python3\nnormalize(src, dst[, alpha[, beta[, norm_type[, dtype[, mask]]]]]) -> dst\n```","ref":"Evision.html#normalize/3"},{"type":"function","title":"Evision.patchNaNs/1","doc":"Replaces NaNs by given number\n##### Keyword Arguments\n- **val**: `double`.\n\n  value to convert the NaNs\n\n##### Return\n- **a**: `Evision.Mat.t()`.\n\n  input/output matrix (CV_32F type).\n\nPython prototype (for reference only):\n```python3\npatchNaNs(a[, val]) -> a\n```","ref":"Evision.html#patchNaNs/1"},{"type":"function","title":"Evision.patchNaNs/2","doc":"Replaces NaNs by given number\n##### Keyword Arguments\n- **val**: `double`.\n\n  value to convert the NaNs\n\n##### Return\n- **a**: `Evision.Mat.t()`.\n\n  input/output matrix (CV_32F type).\n\nPython prototype (for reference only):\n```python3\npatchNaNs(a[, val]) -> a\n```","ref":"Evision.html#patchNaNs/2"},{"type":"function","title":"Evision.pcaBackProject/1","doc":"","ref":"Evision.html#pcaBackProject/1"},{"type":"function","title":"Evision.pcaBackProject/3","doc":"PCABackProject\n\n##### Positional Arguments\n- **data**: `Evision.Mat`\n- **mean**: `Evision.Mat`\n- **eigenvectors**: `Evision.Mat`\n\n##### Return\n- **result**: `Evision.Mat.t()`.\n\nwrap PCA::backProject\n\nPython prototype (for reference only):\n```python3\nPCABackProject(data, mean, eigenvectors[, result]) -> result\n```","ref":"Evision.html#pcaBackProject/3"},{"type":"function","title":"Evision.pcaBackProject/4","doc":"PCABackProject\n\n##### Positional Arguments\n- **data**: `Evision.Mat`\n- **mean**: `Evision.Mat`\n- **eigenvectors**: `Evision.Mat`\n\n##### Return\n- **result**: `Evision.Mat.t()`.\n\nwrap PCA::backProject\n\nPython prototype (for reference only):\n```python3\nPCABackProject(data, mean, eigenvectors[, result]) -> result\n```","ref":"Evision.html#pcaBackProject/4"},{"type":"function","title":"Evision.pcaCompute2/1","doc":"","ref":"Evision.html#pcaCompute2/1"},{"type":"function","title":"Evision.pcaCompute2/2","doc":"PCACompute2\n\n##### Positional Arguments\n- **data**: `Evision.Mat`\n\n##### Keyword Arguments\n- **maxComponents**: `integer()`.\n\n##### Return\n- **mean**: `Evision.Mat.t()`\n- **eigenvectors**: `Evision.Mat.t()`.\n- **eigenvalues**: `Evision.Mat.t()`.\n\nwrap PCA::operator() and add eigenvalues output parameter\n\nPython prototype (for reference only):\n```python3\nPCACompute2(data, mean[, eigenvectors[, eigenvalues[, maxComponents]]]) -> mean, eigenvectors, eigenvalues\n```","ref":"Evision.html#pcaCompute2/2"},{"type":"function","title":"Evision.pcaCompute2/3","doc":"#### Variant 1:\nPCACompute2\n\n##### Positional Arguments\n- **data**: `Evision.Mat`\n- **retainedVariance**: `double`\n\n##### Return\n- **mean**: `Evision.Mat.t()`\n- **eigenvectors**: `Evision.Mat.t()`.\n- **eigenvalues**: `Evision.Mat.t()`.\n\nwrap PCA::operator() and add eigenvalues output parameter\n\nPython prototype (for reference only):\n```python3\nPCACompute2(data, mean, retainedVariance[, eigenvectors[, eigenvalues]]) -> mean, eigenvectors, eigenvalues\n```\n#### Variant 2:\nPCACompute2\n\n##### Positional Arguments\n- **data**: `Evision.Mat`\n\n##### Keyword Arguments\n- **maxComponents**: `integer()`.\n\n##### Return\n- **mean**: `Evision.Mat.t()`\n- **eigenvectors**: `Evision.Mat.t()`.\n- **eigenvalues**: `Evision.Mat.t()`.\n\nwrap PCA::operator() and add eigenvalues output parameter\n\nPython prototype (for reference only):\n```python3\nPCACompute2(data, mean[, eigenvectors[, eigenvalues[, maxComponents]]]) -> mean, eigenvectors, eigenvalues\n```","ref":"Evision.html#pcaCompute2/3"},{"type":"function","title":"Evision.pcaCompute2/4","doc":"PCACompute2\n\n##### Positional Arguments\n- **data**: `Evision.Mat`\n- **retainedVariance**: `double`\n\n##### Return\n- **mean**: `Evision.Mat.t()`\n- **eigenvectors**: `Evision.Mat.t()`.\n- **eigenvalues**: `Evision.Mat.t()`.\n\nwrap PCA::operator() and add eigenvalues output parameter\n\nPython prototype (for reference only):\n```python3\nPCACompute2(data, mean, retainedVariance[, eigenvectors[, eigenvalues]]) -> mean, eigenvectors, eigenvalues\n```","ref":"Evision.html#pcaCompute2/4"},{"type":"function","title":"Evision.pcaCompute/1","doc":"","ref":"Evision.html#pcaCompute/1"},{"type":"function","title":"Evision.pcaCompute/2","doc":"PCACompute\n\n##### Positional Arguments\n- **data**: `Evision.Mat`\n\n##### Keyword Arguments\n- **maxComponents**: `integer()`.\n\n##### Return\n- **mean**: `Evision.Mat.t()`\n- **eigenvectors**: `Evision.Mat.t()`.\n\nwrap PCA::operator()\n\nPython prototype (for reference only):\n```python3\nPCACompute(data, mean[, eigenvectors[, maxComponents]]) -> mean, eigenvectors\n```","ref":"Evision.html#pcaCompute/2"},{"type":"function","title":"Evision.pcaCompute/3","doc":"#### Variant 1:\nPCACompute\n\n##### Positional Arguments\n- **data**: `Evision.Mat`\n- **retainedVariance**: `double`\n\n##### Return\n- **mean**: `Evision.Mat.t()`\n- **eigenvectors**: `Evision.Mat.t()`.\n\nwrap PCA::operator()\n\nPython prototype (for reference only):\n```python3\nPCACompute(data, mean, retainedVariance[, eigenvectors]) -> mean, eigenvectors\n```\n#### Variant 2:\nPCACompute\n\n##### Positional Arguments\n- **data**: `Evision.Mat`\n\n##### Keyword Arguments\n- **maxComponents**: `integer()`.\n\n##### Return\n- **mean**: `Evision.Mat.t()`\n- **eigenvectors**: `Evision.Mat.t()`.\n\nwrap PCA::operator()\n\nPython prototype (for reference only):\n```python3\nPCACompute(data, mean[, eigenvectors[, maxComponents]]) -> mean, eigenvectors\n```","ref":"Evision.html#pcaCompute/3"},{"type":"function","title":"Evision.pcaCompute/4","doc":"PCACompute\n\n##### Positional Arguments\n- **data**: `Evision.Mat`\n- **retainedVariance**: `double`\n\n##### Return\n- **mean**: `Evision.Mat.t()`\n- **eigenvectors**: `Evision.Mat.t()`.\n\nwrap PCA::operator()\n\nPython prototype (for reference only):\n```python3\nPCACompute(data, mean, retainedVariance[, eigenvectors]) -> mean, eigenvectors\n```","ref":"Evision.html#pcaCompute/4"},{"type":"function","title":"Evision.pcaProject/1","doc":"","ref":"Evision.html#pcaProject/1"},{"type":"function","title":"Evision.pcaProject/3","doc":"PCAProject\n\n##### Positional Arguments\n- **data**: `Evision.Mat`\n- **mean**: `Evision.Mat`\n- **eigenvectors**: `Evision.Mat`\n\n##### Return\n- **result**: `Evision.Mat.t()`.\n\nwrap PCA::project\n\nPython prototype (for reference only):\n```python3\nPCAProject(data, mean, eigenvectors[, result]) -> result\n```","ref":"Evision.html#pcaProject/3"},{"type":"function","title":"Evision.pcaProject/4","doc":"PCAProject\n\n##### Positional Arguments\n- **data**: `Evision.Mat`\n- **mean**: `Evision.Mat`\n- **eigenvectors**: `Evision.Mat`\n\n##### Return\n- **result**: `Evision.Mat.t()`.\n\nwrap PCA::project\n\nPython prototype (for reference only):\n```python3\nPCAProject(data, mean, eigenvectors[, result]) -> result\n```","ref":"Evision.html#pcaProject/4"},{"type":"function","title":"Evision.pencilSketch/1","doc":"Pencil-like non-photorealistic line drawing\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n##### Keyword Arguments\n- **sigma_s**: `float`.\n\n  %Range between 0 to 200.\n\n- **sigma_r**: `float`.\n\n  %Range between 0 to 1.\n\n- **shade_factor**: `float`.\n\n  %Range between 0 to 0.1.\n\n##### Return\n- **dst1**: `Evision.Mat.t()`.\n\n  Output 8-bit 1-channel image.\n\n- **dst2**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as src.\n\nPython prototype (for reference only):\n```python3\npencilSketch(src[, dst1[, dst2[, sigma_s[, sigma_r[, shade_factor]]]]]) -> dst1, dst2\n```","ref":"Evision.html#pencilSketch/1"},{"type":"function","title":"Evision.pencilSketch/2","doc":"Pencil-like non-photorealistic line drawing\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n##### Keyword Arguments\n- **sigma_s**: `float`.\n\n  %Range between 0 to 200.\n\n- **sigma_r**: `float`.\n\n  %Range between 0 to 1.\n\n- **shade_factor**: `float`.\n\n  %Range between 0 to 0.1.\n\n##### Return\n- **dst1**: `Evision.Mat.t()`.\n\n  Output 8-bit 1-channel image.\n\n- **dst2**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as src.\n\nPython prototype (for reference only):\n```python3\npencilSketch(src[, dst1[, dst2[, sigma_s[, sigma_r[, shade_factor]]]]]) -> dst1, dst2\n```","ref":"Evision.html#pencilSketch/2"},{"type":"function","title":"Evision.perspectiveTransform/1","doc":"","ref":"Evision.html#perspectiveTransform/1"},{"type":"function","title":"Evision.perspectiveTransform/2","doc":"Performs the perspective matrix transformation of vectors.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input two-channel or three-channel floating-point array; each\n  element is a 2D/3D vector to be transformed.\n\n- **m**: `Evision.Mat`.\n\n  3x3 or 4x4 floating-point transformation matrix.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src.\n\nThe function cv::perspectiveTransform transforms every element of src by\ntreating it as a 2D or 3D vector, in the following way:\n\\f[(x, y, z)  \\rightarrow (x'/w, y'/w, z'/w)\\f]\nwhere\n\\f[(x', y', z', w') =  \\texttt{mat} \\cdot \\begin{bmatrix} x & y & z & 1  \\end{bmatrix}\\f]\nand\n\\f[w =  \\fork{w'}{if \\(w' \\ne 0\\)}{\\infty}{otherwise}\\f]\nHere a 3D vector transformation is shown. In case of a 2D vector\ntransformation, the z component is omitted.\n**Note**: The function transforms a sparse set of 2D or 3D vectors. If you\nwant to transform an image using perspective transformation, use\nwarpPerspective . If you have an inverse problem, that is, you want to\ncompute the most probable perspective transformation out of several\npairs of corresponding points, you can use getPerspectiveTransform or\nfindHomography .\n@sa  transform, warpPerspective, getPerspectiveTransform, findHomography\n\nPython prototype (for reference only):\n```python3\nperspectiveTransform(src, m[, dst]) -> dst\n```","ref":"Evision.html#perspectiveTransform/2"},{"type":"function","title":"Evision.perspectiveTransform/3","doc":"Performs the perspective matrix transformation of vectors.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input two-channel or three-channel floating-point array; each\n  element is a 2D/3D vector to be transformed.\n\n- **m**: `Evision.Mat`.\n\n  3x3 or 4x4 floating-point transformation matrix.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src.\n\nThe function cv::perspectiveTransform transforms every element of src by\ntreating it as a 2D or 3D vector, in the following way:\n\\f[(x, y, z)  \\rightarrow (x'/w, y'/w, z'/w)\\f]\nwhere\n\\f[(x', y', z', w') =  \\texttt{mat} \\cdot \\begin{bmatrix} x & y & z & 1  \\end{bmatrix}\\f]\nand\n\\f[w =  \\fork{w'}{if \\(w' \\ne 0\\)}{\\infty}{otherwise}\\f]\nHere a 3D vector transformation is shown. In case of a 2D vector\ntransformation, the z component is omitted.\n**Note**: The function transforms a sparse set of 2D or 3D vectors. If you\nwant to transform an image using perspective transformation, use\nwarpPerspective . If you have an inverse problem, that is, you want to\ncompute the most probable perspective transformation out of several\npairs of corresponding points, you can use getPerspectiveTransform or\nfindHomography .\n@sa  transform, warpPerspective, getPerspectiveTransform, findHomography\n\nPython prototype (for reference only):\n```python3\nperspectiveTransform(src, m[, dst]) -> dst\n```","ref":"Evision.html#perspectiveTransform/3"},{"type":"function","title":"Evision.phase/1","doc":"","ref":"Evision.html#phase/1"},{"type":"function","title":"Evision.phase/2","doc":"Calculates the rotation angle of 2D vectors.\n\n##### Positional Arguments\n- **x**: `Evision.Mat`.\n\n  input floating-point array of x-coordinates of 2D vectors.\n\n- **y**: `Evision.Mat`.\n\n  input array of y-coordinates of 2D vectors; it must have the\n  same size and the same type as x.\n\n##### Keyword Arguments\n- **angleInDegrees**: `bool`.\n\n  when true, the function calculates the angle in\n  degrees, otherwise, they are measured in radians.\n\n##### Return\n- **angle**: `Evision.Mat.t()`.\n\n  output array of vector angles; it has the same size and\n  same type as x .\n\nThe function cv::phase calculates the rotation angle of each 2D vector that\nis formed from the corresponding elements of x and y :\n\\f[\\texttt{angle} (I) =  \\texttt{atan2} ( \\texttt{y} (I), \\texttt{x} (I))\\f]\nThe angle estimation accuracy is about 0.3 degrees. When x(I)=y(I)=0 ,\nthe corresponding angle(I) is set to 0.\n\nPython prototype (for reference only):\n```python3\nphase(x, y[, angle[, angleInDegrees]]) -> angle\n```","ref":"Evision.html#phase/2"},{"type":"function","title":"Evision.phase/3","doc":"Calculates the rotation angle of 2D vectors.\n\n##### Positional Arguments\n- **x**: `Evision.Mat`.\n\n  input floating-point array of x-coordinates of 2D vectors.\n\n- **y**: `Evision.Mat`.\n\n  input array of y-coordinates of 2D vectors; it must have the\n  same size and the same type as x.\n\n##### Keyword Arguments\n- **angleInDegrees**: `bool`.\n\n  when true, the function calculates the angle in\n  degrees, otherwise, they are measured in radians.\n\n##### Return\n- **angle**: `Evision.Mat.t()`.\n\n  output array of vector angles; it has the same size and\n  same type as x .\n\nThe function cv::phase calculates the rotation angle of each 2D vector that\nis formed from the corresponding elements of x and y :\n\\f[\\texttt{angle} (I) =  \\texttt{atan2} ( \\texttt{y} (I), \\texttt{x} (I))\\f]\nThe angle estimation accuracy is about 0.3 degrees. When x(I)=y(I)=0 ,\nthe corresponding angle(I) is set to 0.\n\nPython prototype (for reference only):\n```python3\nphase(x, y[, angle[, angleInDegrees]]) -> angle\n```","ref":"Evision.html#phase/3"},{"type":"function","title":"Evision.phaseCorrelate/1","doc":"","ref":"Evision.html#phaseCorrelate/1"},{"type":"function","title":"Evision.phaseCorrelate/2","doc":"The function is used to detect translational shifts that occur between two images.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  Source floating point array (CV_32FC1 or CV_64FC1)\n\n- **src2**: `Evision.Mat`.\n\n  Source floating point array (CV_32FC1 or CV_64FC1)\n\n##### Keyword Arguments\n- **window**: `Evision.Mat`.\n\n  Floating point array with windowing coefficients to reduce edge effects (optional).\n\n##### Return\n- **retval**: `Point2d`\n- **response**: `double*`.\n\n  Signal power within the 5x5 centroid around the peak, between 0 and 1 (optional).\n\nThe operation takes advantage of the Fourier shift theorem for detecting the translational shift in\nthe frequency domain. It can be used for fast image registration as well as motion estimation. For\nmore information please see  \nCalculates the cross-power spectrum of two supplied source arrays. The arrays are padded if needed\nwith getOptimalDFTSize.\nThe function performs the following equations:\n- First it applies a Hanning window (see  ) to each\n  image to remove possible edge effects. This window is cached until the array size changes to speed\n  up processing time.\n\n- Next it computes the forward DFTs of each source array:\n  \\f[\\mathbf{G}\\_a = \\mathcal{F}\\\\{src\\_1\\\\}, \\; \\mathbf{G}\\_b = \\mathcal{F}\\\\{src\\_2\\\\}\\f]\n  where \\f$\\mathcal{F}\\f$ is the forward DFT.\n\n- It then computes the cross-power spectrum of each frequency domain array:\n  \\f[R = \\frac{ \\mathbf{G}\\_a \\mathbf{G}\\_b^\\*}{|\\mathbf{G}\\_a \\mathbf{G}\\_b^\\*|}\\f]\n\n- Next the cross-correlation is converted back into the time domain via the inverse DFT:\n  \\f[r = \\mathcal{F}^{-1}\\\\{R\\\\}\\f]\n\n- Finally, it computes the peak location and computes a 5x5 weighted centroid around the peak to\n  achieve sub-pixel accuracy.\n  \\f[(\\Delta x, \\Delta y) = \\texttt{weightedCentroid} \\\\{\\arg \\max\\_{(x, y)}\\\\{r\\\\}\\\\}\\f]\n\n- If non-zero, the response parameter is computed as the sum of the elements of r within the 5x5\n  centroid around the peak location. It is normalized to a maximum of 1 (meaning there is a single\n  peak) and will be smaller when there are multiple peaks.\n\n@returns detected phase shift (sub-pixel) between the two arrays.\n@sa dft, getOptimalDFTSize, idft, mulSpectrums createHanningWindow\n\nPython prototype (for reference only):\n```python3\nphaseCorrelate(src1, src2[, window]) -> retval, response\n```","ref":"Evision.html#phaseCorrelate/2"},{"type":"function","title":"Evision.phaseCorrelate/3","doc":"The function is used to detect translational shifts that occur between two images.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  Source floating point array (CV_32FC1 or CV_64FC1)\n\n- **src2**: `Evision.Mat`.\n\n  Source floating point array (CV_32FC1 or CV_64FC1)\n\n##### Keyword Arguments\n- **window**: `Evision.Mat`.\n\n  Floating point array with windowing coefficients to reduce edge effects (optional).\n\n##### Return\n- **retval**: `Point2d`\n- **response**: `double*`.\n\n  Signal power within the 5x5 centroid around the peak, between 0 and 1 (optional).\n\nThe operation takes advantage of the Fourier shift theorem for detecting the translational shift in\nthe frequency domain. It can be used for fast image registration as well as motion estimation. For\nmore information please see  \nCalculates the cross-power spectrum of two supplied source arrays. The arrays are padded if needed\nwith getOptimalDFTSize.\nThe function performs the following equations:\n- First it applies a Hanning window (see  ) to each\n  image to remove possible edge effects. This window is cached until the array size changes to speed\n  up processing time.\n\n- Next it computes the forward DFTs of each source array:\n  \\f[\\mathbf{G}\\_a = \\mathcal{F}\\\\{src\\_1\\\\}, \\; \\mathbf{G}\\_b = \\mathcal{F}\\\\{src\\_2\\\\}\\f]\n  where \\f$\\mathcal{F}\\f$ is the forward DFT.\n\n- It then computes the cross-power spectrum of each frequency domain array:\n  \\f[R = \\frac{ \\mathbf{G}\\_a \\mathbf{G}\\_b^\\*}{|\\mathbf{G}\\_a \\mathbf{G}\\_b^\\*|}\\f]\n\n- Next the cross-correlation is converted back into the time domain via the inverse DFT:\n  \\f[r = \\mathcal{F}^{-1}\\\\{R\\\\}\\f]\n\n- Finally, it computes the peak location and computes a 5x5 weighted centroid around the peak to\n  achieve sub-pixel accuracy.\n  \\f[(\\Delta x, \\Delta y) = \\texttt{weightedCentroid} \\\\{\\arg \\max\\_{(x, y)}\\\\{r\\\\}\\\\}\\f]\n\n- If non-zero, the response parameter is computed as the sum of the elements of r within the 5x5\n  centroid around the peak location. It is normalized to a maximum of 1 (meaning there is a single\n  peak) and will be smaller when there are multiple peaks.\n\n@returns detected phase shift (sub-pixel) between the two arrays.\n@sa dft, getOptimalDFTSize, idft, mulSpectrums createHanningWindow\n\nPython prototype (for reference only):\n```python3\nphaseCorrelate(src1, src2[, window]) -> retval, response\n```","ref":"Evision.html#phaseCorrelate/3"},{"type":"function","title":"Evision.pointPolygonTest/1","doc":"","ref":"Evision.html#pointPolygonTest/1"},{"type":"function","title":"Evision.pointPolygonTest/3","doc":"Performs a point-in-contour test.\n\n##### Positional Arguments\n- **contour**: `Evision.Mat`.\n\n  Input contour.\n\n- **pt**: `Point2f`.\n\n  Point tested against the contour.\n\n- **measureDist**: `bool`.\n\n  If true, the function estimates the signed distance from the point to the\n  nearest contour edge. Otherwise, the function only checks if the point is inside a contour or not.\n\n##### Return\n- **retval**: `double`\n\nThe function determines whether the point is inside a contour, outside, or lies on an edge (or\ncoincides with a vertex). It returns positive (inside), negative (outside), or zero (on an edge)\nvalue, correspondingly. When measureDist=false , the return value is +1, -1, and 0, respectively.\nOtherwise, the return value is a signed distance between the point and the nearest contour edge.\nSee below a sample output of the function where each image pixel is tested against the contour:\n![sample output](pics/pointpolygon.png)\n\nPython prototype (for reference only):\n```python3\npointPolygonTest(contour, pt, measureDist) -> retval\n```","ref":"Evision.html#pointPolygonTest/3"},{"type":"function","title":"Evision.polarToCart/1","doc":"","ref":"Evision.html#polarToCart/1"},{"type":"function","title":"Evision.polarToCart/2","doc":"Calculates x and y coordinates of 2D vectors from their magnitude and angle.\n\n##### Positional Arguments\n- **magnitude**: `Evision.Mat`.\n\n  input floating-point array of magnitudes of 2D vectors;\n  it can be an empty matrix (=Mat()), in this case, the function assumes\n  that all the magnitudes are =1; if it is not empty, it must have the\n  same size and type as angle.\n\n- **angle**: `Evision.Mat`.\n\n  input floating-point array of angles of 2D vectors.\n\n##### Keyword Arguments\n- **angleInDegrees**: `bool`.\n\n  when true, the input angles are measured in\n  degrees, otherwise, they are measured in radians.\n\n##### Return\n- **x**: `Evision.Mat.t()`.\n\n  output array of x-coordinates of 2D vectors; it has the same\n  size and type as angle.\n\n- **y**: `Evision.Mat.t()`.\n\n  output array of y-coordinates of 2D vectors; it has the same\n  size and type as angle.\n\nThe function cv::polarToCart calculates the Cartesian coordinates of each 2D\nvector represented by the corresponding elements of magnitude and angle:\n\\f[\\begin{array}{l} \\texttt{x} (I) =  \\texttt{magnitude} (I) \\cos ( \\texttt{angle} (I)) \\\\\\\\ \\texttt{y} (I) =  \\texttt{magnitude} (I) \\sin ( \\texttt{angle} (I)) \\\\\\\\ \\end{array}\\f]\nThe relative accuracy of the estimated coordinates is about 1e-6.\n@sa cartToPolar, magnitude, phase, exp, log, pow, sqrt\n\nPython prototype (for reference only):\n```python3\npolarToCart(magnitude, angle[, x[, y[, angleInDegrees]]]) -> x, y\n```","ref":"Evision.html#polarToCart/2"},{"type":"function","title":"Evision.polarToCart/3","doc":"Calculates x and y coordinates of 2D vectors from their magnitude and angle.\n\n##### Positional Arguments\n- **magnitude**: `Evision.Mat`.\n\n  input floating-point array of magnitudes of 2D vectors;\n  it can be an empty matrix (=Mat()), in this case, the function assumes\n  that all the magnitudes are =1; if it is not empty, it must have the\n  same size and type as angle.\n\n- **angle**: `Evision.Mat`.\n\n  input floating-point array of angles of 2D vectors.\n\n##### Keyword Arguments\n- **angleInDegrees**: `bool`.\n\n  when true, the input angles are measured in\n  degrees, otherwise, they are measured in radians.\n\n##### Return\n- **x**: `Evision.Mat.t()`.\n\n  output array of x-coordinates of 2D vectors; it has the same\n  size and type as angle.\n\n- **y**: `Evision.Mat.t()`.\n\n  output array of y-coordinates of 2D vectors; it has the same\n  size and type as angle.\n\nThe function cv::polarToCart calculates the Cartesian coordinates of each 2D\nvector represented by the corresponding elements of magnitude and angle:\n\\f[\\begin{array}{l} \\texttt{x} (I) =  \\texttt{magnitude} (I) \\cos ( \\texttt{angle} (I)) \\\\\\\\ \\texttt{y} (I) =  \\texttt{magnitude} (I) \\sin ( \\texttt{angle} (I)) \\\\\\\\ \\end{array}\\f]\nThe relative accuracy of the estimated coordinates is about 1e-6.\n@sa cartToPolar, magnitude, phase, exp, log, pow, sqrt\n\nPython prototype (for reference only):\n```python3\npolarToCart(magnitude, angle[, x[, y[, angleInDegrees]]]) -> x, y\n```","ref":"Evision.html#polarToCart/3"},{"type":"function","title":"Evision.pollKey/0","doc":"Polls for a pressed key.\n##### Return\n- **retval**: `integer()`\n\nThe function pollKey polls for a key event without waiting. It returns the code of the pressed key\nor -1 if no key was pressed since the last invocation. To wait until a key was pressed, use #waitKey.\n**Note**: The functions #waitKey and #pollKey are the only methods in HighGUI that can fetch and handle\nGUI events, so one of them needs to be called periodically for normal event processing unless\nHighGUI is used within an environment that takes care of event processing.\n**Note**: The function only works if there is at least one HighGUI window created and the window is\nactive. If there are several HighGUI windows, any of them can be active.\n\nPython prototype (for reference only):\n```python3\npollKey() -> retval\n```","ref":"Evision.html#pollKey/0"},{"type":"function","title":"Evision.pollKey/1","doc":"","ref":"Evision.html#pollKey/1"},{"type":"function","title":"Evision.polylines/1","doc":"","ref":"Evision.html#polylines/1"},{"type":"function","title":"Evision.polylines/4","doc":"Draws several polygonal curves.\n\n##### Positional Arguments\n- **pts**: `[Evision.Mat]`.\n\n  Array of polygonal curves.\n\n- **isClosed**: `bool`.\n\n  Flag indicating whether the drawn polylines are closed or not. If they are closed,\n  the function draws a line from the last vertex of each curve to its first vertex.\n\n- **color**: `Evision.scalar()`.\n\n  Polyline color.\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n\n  Thickness of the polyline edges.\n\n- **lineType**: `integer()`.\n\n  Type of the line segments. See #LineTypes\n\n- **shift**: `integer()`.\n\n  Number of fractional bits in the vertex coordinates.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  Image.\n\nThe function cv::polylines draws one or more polygonal curves.\n\nPython prototype (for reference only):\n```python3\npolylines(img, pts, isClosed, color[, thickness[, lineType[, shift]]]) -> img\n```","ref":"Evision.html#polylines/4"},{"type":"function","title":"Evision.polylines/5","doc":"Draws several polygonal curves.\n\n##### Positional Arguments\n- **pts**: `[Evision.Mat]`.\n\n  Array of polygonal curves.\n\n- **isClosed**: `bool`.\n\n  Flag indicating whether the drawn polylines are closed or not. If they are closed,\n  the function draws a line from the last vertex of each curve to its first vertex.\n\n- **color**: `Evision.scalar()`.\n\n  Polyline color.\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n\n  Thickness of the polyline edges.\n\n- **lineType**: `integer()`.\n\n  Type of the line segments. See #LineTypes\n\n- **shift**: `integer()`.\n\n  Number of fractional bits in the vertex coordinates.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  Image.\n\nThe function cv::polylines draws one or more polygonal curves.\n\nPython prototype (for reference only):\n```python3\npolylines(img, pts, isClosed, color[, thickness[, lineType[, shift]]]) -> img\n```","ref":"Evision.html#polylines/5"},{"type":"function","title":"Evision.pow/1","doc":"","ref":"Evision.html#pow/1"},{"type":"function","title":"Evision.pow/2","doc":"Raises every array element to a power.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array.\n\n- **power**: `double`.\n\n  exponent of power.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src.\n\nThe function cv::pow raises every element of the input array to power :\n\\f[\\texttt{dst} (I) =  \\fork{\\texttt{src}(I)^{power}}{if \\(\\texttt{power}\\) is integer}{|\\texttt{src}(I)|^{power}}{otherwise}\\f]\nSo, for a non-integer power exponent, the absolute values of input array\nelements are used. However, it is possible to get true values for\nnegative values using some extra operations. In the example below,\ncomputing the 5th root of array src shows:\n```cpp\nMat mask = src < 0;\npow(src, 1./5, dst);\nsubtract(Scalar::all(0), dst, dst, mask);\n```\nFor some values of power, such as integer values, 0.5 and -0.5,\nspecialized faster algorithms are used.\nSpecial values (NaN, Inf) are not handled.\n@sa sqrt, exp, log, cartToPolar, polarToCart\n\nPython prototype (for reference only):\n```python3\npow(src, power[, dst]) -> dst\n```","ref":"Evision.html#pow/2"},{"type":"function","title":"Evision.pow/3","doc":"Raises every array element to a power.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array.\n\n- **power**: `double`.\n\n  exponent of power.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src.\n\nThe function cv::pow raises every element of the input array to power :\n\\f[\\texttt{dst} (I) =  \\fork{\\texttt{src}(I)^{power}}{if \\(\\texttt{power}\\) is integer}{|\\texttt{src}(I)|^{power}}{otherwise}\\f]\nSo, for a non-integer power exponent, the absolute values of input array\nelements are used. However, it is possible to get true values for\nnegative values using some extra operations. In the example below,\ncomputing the 5th root of array src shows:\n```cpp\nMat mask = src < 0;\npow(src, 1./5, dst);\nsubtract(Scalar::all(0), dst, dst, mask);\n```\nFor some values of power, such as integer values, 0.5 and -0.5,\nspecialized faster algorithms are used.\nSpecial values (NaN, Inf) are not handled.\n@sa sqrt, exp, log, cartToPolar, polarToCart\n\nPython prototype (for reference only):\n```python3\npow(src, power[, dst]) -> dst\n```","ref":"Evision.html#pow/3"},{"type":"function","title":"Evision.preCornerDetect/1","doc":"","ref":"Evision.html#preCornerDetect/1"},{"type":"function","title":"Evision.preCornerDetect/2","doc":"Calculates a feature map for corner detection.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source single-channel 8-bit of floating-point image.\n\n- **ksize**: `integer()`.\n\n  %Aperture size of the Sobel .\n\n##### Keyword Arguments\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method. See #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image that has the type CV_32F and the same size as src .\n\nThe function calculates the complex spatial derivative-based function of the source image\n\\f[\\texttt{dst} = (D\\_x  \\texttt{src} )^2  \\cdot D\\_{yy}  \\texttt{src} + (D\\_y  \\texttt{src} )^2  \\cdot D\\_{xx}  \\texttt{src} - 2 D\\_x  \\texttt{src} \\cdot D\\_y  \\texttt{src} \\cdot D\\_{xy}  \\texttt{src}\\f]\nwhere \\f$D\\_x\\f$,\\f$D\\_y\\f$ are the first image derivatives, \\f$D\\_{xx}\\f$,\\f$D\\_{yy}\\f$ are the second image\nderivatives, and \\f$D\\_{xy}\\f$ is the mixed derivative.\nThe corners can be found as local maximums of the functions, as shown below:\n```\nMat corners, dilated_corners;\npreCornerDetect(image, corners, 3);\n// dilation with 3x3 rectangular structuring element\ndilate(corners, dilated_corners, Mat(), 1);\nMat corner_mask = corners == dilated_corners;\n```\n\nPython prototype (for reference only):\n```python3\npreCornerDetect(src, ksize[, dst[, borderType]]) -> dst\n```","ref":"Evision.html#preCornerDetect/2"},{"type":"function","title":"Evision.preCornerDetect/3","doc":"Calculates a feature map for corner detection.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source single-channel 8-bit of floating-point image.\n\n- **ksize**: `integer()`.\n\n  %Aperture size of the Sobel .\n\n##### Keyword Arguments\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method. See #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image that has the type CV_32F and the same size as src .\n\nThe function calculates the complex spatial derivative-based function of the source image\n\\f[\\texttt{dst} = (D\\_x  \\texttt{src} )^2  \\cdot D\\_{yy}  \\texttt{src} + (D\\_y  \\texttt{src} )^2  \\cdot D\\_{xx}  \\texttt{src} - 2 D\\_x  \\texttt{src} \\cdot D\\_y  \\texttt{src} \\cdot D\\_{xy}  \\texttt{src}\\f]\nwhere \\f$D\\_x\\f$,\\f$D\\_y\\f$ are the first image derivatives, \\f$D\\_{xx}\\f$,\\f$D\\_{yy}\\f$ are the second image\nderivatives, and \\f$D\\_{xy}\\f$ is the mixed derivative.\nThe corners can be found as local maximums of the functions, as shown below:\n```\nMat corners, dilated_corners;\npreCornerDetect(image, corners, 3);\n// dilation with 3x3 rectangular structuring element\ndilate(corners, dilated_corners, Mat(), 1);\nMat corner_mask = corners == dilated_corners;\n```\n\nPython prototype (for reference only):\n```python3\npreCornerDetect(src, ksize[, dst[, borderType]]) -> dst\n```","ref":"Evision.html#preCornerDetect/3"},{"type":"function","title":"Evision.projectPoints/1","doc":"","ref":"Evision.html#projectPoints/1"},{"type":"function","title":"Evision.projectPoints/5","doc":"Projects 3D points to an image plane.\n\n##### Positional Arguments\n- **objectPoints**: `Evision.Mat`.\n\n  Array of object points expressed wrt. the world coordinate frame. A 3xN/Nx3\n  1-channel or 1xN/Nx1 3-channel (or vector\\  ), where N is the number of points in the view.\n\n- **rvec**: `Evision.Mat`.\n\n  The rotation vector (@ref Rodrigues) that, together with tvec, performs a change of\n  basis from world to camera coordinate system, see @ref calibrateCamera for details.\n\n- **tvec**: `Evision.Mat`.\n\n  The translation vector, see parameter description above.\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Camera intrinsic matrix \\f$\\cameramatrix{A}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$\\distcoeffs\\f$ . If the vector is empty, the zero distortion coefficients are assumed.\n\n##### Keyword Arguments\n- **aspectRatio**: `double`.\n\n  Optional \"fixed aspect ratio\" parameter. If the parameter is not 0, the\n  function assumes that the aspect ratio (\\f$f_x / f_y\\f$) is fixed and correspondingly adjusts the\n  jacobian matrix.\n\n##### Return\n- **imagePoints**: `Evision.Mat.t()`.\n\n  Output array of image points, 1xN/Nx1 2-channel, or\n  vector\\  .\n\n- **jacobian**: `Evision.Mat.t()`.\n\n  Optional output 2Nx(10+\\ ) jacobian matrix of derivatives of image\n  points with respect to components of the rotation vector, translation vector, focal lengths,\n  coordinates of the principal point and the distortion coefficients. In the old interface different\n  components of the jacobian are returned via different output parameters.\n\nThe function computes the 2D projections of 3D points to the image plane, given intrinsic and\nextrinsic camera parameters. Optionally, the function computes Jacobians -matrices of partial\nderivatives of image points coordinates (as functions of all the input parameters) with respect to\nthe particular parameters, intrinsic and/or extrinsic. The Jacobians are used during the global\noptimization in @ref calibrateCamera, @ref solvePnP, and @ref stereoCalibrate. The function itself\ncan also be used to compute a re-projection error, given the current intrinsic and extrinsic\nparameters.\n**Note**: By setting rvec = tvec = \\f$\\[0, 0, 0]\\f$, or by setting cameraMatrix to a 3x3 identity matrix,\nor by passing zero distortion coefficients, one can get various useful partial cases of the\nfunction. This means, one can compute the distorted coordinates for a sparse set of points or apply\na perspective transformation (and also compute the derivatives) in the ideal zero-distortion setup.\n\nPython prototype (for reference only):\n```python3\nprojectPoints(objectPoints, rvec, tvec, cameraMatrix, distCoeffs[, imagePoints[, jacobian[, aspectRatio]]]) -> imagePoints, jacobian\n```","ref":"Evision.html#projectPoints/5"},{"type":"function","title":"Evision.projectPoints/6","doc":"Projects 3D points to an image plane.\n\n##### Positional Arguments\n- **objectPoints**: `Evision.Mat`.\n\n  Array of object points expressed wrt. the world coordinate frame. A 3xN/Nx3\n  1-channel or 1xN/Nx1 3-channel (or vector\\  ), where N is the number of points in the view.\n\n- **rvec**: `Evision.Mat`.\n\n  The rotation vector (@ref Rodrigues) that, together with tvec, performs a change of\n  basis from world to camera coordinate system, see @ref calibrateCamera for details.\n\n- **tvec**: `Evision.Mat`.\n\n  The translation vector, see parameter description above.\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Camera intrinsic matrix \\f$\\cameramatrix{A}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$\\distcoeffs\\f$ . If the vector is empty, the zero distortion coefficients are assumed.\n\n##### Keyword Arguments\n- **aspectRatio**: `double`.\n\n  Optional \"fixed aspect ratio\" parameter. If the parameter is not 0, the\n  function assumes that the aspect ratio (\\f$f_x / f_y\\f$) is fixed and correspondingly adjusts the\n  jacobian matrix.\n\n##### Return\n- **imagePoints**: `Evision.Mat.t()`.\n\n  Output array of image points, 1xN/Nx1 2-channel, or\n  vector\\  .\n\n- **jacobian**: `Evision.Mat.t()`.\n\n  Optional output 2Nx(10+\\ ) jacobian matrix of derivatives of image\n  points with respect to components of the rotation vector, translation vector, focal lengths,\n  coordinates of the principal point and the distortion coefficients. In the old interface different\n  components of the jacobian are returned via different output parameters.\n\nThe function computes the 2D projections of 3D points to the image plane, given intrinsic and\nextrinsic camera parameters. Optionally, the function computes Jacobians -matrices of partial\nderivatives of image points coordinates (as functions of all the input parameters) with respect to\nthe particular parameters, intrinsic and/or extrinsic. The Jacobians are used during the global\noptimization in @ref calibrateCamera, @ref solvePnP, and @ref stereoCalibrate. The function itself\ncan also be used to compute a re-projection error, given the current intrinsic and extrinsic\nparameters.\n**Note**: By setting rvec = tvec = \\f$\\[0, 0, 0]\\f$, or by setting cameraMatrix to a 3x3 identity matrix,\nor by passing zero distortion coefficients, one can get various useful partial cases of the\nfunction. This means, one can compute the distorted coordinates for a sparse set of points or apply\na perspective transformation (and also compute the derivatives) in the ideal zero-distortion setup.\n\nPython prototype (for reference only):\n```python3\nprojectPoints(objectPoints, rvec, tvec, cameraMatrix, distCoeffs[, imagePoints[, jacobian[, aspectRatio]]]) -> imagePoints, jacobian\n```","ref":"Evision.html#projectPoints/6"},{"type":"function","title":"Evision.psnr/1","doc":"","ref":"Evision.html#psnr/1"},{"type":"function","title":"Evision.psnr/2","doc":"Computes the Peak Signal-to-Noise Ratio (PSNR) image quality metric.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array.\n\n- **src2**: `Evision.Mat`.\n\n  second input array of the same size as src1.\n\n##### Keyword Arguments\n- **r**: `double`.\n\n  the maximum pixel value (255 by default)\n\n##### Return\n- **retval**: `double`\n\nThis function calculates the Peak Signal-to-Noise Ratio (PSNR) image quality metric in decibels (dB),\nbetween two input arrays src1 and src2. The arrays must have the same type.\nThe PSNR is calculated as follows:\n\\f[\n\\texttt{PSNR} = 10 \\cdot \\log\\_{10}{\\left( \\frac{R^2}{MSE} \\right) }\n\\f]\nwhere R is the maximum integer value of depth (e.g. 255 in the case of CV_8U data)\nand MSE is the mean squared error between the two arrays.\n\nPython prototype (for reference only):\n```python3\nPSNR(src1, src2[, R]) -> retval\n```","ref":"Evision.html#psnr/2"},{"type":"function","title":"Evision.psnr/3","doc":"Computes the Peak Signal-to-Noise Ratio (PSNR) image quality metric.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array.\n\n- **src2**: `Evision.Mat`.\n\n  second input array of the same size as src1.\n\n##### Keyword Arguments\n- **r**: `double`.\n\n  the maximum pixel value (255 by default)\n\n##### Return\n- **retval**: `double`\n\nThis function calculates the Peak Signal-to-Noise Ratio (PSNR) image quality metric in decibels (dB),\nbetween two input arrays src1 and src2. The arrays must have the same type.\nThe PSNR is calculated as follows:\n\\f[\n\\texttt{PSNR} = 10 \\cdot \\log\\_{10}{\\left( \\frac{R^2}{MSE} \\right) }\n\\f]\nwhere R is the maximum integer value of depth (e.g. 255 in the case of CV_8U data)\nand MSE is the mean squared error between the two arrays.\n\nPython prototype (for reference only):\n```python3\nPSNR(src1, src2[, R]) -> retval\n```","ref":"Evision.html#psnr/3"},{"type":"function","title":"Evision.putText/1","doc":"","ref":"Evision.html#putText/1"},{"type":"function","title":"Evision.putText/6","doc":"Draws a text string.\n\n##### Positional Arguments\n- **text**: `String`.\n\n  Text string to be drawn.\n\n- **org**: `Point`.\n\n  Bottom-left corner of the text string in the image.\n\n- **fontFace**: `integer()`.\n\n  Font type, see #HersheyFonts.\n\n- **fontScale**: `double`.\n\n  Font scale factor that is multiplied by the font-specific base size.\n\n- **color**: `Evision.scalar()`.\n\n  Text color.\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n\n  Thickness of the lines used to draw a text.\n\n- **lineType**: `integer()`.\n\n  Line type. See #LineTypes\n\n- **bottomLeftOrigin**: `bool`.\n\n  When true, the image data origin is at the bottom-left corner. Otherwise,\n  it is at the top-left corner.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  Image.\n\nThe function cv::putText renders the specified text string in the image. Symbols that cannot be rendered\nusing the specified font are replaced by question marks. See #getTextSize for a text rendering code\nexample.\n\nPython prototype (for reference only):\n```python3\nputText(img, text, org, fontFace, fontScale, color[, thickness[, lineType[, bottomLeftOrigin]]]) -> img\n```","ref":"Evision.html#putText/6"},{"type":"function","title":"Evision.putText/7","doc":"Draws a text string.\n\n##### Positional Arguments\n- **text**: `String`.\n\n  Text string to be drawn.\n\n- **org**: `Point`.\n\n  Bottom-left corner of the text string in the image.\n\n- **fontFace**: `integer()`.\n\n  Font type, see #HersheyFonts.\n\n- **fontScale**: `double`.\n\n  Font scale factor that is multiplied by the font-specific base size.\n\n- **color**: `Evision.scalar()`.\n\n  Text color.\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n\n  Thickness of the lines used to draw a text.\n\n- **lineType**: `integer()`.\n\n  Line type. See #LineTypes\n\n- **bottomLeftOrigin**: `bool`.\n\n  When true, the image data origin is at the bottom-left corner. Otherwise,\n  it is at the top-left corner.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  Image.\n\nThe function cv::putText renders the specified text string in the image. Symbols that cannot be rendered\nusing the specified font are replaced by question marks. See #getTextSize for a text rendering code\nexample.\n\nPython prototype (for reference only):\n```python3\nputText(img, text, org, fontFace, fontScale, color[, thickness[, lineType[, bottomLeftOrigin]]]) -> img\n```","ref":"Evision.html#putText/7"},{"type":"function","title":"Evision.pyrDown/1","doc":"Blurs an image and downsamples it.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image.\n\n##### Keyword Arguments\n- **dstsize**: `Size`.\n\n  size of the output image.\n\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method, see #BorderTypes (#BORDER_CONSTANT isn't supported)\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image; it has the specified size and the same type as src.\n\nBy default, size of the output image is computed as `Size((src.cols+1)/2, (src.rows+1)/2)`, but in\nany case, the following conditions should be satisfied:\n\\f[\\begin{array}{l} | \\texttt{dstsize.width} \\*2-src.cols| \\leq 2 \\\\\\\\ | \\texttt{dstsize.height} \\*2-src.rows| \\leq 2 \\end{array}\\f]\nThe function performs the downsampling step of the Gaussian pyramid construction. First, it\nconvolves the source image with the kernel:\n\\f[\\frac{1}{256} \\begin{bmatrix} 1 & 4 & 6 & 4 & 1  \\\\\\\\ 4 & 16 & 24 & 16 & 4  \\\\\\\\ 6 & 24 & 36 & 24 & 6  \\\\\\\\ 4 & 16 & 24 & 16 & 4  \\\\\\\\ 1 & 4 & 6 & 4 & 1 \\end{bmatrix}\\f]\nThen, it downsamples the image by rejecting even rows and columns.\n\nPython prototype (for reference only):\n```python3\npyrDown(src[, dst[, dstsize[, borderType]]]) -> dst\n```","ref":"Evision.html#pyrDown/1"},{"type":"function","title":"Evision.pyrDown/2","doc":"Blurs an image and downsamples it.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image.\n\n##### Keyword Arguments\n- **dstsize**: `Size`.\n\n  size of the output image.\n\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method, see #BorderTypes (#BORDER_CONSTANT isn't supported)\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image; it has the specified size and the same type as src.\n\nBy default, size of the output image is computed as `Size((src.cols+1)/2, (src.rows+1)/2)`, but in\nany case, the following conditions should be satisfied:\n\\f[\\begin{array}{l} | \\texttt{dstsize.width} \\*2-src.cols| \\leq 2 \\\\\\\\ | \\texttt{dstsize.height} \\*2-src.rows| \\leq 2 \\end{array}\\f]\nThe function performs the downsampling step of the Gaussian pyramid construction. First, it\nconvolves the source image with the kernel:\n\\f[\\frac{1}{256} \\begin{bmatrix} 1 & 4 & 6 & 4 & 1  \\\\\\\\ 4 & 16 & 24 & 16 & 4  \\\\\\\\ 6 & 24 & 36 & 24 & 6  \\\\\\\\ 4 & 16 & 24 & 16 & 4  \\\\\\\\ 1 & 4 & 6 & 4 & 1 \\end{bmatrix}\\f]\nThen, it downsamples the image by rejecting even rows and columns.\n\nPython prototype (for reference only):\n```python3\npyrDown(src[, dst[, dstsize[, borderType]]]) -> dst\n```","ref":"Evision.html#pyrDown/2"},{"type":"function","title":"Evision.pyrMeanShiftFiltering/1","doc":"","ref":"Evision.html#pyrMeanShiftFiltering/1"},{"type":"function","title":"Evision.pyrMeanShiftFiltering/3","doc":"Performs initial step of meanshift segmentation of an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  The source 8-bit, 3-channel image.\n\n- **sp**: `double`.\n\n  The spatial window radius.\n\n- **sr**: `double`.\n\n  The color window radius.\n\n##### Keyword Arguments\n- **maxLevel**: `integer()`.\n\n  Maximum level of the pyramid for the segmentation.\n\n- **termcrit**: `TermCriteria`.\n\n  Termination criteria: when to stop meanshift iterations.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  The destination image of the same format and the same size as the source.\n\nThe function implements the filtering stage of meanshift segmentation, that is, the output of the\nfunction is the filtered \"posterized\" image with color gradients and fine-grain texture flattened.\nAt every pixel (X,Y) of the input image (or down-sized input image, see below) the function executes\nmeanshift iterations, that is, the pixel (X,Y) neighborhood in the joint space-color hyperspace is\nconsidered:\n\\f[(x,y): X- \\texttt{sp} \\le x  \\le X+ \\texttt{sp} , Y- \\texttt{sp} \\le y  \\le Y+ \\texttt{sp} , ||(R,G,B)-(r,g,b)||   \\le \\texttt{sr}\\f]\nwhere (R,G,B) and (r,g,b) are the vectors of color components at (X,Y) and (x,y), respectively\n(though, the algorithm does not depend on the color space used, so any 3-component color space can\nbe used instead). Over the neighborhood the average spatial value (X',Y') and average color vector\n(R',G',B') are found and they act as the neighborhood center on the next iteration:\n\\f[(X,Y)~(X',Y'), (R,G,B)~(R',G',B').\\f]\nAfter the iterations over, the color components of the initial pixel (that is, the pixel from where\nthe iterations started) are set to the final value (average color at the last iteration):\n\\f[I(X,Y) <- (R\\*,G\\*,B\\*)\\f]\nWhen maxLevel \\> 0, the gaussian pyramid of maxLevel+1 levels is built, and the above procedure is\nrun on the smallest layer first. After that, the results are propagated to the larger layer and the\niterations are run again only on those pixels where the layer colors differ by more than sr from the\nlower-resolution layer of the pyramid. That makes boundaries of color regions sharper. Note that the\nresults will be actually different from the ones obtained by running the meanshift procedure on the\nwhole original image (i.e. when maxLevel==0).\n\nPython prototype (for reference only):\n```python3\npyrMeanShiftFiltering(src, sp, sr[, dst[, maxLevel[, termcrit]]]) -> dst\n```","ref":"Evision.html#pyrMeanShiftFiltering/3"},{"type":"function","title":"Evision.pyrMeanShiftFiltering/4","doc":"Performs initial step of meanshift segmentation of an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  The source 8-bit, 3-channel image.\n\n- **sp**: `double`.\n\n  The spatial window radius.\n\n- **sr**: `double`.\n\n  The color window radius.\n\n##### Keyword Arguments\n- **maxLevel**: `integer()`.\n\n  Maximum level of the pyramid for the segmentation.\n\n- **termcrit**: `TermCriteria`.\n\n  Termination criteria: when to stop meanshift iterations.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  The destination image of the same format and the same size as the source.\n\nThe function implements the filtering stage of meanshift segmentation, that is, the output of the\nfunction is the filtered \"posterized\" image with color gradients and fine-grain texture flattened.\nAt every pixel (X,Y) of the input image (or down-sized input image, see below) the function executes\nmeanshift iterations, that is, the pixel (X,Y) neighborhood in the joint space-color hyperspace is\nconsidered:\n\\f[(x,y): X- \\texttt{sp} \\le x  \\le X+ \\texttt{sp} , Y- \\texttt{sp} \\le y  \\le Y+ \\texttt{sp} , ||(R,G,B)-(r,g,b)||   \\le \\texttt{sr}\\f]\nwhere (R,G,B) and (r,g,b) are the vectors of color components at (X,Y) and (x,y), respectively\n(though, the algorithm does not depend on the color space used, so any 3-component color space can\nbe used instead). Over the neighborhood the average spatial value (X',Y') and average color vector\n(R',G',B') are found and they act as the neighborhood center on the next iteration:\n\\f[(X,Y)~(X',Y'), (R,G,B)~(R',G',B').\\f]\nAfter the iterations over, the color components of the initial pixel (that is, the pixel from where\nthe iterations started) are set to the final value (average color at the last iteration):\n\\f[I(X,Y) <- (R\\*,G\\*,B\\*)\\f]\nWhen maxLevel \\> 0, the gaussian pyramid of maxLevel+1 levels is built, and the above procedure is\nrun on the smallest layer first. After that, the results are propagated to the larger layer and the\niterations are run again only on those pixels where the layer colors differ by more than sr from the\nlower-resolution layer of the pyramid. That makes boundaries of color regions sharper. Note that the\nresults will be actually different from the ones obtained by running the meanshift procedure on the\nwhole original image (i.e. when maxLevel==0).\n\nPython prototype (for reference only):\n```python3\npyrMeanShiftFiltering(src, sp, sr[, dst[, maxLevel[, termcrit]]]) -> dst\n```","ref":"Evision.html#pyrMeanShiftFiltering/4"},{"type":"function","title":"Evision.pyrUp/1","doc":"Upsamples an image and then blurs it.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image.\n\n##### Keyword Arguments\n- **dstsize**: `Size`.\n\n  size of the output image.\n\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method, see #BorderTypes (only #BORDER_DEFAULT is supported)\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image. It has the specified size and the same type as src .\n\nBy default, size of the output image is computed as `Size(src.cols\\*2, (src.rows\\*2)`, but in any\ncase, the following conditions should be satisfied:\n\\f[\\begin{array}{l} | \\texttt{dstsize.width} -src.cols\\*2| \\leq  ( \\texttt{dstsize.width}   \\mod  2)  \\\\\\\\ | \\texttt{dstsize.height} -src.rows\\*2| \\leq  ( \\texttt{dstsize.height}   \\mod  2) \\end{array}\\f]\nThe function performs the upsampling step of the Gaussian pyramid construction, though it can\nactually be used to construct the Laplacian pyramid. First, it upsamples the source image by\ninjecting even zero rows and columns and then convolves the result with the same kernel as in\npyrDown multiplied by 4.\n\nPython prototype (for reference only):\n```python3\npyrUp(src[, dst[, dstsize[, borderType]]]) -> dst\n```","ref":"Evision.html#pyrUp/1"},{"type":"function","title":"Evision.pyrUp/2","doc":"Upsamples an image and then blurs it.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image.\n\n##### Keyword Arguments\n- **dstsize**: `Size`.\n\n  size of the output image.\n\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method, see #BorderTypes (only #BORDER_DEFAULT is supported)\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image. It has the specified size and the same type as src .\n\nBy default, size of the output image is computed as `Size(src.cols\\*2, (src.rows\\*2)`, but in any\ncase, the following conditions should be satisfied:\n\\f[\\begin{array}{l} | \\texttt{dstsize.width} -src.cols\\*2| \\leq  ( \\texttt{dstsize.width}   \\mod  2)  \\\\\\\\ | \\texttt{dstsize.height} -src.rows\\*2| \\leq  ( \\texttt{dstsize.height}   \\mod  2) \\end{array}\\f]\nThe function performs the upsampling step of the Gaussian pyramid construction, though it can\nactually be used to construct the Laplacian pyramid. First, it upsamples the source image by\ninjecting even zero rows and columns and then convolves the result with the same kernel as in\npyrDown multiplied by 4.\n\nPython prototype (for reference only):\n```python3\npyrUp(src[, dst[, dstsize[, borderType]]]) -> dst\n```","ref":"Evision.html#pyrUp/2"},{"type":"function","title":"Evision.randn/1","doc":"","ref":"Evision.html#randn/1"},{"type":"function","title":"Evision.randn/3","doc":"Fills the array with normally distributed random numbers.\n\n##### Positional Arguments\n- **mean**: `Evision.Mat`.\n\n  mean value (expectation) of the generated random numbers.\n\n- **stddev**: `Evision.Mat`.\n\n  standard deviation of the generated random numbers; it can be either a vector (in\n  which case a diagonal standard deviation matrix is assumed) or a square matrix.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of random numbers; the array must be pre-allocated and have 1 to 4 channels.\n\nThe function cv::randn fills the matrix dst with normally distributed random numbers with the specified\nmean vector and the standard deviation matrix. The generated random numbers are clipped to fit the\nvalue range of the output array data type.\n@sa RNG, randu\n\nPython prototype (for reference only):\n```python3\nrandn(dst, mean, stddev) -> dst\n```","ref":"Evision.html#randn/3"},{"type":"function","title":"Evision.randShuffle/1","doc":"Shuffles the array elements randomly.\n##### Keyword Arguments\n- **iterFactor**: `double`.\n\n  scale factor that determines the number of random swap operations (see the details\n  below).\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  input/output numerical 1D array.\n\nThe function cv::randShuffle shuffles the specified 1D array by randomly choosing pairs of elements and\nswapping them. The number of such swap operations will be dst.rows\\*dst.cols\\*iterFactor .\n@sa RNG, sort\n\nPython prototype (for reference only):\n```python3\nrandShuffle(dst[, iterFactor]) -> dst\n```","ref":"Evision.html#randShuffle/1"},{"type":"function","title":"Evision.randShuffle/2","doc":"Shuffles the array elements randomly.\n##### Keyword Arguments\n- **iterFactor**: `double`.\n\n  scale factor that determines the number of random swap operations (see the details\n  below).\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  input/output numerical 1D array.\n\nThe function cv::randShuffle shuffles the specified 1D array by randomly choosing pairs of elements and\nswapping them. The number of such swap operations will be dst.rows\\*dst.cols\\*iterFactor .\n@sa RNG, sort\n\nPython prototype (for reference only):\n```python3\nrandShuffle(dst[, iterFactor]) -> dst\n```","ref":"Evision.html#randShuffle/2"},{"type":"function","title":"Evision.randu/1","doc":"","ref":"Evision.html#randu/1"},{"type":"function","title":"Evision.randu/3","doc":"Generates a single uniformly-distributed random number or an array of random numbers.\n\n##### Positional Arguments\n- **low**: `Evision.Mat`.\n\n  inclusive lower boundary of the generated random numbers.\n\n- **high**: `Evision.Mat`.\n\n  exclusive upper boundary of the generated random numbers.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of random numbers; the array must be pre-allocated.\n\nNon-template variant of the function fills the matrix dst with uniformly-distributed\nrandom numbers from the specified range:\n\\f[\\texttt{low} \\_c  \\leq \\texttt{dst} (I)\\_c <  \\texttt{high} \\_c\\f]\n@sa RNG, randn, theRNG\n\nPython prototype (for reference only):\n```python3\nrandu(dst, low, high) -> dst\n```","ref":"Evision.html#randu/3"},{"type":"function","title":"Evision.readOpticalFlow/1","doc":"Read a .flo file\n\n##### Positional Arguments\n- **path**: `String`.\n\n  Path to the file to be loaded\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nThe function readOpticalFlow loads a flow field from a file and returns it as a single matrix.\nResulting Mat has a type CV_32FC2 - floating-point, 2-channel. First channel corresponds to the\nflow in the horizontal direction (u), second - vertical (v).\n\nPython prototype (for reference only):\n```python3\nreadOpticalFlow(path) -> retval\n```","ref":"Evision.html#readOpticalFlow/1"},{"type":"function","title":"Evision.recoverPose/1","doc":"","ref":"Evision.html#recoverPose/1"},{"type":"function","title":"Evision.recoverPose/3","doc":"recoverPose\n\n##### Positional Arguments\n- **e**: `Evision.Mat`.\n\n  The input essential matrix.\n\n- **points1**: `Evision.Mat`.\n\n  Array of N 2D points from the first image. The point coordinates should be\n  floating-point (single or double precision).\n\n- **points2**: `Evision.Mat`.\n\n  Array of the second image points of the same size and format as points1 .\n\n##### Keyword Arguments\n- **focal**: `double`.\n\n  Focal length of the camera. Note that this function assumes that points1 and points2\n  are feature points from cameras with same focal length and principal point.\n\n- **pp**: `Point2d`.\n\n  principal point of the camera.\n\n##### Return\n- **retval**: `integer()`\n- **r**: `Evision.Mat.t()`.\n\n  Output rotation matrix. Together with the translation vector, this matrix makes up a tuple\n  that performs a change of basis from the first camera's coordinate system to the second camera's\n  coordinate system. Note that, in general, t can not be used for this tuple, see the parameter\n  description below.\n\n- **t**: `Evision.Mat.t()`.\n\n  Output translation vector. This vector is obtained by @ref decomposeEssentialMat and\n  therefore is only known up to scale, i.e. t is the direction of the translation vector and has unit\n  length.\n\n- **mask**: `Evision.Mat.t()`.\n\n  Input/output mask for inliers in points1 and points2. If it is not empty, then it marks\n  inliers in points1 and points2 for the given essential matrix E. Only these inliers will be used to\n  recover pose. In the output mask only inliers which pass the chirality check.\n\nHas overloading in C++\n\nThis function differs from the one above that it computes camera intrinsic matrix from focal length and\nprincipal point:\n\\f[A =\n\\begin{bmatrix}\nf & 0 & x\\_{pp}  \\\\\\\\\n0 & f & y\\_{pp}  \\\\\\\\\n0 & 0 & 1\n\\end{bmatrix}\\f]\n\nPython prototype (for reference only):\n```python3\nrecoverPose(E, points1, points2[, R[, t[, focal[, pp[, mask]]]]]) -> retval, R, t, mask\n```","ref":"Evision.html#recoverPose/3"},{"type":"function","title":"Evision.recoverPose/4","doc":"#### Variant 1:\nRecovers the relative camera rotation and the translation from an estimated essential\nmatrix and the corresponding points in two images, using chirality check. Returns the number of\ninliers that pass the check.\n\n##### Positional Arguments\n- **e**: `Evision.Mat`.\n\n  The input essential matrix.\n\n- **points1**: `Evision.Mat`.\n\n  Array of N 2D points from the first image. The point coordinates should be\n  floating-point (single or double precision).\n\n- **points2**: `Evision.Mat`.\n\n  Array of the second image points of the same size and format as points1 .\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Camera intrinsic matrix \\f$\\cameramatrix{A}\\f$ .\n  Note that this function assumes that points1 and points2 are feature points from cameras with the\n  same camera intrinsic matrix.\n\n##### Return\n- **retval**: `integer()`\n- **r**: `Evision.Mat.t()`.\n\n  Output rotation matrix. Together with the translation vector, this matrix makes up a tuple\n  that performs a change of basis from the first camera's coordinate system to the second camera's\n  coordinate system. Note that, in general, t can not be used for this tuple, see the parameter\n  described below.\n\n- **t**: `Evision.Mat.t()`.\n\n  Output translation vector. This vector is obtained by @ref decomposeEssentialMat and\n  therefore is only known up to scale, i.e. t is the direction of the translation vector and has unit\n  length.\n\n- **mask**: `Evision.Mat.t()`.\n\n  Input/output mask for inliers in points1 and points2. If it is not empty, then it marks\n  inliers in points1 and points2 for the given essential matrix E. Only these inliers will be used to\n  recover pose. In the output mask only inliers which pass the chirality check.\n\nThis function decomposes an essential matrix using @ref decomposeEssentialMat and then verifies\npossible pose hypotheses by doing chirality check. The chirality check means that the\ntriangulated 3D points should have positive depth. Some details can be found in @cite Nister03.\nThis function can be used to process the output E and mask from @ref findEssentialMat. In this\nscenario, points1 and points2 are the same input for #findEssentialMat :\n```\n// Example. Estimation of fundamental matrix using the RANSAC algorithm\nint point_count = 100;\nvector  points1(point_count);\nvector  points2(point_count);\n// initialize the points here ...\nfor( int i = 0; i   retval, R, t, mask\n```\n#### Variant 2:\nrecoverPose\n\n##### Positional Arguments\n- **e**: `Evision.Mat`.\n\n  The input essential matrix.\n\n- **points1**: `Evision.Mat`.\n\n  Array of N 2D points from the first image. The point coordinates should be\n  floating-point (single or double precision).\n\n- **points2**: `Evision.Mat`.\n\n  Array of the second image points of the same size and format as points1 .\n\n##### Keyword Arguments\n- **focal**: `double`.\n\n  Focal length of the camera. Note that this function assumes that points1 and points2\n  are feature points from cameras with same focal length and principal point.\n\n- **pp**: `Point2d`.\n\n  principal point of the camera.\n\n##### Return\n- **retval**: `integer()`\n- **r**: `Evision.Mat.t()`.\n\n  Output rotation matrix. Together with the translation vector, this matrix makes up a tuple\n  that performs a change of basis from the first camera's coordinate system to the second camera's\n  coordinate system. Note that, in general, t can not be used for this tuple, see the parameter\n  description below.\n\n- **t**: `Evision.Mat.t()`.\n\n  Output translation vector. This vector is obtained by @ref decomposeEssentialMat and\n  therefore is only known up to scale, i.e. t is the direction of the translation vector and has unit\n  length.\n\n- **mask**: `Evision.Mat.t()`.\n\n  Input/output mask for inliers in points1 and points2. If it is not empty, then it marks\n  inliers in points1 and points2 for the given essential matrix E. Only these inliers will be used to\n  recover pose. In the output mask only inliers which pass the chirality check.\n\nHas overloading in C++\n\nThis function differs from the one above that it computes camera intrinsic matrix from focal length and\nprincipal point:\n\\f[A =\n\\begin{bmatrix}\nf & 0 & x\\_{pp}  \\\\\\\\\n0 & f & y\\_{pp}  \\\\\\\\\n0 & 0 & 1\n\\end{bmatrix}\\f]\n\nPython prototype (for reference only):\n```python3\nrecoverPose(E, points1, points2[, R[, t[, focal[, pp[, mask]]]]]) -> retval, R, t, mask\n```","ref":"Evision.html#recoverPose/4"},{"type":"function","title":"Evision.recoverPose/5","doc":"#### Variant 1:\nrecoverPose\n\n##### Positional Arguments\n- **e**: `Evision.Mat`.\n\n  The input essential matrix.\n\n- **points1**: `Evision.Mat`.\n\n  Array of N 2D points from the first image. The point coordinates should be\n  floating-point (single or double precision).\n\n- **points2**: `Evision.Mat`.\n\n  Array of the second image points of the same size and format as points1.\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Camera intrinsic matrix \\f$\\cameramatrix{A}\\f$ .\n  Note that this function assumes that points1 and points2 are feature points from cameras with the\n  same camera intrinsic matrix.\n\n- **distanceThresh**: `double`.\n\n  threshold distance which is used to filter out far away points (i.e. infinite\n  points).\n\n##### Return\n- **retval**: `integer()`\n- **r**: `Evision.Mat.t()`.\n\n  Output rotation matrix. Together with the translation vector, this matrix makes up a tuple\n  that performs a change of basis from the first camera's coordinate system to the second camera's\n  coordinate system. Note that, in general, t can not be used for this tuple, see the parameter\n  description below.\n\n- **t**: `Evision.Mat.t()`.\n\n  Output translation vector. This vector is obtained by @ref decomposeEssentialMat and\n  therefore is only known up to scale, i.e. t is the direction of the translation vector and has unit\n  length.\n\n- **mask**: `Evision.Mat.t()`.\n\n  Input/output mask for inliers in points1 and points2. If it is not empty, then it marks\n  inliers in points1 and points2 for the given essential matrix E. Only these inliers will be used to\n  recover pose. In the output mask only inliers which pass the chirality check.\n\n- **triangulatedPoints**: `Evision.Mat.t()`.\n\n  3D points which were reconstructed by triangulation.\n\nHas overloading in C++\n\nThis function differs from the one above that it outputs the triangulated 3D point that are used for\nthe chirality check.\n\nPython prototype (for reference only):\n```python3\nrecoverPose(E, points1, points2, cameraMatrix, distanceThresh[, R[, t[, mask[, triangulatedPoints]]]]) -> retval, R, t, mask, triangulatedPoints\n```\n#### Variant 2:\nRecovers the relative camera rotation and the translation from an estimated essential\nmatrix and the corresponding points in two images, using chirality check. Returns the number of\ninliers that pass the check.\n\n##### Positional Arguments\n- **e**: `Evision.Mat`.\n\n  The input essential matrix.\n\n- **points1**: `Evision.Mat`.\n\n  Array of N 2D points from the first image. The point coordinates should be\n  floating-point (single or double precision).\n\n- **points2**: `Evision.Mat`.\n\n  Array of the second image points of the same size and format as points1 .\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Camera intrinsic matrix \\f$\\cameramatrix{A}\\f$ .\n  Note that this function assumes that points1 and points2 are feature points from cameras with the\n  same camera intrinsic matrix.\n\n##### Return\n- **retval**: `integer()`\n- **r**: `Evision.Mat.t()`.\n\n  Output rotation matrix. Together with the translation vector, this matrix makes up a tuple\n  that performs a change of basis from the first camera's coordinate system to the second camera's\n  coordinate system. Note that, in general, t can not be used for this tuple, see the parameter\n  described below.\n\n- **t**: `Evision.Mat.t()`.\n\n  Output translation vector. This vector is obtained by @ref decomposeEssentialMat and\n  therefore is only known up to scale, i.e. t is the direction of the translation vector and has unit\n  length.\n\n- **mask**: `Evision.Mat.t()`.\n\n  Input/output mask for inliers in points1 and points2. If it is not empty, then it marks\n  inliers in points1 and points2 for the given essential matrix E. Only these inliers will be used to\n  recover pose. In the output mask only inliers which pass the chirality check.\n\nThis function decomposes an essential matrix using @ref decomposeEssentialMat and then verifies\npossible pose hypotheses by doing chirality check. The chirality check means that the\ntriangulated 3D points should have positive depth. Some details can be found in @cite Nister03.\nThis function can be used to process the output E and mask from @ref findEssentialMat. In this\nscenario, points1 and points2 are the same input for #findEssentialMat :\n```\n// Example. Estimation of fundamental matrix using the RANSAC algorithm\nint point_count = 100;\nvector  points1(point_count);\nvector  points2(point_count);\n// initialize the points here ...\nfor( int i = 0; i   retval, R, t, mask\n```","ref":"Evision.html#recoverPose/5"},{"type":"function","title":"Evision.recoverPose/6","doc":"#### Variant 1:\nRecovers the relative camera rotation and the translation from corresponding points in two images from two different cameras, using cheirality check. Returns the number of\ninliers that pass the check.\n\n##### Positional Arguments\n- **points1**: `Evision.Mat`.\n\n  Array of N 2D points from the first image. The point coordinates should be\n  floating-point (single or double precision).\n\n- **points2**: `Evision.Mat`.\n\n  Array of the second image points of the same size and format as points1 .\n\n- **cameraMatrix1**: `Evision.Mat`.\n\n  Input/output camera matrix for the first camera, the same as in\n\n- **distCoeffs1**: `Evision.Mat`.\n\n  Input/output vector of distortion coefficients, the same as in\n\n- **cameraMatrix2**: `Evision.Mat`.\n\n  Input/output camera matrix for the first camera, the same as in\n\n- **distCoeffs2**: `Evision.Mat`.\n\n  Input/output vector of distortion coefficients, the same as in\n\n##### Keyword Arguments\n- **method**: `integer()`.\n\n  Method for computing an essential matrix.\n  - @ref RANSAC for the RANSAC algorithm.\n  - @ref LMEDS for the LMedS algorithm.\n\n- **prob**: `double`.\n\n  Parameter used for the RANSAC or LMedS methods only. It specifies a desirable level of\n  confidence (probability) that the estimated matrix is correct.\n\n- **threshold**: `double`.\n\n  Parameter used for RANSAC. It is the maximum distance from a point to an epipolar\n  line in pixels, beyond which the point is considered an outlier and is not used for computing the\n  final fundamental matrix. It can be set to something like 1-3, depending on the accuracy of the\n  point localization, image resolution, and the image noise.\n\n##### Return\n- **retval**: `integer()`\n- **e**: `Evision.Mat.t()`.\n\n  The output essential matrix.\n\n- **r**: `Evision.Mat.t()`.\n\n  Output rotation matrix. Together with the translation vector, this matrix makes up a tuple\n  that performs a change of basis from the first camera's coordinate system to the second camera's\n  coordinate system. Note that, in general, t can not be used for this tuple, see the parameter\n  described below.\n\n- **t**: `Evision.Mat.t()`.\n\n  Output translation vector. This vector is obtained by @ref decomposeEssentialMat and\n  therefore is only known up to scale, i.e. t is the direction of the translation vector and has unit\n  length.\n\n- **mask**: `Evision.Mat.t()`.\n\n  Input/output mask for inliers in points1 and points2. If it is not empty, then it marks\n  inliers in points1 and points2 for then given essential matrix E. Only these inliers will be used to\n  recover pose. In the output mask only inliers which pass the cheirality check.\n\n@ref calibrateCamera. Furthermore, for the stereo case, additional flags may be used, see below.\n@ref calibrateCamera.\n@ref calibrateCamera. Furthermore, for the stereo case, additional flags may be used, see below.\n@ref calibrateCamera.\n\nThis function decomposes an essential matrix using @ref decomposeEssentialMat and then verifies\npossible pose hypotheses by doing cheirality check. The cheirality check means that the\ntriangulated 3D points should have positive depth. Some details can be found in @cite Nister03.\nThis function can be used to process the output E and mask from @ref findEssentialMat. In this\nscenario, points1 and points2 are the same input for findEssentialMat.:\n```\n// Example. Estimation of fundamental matrix using the RANSAC algorithm\nint point_count = 100;\nvector  points1(point_count);\nvector  points2(point_count);\n// initialize the points here ...\nfor( int i = 0; i   retval, E, R, t, mask\n```\n#### Variant 2:\nrecoverPose\n\n##### Positional Arguments\n- **e**: `Evision.Mat`.\n\n  The input essential matrix.\n\n- **points1**: `Evision.Mat`.\n\n  Array of N 2D points from the first image. The point coordinates should be\n  floating-point (single or double precision).\n\n- **points2**: `Evision.Mat`.\n\n  Array of the second image points of the same size and format as points1.\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Camera intrinsic matrix \\f$\\cameramatrix{A}\\f$ .\n  Note that this function assumes that points1 and points2 are feature points from cameras with the\n  same camera intrinsic matrix.\n\n- **distanceThresh**: `double`.\n\n  threshold distance which is used to filter out far away points (i.e. infinite\n  points).\n\n##### Return\n- **retval**: `integer()`\n- **r**: `Evision.Mat.t()`.\n\n  Output rotation matrix. Together with the translation vector, this matrix makes up a tuple\n  that performs a change of basis from the first camera's coordinate system to the second camera's\n  coordinate system. Note that, in general, t can not be used for this tuple, see the parameter\n  description below.\n\n- **t**: `Evision.Mat.t()`.\n\n  Output translation vector. This vector is obtained by @ref decomposeEssentialMat and\n  therefore is only known up to scale, i.e. t is the direction of the translation vector and has unit\n  length.\n\n- **mask**: `Evision.Mat.t()`.\n\n  Input/output mask for inliers in points1 and points2. If it is not empty, then it marks\n  inliers in points1 and points2 for the given essential matrix E. Only these inliers will be used to\n  recover pose. In the output mask only inliers which pass the chirality check.\n\n- **triangulatedPoints**: `Evision.Mat.t()`.\n\n  3D points which were reconstructed by triangulation.\n\nHas overloading in C++\n\nThis function differs from the one above that it outputs the triangulated 3D point that are used for\nthe chirality check.\n\nPython prototype (for reference only):\n```python3\nrecoverPose(E, points1, points2, cameraMatrix, distanceThresh[, R[, t[, mask[, triangulatedPoints]]]]) -> retval, R, t, mask, triangulatedPoints\n```","ref":"Evision.html#recoverPose/6"},{"type":"function","title":"Evision.recoverPose/7","doc":"Recovers the relative camera rotation and the translation from corresponding points in two images from two different cameras, using cheirality check. Returns the number of\ninliers that pass the check.\n\n##### Positional Arguments\n- **points1**: `Evision.Mat`.\n\n  Array of N 2D points from the first image. The point coordinates should be\n  floating-point (single or double precision).\n\n- **points2**: `Evision.Mat`.\n\n  Array of the second image points of the same size and format as points1 .\n\n- **cameraMatrix1**: `Evision.Mat`.\n\n  Input/output camera matrix for the first camera, the same as in\n\n- **distCoeffs1**: `Evision.Mat`.\n\n  Input/output vector of distortion coefficients, the same as in\n\n- **cameraMatrix2**: `Evision.Mat`.\n\n  Input/output camera matrix for the first camera, the same as in\n\n- **distCoeffs2**: `Evision.Mat`.\n\n  Input/output vector of distortion coefficients, the same as in\n\n##### Keyword Arguments\n- **method**: `integer()`.\n\n  Method for computing an essential matrix.\n  - @ref RANSAC for the RANSAC algorithm.\n  - @ref LMEDS for the LMedS algorithm.\n\n- **prob**: `double`.\n\n  Parameter used for the RANSAC or LMedS methods only. It specifies a desirable level of\n  confidence (probability) that the estimated matrix is correct.\n\n- **threshold**: `double`.\n\n  Parameter used for RANSAC. It is the maximum distance from a point to an epipolar\n  line in pixels, beyond which the point is considered an outlier and is not used for computing the\n  final fundamental matrix. It can be set to something like 1-3, depending on the accuracy of the\n  point localization, image resolution, and the image noise.\n\n##### Return\n- **retval**: `integer()`\n- **e**: `Evision.Mat.t()`.\n\n  The output essential matrix.\n\n- **r**: `Evision.Mat.t()`.\n\n  Output rotation matrix. Together with the translation vector, this matrix makes up a tuple\n  that performs a change of basis from the first camera's coordinate system to the second camera's\n  coordinate system. Note that, in general, t can not be used for this tuple, see the parameter\n  described below.\n\n- **t**: `Evision.Mat.t()`.\n\n  Output translation vector. This vector is obtained by @ref decomposeEssentialMat and\n  therefore is only known up to scale, i.e. t is the direction of the translation vector and has unit\n  length.\n\n- **mask**: `Evision.Mat.t()`.\n\n  Input/output mask for inliers in points1 and points2. If it is not empty, then it marks\n  inliers in points1 and points2 for then given essential matrix E. Only these inliers will be used to\n  recover pose. In the output mask only inliers which pass the cheirality check.\n\n@ref calibrateCamera. Furthermore, for the stereo case, additional flags may be used, see below.\n@ref calibrateCamera.\n@ref calibrateCamera. Furthermore, for the stereo case, additional flags may be used, see below.\n@ref calibrateCamera.\n\nThis function decomposes an essential matrix using @ref decomposeEssentialMat and then verifies\npossible pose hypotheses by doing cheirality check. The cheirality check means that the\ntriangulated 3D points should have positive depth. Some details can be found in @cite Nister03.\nThis function can be used to process the output E and mask from @ref findEssentialMat. In this\nscenario, points1 and points2 are the same input for findEssentialMat.:\n```\n// Example. Estimation of fundamental matrix using the RANSAC algorithm\nint point_count = 100;\nvector  points1(point_count);\nvector  points2(point_count);\n// initialize the points here ...\nfor( int i = 0; i   retval, E, R, t, mask\n```","ref":"Evision.html#recoverPose/7"},{"type":"function","title":"Evision.rectangle/1","doc":"","ref":"Evision.html#rectangle/1"},{"type":"function","title":"Evision.rectangle/3","doc":"rectangle\n\n##### Positional Arguments\n- **rec**: `Rect`\n- **color**: `Evision.scalar()`\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n- **lineType**: `integer()`.\n- **shift**: `integer()`.\n\n##### Return\n- **img**: `Evision.Mat.t()`\n\nHas overloading in C++\n\nuse `rec` parameter as alternative specification of the drawn rectangle: `r.tl() and\nr.br()-Point(1,1)` are opposite corners\n\nPython prototype (for reference only):\n```python3\nrectangle(img, rec, color[, thickness[, lineType[, shift]]]) -> img\n```","ref":"Evision.html#rectangle/3"},{"type":"function","title":"Evision.rectangle/4","doc":"#### Variant 1:\nDraws a simple, thick, or filled up-right rectangle.\n\n##### Positional Arguments\n- **pt1**: `Point`.\n\n  Vertex of the rectangle.\n\n- **pt2**: `Point`.\n\n  Vertex of the rectangle opposite to pt1 .\n\n- **color**: `Evision.scalar()`.\n\n  Rectangle color or brightness (grayscale image).\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n\n  Thickness of lines that make up the rectangle. Negative values, like #FILLED,\n  mean that the function has to draw a filled rectangle.\n\n- **lineType**: `integer()`.\n\n  Type of the line. See #LineTypes\n\n- **shift**: `integer()`.\n\n  Number of fractional bits in the point coordinates.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  Image.\n\nThe function cv::rectangle draws a rectangle outline or a filled rectangle whose two opposite corners\nare pt1 and pt2.\n\nPython prototype (for reference only):\n```python3\nrectangle(img, pt1, pt2, color[, thickness[, lineType[, shift]]]) -> img\n```\n#### Variant 2:\nrectangle\n\n##### Positional Arguments\n- **rec**: `Rect`\n- **color**: `Evision.scalar()`\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n- **lineType**: `integer()`.\n- **shift**: `integer()`.\n\n##### Return\n- **img**: `Evision.Mat.t()`\n\nHas overloading in C++\n\nuse `rec` parameter as alternative specification of the drawn rectangle: `r.tl() and\nr.br()-Point(1,1)` are opposite corners\n\nPython prototype (for reference only):\n```python3\nrectangle(img, rec, color[, thickness[, lineType[, shift]]]) -> img\n```","ref":"Evision.html#rectangle/4"},{"type":"function","title":"Evision.rectangle/5","doc":"Draws a simple, thick, or filled up-right rectangle.\n\n##### Positional Arguments\n- **pt1**: `Point`.\n\n  Vertex of the rectangle.\n\n- **pt2**: `Point`.\n\n  Vertex of the rectangle opposite to pt1 .\n\n- **color**: `Evision.scalar()`.\n\n  Rectangle color or brightness (grayscale image).\n\n##### Keyword Arguments\n- **thickness**: `integer()`.\n\n  Thickness of lines that make up the rectangle. Negative values, like #FILLED,\n  mean that the function has to draw a filled rectangle.\n\n- **lineType**: `integer()`.\n\n  Type of the line. See #LineTypes\n\n- **shift**: `integer()`.\n\n  Number of fractional bits in the point coordinates.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  Image.\n\nThe function cv::rectangle draws a rectangle outline or a filled rectangle whose two opposite corners\nare pt1 and pt2.\n\nPython prototype (for reference only):\n```python3\nrectangle(img, pt1, pt2, color[, thickness[, lineType[, shift]]]) -> img\n```","ref":"Evision.html#rectangle/5"},{"type":"function","title":"Evision.rectangleIntersectionArea/1","doc":"","ref":"Evision.html#rectangleIntersectionArea/1"},{"type":"function","title":"Evision.rectangleIntersectionArea/2","doc":"Finds out if there is any intersection between two rectangles\n\n##### Positional Arguments\n- **a**: `Rect2d`.\n\n  First rectangle\n\n- **b**: `Rect2d`.\n\n  Second rectangle\n\n##### Return\n- **retval**: `double`\n\n mainly useful for language bindings\n@return the area of the intersection\n\nPython prototype (for reference only):\n```python3\nrectangleIntersectionArea(a, b) -> retval\n```","ref":"Evision.html#rectangleIntersectionArea/2"},{"type":"function","title":"Evision.rectify3Collinear/1","doc":"","ref":"Evision.html#rectify3Collinear/1"},{"type":"function","title":"Evision.rectify3Collinear/16","doc":"rectify3Collinear\n\n##### Positional Arguments\n- **cameraMatrix1**: `Evision.Mat`\n- **distCoeffs1**: `Evision.Mat`\n- **cameraMatrix2**: `Evision.Mat`\n- **distCoeffs2**: `Evision.Mat`\n- **cameraMatrix3**: `Evision.Mat`\n- **distCoeffs3**: `Evision.Mat`\n- **imgpt1**: `[Evision.Mat]`\n- **imgpt3**: `[Evision.Mat]`\n- **imageSize**: `Size`\n- **r12**: `Evision.Mat`\n- **t12**: `Evision.Mat`\n- **r13**: `Evision.Mat`\n- **t13**: `Evision.Mat`\n- **alpha**: `double`\n- **newImgSize**: `Size`\n- **flags**: `integer()`\n\n##### Return\n- **retval**: `float`\n- **r1**: `Evision.Mat.t()`.\n- **r2**: `Evision.Mat.t()`.\n- **r3**: `Evision.Mat.t()`.\n- **p1**: `Evision.Mat.t()`.\n- **p2**: `Evision.Mat.t()`.\n- **p3**: `Evision.Mat.t()`.\n- **q**: `Evision.Mat.t()`.\n- **roi1**: `Rect*`\n- **roi2**: `Rect*`\n\nPython prototype (for reference only):\n```python3\nrectify3Collinear(cameraMatrix1, distCoeffs1, cameraMatrix2, distCoeffs2, cameraMatrix3, distCoeffs3, imgpt1, imgpt3, imageSize, R12, T12, R13, T13, alpha, newImgSize, flags[, R1[, R2[, R3[, P1[, P2[, P3[, Q]]]]]]]) -> retval, R1, R2, R3, P1, P2, P3, Q, roi1, roi2\n```","ref":"Evision.html#rectify3Collinear/16"},{"type":"function","title":"Evision.rectify3Collinear/17","doc":"rectify3Collinear\n\n##### Positional Arguments\n- **cameraMatrix1**: `Evision.Mat`\n- **distCoeffs1**: `Evision.Mat`\n- **cameraMatrix2**: `Evision.Mat`\n- **distCoeffs2**: `Evision.Mat`\n- **cameraMatrix3**: `Evision.Mat`\n- **distCoeffs3**: `Evision.Mat`\n- **imgpt1**: `[Evision.Mat]`\n- **imgpt3**: `[Evision.Mat]`\n- **imageSize**: `Size`\n- **r12**: `Evision.Mat`\n- **t12**: `Evision.Mat`\n- **r13**: `Evision.Mat`\n- **t13**: `Evision.Mat`\n- **alpha**: `double`\n- **newImgSize**: `Size`\n- **flags**: `integer()`\n\n##### Return\n- **retval**: `float`\n- **r1**: `Evision.Mat.t()`.\n- **r2**: `Evision.Mat.t()`.\n- **r3**: `Evision.Mat.t()`.\n- **p1**: `Evision.Mat.t()`.\n- **p2**: `Evision.Mat.t()`.\n- **p3**: `Evision.Mat.t()`.\n- **q**: `Evision.Mat.t()`.\n- **roi1**: `Rect*`\n- **roi2**: `Rect*`\n\nPython prototype (for reference only):\n```python3\nrectify3Collinear(cameraMatrix1, distCoeffs1, cameraMatrix2, distCoeffs2, cameraMatrix3, distCoeffs3, imgpt1, imgpt3, imageSize, R12, T12, R13, T13, alpha, newImgSize, flags[, R1[, R2[, R3[, P1[, P2[, P3[, Q]]]]]]]) -> retval, R1, R2, R3, P1, P2, P3, Q, roi1, roi2\n```","ref":"Evision.html#rectify3Collinear/17"},{"type":"function","title":"Evision.reduce/1","doc":"","ref":"Evision.html#reduce/1"},{"type":"function","title":"Evision.reduce/3","doc":"Reduces a matrix to a vector.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input 2D matrix.\n\n- **dim**: `integer()`.\n\n  dimension index along which the matrix is reduced. 0 means that the matrix is reduced to\n  a single row. 1 means that the matrix is reduced to a single column.\n\n- **rtype**: `integer()`.\n\n  reduction operation that could be one of #ReduceTypes\n\n##### Keyword Arguments\n- **dtype**: `integer()`.\n\n  when negative, the output vector will have the same type as the input matrix,\n  otherwise, its type will be CV_MAKE_TYPE(CV_MAT_DEPTH(dtype), src.channels()).\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output vector. Its size and type is defined by dim and dtype parameters.\n\nThe function #reduce reduces the matrix to a vector by treating the matrix rows/columns as a set of\n1D vectors and performing the specified operation on the vectors until a single row/column is\nobtained. For example, the function can be used to compute horizontal and vertical projections of a\nraster image. In case of #REDUCE_MAX and #REDUCE_MIN, the output image should have the same type as the source one.\nIn case of #REDUCE_SUM, #REDUCE_SUM2 and #REDUCE_AVG, the output may have a larger element bit-depth to preserve accuracy.\nAnd multi-channel arrays are also supported in these two reduction modes.\nThe following code demonstrates its usage for a single channel matrix.\n@snippet snippets/core_reduce.cpp example\nAnd the following code demonstrates its usage for a two-channel matrix.\n@snippet snippets/core_reduce.cpp example2\n@sa repeat, reduceArgMin, reduceArgMax\n\nPython prototype (for reference only):\n```python3\nreduce(src, dim, rtype[, dst[, dtype]]) -> dst\n```","ref":"Evision.html#reduce/3"},{"type":"function","title":"Evision.reduce/4","doc":"Reduces a matrix to a vector.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input 2D matrix.\n\n- **dim**: `integer()`.\n\n  dimension index along which the matrix is reduced. 0 means that the matrix is reduced to\n  a single row. 1 means that the matrix is reduced to a single column.\n\n- **rtype**: `integer()`.\n\n  reduction operation that could be one of #ReduceTypes\n\n##### Keyword Arguments\n- **dtype**: `integer()`.\n\n  when negative, the output vector will have the same type as the input matrix,\n  otherwise, its type will be CV_MAKE_TYPE(CV_MAT_DEPTH(dtype), src.channels()).\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output vector. Its size and type is defined by dim and dtype parameters.\n\nThe function #reduce reduces the matrix to a vector by treating the matrix rows/columns as a set of\n1D vectors and performing the specified operation on the vectors until a single row/column is\nobtained. For example, the function can be used to compute horizontal and vertical projections of a\nraster image. In case of #REDUCE_MAX and #REDUCE_MIN, the output image should have the same type as the source one.\nIn case of #REDUCE_SUM, #REDUCE_SUM2 and #REDUCE_AVG, the output may have a larger element bit-depth to preserve accuracy.\nAnd multi-channel arrays are also supported in these two reduction modes.\nThe following code demonstrates its usage for a single channel matrix.\n@snippet snippets/core_reduce.cpp example\nAnd the following code demonstrates its usage for a two-channel matrix.\n@snippet snippets/core_reduce.cpp example2\n@sa repeat, reduceArgMin, reduceArgMax\n\nPython prototype (for reference only):\n```python3\nreduce(src, dim, rtype[, dst[, dtype]]) -> dst\n```","ref":"Evision.html#reduce/4"},{"type":"function","title":"Evision.reduceArgMax/1","doc":"","ref":"Evision.html#reduceArgMax/1"},{"type":"function","title":"Evision.reduceArgMax/2","doc":"Finds indices of max elements along provided axis\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input single-channel array.\n\n- **axis**: `integer()`.\n\n  axis to reduce along.\n\n##### Keyword Arguments\n- **lastIndex**: `bool`.\n\n  whether to get the index of first or last occurrence of max.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of type CV_32SC1 with the same dimensionality as src,\n  except for axis being reduced - it should be set to 1.\n\n**Note**: \n- If input or output array is not continuous, this function will create an internal copy.\n- NaN handling is left unspecified, see patchNaNs().\n- The returned index is always in bounds of input matrix.\n\n@sa reduceArgMin, minMaxLoc, min, max, compare, reduce\n\nPython prototype (for reference only):\n```python3\nreduceArgMax(src, axis[, dst[, lastIndex]]) -> dst\n```","ref":"Evision.html#reduceArgMax/2"},{"type":"function","title":"Evision.reduceArgMax/3","doc":"Finds indices of max elements along provided axis\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input single-channel array.\n\n- **axis**: `integer()`.\n\n  axis to reduce along.\n\n##### Keyword Arguments\n- **lastIndex**: `bool`.\n\n  whether to get the index of first or last occurrence of max.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of type CV_32SC1 with the same dimensionality as src,\n  except for axis being reduced - it should be set to 1.\n\n**Note**: \n- If input or output array is not continuous, this function will create an internal copy.\n- NaN handling is left unspecified, see patchNaNs().\n- The returned index is always in bounds of input matrix.\n\n@sa reduceArgMin, minMaxLoc, min, max, compare, reduce\n\nPython prototype (for reference only):\n```python3\nreduceArgMax(src, axis[, dst[, lastIndex]]) -> dst\n```","ref":"Evision.html#reduceArgMax/3"},{"type":"function","title":"Evision.reduceArgMin/1","doc":"","ref":"Evision.html#reduceArgMin/1"},{"type":"function","title":"Evision.reduceArgMin/2","doc":"Finds indices of min elements along provided axis\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input single-channel array.\n\n- **axis**: `integer()`.\n\n  axis to reduce along.\n\n##### Keyword Arguments\n- **lastIndex**: `bool`.\n\n  whether to get the index of first or last occurrence of min.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of type CV_32SC1 with the same dimensionality as src,\n  except for axis being reduced - it should be set to 1.\n\n**Note**: \n- If input or output array is not continuous, this function will create an internal copy.\n- NaN handling is left unspecified, see patchNaNs().\n- The returned index is always in bounds of input matrix.\n\n@sa reduceArgMax, minMaxLoc, min, max, compare, reduce\n\nPython prototype (for reference only):\n```python3\nreduceArgMin(src, axis[, dst[, lastIndex]]) -> dst\n```","ref":"Evision.html#reduceArgMin/2"},{"type":"function","title":"Evision.reduceArgMin/3","doc":"Finds indices of min elements along provided axis\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input single-channel array.\n\n- **axis**: `integer()`.\n\n  axis to reduce along.\n\n##### Keyword Arguments\n- **lastIndex**: `bool`.\n\n  whether to get the index of first or last occurrence of min.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of type CV_32SC1 with the same dimensionality as src,\n  except for axis being reduced - it should be set to 1.\n\n**Note**: \n- If input or output array is not continuous, this function will create an internal copy.\n- NaN handling is left unspecified, see patchNaNs().\n- The returned index is always in bounds of input matrix.\n\n@sa reduceArgMax, minMaxLoc, min, max, compare, reduce\n\nPython prototype (for reference only):\n```python3\nreduceArgMin(src, axis[, dst[, lastIndex]]) -> dst\n```","ref":"Evision.html#reduceArgMin/3"},{"type":"function","title":"Evision.remap/1","doc":"","ref":"Evision.html#remap/1"},{"type":"function","title":"Evision.remap/4","doc":"Applies a generic geometrical transformation to an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image.\n\n- **map1**: `Evision.Mat`.\n\n  The first map of either (x,y) points or just x values having the type CV_16SC2 ,\n  CV_32FC1, or CV_32FC2. See #convertMaps for details on converting a floating point\n  representation to fixed-point for speed.\n\n- **map2**: `Evision.Mat`.\n\n  The second map of y values having the type CV_16UC1, CV_32FC1, or none (empty map\n  if map1 is (x,y) points), respectively.\n\n- **interpolation**: `integer()`.\n\n  Interpolation method (see #InterpolationFlags). The methods #INTER_AREA\n  #INTER_LINEAR_EXACT and #INTER_NEAREST_EXACT are not supported by this function.\n  The extra flag WARP_RELATIVE_MAP that can be ORed to the interpolation method\n  (e.g. INTER_LINEAR | WARP_RELATIVE_MAP)\n\n##### Keyword Arguments\n- **borderMode**: `integer()`.\n\n  Pixel extrapolation method (see #BorderTypes). When\n  borderMode=#BORDER_TRANSPARENT, it means that the pixels in the destination image that\n  corresponds to the \"outliers\" in the source image are not modified by the function.\n\n- **borderValue**: `Evision.scalar()`.\n\n  Value used in case of a constant border. By default, it is 0.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image. It has the same size as map1 and the same type as src .\n\nThe function remap transforms the source image using the specified map:\n\\f[\\texttt{dst} (x,y) =  \\texttt{src} (map\\_x(x,y),map\\_y(x,y))\\f]\n\\f[\\texttt{dst} (x,y) =  \\texttt{src} (x+map\\_x(x,y),y+map\\_y(x,y))\\f] with WARP_RELATIVE_MAP\nwhere values of pixels with non-integer coordinates are computed using one of available\ninterpolation methods. \\f$map\\_x\\f$ and \\f$map\\_y\\f$ can be encoded as separate floating-point maps\nin \\f$map\\_1\\f$ and \\f$map\\_2\\f$ respectively, or interleaved floating-point maps of \\f$(x,y)\\f$ in\n\\f$map\\_1\\f$, or fixed-point maps created by using #convertMaps. The reason you might want to\nconvert from floating to fixed-point representations of a map is that they can yield much faster\n(\\~2x) remapping operations. In the converted case, \\f$map\\_1\\f$ contains pairs (cvFloor(x),\ncvFloor(y)) and \\f$map\\_2\\f$ contains indices in a table of interpolation coefficients.\nThis function cannot operate in-place.\n**Note**: \nDue to current implementation limitations the size of an input and output images should be less than 32767x32767.\n\nPython prototype (for reference only):\n```python3\nremap(src, map1, map2, interpolation[, dst[, borderMode[, borderValue]]]) -> dst\n```","ref":"Evision.html#remap/4"},{"type":"function","title":"Evision.remap/5","doc":"Applies a generic geometrical transformation to an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image.\n\n- **map1**: `Evision.Mat`.\n\n  The first map of either (x,y) points or just x values having the type CV_16SC2 ,\n  CV_32FC1, or CV_32FC2. See #convertMaps for details on converting a floating point\n  representation to fixed-point for speed.\n\n- **map2**: `Evision.Mat`.\n\n  The second map of y values having the type CV_16UC1, CV_32FC1, or none (empty map\n  if map1 is (x,y) points), respectively.\n\n- **interpolation**: `integer()`.\n\n  Interpolation method (see #InterpolationFlags). The methods #INTER_AREA\n  #INTER_LINEAR_EXACT and #INTER_NEAREST_EXACT are not supported by this function.\n  The extra flag WARP_RELATIVE_MAP that can be ORed to the interpolation method\n  (e.g. INTER_LINEAR | WARP_RELATIVE_MAP)\n\n##### Keyword Arguments\n- **borderMode**: `integer()`.\n\n  Pixel extrapolation method (see #BorderTypes). When\n  borderMode=#BORDER_TRANSPARENT, it means that the pixels in the destination image that\n  corresponds to the \"outliers\" in the source image are not modified by the function.\n\n- **borderValue**: `Evision.scalar()`.\n\n  Value used in case of a constant border. By default, it is 0.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image. It has the same size as map1 and the same type as src .\n\nThe function remap transforms the source image using the specified map:\n\\f[\\texttt{dst} (x,y) =  \\texttt{src} (map\\_x(x,y),map\\_y(x,y))\\f]\n\\f[\\texttt{dst} (x,y) =  \\texttt{src} (x+map\\_x(x,y),y+map\\_y(x,y))\\f] with WARP_RELATIVE_MAP\nwhere values of pixels with non-integer coordinates are computed using one of available\ninterpolation methods. \\f$map\\_x\\f$ and \\f$map\\_y\\f$ can be encoded as separate floating-point maps\nin \\f$map\\_1\\f$ and \\f$map\\_2\\f$ respectively, or interleaved floating-point maps of \\f$(x,y)\\f$ in\n\\f$map\\_1\\f$, or fixed-point maps created by using #convertMaps. The reason you might want to\nconvert from floating to fixed-point representations of a map is that they can yield much faster\n(\\~2x) remapping operations. In the converted case, \\f$map\\_1\\f$ contains pairs (cvFloor(x),\ncvFloor(y)) and \\f$map\\_2\\f$ contains indices in a table of interpolation coefficients.\nThis function cannot operate in-place.\n**Note**: \nDue to current implementation limitations the size of an input and output images should be less than 32767x32767.\n\nPython prototype (for reference only):\n```python3\nremap(src, map1, map2, interpolation[, dst[, borderMode[, borderValue]]]) -> dst\n```","ref":"Evision.html#remap/5"},{"type":"function","title":"Evision.repeat/1","doc":"","ref":"Evision.html#repeat/1"},{"type":"function","title":"Evision.repeat/3","doc":"Fills the output array with repeated copies of the input array.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array to replicate.\n\n- **ny**: `integer()`.\n\n  Flag to specify how many times the `src` is repeated along the\n  vertical axis.\n\n- **nx**: `integer()`.\n\n  Flag to specify how many times the `src` is repeated along the\n  horizontal axis.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same type as `src`.\n\nThe function cv::repeat duplicates the input array one or more times along each of the two axes:\n\\f[\\texttt{dst} \\_{ij}= \\texttt{src} \\_{i\\mod src.rows, \\; j\\mod src.cols }\\f]\nThe second variant of the function is more convenient to use with @ref MatrixExpressions.\n@sa cv::reduce\n\nPython prototype (for reference only):\n```python3\nrepeat(src, ny, nx[, dst]) -> dst\n```","ref":"Evision.html#repeat/3"},{"type":"function","title":"Evision.repeat/4","doc":"Fills the output array with repeated copies of the input array.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array to replicate.\n\n- **ny**: `integer()`.\n\n  Flag to specify how many times the `src` is repeated along the\n  vertical axis.\n\n- **nx**: `integer()`.\n\n  Flag to specify how many times the `src` is repeated along the\n  horizontal axis.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same type as `src`.\n\nThe function cv::repeat duplicates the input array one or more times along each of the two axes:\n\\f[\\texttt{dst} \\_{ij}= \\texttt{src} \\_{i\\mod src.rows, \\; j\\mod src.cols }\\f]\nThe second variant of the function is more convenient to use with @ref MatrixExpressions.\n@sa cv::reduce\n\nPython prototype (for reference only):\n```python3\nrepeat(src, ny, nx[, dst]) -> dst\n```","ref":"Evision.html#repeat/4"},{"type":"function","title":"Evision.reprojectImageTo3D/1","doc":"","ref":"Evision.html#reprojectImageTo3D/1"},{"type":"function","title":"Evision.reprojectImageTo3D/2","doc":"Reprojects a disparity image to 3D space.\n\n##### Positional Arguments\n- **disparity**: `Evision.Mat`.\n\n  Input single-channel 8-bit unsigned, 16-bit signed, 32-bit signed or 32-bit\n  floating-point disparity image. The values of 8-bit / 16-bit signed formats are assumed to have no\n  fractional bits. If the disparity is 16-bit signed format, as computed by @ref StereoBM or\n\n- **q**: `Evision.Mat`.\n\n  \\f$4 \\times 4\\f$ perspective transformation matrix that can be obtained with\n\n##### Keyword Arguments\n- **handleMissingValues**: `bool`.\n\n  Indicates, whether the function should handle missing values (i.e.\n  points where the disparity was not computed). If handleMissingValues=true, then pixels with the\n  minimal disparity that corresponds to the outliers (see StereoMatcher::compute ) are transformed\n  to 3D points with a very large Z value (currently set to 10000).\n\n- **ddepth**: `integer()`.\n\n  The optional output array depth. If it is -1, the output image will have CV_32F\n  depth. ddepth can also be set to CV_16S, CV_32S or CV_32F.\n\n##### Return\n- **3dImage**: `Evision.Mat.t()`.\n\n  Output 3-channel floating-point image of the same size as disparity. Each element of\n  _3dImage(x,y) contains 3D coordinates of the point (x,y) computed from the disparity map. If one\n  uses Q obtained by @ref stereoRectify, then the returned points are represented in the first\n  camera's rectified coordinate system.\n\n@ref StereoSGBM and maybe other algorithms, it should be divided by 16 (and scaled to float) before\nbeing used here.\n@ref stereoRectify.\n\nThe function transforms a single-channel disparity map to a 3-channel image representing a 3D\nsurface. That is, for each pixel (x,y) and the corresponding disparity d=disparity(x,y) , it\ncomputes:\n\\f[\\begin{bmatrix}\nX \\\\\\\\\nY \\\\\\\\\nZ \\\\\\\\\nW\n\\end{bmatrix} = Q \\begin{bmatrix}\nx \\\\\\\\\ny \\\\\\\\\n\\texttt{disparity} (x,y) \\\\\\\\\n1\n\\end{bmatrix}.\\f]\n@sa\nTo reproject a sparse set of points {(x,y,d),...} to 3D space, use perspectiveTransform.\n\nPython prototype (for reference only):\n```python3\nreprojectImageTo3D(disparity, Q[, _3dImage[, handleMissingValues[, ddepth]]]) -> _3dImage\n```","ref":"Evision.html#reprojectImageTo3D/2"},{"type":"function","title":"Evision.reprojectImageTo3D/3","doc":"Reprojects a disparity image to 3D space.\n\n##### Positional Arguments\n- **disparity**: `Evision.Mat`.\n\n  Input single-channel 8-bit unsigned, 16-bit signed, 32-bit signed or 32-bit\n  floating-point disparity image. The values of 8-bit / 16-bit signed formats are assumed to have no\n  fractional bits. If the disparity is 16-bit signed format, as computed by @ref StereoBM or\n\n- **q**: `Evision.Mat`.\n\n  \\f$4 \\times 4\\f$ perspective transformation matrix that can be obtained with\n\n##### Keyword Arguments\n- **handleMissingValues**: `bool`.\n\n  Indicates, whether the function should handle missing values (i.e.\n  points where the disparity was not computed). If handleMissingValues=true, then pixels with the\n  minimal disparity that corresponds to the outliers (see StereoMatcher::compute ) are transformed\n  to 3D points with a very large Z value (currently set to 10000).\n\n- **ddepth**: `integer()`.\n\n  The optional output array depth. If it is -1, the output image will have CV_32F\n  depth. ddepth can also be set to CV_16S, CV_32S or CV_32F.\n\n##### Return\n- **3dImage**: `Evision.Mat.t()`.\n\n  Output 3-channel floating-point image of the same size as disparity. Each element of\n  _3dImage(x,y) contains 3D coordinates of the point (x,y) computed from the disparity map. If one\n  uses Q obtained by @ref stereoRectify, then the returned points are represented in the first\n  camera's rectified coordinate system.\n\n@ref StereoSGBM and maybe other algorithms, it should be divided by 16 (and scaled to float) before\nbeing used here.\n@ref stereoRectify.\n\nThe function transforms a single-channel disparity map to a 3-channel image representing a 3D\nsurface. That is, for each pixel (x,y) and the corresponding disparity d=disparity(x,y) , it\ncomputes:\n\\f[\\begin{bmatrix}\nX \\\\\\\\\nY \\\\\\\\\nZ \\\\\\\\\nW\n\\end{bmatrix} = Q \\begin{bmatrix}\nx \\\\\\\\\ny \\\\\\\\\n\\texttt{disparity} (x,y) \\\\\\\\\n1\n\\end{bmatrix}.\\f]\n@sa\nTo reproject a sparse set of points {(x,y,d),...} to 3D space, use perspectiveTransform.\n\nPython prototype (for reference only):\n```python3\nreprojectImageTo3D(disparity, Q[, _3dImage[, handleMissingValues[, ddepth]]]) -> _3dImage\n```","ref":"Evision.html#reprojectImageTo3D/3"},{"type":"function","title":"Evision.resize/1","doc":"","ref":"Evision.html#resize/1"},{"type":"function","title":"Evision.resize/2","doc":"Resizes an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image.\n\n- **dsize**: `Size`.\n\n  output image size; if it equals zero (`None` in Python), it is computed as:\n  \\f[\\texttt{dsize = Size(round(fx*src.cols), round(fy*src.rows))}\\f]\n  Either dsize or both fx and fy must be non-zero.\n\n##### Keyword Arguments\n- **fx**: `double`.\n\n  scale factor along the horizontal axis; when it equals 0, it is computed as\n  \\f[\\texttt{(double)dsize.width/src.cols}\\f]\n\n- **fy**: `double`.\n\n  scale factor along the vertical axis; when it equals 0, it is computed as\n  \\f[\\texttt{(double)dsize.height/src.rows}\\f]\n\n- **interpolation**: `integer()`.\n\n  interpolation method, see #InterpolationFlags\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image; it has the size dsize (when it is non-zero) or the size computed from\n  src.size(), fx, and fy; the type of dst is the same as of src.\n\nThe function resize resizes the image src down to or up to the specified size. Note that the\ninitial dst type or size are not taken into account. Instead, the size and type are derived from\nthe `src`,`dsize`,`fx`, and `fy`. If you want to resize src so that it fits the pre-created dst,\nyou may call the function as follows:\n```\n// explicitly specify dsize=dst.size(); fx and fy will be computed from that.\nresize(src, dst, dst.size(), 0, 0, interpolation);\n```\nIf you want to decimate the image by factor of 2 in each direction, you can call the function this\nway:\n```\n// specify fx and fy and let the function compute the destination image size.\nresize(src, dst, Size(), 0.5, 0.5, interpolation);\n```\nTo shrink an image, it will generally look best with #INTER_AREA interpolation, whereas to\nenlarge an image, it will generally look best with #INTER_CUBIC (slow) or #INTER_LINEAR\n(faster but still looks OK).\n\n@sa  warpAffine, warpPerspective, remap\n\nPython prototype (for reference only):\n```python3\nresize(src, dsize[, dst[, fx[, fy[, interpolation]]]]) -> dst\n```","ref":"Evision.html#resize/2"},{"type":"function","title":"Evision.resize/3","doc":"Resizes an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image.\n\n- **dsize**: `Size`.\n\n  output image size; if it equals zero (`None` in Python), it is computed as:\n  \\f[\\texttt{dsize = Size(round(fx*src.cols), round(fy*src.rows))}\\f]\n  Either dsize or both fx and fy must be non-zero.\n\n##### Keyword Arguments\n- **fx**: `double`.\n\n  scale factor along the horizontal axis; when it equals 0, it is computed as\n  \\f[\\texttt{(double)dsize.width/src.cols}\\f]\n\n- **fy**: `double`.\n\n  scale factor along the vertical axis; when it equals 0, it is computed as\n  \\f[\\texttt{(double)dsize.height/src.rows}\\f]\n\n- **interpolation**: `integer()`.\n\n  interpolation method, see #InterpolationFlags\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image; it has the size dsize (when it is non-zero) or the size computed from\n  src.size(), fx, and fy; the type of dst is the same as of src.\n\nThe function resize resizes the image src down to or up to the specified size. Note that the\ninitial dst type or size are not taken into account. Instead, the size and type are derived from\nthe `src`,`dsize`,`fx`, and `fy`. If you want to resize src so that it fits the pre-created dst,\nyou may call the function as follows:\n```\n// explicitly specify dsize=dst.size(); fx and fy will be computed from that.\nresize(src, dst, dst.size(), 0, 0, interpolation);\n```\nIf you want to decimate the image by factor of 2 in each direction, you can call the function this\nway:\n```\n// specify fx and fy and let the function compute the destination image size.\nresize(src, dst, Size(), 0.5, 0.5, interpolation);\n```\nTo shrink an image, it will generally look best with #INTER_AREA interpolation, whereas to\nenlarge an image, it will generally look best with #INTER_CUBIC (slow) or #INTER_LINEAR\n(faster but still looks OK).\n\n@sa  warpAffine, warpPerspective, remap\n\nPython prototype (for reference only):\n```python3\nresize(src, dsize[, dst[, fx[, fy[, interpolation]]]]) -> dst\n```","ref":"Evision.html#resize/3"},{"type":"function","title":"Evision.resizeWindow/1","doc":"","ref":"Evision.html#resizeWindow/1"},{"type":"function","title":"Evision.resizeWindow/2","doc":"resizeWindow\n\n##### Positional Arguments\n- **winname**: `String`.\n\n  Window name.\n\n- **size**: `Size`.\n\n  The new window size.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nresizeWindow(winname, size) -> None\n```","ref":"Evision.html#resizeWindow/2"},{"type":"function","title":"Evision.resizeWindow/3","doc":"Resizes the window to the specified size\n\n##### Positional Arguments\n- **winname**: `String`.\n\n  Window name.\n\n- **width**: `integer()`.\n\n  The new window width.\n\n- **height**: `integer()`.\n\n  The new window height.\n\n**Note**: The specified window size is for the image area. Toolbars are not counted.\nOnly windows created without cv::WINDOW_AUTOSIZE flag can be resized.\n\nPython prototype (for reference only):\n```python3\nresizeWindow(winname, width, height) -> None\n```","ref":"Evision.html#resizeWindow/3"},{"type":"function","title":"Evision.rodrigues/1","doc":"Converts a rotation matrix to a rotation vector or vice versa.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input rotation vector (3x1 or 1x3) or rotation matrix (3x3).\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output rotation matrix (3x3) or rotation vector (3x1 or 1x3), respectively.\n\n- **jacobian**: `Evision.Mat.t()`.\n\n  Optional output Jacobian matrix, 3x9 or 9x3, which is a matrix of partial\n  derivatives of the output array components with respect to the input array components.\n\n\\f[\\begin{array}{l} \\theta \\leftarrow norm(r) \\\\\\\\ r  \\leftarrow r/ \\theta \\\\\\\\ R =  \\cos(\\theta) I + (1- \\cos{\\theta} ) r r^T +  \\sin(\\theta) \\vecthreethree{0}{-r\\_z}{r\\_y}{r\\_z}{0}{-r\\_x}{-r\\_y}{r\\_x}{0} \\end{array}\\f]\nInverse transformation can be also done easily, since\n\\f[\\sin ( \\theta ) \\vecthreethree{0}{-r\\_z}{r\\_y}{r\\_z}{0}{-r\\_x}{-r\\_y}{r\\_x}{0} = \\frac{R - R^T}{2}\\f]\nA rotation vector is a convenient and most compact representation of a rotation matrix (since any\nrotation matrix has just 3 degrees of freedom). The representation is used in the global 3D geometry\noptimization procedures like @ref calibrateCamera, @ref stereoCalibrate, or @ref solvePnP .\n**Note**: More information about the computation of the derivative of a 3D rotation matrix with respect to its exponential coordinate\ncan be found in:\n- A Compact Formula for the Derivative of a 3-D Rotation in Exponential Coordinates, Guillermo Gallego, Anthony J. Yezzi @cite Gallego2014ACF\n\n**Note**: Useful information on SE(3) and Lie Groups can be found in:\n- A tutorial on SE(3) transformation parameterizations and on-manifold optimization, Jose-Luis Blanco @cite blanco2010tutorial\n- Lie Groups for 2D and 3D Transformation, Ethan Eade @cite Eade17\n- A micro Lie theory for state estimation in robotics, Joan Solà, Jérémie Deray, Dinesh Atchuthan @cite Sol2018AML\n\nPython prototype (for reference only):\n```python3\nRodrigues(src[, dst[, jacobian]]) -> dst, jacobian\n```","ref":"Evision.html#rodrigues/1"},{"type":"function","title":"Evision.rodrigues/2","doc":"Converts a rotation matrix to a rotation vector or vice versa.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input rotation vector (3x1 or 1x3) or rotation matrix (3x3).\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output rotation matrix (3x3) or rotation vector (3x1 or 1x3), respectively.\n\n- **jacobian**: `Evision.Mat.t()`.\n\n  Optional output Jacobian matrix, 3x9 or 9x3, which is a matrix of partial\n  derivatives of the output array components with respect to the input array components.\n\n\\f[\\begin{array}{l} \\theta \\leftarrow norm(r) \\\\\\\\ r  \\leftarrow r/ \\theta \\\\\\\\ R =  \\cos(\\theta) I + (1- \\cos{\\theta} ) r r^T +  \\sin(\\theta) \\vecthreethree{0}{-r\\_z}{r\\_y}{r\\_z}{0}{-r\\_x}{-r\\_y}{r\\_x}{0} \\end{array}\\f]\nInverse transformation can be also done easily, since\n\\f[\\sin ( \\theta ) \\vecthreethree{0}{-r\\_z}{r\\_y}{r\\_z}{0}{-r\\_x}{-r\\_y}{r\\_x}{0} = \\frac{R - R^T}{2}\\f]\nA rotation vector is a convenient and most compact representation of a rotation matrix (since any\nrotation matrix has just 3 degrees of freedom). The representation is used in the global 3D geometry\noptimization procedures like @ref calibrateCamera, @ref stereoCalibrate, or @ref solvePnP .\n**Note**: More information about the computation of the derivative of a 3D rotation matrix with respect to its exponential coordinate\ncan be found in:\n- A Compact Formula for the Derivative of a 3-D Rotation in Exponential Coordinates, Guillermo Gallego, Anthony J. Yezzi @cite Gallego2014ACF\n\n**Note**: Useful information on SE(3) and Lie Groups can be found in:\n- A tutorial on SE(3) transformation parameterizations and on-manifold optimization, Jose-Luis Blanco @cite blanco2010tutorial\n- Lie Groups for 2D and 3D Transformation, Ethan Eade @cite Eade17\n- A micro Lie theory for state estimation in robotics, Joan Solà, Jérémie Deray, Dinesh Atchuthan @cite Sol2018AML\n\nPython prototype (for reference only):\n```python3\nRodrigues(src[, dst[, jacobian]]) -> dst, jacobian\n```","ref":"Evision.html#rodrigues/2"},{"type":"function","title":"Evision.rotate/1","doc":"","ref":"Evision.html#rotate/1"},{"type":"function","title":"Evision.rotate/2","doc":"Rotates a 2D array in multiples of 90 degrees.\nThe function cv::rotate rotates the array in one of three different ways:\nRotate by 90 degrees clockwise (rotateCode = ROTATE_90_CLOCKWISE).\nRotate by 180 degrees clockwise (rotateCode = ROTATE_180).\nRotate by 270 degrees clockwise (rotateCode = ROTATE_90_COUNTERCLOCKWISE).\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array.\n\n- **rotateCode**: `integer()`.\n\n  an enum to specify how to rotate the array; see the enum #RotateFlags\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same type as src.  The size is the same with ROTATE_180,\n  and the rows and cols are switched for ROTATE_90_CLOCKWISE and ROTATE_90_COUNTERCLOCKWISE.\n\n@sa transpose, repeat, completeSymm, flip, RotateFlags\n\nPython prototype (for reference only):\n```python3\nrotate(src, rotateCode[, dst]) -> dst\n```","ref":"Evision.html#rotate/2"},{"type":"function","title":"Evision.rotate/3","doc":"Rotates a 2D array in multiples of 90 degrees.\nThe function cv::rotate rotates the array in one of three different ways:\nRotate by 90 degrees clockwise (rotateCode = ROTATE_90_CLOCKWISE).\nRotate by 180 degrees clockwise (rotateCode = ROTATE_180).\nRotate by 270 degrees clockwise (rotateCode = ROTATE_90_COUNTERCLOCKWISE).\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array.\n\n- **rotateCode**: `integer()`.\n\n  an enum to specify how to rotate the array; see the enum #RotateFlags\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same type as src.  The size is the same with ROTATE_180,\n  and the rows and cols are switched for ROTATE_90_CLOCKWISE and ROTATE_90_COUNTERCLOCKWISE.\n\n@sa transpose, repeat, completeSymm, flip, RotateFlags\n\nPython prototype (for reference only):\n```python3\nrotate(src, rotateCode[, dst]) -> dst\n```","ref":"Evision.html#rotate/3"},{"type":"function","title":"Evision.rotatedRectangleIntersection/1","doc":"","ref":"Evision.html#rotatedRectangleIntersection/1"},{"type":"function","title":"Evision.rotatedRectangleIntersection/2","doc":"Finds out if there is any intersection between two rotated rectangles.\n\n##### Positional Arguments\n- **rect1**: `{centre={x, y}, size={s1, s2}, angle}`.\n\n  First rectangle\n\n- **rect2**: `{centre={x, y}, size={s1, s2}, angle}`.\n\n  Second rectangle\n\n##### Return\n- **retval**: `integer()`\n- **intersectingRegion**: `Evision.Mat.t()`.\n\n  The output array of the vertices of the intersecting region. It returns\n  at most 8 vertices. Stored as std::vector\\  or cv::Mat as Mx1 of type CV_32FC2.\n\nIf there is then the vertices of the intersecting region are returned as well.\nBelow are some examples of intersection configurations. The hatched pattern indicates the\nintersecting region and the red vertices are returned by the function.\n![intersection examples](pics/intersection.png)\n@returns One of #RectanglesIntersectTypes\n\nPython prototype (for reference only):\n```python3\nrotatedRectangleIntersection(rect1, rect2[, intersectingRegion]) -> retval, intersectingRegion\n```","ref":"Evision.html#rotatedRectangleIntersection/2"},{"type":"function","title":"Evision.rotatedRectangleIntersection/3","doc":"Finds out if there is any intersection between two rotated rectangles.\n\n##### Positional Arguments\n- **rect1**: `{centre={x, y}, size={s1, s2}, angle}`.\n\n  First rectangle\n\n- **rect2**: `{centre={x, y}, size={s1, s2}, angle}`.\n\n  Second rectangle\n\n##### Return\n- **retval**: `integer()`\n- **intersectingRegion**: `Evision.Mat.t()`.\n\n  The output array of the vertices of the intersecting region. It returns\n  at most 8 vertices. Stored as std::vector\\  or cv::Mat as Mx1 of type CV_32FC2.\n\nIf there is then the vertices of the intersecting region are returned as well.\nBelow are some examples of intersection configurations. The hatched pattern indicates the\nintersecting region and the red vertices are returned by the function.\n![intersection examples](pics/intersection.png)\n@returns One of #RectanglesIntersectTypes\n\nPython prototype (for reference only):\n```python3\nrotatedRectangleIntersection(rect1, rect2[, intersectingRegion]) -> retval, intersectingRegion\n```","ref":"Evision.html#rotatedRectangleIntersection/3"},{"type":"function","title":"Evision.rqDecomp3x3/1","doc":"Computes an RQ decomposition of 3x3 matrices.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  3x3 input matrix.\n\n##### Return\n- **retval**: `Vec3d`\n- **mtxR**: `Evision.Mat.t()`.\n\n  Output 3x3 upper-triangular matrix.\n\n- **mtxQ**: `Evision.Mat.t()`.\n\n  Output 3x3 orthogonal matrix.\n\n- **qx**: `Evision.Mat.t()`.\n\n  Optional output 3x3 rotation matrix around x-axis.\n\n- **qy**: `Evision.Mat.t()`.\n\n  Optional output 3x3 rotation matrix around y-axis.\n\n- **qz**: `Evision.Mat.t()`.\n\n  Optional output 3x3 rotation matrix around z-axis.\n\nThe function computes a RQ decomposition using the given rotations. This function is used in\n#decomposeProjectionMatrix to decompose the left 3x3 submatrix of a projection matrix into a camera\nand a rotation matrix.\nIt optionally returns three rotation matrices, one for each axis, and the three Euler angles in\ndegrees (as the return value) that could be used in OpenGL. Note, there is always more than one\nsequence of rotations about the three principal axes that results in the same orientation of an\nobject, e.g. see @cite Slabaugh . Returned three rotation matrices and corresponding three Euler angles\nare only one of the possible solutions.\n\nPython prototype (for reference only):\n```python3\nRQDecomp3x3(src[, mtxR[, mtxQ[, Qx[, Qy[, Qz]]]]]) -> retval, mtxR, mtxQ, Qx, Qy, Qz\n```","ref":"Evision.html#rqDecomp3x3/1"},{"type":"function","title":"Evision.rqDecomp3x3/2","doc":"Computes an RQ decomposition of 3x3 matrices.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  3x3 input matrix.\n\n##### Return\n- **retval**: `Vec3d`\n- **mtxR**: `Evision.Mat.t()`.\n\n  Output 3x3 upper-triangular matrix.\n\n- **mtxQ**: `Evision.Mat.t()`.\n\n  Output 3x3 orthogonal matrix.\n\n- **qx**: `Evision.Mat.t()`.\n\n  Optional output 3x3 rotation matrix around x-axis.\n\n- **qy**: `Evision.Mat.t()`.\n\n  Optional output 3x3 rotation matrix around y-axis.\n\n- **qz**: `Evision.Mat.t()`.\n\n  Optional output 3x3 rotation matrix around z-axis.\n\nThe function computes a RQ decomposition using the given rotations. This function is used in\n#decomposeProjectionMatrix to decompose the left 3x3 submatrix of a projection matrix into a camera\nand a rotation matrix.\nIt optionally returns three rotation matrices, one for each axis, and the three Euler angles in\ndegrees (as the return value) that could be used in OpenGL. Note, there is always more than one\nsequence of rotations about the three principal axes that results in the same orientation of an\nobject, e.g. see @cite Slabaugh . Returned three rotation matrices and corresponding three Euler angles\nare only one of the possible solutions.\n\nPython prototype (for reference only):\n```python3\nRQDecomp3x3(src[, mtxR[, mtxQ[, Qx[, Qy[, Qz]]]]]) -> retval, mtxR, mtxQ, Qx, Qy, Qz\n```","ref":"Evision.html#rqDecomp3x3/2"},{"type":"function","title":"Evision.sampsonDistance/1","doc":"","ref":"Evision.html#sampsonDistance/1"},{"type":"function","title":"Evision.sampsonDistance/3","doc":"Calculates the Sampson Distance between two points.\n\n##### Positional Arguments\n- **pt1**: `Evision.Mat`.\n\n  first homogeneous 2d point\n\n- **pt2**: `Evision.Mat`.\n\n  second homogeneous 2d point\n\n- **f**: `Evision.Mat`.\n\n  fundamental matrix\n\n##### Return\n- **retval**: `double`\n\nThe function cv::sampsonDistance calculates and returns the first order approximation of the geometric error as:\n\\f[\nsd( \\texttt{pt1} , \\texttt{pt2} )=\n\\frac{(\\texttt{pt2}^t \\cdot \\texttt{F} \\cdot \\texttt{pt1})^2}\n{((\\texttt{F} \\cdot \\texttt{pt1})(0))^2 +\n((\\texttt{F} \\cdot \\texttt{pt1})(1))^2 +\n((\\texttt{F}^t \\cdot \\texttt{pt2})(0))^2 +\n((\\texttt{F}^t \\cdot \\texttt{pt2})(1))^2}\n\\f]\nThe fundamental matrix may be calculated using the #findFundamentalMat function. See @cite HartleyZ00 11.4.3 for details.\n@return The computed Sampson distance.\n\nPython prototype (for reference only):\n```python3\nsampsonDistance(pt1, pt2, F) -> retval\n```","ref":"Evision.html#sampsonDistance/3"},{"type":"function","title":"Evision.scaleAdd/1","doc":"","ref":"Evision.html#scaleAdd/1"},{"type":"function","title":"Evision.scaleAdd/3","doc":"Calculates the sum of a scaled array and another array.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array.\n\n- **alpha**: `double`.\n\n  scale factor for the first array.\n\n- **src2**: `Evision.Mat`.\n\n  second input array of the same size and type as src1.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src1.\n\nThe function scaleAdd is one of the classical primitive linear algebra operations, known as DAXPY\nor SAXPY in [BLAS](http://en.wikipedia.org/wiki/Basic_Linear_Algebra_Subprograms). It calculates\nthe sum of a scaled array and another array:\n\\f[\\texttt{dst} (I)= \\texttt{scale} \\cdot \\texttt{src1} (I) +  \\texttt{src2} (I)\\f]\nThe function can also be emulated with a matrix expression, for example:\n```cpp\nMat A(3, 3, CV_64F);\n...\nA.row(0) = A.row(1)*2 + A.row(2);\n```\n@sa add, addWeighted, subtract, Mat::dot, Mat::convertTo\n\nPython prototype (for reference only):\n```python3\nscaleAdd(src1, alpha, src2[, dst]) -> dst\n```","ref":"Evision.html#scaleAdd/3"},{"type":"function","title":"Evision.scaleAdd/4","doc":"Calculates the sum of a scaled array and another array.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array.\n\n- **alpha**: `double`.\n\n  scale factor for the first array.\n\n- **src2**: `Evision.Mat`.\n\n  second input array of the same size and type as src1.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src1.\n\nThe function scaleAdd is one of the classical primitive linear algebra operations, known as DAXPY\nor SAXPY in [BLAS](http://en.wikipedia.org/wiki/Basic_Linear_Algebra_Subprograms). It calculates\nthe sum of a scaled array and another array:\n\\f[\\texttt{dst} (I)= \\texttt{scale} \\cdot \\texttt{src1} (I) +  \\texttt{src2} (I)\\f]\nThe function can also be emulated with a matrix expression, for example:\n```cpp\nMat A(3, 3, CV_64F);\n...\nA.row(0) = A.row(1)*2 + A.row(2);\n```\n@sa add, addWeighted, subtract, Mat::dot, Mat::convertTo\n\nPython prototype (for reference only):\n```python3\nscaleAdd(src1, alpha, src2[, dst]) -> dst\n```","ref":"Evision.html#scaleAdd/4"},{"type":"function","title":"Evision.scharr/1","doc":"","ref":"Evision.html#scharr/1"},{"type":"function","title":"Evision.scharr/4","doc":"Calculates the first x- or y- image derivative using Scharr operator.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image.\n\n- **ddepth**: `integer()`.\n\n  output image depth, see @ref filter_depths \"combinations\"\n\n- **dx**: `integer()`.\n\n  order of the derivative x.\n\n- **dy**: `integer()`.\n\n  order of the derivative y.\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  optional scale factor for the computed derivative values; by default, no scaling is\n  applied (see #getDerivKernels for details).\n\n- **delta**: `double`.\n\n  optional delta value that is added to the results prior to storing them in dst.\n\n- **borderType**: `integer()`.\n\n  pixel extrapolation method, see #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and the same number of channels as src.\n\nThe function computes the first x- or y- spatial image derivative using the Scharr operator. The\ncall\n\\f[\\texttt{Scharr(src, dst, ddepth, dx, dy, scale, delta, borderType)}\\f]\nis equivalent to\n\\f[\\texttt{Sobel(src, dst, ddepth, dx, dy, FILTER\\_SCHARR, scale, delta, borderType)} .\\f]\n@sa  cartToPolar\n\nPython prototype (for reference only):\n```python3\nScharr(src, ddepth, dx, dy[, dst[, scale[, delta[, borderType]]]]) -> dst\n```","ref":"Evision.html#scharr/4"},{"type":"function","title":"Evision.scharr/5","doc":"Calculates the first x- or y- image derivative using Scharr operator.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image.\n\n- **ddepth**: `integer()`.\n\n  output image depth, see @ref filter_depths \"combinations\"\n\n- **dx**: `integer()`.\n\n  order of the derivative x.\n\n- **dy**: `integer()`.\n\n  order of the derivative y.\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  optional scale factor for the computed derivative values; by default, no scaling is\n  applied (see #getDerivKernels for details).\n\n- **delta**: `double`.\n\n  optional delta value that is added to the results prior to storing them in dst.\n\n- **borderType**: `integer()`.\n\n  pixel extrapolation method, see #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and the same number of channels as src.\n\nThe function computes the first x- or y- spatial image derivative using the Scharr operator. The\ncall\n\\f[\\texttt{Scharr(src, dst, ddepth, dx, dy, scale, delta, borderType)}\\f]\nis equivalent to\n\\f[\\texttt{Sobel(src, dst, ddepth, dx, dy, FILTER\\_SCHARR, scale, delta, borderType)} .\\f]\n@sa  cartToPolar\n\nPython prototype (for reference only):\n```python3\nScharr(src, ddepth, dx, dy[, dst[, scale[, delta[, borderType]]]]) -> dst\n```","ref":"Evision.html#scharr/5"},{"type":"function","title":"Evision.seamlessClone/1","doc":"","ref":"Evision.html#seamlessClone/1"},{"type":"function","title":"Evision.seamlessClone/5","doc":"Image editing tasks concern either global changes (color/intensity corrections, filters,\ndeformations) or local changes concerned to a selection. Here we are interested in achieving local\nchanges, ones that are restricted to a region manually selected (ROI), in a seamless and effortless\nmanner. The extent of the changes ranges from slight distortions to complete replacement by novel\ncontent @cite PM03 .\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n- **dst**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n- **mask**: `Evision.Mat`.\n\n  Input 8-bit 1 or 3-channel image.\n\n- **p**: `Point`.\n\n  Point in dst image where object is placed.\n\n- **flags**: `integer()`.\n\n  Cloning method that could be cv::NORMAL_CLONE, cv::MIXED_CLONE or cv::MONOCHROME_TRANSFER\n\n##### Return\n- **blend**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as dst.\n\nPython prototype (for reference only):\n```python3\nseamlessClone(src, dst, mask, p, flags[, blend]) -> blend\n```","ref":"Evision.html#seamlessClone/5"},{"type":"function","title":"Evision.seamlessClone/6","doc":"Image editing tasks concern either global changes (color/intensity corrections, filters,\ndeformations) or local changes concerned to a selection. Here we are interested in achieving local\nchanges, ones that are restricted to a region manually selected (ROI), in a seamless and effortless\nmanner. The extent of the changes ranges from slight distortions to complete replacement by novel\ncontent @cite PM03 .\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n- **dst**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n- **mask**: `Evision.Mat`.\n\n  Input 8-bit 1 or 3-channel image.\n\n- **p**: `Point`.\n\n  Point in dst image where object is placed.\n\n- **flags**: `integer()`.\n\n  Cloning method that could be cv::NORMAL_CLONE, cv::MIXED_CLONE or cv::MONOCHROME_TRANSFER\n\n##### Return\n- **blend**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as dst.\n\nPython prototype (for reference only):\n```python3\nseamlessClone(src, dst, mask, p, flags[, blend]) -> blend\n```","ref":"Evision.html#seamlessClone/6"},{"type":"function","title":"Evision.selectROI/1","doc":"selectROI\n\n##### Positional Arguments\n- **img**: `Evision.Mat`\n\n##### Keyword Arguments\n- **showCrosshair**: `bool`.\n- **fromCenter**: `bool`.\n- **printNotice**: `bool`.\n\n##### Return\n- **retval**: `Rect`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nselectROI(img[, showCrosshair[, fromCenter[, printNotice]]]) -> retval\n```","ref":"Evision.html#selectROI/1"},{"type":"function","title":"Evision.selectROI/2","doc":"#### Variant 1:\nAllows users to select a ROI on the given image.\n\n##### Positional Arguments\n- **windowName**: `String`.\n\n  name of the window where selection process will be shown.\n\n- **img**: `Evision.Mat`.\n\n  image to select a ROI.\n\n##### Keyword Arguments\n- **showCrosshair**: `bool`.\n\n  if true crosshair of selection rectangle will be shown.\n\n- **fromCenter**: `bool`.\n\n  if true center of selection will match initial mouse position. In opposite case a corner of\n  selection rectangle will correspont to the initial mouse position.\n\n- **printNotice**: `bool`.\n\n  if true a notice to select ROI or cancel selection will be printed in console.\n\n##### Return\n- **retval**: `Rect`\n\nThe function creates a window and allows users to select a ROI using the mouse.\nControls: use `space` or `enter` to finish selection, use key `c` to cancel selection (function will return the zero cv::Rect).\n@return selected ROI or empty rect if selection canceled.\n**Note**: The function sets it's own mouse callback for specified window using cv::setMouseCallback(windowName, ...).\nAfter finish of work an empty callback will be set for the used window.\n\nPython prototype (for reference only):\n```python3\nselectROI(windowName, img[, showCrosshair[, fromCenter[, printNotice]]]) -> retval\n```\n#### Variant 2:\nselectROI\n\n##### Positional Arguments\n- **img**: `Evision.Mat`\n\n##### Keyword Arguments\n- **showCrosshair**: `bool`.\n- **fromCenter**: `bool`.\n- **printNotice**: `bool`.\n\n##### Return\n- **retval**: `Rect`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nselectROI(img[, showCrosshair[, fromCenter[, printNotice]]]) -> retval\n```","ref":"Evision.html#selectROI/2"},{"type":"function","title":"Evision.selectROI/3","doc":"Allows users to select a ROI on the given image.\n\n##### Positional Arguments\n- **windowName**: `String`.\n\n  name of the window where selection process will be shown.\n\n- **img**: `Evision.Mat`.\n\n  image to select a ROI.\n\n##### Keyword Arguments\n- **showCrosshair**: `bool`.\n\n  if true crosshair of selection rectangle will be shown.\n\n- **fromCenter**: `bool`.\n\n  if true center of selection will match initial mouse position. In opposite case a corner of\n  selection rectangle will correspont to the initial mouse position.\n\n- **printNotice**: `bool`.\n\n  if true a notice to select ROI or cancel selection will be printed in console.\n\n##### Return\n- **retval**: `Rect`\n\nThe function creates a window and allows users to select a ROI using the mouse.\nControls: use `space` or `enter` to finish selection, use key `c` to cancel selection (function will return the zero cv::Rect).\n@return selected ROI or empty rect if selection canceled.\n**Note**: The function sets it's own mouse callback for specified window using cv::setMouseCallback(windowName, ...).\nAfter finish of work an empty callback will be set for the used window.\n\nPython prototype (for reference only):\n```python3\nselectROI(windowName, img[, showCrosshair[, fromCenter[, printNotice]]]) -> retval\n```","ref":"Evision.html#selectROI/3"},{"type":"function","title":"Evision.selectROIs/1","doc":"","ref":"Evision.html#selectROIs/1"},{"type":"function","title":"Evision.selectROIs/2","doc":"Allows users to select multiple ROIs on the given image.\n\n##### Positional Arguments\n- **windowName**: `String`.\n\n  name of the window where selection process will be shown.\n\n- **img**: `Evision.Mat`.\n\n  image to select a ROI.\n\n##### Keyword Arguments\n- **showCrosshair**: `bool`.\n\n  if true crosshair of selection rectangle will be shown.\n\n- **fromCenter**: `bool`.\n\n  if true center of selection will match initial mouse position. In opposite case a corner of\n  selection rectangle will correspont to the initial mouse position.\n\n- **printNotice**: `bool`.\n\n  if true a notice to select ROI or cancel selection will be printed in console.\n\n##### Return\n- **boundingBoxes**: `[Rect]`.\n\n  selected ROIs.\n\nThe function creates a window and allows users to select multiple ROIs using the mouse.\nControls: use `space` or `enter` to finish current selection and start a new one,\nuse `esc` to terminate multiple ROI selection process.\n\n**Note**: The function sets it's own mouse callback for specified window using cv::setMouseCallback(windowName, ...).\nAfter finish of work an empty callback will be set for the used window.\n\nPython prototype (for reference only):\n```python3\nselectROIs(windowName, img[, showCrosshair[, fromCenter[, printNotice]]]) -> boundingBoxes\n```","ref":"Evision.html#selectROIs/2"},{"type":"function","title":"Evision.selectROIs/3","doc":"Allows users to select multiple ROIs on the given image.\n\n##### Positional Arguments\n- **windowName**: `String`.\n\n  name of the window where selection process will be shown.\n\n- **img**: `Evision.Mat`.\n\n  image to select a ROI.\n\n##### Keyword Arguments\n- **showCrosshair**: `bool`.\n\n  if true crosshair of selection rectangle will be shown.\n\n- **fromCenter**: `bool`.\n\n  if true center of selection will match initial mouse position. In opposite case a corner of\n  selection rectangle will correspont to the initial mouse position.\n\n- **printNotice**: `bool`.\n\n  if true a notice to select ROI or cancel selection will be printed in console.\n\n##### Return\n- **boundingBoxes**: `[Rect]`.\n\n  selected ROIs.\n\nThe function creates a window and allows users to select multiple ROIs using the mouse.\nControls: use `space` or `enter` to finish current selection and start a new one,\nuse `esc` to terminate multiple ROI selection process.\n\n**Note**: The function sets it's own mouse callback for specified window using cv::setMouseCallback(windowName, ...).\nAfter finish of work an empty callback will be set for the used window.\n\nPython prototype (for reference only):\n```python3\nselectROIs(windowName, img[, showCrosshair[, fromCenter[, printNotice]]]) -> boundingBoxes\n```","ref":"Evision.html#selectROIs/3"},{"type":"function","title":"Evision.sepFilter2D/1","doc":"","ref":"Evision.html#sepFilter2D/1"},{"type":"function","title":"Evision.sepFilter2D/4","doc":"Applies a separable linear filter to an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image.\n\n- **ddepth**: `integer()`.\n\n  Destination image depth, see @ref filter_depths \"combinations\"\n\n- **kernelX**: `Evision.Mat`.\n\n  Coefficients for filtering each row.\n\n- **kernelY**: `Evision.Mat`.\n\n  Coefficients for filtering each column.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor position within the kernel. The default value \\f$(-1,-1)\\f$ means that the anchor\n  is at the kernel center.\n\n- **delta**: `double`.\n\n  Value added to the filtered results before storing them.\n\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method, see #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and the same number of channels as src .\n\nThe function applies a separable linear filter to the image. That is, first, every row of src is\nfiltered with the 1D kernel kernelX. Then, every column of the result is filtered with the 1D\nkernel kernelY. The final result shifted by delta is stored in dst .\n@sa  filter2D, Sobel, GaussianBlur, boxFilter, blur\n\nPython prototype (for reference only):\n```python3\nsepFilter2D(src, ddepth, kernelX, kernelY[, dst[, anchor[, delta[, borderType]]]]) -> dst\n```","ref":"Evision.html#sepFilter2D/4"},{"type":"function","title":"Evision.sepFilter2D/5","doc":"Applies a separable linear filter to an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image.\n\n- **ddepth**: `integer()`.\n\n  Destination image depth, see @ref filter_depths \"combinations\"\n\n- **kernelX**: `Evision.Mat`.\n\n  Coefficients for filtering each row.\n\n- **kernelY**: `Evision.Mat`.\n\n  Coefficients for filtering each column.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor position within the kernel. The default value \\f$(-1,-1)\\f$ means that the anchor\n  is at the kernel center.\n\n- **delta**: `double`.\n\n  Value added to the filtered results before storing them.\n\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method, see #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and the same number of channels as src .\n\nThe function applies a separable linear filter to the image. That is, first, every row of src is\nfiltered with the 1D kernel kernelX. Then, every column of the result is filtered with the 1D\nkernel kernelY. The final result shifted by delta is stored in dst .\n@sa  filter2D, Sobel, GaussianBlur, boxFilter, blur\n\nPython prototype (for reference only):\n```python3\nsepFilter2D(src, ddepth, kernelX, kernelY[, dst[, anchor[, delta[, borderType]]]]) -> dst\n```","ref":"Evision.html#sepFilter2D/5"},{"type":"function","title":"Evision.setIdentity/1","doc":"Initializes a scaled identity matrix.\n##### Keyword Arguments\n- **s**: `Evision.scalar()`.\n\n  value to assign to diagonal elements.\n\n##### Return\n- **mtx**: `Evision.Mat.t()`.\n\n  matrix to initialize (not necessarily square).\n\nThe function cv::setIdentity initializes a scaled identity matrix:\n\\f[\\texttt{mtx} (i,j)= \\fork{\\texttt{value}}{ if \\(i=j\\)}{0}{otherwise}\\f]\nThe function can also be emulated using the matrix initializers and the\nmatrix expressions:\n```\nMat A = Mat::eye(4, 3, CV_32F)*5;\n// A will be set to [[5, 0, 0], [0, 5, 0], [0, 0, 5], [0, 0, 0]]\n```\n@sa Mat::zeros, Mat::ones, Mat::setTo, Mat::operator=\n\nPython prototype (for reference only):\n```python3\nsetIdentity(mtx[, s]) -> mtx\n```","ref":"Evision.html#setIdentity/1"},{"type":"function","title":"Evision.setIdentity/2","doc":"Initializes a scaled identity matrix.\n##### Keyword Arguments\n- **s**: `Evision.scalar()`.\n\n  value to assign to diagonal elements.\n\n##### Return\n- **mtx**: `Evision.Mat.t()`.\n\n  matrix to initialize (not necessarily square).\n\nThe function cv::setIdentity initializes a scaled identity matrix:\n\\f[\\texttt{mtx} (i,j)= \\fork{\\texttt{value}}{ if \\(i=j\\)}{0}{otherwise}\\f]\nThe function can also be emulated using the matrix initializers and the\nmatrix expressions:\n```\nMat A = Mat::eye(4, 3, CV_32F)*5;\n// A will be set to [[5, 0, 0], [0, 5, 0], [0, 0, 5], [0, 0, 0]]\n```\n@sa Mat::zeros, Mat::ones, Mat::setTo, Mat::operator=\n\nPython prototype (for reference only):\n```python3\nsetIdentity(mtx[, s]) -> mtx\n```","ref":"Evision.html#setIdentity/2"},{"type":"function","title":"Evision.setLogLevel/1","doc":"setLogLevel\n\n##### Positional Arguments\n- **level**: `integer()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetLogLevel(level) -> retval\n```","ref":"Evision.html#setLogLevel/1"},{"type":"function","title":"Evision.setNumThreads/1","doc":"OpenCV will try to set the number of threads for subsequent parallel regions.\n\n##### Positional Arguments\n- **nthreads**: `integer()`.\n\n  Number of threads used by OpenCV.\n\nIf threads == 1, OpenCV will disable threading optimizations and run all it's functions\nsequentially. Passing threads \\< 0 will reset threads number to system default.\nThe function is not thread-safe. It must not be called in parallel region or concurrent threads.\nOpenCV will try to run its functions with specified threads number, but some behaviour differs from\nframework:\n- `TBB` - User-defined parallel constructions will run with the same threads number, if\n  another is not specified. If later on user creates his own scheduler, OpenCV will use it.\n\n- `OpenMP` - No special defined behaviour.\n- `Concurrency` - If threads == 1, OpenCV will disable threading optimizations and run its\n  functions sequentially.\n\n- `GCD` - Supports only values \\<= 0.\n- `C=` - No special defined behaviour.\n@sa getNumThreads, getThreadNum\n\nPython prototype (for reference only):\n```python3\nsetNumThreads(nthreads) -> None\n```","ref":"Evision.html#setNumThreads/1"},{"type":"function","title":"Evision.setRNGSeed/1","doc":"Sets state of default random number generator.\n\n##### Positional Arguments\n- **seed**: `integer()`.\n\n  new state for default random number generator\n\nThe function cv::setRNGSeed sets state of default random number generator to custom value.\n@sa RNG, randu, randn\n\nPython prototype (for reference only):\n```python3\nsetRNGSeed(seed) -> None\n```","ref":"Evision.html#setRNGSeed/1"},{"type":"function","title":"Evision.setTrackbarMax/1","doc":"","ref":"Evision.html#setTrackbarMax/1"},{"type":"function","title":"Evision.setTrackbarMax/3","doc":"Sets the trackbar maximum position.\n\n##### Positional Arguments\n- **trackbarname**: `String`.\n\n  Name of the trackbar.\n\n- **winname**: `String`.\n\n  Name of the window that is the parent of trackbar.\n\n- **maxval**: `integer()`.\n\n  New maximum position.\n\nThe function sets the maximum position of the specified trackbar in the specified window.\n**Note**: [__Qt Backend Only__] winname can be empty if the trackbar is attached to the control\npanel.\n\nPython prototype (for reference only):\n```python3\nsetTrackbarMax(trackbarname, winname, maxval) -> None\n```","ref":"Evision.html#setTrackbarMax/3"},{"type":"function","title":"Evision.setTrackbarMin/1","doc":"","ref":"Evision.html#setTrackbarMin/1"},{"type":"function","title":"Evision.setTrackbarMin/3","doc":"Sets the trackbar minimum position.\n\n##### Positional Arguments\n- **trackbarname**: `String`.\n\n  Name of the trackbar.\n\n- **winname**: `String`.\n\n  Name of the window that is the parent of trackbar.\n\n- **minval**: `integer()`.\n\n  New minimum position.\n\nThe function sets the minimum position of the specified trackbar in the specified window.\n**Note**: [__Qt Backend Only__] winname can be empty if the trackbar is attached to the control\npanel.\n\nPython prototype (for reference only):\n```python3\nsetTrackbarMin(trackbarname, winname, minval) -> None\n```","ref":"Evision.html#setTrackbarMin/3"},{"type":"function","title":"Evision.setTrackbarPos/1","doc":"","ref":"Evision.html#setTrackbarPos/1"},{"type":"function","title":"Evision.setTrackbarPos/3","doc":"Sets the trackbar position.\n\n##### Positional Arguments\n- **trackbarname**: `String`.\n\n  Name of the trackbar.\n\n- **winname**: `String`.\n\n  Name of the window that is the parent of trackbar.\n\n- **pos**: `integer()`.\n\n  New position.\n\nThe function sets the position of the specified trackbar in the specified window.\n**Note**: [__Qt Backend Only__] winname can be empty if the trackbar is attached to the control\npanel.\n\nPython prototype (for reference only):\n```python3\nsetTrackbarPos(trackbarname, winname, pos) -> None\n```","ref":"Evision.html#setTrackbarPos/3"},{"type":"function","title":"Evision.setUseOpenVX/1","doc":"setUseOpenVX\n\n##### Positional Arguments\n- **flag**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetUseOpenVX(flag) -> None\n```","ref":"Evision.html#setUseOpenVX/1"},{"type":"function","title":"Evision.setUseOptimized/1","doc":"Enables or disables the optimized code.\n\n##### Positional Arguments\n- **onoff**: `bool`.\n\n  The boolean flag specifying whether the optimized code should be used (onoff=true)\n  or not (onoff=false).\n\nThe function can be used to dynamically turn on and off optimized dispatched code (code that uses SSE4.2, AVX/AVX2,\nand other instructions on the platforms that support it). It sets a global flag that is further\nchecked by OpenCV functions. Since the flag is not checked in the inner OpenCV loops, it is only\nsafe to call the function on the very top level in your application where you can be sure that no\nother OpenCV function is currently executed.\nBy default, the optimized code is enabled unless you disable it in CMake. The current status can be\nretrieved using useOptimized.\n\nPython prototype (for reference only):\n```python3\nsetUseOptimized(onoff) -> None\n```","ref":"Evision.html#setUseOptimized/1"},{"type":"function","title":"Evision.setWindowProperty/1","doc":"","ref":"Evision.html#setWindowProperty/1"},{"type":"function","title":"Evision.setWindowProperty/3","doc":"Changes parameters of a window dynamically.\n\n##### Positional Arguments\n- **winname**: `String`.\n\n  Name of the window.\n\n- **prop_id**: `integer()`.\n\n  Window property to edit. The supported operation flags are: (cv::WindowPropertyFlags)\n\n- **prop_value**: `double`.\n\n  New value of the window property. The supported flags are: (cv::WindowFlags)\n\nThe function setWindowProperty enables changing properties of a window.\n\n**Note**: [__Wayland Backend Only__] This function is not supported.\n\nPython prototype (for reference only):\n```python3\nsetWindowProperty(winname, prop_id, prop_value) -> None\n```","ref":"Evision.html#setWindowProperty/3"},{"type":"function","title":"Evision.setWindowTitle/1","doc":"","ref":"Evision.html#setWindowTitle/1"},{"type":"function","title":"Evision.setWindowTitle/2","doc":"Updates window title\n\n##### Positional Arguments\n- **winname**: `String`.\n\n  Name of the window.\n\n- **title**: `String`.\n\n  New title.\n\nPython prototype (for reference only):\n```python3\nsetWindowTitle(winname, title) -> None\n```","ref":"Evision.html#setWindowTitle/2"},{"type":"function","title":"Evision.sobel/1","doc":"","ref":"Evision.html#sobel/1"},{"type":"function","title":"Evision.sobel/4","doc":"Calculates the first, second, third, or mixed image derivatives using an extended Sobel operator.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image.\n\n- **ddepth**: `integer()`.\n\n  output image depth, see @ref filter_depths \"combinations\"; in the case of\n  8-bit input images it will result in truncated derivatives.\n\n- **dx**: `integer()`.\n\n  order of the derivative x.\n\n- **dy**: `integer()`.\n\n  order of the derivative y.\n\n##### Keyword Arguments\n- **ksize**: `integer()`.\n\n  size of the extended Sobel kernel; it must be 1, 3, 5, or 7.\n\n- **scale**: `double`.\n\n  optional scale factor for the computed derivative values; by default, no scaling is\n  applied (see #getDerivKernels for details).\n\n- **delta**: `double`.\n\n  optional delta value that is added to the results prior to storing them in dst.\n\n- **borderType**: `integer()`.\n\n  pixel extrapolation method, see #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and the same number of channels as src .\n\nIn all cases except one, the \\f$\\texttt{ksize} \\times \\texttt{ksize}\\f$ separable kernel is used to\ncalculate the derivative. When \\f$\\texttt{ksize = 1}\\f$, the \\f$3 \\times 1\\f$ or \\f$1 \\times 3\\f$\nkernel is used (that is, no Gaussian smoothing is done). `ksize = 1` can only be used for the first\nor the second x- or y- derivatives.\nThere is also the special value `ksize = #FILTER_SCHARR (-1)` that corresponds to the \\f$3\\times3\\f$ Scharr\nfilter that may give more accurate results than the \\f$3\\times3\\f$ Sobel. The Scharr aperture is\n\\f[\\vecthreethree{-3}{0}{3}{-10}{0}{10}{-3}{0}{3}\\f]\nfor the x-derivative, or transposed for the y-derivative.\nThe function calculates an image derivative by convolving the image with the appropriate kernel:\n\\f[\\texttt{dst} =  \\frac{\\partial^{xorder+yorder} \\texttt{src}}{\\partial x^{xorder} \\partial y^{yorder}}\\f]\nThe Sobel operators combine Gaussian smoothing and differentiation, so the result is more or less\nresistant to the noise. Most often, the function is called with ( xorder = 1, yorder = 0, ksize = 3)\nor ( xorder = 0, yorder = 1, ksize = 3) to calculate the first x- or y- image derivative. The first\ncase corresponds to a kernel of:\n\\f[\\vecthreethree{-1}{0}{1}{-2}{0}{2}{-1}{0}{1}\\f]\nThe second case corresponds to a kernel of:\n\\f[\\vecthreethree{-1}{-2}{-1}{0}{0}{0}{1}{2}{1}\\f]\n@sa  Scharr, Laplacian, sepFilter2D, filter2D, GaussianBlur, cartToPolar\n\nPython prototype (for reference only):\n```python3\nSobel(src, ddepth, dx, dy[, dst[, ksize[, scale[, delta[, borderType]]]]]) -> dst\n```","ref":"Evision.html#sobel/4"},{"type":"function","title":"Evision.sobel/5","doc":"Calculates the first, second, third, or mixed image derivatives using an extended Sobel operator.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image.\n\n- **ddepth**: `integer()`.\n\n  output image depth, see @ref filter_depths \"combinations\"; in the case of\n  8-bit input images it will result in truncated derivatives.\n\n- **dx**: `integer()`.\n\n  order of the derivative x.\n\n- **dy**: `integer()`.\n\n  order of the derivative y.\n\n##### Keyword Arguments\n- **ksize**: `integer()`.\n\n  size of the extended Sobel kernel; it must be 1, 3, 5, or 7.\n\n- **scale**: `double`.\n\n  optional scale factor for the computed derivative values; by default, no scaling is\n  applied (see #getDerivKernels for details).\n\n- **delta**: `double`.\n\n  optional delta value that is added to the results prior to storing them in dst.\n\n- **borderType**: `integer()`.\n\n  pixel extrapolation method, see #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and the same number of channels as src .\n\nIn all cases except one, the \\f$\\texttt{ksize} \\times \\texttt{ksize}\\f$ separable kernel is used to\ncalculate the derivative. When \\f$\\texttt{ksize = 1}\\f$, the \\f$3 \\times 1\\f$ or \\f$1 \\times 3\\f$\nkernel is used (that is, no Gaussian smoothing is done). `ksize = 1` can only be used for the first\nor the second x- or y- derivatives.\nThere is also the special value `ksize = #FILTER_SCHARR (-1)` that corresponds to the \\f$3\\times3\\f$ Scharr\nfilter that may give more accurate results than the \\f$3\\times3\\f$ Sobel. The Scharr aperture is\n\\f[\\vecthreethree{-3}{0}{3}{-10}{0}{10}{-3}{0}{3}\\f]\nfor the x-derivative, or transposed for the y-derivative.\nThe function calculates an image derivative by convolving the image with the appropriate kernel:\n\\f[\\texttt{dst} =  \\frac{\\partial^{xorder+yorder} \\texttt{src}}{\\partial x^{xorder} \\partial y^{yorder}}\\f]\nThe Sobel operators combine Gaussian smoothing and differentiation, so the result is more or less\nresistant to the noise. Most often, the function is called with ( xorder = 1, yorder = 0, ksize = 3)\nor ( xorder = 0, yorder = 1, ksize = 3) to calculate the first x- or y- image derivative. The first\ncase corresponds to a kernel of:\n\\f[\\vecthreethree{-1}{0}{1}{-2}{0}{2}{-1}{0}{1}\\f]\nThe second case corresponds to a kernel of:\n\\f[\\vecthreethree{-1}{-2}{-1}{0}{0}{0}{1}{2}{1}\\f]\n@sa  Scharr, Laplacian, sepFilter2D, filter2D, GaussianBlur, cartToPolar\n\nPython prototype (for reference only):\n```python3\nSobel(src, ddepth, dx, dy[, dst[, ksize[, scale[, delta[, borderType]]]]]) -> dst\n```","ref":"Evision.html#sobel/5"},{"type":"function","title":"Evision.solve/1","doc":"","ref":"Evision.html#solve/1"},{"type":"function","title":"Evision.solve/2","doc":"Solves one or more linear systems or least-squares problems.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  input matrix on the left-hand side of the system.\n\n- **src2**: `Evision.Mat`.\n\n  input matrix on the right-hand side of the system.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  solution (matrix inversion) method (#DecompTypes)\n\n##### Return\n- **retval**: `bool`\n- **dst**: `Evision.Mat.t()`.\n\n  output solution.\n\nThe function cv::solve solves a linear system or least-squares problem (the\nlatter is possible with SVD or QR methods, or by specifying the flag\n#DECOMP_NORMAL ):\n\\f[\\texttt{dst} =  \\arg \\min \\_X \\| \\texttt{src1} \\cdot \\texttt{X} -  \\texttt{src2} \\|\\f]\nIf #DECOMP_LU or #DECOMP_CHOLESKY method is used, the function returns 1\nif src1 (or \\f$\\texttt{src1}^T\\texttt{src1}\\f$ ) is non-singular. Otherwise,\nit returns 0. In the latter case, dst is not valid. Other methods find a\npseudo-solution in case of a singular left-hand side part.\n**Note**: If you want to find a unity-norm solution of an under-defined\nsingular system \\f$\\texttt{src1}\\cdot\\texttt{dst}=0\\f$ , the function solve\nwill not do the work. Use SVD::solveZ instead.\n@sa invert, SVD, eigen\n\nPython prototype (for reference only):\n```python3\nsolve(src1, src2[, dst[, flags]]) -> retval, dst\n```","ref":"Evision.html#solve/2"},{"type":"function","title":"Evision.solve/3","doc":"Solves one or more linear systems or least-squares problems.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  input matrix on the left-hand side of the system.\n\n- **src2**: `Evision.Mat`.\n\n  input matrix on the right-hand side of the system.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  solution (matrix inversion) method (#DecompTypes)\n\n##### Return\n- **retval**: `bool`\n- **dst**: `Evision.Mat.t()`.\n\n  output solution.\n\nThe function cv::solve solves a linear system or least-squares problem (the\nlatter is possible with SVD or QR methods, or by specifying the flag\n#DECOMP_NORMAL ):\n\\f[\\texttt{dst} =  \\arg \\min \\_X \\| \\texttt{src1} \\cdot \\texttt{X} -  \\texttt{src2} \\|\\f]\nIf #DECOMP_LU or #DECOMP_CHOLESKY method is used, the function returns 1\nif src1 (or \\f$\\texttt{src1}^T\\texttt{src1}\\f$ ) is non-singular. Otherwise,\nit returns 0. In the latter case, dst is not valid. Other methods find a\npseudo-solution in case of a singular left-hand side part.\n**Note**: If you want to find a unity-norm solution of an under-defined\nsingular system \\f$\\texttt{src1}\\cdot\\texttt{dst}=0\\f$ , the function solve\nwill not do the work. Use SVD::solveZ instead.\n@sa invert, SVD, eigen\n\nPython prototype (for reference only):\n```python3\nsolve(src1, src2[, dst[, flags]]) -> retval, dst\n```","ref":"Evision.html#solve/3"},{"type":"function","title":"Evision.solveCubic/1","doc":"Finds the real roots of a cubic equation.\n\n##### Positional Arguments\n- **coeffs**: `Evision.Mat`.\n\n  equation coefficients, an array of 3 or 4 elements.\n\n##### Return\n- **retval**: `integer()`\n- **roots**: `Evision.Mat.t()`.\n\n  output array of real roots that has 1 or 3 elements.\n\nThe function solveCubic finds the real roots of a cubic equation:\n- if coeffs is a 4-element vector:\n  \\f[\\texttt{coeffs} \\[0] x^3 +  \\texttt{coeffs} \\[1] x^2 +  \\texttt{coeffs} \\[2] x +  \\texttt{coeffs} \\[3] = 0\\f]\n\n- if coeffs is a 3-element vector:\n  \\f[x^3 +  \\texttt{coeffs} \\[0] x^2 +  \\texttt{coeffs} \\[1] x +  \\texttt{coeffs} \\[2] = 0\\f]\n\nThe roots are stored in the roots array.\n@return number of real roots. It can be 0, 1 or 2.\n\nPython prototype (for reference only):\n```python3\nsolveCubic(coeffs[, roots]) -> retval, roots\n```","ref":"Evision.html#solveCubic/1"},{"type":"function","title":"Evision.solveCubic/2","doc":"Finds the real roots of a cubic equation.\n\n##### Positional Arguments\n- **coeffs**: `Evision.Mat`.\n\n  equation coefficients, an array of 3 or 4 elements.\n\n##### Return\n- **retval**: `integer()`\n- **roots**: `Evision.Mat.t()`.\n\n  output array of real roots that has 1 or 3 elements.\n\nThe function solveCubic finds the real roots of a cubic equation:\n- if coeffs is a 4-element vector:\n  \\f[\\texttt{coeffs} \\[0] x^3 +  \\texttt{coeffs} \\[1] x^2 +  \\texttt{coeffs} \\[2] x +  \\texttt{coeffs} \\[3] = 0\\f]\n\n- if coeffs is a 3-element vector:\n  \\f[x^3 +  \\texttt{coeffs} \\[0] x^2 +  \\texttt{coeffs} \\[1] x +  \\texttt{coeffs} \\[2] = 0\\f]\n\nThe roots are stored in the roots array.\n@return number of real roots. It can be 0, 1 or 2.\n\nPython prototype (for reference only):\n```python3\nsolveCubic(coeffs[, roots]) -> retval, roots\n```","ref":"Evision.html#solveCubic/2"},{"type":"function","title":"Evision.solveLP/1","doc":"","ref":"Evision.html#solveLP/1"},{"type":"function","title":"Evision.solveLP/2","doc":"solveLP\n\n##### Positional Arguments\n- **func**: `Evision.Mat`\n- **constr**: `Evision.Mat`\n\n##### Return\n- **retval**: `integer()`\n- **z**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nsolveLP(Func, Constr[, z]) -> retval, z\n```","ref":"Evision.html#solveLP/2"},{"type":"function","title":"Evision.solveLP/3","doc":"#### Variant 1:\nSolve given (non-integer) linear programming problem using the Simplex Algorithm (Simplex Method).\n\n##### Positional Arguments\n- **func**: `Evision.Mat`.\n\n  This row-vector corresponds to \\f$c\\f$ in the LP problem formulation (see above). It should\n  contain 32- or 64-bit floating point numbers. As a convenience, column-vector may be also submitted,\n  in the latter case it is understood to correspond to \\f$c^T\\f$.\n\n- **constr**: `Evision.Mat`.\n\n  `m`-by-`n+1` matrix, whose rightmost column corresponds to \\f$b\\f$ in formulation above\n  and the remaining to \\f$A\\f$. It should contain 32- or 64-bit floating point numbers.\n\n- **constr_eps**: `double`.\n\n  allowed numeric disparity for constraints\n\n##### Return\n- **retval**: `integer()`\n- **z**: `Evision.Mat.t()`.\n\n  The solution will be returned here as a column-vector - it corresponds to \\f$c\\f$ in the\n  formulation above. It will contain 64-bit floating point numbers.\n\nWhat we mean here by \"linear programming problem\" (or LP problem, for short) can be formulated as:\n\\f[\\mbox{Maximize } c\\cdot x\\\\\\\\\n\\mbox{Subject to:}\\\\\\\\\nAx\\leq b\\\\\\\\\nx\\geq 0\\f]\nWhere \\f$c\\f$ is fixed `1`-by-`n` row-vector, \\f$A\\f$ is fixed `m`-by-`n` matrix, \\f$b\\f$ is fixed `m`-by-`1`\ncolumn vector and \\f$x\\f$ is an arbitrary `n`-by-`1` column vector, which satisfies the constraints.\nSimplex algorithm is one of many algorithms that are designed to handle this sort of problems\nefficiently. Although it is not optimal in theoretical sense (there exist algorithms that can solve\nany problem written as above in polynomial time, while simplex method degenerates to exponential\ntime for some special cases), it is well-studied, easy to implement and is shown to work well for\nreal-life purposes.\nThe particular implementation is taken almost verbatim from **Introduction to Algorithms, third\nedition** by T. H. Cormen, C. E. Leiserson, R. L. Rivest and Clifford Stein. In particular, the\nBland's rule   is used to prevent cycling.\n@return One of cv::SolveLPResult\n\nPython prototype (for reference only):\n```python3\nsolveLP(Func, Constr, constr_eps[, z]) -> retval, z\n```\n#### Variant 2:\nsolveLP\n\n##### Positional Arguments\n- **func**: `Evision.Mat`\n- **constr**: `Evision.Mat`\n\n##### Return\n- **retval**: `integer()`\n- **z**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nsolveLP(Func, Constr[, z]) -> retval, z\n```","ref":"Evision.html#solveLP/3"},{"type":"function","title":"Evision.solveLP/4","doc":"Solve given (non-integer) linear programming problem using the Simplex Algorithm (Simplex Method).\n\n##### Positional Arguments\n- **func**: `Evision.Mat`.\n\n  This row-vector corresponds to \\f$c\\f$ in the LP problem formulation (see above). It should\n  contain 32- or 64-bit floating point numbers. As a convenience, column-vector may be also submitted,\n  in the latter case it is understood to correspond to \\f$c^T\\f$.\n\n- **constr**: `Evision.Mat`.\n\n  `m`-by-`n+1` matrix, whose rightmost column corresponds to \\f$b\\f$ in formulation above\n  and the remaining to \\f$A\\f$. It should contain 32- or 64-bit floating point numbers.\n\n- **constr_eps**: `double`.\n\n  allowed numeric disparity for constraints\n\n##### Return\n- **retval**: `integer()`\n- **z**: `Evision.Mat.t()`.\n\n  The solution will be returned here as a column-vector - it corresponds to \\f$c\\f$ in the\n  formulation above. It will contain 64-bit floating point numbers.\n\nWhat we mean here by \"linear programming problem\" (or LP problem, for short) can be formulated as:\n\\f[\\mbox{Maximize } c\\cdot x\\\\\\\\\n\\mbox{Subject to:}\\\\\\\\\nAx\\leq b\\\\\\\\\nx\\geq 0\\f]\nWhere \\f$c\\f$ is fixed `1`-by-`n` row-vector, \\f$A\\f$ is fixed `m`-by-`n` matrix, \\f$b\\f$ is fixed `m`-by-`1`\ncolumn vector and \\f$x\\f$ is an arbitrary `n`-by-`1` column vector, which satisfies the constraints.\nSimplex algorithm is one of many algorithms that are designed to handle this sort of problems\nefficiently. Although it is not optimal in theoretical sense (there exist algorithms that can solve\nany problem written as above in polynomial time, while simplex method degenerates to exponential\ntime for some special cases), it is well-studied, easy to implement and is shown to work well for\nreal-life purposes.\nThe particular implementation is taken almost verbatim from **Introduction to Algorithms, third\nedition** by T. H. Cormen, C. E. Leiserson, R. L. Rivest and Clifford Stein. In particular, the\nBland's rule   is used to prevent cycling.\n@return One of cv::SolveLPResult\n\nPython prototype (for reference only):\n```python3\nsolveLP(Func, Constr, constr_eps[, z]) -> retval, z\n```","ref":"Evision.html#solveLP/4"},{"type":"function","title":"Evision.solveP3P/1","doc":"","ref":"Evision.html#solveP3P/1"},{"type":"function","title":"Evision.solveP3P/5","doc":"Finds an object pose from 3 3D-2D point correspondences.\n\n##### Positional Arguments\n- **objectPoints**: `Evision.Mat`.\n\n  Array of object points in the object coordinate space, 3x3 1-channel or\n  1x3/3x1 3-channel. vector\\  can be also passed here.\n\n- **imagePoints**: `Evision.Mat`.\n\n  Array of corresponding image points, 3x2 1-channel or 1x3/3x1 2-channel.\n  vector\\  can be also passed here.\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input camera intrinsic matrix \\f$\\cameramatrix{A}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$\\distcoeffs\\f$. If the vector is NULL/empty, the zero distortion coefficients are\n  assumed.\n\n- **flags**: `integer()`.\n\n  Method for solving a P3P problem:\n  - @ref SOLVEPNP_P3P Method is based on the paper of X.S. Gao, X.-R. Hou, J. Tang, H.-F. Chang\n    \"Complete Solution Classification for the Perspective-Three-Point Problem\" (@cite gao2003complete).\n  - @ref SOLVEPNP_AP3P Method is based on the paper of T. Ke and S. Roumeliotis.\n    \"An Efficient Algebraic Solution to the Perspective-Three-Point Problem\" (@cite Ke17).\n\n##### Return\n- **retval**: `integer()`\n- **rvecs**: `[Evision.Mat]`.\n\n  Output rotation vectors (see @ref Rodrigues ) that, together with tvecs, brings points from\n  the model coordinate system to the camera coordinate system. A P3P problem has up to 4 solutions.\n\n- **tvecs**: `[Evision.Mat]`.\n\n  Output translation vectors.\n\n@see @ref calib3d_solvePnP\n\nThe function estimates the object pose given 3 object points, their corresponding image\nprojections, as well as the camera intrinsic matrix and the distortion coefficients.\n**Note**: \nThe solutions are sorted by reprojection errors (lowest to highest).\n\nPython prototype (for reference only):\n```python3\nsolveP3P(objectPoints, imagePoints, cameraMatrix, distCoeffs, flags[, rvecs[, tvecs]]) -> retval, rvecs, tvecs\n```","ref":"Evision.html#solveP3P/5"},{"type":"function","title":"Evision.solveP3P/6","doc":"Finds an object pose from 3 3D-2D point correspondences.\n\n##### Positional Arguments\n- **objectPoints**: `Evision.Mat`.\n\n  Array of object points in the object coordinate space, 3x3 1-channel or\n  1x3/3x1 3-channel. vector\\  can be also passed here.\n\n- **imagePoints**: `Evision.Mat`.\n\n  Array of corresponding image points, 3x2 1-channel or 1x3/3x1 2-channel.\n  vector\\  can be also passed here.\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input camera intrinsic matrix \\f$\\cameramatrix{A}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$\\distcoeffs\\f$. If the vector is NULL/empty, the zero distortion coefficients are\n  assumed.\n\n- **flags**: `integer()`.\n\n  Method for solving a P3P problem:\n  - @ref SOLVEPNP_P3P Method is based on the paper of X.S. Gao, X.-R. Hou, J. Tang, H.-F. Chang\n    \"Complete Solution Classification for the Perspective-Three-Point Problem\" (@cite gao2003complete).\n  - @ref SOLVEPNP_AP3P Method is based on the paper of T. Ke and S. Roumeliotis.\n    \"An Efficient Algebraic Solution to the Perspective-Three-Point Problem\" (@cite Ke17).\n\n##### Return\n- **retval**: `integer()`\n- **rvecs**: `[Evision.Mat]`.\n\n  Output rotation vectors (see @ref Rodrigues ) that, together with tvecs, brings points from\n  the model coordinate system to the camera coordinate system. A P3P problem has up to 4 solutions.\n\n- **tvecs**: `[Evision.Mat]`.\n\n  Output translation vectors.\n\n@see @ref calib3d_solvePnP\n\nThe function estimates the object pose given 3 object points, their corresponding image\nprojections, as well as the camera intrinsic matrix and the distortion coefficients.\n**Note**: \nThe solutions are sorted by reprojection errors (lowest to highest).\n\nPython prototype (for reference only):\n```python3\nsolveP3P(objectPoints, imagePoints, cameraMatrix, distCoeffs, flags[, rvecs[, tvecs]]) -> retval, rvecs, tvecs\n```","ref":"Evision.html#solveP3P/6"},{"type":"function","title":"Evision.solvePnP/1","doc":"","ref":"Evision.html#solvePnP/1"},{"type":"function","title":"Evision.solvePnP/4","doc":"Finds an object pose from 3D-2D point correspondences.\n\n##### Positional Arguments\n- **objectPoints**: `Evision.Mat`.\n\n  Array of object points in the object coordinate space, Nx3 1-channel or\n  1xN/Nx1 3-channel, where N is the number of points. vector\\  can be also passed here.\n\n- **imagePoints**: `Evision.Mat`.\n\n  Array of corresponding image points, Nx2 1-channel or 1xN/Nx1 2-channel,\n  where N is the number of points. vector\\  can be also passed here.\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input camera intrinsic matrix \\f$\\cameramatrix{A}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$\\distcoeffs\\f$. If the vector is NULL/empty, the zero distortion coefficients are\n  assumed.\n\n##### Keyword Arguments\n- **useExtrinsicGuess**: `bool`.\n\n  Parameter used for #SOLVEPNP_ITERATIVE. If true (1), the function uses\n  the provided rvec and tvec values as initial approximations of the rotation and translation\n  vectors, respectively, and further optimizes them.\n\n- **flags**: `integer()`.\n\n  Method for solving a PnP problem: see @ref calib3d_solvePnP_flags\n\n##### Return\n- **retval**: `bool`\n- **rvec**: `Evision.Mat.t()`.\n\n  Output rotation vector (see @ref Rodrigues ) that, together with tvec, brings points from\n  the model coordinate system to the camera coordinate system.\n\n- **tvec**: `Evision.Mat.t()`.\n\n  Output translation vector.\n\n@see @ref calib3d_solvePnP\nThis function returns the rotation and the translation vectors that transform a 3D point expressed in the object\ncoordinate frame to the camera coordinate frame, using different methods:\n- P3P methods (@ref SOLVEPNP_P3P, @ref SOLVEPNP_AP3P): need 4 input points to return a unique solution.\n- @ref SOLVEPNP_IPPE Input points must be >= 4 and object points must be coplanar.\n- @ref SOLVEPNP_IPPE_SQUARE Special case suitable for marker pose estimation.\n  Number of input points must be 4. Object points must be defined in the following order:\n\n- point 0: [-squareLength / 2,  squareLength / 2, 0]\n- point 1: [ squareLength / 2,  squareLength / 2, 0]\n- point 2: [ squareLength / 2, -squareLength / 2, 0]\n- point 3: [-squareLength / 2, -squareLength / 2, 0]\n- for all the other flags, number of input points must be >= 4 and object points can be in any configuration.\n\nMore information about Perspective-n-Points is described in @ref calib3d_solvePnP\n**Note**: \n- An example of how to use solvePnP for planar augmented reality can be found at\n  opencv_source_code/samples/python/plane_ar.py\n\n- If you are using Python:\n- Numpy array slices won't work as input because solvePnP requires contiguous\n  arrays (enforced by the assertion using cv::Mat::checkVector() around line 55 of\n  modules/calib3d/src/solvepnp.cpp version 2.4.9)\n\n- The P3P algorithm requires image points to be in an array of shape (N,1,2) due\n  to its calling of #undistortPoints (around line 75 of modules/calib3d/src/solvepnp.cpp version 2.4.9)\n  which requires 2-channel information.\n\n- Thus, given some data D = np.array(...) where D.shape = (N,M), in order to use a subset of\n  it as, e.g., imagePoints, one must effectively copy it into a new array: imagePoints =\n  np.ascontiguousarray(D[:,:2]).reshape((N,1,2))\n\n- The methods @ref SOLVEPNP_DLS and @ref SOLVEPNP_UPNP cannot be used as the current implementations are\n  unstable and sometimes give completely wrong results. If you pass one of these two\n  flags, @ref SOLVEPNP_EPNP method will be used instead.\n\n- The minimum number of points is 4 in the general case. In the case of @ref SOLVEPNP_P3P and @ref SOLVEPNP_AP3P\n  methods, it is required to use exactly 4 points (the first 3 points are used to estimate all the solutions\n  of the P3P problem, the last one is used to retain the best solution that minimizes the reprojection error).\n\n- With @ref SOLVEPNP_ITERATIVE method and `useExtrinsicGuess=true`, the minimum number of points is 3 (3 points\n  are sufficient to compute a pose but there are up to 4 solutions). The initial solution should be close to the\n  global solution to converge.\n\n- With @ref SOLVEPNP_IPPE input points must be >= 4 and object points must be coplanar.\n- With @ref SOLVEPNP_IPPE_SQUARE this is a special case suitable for marker pose estimation.\n  Number of input points must be 4. Object points must be defined in the following order:\n\n- point 0: [-squareLength / 2,  squareLength / 2, 0]\n- point 1: [ squareLength / 2,  squareLength / 2, 0]\n- point 2: [ squareLength / 2, -squareLength / 2, 0]\n- point 3: [-squareLength / 2, -squareLength / 2, 0]\n- With @ref SOLVEPNP_SQPNP input points must be >= 3\n\nPython prototype (for reference only):\n```python3\nsolvePnP(objectPoints, imagePoints, cameraMatrix, distCoeffs[, rvec[, tvec[, useExtrinsicGuess[, flags]]]]) -> retval, rvec, tvec\n```","ref":"Evision.html#solvePnP/4"},{"type":"function","title":"Evision.solvePnP/5","doc":"Finds an object pose from 3D-2D point correspondences.\n\n##### Positional Arguments\n- **objectPoints**: `Evision.Mat`.\n\n  Array of object points in the object coordinate space, Nx3 1-channel or\n  1xN/Nx1 3-channel, where N is the number of points. vector\\  can be also passed here.\n\n- **imagePoints**: `Evision.Mat`.\n\n  Array of corresponding image points, Nx2 1-channel or 1xN/Nx1 2-channel,\n  where N is the number of points. vector\\  can be also passed here.\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input camera intrinsic matrix \\f$\\cameramatrix{A}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$\\distcoeffs\\f$. If the vector is NULL/empty, the zero distortion coefficients are\n  assumed.\n\n##### Keyword Arguments\n- **useExtrinsicGuess**: `bool`.\n\n  Parameter used for #SOLVEPNP_ITERATIVE. If true (1), the function uses\n  the provided rvec and tvec values as initial approximations of the rotation and translation\n  vectors, respectively, and further optimizes them.\n\n- **flags**: `integer()`.\n\n  Method for solving a PnP problem: see @ref calib3d_solvePnP_flags\n\n##### Return\n- **retval**: `bool`\n- **rvec**: `Evision.Mat.t()`.\n\n  Output rotation vector (see @ref Rodrigues ) that, together with tvec, brings points from\n  the model coordinate system to the camera coordinate system.\n\n- **tvec**: `Evision.Mat.t()`.\n\n  Output translation vector.\n\n@see @ref calib3d_solvePnP\nThis function returns the rotation and the translation vectors that transform a 3D point expressed in the object\ncoordinate frame to the camera coordinate frame, using different methods:\n- P3P methods (@ref SOLVEPNP_P3P, @ref SOLVEPNP_AP3P): need 4 input points to return a unique solution.\n- @ref SOLVEPNP_IPPE Input points must be >= 4 and object points must be coplanar.\n- @ref SOLVEPNP_IPPE_SQUARE Special case suitable for marker pose estimation.\n  Number of input points must be 4. Object points must be defined in the following order:\n\n- point 0: [-squareLength / 2,  squareLength / 2, 0]\n- point 1: [ squareLength / 2,  squareLength / 2, 0]\n- point 2: [ squareLength / 2, -squareLength / 2, 0]\n- point 3: [-squareLength / 2, -squareLength / 2, 0]\n- for all the other flags, number of input points must be >= 4 and object points can be in any configuration.\n\nMore information about Perspective-n-Points is described in @ref calib3d_solvePnP\n**Note**: \n- An example of how to use solvePnP for planar augmented reality can be found at\n  opencv_source_code/samples/python/plane_ar.py\n\n- If you are using Python:\n- Numpy array slices won't work as input because solvePnP requires contiguous\n  arrays (enforced by the assertion using cv::Mat::checkVector() around line 55 of\n  modules/calib3d/src/solvepnp.cpp version 2.4.9)\n\n- The P3P algorithm requires image points to be in an array of shape (N,1,2) due\n  to its calling of #undistortPoints (around line 75 of modules/calib3d/src/solvepnp.cpp version 2.4.9)\n  which requires 2-channel information.\n\n- Thus, given some data D = np.array(...) where D.shape = (N,M), in order to use a subset of\n  it as, e.g., imagePoints, one must effectively copy it into a new array: imagePoints =\n  np.ascontiguousarray(D[:,:2]).reshape((N,1,2))\n\n- The methods @ref SOLVEPNP_DLS and @ref SOLVEPNP_UPNP cannot be used as the current implementations are\n  unstable and sometimes give completely wrong results. If you pass one of these two\n  flags, @ref SOLVEPNP_EPNP method will be used instead.\n\n- The minimum number of points is 4 in the general case. In the case of @ref SOLVEPNP_P3P and @ref SOLVEPNP_AP3P\n  methods, it is required to use exactly 4 points (the first 3 points are used to estimate all the solutions\n  of the P3P problem, the last one is used to retain the best solution that minimizes the reprojection error).\n\n- With @ref SOLVEPNP_ITERATIVE method and `useExtrinsicGuess=true`, the minimum number of points is 3 (3 points\n  are sufficient to compute a pose but there are up to 4 solutions). The initial solution should be close to the\n  global solution to converge.\n\n- With @ref SOLVEPNP_IPPE input points must be >= 4 and object points must be coplanar.\n- With @ref SOLVEPNP_IPPE_SQUARE this is a special case suitable for marker pose estimation.\n  Number of input points must be 4. Object points must be defined in the following order:\n\n- point 0: [-squareLength / 2,  squareLength / 2, 0]\n- point 1: [ squareLength / 2,  squareLength / 2, 0]\n- point 2: [ squareLength / 2, -squareLength / 2, 0]\n- point 3: [-squareLength / 2, -squareLength / 2, 0]\n- With @ref SOLVEPNP_SQPNP input points must be >= 3\n\nPython prototype (for reference only):\n```python3\nsolvePnP(objectPoints, imagePoints, cameraMatrix, distCoeffs[, rvec[, tvec[, useExtrinsicGuess[, flags]]]]) -> retval, rvec, tvec\n```","ref":"Evision.html#solvePnP/5"},{"type":"function","title":"Evision.solvePnPGeneric/1","doc":"","ref":"Evision.html#solvePnPGeneric/1"},{"type":"function","title":"Evision.solvePnPGeneric/4","doc":"Finds an object pose from 3D-2D point correspondences.\n\n##### Positional Arguments\n- **objectPoints**: `Evision.Mat`.\n\n  Array of object points in the object coordinate space, Nx3 1-channel or\n  1xN/Nx1 3-channel, where N is the number of points. vector\\  can be also passed here.\n\n- **imagePoints**: `Evision.Mat`.\n\n  Array of corresponding image points, Nx2 1-channel or 1xN/Nx1 2-channel,\n  where N is the number of points. vector\\  can be also passed here.\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input camera intrinsic matrix \\f$\\cameramatrix{A}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$\\distcoeffs\\f$. If the vector is NULL/empty, the zero distortion coefficients are\n  assumed.\n\n##### Keyword Arguments\n- **useExtrinsicGuess**: `bool`.\n\n  Parameter used for #SOLVEPNP_ITERATIVE. If true (1), the function uses\n  the provided rvec and tvec values as initial approximations of the rotation and translation\n  vectors, respectively, and further optimizes them.\n\n- **flags**: `SolvePnPMethod`.\n\n  Method for solving a PnP problem: see @ref calib3d_solvePnP_flags\n\n- **rvec**: `Evision.Mat`.\n\n  Rotation vector used to initialize an iterative PnP refinement algorithm, when flag is @ref SOLVEPNP_ITERATIVE\n  and useExtrinsicGuess is set to true.\n\n- **tvec**: `Evision.Mat`.\n\n  Translation vector used to initialize an iterative PnP refinement algorithm, when flag is @ref SOLVEPNP_ITERATIVE\n  and useExtrinsicGuess is set to true.\n\n##### Return\n- **retval**: `integer()`\n- **rvecs**: `[Evision.Mat]`.\n\n  Vector of output rotation vectors (see @ref Rodrigues ) that, together with tvecs, brings points from\n  the model coordinate system to the camera coordinate system.\n\n- **tvecs**: `[Evision.Mat]`.\n\n  Vector of output translation vectors.\n\n- **reprojectionError**: `Evision.Mat.t()`.\n\n  Optional vector of reprojection error, that is the RMS error\n  (\\f$ \\text{RMSE} = \\sqrt{\\frac{\\sum_{i}^{N} \\left ( \\hat{y_i} - y_i \\right )^2}{N}} \\f$) between the input image points\n  and the 3D object points projected with the estimated pose.\n\n@see @ref calib3d_solvePnP\nThis function returns a list of all the possible solutions (a solution is a  \ncouple), depending on the number of input points and the chosen method:\n- P3P methods (@ref SOLVEPNP_P3P, @ref SOLVEPNP_AP3P): 3 or 4 input points. Number of returned solutions can be between 0 and 4 with 3 input points.\n- @ref SOLVEPNP_IPPE Input points must be >= 4 and object points must be coplanar. Returns 2 solutions.\n- @ref SOLVEPNP_IPPE_SQUARE Special case suitable for marker pose estimation.\n  Number of input points must be 4 and 2 solutions are returned. Object points must be defined in the following order:\n\n- point 0: [-squareLength / 2,  squareLength / 2, 0]\n- point 1: [ squareLength / 2,  squareLength / 2, 0]\n- point 2: [ squareLength / 2, -squareLength / 2, 0]\n- point 3: [-squareLength / 2, -squareLength / 2, 0]\n- for all the other flags, number of input points must be >= 4 and object points can be in any configuration.\n  Only 1 solution is returned.\n\nMore information is described in @ref calib3d_solvePnP\n**Note**: \n- An example of how to use solvePnP for planar augmented reality can be found at\n  opencv_source_code/samples/python/plane_ar.py\n\n- If you are using Python:\n- Numpy array slices won't work as input because solvePnP requires contiguous\n  arrays (enforced by the assertion using cv::Mat::checkVector() around line 55 of\n  modules/calib3d/src/solvepnp.cpp version 2.4.9)\n\n- The P3P algorithm requires image points to be in an array of shape (N,1,2) due\n  to its calling of #undistortPoints (around line 75 of modules/calib3d/src/solvepnp.cpp version 2.4.9)\n  which requires 2-channel information.\n\n- Thus, given some data D = np.array(...) where D.shape = (N,M), in order to use a subset of\n  it as, e.g., imagePoints, one must effectively copy it into a new array: imagePoints =\n  np.ascontiguousarray(D[:,:2]).reshape((N,1,2))\n\n- The methods @ref SOLVEPNP_DLS and @ref SOLVEPNP_UPNP cannot be used as the current implementations are\n  unstable and sometimes give completely wrong results. If you pass one of these two\n  flags, @ref SOLVEPNP_EPNP method will be used instead.\n\n- The minimum number of points is 4 in the general case. In the case of @ref SOLVEPNP_P3P and @ref SOLVEPNP_AP3P\n  methods, it is required to use exactly 4 points (the first 3 points are used to estimate all the solutions\n  of the P3P problem, the last one is used to retain the best solution that minimizes the reprojection error).\n\n- With @ref SOLVEPNP_ITERATIVE method and `useExtrinsicGuess=true`, the minimum number of points is 3 (3 points\n  are sufficient to compute a pose but there are up to 4 solutions). The initial solution should be close to the\n  global solution to converge.\n\n- With @ref SOLVEPNP_IPPE input points must be >= 4 and object points must be coplanar.\n- With @ref SOLVEPNP_IPPE_SQUARE this is a special case suitable for marker pose estimation.\n  Number of input points must be 4. Object points must be defined in the following order:\n\n- point 0: [-squareLength / 2,  squareLength / 2, 0]\n- point 1: [ squareLength / 2,  squareLength / 2, 0]\n- point 2: [ squareLength / 2, -squareLength / 2, 0]\n- point 3: [-squareLength / 2, -squareLength / 2, 0]\n\nPython prototype (for reference only):\n```python3\nsolvePnPGeneric(objectPoints, imagePoints, cameraMatrix, distCoeffs[, rvecs[, tvecs[, useExtrinsicGuess[, flags[, rvec[, tvec[, reprojectionError]]]]]]]) -> retval, rvecs, tvecs, reprojectionError\n```","ref":"Evision.html#solvePnPGeneric/4"},{"type":"function","title":"Evision.solvePnPGeneric/5","doc":"Finds an object pose from 3D-2D point correspondences.\n\n##### Positional Arguments\n- **objectPoints**: `Evision.Mat`.\n\n  Array of object points in the object coordinate space, Nx3 1-channel or\n  1xN/Nx1 3-channel, where N is the number of points. vector\\  can be also passed here.\n\n- **imagePoints**: `Evision.Mat`.\n\n  Array of corresponding image points, Nx2 1-channel or 1xN/Nx1 2-channel,\n  where N is the number of points. vector\\  can be also passed here.\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input camera intrinsic matrix \\f$\\cameramatrix{A}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$\\distcoeffs\\f$. If the vector is NULL/empty, the zero distortion coefficients are\n  assumed.\n\n##### Keyword Arguments\n- **useExtrinsicGuess**: `bool`.\n\n  Parameter used for #SOLVEPNP_ITERATIVE. If true (1), the function uses\n  the provided rvec and tvec values as initial approximations of the rotation and translation\n  vectors, respectively, and further optimizes them.\n\n- **flags**: `SolvePnPMethod`.\n\n  Method for solving a PnP problem: see @ref calib3d_solvePnP_flags\n\n- **rvec**: `Evision.Mat`.\n\n  Rotation vector used to initialize an iterative PnP refinement algorithm, when flag is @ref SOLVEPNP_ITERATIVE\n  and useExtrinsicGuess is set to true.\n\n- **tvec**: `Evision.Mat`.\n\n  Translation vector used to initialize an iterative PnP refinement algorithm, when flag is @ref SOLVEPNP_ITERATIVE\n  and useExtrinsicGuess is set to true.\n\n##### Return\n- **retval**: `integer()`\n- **rvecs**: `[Evision.Mat]`.\n\n  Vector of output rotation vectors (see @ref Rodrigues ) that, together with tvecs, brings points from\n  the model coordinate system to the camera coordinate system.\n\n- **tvecs**: `[Evision.Mat]`.\n\n  Vector of output translation vectors.\n\n- **reprojectionError**: `Evision.Mat.t()`.\n\n  Optional vector of reprojection error, that is the RMS error\n  (\\f$ \\text{RMSE} = \\sqrt{\\frac{\\sum_{i}^{N} \\left ( \\hat{y_i} - y_i \\right )^2}{N}} \\f$) between the input image points\n  and the 3D object points projected with the estimated pose.\n\n@see @ref calib3d_solvePnP\nThis function returns a list of all the possible solutions (a solution is a  \ncouple), depending on the number of input points and the chosen method:\n- P3P methods (@ref SOLVEPNP_P3P, @ref SOLVEPNP_AP3P): 3 or 4 input points. Number of returned solutions can be between 0 and 4 with 3 input points.\n- @ref SOLVEPNP_IPPE Input points must be >= 4 and object points must be coplanar. Returns 2 solutions.\n- @ref SOLVEPNP_IPPE_SQUARE Special case suitable for marker pose estimation.\n  Number of input points must be 4 and 2 solutions are returned. Object points must be defined in the following order:\n\n- point 0: [-squareLength / 2,  squareLength / 2, 0]\n- point 1: [ squareLength / 2,  squareLength / 2, 0]\n- point 2: [ squareLength / 2, -squareLength / 2, 0]\n- point 3: [-squareLength / 2, -squareLength / 2, 0]\n- for all the other flags, number of input points must be >= 4 and object points can be in any configuration.\n  Only 1 solution is returned.\n\nMore information is described in @ref calib3d_solvePnP\n**Note**: \n- An example of how to use solvePnP for planar augmented reality can be found at\n  opencv_source_code/samples/python/plane_ar.py\n\n- If you are using Python:\n- Numpy array slices won't work as input because solvePnP requires contiguous\n  arrays (enforced by the assertion using cv::Mat::checkVector() around line 55 of\n  modules/calib3d/src/solvepnp.cpp version 2.4.9)\n\n- The P3P algorithm requires image points to be in an array of shape (N,1,2) due\n  to its calling of #undistortPoints (around line 75 of modules/calib3d/src/solvepnp.cpp version 2.4.9)\n  which requires 2-channel information.\n\n- Thus, given some data D = np.array(...) where D.shape = (N,M), in order to use a subset of\n  it as, e.g., imagePoints, one must effectively copy it into a new array: imagePoints =\n  np.ascontiguousarray(D[:,:2]).reshape((N,1,2))\n\n- The methods @ref SOLVEPNP_DLS and @ref SOLVEPNP_UPNP cannot be used as the current implementations are\n  unstable and sometimes give completely wrong results. If you pass one of these two\n  flags, @ref SOLVEPNP_EPNP method will be used instead.\n\n- The minimum number of points is 4 in the general case. In the case of @ref SOLVEPNP_P3P and @ref SOLVEPNP_AP3P\n  methods, it is required to use exactly 4 points (the first 3 points are used to estimate all the solutions\n  of the P3P problem, the last one is used to retain the best solution that minimizes the reprojection error).\n\n- With @ref SOLVEPNP_ITERATIVE method and `useExtrinsicGuess=true`, the minimum number of points is 3 (3 points\n  are sufficient to compute a pose but there are up to 4 solutions). The initial solution should be close to the\n  global solution to converge.\n\n- With @ref SOLVEPNP_IPPE input points must be >= 4 and object points must be coplanar.\n- With @ref SOLVEPNP_IPPE_SQUARE this is a special case suitable for marker pose estimation.\n  Number of input points must be 4. Object points must be defined in the following order:\n\n- point 0: [-squareLength / 2,  squareLength / 2, 0]\n- point 1: [ squareLength / 2,  squareLength / 2, 0]\n- point 2: [ squareLength / 2, -squareLength / 2, 0]\n- point 3: [-squareLength / 2, -squareLength / 2, 0]\n\nPython prototype (for reference only):\n```python3\nsolvePnPGeneric(objectPoints, imagePoints, cameraMatrix, distCoeffs[, rvecs[, tvecs[, useExtrinsicGuess[, flags[, rvec[, tvec[, reprojectionError]]]]]]]) -> retval, rvecs, tvecs, reprojectionError\n```","ref":"Evision.html#solvePnPGeneric/5"},{"type":"function","title":"Evision.solvePnPRansac/1","doc":"","ref":"Evision.html#solvePnPRansac/1"},{"type":"function","title":"Evision.solvePnPRansac/4","doc":"solvePnPRansac\n\n##### Positional Arguments\n- **objectPoints**: `Evision.Mat`\n- **imagePoints**: `Evision.Mat`\n- **distCoeffs**: `Evision.Mat`\n\n##### Keyword Arguments\n- **params**: `Evision.UsacParams`.\n\n##### Return\n- **retval**: `bool`\n- **cameraMatrix**: `Evision.Mat.t()`\n- **rvec**: `Evision.Mat.t()`.\n- **tvec**: `Evision.Mat.t()`.\n- **inliers**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nsolvePnPRansac(objectPoints, imagePoints, cameraMatrix, distCoeffs[, rvec[, tvec[, inliers[, params]]]]) -> retval, cameraMatrix, rvec, tvec, inliers\n```","ref":"Evision.html#solvePnPRansac/4"},{"type":"function","title":"Evision.solvePnPRansac/5","doc":"solvePnPRansac\n\n##### Positional Arguments\n- **objectPoints**: `Evision.Mat`\n- **imagePoints**: `Evision.Mat`\n- **distCoeffs**: `Evision.Mat`\n\n##### Keyword Arguments\n- **params**: `Evision.UsacParams`.\n\n##### Return\n- **retval**: `bool`\n- **cameraMatrix**: `Evision.Mat.t()`\n- **rvec**: `Evision.Mat.t()`.\n- **tvec**: `Evision.Mat.t()`.\n- **inliers**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nsolvePnPRansac(objectPoints, imagePoints, cameraMatrix, distCoeffs[, rvec[, tvec[, inliers[, params]]]]) -> retval, cameraMatrix, rvec, tvec, inliers\n```","ref":"Evision.html#solvePnPRansac/5"},{"type":"function","title":"Evision.solvePnPRefineLM/1","doc":"","ref":"Evision.html#solvePnPRefineLM/1"},{"type":"function","title":"Evision.solvePnPRefineLM/6","doc":"Refine a pose (the translation and the rotation that transform a 3D point expressed in the object coordinate frame\nto the camera coordinate frame) from a 3D-2D point correspondences and starting from an initial solution.\n\n##### Positional Arguments\n- **objectPoints**: `Evision.Mat`.\n\n  Array of object points in the object coordinate space, Nx3 1-channel or 1xN/Nx1 3-channel,\n  where N is the number of points. vector\\  can also be passed here.\n\n- **imagePoints**: `Evision.Mat`.\n\n  Array of corresponding image points, Nx2 1-channel or 1xN/Nx1 2-channel,\n  where N is the number of points. vector\\  can also be passed here.\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input camera intrinsic matrix \\f$\\cameramatrix{A}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$\\distcoeffs\\f$. If the vector is NULL/empty, the zero distortion coefficients are\n  assumed.\n\n##### Keyword Arguments\n- **criteria**: `TermCriteria`.\n\n  Criteria when to stop the Levenberg-Marquard iterative algorithm.\n\n##### Return\n- **rvec**: `Evision.Mat.t()`.\n\n  Input/Output rotation vector (see @ref Rodrigues ) that, together with tvec, brings points from\n  the model coordinate system to the camera coordinate system. Input values are used as an initial solution.\n\n- **tvec**: `Evision.Mat.t()`.\n\n  Input/Output translation vector. Input values are used as an initial solution.\n\n@see @ref calib3d_solvePnP\n\nThe function refines the object pose given at least 3 object points, their corresponding image\nprojections, an initial solution for the rotation and translation vector,\nas well as the camera intrinsic matrix and the distortion coefficients.\nThe function minimizes the projection error with respect to the rotation and the translation vectors, according\nto a Levenberg-Marquardt iterative minimization @cite Madsen04 @cite Eade13 process.\n\nPython prototype (for reference only):\n```python3\nsolvePnPRefineLM(objectPoints, imagePoints, cameraMatrix, distCoeffs, rvec, tvec[, criteria]) -> rvec, tvec\n```","ref":"Evision.html#solvePnPRefineLM/6"},{"type":"function","title":"Evision.solvePnPRefineLM/7","doc":"Refine a pose (the translation and the rotation that transform a 3D point expressed in the object coordinate frame\nto the camera coordinate frame) from a 3D-2D point correspondences and starting from an initial solution.\n\n##### Positional Arguments\n- **objectPoints**: `Evision.Mat`.\n\n  Array of object points in the object coordinate space, Nx3 1-channel or 1xN/Nx1 3-channel,\n  where N is the number of points. vector\\  can also be passed here.\n\n- **imagePoints**: `Evision.Mat`.\n\n  Array of corresponding image points, Nx2 1-channel or 1xN/Nx1 2-channel,\n  where N is the number of points. vector\\  can also be passed here.\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input camera intrinsic matrix \\f$\\cameramatrix{A}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$\\distcoeffs\\f$. If the vector is NULL/empty, the zero distortion coefficients are\n  assumed.\n\n##### Keyword Arguments\n- **criteria**: `TermCriteria`.\n\n  Criteria when to stop the Levenberg-Marquard iterative algorithm.\n\n##### Return\n- **rvec**: `Evision.Mat.t()`.\n\n  Input/Output rotation vector (see @ref Rodrigues ) that, together with tvec, brings points from\n  the model coordinate system to the camera coordinate system. Input values are used as an initial solution.\n\n- **tvec**: `Evision.Mat.t()`.\n\n  Input/Output translation vector. Input values are used as an initial solution.\n\n@see @ref calib3d_solvePnP\n\nThe function refines the object pose given at least 3 object points, their corresponding image\nprojections, an initial solution for the rotation and translation vector,\nas well as the camera intrinsic matrix and the distortion coefficients.\nThe function minimizes the projection error with respect to the rotation and the translation vectors, according\nto a Levenberg-Marquardt iterative minimization @cite Madsen04 @cite Eade13 process.\n\nPython prototype (for reference only):\n```python3\nsolvePnPRefineLM(objectPoints, imagePoints, cameraMatrix, distCoeffs, rvec, tvec[, criteria]) -> rvec, tvec\n```","ref":"Evision.html#solvePnPRefineLM/7"},{"type":"function","title":"Evision.solvePnPRefineVVS/1","doc":"","ref":"Evision.html#solvePnPRefineVVS/1"},{"type":"function","title":"Evision.solvePnPRefineVVS/6","doc":"Refine a pose (the translation and the rotation that transform a 3D point expressed in the object coordinate frame\nto the camera coordinate frame) from a 3D-2D point correspondences and starting from an initial solution.\n\n##### Positional Arguments\n- **objectPoints**: `Evision.Mat`.\n\n  Array of object points in the object coordinate space, Nx3 1-channel or 1xN/Nx1 3-channel,\n  where N is the number of points. vector\\  can also be passed here.\n\n- **imagePoints**: `Evision.Mat`.\n\n  Array of corresponding image points, Nx2 1-channel or 1xN/Nx1 2-channel,\n  where N is the number of points. vector\\  can also be passed here.\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input camera intrinsic matrix \\f$\\cameramatrix{A}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$\\distcoeffs\\f$. If the vector is NULL/empty, the zero distortion coefficients are\n  assumed.\n\n##### Keyword Arguments\n- **criteria**: `TermCriteria`.\n\n  Criteria when to stop the Levenberg-Marquard iterative algorithm.\n\n- **vVSlambda**: `double`.\n\n  Gain for the virtual visual servoing control law, equivalent to the \\f$\\alpha\\f$\n  gain in the Damped Gauss-Newton formulation.\n\n##### Return\n- **rvec**: `Evision.Mat.t()`.\n\n  Input/Output rotation vector (see @ref Rodrigues ) that, together with tvec, brings points from\n  the model coordinate system to the camera coordinate system. Input values are used as an initial solution.\n\n- **tvec**: `Evision.Mat.t()`.\n\n  Input/Output translation vector. Input values are used as an initial solution.\n\n@see @ref calib3d_solvePnP\n\nThe function refines the object pose given at least 3 object points, their corresponding image\nprojections, an initial solution for the rotation and translation vector,\nas well as the camera intrinsic matrix and the distortion coefficients.\nThe function minimizes the projection error with respect to the rotation and the translation vectors, using a\nvirtual visual servoing (VVS) @cite Chaumette06 @cite Marchand16 scheme.\n\nPython prototype (for reference only):\n```python3\nsolvePnPRefineVVS(objectPoints, imagePoints, cameraMatrix, distCoeffs, rvec, tvec[, criteria[, VVSlambda]]) -> rvec, tvec\n```","ref":"Evision.html#solvePnPRefineVVS/6"},{"type":"function","title":"Evision.solvePnPRefineVVS/7","doc":"Refine a pose (the translation and the rotation that transform a 3D point expressed in the object coordinate frame\nto the camera coordinate frame) from a 3D-2D point correspondences and starting from an initial solution.\n\n##### Positional Arguments\n- **objectPoints**: `Evision.Mat`.\n\n  Array of object points in the object coordinate space, Nx3 1-channel or 1xN/Nx1 3-channel,\n  where N is the number of points. vector\\  can also be passed here.\n\n- **imagePoints**: `Evision.Mat`.\n\n  Array of corresponding image points, Nx2 1-channel or 1xN/Nx1 2-channel,\n  where N is the number of points. vector\\  can also be passed here.\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input camera intrinsic matrix \\f$\\cameramatrix{A}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$\\distcoeffs\\f$. If the vector is NULL/empty, the zero distortion coefficients are\n  assumed.\n\n##### Keyword Arguments\n- **criteria**: `TermCriteria`.\n\n  Criteria when to stop the Levenberg-Marquard iterative algorithm.\n\n- **vVSlambda**: `double`.\n\n  Gain for the virtual visual servoing control law, equivalent to the \\f$\\alpha\\f$\n  gain in the Damped Gauss-Newton formulation.\n\n##### Return\n- **rvec**: `Evision.Mat.t()`.\n\n  Input/Output rotation vector (see @ref Rodrigues ) that, together with tvec, brings points from\n  the model coordinate system to the camera coordinate system. Input values are used as an initial solution.\n\n- **tvec**: `Evision.Mat.t()`.\n\n  Input/Output translation vector. Input values are used as an initial solution.\n\n@see @ref calib3d_solvePnP\n\nThe function refines the object pose given at least 3 object points, their corresponding image\nprojections, an initial solution for the rotation and translation vector,\nas well as the camera intrinsic matrix and the distortion coefficients.\nThe function minimizes the projection error with respect to the rotation and the translation vectors, using a\nvirtual visual servoing (VVS) @cite Chaumette06 @cite Marchand16 scheme.\n\nPython prototype (for reference only):\n```python3\nsolvePnPRefineVVS(objectPoints, imagePoints, cameraMatrix, distCoeffs, rvec, tvec[, criteria[, VVSlambda]]) -> rvec, tvec\n```","ref":"Evision.html#solvePnPRefineVVS/7"},{"type":"function","title":"Evision.solvePoly/1","doc":"Finds the real or complex roots of a polynomial equation.\n\n##### Positional Arguments\n- **coeffs**: `Evision.Mat`.\n\n  array of polynomial coefficients.\n\n##### Keyword Arguments\n- **maxIters**: `integer()`.\n\n  maximum number of iterations the algorithm does.\n\n##### Return\n- **retval**: `double`\n- **roots**: `Evision.Mat.t()`.\n\n  output (complex) array of roots.\n\nThe function cv::solvePoly finds real and complex roots of a polynomial equation:\n\\f[\\texttt{coeffs} \\[n] x^{n} +  \\texttt{coeffs} \\[n-1] x^{n-1} + ... +  \\texttt{coeffs} \\[1] x +  \\texttt{coeffs} \\[0] = 0\\f]\n\nPython prototype (for reference only):\n```python3\nsolvePoly(coeffs[, roots[, maxIters]]) -> retval, roots\n```","ref":"Evision.html#solvePoly/1"},{"type":"function","title":"Evision.solvePoly/2","doc":"Finds the real or complex roots of a polynomial equation.\n\n##### Positional Arguments\n- **coeffs**: `Evision.Mat`.\n\n  array of polynomial coefficients.\n\n##### Keyword Arguments\n- **maxIters**: `integer()`.\n\n  maximum number of iterations the algorithm does.\n\n##### Return\n- **retval**: `double`\n- **roots**: `Evision.Mat.t()`.\n\n  output (complex) array of roots.\n\nThe function cv::solvePoly finds real and complex roots of a polynomial equation:\n\\f[\\texttt{coeffs} \\[n] x^{n} +  \\texttt{coeffs} \\[n-1] x^{n-1} + ... +  \\texttt{coeffs} \\[1] x +  \\texttt{coeffs} \\[0] = 0\\f]\n\nPython prototype (for reference only):\n```python3\nsolvePoly(coeffs[, roots[, maxIters]]) -> retval, roots\n```","ref":"Evision.html#solvePoly/2"},{"type":"function","title":"Evision.sort/1","doc":"","ref":"Evision.html#sort/1"},{"type":"function","title":"Evision.sort/2","doc":"Sorts each row or each column of a matrix.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input single-channel array.\n\n- **flags**: `integer()`.\n\n  operation flags, a combination of #SortFlags\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src.\n\nThe function cv::sort sorts each matrix row or each matrix column in\nascending or descending order. So you should pass two operation flags to\nget desired behaviour. If you want to sort matrix rows or columns\nlexicographically, you can use STL std::sort generic function with the\nproper comparison predicate.\n@sa sortIdx, randShuffle\n\nPython prototype (for reference only):\n```python3\nsort(src, flags[, dst]) -> dst\n```","ref":"Evision.html#sort/2"},{"type":"function","title":"Evision.sort/3","doc":"Sorts each row or each column of a matrix.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input single-channel array.\n\n- **flags**: `integer()`.\n\n  operation flags, a combination of #SortFlags\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src.\n\nThe function cv::sort sorts each matrix row or each matrix column in\nascending or descending order. So you should pass two operation flags to\nget desired behaviour. If you want to sort matrix rows or columns\nlexicographically, you can use STL std::sort generic function with the\nproper comparison predicate.\n@sa sortIdx, randShuffle\n\nPython prototype (for reference only):\n```python3\nsort(src, flags[, dst]) -> dst\n```","ref":"Evision.html#sort/3"},{"type":"function","title":"Evision.sortIdx/1","doc":"","ref":"Evision.html#sortIdx/1"},{"type":"function","title":"Evision.sortIdx/2","doc":"Sorts each row or each column of a matrix.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input single-channel array.\n\n- **flags**: `integer()`.\n\n  operation flags that could be a combination of cv::SortFlags\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output integer array of the same size as src.\n\nThe function cv::sortIdx sorts each matrix row or each matrix column in the\nascending or descending order. So you should pass two operation flags to\nget desired behaviour. Instead of reordering the elements themselves, it\nstores the indices of sorted elements in the output array. For example:\n```\nMat A = Mat::eye(3,3,CV_32F), B;\nsortIdx(A, B, SORT_EVERY_ROW + SORT_ASCENDING);\n// B will probably contain\n// (because of equal elements in A some permutations are possible):\n// [[1, 2, 0], [0, 2, 1], [0, 1, 2]]\n```\n@sa sort, randShuffle\n\nPython prototype (for reference only):\n```python3\nsortIdx(src, flags[, dst]) -> dst\n```","ref":"Evision.html#sortIdx/2"},{"type":"function","title":"Evision.sortIdx/3","doc":"Sorts each row or each column of a matrix.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input single-channel array.\n\n- **flags**: `integer()`.\n\n  operation flags that could be a combination of cv::SortFlags\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output integer array of the same size as src.\n\nThe function cv::sortIdx sorts each matrix row or each matrix column in the\nascending or descending order. So you should pass two operation flags to\nget desired behaviour. Instead of reordering the elements themselves, it\nstores the indices of sorted elements in the output array. For example:\n```\nMat A = Mat::eye(3,3,CV_32F), B;\nsortIdx(A, B, SORT_EVERY_ROW + SORT_ASCENDING);\n// B will probably contain\n// (because of equal elements in A some permutations are possible):\n// [[1, 2, 0], [0, 2, 1], [0, 1, 2]]\n```\n@sa sort, randShuffle\n\nPython prototype (for reference only):\n```python3\nsortIdx(src, flags[, dst]) -> dst\n```","ref":"Evision.html#sortIdx/3"},{"type":"function","title":"Evision.spatialGradient/1","doc":"Calculates the first order image derivative in both x and y using a Sobel operator\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image.\n\n##### Keyword Arguments\n- **ksize**: `integer()`.\n\n  size of Sobel kernel. It must be 3.\n\n- **borderType**: `integer()`.\n\n  pixel extrapolation method, see #BorderTypes.\n  Only #BORDER_DEFAULT=#BORDER_REFLECT_101 and #BORDER_REPLICATE are supported.\n\n##### Return\n- **dx**: `Evision.Mat.t()`.\n\n  output image with first-order derivative in x.\n\n- **dy**: `Evision.Mat.t()`.\n\n  output image with first-order derivative in y.\n\nEquivalent to calling:\n```\nSobel( src, dx, CV_16SC1, 1, 0, 3 );\nSobel( src, dy, CV_16SC1, 0, 1, 3 );\n```\n\n@sa Sobel\n\nPython prototype (for reference only):\n```python3\nspatialGradient(src[, dx[, dy[, ksize[, borderType]]]]) -> dx, dy\n```","ref":"Evision.html#spatialGradient/1"},{"type":"function","title":"Evision.spatialGradient/2","doc":"Calculates the first order image derivative in both x and y using a Sobel operator\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image.\n\n##### Keyword Arguments\n- **ksize**: `integer()`.\n\n  size of Sobel kernel. It must be 3.\n\n- **borderType**: `integer()`.\n\n  pixel extrapolation method, see #BorderTypes.\n  Only #BORDER_DEFAULT=#BORDER_REFLECT_101 and #BORDER_REPLICATE are supported.\n\n##### Return\n- **dx**: `Evision.Mat.t()`.\n\n  output image with first-order derivative in x.\n\n- **dy**: `Evision.Mat.t()`.\n\n  output image with first-order derivative in y.\n\nEquivalent to calling:\n```\nSobel( src, dx, CV_16SC1, 1, 0, 3 );\nSobel( src, dy, CV_16SC1, 0, 1, 3 );\n```\n\n@sa Sobel\n\nPython prototype (for reference only):\n```python3\nspatialGradient(src[, dx[, dy[, ksize[, borderType]]]]) -> dx, dy\n```","ref":"Evision.html#spatialGradient/2"},{"type":"function","title":"Evision.split/1","doc":"split\n\n##### Positional Arguments\n- **m**: `Evision.Mat`.\n\n  input multi-channel array.\n\n##### Return\n- **mv**: `[Evision.Mat]`.\n\n  output vector of arrays; the arrays themselves are reallocated, if needed.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nsplit(m[, mv]) -> mv\n```","ref":"Evision.html#split/1"},{"type":"function","title":"Evision.split/2","doc":"split\n\n##### Positional Arguments\n- **m**: `Evision.Mat`.\n\n  input multi-channel array.\n\n##### Return\n- **mv**: `[Evision.Mat]`.\n\n  output vector of arrays; the arrays themselves are reallocated, if needed.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nsplit(m[, mv]) -> mv\n```","ref":"Evision.html#split/2"},{"type":"function","title":"Evision.sqrBoxFilter/1","doc":"","ref":"Evision.html#sqrBoxFilter/1"},{"type":"function","title":"Evision.sqrBoxFilter/3","doc":"Calculates the normalized sum of squares of the pixel values overlapping the filter.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image\n\n- **ddepth**: `integer()`.\n\n  the output image depth (-1 to use src.depth())\n\n- **ksize**: `Size`.\n\n  kernel size\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  kernel anchor point. The default value of Point(-1, -1) denotes that the anchor is at the kernel\n  center.\n\n- **normalize**: `bool`.\n\n  flag, specifying whether the kernel is to be normalized by it's area or not.\n\n- **borderType**: `integer()`.\n\n  border mode used to extrapolate pixels outside of the image, see #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and type as src\n\nFor every pixel \\f$ (x, y) \\f$ in the source image, the function calculates the sum of squares of those neighboring\npixel values which overlap the filter placed over the pixel \\f$ (x, y) \\f$.\nThe unnormalized square box filter can be useful in computing local image statistics such as the local\nvariance and standard deviation around the neighborhood of a pixel.\n@sa boxFilter\n\nPython prototype (for reference only):\n```python3\nsqrBoxFilter(src, ddepth, ksize[, dst[, anchor[, normalize[, borderType]]]]) -> dst\n```","ref":"Evision.html#sqrBoxFilter/3"},{"type":"function","title":"Evision.sqrBoxFilter/4","doc":"Calculates the normalized sum of squares of the pixel values overlapping the filter.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image\n\n- **ddepth**: `integer()`.\n\n  the output image depth (-1 to use src.depth())\n\n- **ksize**: `Size`.\n\n  kernel size\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  kernel anchor point. The default value of Point(-1, -1) denotes that the anchor is at the kernel\n  center.\n\n- **normalize**: `bool`.\n\n  flag, specifying whether the kernel is to be normalized by it's area or not.\n\n- **borderType**: `integer()`.\n\n  border mode used to extrapolate pixels outside of the image, see #BorderTypes. #BORDER_WRAP is not supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and type as src\n\nFor every pixel \\f$ (x, y) \\f$ in the source image, the function calculates the sum of squares of those neighboring\npixel values which overlap the filter placed over the pixel \\f$ (x, y) \\f$.\nThe unnormalized square box filter can be useful in computing local image statistics such as the local\nvariance and standard deviation around the neighborhood of a pixel.\n@sa boxFilter\n\nPython prototype (for reference only):\n```python3\nsqrBoxFilter(src, ddepth, ksize[, dst[, anchor[, normalize[, borderType]]]]) -> dst\n```","ref":"Evision.html#sqrBoxFilter/4"},{"type":"function","title":"Evision.sqrt/1","doc":"Calculates a square root of array elements.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input floating-point array.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src.\n\nThe function cv::sqrt calculates a square root of each input array element.\nIn case of multi-channel arrays, each channel is processed\nindependently. The accuracy is approximately the same as of the built-in\nstd::sqrt .\n\nPython prototype (for reference only):\n```python3\nsqrt(src[, dst]) -> dst\n```","ref":"Evision.html#sqrt/1"},{"type":"function","title":"Evision.sqrt/2","doc":"Calculates a square root of array elements.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input floating-point array.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and type as src.\n\nThe function cv::sqrt calculates a square root of each input array element.\nIn case of multi-channel arrays, each channel is processed\nindependently. The accuracy is approximately the same as of the built-in\nstd::sqrt .\n\nPython prototype (for reference only):\n```python3\nsqrt(src[, dst]) -> dst\n```","ref":"Evision.html#sqrt/2"},{"type":"function","title":"Evision.stackBlur/1","doc":"","ref":"Evision.html#stackBlur/1"},{"type":"function","title":"Evision.stackBlur/2","doc":"Blurs an image using the stackBlur.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image. The number of channels can be arbitrary, but the depth should be one of\n  CV_8U, CV_16U, CV_16S or CV_32F.\n\n- **ksize**: `Size`.\n\n  stack-blurring kernel size. The ksize.width and ksize.height can differ but they both must be\n  positive and odd.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and type as src.\n\nThe function applies and stackBlur to an image.\nstackBlur can generate similar results as Gaussian blur, and the time consumption does not increase with the increase of kernel size.\nIt creates a kind of moving stack of colors whilst scanning through the image. Thereby it just has to add one new block of color to the right side\nof the stack and remove the leftmost color. The remaining colors on the topmost layer of the stack are either added on or reduced by one,\ndepending on if they are on the right or on the left side of the stack. The only supported borderType is BORDER_REPLICATE.\nOriginal paper was proposed by Mario Klingemann, which can be found http://underdestruction.com/2004/02/25/stackblur-2004.\n\nPython prototype (for reference only):\n```python3\nstackBlur(src, ksize[, dst]) -> dst\n```","ref":"Evision.html#stackBlur/2"},{"type":"function","title":"Evision.stackBlur/3","doc":"Blurs an image using the stackBlur.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image. The number of channels can be arbitrary, but the depth should be one of\n  CV_8U, CV_16U, CV_16S or CV_32F.\n\n- **ksize**: `Size`.\n\n  stack-blurring kernel size. The ksize.width and ksize.height can differ but they both must be\n  positive and odd.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image of the same size and type as src.\n\nThe function applies and stackBlur to an image.\nstackBlur can generate similar results as Gaussian blur, and the time consumption does not increase with the increase of kernel size.\nIt creates a kind of moving stack of colors whilst scanning through the image. Thereby it just has to add one new block of color to the right side\nof the stack and remove the leftmost color. The remaining colors on the topmost layer of the stack are either added on or reduced by one,\ndepending on if they are on the right or on the left side of the stack. The only supported borderType is BORDER_REPLICATE.\nOriginal paper was proposed by Mario Klingemann, which can be found http://underdestruction.com/2004/02/25/stackblur-2004.\n\nPython prototype (for reference only):\n```python3\nstackBlur(src, ksize[, dst]) -> dst\n```","ref":"Evision.html#stackBlur/3"},{"type":"function","title":"Evision.startWindowThread/0","doc":"startWindowThread\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nstartWindowThread() -> retval\n```","ref":"Evision.html#startWindowThread/0"},{"type":"function","title":"Evision.startWindowThread/1","doc":"","ref":"Evision.html#startWindowThread/1"},{"type":"function","title":"Evision.stereoCalibrate/1","doc":"","ref":"Evision.html#stereoCalibrate/1"},{"type":"function","title":"Evision.stereoCalibrate/8","doc":"stereoCalibrate\n\n##### Positional Arguments\n- **objectPoints**: `[Evision.Mat]`\n- **imagePoints1**: `[Evision.Mat]`\n- **imagePoints2**: `[Evision.Mat]`\n- **imageSize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **criteria**: `TermCriteria`.\n\n##### Return\n- **retval**: `double`\n- **cameraMatrix1**: `Evision.Mat.t()`\n- **distCoeffs1**: `Evision.Mat.t()`\n- **cameraMatrix2**: `Evision.Mat.t()`\n- **distCoeffs2**: `Evision.Mat.t()`\n- **r**: `Evision.Mat.t()`.\n- **t**: `Evision.Mat.t()`.\n- **e**: `Evision.Mat.t()`.\n- **f**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nstereoCalibrate(objectPoints, imagePoints1, imagePoints2, cameraMatrix1, distCoeffs1, cameraMatrix2, distCoeffs2, imageSize[, R[, T[, E[, F[, flags[, criteria]]]]]]) -> retval, cameraMatrix1, distCoeffs1, cameraMatrix2, distCoeffs2, R, T, E, F\n```","ref":"Evision.html#stereoCalibrate/8"},{"type":"function","title":"Evision.stereoCalibrate/9","doc":"stereoCalibrate\n\n##### Positional Arguments\n- **objectPoints**: `[Evision.Mat]`\n- **imagePoints1**: `[Evision.Mat]`\n- **imagePoints2**: `[Evision.Mat]`\n- **imageSize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **criteria**: `TermCriteria`.\n\n##### Return\n- **retval**: `double`\n- **cameraMatrix1**: `Evision.Mat.t()`\n- **distCoeffs1**: `Evision.Mat.t()`\n- **cameraMatrix2**: `Evision.Mat.t()`\n- **distCoeffs2**: `Evision.Mat.t()`\n- **r**: `Evision.Mat.t()`.\n- **t**: `Evision.Mat.t()`.\n- **e**: `Evision.Mat.t()`.\n- **f**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nstereoCalibrate(objectPoints, imagePoints1, imagePoints2, cameraMatrix1, distCoeffs1, cameraMatrix2, distCoeffs2, imageSize[, R[, T[, E[, F[, flags[, criteria]]]]]]) -> retval, cameraMatrix1, distCoeffs1, cameraMatrix2, distCoeffs2, R, T, E, F\n```","ref":"Evision.html#stereoCalibrate/9"},{"type":"function","title":"Evision.stereoCalibrate/10","doc":"stereoCalibrate\n\n##### Positional Arguments\n- **objectPoints**: `[Evision.Mat]`\n- **imagePoints1**: `[Evision.Mat]`\n- **imagePoints2**: `[Evision.Mat]`\n- **imageSize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **criteria**: `TermCriteria`.\n\n##### Return\n- **retval**: `double`\n- **cameraMatrix1**: `Evision.Mat.t()`\n- **distCoeffs1**: `Evision.Mat.t()`\n- **cameraMatrix2**: `Evision.Mat.t()`\n- **distCoeffs2**: `Evision.Mat.t()`\n- **r**: `Evision.Mat.t()`\n- **t**: `Evision.Mat.t()`\n- **e**: `Evision.Mat.t()`.\n- **f**: `Evision.Mat.t()`.\n- **perViewErrors**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nstereoCalibrate(objectPoints, imagePoints1, imagePoints2, cameraMatrix1, distCoeffs1, cameraMatrix2, distCoeffs2, imageSize, R, T[, E[, F[, perViewErrors[, flags[, criteria]]]]]) -> retval, cameraMatrix1, distCoeffs1, cameraMatrix2, distCoeffs2, R, T, E, F, perViewErrors\n```","ref":"Evision.html#stereoCalibrate/10"},{"type":"function","title":"Evision.stereoCalibrate/11","doc":"stereoCalibrate\n\n##### Positional Arguments\n- **objectPoints**: `[Evision.Mat]`\n- **imagePoints1**: `[Evision.Mat]`\n- **imagePoints2**: `[Evision.Mat]`\n- **imageSize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **criteria**: `TermCriteria`.\n\n##### Return\n- **retval**: `double`\n- **cameraMatrix1**: `Evision.Mat.t()`\n- **distCoeffs1**: `Evision.Mat.t()`\n- **cameraMatrix2**: `Evision.Mat.t()`\n- **distCoeffs2**: `Evision.Mat.t()`\n- **r**: `Evision.Mat.t()`\n- **t**: `Evision.Mat.t()`\n- **e**: `Evision.Mat.t()`.\n- **f**: `Evision.Mat.t()`.\n- **perViewErrors**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nstereoCalibrate(objectPoints, imagePoints1, imagePoints2, cameraMatrix1, distCoeffs1, cameraMatrix2, distCoeffs2, imageSize, R, T[, E[, F[, perViewErrors[, flags[, criteria]]]]]) -> retval, cameraMatrix1, distCoeffs1, cameraMatrix2, distCoeffs2, R, T, E, F, perViewErrors\n```","ref":"Evision.html#stereoCalibrate/11"},{"type":"function","title":"Evision.stereoCalibrateExtended/1","doc":"","ref":"Evision.html#stereoCalibrateExtended/1"},{"type":"function","title":"Evision.stereoCalibrateExtended/10","doc":"Calibrates a stereo camera set up. This function finds the intrinsic parameters\nfor each of the two cameras and the extrinsic parameters between the two cameras.\n\n##### Positional Arguments\n- **objectPoints**: `[Evision.Mat]`.\n\n  Vector of vectors of the calibration pattern points. The same structure as\n  in @ref calibrateCamera. For each pattern view, both cameras need to see the same object\n  points. Therefore, objectPoints.size(), imagePoints1.size(), and imagePoints2.size() need to be\n  equal as well as objectPoints[i].size(), imagePoints1[i].size(), and imagePoints2[i].size() need to\n  be equal for each i.\n\n- **imagePoints1**: `[Evision.Mat]`.\n\n  Vector of vectors of the projections of the calibration pattern points,\n  observed by the first camera. The same structure as in @ref calibrateCamera.\n\n- **imagePoints2**: `[Evision.Mat]`.\n\n  Vector of vectors of the projections of the calibration pattern points,\n  observed by the second camera. The same structure as in @ref calibrateCamera.\n\n- **imageSize**: `Size`.\n\n  Size of the image used only to initialize the camera intrinsic matrices.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Different flags that may be zero or a combination of the following values:\n  - @ref CALIB_FIX_INTRINSIC Fix cameraMatrix? and distCoeffs? so that only R, T, E, and F\n    matrices are estimated.\n  - @ref CALIB_USE_INTRINSIC_GUESS Optimize some or all of the intrinsic parameters\n    according to the specified flags. Initial values are provided by the user.\n  - @ref CALIB_USE_EXTRINSIC_GUESS R and T contain valid initial values that are optimized further.\n    Otherwise R and T are initialized to the median value of the pattern views (each dimension separately).\n  - @ref CALIB_FIX_PRINCIPAL_POINT Fix the principal points during the optimization.\n  - @ref CALIB_FIX_FOCAL_LENGTH Fix \\f$f^{(j)}_x\\f$ and \\f$f^{(j)}_y\\f$ .\n  - @ref CALIB_FIX_ASPECT_RATIO Optimize \\f$f^{(j)}_y\\f$ . Fix the ratio \\f$f^{(j)}_x/f^{(j)}_y\\f$\n    .\n  - @ref CALIB_SAME_FOCAL_LENGTH Enforce \\f$f^{(0)}_x=f^{(1)}_x\\f$ and \\f$f^{(0)}_y=f^{(1)}_y\\f$ .\n  - @ref CALIB_ZERO_TANGENT_DIST Set tangential distortion coefficients for each camera to\n    zeros and fix there.\n  - @ref CALIB_FIX_K1,..., @ref CALIB_FIX_K6 Do not change the corresponding radial\n    distortion coefficient during the optimization. If @ref CALIB_USE_INTRINSIC_GUESS is set,\n    the coefficient from the supplied distCoeffs matrix is used. Otherwise, it is set to 0.\n  - @ref CALIB_RATIONAL_MODEL Enable coefficients k4, k5, and k6. To provide the backward\n    compatibility, this extra flag should be explicitly specified to make the calibration\n    function use the rational model and return 8 coefficients. If the flag is not set, the\n    function computes and returns only 5 distortion coefficients.\n  - @ref CALIB_THIN_PRISM_MODEL Coefficients s1, s2, s3 and s4 are enabled. To provide the\n    backward compatibility, this extra flag should be explicitly specified to make the\n    calibration function use the thin prism model and return 12 coefficients. If the flag is not\n    set, the function computes and returns only 5 distortion coefficients.\n  - @ref CALIB_FIX_S1_S2_S3_S4 The thin prism distortion coefficients are not changed during\n    the optimization. If @ref CALIB_USE_INTRINSIC_GUESS is set, the coefficient from the\n    supplied distCoeffs matrix is used. Otherwise, it is set to 0.\n  - @ref CALIB_TILTED_MODEL Coefficients tauX and tauY are enabled. To provide the\n    backward compatibility, this extra flag should be explicitly specified to make the\n    calibration function use the tilted sensor model and return 14 coefficients. If the flag is not\n    set, the function computes and returns only 5 distortion coefficients.\n  - @ref CALIB_FIX_TAUX_TAUY The coefficients of the tilted sensor model are not changed during\n    the optimization. If @ref CALIB_USE_INTRINSIC_GUESS is set, the coefficient from the\n    supplied distCoeffs matrix is used. Otherwise, it is set to 0.\n\n- **criteria**: `TermCriteria`.\n\n  Termination criteria for the iterative optimization algorithm.\n\n##### Return\n- **retval**: `double`\n- **cameraMatrix1**: `Evision.Mat.t()`.\n\n  Input/output camera intrinsic matrix for the first camera, the same as in\n\n- **distCoeffs1**: `Evision.Mat.t()`.\n\n  Input/output vector of distortion coefficients, the same as in\n\n- **cameraMatrix2**: `Evision.Mat.t()`.\n\n  Input/output second camera intrinsic matrix for the second camera. See description for\n  cameraMatrix1.\n\n- **distCoeffs2**: `Evision.Mat.t()`.\n\n  Input/output lens distortion coefficients for the second camera. See\n  description for distCoeffs1.\n\n- **r**: `Evision.Mat.t()`.\n\n  Output rotation matrix. Together with the translation vector T, this matrix brings\n  points given in the first camera's coordinate system to points in the second camera's\n  coordinate system. In more technical terms, the tuple of R and T performs a change of basis\n  from the first camera's coordinate system to the second camera's coordinate system. Due to its\n  duality, this tuple is equivalent to the position of the first camera with respect to the\n  second camera coordinate system.\n\n- **t**: `Evision.Mat.t()`.\n\n  Output translation vector, see description above.\n\n- **e**: `Evision.Mat.t()`.\n\n  Output essential matrix.\n\n- **f**: `Evision.Mat.t()`.\n\n  Output fundamental matrix.\n\n- **rvecs**: `[Evision.Mat]`.\n\n  Output vector of rotation vectors ( @ref Rodrigues ) estimated for each pattern view in the\n  coordinate system of the first camera of the stereo pair (e.g. std::vector ). More in detail, each\n  i-th rotation vector together with the corresponding i-th translation vector (see the next output parameter\n  description) brings the calibration pattern from the object coordinate space (in which object points are\n  specified) to the camera coordinate space of the first camera of the stereo pair. In more technical terms,\n  the tuple of the i-th rotation and translation vector performs a change of basis from object coordinate space\n  to camera coordinate space of the first camera of the stereo pair.\n\n- **tvecs**: `[Evision.Mat]`.\n\n  Output vector of translation vectors estimated for each pattern view, see parameter description\n  of previous output parameter ( rvecs ).\n\n- **perViewErrors**: `Evision.Mat.t()`.\n\n  Output vector of the RMS re-projection error estimated for each pattern view.\n\n@ref calibrateCamera. Furthermore, for the stereo case, additional flags may be used, see below.\n@ref calibrateCamera.\n\nThe function estimates the transformation between two cameras making a stereo pair. If one computes\nthe poses of an object relative to the first camera and to the second camera,\n( \\f$R\\_1\\f$,\\f$T\\_1\\f$ ) and (\\f$R\\_2\\f$,\\f$T\\_2\\f$), respectively, for a stereo camera where the\nrelative position and orientation between the two cameras are fixed, then those poses definitely\nrelate to each other. This means, if the relative position and orientation (\\f$R\\f$,\\f$T\\f$) of the\ntwo cameras is known, it is possible to compute (\\f$R\\_2\\f$,\\f$T\\_2\\f$) when (\\f$R\\_1\\f$,\\f$T\\_1\\f$) is\ngiven. This is what the described function does. It computes (\\f$R\\f$,\\f$T\\f$) such that:\n\\f[R\\_2=R R\\_1\\f]\n\\f[T\\_2=R T\\_1 + T.\\f]\nTherefore, one can compute the coordinate representation of a 3D point for the second camera's\ncoordinate system when given the point's coordinate representation in the first camera's coordinate\nsystem:\n\\f[\\begin{bmatrix}\nX\\_2 \\\\\\\\\nY\\_2 \\\\\\\\\nZ\\_2 \\\\\\\\\n1\n\\end{bmatrix} = \\begin{bmatrix}\nR & T \\\\\\\\\n0 & 1\n\\end{bmatrix} \\begin{bmatrix}\nX\\_1 \\\\\\\\\nY\\_1 \\\\\\\\\nZ\\_1 \\\\\\\\\n1\n\\end{bmatrix}.\\f]\nOptionally, it computes the essential matrix E:\n\\f[E= \\vecthreethree{0}{-T\\_2}{T\\_1}{T\\_2}{0}{-T\\_0}{-T\\_1}{T\\_0}{0} R\\f]\nwhere \\f$T\\_i\\f$ are components of the translation vector \\f$T\\f$ : \\f$T=\\[T\\_0, T\\_1, T\\_2]^T\\f$ .\nAnd the function can also compute the fundamental matrix F:\n\\f[F = cameraMatrix2^{-T}\\cdot E \\cdot cameraMatrix1^{-1}\\f]\nBesides the stereo-related information, the function can also perform a full calibration of each of\nthe two cameras. However, due to the high dimensionality of the parameter space and noise in the\ninput data, the function can diverge from the correct solution. If the intrinsic parameters can be\nestimated with high accuracy for each of the cameras individually (for example, using\n#calibrateCamera ), you are recommended to do so and then pass @ref CALIB_FIX_INTRINSIC flag to the\nfunction along with the computed intrinsic parameters. Otherwise, if all the parameters are\nestimated at once, it makes sense to restrict some parameters, for example, pass\n@ref CALIB_SAME_FOCAL_LENGTH and @ref CALIB_ZERO_TANGENT_DIST flags, which is usually a\nreasonable assumption.\nSimilarly to #calibrateCamera, the function minimizes the total re-projection error for all the\npoints in all the available views from both cameras. The function returns the final value of the\nre-projection error.\n\nPython prototype (for reference only):\n```python3\nstereoCalibrateExtended(objectPoints, imagePoints1, imagePoints2, cameraMatrix1, distCoeffs1, cameraMatrix2, distCoeffs2, imageSize, R, T[, E[, F[, rvecs[, tvecs[, perViewErrors[, flags[, criteria]]]]]]]) -> retval, cameraMatrix1, distCoeffs1, cameraMatrix2, distCoeffs2, R, T, E, F, rvecs, tvecs, perViewErrors\n```","ref":"Evision.html#stereoCalibrateExtended/10"},{"type":"function","title":"Evision.stereoCalibrateExtended/11","doc":"Calibrates a stereo camera set up. This function finds the intrinsic parameters\nfor each of the two cameras and the extrinsic parameters between the two cameras.\n\n##### Positional Arguments\n- **objectPoints**: `[Evision.Mat]`.\n\n  Vector of vectors of the calibration pattern points. The same structure as\n  in @ref calibrateCamera. For each pattern view, both cameras need to see the same object\n  points. Therefore, objectPoints.size(), imagePoints1.size(), and imagePoints2.size() need to be\n  equal as well as objectPoints[i].size(), imagePoints1[i].size(), and imagePoints2[i].size() need to\n  be equal for each i.\n\n- **imagePoints1**: `[Evision.Mat]`.\n\n  Vector of vectors of the projections of the calibration pattern points,\n  observed by the first camera. The same structure as in @ref calibrateCamera.\n\n- **imagePoints2**: `[Evision.Mat]`.\n\n  Vector of vectors of the projections of the calibration pattern points,\n  observed by the second camera. The same structure as in @ref calibrateCamera.\n\n- **imageSize**: `Size`.\n\n  Size of the image used only to initialize the camera intrinsic matrices.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Different flags that may be zero or a combination of the following values:\n  - @ref CALIB_FIX_INTRINSIC Fix cameraMatrix? and distCoeffs? so that only R, T, E, and F\n    matrices are estimated.\n  - @ref CALIB_USE_INTRINSIC_GUESS Optimize some or all of the intrinsic parameters\n    according to the specified flags. Initial values are provided by the user.\n  - @ref CALIB_USE_EXTRINSIC_GUESS R and T contain valid initial values that are optimized further.\n    Otherwise R and T are initialized to the median value of the pattern views (each dimension separately).\n  - @ref CALIB_FIX_PRINCIPAL_POINT Fix the principal points during the optimization.\n  - @ref CALIB_FIX_FOCAL_LENGTH Fix \\f$f^{(j)}_x\\f$ and \\f$f^{(j)}_y\\f$ .\n  - @ref CALIB_FIX_ASPECT_RATIO Optimize \\f$f^{(j)}_y\\f$ . Fix the ratio \\f$f^{(j)}_x/f^{(j)}_y\\f$\n    .\n  - @ref CALIB_SAME_FOCAL_LENGTH Enforce \\f$f^{(0)}_x=f^{(1)}_x\\f$ and \\f$f^{(0)}_y=f^{(1)}_y\\f$ .\n  - @ref CALIB_ZERO_TANGENT_DIST Set tangential distortion coefficients for each camera to\n    zeros and fix there.\n  - @ref CALIB_FIX_K1,..., @ref CALIB_FIX_K6 Do not change the corresponding radial\n    distortion coefficient during the optimization. If @ref CALIB_USE_INTRINSIC_GUESS is set,\n    the coefficient from the supplied distCoeffs matrix is used. Otherwise, it is set to 0.\n  - @ref CALIB_RATIONAL_MODEL Enable coefficients k4, k5, and k6. To provide the backward\n    compatibility, this extra flag should be explicitly specified to make the calibration\n    function use the rational model and return 8 coefficients. If the flag is not set, the\n    function computes and returns only 5 distortion coefficients.\n  - @ref CALIB_THIN_PRISM_MODEL Coefficients s1, s2, s3 and s4 are enabled. To provide the\n    backward compatibility, this extra flag should be explicitly specified to make the\n    calibration function use the thin prism model and return 12 coefficients. If the flag is not\n    set, the function computes and returns only 5 distortion coefficients.\n  - @ref CALIB_FIX_S1_S2_S3_S4 The thin prism distortion coefficients are not changed during\n    the optimization. If @ref CALIB_USE_INTRINSIC_GUESS is set, the coefficient from the\n    supplied distCoeffs matrix is used. Otherwise, it is set to 0.\n  - @ref CALIB_TILTED_MODEL Coefficients tauX and tauY are enabled. To provide the\n    backward compatibility, this extra flag should be explicitly specified to make the\n    calibration function use the tilted sensor model and return 14 coefficients. If the flag is not\n    set, the function computes and returns only 5 distortion coefficients.\n  - @ref CALIB_FIX_TAUX_TAUY The coefficients of the tilted sensor model are not changed during\n    the optimization. If @ref CALIB_USE_INTRINSIC_GUESS is set, the coefficient from the\n    supplied distCoeffs matrix is used. Otherwise, it is set to 0.\n\n- **criteria**: `TermCriteria`.\n\n  Termination criteria for the iterative optimization algorithm.\n\n##### Return\n- **retval**: `double`\n- **cameraMatrix1**: `Evision.Mat.t()`.\n\n  Input/output camera intrinsic matrix for the first camera, the same as in\n\n- **distCoeffs1**: `Evision.Mat.t()`.\n\n  Input/output vector of distortion coefficients, the same as in\n\n- **cameraMatrix2**: `Evision.Mat.t()`.\n\n  Input/output second camera intrinsic matrix for the second camera. See description for\n  cameraMatrix1.\n\n- **distCoeffs2**: `Evision.Mat.t()`.\n\n  Input/output lens distortion coefficients for the second camera. See\n  description for distCoeffs1.\n\n- **r**: `Evision.Mat.t()`.\n\n  Output rotation matrix. Together with the translation vector T, this matrix brings\n  points given in the first camera's coordinate system to points in the second camera's\n  coordinate system. In more technical terms, the tuple of R and T performs a change of basis\n  from the first camera's coordinate system to the second camera's coordinate system. Due to its\n  duality, this tuple is equivalent to the position of the first camera with respect to the\n  second camera coordinate system.\n\n- **t**: `Evision.Mat.t()`.\n\n  Output translation vector, see description above.\n\n- **e**: `Evision.Mat.t()`.\n\n  Output essential matrix.\n\n- **f**: `Evision.Mat.t()`.\n\n  Output fundamental matrix.\n\n- **rvecs**: `[Evision.Mat]`.\n\n  Output vector of rotation vectors ( @ref Rodrigues ) estimated for each pattern view in the\n  coordinate system of the first camera of the stereo pair (e.g. std::vector ). More in detail, each\n  i-th rotation vector together with the corresponding i-th translation vector (see the next output parameter\n  description) brings the calibration pattern from the object coordinate space (in which object points are\n  specified) to the camera coordinate space of the first camera of the stereo pair. In more technical terms,\n  the tuple of the i-th rotation and translation vector performs a change of basis from object coordinate space\n  to camera coordinate space of the first camera of the stereo pair.\n\n- **tvecs**: `[Evision.Mat]`.\n\n  Output vector of translation vectors estimated for each pattern view, see parameter description\n  of previous output parameter ( rvecs ).\n\n- **perViewErrors**: `Evision.Mat.t()`.\n\n  Output vector of the RMS re-projection error estimated for each pattern view.\n\n@ref calibrateCamera. Furthermore, for the stereo case, additional flags may be used, see below.\n@ref calibrateCamera.\n\nThe function estimates the transformation between two cameras making a stereo pair. If one computes\nthe poses of an object relative to the first camera and to the second camera,\n( \\f$R\\_1\\f$,\\f$T\\_1\\f$ ) and (\\f$R\\_2\\f$,\\f$T\\_2\\f$), respectively, for a stereo camera where the\nrelative position and orientation between the two cameras are fixed, then those poses definitely\nrelate to each other. This means, if the relative position and orientation (\\f$R\\f$,\\f$T\\f$) of the\ntwo cameras is known, it is possible to compute (\\f$R\\_2\\f$,\\f$T\\_2\\f$) when (\\f$R\\_1\\f$,\\f$T\\_1\\f$) is\ngiven. This is what the described function does. It computes (\\f$R\\f$,\\f$T\\f$) such that:\n\\f[R\\_2=R R\\_1\\f]\n\\f[T\\_2=R T\\_1 + T.\\f]\nTherefore, one can compute the coordinate representation of a 3D point for the second camera's\ncoordinate system when given the point's coordinate representation in the first camera's coordinate\nsystem:\n\\f[\\begin{bmatrix}\nX\\_2 \\\\\\\\\nY\\_2 \\\\\\\\\nZ\\_2 \\\\\\\\\n1\n\\end{bmatrix} = \\begin{bmatrix}\nR & T \\\\\\\\\n0 & 1\n\\end{bmatrix} \\begin{bmatrix}\nX\\_1 \\\\\\\\\nY\\_1 \\\\\\\\\nZ\\_1 \\\\\\\\\n1\n\\end{bmatrix}.\\f]\nOptionally, it computes the essential matrix E:\n\\f[E= \\vecthreethree{0}{-T\\_2}{T\\_1}{T\\_2}{0}{-T\\_0}{-T\\_1}{T\\_0}{0} R\\f]\nwhere \\f$T\\_i\\f$ are components of the translation vector \\f$T\\f$ : \\f$T=\\[T\\_0, T\\_1, T\\_2]^T\\f$ .\nAnd the function can also compute the fundamental matrix F:\n\\f[F = cameraMatrix2^{-T}\\cdot E \\cdot cameraMatrix1^{-1}\\f]\nBesides the stereo-related information, the function can also perform a full calibration of each of\nthe two cameras. However, due to the high dimensionality of the parameter space and noise in the\ninput data, the function can diverge from the correct solution. If the intrinsic parameters can be\nestimated with high accuracy for each of the cameras individually (for example, using\n#calibrateCamera ), you are recommended to do so and then pass @ref CALIB_FIX_INTRINSIC flag to the\nfunction along with the computed intrinsic parameters. Otherwise, if all the parameters are\nestimated at once, it makes sense to restrict some parameters, for example, pass\n@ref CALIB_SAME_FOCAL_LENGTH and @ref CALIB_ZERO_TANGENT_DIST flags, which is usually a\nreasonable assumption.\nSimilarly to #calibrateCamera, the function minimizes the total re-projection error for all the\npoints in all the available views from both cameras. The function returns the final value of the\nre-projection error.\n\nPython prototype (for reference only):\n```python3\nstereoCalibrateExtended(objectPoints, imagePoints1, imagePoints2, cameraMatrix1, distCoeffs1, cameraMatrix2, distCoeffs2, imageSize, R, T[, E[, F[, rvecs[, tvecs[, perViewErrors[, flags[, criteria]]]]]]]) -> retval, cameraMatrix1, distCoeffs1, cameraMatrix2, distCoeffs2, R, T, E, F, rvecs, tvecs, perViewErrors\n```","ref":"Evision.html#stereoCalibrateExtended/11"},{"type":"function","title":"Evision.stereoRectify/1","doc":"","ref":"Evision.html#stereoRectify/1"},{"type":"function","title":"Evision.stereoRectify/7","doc":"Computes rectification transforms for each head of a calibrated stereo camera.\n\n##### Positional Arguments\n- **cameraMatrix1**: `Evision.Mat`.\n\n  First camera intrinsic matrix.\n\n- **distCoeffs1**: `Evision.Mat`.\n\n  First camera distortion parameters.\n\n- **cameraMatrix2**: `Evision.Mat`.\n\n  Second camera intrinsic matrix.\n\n- **distCoeffs2**: `Evision.Mat`.\n\n  Second camera distortion parameters.\n\n- **imageSize**: `Size`.\n\n  Size of the image used for stereo calibration.\n\n- **r**: `Evision.Mat`.\n\n  Rotation matrix from the coordinate system of the first camera to the second camera,\n  see @ref stereoCalibrate.\n\n- **t**: `Evision.Mat`.\n\n  Translation vector from the coordinate system of the first camera to the second camera,\n  see @ref stereoCalibrate.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Operation flags that may be zero or @ref CALIB_ZERO_DISPARITY . If the flag is set,\n  the function makes the principal points of each camera have the same pixel coordinates in the\n  rectified views. And if the flag is not set, the function may still shift the images in the\n  horizontal or vertical direction (depending on the orientation of epipolar lines) to maximize the\n  useful image area.\n\n- **alpha**: `double`.\n\n  Free scaling parameter. If it is -1 or absent, the function performs the default\n  scaling. Otherwise, the parameter should be between 0 and 1. alpha=0 means that the rectified\n  images are zoomed and shifted so that only valid pixels are visible (no black areas after\n  rectification). alpha=1 means that the rectified image is decimated and shifted so that all the\n  pixels from the original images from the cameras are retained in the rectified images (no source\n  image pixels are lost). Any intermediate value yields an intermediate result between\n  those two extreme cases.\n\n- **newImageSize**: `Size`.\n\n  New image resolution after rectification. The same size should be passed to\n  #initUndistortRectifyMap (see the stereo_calib.cpp sample in OpenCV samples directory). When (0,0)\n  is passed (default), it is set to the original imageSize . Setting it to a larger value can help you\n  preserve details in the original image, especially when there is a big radial distortion.\n\n##### Return\n- **r1**: `Evision.Mat.t()`.\n\n  Output 3x3 rectification transform (rotation matrix) for the first camera. This matrix\n  brings points given in the unrectified first camera's coordinate system to points in the rectified\n  first camera's coordinate system. In more technical terms, it performs a change of basis from the\n  unrectified first camera's coordinate system to the rectified first camera's coordinate system.\n\n- **r2**: `Evision.Mat.t()`.\n\n  Output 3x3 rectification transform (rotation matrix) for the second camera. This matrix\n  brings points given in the unrectified second camera's coordinate system to points in the rectified\n  second camera's coordinate system. In more technical terms, it performs a change of basis from the\n  unrectified second camera's coordinate system to the rectified second camera's coordinate system.\n\n- **p1**: `Evision.Mat.t()`.\n\n  Output 3x4 projection matrix in the new (rectified) coordinate systems for the first\n  camera, i.e. it projects points given in the rectified first camera coordinate system into the\n  rectified first camera's image.\n\n- **p2**: `Evision.Mat.t()`.\n\n  Output 3x4 projection matrix in the new (rectified) coordinate systems for the second\n  camera, i.e. it projects points given in the rectified first camera coordinate system into the\n  rectified second camera's image.\n\n- **q**: `Evision.Mat.t()`.\n\n  Output \\f$4 \\times 4\\f$ disparity-to-depth mapping matrix (see @ref reprojectImageTo3D).\n\n- **validPixROI1**: `Rect*`.\n\n  Optional output rectangles inside the rectified images where all the pixels\n  are valid. If alpha=0 , the ROIs cover the whole images. Otherwise, they are likely to be smaller\n  (see the picture below).\n\n- **validPixROI2**: `Rect*`.\n\n  Optional output rectangles inside the rectified images where all the pixels\n  are valid. If alpha=0 , the ROIs cover the whole images. Otherwise, they are likely to be smaller\n  (see the picture below).\n\nThe function computes the rotation matrices for each camera that (virtually) make both camera image\nplanes the same plane. Consequently, this makes all the epipolar lines parallel and thus simplifies\nthe dense stereo correspondence problem. The function takes the matrices computed by #stereoCalibrate\nas input. As output, it provides two rotation matrices and also two projection matrices in the new\ncoordinates. The function distinguishes the following two cases:\n- **Horizontal stereo**: the first and the second camera views are shifted relative to each other\n  mainly along the x-axis (with possible small vertical shift). In the rectified images, the\n  corresponding epipolar lines in the left and right cameras are horizontal and have the same\n  y-coordinate. P1 and P2 look like:\n\n\\f[\\texttt{P1} = \\begin{bmatrix}\nf & 0 & cx\\_1 & 0 \\\\\\\\\n0 & f & cy & 0 \\\\\\\\\n0 & 0 & 1 & 0\n\\end{bmatrix}\\f]\n\\f[\\texttt{P2} = \\begin{bmatrix}\nf & 0 & cx\\_2 & T\\_x \\cdot f \\\\\\\\\n0 & f & cy & 0 \\\\\\\\\n0 & 0 & 1 & 0\n\\end{bmatrix} ,\\f]\n\\f[\\texttt{Q} = \\begin{bmatrix}\n1 & 0 & 0 & -cx\\_1 \\\\\\\\\n0 & 1 & 0 & -cy \\\\\\\\\n0 & 0 & 0 & f \\\\\\\\\n0 & 0 & -\\frac{1}{T\\_x} & \\frac{cx\\_1 - cx\\_2}{T\\_x}\n\\end{bmatrix} \\f]\nwhere \\f$T\\_x\\f$ is a horizontal shift between the cameras and \\f$cx\\_1=cx\\_2\\f$ if\n@ref CALIB_ZERO_DISPARITY is set.\n- **Vertical stereo**: the first and the second camera views are shifted relative to each other\n  mainly in the vertical direction (and probably a bit in the horizontal direction too). The epipolar\n  lines in the rectified images are vertical and have the same x-coordinate. P1 and P2 look like:\n\n\\f[\\texttt{P1} = \\begin{bmatrix}\nf & 0 & cx & 0 \\\\\\\\\n0 & f & cy\\_1 & 0 \\\\\\\\\n0 & 0 & 1 & 0\n\\end{bmatrix}\\f]\n\\f[\\texttt{P2} = \\begin{bmatrix}\nf & 0 & cx & 0 \\\\\\\\\n0 & f & cy\\_2 & T\\_y \\cdot f \\\\\\\\\n0 & 0 & 1 & 0\n\\end{bmatrix},\\f]\n\\f[\\texttt{Q} = \\begin{bmatrix}\n1 & 0 & 0 & -cx \\\\\\\\\n0 & 1 & 0 & -cy\\_1 \\\\\\\\\n0 & 0 & 0 & f \\\\\\\\\n0 & 0 & -\\frac{1}{T\\_y} & \\frac{cy\\_1 - cy\\_2}{T\\_y}\n\\end{bmatrix} \\f]\nwhere \\f$T\\_y\\f$ is a vertical shift between the cameras and \\f$cy\\_1=cy\\_2\\f$ if\n@ref CALIB_ZERO_DISPARITY is set.\nAs you can see, the first three columns of P1 and P2 will effectively be the new \"rectified\" camera\nmatrices. The matrices, together with R1 and R2 , can then be passed to #initUndistortRectifyMap to\ninitialize the rectification map for each camera.\nSee below the screenshot from the stereo_calib.cpp sample. Some red horizontal lines pass through\nthe corresponding image regions. This means that the images are well rectified, which is what most\nstereo correspondence algorithms rely on. The green rectangles are roi1 and roi2 . You see that\ntheir interiors are all valid pixels.\n![image](pics/stereo_undistort.jpg)\n\nPython prototype (for reference only):\n```python3\nstereoRectify(cameraMatrix1, distCoeffs1, cameraMatrix2, distCoeffs2, imageSize, R, T[, R1[, R2[, P1[, P2[, Q[, flags[, alpha[, newImageSize]]]]]]]]) -> R1, R2, P1, P2, Q, validPixROI1, validPixROI2\n```","ref":"Evision.html#stereoRectify/7"},{"type":"function","title":"Evision.stereoRectify/8","doc":"Computes rectification transforms for each head of a calibrated stereo camera.\n\n##### Positional Arguments\n- **cameraMatrix1**: `Evision.Mat`.\n\n  First camera intrinsic matrix.\n\n- **distCoeffs1**: `Evision.Mat`.\n\n  First camera distortion parameters.\n\n- **cameraMatrix2**: `Evision.Mat`.\n\n  Second camera intrinsic matrix.\n\n- **distCoeffs2**: `Evision.Mat`.\n\n  Second camera distortion parameters.\n\n- **imageSize**: `Size`.\n\n  Size of the image used for stereo calibration.\n\n- **r**: `Evision.Mat`.\n\n  Rotation matrix from the coordinate system of the first camera to the second camera,\n  see @ref stereoCalibrate.\n\n- **t**: `Evision.Mat`.\n\n  Translation vector from the coordinate system of the first camera to the second camera,\n  see @ref stereoCalibrate.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Operation flags that may be zero or @ref CALIB_ZERO_DISPARITY . If the flag is set,\n  the function makes the principal points of each camera have the same pixel coordinates in the\n  rectified views. And if the flag is not set, the function may still shift the images in the\n  horizontal or vertical direction (depending on the orientation of epipolar lines) to maximize the\n  useful image area.\n\n- **alpha**: `double`.\n\n  Free scaling parameter. If it is -1 or absent, the function performs the default\n  scaling. Otherwise, the parameter should be between 0 and 1. alpha=0 means that the rectified\n  images are zoomed and shifted so that only valid pixels are visible (no black areas after\n  rectification). alpha=1 means that the rectified image is decimated and shifted so that all the\n  pixels from the original images from the cameras are retained in the rectified images (no source\n  image pixels are lost). Any intermediate value yields an intermediate result between\n  those two extreme cases.\n\n- **newImageSize**: `Size`.\n\n  New image resolution after rectification. The same size should be passed to\n  #initUndistortRectifyMap (see the stereo_calib.cpp sample in OpenCV samples directory). When (0,0)\n  is passed (default), it is set to the original imageSize . Setting it to a larger value can help you\n  preserve details in the original image, especially when there is a big radial distortion.\n\n##### Return\n- **r1**: `Evision.Mat.t()`.\n\n  Output 3x3 rectification transform (rotation matrix) for the first camera. This matrix\n  brings points given in the unrectified first camera's coordinate system to points in the rectified\n  first camera's coordinate system. In more technical terms, it performs a change of basis from the\n  unrectified first camera's coordinate system to the rectified first camera's coordinate system.\n\n- **r2**: `Evision.Mat.t()`.\n\n  Output 3x3 rectification transform (rotation matrix) for the second camera. This matrix\n  brings points given in the unrectified second camera's coordinate system to points in the rectified\n  second camera's coordinate system. In more technical terms, it performs a change of basis from the\n  unrectified second camera's coordinate system to the rectified second camera's coordinate system.\n\n- **p1**: `Evision.Mat.t()`.\n\n  Output 3x4 projection matrix in the new (rectified) coordinate systems for the first\n  camera, i.e. it projects points given in the rectified first camera coordinate system into the\n  rectified first camera's image.\n\n- **p2**: `Evision.Mat.t()`.\n\n  Output 3x4 projection matrix in the new (rectified) coordinate systems for the second\n  camera, i.e. it projects points given in the rectified first camera coordinate system into the\n  rectified second camera's image.\n\n- **q**: `Evision.Mat.t()`.\n\n  Output \\f$4 \\times 4\\f$ disparity-to-depth mapping matrix (see @ref reprojectImageTo3D).\n\n- **validPixROI1**: `Rect*`.\n\n  Optional output rectangles inside the rectified images where all the pixels\n  are valid. If alpha=0 , the ROIs cover the whole images. Otherwise, they are likely to be smaller\n  (see the picture below).\n\n- **validPixROI2**: `Rect*`.\n\n  Optional output rectangles inside the rectified images where all the pixels\n  are valid. If alpha=0 , the ROIs cover the whole images. Otherwise, they are likely to be smaller\n  (see the picture below).\n\nThe function computes the rotation matrices for each camera that (virtually) make both camera image\nplanes the same plane. Consequently, this makes all the epipolar lines parallel and thus simplifies\nthe dense stereo correspondence problem. The function takes the matrices computed by #stereoCalibrate\nas input. As output, it provides two rotation matrices and also two projection matrices in the new\ncoordinates. The function distinguishes the following two cases:\n- **Horizontal stereo**: the first and the second camera views are shifted relative to each other\n  mainly along the x-axis (with possible small vertical shift). In the rectified images, the\n  corresponding epipolar lines in the left and right cameras are horizontal and have the same\n  y-coordinate. P1 and P2 look like:\n\n\\f[\\texttt{P1} = \\begin{bmatrix}\nf & 0 & cx\\_1 & 0 \\\\\\\\\n0 & f & cy & 0 \\\\\\\\\n0 & 0 & 1 & 0\n\\end{bmatrix}\\f]\n\\f[\\texttt{P2} = \\begin{bmatrix}\nf & 0 & cx\\_2 & T\\_x \\cdot f \\\\\\\\\n0 & f & cy & 0 \\\\\\\\\n0 & 0 & 1 & 0\n\\end{bmatrix} ,\\f]\n\\f[\\texttt{Q} = \\begin{bmatrix}\n1 & 0 & 0 & -cx\\_1 \\\\\\\\\n0 & 1 & 0 & -cy \\\\\\\\\n0 & 0 & 0 & f \\\\\\\\\n0 & 0 & -\\frac{1}{T\\_x} & \\frac{cx\\_1 - cx\\_2}{T\\_x}\n\\end{bmatrix} \\f]\nwhere \\f$T\\_x\\f$ is a horizontal shift between the cameras and \\f$cx\\_1=cx\\_2\\f$ if\n@ref CALIB_ZERO_DISPARITY is set.\n- **Vertical stereo**: the first and the second camera views are shifted relative to each other\n  mainly in the vertical direction (and probably a bit in the horizontal direction too). The epipolar\n  lines in the rectified images are vertical and have the same x-coordinate. P1 and P2 look like:\n\n\\f[\\texttt{P1} = \\begin{bmatrix}\nf & 0 & cx & 0 \\\\\\\\\n0 & f & cy\\_1 & 0 \\\\\\\\\n0 & 0 & 1 & 0\n\\end{bmatrix}\\f]\n\\f[\\texttt{P2} = \\begin{bmatrix}\nf & 0 & cx & 0 \\\\\\\\\n0 & f & cy\\_2 & T\\_y \\cdot f \\\\\\\\\n0 & 0 & 1 & 0\n\\end{bmatrix},\\f]\n\\f[\\texttt{Q} = \\begin{bmatrix}\n1 & 0 & 0 & -cx \\\\\\\\\n0 & 1 & 0 & -cy\\_1 \\\\\\\\\n0 & 0 & 0 & f \\\\\\\\\n0 & 0 & -\\frac{1}{T\\_y} & \\frac{cy\\_1 - cy\\_2}{T\\_y}\n\\end{bmatrix} \\f]\nwhere \\f$T\\_y\\f$ is a vertical shift between the cameras and \\f$cy\\_1=cy\\_2\\f$ if\n@ref CALIB_ZERO_DISPARITY is set.\nAs you can see, the first three columns of P1 and P2 will effectively be the new \"rectified\" camera\nmatrices. The matrices, together with R1 and R2 , can then be passed to #initUndistortRectifyMap to\ninitialize the rectification map for each camera.\nSee below the screenshot from the stereo_calib.cpp sample. Some red horizontal lines pass through\nthe corresponding image regions. This means that the images are well rectified, which is what most\nstereo correspondence algorithms rely on. The green rectangles are roi1 and roi2 . You see that\ntheir interiors are all valid pixels.\n![image](pics/stereo_undistort.jpg)\n\nPython prototype (for reference only):\n```python3\nstereoRectify(cameraMatrix1, distCoeffs1, cameraMatrix2, distCoeffs2, imageSize, R, T[, R1[, R2[, P1[, P2[, Q[, flags[, alpha[, newImageSize]]]]]]]]) -> R1, R2, P1, P2, Q, validPixROI1, validPixROI2\n```","ref":"Evision.html#stereoRectify/8"},{"type":"function","title":"Evision.stereoRectifyUncalibrated/1","doc":"","ref":"Evision.html#stereoRectifyUncalibrated/1"},{"type":"function","title":"Evision.stereoRectifyUncalibrated/4","doc":"Computes a rectification transform for an uncalibrated stereo camera.\n\n##### Positional Arguments\n- **points1**: `Evision.Mat`.\n\n  Array of feature points in the first image.\n\n- **points2**: `Evision.Mat`.\n\n  The corresponding points in the second image. The same formats as in\n  #findFundamentalMat are supported.\n\n- **f**: `Evision.Mat`.\n\n  Input fundamental matrix. It can be computed from the same set of point pairs using\n  #findFundamentalMat .\n\n- **imgSize**: `Size`.\n\n  Size of the image.\n\n##### Keyword Arguments\n- **threshold**: `double`.\n\n  Optional threshold used to filter out the outliers. If the parameter is greater\n  than zero, all the point pairs that do not comply with the epipolar geometry (that is, the points\n  for which \\f$|\\texttt{points2[i]}^T \\cdot \\texttt{F} \\cdot \\texttt{points1[i]}|>\\texttt{threshold}\\f$ )\n  are rejected prior to computing the homographies. Otherwise, all the points are considered inliers.\n\n##### Return\n- **retval**: `bool`\n- **h1**: `Evision.Mat.t()`.\n\n  Output rectification homography matrix for the first image.\n\n- **h2**: `Evision.Mat.t()`.\n\n  Output rectification homography matrix for the second image.\n\nThe function computes the rectification transformations without knowing intrinsic parameters of the\ncameras and their relative position in the space, which explains the suffix \"uncalibrated\". Another\nrelated difference from #stereoRectify is that the function outputs not the rectification\ntransformations in the object (3D) space, but the planar perspective transformations encoded by the\nhomography matrices H1 and H2 . The function implements the algorithm @cite Hartley99 .\n**Note**: \nWhile the algorithm does not need to know the intrinsic parameters of the cameras, it heavily\ndepends on the epipolar geometry. Therefore, if the camera lenses have a significant distortion,\nit would be better to correct it before computing the fundamental matrix and calling this\nfunction. For example, distortion coefficients can be estimated for each head of stereo camera\nseparately by using #calibrateCamera . Then, the images can be corrected using #undistort , or\njust the point coordinates can be corrected with #undistortPoints .\n\nPython prototype (for reference only):\n```python3\nstereoRectifyUncalibrated(points1, points2, F, imgSize[, H1[, H2[, threshold]]]) -> retval, H1, H2\n```","ref":"Evision.html#stereoRectifyUncalibrated/4"},{"type":"function","title":"Evision.stereoRectifyUncalibrated/5","doc":"Computes a rectification transform for an uncalibrated stereo camera.\n\n##### Positional Arguments\n- **points1**: `Evision.Mat`.\n\n  Array of feature points in the first image.\n\n- **points2**: `Evision.Mat`.\n\n  The corresponding points in the second image. The same formats as in\n  #findFundamentalMat are supported.\n\n- **f**: `Evision.Mat`.\n\n  Input fundamental matrix. It can be computed from the same set of point pairs using\n  #findFundamentalMat .\n\n- **imgSize**: `Size`.\n\n  Size of the image.\n\n##### Keyword Arguments\n- **threshold**: `double`.\n\n  Optional threshold used to filter out the outliers. If the parameter is greater\n  than zero, all the point pairs that do not comply with the epipolar geometry (that is, the points\n  for which \\f$|\\texttt{points2[i]}^T \\cdot \\texttt{F} \\cdot \\texttt{points1[i]}|>\\texttt{threshold}\\f$ )\n  are rejected prior to computing the homographies. Otherwise, all the points are considered inliers.\n\n##### Return\n- **retval**: `bool`\n- **h1**: `Evision.Mat.t()`.\n\n  Output rectification homography matrix for the first image.\n\n- **h2**: `Evision.Mat.t()`.\n\n  Output rectification homography matrix for the second image.\n\nThe function computes the rectification transformations without knowing intrinsic parameters of the\ncameras and their relative position in the space, which explains the suffix \"uncalibrated\". Another\nrelated difference from #stereoRectify is that the function outputs not the rectification\ntransformations in the object (3D) space, but the planar perspective transformations encoded by the\nhomography matrices H1 and H2 . The function implements the algorithm @cite Hartley99 .\n**Note**: \nWhile the algorithm does not need to know the intrinsic parameters of the cameras, it heavily\ndepends on the epipolar geometry. Therefore, if the camera lenses have a significant distortion,\nit would be better to correct it before computing the fundamental matrix and calling this\nfunction. For example, distortion coefficients can be estimated for each head of stereo camera\nseparately by using #calibrateCamera . Then, the images can be corrected using #undistort , or\njust the point coordinates can be corrected with #undistortPoints .\n\nPython prototype (for reference only):\n```python3\nstereoRectifyUncalibrated(points1, points2, F, imgSize[, H1[, H2[, threshold]]]) -> retval, H1, H2\n```","ref":"Evision.html#stereoRectifyUncalibrated/5"},{"type":"function","title":"Evision.stylization/1","doc":"Stylization aims to produce digital imagery with a wide variety of effects not focused on\nphotorealism. Edge-aware filters are ideal for stylization, as they can abstract regions of low\ncontrast while preserving, or enhancing, high-contrast features.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n##### Keyword Arguments\n- **sigma_s**: `float`.\n\n  %Range between 0 to 200.\n\n- **sigma_r**: `float`.\n\n  %Range between 0 to 1.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as src.\n\nPython prototype (for reference only):\n```python3\nstylization(src[, dst[, sigma_s[, sigma_r]]]) -> dst\n```","ref":"Evision.html#stylization/1"},{"type":"function","title":"Evision.stylization/2","doc":"Stylization aims to produce digital imagery with a wide variety of effects not focused on\nphotorealism. Edge-aware filters are ideal for stylization, as they can abstract regions of low\ncontrast while preserving, or enhancing, high-contrast features.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n##### Keyword Arguments\n- **sigma_s**: `float`.\n\n  %Range between 0 to 200.\n\n- **sigma_r**: `float`.\n\n  %Range between 0 to 1.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as src.\n\nPython prototype (for reference only):\n```python3\nstylization(src[, dst[, sigma_s[, sigma_r]]]) -> dst\n```","ref":"Evision.html#stylization/2"},{"type":"function","title":"Evision.subtract/1","doc":"","ref":"Evision.html#subtract/1"},{"type":"function","title":"Evision.subtract/2","doc":"Calculates the per-element difference between two arrays or array and a scalar.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array or a scalar.\n\n- **src2**: `Evision.Mat`.\n\n  second input array or a scalar.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  optional operation mask; this is an 8-bit single channel array that specifies elements\n  of the output array to be changed.\n\n- **dtype**: `integer()`.\n\n  optional depth of the output array\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and the same number of channels as the input array.\n\nThe function subtract calculates:\n- Difference between two arrays, when both input arrays have the same size and the same number of\n  channels:\n  \\f[\\texttt{dst}(I) =  \\texttt{saturate} ( \\texttt{src1}(I) -  \\texttt{src2}(I)) \\quad \\texttt{if mask}(I) \\ne0\\f]\n\n- Difference between an array and a scalar, when src2 is constructed from Scalar or has the same\n  number of elements as `src1.channels()`:\n  \\f[\\texttt{dst}(I) =  \\texttt{saturate} ( \\texttt{src1}(I) -  \\texttt{src2} ) \\quad \\texttt{if mask}(I) \\ne0\\f]\n\n- Difference between a scalar and an array, when src1 is constructed from Scalar or has the same\n  number of elements as `src2.channels()`:\n  \\f[\\texttt{dst}(I) =  \\texttt{saturate} ( \\texttt{src1} -  \\texttt{src2}(I) ) \\quad \\texttt{if mask}(I) \\ne0\\f]\n\n- The reverse difference between a scalar and an array in the case of `SubRS`:\n  \\f[\\texttt{dst}(I) =  \\texttt{saturate} ( \\texttt{src2} -  \\texttt{src1}(I) ) \\quad \\texttt{if mask}(I) \\ne0\\f]\n  where I is a multi-dimensional index of array elements. In case of multi-channel arrays, each\n  channel is processed independently.\n\nThe first function in the list above can be replaced with matrix expressions:\n```cpp\ndst = src1 - src2;\ndst -= src1; // equivalent to subtract(dst, src1, dst);\n```\nThe input arrays and the output array can all have the same or different depths. For example, you\ncan subtract to 8-bit unsigned arrays and store the difference in a 16-bit signed array. Depth of\nthe output array is determined by dtype parameter. In the second and third cases above, as well as\nin the first case, when src1.depth() == src2.depth(), dtype can be set to the default -1. In this\ncase the output array will have the same depth as the input array, be it src1, src2 or both.\n**Note**: Saturation is not applied when the output array has the depth CV_32S. You may even get\nresult of an incorrect sign in the case of overflow.\n**Note**: (Python) Be careful to difference behaviour between src1/src2 are single number and they are tuple/array.\n`subtract(src,X)` means `subtract(src,(X,X,X,X))`.\n`subtract(src,(X,))` means `subtract(src,(X,0,0,0))`.\n@sa  add, addWeighted, scaleAdd, Mat::convertTo\n\nPython prototype (for reference only):\n```python3\nsubtract(src1, src2[, dst[, mask[, dtype]]]) -> dst\n```","ref":"Evision.html#subtract/2"},{"type":"function","title":"Evision.subtract/3","doc":"Calculates the per-element difference between two arrays or array and a scalar.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  first input array or a scalar.\n\n- **src2**: `Evision.Mat`.\n\n  second input array or a scalar.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  optional operation mask; this is an 8-bit single channel array that specifies elements\n  of the output array to be changed.\n\n- **dtype**: `integer()`.\n\n  optional depth of the output array\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and the same number of channels as the input array.\n\nThe function subtract calculates:\n- Difference between two arrays, when both input arrays have the same size and the same number of\n  channels:\n  \\f[\\texttt{dst}(I) =  \\texttt{saturate} ( \\texttt{src1}(I) -  \\texttt{src2}(I)) \\quad \\texttt{if mask}(I) \\ne0\\f]\n\n- Difference between an array and a scalar, when src2 is constructed from Scalar or has the same\n  number of elements as `src1.channels()`:\n  \\f[\\texttt{dst}(I) =  \\texttt{saturate} ( \\texttt{src1}(I) -  \\texttt{src2} ) \\quad \\texttt{if mask}(I) \\ne0\\f]\n\n- Difference between a scalar and an array, when src1 is constructed from Scalar or has the same\n  number of elements as `src2.channels()`:\n  \\f[\\texttt{dst}(I) =  \\texttt{saturate} ( \\texttt{src1} -  \\texttt{src2}(I) ) \\quad \\texttt{if mask}(I) \\ne0\\f]\n\n- The reverse difference between a scalar and an array in the case of `SubRS`:\n  \\f[\\texttt{dst}(I) =  \\texttt{saturate} ( \\texttt{src2} -  \\texttt{src1}(I) ) \\quad \\texttt{if mask}(I) \\ne0\\f]\n  where I is a multi-dimensional index of array elements. In case of multi-channel arrays, each\n  channel is processed independently.\n\nThe first function in the list above can be replaced with matrix expressions:\n```cpp\ndst = src1 - src2;\ndst -= src1; // equivalent to subtract(dst, src1, dst);\n```\nThe input arrays and the output array can all have the same or different depths. For example, you\ncan subtract to 8-bit unsigned arrays and store the difference in a 16-bit signed array. Depth of\nthe output array is determined by dtype parameter. In the second and third cases above, as well as\nin the first case, when src1.depth() == src2.depth(), dtype can be set to the default -1. In this\ncase the output array will have the same depth as the input array, be it src1, src2 or both.\n**Note**: Saturation is not applied when the output array has the depth CV_32S. You may even get\nresult of an incorrect sign in the case of overflow.\n**Note**: (Python) Be careful to difference behaviour between src1/src2 are single number and they are tuple/array.\n`subtract(src,X)` means `subtract(src,(X,X,X,X))`.\n`subtract(src,(X,))` means `subtract(src,(X,0,0,0))`.\n@sa  add, addWeighted, scaleAdd, Mat::convertTo\n\nPython prototype (for reference only):\n```python3\nsubtract(src1, src2[, dst[, mask[, dtype]]]) -> dst\n```","ref":"Evision.html#subtract/3"},{"type":"function","title":"Evision.sumElems/1","doc":"Calculates the sum of array elements.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array that must have from 1 to 4 channels.\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n\nThe function cv::sum calculates and returns the sum of array elements,\nindependently for each channel.\n@sa  countNonZero, mean, meanStdDev, norm, minMaxLoc, reduce\n\nPython prototype (for reference only):\n```python3\nsumElems(src) -> retval\n```","ref":"Evision.html#sumElems/1"},{"type":"function","title":"Evision.svBackSubst/1","doc":"","ref":"Evision.html#svBackSubst/1"},{"type":"function","title":"Evision.svBackSubst/4","doc":"SVBackSubst\n\n##### Positional Arguments\n- **w**: `Evision.Mat`\n- **u**: `Evision.Mat`\n- **vt**: `Evision.Mat`\n- **rhs**: `Evision.Mat`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nwrap SVD::backSubst\n\nPython prototype (for reference only):\n```python3\nSVBackSubst(w, u, vt, rhs[, dst]) -> dst\n```","ref":"Evision.html#svBackSubst/4"},{"type":"function","title":"Evision.svBackSubst/5","doc":"SVBackSubst\n\n##### Positional Arguments\n- **w**: `Evision.Mat`\n- **u**: `Evision.Mat`\n- **vt**: `Evision.Mat`\n- **rhs**: `Evision.Mat`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nwrap SVD::backSubst\n\nPython prototype (for reference only):\n```python3\nSVBackSubst(w, u, vt, rhs[, dst]) -> dst\n```","ref":"Evision.html#svBackSubst/5"},{"type":"function","title":"Evision.svdDecomp/1","doc":"SVDecomp\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n##### Return\n- **w**: `Evision.Mat.t()`.\n- **u**: `Evision.Mat.t()`.\n- **vt**: `Evision.Mat.t()`.\n\nwrap SVD::compute\n\nPython prototype (for reference only):\n```python3\nSVDecomp(src[, w[, u[, vt[, flags]]]]) -> w, u, vt\n```","ref":"Evision.html#svdDecomp/1"},{"type":"function","title":"Evision.svdDecomp/2","doc":"SVDecomp\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n##### Return\n- **w**: `Evision.Mat.t()`.\n- **u**: `Evision.Mat.t()`.\n- **vt**: `Evision.Mat.t()`.\n\nwrap SVD::compute\n\nPython prototype (for reference only):\n```python3\nSVDecomp(src[, w[, u[, vt[, flags]]]]) -> w, u, vt\n```","ref":"Evision.html#svdDecomp/2"},{"type":"function","title":"Evision.textureFlattening/1","doc":"","ref":"Evision.html#textureFlattening/1"},{"type":"function","title":"Evision.textureFlattening/2","doc":"By retaining only the gradients at edge locations, before integrating with the Poisson solver, one\nwashes out the texture of the selected region, giving its contents a flat aspect. Here Canny Edge %Detector is used.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n- **mask**: `Evision.Mat`.\n\n  Input 8-bit 1 or 3-channel image.\n\n##### Keyword Arguments\n- **low_threshold**: `float`.\n\n  %Range from 0 to 100.\n\n- **high_threshold**: `float`.\n\n  Value \\> 100.\n\n- **kernel_size**: `integer()`.\n\n  The size of the Sobel kernel to be used.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as src.\n\n**Note**: \nThe algorithm assumes that the color of the source image is close to that of the destination. This\nassumption means that when the colors don't match, the source image color gets tinted toward the\ncolor of the destination image.\n\nPython prototype (for reference only):\n```python3\ntextureFlattening(src, mask[, dst[, low_threshold[, high_threshold[, kernel_size]]]]) -> dst\n```","ref":"Evision.html#textureFlattening/2"},{"type":"function","title":"Evision.textureFlattening/3","doc":"By retaining only the gradients at edge locations, before integrating with the Poisson solver, one\nwashes out the texture of the selected region, giving its contents a flat aspect. Here Canny Edge %Detector is used.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n- **mask**: `Evision.Mat`.\n\n  Input 8-bit 1 or 3-channel image.\n\n##### Keyword Arguments\n- **low_threshold**: `float`.\n\n  %Range from 0 to 100.\n\n- **high_threshold**: `float`.\n\n  Value \\> 100.\n\n- **kernel_size**: `integer()`.\n\n  The size of the Sobel kernel to be used.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as src.\n\n**Note**: \nThe algorithm assumes that the color of the source image is close to that of the destination. This\nassumption means that when the colors don't match, the source image color gets tinted toward the\ncolor of the destination image.\n\nPython prototype (for reference only):\n```python3\ntextureFlattening(src, mask[, dst[, low_threshold[, high_threshold[, kernel_size]]]]) -> dst\n```","ref":"Evision.html#textureFlattening/3"},{"type":"function","title":"Evision.threshold/1","doc":"","ref":"Evision.html#threshold/1"},{"type":"function","title":"Evision.threshold/4","doc":"Applies a fixed-level threshold to each array element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array (multiple-channel, 8-bit or 32-bit floating point).\n\n- **thresh**: `double`.\n\n  threshold value.\n\n- **maxval**: `double`.\n\n  maximum value to use with the #THRESH_BINARY and #THRESH_BINARY_INV thresholding\n  types.\n\n- **type**: `integer()`.\n\n  thresholding type (see #ThresholdTypes).\n\n##### Return\n- **retval**: `double`\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size  and type and the same number of channels as src.\n\nThe function applies fixed-level thresholding to a multiple-channel array. The function is typically\nused to get a bi-level (binary) image out of a grayscale image ( #compare could be also used for\nthis purpose) or for removing a noise, that is, filtering out pixels with too small or too large\nvalues. There are several types of thresholding supported by the function. They are determined by\ntype parameter.\nAlso, the special values #THRESH_OTSU or #THRESH_TRIANGLE may be combined with one of the\nabove values. In these cases, the function determines the optimal threshold value using the Otsu's\nor Triangle algorithm and uses it instead of the specified thresh.\n**Note**: Currently, the Otsu's and Triangle methods are implemented only for 8-bit single-channel images.\n@return the computed threshold value if Otsu's or Triangle methods used.\n@sa  adaptiveThreshold, findContours, compare, min, max\n\nPython prototype (for reference only):\n```python3\nthreshold(src, thresh, maxval, type[, dst]) -> retval, dst\n```","ref":"Evision.html#threshold/4"},{"type":"function","title":"Evision.threshold/5","doc":"Applies a fixed-level threshold to each array element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array (multiple-channel, 8-bit or 32-bit floating point).\n\n- **thresh**: `double`.\n\n  threshold value.\n\n- **maxval**: `double`.\n\n  maximum value to use with the #THRESH_BINARY and #THRESH_BINARY_INV thresholding\n  types.\n\n- **type**: `integer()`.\n\n  thresholding type (see #ThresholdTypes).\n\n##### Return\n- **retval**: `double`\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size  and type and the same number of channels as src.\n\nThe function applies fixed-level thresholding to a multiple-channel array. The function is typically\nused to get a bi-level (binary) image out of a grayscale image ( #compare could be also used for\nthis purpose) or for removing a noise, that is, filtering out pixels with too small or too large\nvalues. There are several types of thresholding supported by the function. They are determined by\ntype parameter.\nAlso, the special values #THRESH_OTSU or #THRESH_TRIANGLE may be combined with one of the\nabove values. In these cases, the function determines the optimal threshold value using the Otsu's\nor Triangle algorithm and uses it instead of the specified thresh.\n**Note**: Currently, the Otsu's and Triangle methods are implemented only for 8-bit single-channel images.\n@return the computed threshold value if Otsu's or Triangle methods used.\n@sa  adaptiveThreshold, findContours, compare, min, max\n\nPython prototype (for reference only):\n```python3\nthreshold(src, thresh, maxval, type[, dst]) -> retval, dst\n```","ref":"Evision.html#threshold/5"},{"type":"function","title":"Evision.trace/1","doc":"Returns the trace of a matrix.\n\n##### Positional Arguments\n- **mtx**: `Evision.Mat`.\n\n  input matrix.\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n\nThe function cv::trace returns the sum of the diagonal elements of the\nmatrix mtx .\n\\f[\\mathrm{tr} ( \\texttt{mtx} ) =  \\sum \\_i  \\texttt{mtx} (i,i)\\f]\n\nPython prototype (for reference only):\n```python3\ntrace(mtx) -> retval\n```","ref":"Evision.html#trace/1"},{"type":"function","title":"Evision.transform/1","doc":"","ref":"Evision.html#transform/1"},{"type":"function","title":"Evision.transform/2","doc":"Performs the matrix transformation of every array element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array that must have as many channels (1 to 4) as\n  m.cols or m.cols-1.\n\n- **m**: `Evision.Mat`.\n\n  transformation 2x2 or 2x3 floating-point matrix.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and depth as src; it has as\n  many channels as m.rows.\n\nThe function cv::transform performs the matrix transformation of every\nelement of the array src and stores the results in dst :\n\\f[\\texttt{dst} (I) =  \\texttt{m} \\cdot \\texttt{src} (I)\\f]\n(when m.cols=src.channels() ), or\n\\f[\\texttt{dst} (I) =  \\texttt{m} \\cdot \\[ \\texttt{src} (I); 1]\\f]\n(when m.cols=src.channels()+1 )\nEvery element of the N -channel array src is interpreted as N -element\nvector that is transformed using the M x N or M x (N+1) matrix m to\nM-element vector - the corresponding element of the output array dst .\nThe function may be used for geometrical transformation of\nN -dimensional points, arbitrary linear color space transformation (such\nas various kinds of RGB to YUV transforms), shuffling the image\nchannels, and so forth.\n@sa perspectiveTransform, getAffineTransform, estimateAffine2D, warpAffine, warpPerspective\n\nPython prototype (for reference only):\n```python3\ntransform(src, m[, dst]) -> dst\n```","ref":"Evision.html#transform/2"},{"type":"function","title":"Evision.transform/3","doc":"Performs the matrix transformation of every array element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array that must have as many channels (1 to 4) as\n  m.cols or m.cols-1.\n\n- **m**: `Evision.Mat`.\n\n  transformation 2x2 or 2x3 floating-point matrix.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size and depth as src; it has as\n  many channels as m.rows.\n\nThe function cv::transform performs the matrix transformation of every\nelement of the array src and stores the results in dst :\n\\f[\\texttt{dst} (I) =  \\texttt{m} \\cdot \\texttt{src} (I)\\f]\n(when m.cols=src.channels() ), or\n\\f[\\texttt{dst} (I) =  \\texttt{m} \\cdot \\[ \\texttt{src} (I); 1]\\f]\n(when m.cols=src.channels()+1 )\nEvery element of the N -channel array src is interpreted as N -element\nvector that is transformed using the M x N or M x (N+1) matrix m to\nM-element vector - the corresponding element of the output array dst .\nThe function may be used for geometrical transformation of\nN -dimensional points, arbitrary linear color space transformation (such\nas various kinds of RGB to YUV transforms), shuffling the image\nchannels, and so forth.\n@sa perspectiveTransform, getAffineTransform, estimateAffine2D, warpAffine, warpPerspective\n\nPython prototype (for reference only):\n```python3\ntransform(src, m[, dst]) -> dst\n```","ref":"Evision.html#transform/3"},{"type":"function","title":"Evision.transpose/1","doc":"Transposes a matrix.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same type as src.\n\nThe function cv::transpose transposes the matrix src :\n\\f[\\texttt{dst} (i,j) =  \\texttt{src} (j,i)\\f]\n**Note**: No complex conjugation is done in case of a complex matrix. It\nshould be done separately if needed.\n\nPython prototype (for reference only):\n```python3\ntranspose(src[, dst]) -> dst\n```","ref":"Evision.html#transpose/1"},{"type":"function","title":"Evision.transpose/2","doc":"Transposes a matrix.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same type as src.\n\nThe function cv::transpose transposes the matrix src :\n\\f[\\texttt{dst} (i,j) =  \\texttt{src} (j,i)\\f]\n**Note**: No complex conjugation is done in case of a complex matrix. It\nshould be done separately if needed.\n\nPython prototype (for reference only):\n```python3\ntranspose(src[, dst]) -> dst\n```","ref":"Evision.html#transpose/2"},{"type":"function","title":"Evision.transposeND/1","doc":"","ref":"Evision.html#transposeND/1"},{"type":"function","title":"Evision.transposeND/2","doc":"Transpose for n-dimensional matrices.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array.\n\n- **order**: `[integer()]`.\n\n  a permutation of [0,1,..,N-1] where N is the number of axes of src.\n  The i'th axis of dst will correspond to the axis numbered order[i] of the input.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same type as src.\n\n**Note**: Input should be continuous single-channel matrix.\n\nPython prototype (for reference only):\n```python3\ntransposeND(src, order[, dst]) -> dst\n```","ref":"Evision.html#transposeND/2"},{"type":"function","title":"Evision.transposeND/3","doc":"Transpose for n-dimensional matrices.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input array.\n\n- **order**: `[integer()]`.\n\n  a permutation of [0,1,..,N-1] where N is the number of axes of src.\n  The i'th axis of dst will correspond to the axis numbered order[i] of the input.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same type as src.\n\n**Note**: Input should be continuous single-channel matrix.\n\nPython prototype (for reference only):\n```python3\ntransposeND(src, order[, dst]) -> dst\n```","ref":"Evision.html#transposeND/3"},{"type":"function","title":"Evision.triangulatePoints/1","doc":"","ref":"Evision.html#triangulatePoints/1"},{"type":"function","title":"Evision.triangulatePoints/4","doc":"This function reconstructs 3-dimensional points (in homogeneous coordinates) by using\ntheir observations with a stereo camera.\n\n##### Positional Arguments\n- **projMatr1**: `Evision.Mat`.\n\n  3x4 projection matrix of the first camera, i.e. this matrix projects 3D points\n  given in the world's coordinate system into the first image.\n\n- **projMatr2**: `Evision.Mat`.\n\n  3x4 projection matrix of the second camera, i.e. this matrix projects 3D points\n  given in the world's coordinate system into the second image.\n\n- **projPoints1**: `Evision.Mat`.\n\n  2xN array of feature points in the first image. In the case of the c++ version,\n  it can be also a vector of feature points or two-channel matrix of size 1xN or Nx1.\n\n- **projPoints2**: `Evision.Mat`.\n\n  2xN array of corresponding points in the second image. In the case of the c++\n  version, it can be also a vector of feature points or two-channel matrix of size 1xN or Nx1.\n\n##### Return\n- **points4D**: `Evision.Mat.t()`.\n\n  4xN array of reconstructed points in homogeneous coordinates. These points are\n  returned in the world's coordinate system.\n\n**Note**: \nKeep in mind that all input data should be of float type in order for this function to work.\n**Note**: \nIf the projection matrices from @ref stereoRectify are used, then the returned points are\nrepresented in the first camera's rectified coordinate system.\n@sa\nreprojectImageTo3D\n\nPython prototype (for reference only):\n```python3\ntriangulatePoints(projMatr1, projMatr2, projPoints1, projPoints2[, points4D]) -> points4D\n```","ref":"Evision.html#triangulatePoints/4"},{"type":"function","title":"Evision.triangulatePoints/5","doc":"This function reconstructs 3-dimensional points (in homogeneous coordinates) by using\ntheir observations with a stereo camera.\n\n##### Positional Arguments\n- **projMatr1**: `Evision.Mat`.\n\n  3x4 projection matrix of the first camera, i.e. this matrix projects 3D points\n  given in the world's coordinate system into the first image.\n\n- **projMatr2**: `Evision.Mat`.\n\n  3x4 projection matrix of the second camera, i.e. this matrix projects 3D points\n  given in the world's coordinate system into the second image.\n\n- **projPoints1**: `Evision.Mat`.\n\n  2xN array of feature points in the first image. In the case of the c++ version,\n  it can be also a vector of feature points or two-channel matrix of size 1xN or Nx1.\n\n- **projPoints2**: `Evision.Mat`.\n\n  2xN array of corresponding points in the second image. In the case of the c++\n  version, it can be also a vector of feature points or two-channel matrix of size 1xN or Nx1.\n\n##### Return\n- **points4D**: `Evision.Mat.t()`.\n\n  4xN array of reconstructed points in homogeneous coordinates. These points are\n  returned in the world's coordinate system.\n\n**Note**: \nKeep in mind that all input data should be of float type in order for this function to work.\n**Note**: \nIf the projection matrices from @ref stereoRectify are used, then the returned points are\nrepresented in the first camera's rectified coordinate system.\n@sa\nreprojectImageTo3D\n\nPython prototype (for reference only):\n```python3\ntriangulatePoints(projMatr1, projMatr2, projPoints1, projPoints2[, points4D]) -> points4D\n```","ref":"Evision.html#triangulatePoints/5"},{"type":"function","title":"Evision.undistort/1","doc":"","ref":"Evision.html#undistort/1"},{"type":"function","title":"Evision.undistort/3","doc":"Transforms an image to compensate for lens distortion.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input (distorted) image.\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input camera matrix \\f$A = \\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$(k_1, k_2, p_1, p_2[, k_3[, k_4, k_5, k_6[, s_1, s_2, s_3, s_4[, \\tau_x, \\tau_y]]]])\\f$\n  of 4, 5, 8, 12 or 14 elements. If the vector is NULL/empty, the zero distortion coefficients are assumed.\n\n##### Keyword Arguments\n- **newCameraMatrix**: `Evision.Mat`.\n\n  Camera matrix of the distorted image. By default, it is the same as\n  cameraMatrix but you may additionally scale and shift the result by using a different matrix.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output (corrected) image that has the same size and type as src .\n\nThe function transforms an image to compensate radial and tangential lens distortion.\nThe function is simply a combination of #initUndistortRectifyMap (with unity R ) and #remap\n(with bilinear interpolation). See the former function for details of the transformation being\nperformed.\nThose pixels in the destination image, for which there is no correspondent pixels in the source\nimage, are filled with zeros (black color).\nA particular subset of the source image that will be visible in the corrected image can be regulated\nby newCameraMatrix. You can use #getOptimalNewCameraMatrix to compute the appropriate\nnewCameraMatrix depending on your requirements.\nThe camera matrix and the distortion parameters can be determined using #calibrateCamera. If\nthe resolution of images is different from the resolution used at the calibration stage, \\f$f\\_x,\nf\\_y, c\\_x\\f$ and \\f$c\\_y\\f$ need to be scaled accordingly, while the distortion coefficients remain\nthe same.\n\nPython prototype (for reference only):\n```python3\nundistort(src, cameraMatrix, distCoeffs[, dst[, newCameraMatrix]]) -> dst\n```","ref":"Evision.html#undistort/3"},{"type":"function","title":"Evision.undistort/4","doc":"Transforms an image to compensate for lens distortion.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input (distorted) image.\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input camera matrix \\f$A = \\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$(k_1, k_2, p_1, p_2[, k_3[, k_4, k_5, k_6[, s_1, s_2, s_3, s_4[, \\tau_x, \\tau_y]]]])\\f$\n  of 4, 5, 8, 12 or 14 elements. If the vector is NULL/empty, the zero distortion coefficients are assumed.\n\n##### Keyword Arguments\n- **newCameraMatrix**: `Evision.Mat`.\n\n  Camera matrix of the distorted image. By default, it is the same as\n  cameraMatrix but you may additionally scale and shift the result by using a different matrix.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output (corrected) image that has the same size and type as src .\n\nThe function transforms an image to compensate radial and tangential lens distortion.\nThe function is simply a combination of #initUndistortRectifyMap (with unity R ) and #remap\n(with bilinear interpolation). See the former function for details of the transformation being\nperformed.\nThose pixels in the destination image, for which there is no correspondent pixels in the source\nimage, are filled with zeros (black color).\nA particular subset of the source image that will be visible in the corrected image can be regulated\nby newCameraMatrix. You can use #getOptimalNewCameraMatrix to compute the appropriate\nnewCameraMatrix depending on your requirements.\nThe camera matrix and the distortion parameters can be determined using #calibrateCamera. If\nthe resolution of images is different from the resolution used at the calibration stage, \\f$f\\_x,\nf\\_y, c\\_x\\f$ and \\f$c\\_y\\f$ need to be scaled accordingly, while the distortion coefficients remain\nthe same.\n\nPython prototype (for reference only):\n```python3\nundistort(src, cameraMatrix, distCoeffs[, dst[, newCameraMatrix]]) -> dst\n```","ref":"Evision.html#undistort/4"},{"type":"function","title":"Evision.undistortImagePoints/1","doc":"","ref":"Evision.html#undistortImagePoints/1"},{"type":"function","title":"Evision.undistortImagePoints/3","doc":"Compute undistorted image points position\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Observed points position, 2xN/Nx2 1-channel or 1xN/Nx1 2-channel (CV_32FC2 or\n  CV_64FC2) (or vector\\  ).\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Camera matrix \\f$\\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Distortion coefficients\n\n##### Keyword Arguments\n- **arg1**: `TermCriteria`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output undistorted points position (1xN/Nx1 2-channel or vector\\  ).\n\nPython prototype (for reference only):\n```python3\nundistortImagePoints(src, cameraMatrix, distCoeffs[, dst[, arg1]]) -> dst\n```","ref":"Evision.html#undistortImagePoints/3"},{"type":"function","title":"Evision.undistortImagePoints/4","doc":"Compute undistorted image points position\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Observed points position, 2xN/Nx2 1-channel or 1xN/Nx1 2-channel (CV_32FC2 or\n  CV_64FC2) (or vector\\  ).\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Camera matrix \\f$\\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Distortion coefficients\n\n##### Keyword Arguments\n- **arg1**: `TermCriteria`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output undistorted points position (1xN/Nx1 2-channel or vector\\  ).\n\nPython prototype (for reference only):\n```python3\nundistortImagePoints(src, cameraMatrix, distCoeffs[, dst[, arg1]]) -> dst\n```","ref":"Evision.html#undistortImagePoints/4"},{"type":"function","title":"Evision.undistortPoints/1","doc":"","ref":"Evision.html#undistortPoints/1"},{"type":"function","title":"Evision.undistortPoints/3","doc":"Computes the ideal point coordinates from the observed point coordinates.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Observed point coordinates, 2xN/Nx2 1-channel or 1xN/Nx1 2-channel (CV_32FC2 or CV_64FC2) (or\n  vector\\  ).\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Camera matrix \\f$\\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$(k_1, k_2, p_1, p_2[, k_3[, k_4, k_5, k_6[, s_1, s_2, s_3, s_4[, \\tau_x, \\tau_y]]]])\\f$\n  of 4, 5, 8, 12 or 14 elements. If the vector is NULL/empty, the zero distortion coefficients are assumed.\n\n##### Keyword Arguments\n- **r**: `Evision.Mat`.\n\n  Rectification transformation in the object space (3x3 matrix). R1 or R2 computed by\n  #stereoRectify can be passed here. If the matrix is empty, the identity transformation is used.\n\n- **p**: `Evision.Mat`.\n\n  New camera matrix (3x3) or new projection matrix (3x4) \\f$\\begin{bmatrix} {f'}_x & 0 & {c'}_x & t_x \\\\\\\\ 0 & {f'}_y & {c'}_y & t_y \\\\\\\\ 0 & 0 & 1 & t_z \\end{bmatrix}\\f$. P1 or P2 computed by\n  #stereoRectify can be passed here. If the matrix is empty, the identity new camera matrix is used.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output ideal point coordinates (1xN/Nx1 2-channel or vector\\  ) after undistortion and reverse perspective\n  transformation. If matrix P is identity or omitted, dst will contain normalized point coordinates.\n\nThe function is similar to #undistort and #initUndistortRectifyMap but it operates on a\nsparse set of points instead of a raster image. Also the function performs a reverse transformation\nto  #projectPoints. In case of a 3D object, it does not reconstruct its 3D coordinates, but for a\nplanar object, it does, up to a translation vector, if the proper R is specified.\nFor each observed point coordinate \\f$(u, v)\\f$ the function computes:\n\\f[\n\\begin{array}{l}\nx^{\"}  \\leftarrow (u - c\\_x)/f\\_x  \\\\\\\\\ny^{\"}  \\leftarrow (v - c\\_y)/f\\_y  \\\\\\\\\n(x',y') = undistort(x^{\"},y^{\"}, \\texttt{distCoeffs}) \\\\\\\\\n{\\[X\\,Y\\,W]} ^T  \\leftarrow R\\*\\[x' \\, y' \\, 1]^T  \\\\\\\\\nx  \\leftarrow X/W  \\\\\\\\\ny  \\leftarrow Y/W  \\\\\\\\\n\\text{only performed if P is specified:} \\\\\\\\\nu'  \\leftarrow x {f'}\\_x + {c'}\\_x  \\\\\\\\\nv'  \\leftarrow y {f'}\\_y + {c'}\\_y\n\\end{array}\n\\f]\nwhere *undistort* is an approximate iterative algorithm that estimates the normalized original\npoint coordinates out of the normalized distorted point coordinates (\"normalized\" means that the\ncoordinates do not depend on the camera matrix).\nThe function can be used for both a stereo camera head or a monocular camera (when R is empty).\n\nPython prototype (for reference only):\n```python3\nundistortPoints(src, cameraMatrix, distCoeffs[, dst[, R[, P]]]) -> dst\n```","ref":"Evision.html#undistortPoints/3"},{"type":"function","title":"Evision.undistortPoints/4","doc":"Computes the ideal point coordinates from the observed point coordinates.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Observed point coordinates, 2xN/Nx2 1-channel or 1xN/Nx1 2-channel (CV_32FC2 or CV_64FC2) (or\n  vector\\  ).\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Camera matrix \\f$\\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients\n  \\f$(k_1, k_2, p_1, p_2[, k_3[, k_4, k_5, k_6[, s_1, s_2, s_3, s_4[, \\tau_x, \\tau_y]]]])\\f$\n  of 4, 5, 8, 12 or 14 elements. If the vector is NULL/empty, the zero distortion coefficients are assumed.\n\n##### Keyword Arguments\n- **r**: `Evision.Mat`.\n\n  Rectification transformation in the object space (3x3 matrix). R1 or R2 computed by\n  #stereoRectify can be passed here. If the matrix is empty, the identity transformation is used.\n\n- **p**: `Evision.Mat`.\n\n  New camera matrix (3x3) or new projection matrix (3x4) \\f$\\begin{bmatrix} {f'}_x & 0 & {c'}_x & t_x \\\\\\\\ 0 & {f'}_y & {c'}_y & t_y \\\\\\\\ 0 & 0 & 1 & t_z \\end{bmatrix}\\f$. P1 or P2 computed by\n  #stereoRectify can be passed here. If the matrix is empty, the identity new camera matrix is used.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output ideal point coordinates (1xN/Nx1 2-channel or vector\\  ) after undistortion and reverse perspective\n  transformation. If matrix P is identity or omitted, dst will contain normalized point coordinates.\n\nThe function is similar to #undistort and #initUndistortRectifyMap but it operates on a\nsparse set of points instead of a raster image. Also the function performs a reverse transformation\nto  #projectPoints. In case of a 3D object, it does not reconstruct its 3D coordinates, but for a\nplanar object, it does, up to a translation vector, if the proper R is specified.\nFor each observed point coordinate \\f$(u, v)\\f$ the function computes:\n\\f[\n\\begin{array}{l}\nx^{\"}  \\leftarrow (u - c\\_x)/f\\_x  \\\\\\\\\ny^{\"}  \\leftarrow (v - c\\_y)/f\\_y  \\\\\\\\\n(x',y') = undistort(x^{\"},y^{\"}, \\texttt{distCoeffs}) \\\\\\\\\n{\\[X\\,Y\\,W]} ^T  \\leftarrow R\\*\\[x' \\, y' \\, 1]^T  \\\\\\\\\nx  \\leftarrow X/W  \\\\\\\\\ny  \\leftarrow Y/W  \\\\\\\\\n\\text{only performed if P is specified:} \\\\\\\\\nu'  \\leftarrow x {f'}\\_x + {c'}\\_x  \\\\\\\\\nv'  \\leftarrow y {f'}\\_y + {c'}\\_y\n\\end{array}\n\\f]\nwhere *undistort* is an approximate iterative algorithm that estimates the normalized original\npoint coordinates out of the normalized distorted point coordinates (\"normalized\" means that the\ncoordinates do not depend on the camera matrix).\nThe function can be used for both a stereo camera head or a monocular camera (when R is empty).\n\nPython prototype (for reference only):\n```python3\nundistortPoints(src, cameraMatrix, distCoeffs[, dst[, R[, P]]]) -> dst\n```","ref":"Evision.html#undistortPoints/4"},{"type":"function","title":"Evision.undistortPointsIter/1","doc":"","ref":"Evision.html#undistortPointsIter/1"},{"type":"function","title":"Evision.undistortPointsIter/6","doc":"undistortPointsIter\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n- **cameraMatrix**: `Evision.Mat`\n- **distCoeffs**: `Evision.Mat`\n- **r**: `Evision.Mat`\n- **p**: `Evision.Mat`\n- **criteria**: `TermCriteria`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\n**Note**: Default version of #undistortPoints does 5 iterations to compute undistorted points.\n\nPython prototype (for reference only):\n```python3\nundistortPointsIter(src, cameraMatrix, distCoeffs, R, P, criteria[, dst]) -> dst\n```","ref":"Evision.html#undistortPointsIter/6"},{"type":"function","title":"Evision.undistortPointsIter/7","doc":"undistortPointsIter\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n- **cameraMatrix**: `Evision.Mat`\n- **distCoeffs**: `Evision.Mat`\n- **r**: `Evision.Mat`\n- **p**: `Evision.Mat`\n- **criteria**: `TermCriteria`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\n**Note**: Default version of #undistortPoints does 5 iterations to compute undistorted points.\n\nPython prototype (for reference only):\n```python3\nundistortPointsIter(src, cameraMatrix, distCoeffs, R, P, criteria[, dst]) -> dst\n```","ref":"Evision.html#undistortPointsIter/7"},{"type":"function","title":"Evision.useOpenVX/0","doc":"useOpenVX\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nuseOpenVX() -> retval\n```","ref":"Evision.html#useOpenVX/0"},{"type":"function","title":"Evision.useOpenVX/1","doc":"","ref":"Evision.html#useOpenVX/1"},{"type":"function","title":"Evision.useOptimized/0","doc":"Returns the status of optimized code usage.\n##### Return\n- **retval**: `bool`\n\nThe function returns true if the optimized code is enabled. Otherwise, it returns false.\n\nPython prototype (for reference only):\n```python3\nuseOptimized() -> retval\n```","ref":"Evision.html#useOptimized/0"},{"type":"function","title":"Evision.useOptimized/1","doc":"","ref":"Evision.html#useOptimized/1"},{"type":"function","title":"Evision.validateDisparity/1","doc":"","ref":"Evision.html#validateDisparity/1"},{"type":"function","title":"Evision.validateDisparity/4","doc":"validateDisparity\n\n##### Positional Arguments\n- **cost**: `Evision.Mat`\n- **minDisparity**: `integer()`\n- **numberOfDisparities**: `integer()`\n\n##### Keyword Arguments\n- **disp12MaxDisp**: `integer()`.\n\n##### Return\n- **disparity**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nvalidateDisparity(disparity, cost, minDisparity, numberOfDisparities[, disp12MaxDisp]) -> disparity\n```","ref":"Evision.html#validateDisparity/4"},{"type":"function","title":"Evision.validateDisparity/5","doc":"validateDisparity\n\n##### Positional Arguments\n- **cost**: `Evision.Mat`\n- **minDisparity**: `integer()`\n- **numberOfDisparities**: `integer()`\n\n##### Keyword Arguments\n- **disp12MaxDisp**: `integer()`.\n\n##### Return\n- **disparity**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nvalidateDisparity(disparity, cost, minDisparity, numberOfDisparities[, disp12MaxDisp]) -> disparity\n```","ref":"Evision.html#validateDisparity/5"},{"type":"function","title":"Evision.vconcat/1","doc":"vconcat\n\n##### Positional Arguments\n- **src**: `[Evision.Mat]`.\n\n  input array or vector of matrices. all of the matrices must have the same number of cols and the same depth\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array. It has the same number of cols and depth as the src, and the sum of rows of the src.\n  same depth.\n\nHas overloading in C++\n\n```cpp\nstd::vector  matrices = { cv::Mat(1, 4, CV_8UC1, cv::Scalar(1)),\ncv::Mat(1, 4, CV_8UC1, cv::Scalar(2)),\ncv::Mat(1, 4, CV_8UC1, cv::Scalar(3)),};\ncv::Mat out;\ncv::vconcat( matrices, out );\n//out:\n//[1,   1,   1,   1;\n// 2,   2,   2,   2;\n// 3,   3,   3,   3]\n```\n\nPython prototype (for reference only):\n```python3\nvconcat(src[, dst]) -> dst\n```","ref":"Evision.html#vconcat/1"},{"type":"function","title":"Evision.vconcat/2","doc":"vconcat\n\n##### Positional Arguments\n- **src**: `[Evision.Mat]`.\n\n  input array or vector of matrices. all of the matrices must have the same number of cols and the same depth\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array. It has the same number of cols and depth as the src, and the sum of rows of the src.\n  same depth.\n\nHas overloading in C++\n\n```cpp\nstd::vector  matrices = { cv::Mat(1, 4, CV_8UC1, cv::Scalar(1)),\ncv::Mat(1, 4, CV_8UC1, cv::Scalar(2)),\ncv::Mat(1, 4, CV_8UC1, cv::Scalar(3)),};\ncv::Mat out;\ncv::vconcat( matrices, out );\n//out:\n//[1,   1,   1,   1;\n// 2,   2,   2,   2;\n// 3,   3,   3,   3]\n```\n\nPython prototype (for reference only):\n```python3\nvconcat(src[, dst]) -> dst\n```","ref":"Evision.html#vconcat/2"},{"type":"function","title":"Evision.waitKeyEx/0","doc":"Similar to #waitKey, but returns full key code.\n##### Keyword Arguments\n- **delay**: `integer()`.\n\n##### Return\n- **retval**: `integer()`\n\n**Note**: Key code is implementation specific and depends on used backend: QT/GTK/Win32/etc\n\nPython prototype (for reference only):\n```python3\nwaitKeyEx([, delay]) -> retval\n```","ref":"Evision.html#waitKeyEx/0"},{"type":"function","title":"Evision.waitKeyEx/1","doc":"Similar to #waitKey, but returns full key code.\n##### Keyword Arguments\n- **delay**: `integer()`.\n\n##### Return\n- **retval**: `integer()`\n\n**Note**: Key code is implementation specific and depends on used backend: QT/GTK/Win32/etc\n\nPython prototype (for reference only):\n```python3\nwaitKeyEx([, delay]) -> retval\n```","ref":"Evision.html#waitKeyEx/1"},{"type":"function","title":"Evision.warpAffine/1","doc":"","ref":"Evision.html#warpAffine/1"},{"type":"function","title":"Evision.warpAffine/3","doc":"Applies an affine transformation to an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image.\n\n- **m**: `Evision.Mat`.\n\n  \\f$2\\times 3\\f$ transformation matrix.\n\n- **dsize**: `Size`.\n\n  size of the output image.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  combination of interpolation methods (see #InterpolationFlags) and the optional\n  flag #WARP_INVERSE_MAP that means that M is the inverse transformation (\n  \\f$\\texttt{dst}\\rightarrow\\texttt{src}\\f$ ).\n\n- **borderMode**: `integer()`.\n\n  pixel extrapolation method (see #BorderTypes); when\n  borderMode=#BORDER_TRANSPARENT, it means that the pixels in the destination image corresponding to\n  the \"outliers\" in the source image are not modified by the function.\n\n- **borderValue**: `Evision.scalar()`.\n\n  value used in case of a constant border; by default, it is 0.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image that has the size dsize and the same type as src .\n\nThe function warpAffine transforms the source image using the specified matrix:\n\\f[\\texttt{dst} (x,y) =  \\texttt{src} ( \\texttt{M} \\_{11} x +  \\texttt{M} \\_{12} y +  \\texttt{M} \\_{13}, \\texttt{M} \\_{21} x +  \\texttt{M} \\_{22} y +  \\texttt{M} \\_{23})\\f]\nwhen the flag #WARP_INVERSE_MAP is set. Otherwise, the transformation is first inverted\nwith #invertAffineTransform and then put in the formula above instead of M. The function cannot\noperate in-place.\n\n@sa  warpPerspective, resize, remap, getRectSubPix, transform\n\nPython prototype (for reference only):\n```python3\nwarpAffine(src, M, dsize[, dst[, flags[, borderMode[, borderValue]]]]) -> dst\n```","ref":"Evision.html#warpAffine/3"},{"type":"function","title":"Evision.warpAffine/4","doc":"Applies an affine transformation to an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image.\n\n- **m**: `Evision.Mat`.\n\n  \\f$2\\times 3\\f$ transformation matrix.\n\n- **dsize**: `Size`.\n\n  size of the output image.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  combination of interpolation methods (see #InterpolationFlags) and the optional\n  flag #WARP_INVERSE_MAP that means that M is the inverse transformation (\n  \\f$\\texttt{dst}\\rightarrow\\texttt{src}\\f$ ).\n\n- **borderMode**: `integer()`.\n\n  pixel extrapolation method (see #BorderTypes); when\n  borderMode=#BORDER_TRANSPARENT, it means that the pixels in the destination image corresponding to\n  the \"outliers\" in the source image are not modified by the function.\n\n- **borderValue**: `Evision.scalar()`.\n\n  value used in case of a constant border; by default, it is 0.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image that has the size dsize and the same type as src .\n\nThe function warpAffine transforms the source image using the specified matrix:\n\\f[\\texttt{dst} (x,y) =  \\texttt{src} ( \\texttt{M} \\_{11} x +  \\texttt{M} \\_{12} y +  \\texttt{M} \\_{13}, \\texttt{M} \\_{21} x +  \\texttt{M} \\_{22} y +  \\texttt{M} \\_{23})\\f]\nwhen the flag #WARP_INVERSE_MAP is set. Otherwise, the transformation is first inverted\nwith #invertAffineTransform and then put in the formula above instead of M. The function cannot\noperate in-place.\n\n@sa  warpPerspective, resize, remap, getRectSubPix, transform\n\nPython prototype (for reference only):\n```python3\nwarpAffine(src, M, dsize[, dst[, flags[, borderMode[, borderValue]]]]) -> dst\n```","ref":"Evision.html#warpAffine/4"},{"type":"function","title":"Evision.warpPerspective/1","doc":"","ref":"Evision.html#warpPerspective/1"},{"type":"function","title":"Evision.warpPerspective/3","doc":"Applies a perspective transformation to an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image.\n\n- **m**: `Evision.Mat`.\n\n  \\f$3\\times 3\\f$ transformation matrix.\n\n- **dsize**: `Size`.\n\n  size of the output image.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  combination of interpolation methods (#INTER_LINEAR or #INTER_NEAREST) and the\n  optional flag #WARP_INVERSE_MAP, that sets M as the inverse transformation (\n  \\f$\\texttt{dst}\\rightarrow\\texttt{src}\\f$ ).\n\n- **borderMode**: `integer()`.\n\n  pixel extrapolation method (#BORDER_CONSTANT or #BORDER_REPLICATE).\n\n- **borderValue**: `Evision.scalar()`.\n\n  value used in case of a constant border; by default, it equals 0.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image that has the size dsize and the same type as src .\n\nThe function warpPerspective transforms the source image using the specified matrix:\n\\f[\\texttt{dst} (x,y) =  \\texttt{src} \\left ( \\frac{M\\_{11} x + M\\_{12} y + M\\_{13}}{M\\_{31} x + M\\_{32} y + M\\_{33}} ,\n\\frac{M\\_{21} x + M\\_{22} y + M\\_{23}}{M\\_{31} x + M\\_{32} y + M\\_{33}} \\right )\\f]\nwhen the flag #WARP_INVERSE_MAP is set. Otherwise, the transformation is first inverted with invert\nand then put in the formula above instead of M. The function cannot operate in-place.\n\n@sa  warpAffine, resize, remap, getRectSubPix, perspectiveTransform\n\nPython prototype (for reference only):\n```python3\nwarpPerspective(src, M, dsize[, dst[, flags[, borderMode[, borderValue]]]]) -> dst\n```","ref":"Evision.html#warpPerspective/3"},{"type":"function","title":"Evision.warpPerspective/4","doc":"Applies a perspective transformation to an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input image.\n\n- **m**: `Evision.Mat`.\n\n  \\f$3\\times 3\\f$ transformation matrix.\n\n- **dsize**: `Size`.\n\n  size of the output image.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  combination of interpolation methods (#INTER_LINEAR or #INTER_NEAREST) and the\n  optional flag #WARP_INVERSE_MAP, that sets M as the inverse transformation (\n  \\f$\\texttt{dst}\\rightarrow\\texttt{src}\\f$ ).\n\n- **borderMode**: `integer()`.\n\n  pixel extrapolation method (#BORDER_CONSTANT or #BORDER_REPLICATE).\n\n- **borderValue**: `Evision.scalar()`.\n\n  value used in case of a constant border; by default, it equals 0.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image that has the size dsize and the same type as src .\n\nThe function warpPerspective transforms the source image using the specified matrix:\n\\f[\\texttt{dst} (x,y) =  \\texttt{src} \\left ( \\frac{M\\_{11} x + M\\_{12} y + M\\_{13}}{M\\_{31} x + M\\_{32} y + M\\_{33}} ,\n\\frac{M\\_{21} x + M\\_{22} y + M\\_{23}}{M\\_{31} x + M\\_{32} y + M\\_{33}} \\right )\\f]\nwhen the flag #WARP_INVERSE_MAP is set. Otherwise, the transformation is first inverted with invert\nand then put in the formula above instead of M. The function cannot operate in-place.\n\n@sa  warpAffine, resize, remap, getRectSubPix, perspectiveTransform\n\nPython prototype (for reference only):\n```python3\nwarpPerspective(src, M, dsize[, dst[, flags[, borderMode[, borderValue]]]]) -> dst\n```","ref":"Evision.html#warpPerspective/4"},{"type":"function","title":"Evision.warpPolar/1","doc":"","ref":"Evision.html#warpPolar/1"},{"type":"function","title":"Evision.warpPolar/5","doc":"warpPolar\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image.\n\n- **dsize**: `Size`.\n\n  The destination image size (see description for valid options).\n\n- **center**: `Point2f`.\n\n  The transformation center.\n\n- **maxRadius**: `double`.\n\n  The radius of the bounding circle to transform. It determines the inverse magnitude scale parameter too.\n\n- **flags**: `integer()`.\n\n  A combination of interpolation methods, #InterpolationFlags + #WarpPolarMode.\n  - Add #WARP_POLAR_LINEAR to select linear polar mapping (default)\n  - Add #WARP_POLAR_LOG to select semilog polar mapping\n  - Add #WARP_INVERSE_MAP for reverse mapping.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image. It will have same type as src.\n\n\\brief Remaps an image to polar or semilog-polar coordinates space\n@anchor polar_remaps_reference_image\n![Polar remaps reference](pics/polar_remap_doc.png)\nTransform the source image using the following transformation:\n\\f[\ndst(\\rho , \\phi ) = src(x,y)\n\\f]\nwhere\n\\f[\n\\begin{array}{l}\n\\vec{I} = (x - center.x, \\;y - center.y) \\\\\\\\\n\\phi = Kangle \\cdot \\texttt{angle} (\\vec{I}) \\\\\\\\\n\\rho = \\left\\\\{\\begin{matrix}\nKlin \\cdot \\texttt{magnitude} (\\vec{I}) & default \\\\\\\\\nKlog \\cdot log\\_e(\\texttt{magnitude} (\\vec{I})) & if \\; semilog \\\\\\\\\n\\end{matrix}\\right.\n\\end{array}\n\\f]\nand\n\\f[\n\\begin{array}{l}\nKangle = dsize.height / 2\\Pi \\\\\\\\\nKlin = dsize.width / maxRadius \\\\\\\\\nKlog = dsize.width / log\\_e(maxRadius) \\\\\\\\\n\\end{array}\n\\f]\n\\par Linear vs semilog mapping\nPolar mapping can be linear or semi-log. Add one of #WarpPolarMode to `flags` to specify the polar mapping mode.\nLinear is the default mode.\nThe semilog mapping emulates the human \"foveal\" vision that permit very high acuity on the line of sight (central vision)\nin contrast to peripheral vision where acuity is minor.\n\\par Option on `dsize`:\n- if both values in `dsize <=0 ` (default),\n  the destination image will have (almost) same area of source bounding circle:\n  \\f[\\begin{array}{l}\n  dsize.area  \\leftarrow (maxRadius^2 \\cdot \\Pi) \\\\\\\\\n  dsize.width = \\texttt{cvRound}(maxRadius) \\\\\\\\\n  dsize.height = \\texttt{cvRound}(maxRadius \\cdot \\Pi) \\\\\\\\\n  \\end{array}\\f]\n\n- if only `dsize.height <= 0`,\n  the destination image area will be proportional to the bounding circle area but scaled by `Kx * Kx`:\n  \\f[\\begin{array}{l}\n  dsize.height = \\texttt{cvRound}(dsize.width \\cdot \\Pi) \\\\\\\\\n  \\end{array}\n  \\f]\n\n- if both values in `dsize > 0 `,\n  the destination image will have the given size therefore the area of the bounding circle will be scaled to `dsize`.\n\n\\par Reverse mapping\nYou can get reverse mapping adding #WARP_INVERSE_MAP to `flags`\n\\snippet polar_transforms.cpp InverseMap\nIn addiction, to calculate the original coordinate from a polar mapped coordinate \\f$(rho, phi)->(x, y)\\f$:\n\\snippet polar_transforms.cpp InverseCoordinate\n**Note**: \n- The function can not operate in-place.\n- To calculate magnitude and angle in degrees #cartToPolar is used internally thus angles are measured from 0 to 360 with accuracy about 0.3 degrees.\n- This function uses #remap. Due to current implementation limitations the size of an input and output images should be less than 32767x32767.\n\n@sa cv::remap\n\nPython prototype (for reference only):\n```python3\nwarpPolar(src, dsize, center, maxRadius, flags[, dst]) -> dst\n```","ref":"Evision.html#warpPolar/5"},{"type":"function","title":"Evision.warpPolar/6","doc":"warpPolar\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image.\n\n- **dsize**: `Size`.\n\n  The destination image size (see description for valid options).\n\n- **center**: `Point2f`.\n\n  The transformation center.\n\n- **maxRadius**: `double`.\n\n  The radius of the bounding circle to transform. It determines the inverse magnitude scale parameter too.\n\n- **flags**: `integer()`.\n\n  A combination of interpolation methods, #InterpolationFlags + #WarpPolarMode.\n  - Add #WARP_POLAR_LINEAR to select linear polar mapping (default)\n  - Add #WARP_POLAR_LOG to select semilog polar mapping\n  - Add #WARP_INVERSE_MAP for reverse mapping.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image. It will have same type as src.\n\n\\brief Remaps an image to polar or semilog-polar coordinates space\n@anchor polar_remaps_reference_image\n![Polar remaps reference](pics/polar_remap_doc.png)\nTransform the source image using the following transformation:\n\\f[\ndst(\\rho , \\phi ) = src(x,y)\n\\f]\nwhere\n\\f[\n\\begin{array}{l}\n\\vec{I} = (x - center.x, \\;y - center.y) \\\\\\\\\n\\phi = Kangle \\cdot \\texttt{angle} (\\vec{I}) \\\\\\\\\n\\rho = \\left\\\\{\\begin{matrix}\nKlin \\cdot \\texttt{magnitude} (\\vec{I}) & default \\\\\\\\\nKlog \\cdot log\\_e(\\texttt{magnitude} (\\vec{I})) & if \\; semilog \\\\\\\\\n\\end{matrix}\\right.\n\\end{array}\n\\f]\nand\n\\f[\n\\begin{array}{l}\nKangle = dsize.height / 2\\Pi \\\\\\\\\nKlin = dsize.width / maxRadius \\\\\\\\\nKlog = dsize.width / log\\_e(maxRadius) \\\\\\\\\n\\end{array}\n\\f]\n\\par Linear vs semilog mapping\nPolar mapping can be linear or semi-log. Add one of #WarpPolarMode to `flags` to specify the polar mapping mode.\nLinear is the default mode.\nThe semilog mapping emulates the human \"foveal\" vision that permit very high acuity on the line of sight (central vision)\nin contrast to peripheral vision where acuity is minor.\n\\par Option on `dsize`:\n- if both values in `dsize <=0 ` (default),\n  the destination image will have (almost) same area of source bounding circle:\n  \\f[\\begin{array}{l}\n  dsize.area  \\leftarrow (maxRadius^2 \\cdot \\Pi) \\\\\\\\\n  dsize.width = \\texttt{cvRound}(maxRadius) \\\\\\\\\n  dsize.height = \\texttt{cvRound}(maxRadius \\cdot \\Pi) \\\\\\\\\n  \\end{array}\\f]\n\n- if only `dsize.height <= 0`,\n  the destination image area will be proportional to the bounding circle area but scaled by `Kx * Kx`:\n  \\f[\\begin{array}{l}\n  dsize.height = \\texttt{cvRound}(dsize.width \\cdot \\Pi) \\\\\\\\\n  \\end{array}\n  \\f]\n\n- if both values in `dsize > 0 `,\n  the destination image will have the given size therefore the area of the bounding circle will be scaled to `dsize`.\n\n\\par Reverse mapping\nYou can get reverse mapping adding #WARP_INVERSE_MAP to `flags`\n\\snippet polar_transforms.cpp InverseMap\nIn addiction, to calculate the original coordinate from a polar mapped coordinate \\f$(rho, phi)->(x, y)\\f$:\n\\snippet polar_transforms.cpp InverseCoordinate\n**Note**: \n- The function can not operate in-place.\n- To calculate magnitude and angle in degrees #cartToPolar is used internally thus angles are measured from 0 to 360 with accuracy about 0.3 degrees.\n- This function uses #remap. Due to current implementation limitations the size of an input and output images should be less than 32767x32767.\n\n@sa cv::remap\n\nPython prototype (for reference only):\n```python3\nwarpPolar(src, dsize, center, maxRadius, flags[, dst]) -> dst\n```","ref":"Evision.html#warpPolar/6"},{"type":"function","title":"Evision.watershed/1","doc":"","ref":"Evision.html#watershed/1"},{"type":"function","title":"Evision.watershed/2","doc":"Performs a marker-based image segmentation using the watershed algorithm.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Input 8-bit 3-channel image.\n\n##### Return\n- **markers**: `Evision.Mat.t()`.\n\n  Input/output 32-bit single-channel image (map) of markers. It should have the same\n  size as image .\n\nThe function implements one of the variants of watershed, non-parametric marker-based segmentation\nalgorithm, described in @cite Meyer92 .\nBefore passing the image to the function, you have to roughly outline the desired regions in the\nimage markers with positive (\\>0) indices. So, every region is represented as one or more connected\ncomponents with the pixel values 1, 2, 3, and so on. Such markers can be retrieved from a binary\nmask using #findContours and #drawContours (see the watershed.cpp demo). The markers are \"seeds\" of\nthe future image regions. All the other pixels in markers , whose relation to the outlined regions\nis not known and should be defined by the algorithm, should be set to 0's. In the function output,\neach pixel in markers is set to a value of the \"seed\" components or to -1 at boundaries between the\nregions.\n**Note**: Any two neighbor connected components are not necessarily separated by a watershed boundary\n(-1's pixels); for example, they can touch each other in the initial marker image passed to the\nfunction.\n\n@sa findContours\n\nPython prototype (for reference only):\n```python3\nwatershed(image, markers) -> markers\n```","ref":"Evision.html#watershed/2"},{"type":"function","title":"Evision.writeOpticalFlow/1","doc":"","ref":"Evision.html#writeOpticalFlow/1"},{"type":"function","title":"Evision.writeOpticalFlow/2","doc":"Write a .flo to disk\n\n##### Positional Arguments\n- **path**: `String`.\n\n  Path to the file to be written\n\n- **flow**: `Evision.Mat`.\n\n  Flow field to be stored\n\n##### Return\n- **retval**: `bool`\n\nThe function stores a flow field in a file, returns true on success, false otherwise.\nThe flow field must be a 2-channel, floating-point matrix (CV_32FC2). First channel corresponds\nto the flow in the horizontal direction (u), second - vertical (v).\n\nPython prototype (for reference only):\n```python3\nwriteOpticalFlow(path, flow) -> retval\n```","ref":"Evision.html#writeOpticalFlow/2"},{"type":"type","title":"Evision.enum/0","doc":"","ref":"Evision.html#t:enum/0"},{"type":"type","title":"Evision.scalar/0","doc":"Scalars are n-element tuples, where n can be 1, 2, 3, or 4.\n\nWhen passing a single number `X` as a scalar, it will be converted to `{X, 0, 0, 0}`.\n\nWhen passing a tuple with more than 4 elements, it will raise an error.","ref":"Evision.html#t:scalar/0"},{"type":"module","title":"Evision.AKAZE","doc":"","ref":"Evision.AKAZE.html"},{"type":"function","title":"Evision.AKAZE.compute/1","doc":"","ref":"Evision.AKAZE.html#compute/1"},{"type":"function","title":"Evision.AKAZE.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.AKAZE.html#compute/3"},{"type":"function","title":"Evision.AKAZE.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.AKAZE.html#compute/4"},{"type":"function","title":"Evision.AKAZE.create/0","doc":"The AKAZE constructor\n##### Keyword Arguments\n- **descriptor_type**: `AKAZE_DescriptorType`.\n\n  Type of the extracted descriptor: DESCRIPTOR_KAZE,\n  DESCRIPTOR_KAZE_UPRIGHT, DESCRIPTOR_MLDB or DESCRIPTOR_MLDB_UPRIGHT.\n\n- **descriptor_size**: `integer()`.\n\n  Size of the descriptor in bits. 0 -\\> Full size\n\n- **descriptor_channels**: `integer()`.\n\n  Number of channels in the descriptor (1, 2, 3)\n\n- **threshold**: `float`.\n\n  Detector response threshold to accept point\n\n- **nOctaves**: `integer()`.\n\n  Maximum octave evolution of the image\n\n- **nOctaveLayers**: `integer()`.\n\n  Default number of sublevels per scale level\n\n- **diffusivity**: `KAZE_DiffusivityType`.\n\n  Diffusivity type. DIFF_PM_G1, DIFF_PM_G2, DIFF_WEICKERT or\n  DIFF_CHARBONNIER\n\n- **max_points**: `integer()`.\n\n  Maximum amount of returned points. In case if image contains\n  more features, then the features with highest response are returned.\n  Negative value means no limitation.\n\n##### Return\n- **retval**: `Evision.AKAZE.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, descriptor_type[, descriptor_size[, descriptor_channels[, threshold[, nOctaves[, nOctaveLayers[, diffusivity[, max_points]]]]]]]]) -> retval\n```","ref":"Evision.AKAZE.html#create/0"},{"type":"function","title":"Evision.AKAZE.create/1","doc":"The AKAZE constructor\n##### Keyword Arguments\n- **descriptor_type**: `AKAZE_DescriptorType`.\n\n  Type of the extracted descriptor: DESCRIPTOR_KAZE,\n  DESCRIPTOR_KAZE_UPRIGHT, DESCRIPTOR_MLDB or DESCRIPTOR_MLDB_UPRIGHT.\n\n- **descriptor_size**: `integer()`.\n\n  Size of the descriptor in bits. 0 -\\> Full size\n\n- **descriptor_channels**: `integer()`.\n\n  Number of channels in the descriptor (1, 2, 3)\n\n- **threshold**: `float`.\n\n  Detector response threshold to accept point\n\n- **nOctaves**: `integer()`.\n\n  Maximum octave evolution of the image\n\n- **nOctaveLayers**: `integer()`.\n\n  Default number of sublevels per scale level\n\n- **diffusivity**: `KAZE_DiffusivityType`.\n\n  Diffusivity type. DIFF_PM_G1, DIFF_PM_G2, DIFF_WEICKERT or\n  DIFF_CHARBONNIER\n\n- **max_points**: `integer()`.\n\n  Maximum amount of returned points. In case if image contains\n  more features, then the features with highest response are returned.\n  Negative value means no limitation.\n\n##### Return\n- **retval**: `Evision.AKAZE.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, descriptor_type[, descriptor_size[, descriptor_channels[, threshold[, nOctaves[, nOctaveLayers[, diffusivity[, max_points]]]]]]]]) -> retval\n```","ref":"Evision.AKAZE.html#create/1"},{"type":"function","title":"Evision.AKAZE.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.AKAZE.html#defaultNorm/1"},{"type":"function","title":"Evision.AKAZE.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.AKAZE.html#descriptorSize/1"},{"type":"function","title":"Evision.AKAZE.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.AKAZE.html#descriptorType/1"},{"type":"function","title":"Evision.AKAZE.detect/1","doc":"","ref":"Evision.AKAZE.html#detect/1"},{"type":"function","title":"Evision.AKAZE.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.AKAZE.html#detect/2"},{"type":"function","title":"Evision.AKAZE.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.AKAZE.html#detect/3"},{"type":"function","title":"Evision.AKAZE.detectAndCompute/1","doc":"","ref":"Evision.AKAZE.html#detectAndCompute/1"},{"type":"function","title":"Evision.AKAZE.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.AKAZE.html#detectAndCompute/3"},{"type":"function","title":"Evision.AKAZE.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.AKAZE.html#detectAndCompute/4"},{"type":"function","title":"Evision.AKAZE.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.AKAZE.html#empty/1"},{"type":"function","title":"Evision.AKAZE.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.AKAZE.html#getDefaultName/1"},{"type":"function","title":"Evision.AKAZE.getDescriptorChannels/1","doc":"getDescriptorChannels\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetDescriptorChannels() -> retval\n```","ref":"Evision.AKAZE.html#getDescriptorChannels/1"},{"type":"function","title":"Evision.AKAZE.getDescriptorSize/1","doc":"getDescriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetDescriptorSize() -> retval\n```","ref":"Evision.AKAZE.html#getDescriptorSize/1"},{"type":"function","title":"Evision.AKAZE.getDescriptorType/1","doc":"getDescriptorType\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n\n##### Return\n- **retval**: `AKAZE::DescriptorType`\n\nPython prototype (for reference only):\n```python3\ngetDescriptorType() -> retval\n```","ref":"Evision.AKAZE.html#getDescriptorType/1"},{"type":"function","title":"Evision.AKAZE.getDiffusivity/1","doc":"getDiffusivity\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n\n##### Return\n- **retval**: `KAZE::DiffusivityType`\n\nPython prototype (for reference only):\n```python3\ngetDiffusivity() -> retval\n```","ref":"Evision.AKAZE.html#getDiffusivity/1"},{"type":"function","title":"Evision.AKAZE.getMaxPoints/1","doc":"getMaxPoints\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxPoints() -> retval\n```","ref":"Evision.AKAZE.html#getMaxPoints/1"},{"type":"function","title":"Evision.AKAZE.getNOctaveLayers/1","doc":"getNOctaveLayers\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNOctaveLayers() -> retval\n```","ref":"Evision.AKAZE.html#getNOctaveLayers/1"},{"type":"function","title":"Evision.AKAZE.getNOctaves/1","doc":"getNOctaves\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNOctaves() -> retval\n```","ref":"Evision.AKAZE.html#getNOctaves/1"},{"type":"function","title":"Evision.AKAZE.getThreshold/1","doc":"getThreshold\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetThreshold() -> retval\n```","ref":"Evision.AKAZE.html#getThreshold/1"},{"type":"function","title":"Evision.AKAZE.read/1","doc":"","ref":"Evision.AKAZE.html#read/1"},{"type":"function","title":"Evision.AKAZE.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.AKAZE.html#read/2"},{"type":"function","title":"Evision.AKAZE.setDescriptorChannels/1","doc":"","ref":"Evision.AKAZE.html#setDescriptorChannels/1"},{"type":"function","title":"Evision.AKAZE.setDescriptorChannels/2","doc":"setDescriptorChannels\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n- **dch**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetDescriptorChannels(dch) -> None\n```","ref":"Evision.AKAZE.html#setDescriptorChannels/2"},{"type":"function","title":"Evision.AKAZE.setDescriptorSize/1","doc":"","ref":"Evision.AKAZE.html#setDescriptorSize/1"},{"type":"function","title":"Evision.AKAZE.setDescriptorSize/2","doc":"setDescriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n- **dsize**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetDescriptorSize(dsize) -> None\n```","ref":"Evision.AKAZE.html#setDescriptorSize/2"},{"type":"function","title":"Evision.AKAZE.setDescriptorType/1","doc":"","ref":"Evision.AKAZE.html#setDescriptorType/1"},{"type":"function","title":"Evision.AKAZE.setDescriptorType/2","doc":"setDescriptorType\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n- **dtype**: `AKAZE_DescriptorType`\n\nPython prototype (for reference only):\n```python3\nsetDescriptorType(dtype) -> None\n```","ref":"Evision.AKAZE.html#setDescriptorType/2"},{"type":"function","title":"Evision.AKAZE.setDiffusivity/1","doc":"","ref":"Evision.AKAZE.html#setDiffusivity/1"},{"type":"function","title":"Evision.AKAZE.setDiffusivity/2","doc":"setDiffusivity\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n- **diff**: `KAZE_DiffusivityType`\n\nPython prototype (for reference only):\n```python3\nsetDiffusivity(diff) -> None\n```","ref":"Evision.AKAZE.html#setDiffusivity/2"},{"type":"function","title":"Evision.AKAZE.setMaxPoints/1","doc":"","ref":"Evision.AKAZE.html#setMaxPoints/1"},{"type":"function","title":"Evision.AKAZE.setMaxPoints/2","doc":"setMaxPoints\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n- **max_points**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxPoints(max_points) -> None\n```","ref":"Evision.AKAZE.html#setMaxPoints/2"},{"type":"function","title":"Evision.AKAZE.setNOctaveLayers/1","doc":"","ref":"Evision.AKAZE.html#setNOctaveLayers/1"},{"type":"function","title":"Evision.AKAZE.setNOctaveLayers/2","doc":"setNOctaveLayers\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n- **octaveLayers**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNOctaveLayers(octaveLayers) -> None\n```","ref":"Evision.AKAZE.html#setNOctaveLayers/2"},{"type":"function","title":"Evision.AKAZE.setNOctaves/1","doc":"","ref":"Evision.AKAZE.html#setNOctaves/1"},{"type":"function","title":"Evision.AKAZE.setNOctaves/2","doc":"setNOctaves\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n- **octaves**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNOctaves(octaves) -> None\n```","ref":"Evision.AKAZE.html#setNOctaves/2"},{"type":"function","title":"Evision.AKAZE.setThreshold/1","doc":"","ref":"Evision.AKAZE.html#setThreshold/1"},{"type":"function","title":"Evision.AKAZE.setThreshold/2","doc":"setThreshold\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n- **threshold**: `double`\n\nPython prototype (for reference only):\n```python3\nsetThreshold(threshold) -> None\n```","ref":"Evision.AKAZE.html#setThreshold/2"},{"type":"function","title":"Evision.AKAZE.write/1","doc":"","ref":"Evision.AKAZE.html#write/1"},{"type":"function","title":"Evision.AKAZE.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.AKAZE.html#write/2"},{"type":"function","title":"Evision.AKAZE.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.AKAZE.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.AKAZE.html#write/3"},{"type":"type","title":"Evision.AKAZE.t/0","doc":"Type that represents an `AKAZE` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.AKAZE.html#t:t/0"},{"type":"module","title":"Evision.AKAZE.DescriptorType","doc":"","ref":"Evision.AKAZE.DescriptorType.html"},{"type":"function","title":"Evision.AKAZE.DescriptorType.cv_DESCRIPTOR_KAZE/0","doc":"","ref":"Evision.AKAZE.DescriptorType.html#cv_DESCRIPTOR_KAZE/0"},{"type":"function","title":"Evision.AKAZE.DescriptorType.cv_DESCRIPTOR_KAZE_UPRIGHT/0","doc":"","ref":"Evision.AKAZE.DescriptorType.html#cv_DESCRIPTOR_KAZE_UPRIGHT/0"},{"type":"function","title":"Evision.AKAZE.DescriptorType.cv_DESCRIPTOR_MLDB/0","doc":"","ref":"Evision.AKAZE.DescriptorType.html#cv_DESCRIPTOR_MLDB/0"},{"type":"function","title":"Evision.AKAZE.DescriptorType.cv_DESCRIPTOR_MLDB_UPRIGHT/0","doc":"","ref":"Evision.AKAZE.DescriptorType.html#cv_DESCRIPTOR_MLDB_UPRIGHT/0"},{"type":"type","title":"Evision.AKAZE.DescriptorType.enum/0","doc":"","ref":"Evision.AKAZE.DescriptorType.html#t:enum/0"},{"type":"module","title":"Evision.AccessFlag","doc":"","ref":"Evision.AccessFlag.html"},{"type":"function","title":"Evision.AccessFlag.cv_ACCESS_FAST/0","doc":"","ref":"Evision.AccessFlag.html#cv_ACCESS_FAST/0"},{"type":"function","title":"Evision.AccessFlag.cv_ACCESS_MASK/0","doc":"","ref":"Evision.AccessFlag.html#cv_ACCESS_MASK/0"},{"type":"function","title":"Evision.AccessFlag.cv_ACCESS_READ/0","doc":"","ref":"Evision.AccessFlag.html#cv_ACCESS_READ/0"},{"type":"function","title":"Evision.AccessFlag.cv_ACCESS_RW/0","doc":"","ref":"Evision.AccessFlag.html#cv_ACCESS_RW/0"},{"type":"function","title":"Evision.AccessFlag.cv_ACCESS_WRITE/0","doc":"","ref":"Evision.AccessFlag.html#cv_ACCESS_WRITE/0"},{"type":"type","title":"Evision.AccessFlag.enum/0","doc":"","ref":"Evision.AccessFlag.html#t:enum/0"},{"type":"module","title":"Evision.AdaptiveThresholdTypes","doc":"","ref":"Evision.AdaptiveThresholdTypes.html"},{"type":"function","title":"Evision.AdaptiveThresholdTypes.cv_ADAPTIVE_THRESH_GAUSSIAN_C/0","doc":"","ref":"Evision.AdaptiveThresholdTypes.html#cv_ADAPTIVE_THRESH_GAUSSIAN_C/0"},{"type":"function","title":"Evision.AdaptiveThresholdTypes.cv_ADAPTIVE_THRESH_MEAN_C/0","doc":"","ref":"Evision.AdaptiveThresholdTypes.html#cv_ADAPTIVE_THRESH_MEAN_C/0"},{"type":"type","title":"Evision.AdaptiveThresholdTypes.enum/0","doc":"","ref":"Evision.AdaptiveThresholdTypes.html#t:enum/0"},{"type":"module","title":"Evision.AffineFeature","doc":"","ref":"Evision.AffineFeature.html"},{"type":"function","title":"Evision.AffineFeature.compute/1","doc":"","ref":"Evision.AffineFeature.html#compute/1"},{"type":"function","title":"Evision.AffineFeature.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.AffineFeature.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.AffineFeature.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.AffineFeature.html#compute/3"},{"type":"function","title":"Evision.AffineFeature.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.AffineFeature.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.AffineFeature.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.AffineFeature.html#compute/4"},{"type":"function","title":"Evision.AffineFeature.create/1","doc":"create\n\n##### Positional Arguments\n- **backend**: `Evision.Feature2D`.\n\n  The detector/extractor you want to use as backend.\n\n##### Keyword Arguments\n- **maxTilt**: `integer()`.\n\n  The highest power index of tilt factor. 5 is used in the paper as tilt sampling range n.\n\n- **minTilt**: `integer()`.\n\n  The lowest power index of tilt factor. 0 is used in the paper.\n\n- **tiltStep**: `float`.\n\n  Tilt sampling step \\f$\\delta_t\\f$ in Algorithm 1 in the paper.\n\n- **rotateStepBase**: `float`.\n\n  Rotation sampling step factor b in Algorithm 1 in the paper.\n\n##### Return\n- **retval**: `Evision.AffineFeature.t()`\n\nPython prototype (for reference only):\n```python3\ncreate(backend[, maxTilt[, minTilt[, tiltStep[, rotateStepBase]]]]) -> retval\n```","ref":"Evision.AffineFeature.html#create/1"},{"type":"function","title":"Evision.AffineFeature.create/2","doc":"create\n\n##### Positional Arguments\n- **backend**: `Evision.Feature2D`.\n\n  The detector/extractor you want to use as backend.\n\n##### Keyword Arguments\n- **maxTilt**: `integer()`.\n\n  The highest power index of tilt factor. 5 is used in the paper as tilt sampling range n.\n\n- **minTilt**: `integer()`.\n\n  The lowest power index of tilt factor. 0 is used in the paper.\n\n- **tiltStep**: `float`.\n\n  Tilt sampling step \\f$\\delta_t\\f$ in Algorithm 1 in the paper.\n\n- **rotateStepBase**: `float`.\n\n  Rotation sampling step factor b in Algorithm 1 in the paper.\n\n##### Return\n- **retval**: `Evision.AffineFeature.t()`\n\nPython prototype (for reference only):\n```python3\ncreate(backend[, maxTilt[, minTilt[, tiltStep[, rotateStepBase]]]]) -> retval\n```","ref":"Evision.AffineFeature.html#create/2"},{"type":"function","title":"Evision.AffineFeature.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.AffineFeature.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.AffineFeature.html#defaultNorm/1"},{"type":"function","title":"Evision.AffineFeature.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.AffineFeature.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.AffineFeature.html#descriptorSize/1"},{"type":"function","title":"Evision.AffineFeature.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.AffineFeature.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.AffineFeature.html#descriptorType/1"},{"type":"function","title":"Evision.AffineFeature.detect/1","doc":"","ref":"Evision.AffineFeature.html#detect/1"},{"type":"function","title":"Evision.AffineFeature.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.AffineFeature.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.AffineFeature.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.AffineFeature.html#detect/2"},{"type":"function","title":"Evision.AffineFeature.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.AffineFeature.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.AffineFeature.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.AffineFeature.html#detect/3"},{"type":"function","title":"Evision.AffineFeature.detectAndCompute/1","doc":"","ref":"Evision.AffineFeature.html#detectAndCompute/1"},{"type":"function","title":"Evision.AffineFeature.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.AffineFeature.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.AffineFeature.html#detectAndCompute/3"},{"type":"function","title":"Evision.AffineFeature.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.AffineFeature.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.AffineFeature.html#detectAndCompute/4"},{"type":"function","title":"Evision.AffineFeature.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.AffineFeature.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.AffineFeature.html#empty/1"},{"type":"function","title":"Evision.AffineFeature.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.AffineFeature.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.AffineFeature.html#getDefaultName/1"},{"type":"function","title":"Evision.AffineFeature.getViewParams/1","doc":"","ref":"Evision.AffineFeature.html#getViewParams/1"},{"type":"function","title":"Evision.AffineFeature.getViewParams/3","doc":"getViewParams\n\n##### Positional Arguments\n- **self**: `Evision.AffineFeature.t()`\n- **tilts**: `[float]`\n- **rolls**: `[float]`\n\nPython prototype (for reference only):\n```python3\ngetViewParams(tilts, rolls) -> None\n```","ref":"Evision.AffineFeature.html#getViewParams/3"},{"type":"function","title":"Evision.AffineFeature.read/1","doc":"","ref":"Evision.AffineFeature.html#read/1"},{"type":"function","title":"Evision.AffineFeature.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.AffineFeature.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.AffineFeature.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.AffineFeature.html#read/2"},{"type":"function","title":"Evision.AffineFeature.setViewParams/1","doc":"","ref":"Evision.AffineFeature.html#setViewParams/1"},{"type":"function","title":"Evision.AffineFeature.setViewParams/3","doc":"setViewParams\n\n##### Positional Arguments\n- **self**: `Evision.AffineFeature.t()`\n- **tilts**: `[float]`\n- **rolls**: `[float]`\n\nPython prototype (for reference only):\n```python3\nsetViewParams(tilts, rolls) -> None\n```","ref":"Evision.AffineFeature.html#setViewParams/3"},{"type":"function","title":"Evision.AffineFeature.write/1","doc":"","ref":"Evision.AffineFeature.html#write/1"},{"type":"function","title":"Evision.AffineFeature.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.AffineFeature.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.AffineFeature.html#write/2"},{"type":"function","title":"Evision.AffineFeature.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.AffineFeature.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.AffineFeature.html#write/3"},{"type":"type","title":"Evision.AffineFeature.t/0","doc":"Type that represents an `AffineFeature` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.AffineFeature.html#t:t/0"},{"type":"module","title":"Evision.AffineTransformer","doc":"","ref":"Evision.AffineTransformer.html"},{"type":"function","title":"Evision.AffineTransformer.getFullAffine/1","doc":"getFullAffine\n\n##### Positional Arguments\n- **self**: `Evision.AffineTransformer.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetFullAffine() -> retval\n```","ref":"Evision.AffineTransformer.html#getFullAffine/1"},{"type":"function","title":"Evision.AffineTransformer.setFullAffine/1","doc":"","ref":"Evision.AffineTransformer.html#setFullAffine/1"},{"type":"function","title":"Evision.AffineTransformer.setFullAffine/2","doc":"setFullAffine\n\n##### Positional Arguments\n- **self**: `Evision.AffineTransformer.t()`\n- **fullAffine**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetFullAffine(fullAffine) -> None\n```","ref":"Evision.AffineTransformer.html#setFullAffine/2"},{"type":"type","title":"Evision.AffineTransformer.t/0","doc":"Type that represents an `AffineTransformer` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.AffineTransformer.html#t:t/0"},{"type":"module","title":"Evision.AgastFeatureDetector","doc":"","ref":"Evision.AgastFeatureDetector.html"},{"type":"function","title":"Evision.AgastFeatureDetector.compute/1","doc":"","ref":"Evision.AgastFeatureDetector.html#compute/1"},{"type":"function","title":"Evision.AgastFeatureDetector.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.AgastFeatureDetector.html#compute/3"},{"type":"function","title":"Evision.AgastFeatureDetector.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.AgastFeatureDetector.html#compute/4"},{"type":"function","title":"Evision.AgastFeatureDetector.create/0","doc":"create\n##### Keyword Arguments\n- **threshold**: `integer()`.\n- **nonmaxSuppression**: `bool`.\n- **type**: `AgastFeatureDetector_DetectorType`.\n\n##### Return\n- **retval**: `Evision.AgastFeatureDetector.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, threshold[, nonmaxSuppression[, type]]]) -> retval\n```","ref":"Evision.AgastFeatureDetector.html#create/0"},{"type":"function","title":"Evision.AgastFeatureDetector.create/1","doc":"create\n##### Keyword Arguments\n- **threshold**: `integer()`.\n- **nonmaxSuppression**: `bool`.\n- **type**: `AgastFeatureDetector_DetectorType`.\n\n##### Return\n- **retval**: `Evision.AgastFeatureDetector.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, threshold[, nonmaxSuppression[, type]]]) -> retval\n```","ref":"Evision.AgastFeatureDetector.html#create/1"},{"type":"function","title":"Evision.AgastFeatureDetector.cv_NONMAX_SUPPRESSION/0","doc":"","ref":"Evision.AgastFeatureDetector.html#cv_NONMAX_SUPPRESSION/0"},{"type":"function","title":"Evision.AgastFeatureDetector.cv_THRESHOLD/0","doc":"","ref":"Evision.AgastFeatureDetector.html#cv_THRESHOLD/0"},{"type":"function","title":"Evision.AgastFeatureDetector.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.AgastFeatureDetector.html#defaultNorm/1"},{"type":"function","title":"Evision.AgastFeatureDetector.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.AgastFeatureDetector.html#descriptorSize/1"},{"type":"function","title":"Evision.AgastFeatureDetector.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.AgastFeatureDetector.html#descriptorType/1"},{"type":"function","title":"Evision.AgastFeatureDetector.detect/1","doc":"","ref":"Evision.AgastFeatureDetector.html#detect/1"},{"type":"function","title":"Evision.AgastFeatureDetector.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.AgastFeatureDetector.html#detect/2"},{"type":"function","title":"Evision.AgastFeatureDetector.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.AgastFeatureDetector.html#detect/3"},{"type":"function","title":"Evision.AgastFeatureDetector.detectAndCompute/1","doc":"","ref":"Evision.AgastFeatureDetector.html#detectAndCompute/1"},{"type":"function","title":"Evision.AgastFeatureDetector.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.AgastFeatureDetector.html#detectAndCompute/3"},{"type":"function","title":"Evision.AgastFeatureDetector.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.AgastFeatureDetector.html#detectAndCompute/4"},{"type":"function","title":"Evision.AgastFeatureDetector.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.AgastFeatureDetector.html#empty/1"},{"type":"function","title":"Evision.AgastFeatureDetector.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.AgastFeatureDetector.html#getDefaultName/1"},{"type":"function","title":"Evision.AgastFeatureDetector.getNonmaxSuppression/1","doc":"getNonmaxSuppression\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetNonmaxSuppression() -> retval\n```","ref":"Evision.AgastFeatureDetector.html#getNonmaxSuppression/1"},{"type":"function","title":"Evision.AgastFeatureDetector.getThreshold/1","doc":"getThreshold\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetThreshold() -> retval\n```","ref":"Evision.AgastFeatureDetector.html#getThreshold/1"},{"type":"function","title":"Evision.AgastFeatureDetector.getType/1","doc":"getType\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n\n##### Return\n- **retval**: `AgastFeatureDetector::DetectorType`\n\nPython prototype (for reference only):\n```python3\ngetType() -> retval\n```","ref":"Evision.AgastFeatureDetector.html#getType/1"},{"type":"function","title":"Evision.AgastFeatureDetector.read/1","doc":"","ref":"Evision.AgastFeatureDetector.html#read/1"},{"type":"function","title":"Evision.AgastFeatureDetector.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.AgastFeatureDetector.html#read/2"},{"type":"function","title":"Evision.AgastFeatureDetector.setNonmaxSuppression/1","doc":"","ref":"Evision.AgastFeatureDetector.html#setNonmaxSuppression/1"},{"type":"function","title":"Evision.AgastFeatureDetector.setNonmaxSuppression/2","doc":"setNonmaxSuppression\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n- **f**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetNonmaxSuppression(f) -> None\n```","ref":"Evision.AgastFeatureDetector.html#setNonmaxSuppression/2"},{"type":"function","title":"Evision.AgastFeatureDetector.setThreshold/1","doc":"","ref":"Evision.AgastFeatureDetector.html#setThreshold/1"},{"type":"function","title":"Evision.AgastFeatureDetector.setThreshold/2","doc":"setThreshold\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n- **threshold**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetThreshold(threshold) -> None\n```","ref":"Evision.AgastFeatureDetector.html#setThreshold/2"},{"type":"function","title":"Evision.AgastFeatureDetector.setType/1","doc":"","ref":"Evision.AgastFeatureDetector.html#setType/1"},{"type":"function","title":"Evision.AgastFeatureDetector.setType/2","doc":"setType\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n- **type**: `AgastFeatureDetector_DetectorType`\n\nPython prototype (for reference only):\n```python3\nsetType(type) -> None\n```","ref":"Evision.AgastFeatureDetector.html#setType/2"},{"type":"function","title":"Evision.AgastFeatureDetector.write/1","doc":"","ref":"Evision.AgastFeatureDetector.html#write/1"},{"type":"function","title":"Evision.AgastFeatureDetector.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.AgastFeatureDetector.html#write/2"},{"type":"function","title":"Evision.AgastFeatureDetector.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.AgastFeatureDetector.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.AgastFeatureDetector.html#write/3"},{"type":"type","title":"Evision.AgastFeatureDetector.enum/0","doc":"","ref":"Evision.AgastFeatureDetector.html#t:enum/0"},{"type":"type","title":"Evision.AgastFeatureDetector.t/0","doc":"Type that represents an `AgastFeatureDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.AgastFeatureDetector.html#t:t/0"},{"type":"module","title":"Evision.AgastFeatureDetector.DetectorType","doc":"","ref":"Evision.AgastFeatureDetector.DetectorType.html"},{"type":"function","title":"Evision.AgastFeatureDetector.DetectorType.cv_AGAST_5_8/0","doc":"","ref":"Evision.AgastFeatureDetector.DetectorType.html#cv_AGAST_5_8/0"},{"type":"function","title":"Evision.AgastFeatureDetector.DetectorType.cv_AGAST_7_12d/0","doc":"","ref":"Evision.AgastFeatureDetector.DetectorType.html#cv_AGAST_7_12d/0"},{"type":"function","title":"Evision.AgastFeatureDetector.DetectorType.cv_AGAST_7_12s/0","doc":"","ref":"Evision.AgastFeatureDetector.DetectorType.html#cv_AGAST_7_12s/0"},{"type":"function","title":"Evision.AgastFeatureDetector.DetectorType.cv_OAST_9_16/0","doc":"","ref":"Evision.AgastFeatureDetector.DetectorType.html#cv_OAST_9_16/0"},{"type":"type","title":"Evision.AgastFeatureDetector.DetectorType.enum/0","doc":"","ref":"Evision.AgastFeatureDetector.DetectorType.html#t:enum/0"},{"type":"module","title":"Evision.Algorithm","doc":"","ref":"Evision.Algorithm.html"},{"type":"function","title":"Evision.Algorithm.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Algorithm.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Algorithm.html#clear/1"},{"type":"function","title":"Evision.Algorithm.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Algorithm.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Algorithm.html#empty/1"},{"type":"function","title":"Evision.Algorithm.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Algorithm.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Algorithm.html#getDefaultName/1"},{"type":"function","title":"Evision.Algorithm.read/1","doc":"","ref":"Evision.Algorithm.html#read/1"},{"type":"function","title":"Evision.Algorithm.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Algorithm.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Algorithm.html#read/2"},{"type":"function","title":"Evision.Algorithm.save/1","doc":"","ref":"Evision.Algorithm.html#save/1"},{"type":"function","title":"Evision.Algorithm.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Algorithm.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Algorithm.html#save/2"},{"type":"function","title":"Evision.Algorithm.write/1","doc":"","ref":"Evision.Algorithm.html#write/1"},{"type":"function","title":"Evision.Algorithm.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Algorithm.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Algorithm.html#write/2"},{"type":"function","title":"Evision.Algorithm.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Algorithm.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Algorithm.html#write/3"},{"type":"type","title":"Evision.Algorithm.t/0","doc":"Type that represents an `Algorithm` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Algorithm.html#t:t/0"},{"type":"module","title":"Evision.AlignExposures","doc":"","ref":"Evision.AlignExposures.html"},{"type":"function","title":"Evision.AlignExposures.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.AlignExposures.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.AlignExposures.html#clear/1"},{"type":"function","title":"Evision.AlignExposures.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.AlignExposures.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.AlignExposures.html#empty/1"},{"type":"function","title":"Evision.AlignExposures.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.AlignExposures.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.AlignExposures.html#getDefaultName/1"},{"type":"function","title":"Evision.AlignExposures.process/1","doc":"","ref":"Evision.AlignExposures.html#process/1"},{"type":"function","title":"Evision.AlignExposures.process/5","doc":"Aligns images\n\n##### Positional Arguments\n- **self**: `Evision.AlignExposures.t()`\n- **src**: `[Evision.Mat]`.\n\n  vector of input images\n\n- **dst**: `[Evision.Mat]`.\n\n  vector of aligned images\n\n- **times**: `Evision.Mat`.\n\n  vector of exposure time values for each image\n\n- **response**: `Evision.Mat`.\n\n  256x1 matrix with inverse camera response function for each pixel value, it should\n  have the same number of channels as images.\n\nPython prototype (for reference only):\n```python3\nprocess(src, dst, times, response) -> None\n```","ref":"Evision.AlignExposures.html#process/5"},{"type":"function","title":"Evision.AlignExposures.read/1","doc":"","ref":"Evision.AlignExposures.html#read/1"},{"type":"function","title":"Evision.AlignExposures.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.AlignExposures.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.AlignExposures.html#read/2"},{"type":"function","title":"Evision.AlignExposures.save/1","doc":"","ref":"Evision.AlignExposures.html#save/1"},{"type":"function","title":"Evision.AlignExposures.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.AlignExposures.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.AlignExposures.html#save/2"},{"type":"function","title":"Evision.AlignExposures.write/1","doc":"","ref":"Evision.AlignExposures.html#write/1"},{"type":"function","title":"Evision.AlignExposures.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.AlignExposures.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.AlignExposures.html#write/2"},{"type":"function","title":"Evision.AlignExposures.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.AlignExposures.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.AlignExposures.html#write/3"},{"type":"type","title":"Evision.AlignExposures.t/0","doc":"Type that represents an `AlignExposures` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.AlignExposures.html#t:t/0"},{"type":"module","title":"Evision.AlignMTB","doc":"","ref":"Evision.AlignMTB.html"},{"type":"function","title":"Evision.AlignMTB.calculateShift/1","doc":"","ref":"Evision.AlignMTB.html#calculateShift/1"},{"type":"function","title":"Evision.AlignMTB.calculateShift/3","doc":"Calculates shift between two images, i. e. how to shift the second image to correspond it with the\nfirst.\n\n##### Positional Arguments\n- **self**: `Evision.AlignMTB.t()`\n- **img0**: `Evision.Mat`.\n\n  first image\n\n- **img1**: `Evision.Mat`.\n\n  second image\n\n##### Return\n- **retval**: `Point`\n\nPython prototype (for reference only):\n```python3\ncalculateShift(img0, img1) -> retval\n```","ref":"Evision.AlignMTB.html#calculateShift/3"},{"type":"function","title":"Evision.AlignMTB.computeBitmaps/1","doc":"","ref":"Evision.AlignMTB.html#computeBitmaps/1"},{"type":"function","title":"Evision.AlignMTB.computeBitmaps/2","doc":"Computes median threshold and exclude bitmaps of given image.\n\n##### Positional Arguments\n- **self**: `Evision.AlignMTB.t()`\n- **img**: `Evision.Mat`.\n\n  input image\n\n##### Return\n- **tb**: `Evision.Mat.t()`.\n\n  median threshold bitmap\n\n- **eb**: `Evision.Mat.t()`.\n\n  exclude bitmap\n\nPython prototype (for reference only):\n```python3\ncomputeBitmaps(img[, tb[, eb]]) -> tb, eb\n```","ref":"Evision.AlignMTB.html#computeBitmaps/2"},{"type":"function","title":"Evision.AlignMTB.computeBitmaps/3","doc":"Computes median threshold and exclude bitmaps of given image.\n\n##### Positional Arguments\n- **self**: `Evision.AlignMTB.t()`\n- **img**: `Evision.Mat`.\n\n  input image\n\n##### Return\n- **tb**: `Evision.Mat.t()`.\n\n  median threshold bitmap\n\n- **eb**: `Evision.Mat.t()`.\n\n  exclude bitmap\n\nPython prototype (for reference only):\n```python3\ncomputeBitmaps(img[, tb[, eb]]) -> tb, eb\n```","ref":"Evision.AlignMTB.html#computeBitmaps/3"},{"type":"function","title":"Evision.AlignMTB.getCut/1","doc":"getCut\n\n##### Positional Arguments\n- **self**: `Evision.AlignMTB.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetCut() -> retval\n```","ref":"Evision.AlignMTB.html#getCut/1"},{"type":"function","title":"Evision.AlignMTB.getExcludeRange/1","doc":"getExcludeRange\n\n##### Positional Arguments\n- **self**: `Evision.AlignMTB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetExcludeRange() -> retval\n```","ref":"Evision.AlignMTB.html#getExcludeRange/1"},{"type":"function","title":"Evision.AlignMTB.getMaxBits/1","doc":"getMaxBits\n\n##### Positional Arguments\n- **self**: `Evision.AlignMTB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxBits() -> retval\n```","ref":"Evision.AlignMTB.html#getMaxBits/1"},{"type":"function","title":"Evision.AlignMTB.process/1","doc":"","ref":"Evision.AlignMTB.html#process/1"},{"type":"function","title":"Evision.AlignMTB.process/3","doc":"Short version of process, that doesn't take extra arguments.\n\n##### Positional Arguments\n- **self**: `Evision.AlignMTB.t()`\n- **src**: `[Evision.Mat]`.\n\n  vector of input images\n\n- **dst**: `[Evision.Mat]`.\n\n  vector of aligned images\n\nPython prototype (for reference only):\n```python3\nprocess(src, dst) -> None\n```","ref":"Evision.AlignMTB.html#process/3"},{"type":"function","title":"Evision.AlignMTB.process/5","doc":"process\n\n##### Positional Arguments\n- **self**: `Evision.AlignMTB.t()`\n- **src**: `[Evision.Mat]`\n- **dst**: `[Evision.Mat]`\n- **times**: `Evision.Mat`\n- **response**: `Evision.Mat`\n\nPython prototype (for reference only):\n```python3\nprocess(src, dst, times, response) -> None\n```","ref":"Evision.AlignMTB.html#process/5"},{"type":"function","title":"Evision.AlignMTB.setCut/1","doc":"","ref":"Evision.AlignMTB.html#setCut/1"},{"type":"function","title":"Evision.AlignMTB.setCut/2","doc":"setCut\n\n##### Positional Arguments\n- **self**: `Evision.AlignMTB.t()`\n- **value**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetCut(value) -> None\n```","ref":"Evision.AlignMTB.html#setCut/2"},{"type":"function","title":"Evision.AlignMTB.setExcludeRange/1","doc":"","ref":"Evision.AlignMTB.html#setExcludeRange/1"},{"type":"function","title":"Evision.AlignMTB.setExcludeRange/2","doc":"setExcludeRange\n\n##### Positional Arguments\n- **self**: `Evision.AlignMTB.t()`\n- **exclude_range**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetExcludeRange(exclude_range) -> None\n```","ref":"Evision.AlignMTB.html#setExcludeRange/2"},{"type":"function","title":"Evision.AlignMTB.setMaxBits/1","doc":"","ref":"Evision.AlignMTB.html#setMaxBits/1"},{"type":"function","title":"Evision.AlignMTB.setMaxBits/2","doc":"setMaxBits\n\n##### Positional Arguments\n- **self**: `Evision.AlignMTB.t()`\n- **max_bits**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxBits(max_bits) -> None\n```","ref":"Evision.AlignMTB.html#setMaxBits/2"},{"type":"function","title":"Evision.AlignMTB.shiftMat/1","doc":"","ref":"Evision.AlignMTB.html#shiftMat/1"},{"type":"function","title":"Evision.AlignMTB.shiftMat/3","doc":"Helper function, that shift Mat filling new regions with zeros.\n\n##### Positional Arguments\n- **self**: `Evision.AlignMTB.t()`\n- **src**: `Evision.Mat`.\n\n  input image\n\n- **shift**: `Point`.\n\n  shift value\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  result image\n\nPython prototype (for reference only):\n```python3\nshiftMat(src, shift[, dst]) -> dst\n```","ref":"Evision.AlignMTB.html#shiftMat/3"},{"type":"function","title":"Evision.AlignMTB.shiftMat/4","doc":"Helper function, that shift Mat filling new regions with zeros.\n\n##### Positional Arguments\n- **self**: `Evision.AlignMTB.t()`\n- **src**: `Evision.Mat`.\n\n  input image\n\n- **shift**: `Point`.\n\n  shift value\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  result image\n\nPython prototype (for reference only):\n```python3\nshiftMat(src, shift[, dst]) -> dst\n```","ref":"Evision.AlignMTB.html#shiftMat/4"},{"type":"type","title":"Evision.AlignMTB.t/0","doc":"Type that represents an `AlignMTB` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.AlignMTB.html#t:t/0"},{"type":"module","title":"Evision.Alphamat","doc":"","ref":"Evision.Alphamat.html"},{"type":"function","title":"Evision.Alphamat.infoFlow/1","doc":"","ref":"Evision.Alphamat.html#infoFlow/1"},{"type":"function","title":"Evision.Alphamat.infoFlow/2","doc":"Compute alpha matte of an object in an image\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Input RGB image\n\n- **tmap**: `Evision.Mat`.\n\n  Input greyscale trimap image\n\n##### Return\n- **result**: `Evision.Mat.t()`.\n\n  Output alpha matte image\n\n The function infoFlow performs alpha matting on a RGB image using a greyscale trimap image, and outputs a greyscale alpha matte image. The output alpha matte can be used to softly extract the foreground object from a background image. Examples can be found in the samples directory.\n\nPython prototype (for reference only):\n```python3\ninfoFlow(image, tmap[, result]) -> result\n```","ref":"Evision.Alphamat.html#infoFlow/2"},{"type":"function","title":"Evision.Alphamat.infoFlow/3","doc":"Compute alpha matte of an object in an image\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Input RGB image\n\n- **tmap**: `Evision.Mat`.\n\n  Input greyscale trimap image\n\n##### Return\n- **result**: `Evision.Mat.t()`.\n\n  Output alpha matte image\n\n The function infoFlow performs alpha matting on a RGB image using a greyscale trimap image, and outputs a greyscale alpha matte image. The output alpha matte can be used to softly extract the foreground object from a background image. Examples can be found in the samples directory.\n\nPython prototype (for reference only):\n```python3\ninfoFlow(image, tmap[, result]) -> result\n```","ref":"Evision.Alphamat.html#infoFlow/3"},{"type":"type","title":"Evision.Alphamat.t/0","doc":"Type that represents an `Alphamat` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Alphamat.html#t:t/0"},{"type":"module","title":"Evision.ArUco","doc":"","ref":"Evision.ArUco.html"},{"type":"function","title":"Evision.ArUco.calibrateCameraAruco/1","doc":"","ref":"Evision.ArUco.html#calibrateCameraAruco/1"},{"type":"function","title":"Evision.ArUco.calibrateCameraAruco/7","doc":"It's the same function as #calibrateCameraAruco but without calibration error estimation.\n\n##### Positional Arguments\n- **corners**: `[Evision.Mat]`\n- **ids**: `Evision.Mat`\n- **counter**: `Evision.Mat`\n- **board**: `Board`\n- **imageSize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **criteria**: `TermCriteria`.\n\n##### Return\n- **retval**: `double`\n- **cameraMatrix**: `Evision.Mat.t()`\n- **distCoeffs**: `Evision.Mat.t()`\n- **rvecs**: `[Evision.Mat]`.\n- **tvecs**: `[Evision.Mat]`.\n\nHas overloading in C++\n\n@deprecated Use Board::matchImagePoints and cv::solvePnP\n\nPython prototype (for reference only):\n```python3\ncalibrateCameraAruco(corners, ids, counter, board, imageSize, cameraMatrix, distCoeffs[, rvecs[, tvecs[, flags[, criteria]]]]) -> retval, cameraMatrix, distCoeffs, rvecs, tvecs\n```","ref":"Evision.ArUco.html#calibrateCameraAruco/7"},{"type":"function","title":"Evision.ArUco.calibrateCameraAruco/8","doc":"It's the same function as #calibrateCameraAruco but without calibration error estimation.\n\n##### Positional Arguments\n- **corners**: `[Evision.Mat]`\n- **ids**: `Evision.Mat`\n- **counter**: `Evision.Mat`\n- **board**: `Board`\n- **imageSize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **criteria**: `TermCriteria`.\n\n##### Return\n- **retval**: `double`\n- **cameraMatrix**: `Evision.Mat.t()`\n- **distCoeffs**: `Evision.Mat.t()`\n- **rvecs**: `[Evision.Mat]`.\n- **tvecs**: `[Evision.Mat]`.\n\nHas overloading in C++\n\n@deprecated Use Board::matchImagePoints and cv::solvePnP\n\nPython prototype (for reference only):\n```python3\ncalibrateCameraAruco(corners, ids, counter, board, imageSize, cameraMatrix, distCoeffs[, rvecs[, tvecs[, flags[, criteria]]]]) -> retval, cameraMatrix, distCoeffs, rvecs, tvecs\n```","ref":"Evision.ArUco.html#calibrateCameraAruco/8"},{"type":"function","title":"Evision.ArUco.calibrateCameraArucoExtended/1","doc":"","ref":"Evision.ArUco.html#calibrateCameraArucoExtended/1"},{"type":"function","title":"Evision.ArUco.calibrateCameraArucoExtended/7","doc":"Calibrate a camera using aruco markers\n\n##### Positional Arguments\n- **corners**: `[Evision.Mat]`.\n\n  vector of detected marker corners in all frames.\n  The corners should have the same format returned by detectMarkers (see #detectMarkers).\n\n- **ids**: `Evision.Mat`.\n\n  list of identifiers for each marker in corners\n\n- **counter**: `Evision.Mat`.\n\n  number of markers in each frame so that corners and ids can be split\n\n- **board**: `Board`.\n\n  Marker Board layout\n\n- **imageSize**: `Size`.\n\n  Size of the image used only to initialize the intrinsic camera matrix.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  flags Different flags  for the calibration process (see #calibrateCamera for details).\n\n- **criteria**: `TermCriteria`.\n\n  Termination criteria for the iterative optimization algorithm.\n\n##### Return\n- **retval**: `double`\n- **cameraMatrix**: `Evision.Mat.t()`.\n\n  Output 3x3 floating-point camera matrix\n  \\f$A = \\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$ . If CV\\_CALIB\\_USE\\_INTRINSIC\\_GUESS\n  and/or CV_CALIB_FIX_ASPECT_RATIO are specified, some or all of fx, fy, cx, cy must be\n  initialized before calling the function.\n\n- **distCoeffs**: `Evision.Mat.t()`.\n\n  Output vector of distortion coefficients\n  \\f$(k_1, k_2, p_1, p_2[, k_3[, k_4, k_5, k_6],[s_1, s_2, s_3, s_4]])\\f$ of 4, 5, 8 or 12 elements\n\n- **rvecs**: `[Evision.Mat]`.\n\n  Output vector of rotation vectors (see Rodrigues ) estimated for each board view\n  (e.g. std::vector >). That is, each k-th rotation vector together with the corresponding\n  k-th translation vector (see the next output parameter description) brings the board pattern\n  from the model coordinate space (in which object points are specified) to the world coordinate\n  space, that is, a real position of the board pattern in the k-th pattern view (k=0.. *M* -1).\n\n- **tvecs**: `[Evision.Mat]`.\n\n  Output vector of translation vectors estimated for each pattern view.\n\n- **stdDeviationsIntrinsics**: `Evision.Mat.t()`.\n\n  Output vector of standard deviations estimated for intrinsic parameters.\n  Order of deviations values:\n  \\f$(f_x, f_y, c_x, c_y, k_1, k_2, p_1, p_2, k_3, k_4, k_5, k_6 , s_1, s_2, s_3,\n  s_4, \\tau_x, \\tau_y)\\f$ If one of parameters is not estimated, it's deviation is equals to zero.\n\n- **stdDeviationsExtrinsics**: `Evision.Mat.t()`.\n\n  Output vector of standard deviations estimated for extrinsic parameters.\n  Order of deviations values: \\f$(R_1, T_1, \\dotsc , R_M, T_M)\\f$ where M is number of pattern views,\n  \\f$R_i, T_i\\f$ are concatenated 1x3 vectors.\n\n- **perViewErrors**: `Evision.Mat.t()`.\n\n  Output vector of average re-projection errors estimated for each pattern view.\n\n This function calibrates a camera using an Aruco Board. The function receives a list of\n detected markers from several views of the Board. The process is similar to the chessboard\n calibration in calibrateCamera(). The function returns the final re-projection error.\n@deprecated Use Board::matchImagePoints and cv::solvePnP\n\nPython prototype (for reference only):\n```python3\ncalibrateCameraArucoExtended(corners, ids, counter, board, imageSize, cameraMatrix, distCoeffs[, rvecs[, tvecs[, stdDeviationsIntrinsics[, stdDeviationsExtrinsics[, perViewErrors[, flags[, criteria]]]]]]]) -> retval, cameraMatrix, distCoeffs, rvecs, tvecs, stdDeviationsIntrinsics, stdDeviationsExtrinsics, perViewErrors\n```","ref":"Evision.ArUco.html#calibrateCameraArucoExtended/7"},{"type":"function","title":"Evision.ArUco.calibrateCameraArucoExtended/8","doc":"Calibrate a camera using aruco markers\n\n##### Positional Arguments\n- **corners**: `[Evision.Mat]`.\n\n  vector of detected marker corners in all frames.\n  The corners should have the same format returned by detectMarkers (see #detectMarkers).\n\n- **ids**: `Evision.Mat`.\n\n  list of identifiers for each marker in corners\n\n- **counter**: `Evision.Mat`.\n\n  number of markers in each frame so that corners and ids can be split\n\n- **board**: `Board`.\n\n  Marker Board layout\n\n- **imageSize**: `Size`.\n\n  Size of the image used only to initialize the intrinsic camera matrix.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  flags Different flags  for the calibration process (see #calibrateCamera for details).\n\n- **criteria**: `TermCriteria`.\n\n  Termination criteria for the iterative optimization algorithm.\n\n##### Return\n- **retval**: `double`\n- **cameraMatrix**: `Evision.Mat.t()`.\n\n  Output 3x3 floating-point camera matrix\n  \\f$A = \\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$ . If CV\\_CALIB\\_USE\\_INTRINSIC\\_GUESS\n  and/or CV_CALIB_FIX_ASPECT_RATIO are specified, some or all of fx, fy, cx, cy must be\n  initialized before calling the function.\n\n- **distCoeffs**: `Evision.Mat.t()`.\n\n  Output vector of distortion coefficients\n  \\f$(k_1, k_2, p_1, p_2[, k_3[, k_4, k_5, k_6],[s_1, s_2, s_3, s_4]])\\f$ of 4, 5, 8 or 12 elements\n\n- **rvecs**: `[Evision.Mat]`.\n\n  Output vector of rotation vectors (see Rodrigues ) estimated for each board view\n  (e.g. std::vector >). That is, each k-th rotation vector together with the corresponding\n  k-th translation vector (see the next output parameter description) brings the board pattern\n  from the model coordinate space (in which object points are specified) to the world coordinate\n  space, that is, a real position of the board pattern in the k-th pattern view (k=0.. *M* -1).\n\n- **tvecs**: `[Evision.Mat]`.\n\n  Output vector of translation vectors estimated for each pattern view.\n\n- **stdDeviationsIntrinsics**: `Evision.Mat.t()`.\n\n  Output vector of standard deviations estimated for intrinsic parameters.\n  Order of deviations values:\n  \\f$(f_x, f_y, c_x, c_y, k_1, k_2, p_1, p_2, k_3, k_4, k_5, k_6 , s_1, s_2, s_3,\n  s_4, \\tau_x, \\tau_y)\\f$ If one of parameters is not estimated, it's deviation is equals to zero.\n\n- **stdDeviationsExtrinsics**: `Evision.Mat.t()`.\n\n  Output vector of standard deviations estimated for extrinsic parameters.\n  Order of deviations values: \\f$(R_1, T_1, \\dotsc , R_M, T_M)\\f$ where M is number of pattern views,\n  \\f$R_i, T_i\\f$ are concatenated 1x3 vectors.\n\n- **perViewErrors**: `Evision.Mat.t()`.\n\n  Output vector of average re-projection errors estimated for each pattern view.\n\n This function calibrates a camera using an Aruco Board. The function receives a list of\n detected markers from several views of the Board. The process is similar to the chessboard\n calibration in calibrateCamera(). The function returns the final re-projection error.\n@deprecated Use Board::matchImagePoints and cv::solvePnP\n\nPython prototype (for reference only):\n```python3\ncalibrateCameraArucoExtended(corners, ids, counter, board, imageSize, cameraMatrix, distCoeffs[, rvecs[, tvecs[, stdDeviationsIntrinsics[, stdDeviationsExtrinsics[, perViewErrors[, flags[, criteria]]]]]]]) -> retval, cameraMatrix, distCoeffs, rvecs, tvecs, stdDeviationsIntrinsics, stdDeviationsExtrinsics, perViewErrors\n```","ref":"Evision.ArUco.html#calibrateCameraArucoExtended/8"},{"type":"function","title":"Evision.ArUco.calibrateCameraCharuco/1","doc":"","ref":"Evision.ArUco.html#calibrateCameraCharuco/1"},{"type":"function","title":"Evision.ArUco.calibrateCameraCharuco/6","doc":"It's the same function as #calibrateCameraCharuco but without calibration error estimation.\n\n##### Positional Arguments\n- **charucoCorners**: `[Evision.Mat]`\n- **charucoIds**: `[Evision.Mat]`\n- **board**: `Evision.ArUco.CharucoBoard`\n- **imageSize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **criteria**: `TermCriteria`.\n\n##### Return\n- **retval**: `double`\n- **cameraMatrix**: `Evision.Mat.t()`\n- **distCoeffs**: `Evision.Mat.t()`\n- **rvecs**: `[Evision.Mat]`.\n- **tvecs**: `[Evision.Mat]`.\n\n@deprecated Use CharucoBoard::matchImagePoints and cv::solvePnP\n\nPython prototype (for reference only):\n```python3\ncalibrateCameraCharuco(charucoCorners, charucoIds, board, imageSize, cameraMatrix, distCoeffs[, rvecs[, tvecs[, flags[, criteria]]]]) -> retval, cameraMatrix, distCoeffs, rvecs, tvecs\n```","ref":"Evision.ArUco.html#calibrateCameraCharuco/6"},{"type":"function","title":"Evision.ArUco.calibrateCameraCharuco/7","doc":"It's the same function as #calibrateCameraCharuco but without calibration error estimation.\n\n##### Positional Arguments\n- **charucoCorners**: `[Evision.Mat]`\n- **charucoIds**: `[Evision.Mat]`\n- **board**: `Evision.ArUco.CharucoBoard`\n- **imageSize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **criteria**: `TermCriteria`.\n\n##### Return\n- **retval**: `double`\n- **cameraMatrix**: `Evision.Mat.t()`\n- **distCoeffs**: `Evision.Mat.t()`\n- **rvecs**: `[Evision.Mat]`.\n- **tvecs**: `[Evision.Mat]`.\n\n@deprecated Use CharucoBoard::matchImagePoints and cv::solvePnP\n\nPython prototype (for reference only):\n```python3\ncalibrateCameraCharuco(charucoCorners, charucoIds, board, imageSize, cameraMatrix, distCoeffs[, rvecs[, tvecs[, flags[, criteria]]]]) -> retval, cameraMatrix, distCoeffs, rvecs, tvecs\n```","ref":"Evision.ArUco.html#calibrateCameraCharuco/7"},{"type":"function","title":"Evision.ArUco.calibrateCameraCharucoExtended/1","doc":"","ref":"Evision.ArUco.html#calibrateCameraCharucoExtended/1"},{"type":"function","title":"Evision.ArUco.calibrateCameraCharucoExtended/6","doc":"Calibrate a camera using Charuco corners\n\n##### Positional Arguments\n- **charucoCorners**: `[Evision.Mat]`.\n\n  vector of detected charuco corners per frame\n\n- **charucoIds**: `[Evision.Mat]`.\n\n  list of identifiers for each corner in charucoCorners per frame\n\n- **board**: `Evision.ArUco.CharucoBoard`.\n\n  Marker Board layout\n\n- **imageSize**: `Size`.\n\n  input image size\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  flags Different flags  for the calibration process (see #calibrateCamera for details).\n\n- **criteria**: `TermCriteria`.\n\n  Termination criteria for the iterative optimization algorithm.\n\n##### Return\n- **retval**: `double`\n- **cameraMatrix**: `Evision.Mat.t()`.\n\n  Output 3x3 floating-point camera matrix\n  \\f$A = \\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$ . If CV\\_CALIB\\_USE\\_INTRINSIC\\_GUESS\n  and/or CV_CALIB_FIX_ASPECT_RATIO are specified, some or all of fx, fy, cx, cy must be\n  initialized before calling the function.\n\n- **distCoeffs**: `Evision.Mat.t()`.\n\n  Output vector of distortion coefficients\n  \\f$(k_1, k_2, p_1, p_2[, k_3[, k_4, k_5, k_6],[s_1, s_2, s_3, s_4]])\\f$ of 4, 5, 8 or 12 elements\n\n- **rvecs**: `[Evision.Mat]`.\n\n  Output vector of rotation vectors (see Rodrigues ) estimated for each board view\n  (e.g. std::vector >). That is, each k-th rotation vector together with the corresponding\n  k-th translation vector (see the next output parameter description) brings the board pattern\n  from the model coordinate space (in which object points are specified) to the world coordinate\n  space, that is, a real position of the board pattern in the k-th pattern view (k=0.. *M* -1).\n\n- **tvecs**: `[Evision.Mat]`.\n\n  Output vector of translation vectors estimated for each pattern view.\n\n- **stdDeviationsIntrinsics**: `Evision.Mat.t()`.\n\n  Output vector of standard deviations estimated for intrinsic parameters.\n  Order of deviations values:\n  \\f$(f_x, f_y, c_x, c_y, k_1, k_2, p_1, p_2, k_3, k_4, k_5, k_6 , s_1, s_2, s_3,\n  s_4, \\tau_x, \\tau_y)\\f$ If one of parameters is not estimated, it's deviation is equals to zero.\n\n- **stdDeviationsExtrinsics**: `Evision.Mat.t()`.\n\n  Output vector of standard deviations estimated for extrinsic parameters.\n  Order of deviations values: \\f$(R_1, T_1, \\dotsc , R_M, T_M)\\f$ where M is number of pattern views,\n  \\f$R_i, T_i\\f$ are concatenated 1x3 vectors.\n\n- **perViewErrors**: `Evision.Mat.t()`.\n\n  Output vector of average re-projection errors estimated for each pattern view.\n\n This function calibrates a camera using a set of corners of a  Charuco Board. The function\n receives a list of detected corners and its identifiers from several views of the Board.\n The function returns the final re-projection error.\n@deprecated Use CharucoBoard::matchImagePoints and cv::solvePnP\n\nPython prototype (for reference only):\n```python3\ncalibrateCameraCharucoExtended(charucoCorners, charucoIds, board, imageSize, cameraMatrix, distCoeffs[, rvecs[, tvecs[, stdDeviationsIntrinsics[, stdDeviationsExtrinsics[, perViewErrors[, flags[, criteria]]]]]]]) -> retval, cameraMatrix, distCoeffs, rvecs, tvecs, stdDeviationsIntrinsics, stdDeviationsExtrinsics, perViewErrors\n```","ref":"Evision.ArUco.html#calibrateCameraCharucoExtended/6"},{"type":"function","title":"Evision.ArUco.calibrateCameraCharucoExtended/7","doc":"Calibrate a camera using Charuco corners\n\n##### Positional Arguments\n- **charucoCorners**: `[Evision.Mat]`.\n\n  vector of detected charuco corners per frame\n\n- **charucoIds**: `[Evision.Mat]`.\n\n  list of identifiers for each corner in charucoCorners per frame\n\n- **board**: `Evision.ArUco.CharucoBoard`.\n\n  Marker Board layout\n\n- **imageSize**: `Size`.\n\n  input image size\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  flags Different flags  for the calibration process (see #calibrateCamera for details).\n\n- **criteria**: `TermCriteria`.\n\n  Termination criteria for the iterative optimization algorithm.\n\n##### Return\n- **retval**: `double`\n- **cameraMatrix**: `Evision.Mat.t()`.\n\n  Output 3x3 floating-point camera matrix\n  \\f$A = \\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$ . If CV\\_CALIB\\_USE\\_INTRINSIC\\_GUESS\n  and/or CV_CALIB_FIX_ASPECT_RATIO are specified, some or all of fx, fy, cx, cy must be\n  initialized before calling the function.\n\n- **distCoeffs**: `Evision.Mat.t()`.\n\n  Output vector of distortion coefficients\n  \\f$(k_1, k_2, p_1, p_2[, k_3[, k_4, k_5, k_6],[s_1, s_2, s_3, s_4]])\\f$ of 4, 5, 8 or 12 elements\n\n- **rvecs**: `[Evision.Mat]`.\n\n  Output vector of rotation vectors (see Rodrigues ) estimated for each board view\n  (e.g. std::vector >). That is, each k-th rotation vector together with the corresponding\n  k-th translation vector (see the next output parameter description) brings the board pattern\n  from the model coordinate space (in which object points are specified) to the world coordinate\n  space, that is, a real position of the board pattern in the k-th pattern view (k=0.. *M* -1).\n\n- **tvecs**: `[Evision.Mat]`.\n\n  Output vector of translation vectors estimated for each pattern view.\n\n- **stdDeviationsIntrinsics**: `Evision.Mat.t()`.\n\n  Output vector of standard deviations estimated for intrinsic parameters.\n  Order of deviations values:\n  \\f$(f_x, f_y, c_x, c_y, k_1, k_2, p_1, p_2, k_3, k_4, k_5, k_6 , s_1, s_2, s_3,\n  s_4, \\tau_x, \\tau_y)\\f$ If one of parameters is not estimated, it's deviation is equals to zero.\n\n- **stdDeviationsExtrinsics**: `Evision.Mat.t()`.\n\n  Output vector of standard deviations estimated for extrinsic parameters.\n  Order of deviations values: \\f$(R_1, T_1, \\dotsc , R_M, T_M)\\f$ where M is number of pattern views,\n  \\f$R_i, T_i\\f$ are concatenated 1x3 vectors.\n\n- **perViewErrors**: `Evision.Mat.t()`.\n\n  Output vector of average re-projection errors estimated for each pattern view.\n\n This function calibrates a camera using a set of corners of a  Charuco Board. The function\n receives a list of detected corners and its identifiers from several views of the Board.\n The function returns the final re-projection error.\n@deprecated Use CharucoBoard::matchImagePoints and cv::solvePnP\n\nPython prototype (for reference only):\n```python3\ncalibrateCameraCharucoExtended(charucoCorners, charucoIds, board, imageSize, cameraMatrix, distCoeffs[, rvecs[, tvecs[, stdDeviationsIntrinsics[, stdDeviationsExtrinsics[, perViewErrors[, flags[, criteria]]]]]]]) -> retval, cameraMatrix, distCoeffs, rvecs, tvecs, stdDeviationsIntrinsics, stdDeviationsExtrinsics, perViewErrors\n```","ref":"Evision.ArUco.html#calibrateCameraCharucoExtended/7"},{"type":"function","title":"Evision.ArUco.detectCharucoDiamond/1","doc":"","ref":"Evision.ArUco.html#detectCharucoDiamond/1"},{"type":"function","title":"Evision.ArUco.detectCharucoDiamond/4","doc":"Detect ChArUco Diamond markers\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  input image necessary for corner subpixel.\n\n- **markerCorners**: `[Evision.Mat]`.\n\n  list of detected marker corners from detectMarkers function.\n\n- **markerIds**: `Evision.Mat`.\n\n  list of marker ids in markerCorners.\n\n- **squareMarkerLengthRate**: `float`.\n\n  rate between square and marker length:\n  squareMarkerLengthRate = squareLength/markerLength. The real units are not necessary.\n\n##### Keyword Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  Optional camera calibration matrix.\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Optional camera distortion coefficients.\n\n- **dictionary**: `Dictionary`.\n\n  dictionary of markers indicating the type of markers.\n\n##### Return\n- **diamondCorners**: `[Evision.Mat]`.\n\n  output list of detected diamond corners (4 corners per diamond). The order\n  is the same than in marker corners: top left, top right, bottom right and bottom left. Similar\n  format than the corners returned by detectMarkers (e.g std::vector  > ).\n\n- **diamondIds**: `Evision.Mat.t()`.\n\n  ids of the diamonds in diamondCorners. The id of each diamond is in fact of\n  type Vec4i, so each diamond has 4 ids, which are the ids of the aruco markers composing the\n  diamond.\n\n This function detects Diamond markers from the previous detected ArUco markers. The diamonds\n are returned in the diamondCorners and diamondIds parameters. If camera calibration parameters\n are provided, the diamond search is based on reprojection. If not, diamond search is based on\n homography. Homography is faster than reprojection, but less accurate.\n@deprecated Use CharucoDetector::detectDiamonds\n\nPython prototype (for reference only):\n```python3\ndetectCharucoDiamond(image, markerCorners, markerIds, squareMarkerLengthRate[, diamondCorners[, diamondIds[, cameraMatrix[, distCoeffs[, dictionary]]]]]) -> diamondCorners, diamondIds\n```","ref":"Evision.ArUco.html#detectCharucoDiamond/4"},{"type":"function","title":"Evision.ArUco.detectCharucoDiamond/5","doc":"Detect ChArUco Diamond markers\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  input image necessary for corner subpixel.\n\n- **markerCorners**: `[Evision.Mat]`.\n\n  list of detected marker corners from detectMarkers function.\n\n- **markerIds**: `Evision.Mat`.\n\n  list of marker ids in markerCorners.\n\n- **squareMarkerLengthRate**: `float`.\n\n  rate between square and marker length:\n  squareMarkerLengthRate = squareLength/markerLength. The real units are not necessary.\n\n##### Keyword Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  Optional camera calibration matrix.\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Optional camera distortion coefficients.\n\n- **dictionary**: `Dictionary`.\n\n  dictionary of markers indicating the type of markers.\n\n##### Return\n- **diamondCorners**: `[Evision.Mat]`.\n\n  output list of detected diamond corners (4 corners per diamond). The order\n  is the same than in marker corners: top left, top right, bottom right and bottom left. Similar\n  format than the corners returned by detectMarkers (e.g std::vector  > ).\n\n- **diamondIds**: `Evision.Mat.t()`.\n\n  ids of the diamonds in diamondCorners. The id of each diamond is in fact of\n  type Vec4i, so each diamond has 4 ids, which are the ids of the aruco markers composing the\n  diamond.\n\n This function detects Diamond markers from the previous detected ArUco markers. The diamonds\n are returned in the diamondCorners and diamondIds parameters. If camera calibration parameters\n are provided, the diamond search is based on reprojection. If not, diamond search is based on\n homography. Homography is faster than reprojection, but less accurate.\n@deprecated Use CharucoDetector::detectDiamonds\n\nPython prototype (for reference only):\n```python3\ndetectCharucoDiamond(image, markerCorners, markerIds, squareMarkerLengthRate[, diamondCorners[, diamondIds[, cameraMatrix[, distCoeffs[, dictionary]]]]]) -> diamondCorners, diamondIds\n```","ref":"Evision.ArUco.html#detectCharucoDiamond/5"},{"type":"function","title":"Evision.ArUco.detectMarkers/1","doc":"","ref":"Evision.ArUco.html#detectMarkers/1"},{"type":"function","title":"Evision.ArUco.detectMarkers/2","doc":"detect markers\n\n##### Positional Arguments\n- **image**: `Evision.Mat`\n- **dictionary**: `Dictionary`\n\n##### Keyword Arguments\n- **parameters**: `DetectorParameters`.\n\n##### Return\n- **corners**: `[Evision.Mat]`.\n- **ids**: `Evision.Mat.t()`.\n- **rejectedImgPoints**: `[Evision.Mat]`.\n\n@deprecated Use class ArucoDetector::detectMarkers\n\nPython prototype (for reference only):\n```python3\ndetectMarkers(image, dictionary[, corners[, ids[, parameters[, rejectedImgPoints]]]]) -> corners, ids, rejectedImgPoints\n```","ref":"Evision.ArUco.html#detectMarkers/2"},{"type":"function","title":"Evision.ArUco.detectMarkers/3","doc":"detect markers\n\n##### Positional Arguments\n- **image**: `Evision.Mat`\n- **dictionary**: `Dictionary`\n\n##### Keyword Arguments\n- **parameters**: `DetectorParameters`.\n\n##### Return\n- **corners**: `[Evision.Mat]`.\n- **ids**: `Evision.Mat.t()`.\n- **rejectedImgPoints**: `[Evision.Mat]`.\n\n@deprecated Use class ArucoDetector::detectMarkers\n\nPython prototype (for reference only):\n```python3\ndetectMarkers(image, dictionary[, corners[, ids[, parameters[, rejectedImgPoints]]]]) -> corners, ids, rejectedImgPoints\n```","ref":"Evision.ArUco.html#detectMarkers/3"},{"type":"function","title":"Evision.ArUco.drawCharucoDiamond/1","doc":"","ref":"Evision.ArUco.html#drawCharucoDiamond/1"},{"type":"function","title":"Evision.ArUco.drawCharucoDiamond/4","doc":"Draw a ChArUco Diamond marker\n\n##### Positional Arguments\n- **dictionary**: `Dictionary`.\n\n  dictionary of markers indicating the type of markers.\n\n- **ids**: `Vec4i`.\n\n  list of 4 ids for each ArUco marker in the ChArUco marker.\n\n- **squareLength**: `integer()`.\n\n  size of the chessboard squares in pixels.\n\n- **markerLength**: `integer()`.\n\n  size of the markers in pixels.\n\n##### Keyword Arguments\n- **marginSize**: `integer()`.\n\n  minimum margins (in pixels) of the marker in the output image\n\n- **borderBits**: `integer()`.\n\n  width of the marker borders.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  output image with the marker. The size of this image will be\n  3*squareLength + 2*marginSize,.\n\n This function return the image of a ChArUco marker, ready to be printed.\n@deprecated Use CharucoBoard::generateImage()\n\nPython prototype (for reference only):\n```python3\ndrawCharucoDiamond(dictionary, ids, squareLength, markerLength[, img[, marginSize[, borderBits]]]) -> img\n```","ref":"Evision.ArUco.html#drawCharucoDiamond/4"},{"type":"function","title":"Evision.ArUco.drawCharucoDiamond/5","doc":"Draw a ChArUco Diamond marker\n\n##### Positional Arguments\n- **dictionary**: `Dictionary`.\n\n  dictionary of markers indicating the type of markers.\n\n- **ids**: `Vec4i`.\n\n  list of 4 ids for each ArUco marker in the ChArUco marker.\n\n- **squareLength**: `integer()`.\n\n  size of the chessboard squares in pixels.\n\n- **markerLength**: `integer()`.\n\n  size of the markers in pixels.\n\n##### Keyword Arguments\n- **marginSize**: `integer()`.\n\n  minimum margins (in pixels) of the marker in the output image\n\n- **borderBits**: `integer()`.\n\n  width of the marker borders.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  output image with the marker. The size of this image will be\n  3*squareLength + 2*marginSize,.\n\n This function return the image of a ChArUco marker, ready to be printed.\n@deprecated Use CharucoBoard::generateImage()\n\nPython prototype (for reference only):\n```python3\ndrawCharucoDiamond(dictionary, ids, squareLength, markerLength[, img[, marginSize[, borderBits]]]) -> img\n```","ref":"Evision.ArUco.html#drawCharucoDiamond/5"},{"type":"function","title":"Evision.ArUco.drawDetectedCornersCharuco/1","doc":"","ref":"Evision.ArUco.html#drawDetectedCornersCharuco/1"},{"type":"function","title":"Evision.ArUco.drawDetectedCornersCharuco/2","doc":"Draws a set of Charuco corners\n\n##### Positional Arguments\n- **charucoCorners**: `Evision.Mat`.\n\n  vector of detected charuco corners\n\n##### Keyword Arguments\n- **charucoIds**: `Evision.Mat`.\n\n  list of identifiers for each corner in charucoCorners\n\n- **cornerColor**: `Evision.scalar()`.\n\n  color of the square surrounding each corner\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  input/output image. It must have 1 or 3 channels. The number of channels is not\n  altered.\n\n This function draws a set of detected Charuco corners. If identifiers vector is provided, it also\n draws the id of each corner.\n\nPython prototype (for reference only):\n```python3\ndrawDetectedCornersCharuco(image, charucoCorners[, charucoIds[, cornerColor]]) -> image\n```","ref":"Evision.ArUco.html#drawDetectedCornersCharuco/2"},{"type":"function","title":"Evision.ArUco.drawDetectedCornersCharuco/3","doc":"Draws a set of Charuco corners\n\n##### Positional Arguments\n- **charucoCorners**: `Evision.Mat`.\n\n  vector of detected charuco corners\n\n##### Keyword Arguments\n- **charucoIds**: `Evision.Mat`.\n\n  list of identifiers for each corner in charucoCorners\n\n- **cornerColor**: `Evision.scalar()`.\n\n  color of the square surrounding each corner\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  input/output image. It must have 1 or 3 channels. The number of channels is not\n  altered.\n\n This function draws a set of detected Charuco corners. If identifiers vector is provided, it also\n draws the id of each corner.\n\nPython prototype (for reference only):\n```python3\ndrawDetectedCornersCharuco(image, charucoCorners[, charucoIds[, cornerColor]]) -> image\n```","ref":"Evision.ArUco.html#drawDetectedCornersCharuco/3"},{"type":"function","title":"Evision.ArUco.drawDetectedDiamonds/1","doc":"","ref":"Evision.ArUco.html#drawDetectedDiamonds/1"},{"type":"function","title":"Evision.ArUco.drawDetectedDiamonds/2","doc":"Draw a set of detected ChArUco Diamond markers\n\n##### Positional Arguments\n- **diamondCorners**: `[Evision.Mat]`.\n\n  positions of diamond corners in the same format returned by\n  detectCharucoDiamond(). (e.g std::vector  > ). For N detected markers,\n  the dimensions of this array should be Nx4. The order of the corners should be clockwise.\n\n##### Keyword Arguments\n- **diamondIds**: `Evision.Mat`.\n\n  vector of identifiers for diamonds in diamondCorners, in the same format\n  returned by detectCharucoDiamond() (e.g. std::vector ).\n  Optional, if not provided, ids are not painted.\n\n- **borderColor**: `Evision.scalar()`.\n\n  color of marker borders. Rest of colors (text color and first corner color)\n  are calculated based on this one.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  input/output image. It must have 1 or 3 channels. The number of channels is not\n  altered.\n\n Given an array of detected diamonds, this functions draws them in the image. The marker borders\n are painted and the markers identifiers if provided.\n Useful for debugging purposes.\n\nPython prototype (for reference only):\n```python3\ndrawDetectedDiamonds(image, diamondCorners[, diamondIds[, borderColor]]) -> image\n```","ref":"Evision.ArUco.html#drawDetectedDiamonds/2"},{"type":"function","title":"Evision.ArUco.drawDetectedDiamonds/3","doc":"Draw a set of detected ChArUco Diamond markers\n\n##### Positional Arguments\n- **diamondCorners**: `[Evision.Mat]`.\n\n  positions of diamond corners in the same format returned by\n  detectCharucoDiamond(). (e.g std::vector  > ). For N detected markers,\n  the dimensions of this array should be Nx4. The order of the corners should be clockwise.\n\n##### Keyword Arguments\n- **diamondIds**: `Evision.Mat`.\n\n  vector of identifiers for diamonds in diamondCorners, in the same format\n  returned by detectCharucoDiamond() (e.g. std::vector ).\n  Optional, if not provided, ids are not painted.\n\n- **borderColor**: `Evision.scalar()`.\n\n  color of marker borders. Rest of colors (text color and first corner color)\n  are calculated based on this one.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  input/output image. It must have 1 or 3 channels. The number of channels is not\n  altered.\n\n Given an array of detected diamonds, this functions draws them in the image. The marker borders\n are painted and the markers identifiers if provided.\n Useful for debugging purposes.\n\nPython prototype (for reference only):\n```python3\ndrawDetectedDiamonds(image, diamondCorners[, diamondIds[, borderColor]]) -> image\n```","ref":"Evision.ArUco.html#drawDetectedDiamonds/3"},{"type":"function","title":"Evision.ArUco.drawDetectedMarkers/1","doc":"","ref":"Evision.ArUco.html#drawDetectedMarkers/1"},{"type":"function","title":"Evision.ArUco.drawDetectedMarkers/2","doc":"Draw detected markers in image\n\n##### Positional Arguments\n- **corners**: `[Evision.Mat]`.\n\n  positions of marker corners on input image.\n  (e.g std::vector  > ). For N detected markers, the dimensions of\n  this array should be Nx4. The order of the corners should be clockwise.\n\n##### Keyword Arguments\n- **ids**: `Evision.Mat`.\n\n  vector of identifiers for markers in markersCorners .\n  Optional, if not provided, ids are not painted.\n\n- **borderColor**: `Evision.scalar()`.\n\n  color of marker borders. Rest of colors (text color and first corner color)\n  are calculated based on this one to improve visualization.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  input/output image. It must have 1 or 3 channels. The number of channels is not altered.\n\n Given an array of detected marker corners and its corresponding ids, this functions draws\n the markers in the image. The marker borders are painted and the markers identifiers if provided.\n Useful for debugging purposes.\n\nPython prototype (for reference only):\n```python3\ndrawDetectedMarkers(image, corners[, ids[, borderColor]]) -> image\n```","ref":"Evision.ArUco.html#drawDetectedMarkers/2"},{"type":"function","title":"Evision.ArUco.drawDetectedMarkers/3","doc":"Draw detected markers in image\n\n##### Positional Arguments\n- **corners**: `[Evision.Mat]`.\n\n  positions of marker corners on input image.\n  (e.g std::vector  > ). For N detected markers, the dimensions of\n  this array should be Nx4. The order of the corners should be clockwise.\n\n##### Keyword Arguments\n- **ids**: `Evision.Mat`.\n\n  vector of identifiers for markers in markersCorners .\n  Optional, if not provided, ids are not painted.\n\n- **borderColor**: `Evision.scalar()`.\n\n  color of marker borders. Rest of colors (text color and first corner color)\n  are calculated based on this one to improve visualization.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  input/output image. It must have 1 or 3 channels. The number of channels is not altered.\n\n Given an array of detected marker corners and its corresponding ids, this functions draws\n the markers in the image. The marker borders are painted and the markers identifiers if provided.\n Useful for debugging purposes.\n\nPython prototype (for reference only):\n```python3\ndrawDetectedMarkers(image, corners[, ids[, borderColor]]) -> image\n```","ref":"Evision.ArUco.html#drawDetectedMarkers/3"},{"type":"function","title":"Evision.ArUco.drawPlanarBoard/1","doc":"","ref":"Evision.ArUco.html#drawPlanarBoard/1"},{"type":"function","title":"Evision.ArUco.drawPlanarBoard/4","doc":"draw planar board\n\n##### Positional Arguments\n- **board**: `Board`\n- **outSize**: `Size`\n- **marginSize**: `integer()`\n- **borderBits**: `integer()`\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n@deprecated Use Board::generateImage\n\nPython prototype (for reference only):\n```python3\ndrawPlanarBoard(board, outSize, marginSize, borderBits[, img]) -> img\n```","ref":"Evision.ArUco.html#drawPlanarBoard/4"},{"type":"function","title":"Evision.ArUco.drawPlanarBoard/5","doc":"draw planar board\n\n##### Positional Arguments\n- **board**: `Board`\n- **outSize**: `Size`\n- **marginSize**: `integer()`\n- **borderBits**: `integer()`\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n@deprecated Use Board::generateImage\n\nPython prototype (for reference only):\n```python3\ndrawPlanarBoard(board, outSize, marginSize, borderBits[, img]) -> img\n```","ref":"Evision.ArUco.html#drawPlanarBoard/5"},{"type":"function","title":"Evision.ArUco.estimatePoseBoard/1","doc":"","ref":"Evision.ArUco.html#estimatePoseBoard/1"},{"type":"function","title":"Evision.ArUco.estimatePoseBoard/7","doc":"estimatePoseBoard\n\n##### Positional Arguments\n- **corners**: `[Evision.Mat]`\n- **ids**: `Evision.Mat`\n- **board**: `Board`\n- **cameraMatrix**: `Evision.Mat`\n- **distCoeffs**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useExtrinsicGuess**: `bool`.\n\n##### Return\n- **retval**: `integer()`\n- **rvec**: `Evision.Mat.t()`\n- **tvec**: `Evision.Mat.t()`\n\n@deprecated Use Board::matchImagePoints and cv::solvePnP\n\nPython prototype (for reference only):\n```python3\nestimatePoseBoard(corners, ids, board, cameraMatrix, distCoeffs, rvec, tvec[, useExtrinsicGuess]) -> retval, rvec, tvec\n```","ref":"Evision.ArUco.html#estimatePoseBoard/7"},{"type":"function","title":"Evision.ArUco.estimatePoseBoard/8","doc":"estimatePoseBoard\n\n##### Positional Arguments\n- **corners**: `[Evision.Mat]`\n- **ids**: `Evision.Mat`\n- **board**: `Board`\n- **cameraMatrix**: `Evision.Mat`\n- **distCoeffs**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useExtrinsicGuess**: `bool`.\n\n##### Return\n- **retval**: `integer()`\n- **rvec**: `Evision.Mat.t()`\n- **tvec**: `Evision.Mat.t()`\n\n@deprecated Use Board::matchImagePoints and cv::solvePnP\n\nPython prototype (for reference only):\n```python3\nestimatePoseBoard(corners, ids, board, cameraMatrix, distCoeffs, rvec, tvec[, useExtrinsicGuess]) -> retval, rvec, tvec\n```","ref":"Evision.ArUco.html#estimatePoseBoard/8"},{"type":"function","title":"Evision.ArUco.estimatePoseCharucoBoard/1","doc":"","ref":"Evision.ArUco.html#estimatePoseCharucoBoard/1"},{"type":"function","title":"Evision.ArUco.estimatePoseCharucoBoard/7","doc":"Pose estimation for a ChArUco board given some of their corners\n\n##### Positional Arguments\n- **charucoCorners**: `Evision.Mat`.\n\n  vector of detected charuco corners\n\n- **charucoIds**: `Evision.Mat`.\n\n  list of identifiers for each corner in charucoCorners\n\n- **board**: `Evision.ArUco.CharucoBoard`.\n\n  layout of ChArUco board.\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  input 3x3 floating-point camera matrix\n  \\f$A = \\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$\n\n- **distCoeffs**: `Evision.Mat`.\n\n  vector of distortion coefficients\n  \\f$(k_1, k_2, p_1, p_2[, k_3[, k_4, k_5, k_6],[s_1, s_2, s_3, s_4]])\\f$ of 4, 5, 8 or 12 elements\n\n##### Keyword Arguments\n- **useExtrinsicGuess**: `bool`.\n\n  defines whether initial guess for \\b rvec and \\b tvec will be used or not.\n\n##### Return\n- **retval**: `bool`\n- **rvec**: `Evision.Mat.t()`.\n\n  Output vector (e.g. cv::Mat) corresponding to the rotation vector of the board\n  (see cv::Rodrigues).\n\n- **tvec**: `Evision.Mat.t()`.\n\n  Output vector (e.g. cv::Mat) corresponding to the translation vector of the board.\n\n This function estimates a Charuco board pose from some detected corners.\n The function checks if the input corners are enough and valid to perform pose estimation.\n If pose estimation is valid, returns true, else returns false.\n@deprecated Use CharucoBoard::matchImagePoints and cv::solvePnP\n@sa use cv::drawFrameAxes to get world coordinate system axis for object points\n\nPython prototype (for reference only):\n```python3\nestimatePoseCharucoBoard(charucoCorners, charucoIds, board, cameraMatrix, distCoeffs, rvec, tvec[, useExtrinsicGuess]) -> retval, rvec, tvec\n```","ref":"Evision.ArUco.html#estimatePoseCharucoBoard/7"},{"type":"function","title":"Evision.ArUco.estimatePoseCharucoBoard/8","doc":"Pose estimation for a ChArUco board given some of their corners\n\n##### Positional Arguments\n- **charucoCorners**: `Evision.Mat`.\n\n  vector of detected charuco corners\n\n- **charucoIds**: `Evision.Mat`.\n\n  list of identifiers for each corner in charucoCorners\n\n- **board**: `Evision.ArUco.CharucoBoard`.\n\n  layout of ChArUco board.\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  input 3x3 floating-point camera matrix\n  \\f$A = \\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$\n\n- **distCoeffs**: `Evision.Mat`.\n\n  vector of distortion coefficients\n  \\f$(k_1, k_2, p_1, p_2[, k_3[, k_4, k_5, k_6],[s_1, s_2, s_3, s_4]])\\f$ of 4, 5, 8 or 12 elements\n\n##### Keyword Arguments\n- **useExtrinsicGuess**: `bool`.\n\n  defines whether initial guess for \\b rvec and \\b tvec will be used or not.\n\n##### Return\n- **retval**: `bool`\n- **rvec**: `Evision.Mat.t()`.\n\n  Output vector (e.g. cv::Mat) corresponding to the rotation vector of the board\n  (see cv::Rodrigues).\n\n- **tvec**: `Evision.Mat.t()`.\n\n  Output vector (e.g. cv::Mat) corresponding to the translation vector of the board.\n\n This function estimates a Charuco board pose from some detected corners.\n The function checks if the input corners are enough and valid to perform pose estimation.\n If pose estimation is valid, returns true, else returns false.\n@deprecated Use CharucoBoard::matchImagePoints and cv::solvePnP\n@sa use cv::drawFrameAxes to get world coordinate system axis for object points\n\nPython prototype (for reference only):\n```python3\nestimatePoseCharucoBoard(charucoCorners, charucoIds, board, cameraMatrix, distCoeffs, rvec, tvec[, useExtrinsicGuess]) -> retval, rvec, tvec\n```","ref":"Evision.ArUco.html#estimatePoseCharucoBoard/8"},{"type":"function","title":"Evision.ArUco.estimatePoseSingleMarkers/1","doc":"","ref":"Evision.ArUco.html#estimatePoseSingleMarkers/1"},{"type":"function","title":"Evision.ArUco.estimatePoseSingleMarkers/4","doc":"estimatePoseSingleMarkers\n\n##### Positional Arguments\n- **corners**: `[Evision.Mat]`\n- **markerLength**: `float`\n- **cameraMatrix**: `Evision.Mat`\n- **distCoeffs**: `Evision.Mat`\n\n##### Keyword Arguments\n- **estimateParameters**: `EstimateParameters`.\n\n##### Return\n- **rvecs**: `Evision.Mat.t()`.\n- **tvecs**: `Evision.Mat.t()`.\n- **objPoints**: `Evision.Mat.t()`.\n\n@deprecated Use cv::solvePnP\n\nPython prototype (for reference only):\n```python3\nestimatePoseSingleMarkers(corners, markerLength, cameraMatrix, distCoeffs[, rvecs[, tvecs[, objPoints[, estimateParameters]]]]) -> rvecs, tvecs, objPoints\n```","ref":"Evision.ArUco.html#estimatePoseSingleMarkers/4"},{"type":"function","title":"Evision.ArUco.estimatePoseSingleMarkers/5","doc":"estimatePoseSingleMarkers\n\n##### Positional Arguments\n- **corners**: `[Evision.Mat]`\n- **markerLength**: `float`\n- **cameraMatrix**: `Evision.Mat`\n- **distCoeffs**: `Evision.Mat`\n\n##### Keyword Arguments\n- **estimateParameters**: `EstimateParameters`.\n\n##### Return\n- **rvecs**: `Evision.Mat.t()`.\n- **tvecs**: `Evision.Mat.t()`.\n- **objPoints**: `Evision.Mat.t()`.\n\n@deprecated Use cv::solvePnP\n\nPython prototype (for reference only):\n```python3\nestimatePoseSingleMarkers(corners, markerLength, cameraMatrix, distCoeffs[, rvecs[, tvecs[, objPoints[, estimateParameters]]]]) -> rvecs, tvecs, objPoints\n```","ref":"Evision.ArUco.html#estimatePoseSingleMarkers/5"},{"type":"function","title":"Evision.ArUco.extendDictionary/1","doc":"","ref":"Evision.ArUco.html#extendDictionary/1"},{"type":"function","title":"Evision.ArUco.extendDictionary/2","doc":"Extend base dictionary by new nMarkers\n\n##### Positional Arguments\n- **nMarkers**: `integer()`.\n\n  number of markers in the dictionary\n\n- **markerSize**: `integer()`.\n\n  number of bits per dimension of each markers\n\n##### Keyword Arguments\n- **baseDictionary**: `Dictionary`.\n\n  Include the markers in this dictionary at the beginning (optional)\n\n- **randomSeed**: `integer()`.\n\n  a user supplied seed for theRNG()\n\n##### Return\n- **retval**: `Dictionary`\n\n This function creates a new dictionary composed by nMarkers markers and each markers composed\n by markerSize x markerSize bits. If baseDictionary is provided, its markers are directly\n included and the rest are generated based on them. If the size of baseDictionary is higher\n than nMarkers, only the first nMarkers in baseDictionary are taken and no new marker is added.\n\nPython prototype (for reference only):\n```python3\nextendDictionary(nMarkers, markerSize[, baseDictionary[, randomSeed]]) -> retval\n```","ref":"Evision.ArUco.html#extendDictionary/2"},{"type":"function","title":"Evision.ArUco.extendDictionary/3","doc":"Extend base dictionary by new nMarkers\n\n##### Positional Arguments\n- **nMarkers**: `integer()`.\n\n  number of markers in the dictionary\n\n- **markerSize**: `integer()`.\n\n  number of bits per dimension of each markers\n\n##### Keyword Arguments\n- **baseDictionary**: `Dictionary`.\n\n  Include the markers in this dictionary at the beginning (optional)\n\n- **randomSeed**: `integer()`.\n\n  a user supplied seed for theRNG()\n\n##### Return\n- **retval**: `Dictionary`\n\n This function creates a new dictionary composed by nMarkers markers and each markers composed\n by markerSize x markerSize bits. If baseDictionary is provided, its markers are directly\n included and the rest are generated based on them. If the size of baseDictionary is higher\n than nMarkers, only the first nMarkers in baseDictionary are taken and no new marker is added.\n\nPython prototype (for reference only):\n```python3\nextendDictionary(nMarkers, markerSize[, baseDictionary[, randomSeed]]) -> retval\n```","ref":"Evision.ArUco.html#extendDictionary/3"},{"type":"function","title":"Evision.ArUco.generateImageMarker/1","doc":"","ref":"Evision.ArUco.html#generateImageMarker/1"},{"type":"function","title":"Evision.ArUco.generateImageMarker/3","doc":"Generate a canonical marker image\n\n##### Positional Arguments\n- **dictionary**: `Dictionary`.\n\n  dictionary of markers indicating the type of markers\n\n- **id**: `integer()`.\n\n  identifier of the marker that will be returned. It has to be a valid id in the specified dictionary.\n\n- **sidePixels**: `integer()`.\n\n  size of the image in pixels\n\n##### Keyword Arguments\n- **borderBits**: `integer()`.\n\n  width of the marker border.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  output image with the marker\n\n This function returns a marker image in its canonical form (i.e. ready to be printed)\n\nPython prototype (for reference only):\n```python3\ngenerateImageMarker(dictionary, id, sidePixels[, img[, borderBits]]) -> img\n```","ref":"Evision.ArUco.html#generateImageMarker/3"},{"type":"function","title":"Evision.ArUco.generateImageMarker/4","doc":"Generate a canonical marker image\n\n##### Positional Arguments\n- **dictionary**: `Dictionary`.\n\n  dictionary of markers indicating the type of markers\n\n- **id**: `integer()`.\n\n  identifier of the marker that will be returned. It has to be a valid id in the specified dictionary.\n\n- **sidePixels**: `integer()`.\n\n  size of the image in pixels\n\n##### Keyword Arguments\n- **borderBits**: `integer()`.\n\n  width of the marker border.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  output image with the marker\n\n This function returns a marker image in its canonical form (i.e. ready to be printed)\n\nPython prototype (for reference only):\n```python3\ngenerateImageMarker(dictionary, id, sidePixels[, img[, borderBits]]) -> img\n```","ref":"Evision.ArUco.html#generateImageMarker/4"},{"type":"function","title":"Evision.ArUco.getBoardObjectAndImagePoints/1","doc":"","ref":"Evision.ArUco.html#getBoardObjectAndImagePoints/1"},{"type":"function","title":"Evision.ArUco.getBoardObjectAndImagePoints/3","doc":"get board object and image points\n\n##### Positional Arguments\n- **board**: `Board`\n- **detectedCorners**: `[Evision.Mat]`\n- **detectedIds**: `Evision.Mat`\n\n##### Return\n- **objPoints**: `Evision.Mat.t()`.\n- **imgPoints**: `Evision.Mat.t()`.\n\n@deprecated Use Board::matchImagePoints\n\nPython prototype (for reference only):\n```python3\ngetBoardObjectAndImagePoints(board, detectedCorners, detectedIds[, objPoints[, imgPoints]]) -> objPoints, imgPoints\n```","ref":"Evision.ArUco.html#getBoardObjectAndImagePoints/3"},{"type":"function","title":"Evision.ArUco.getBoardObjectAndImagePoints/4","doc":"get board object and image points\n\n##### Positional Arguments\n- **board**: `Board`\n- **detectedCorners**: `[Evision.Mat]`\n- **detectedIds**: `Evision.Mat`\n\n##### Return\n- **objPoints**: `Evision.Mat.t()`.\n- **imgPoints**: `Evision.Mat.t()`.\n\n@deprecated Use Board::matchImagePoints\n\nPython prototype (for reference only):\n```python3\ngetBoardObjectAndImagePoints(board, detectedCorners, detectedIds[, objPoints[, imgPoints]]) -> objPoints, imgPoints\n```","ref":"Evision.ArUco.html#getBoardObjectAndImagePoints/4"},{"type":"function","title":"Evision.ArUco.getPredefinedDictionary/1","doc":"Returns one of the predefined dictionaries referenced by DICT_*.\n\n##### Positional Arguments\n- **dict**: `integer()`\n\n##### Return\n- **retval**: `Dictionary`\n\nPython prototype (for reference only):\n```python3\ngetPredefinedDictionary(dict) -> retval\n```","ref":"Evision.ArUco.html#getPredefinedDictionary/1"},{"type":"function","title":"Evision.ArUco.interpolateCornersCharuco/1","doc":"","ref":"Evision.ArUco.html#interpolateCornersCharuco/1"},{"type":"function","title":"Evision.ArUco.interpolateCornersCharuco/4","doc":"Interpolate position of ChArUco board corners\n\n##### Positional Arguments\n- **markerCorners**: `[Evision.Mat]`.\n\n  vector of already detected markers corners. For each marker, its four\n  corners are provided, (e.g std::vector  > ). For N detected markers, the\n  dimensions of this array should be Nx4. The order of the corners should be clockwise.\n\n- **markerIds**: `Evision.Mat`.\n\n  list of identifiers for each marker in corners\n\n- **image**: `Evision.Mat`.\n\n  input image necesary for corner refinement. Note that markers are not detected and\n  should be sent in corners and ids parameters.\n\n- **board**: `Evision.ArUco.CharucoBoard`.\n\n  layout of ChArUco board.\n\n##### Keyword Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  optional 3x3 floating-point camera matrix\n  \\f$A = \\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$\n\n- **distCoeffs**: `Evision.Mat`.\n\n  optional vector of distortion coefficients\n  \\f$(k_1, k_2, p_1, p_2[, k_3[, k_4, k_5, k_6],[s_1, s_2, s_3, s_4]])\\f$ of 4, 5, 8 or 12 elements\n\n- **minMarkers**: `integer()`.\n\n  number of adjacent markers that must be detected to return a charuco corner\n\n##### Return\n- **retval**: `integer()`\n- **charucoCorners**: `Evision.Mat.t()`.\n\n  interpolated chessboard corners\n\n- **charucoIds**: `Evision.Mat.t()`.\n\n  interpolated chessboard corners identifiers\n\n This function receives the detected markers and returns the 2D position of the chessboard corners\n from a ChArUco board using the detected Aruco markers. If camera parameters are provided,\n the process is based in an approximated pose estimation, else it is based on local homography.\n Only visible corners are returned. For each corner, its corresponding identifier is\n also returned in charucoIds.\n The function returns the number of interpolated corners.\n@deprecated Use CharucoDetector::detectBoard\n\nPython prototype (for reference only):\n```python3\ninterpolateCornersCharuco(markerCorners, markerIds, image, board[, charucoCorners[, charucoIds[, cameraMatrix[, distCoeffs[, minMarkers]]]]]) -> retval, charucoCorners, charucoIds\n```","ref":"Evision.ArUco.html#interpolateCornersCharuco/4"},{"type":"function","title":"Evision.ArUco.interpolateCornersCharuco/5","doc":"Interpolate position of ChArUco board corners\n\n##### Positional Arguments\n- **markerCorners**: `[Evision.Mat]`.\n\n  vector of already detected markers corners. For each marker, its four\n  corners are provided, (e.g std::vector  > ). For N detected markers, the\n  dimensions of this array should be Nx4. The order of the corners should be clockwise.\n\n- **markerIds**: `Evision.Mat`.\n\n  list of identifiers for each marker in corners\n\n- **image**: `Evision.Mat`.\n\n  input image necesary for corner refinement. Note that markers are not detected and\n  should be sent in corners and ids parameters.\n\n- **board**: `Evision.ArUco.CharucoBoard`.\n\n  layout of ChArUco board.\n\n##### Keyword Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  optional 3x3 floating-point camera matrix\n  \\f$A = \\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$\n\n- **distCoeffs**: `Evision.Mat`.\n\n  optional vector of distortion coefficients\n  \\f$(k_1, k_2, p_1, p_2[, k_3[, k_4, k_5, k_6],[s_1, s_2, s_3, s_4]])\\f$ of 4, 5, 8 or 12 elements\n\n- **minMarkers**: `integer()`.\n\n  number of adjacent markers that must be detected to return a charuco corner\n\n##### Return\n- **retval**: `integer()`\n- **charucoCorners**: `Evision.Mat.t()`.\n\n  interpolated chessboard corners\n\n- **charucoIds**: `Evision.Mat.t()`.\n\n  interpolated chessboard corners identifiers\n\n This function receives the detected markers and returns the 2D position of the chessboard corners\n from a ChArUco board using the detected Aruco markers. If camera parameters are provided,\n the process is based in an approximated pose estimation, else it is based on local homography.\n Only visible corners are returned. For each corner, its corresponding identifier is\n also returned in charucoIds.\n The function returns the number of interpolated corners.\n@deprecated Use CharucoDetector::detectBoard\n\nPython prototype (for reference only):\n```python3\ninterpolateCornersCharuco(markerCorners, markerIds, image, board[, charucoCorners[, charucoIds[, cameraMatrix[, distCoeffs[, minMarkers]]]]]) -> retval, charucoCorners, charucoIds\n```","ref":"Evision.ArUco.html#interpolateCornersCharuco/5"},{"type":"function","title":"Evision.ArUco.refineDetectedMarkers/1","doc":"","ref":"Evision.ArUco.html#refineDetectedMarkers/1"},{"type":"function","title":"Evision.ArUco.refineDetectedMarkers/5","doc":"refine detected markers\n\n##### Positional Arguments\n- **image**: `Evision.Mat`\n- **board**: `Board`\n\n##### Keyword Arguments\n- **cameraMatrix**: `Evision.Mat`.\n- **distCoeffs**: `Evision.Mat`.\n- **minRepDistance**: `float`.\n- **errorCorrectionRate**: `float`.\n- **checkAllOrders**: `bool`.\n- **parameters**: `DetectorParameters`.\n\n##### Return\n- **detectedCorners**: `[Evision.Mat]`\n- **detectedIds**: `Evision.Mat.t()`\n- **rejectedCorners**: `[Evision.Mat]`\n- **recoveredIdxs**: `Evision.Mat.t()`.\n\n@deprecated Use class ArucoDetector::refineDetectedMarkers\n\nPython prototype (for reference only):\n```python3\nrefineDetectedMarkers(image, board, detectedCorners, detectedIds, rejectedCorners[, cameraMatrix[, distCoeffs[, minRepDistance[, errorCorrectionRate[, checkAllOrders[, recoveredIdxs[, parameters]]]]]]]) -> detectedCorners, detectedIds, rejectedCorners, recoveredIdxs\n```","ref":"Evision.ArUco.html#refineDetectedMarkers/5"},{"type":"function","title":"Evision.ArUco.refineDetectedMarkers/6","doc":"refine detected markers\n\n##### Positional Arguments\n- **image**: `Evision.Mat`\n- **board**: `Board`\n\n##### Keyword Arguments\n- **cameraMatrix**: `Evision.Mat`.\n- **distCoeffs**: `Evision.Mat`.\n- **minRepDistance**: `float`.\n- **errorCorrectionRate**: `float`.\n- **checkAllOrders**: `bool`.\n- **parameters**: `DetectorParameters`.\n\n##### Return\n- **detectedCorners**: `[Evision.Mat]`\n- **detectedIds**: `Evision.Mat.t()`\n- **rejectedCorners**: `[Evision.Mat]`\n- **recoveredIdxs**: `Evision.Mat.t()`.\n\n@deprecated Use class ArucoDetector::refineDetectedMarkers\n\nPython prototype (for reference only):\n```python3\nrefineDetectedMarkers(image, board, detectedCorners, detectedIds, rejectedCorners[, cameraMatrix[, distCoeffs[, minRepDistance[, errorCorrectionRate[, checkAllOrders[, recoveredIdxs[, parameters]]]]]]]) -> detectedCorners, detectedIds, rejectedCorners, recoveredIdxs\n```","ref":"Evision.ArUco.html#refineDetectedMarkers/6"},{"type":"function","title":"Evision.ArUco.testCharucoCornersCollinear/1","doc":"","ref":"Evision.ArUco.html#testCharucoCornersCollinear/1"},{"type":"function","title":"Evision.ArUco.testCharucoCornersCollinear/2","doc":"testCharucoCornersCollinear\n\n##### Positional Arguments\n- **board**: `Evision.ArUco.CharucoBoard`\n- **charucoIds**: `Evision.Mat`\n\n##### Return\n- **retval**: `bool`\n\n@deprecated Use CharucoBoard::checkCharucoCornersCollinear\n\nPython prototype (for reference only):\n```python3\ntestCharucoCornersCollinear(board, charucoIds) -> retval\n```","ref":"Evision.ArUco.html#testCharucoCornersCollinear/2"},{"type":"type","title":"Evision.ArUco.t/0","doc":"Type that represents an `ArUco` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ArUco.html#t:t/0"},{"type":"module","title":"Evision.ArUco.ArucoDetector","doc":"","ref":"Evision.ArUco.ArucoDetector.html"},{"type":"function","title":"Evision.ArUco.ArucoDetector.arucoDetector/0","doc":"Basic ArucoDetector constructor\n##### Keyword Arguments\n- **dictionary**: `Dictionary`.\n\n  indicates the type of markers that will be searched\n\n- **detectorParams**: `DetectorParameters`.\n\n  marker detection parameters\n\n- **refineParams**: `RefineParameters`.\n\n  marker refine detection parameters\n\n##### Return\n- **self**: `Evision.ArUco.ArucoDetector.t()`\n\nPython prototype (for reference only):\n```python3\nArucoDetector([, dictionary[, detectorParams[, refineParams]]]) ->  \n```","ref":"Evision.ArUco.ArucoDetector.html#arucoDetector/0"},{"type":"function","title":"Evision.ArUco.ArucoDetector.arucoDetector/1","doc":"Basic ArucoDetector constructor\n##### Keyword Arguments\n- **dictionary**: `Dictionary`.\n\n  indicates the type of markers that will be searched\n\n- **detectorParams**: `DetectorParameters`.\n\n  marker detection parameters\n\n- **refineParams**: `RefineParameters`.\n\n  marker refine detection parameters\n\n##### Return\n- **self**: `Evision.ArUco.ArucoDetector.t()`\n\nPython prototype (for reference only):\n```python3\nArucoDetector([, dictionary[, detectorParams[, refineParams]]]) ->  \n```","ref":"Evision.ArUco.ArucoDetector.html#arucoDetector/1"},{"type":"function","title":"Evision.ArUco.ArucoDetector.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.ArucoDetector.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.ArUco.ArucoDetector.html#clear/1"},{"type":"function","title":"Evision.ArUco.ArucoDetector.detectMarkers/1","doc":"","ref":"Evision.ArUco.ArucoDetector.html#detectMarkers/1"},{"type":"function","title":"Evision.ArUco.ArucoDetector.detectMarkers/2","doc":"Basic marker detection\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.ArucoDetector.t()`\n- **image**: `Evision.Mat`.\n\n  input image\n\n##### Return\n- **corners**: `[Evision.Mat]`.\n\n  vector of detected marker corners. For each marker, its four corners\n  are provided, (e.g std::vector  > ). For N detected markers,\n  the dimensions of this array is Nx4. The order of the corners is clockwise.\n\n- **ids**: `Evision.Mat.t()`.\n\n  vector of identifiers of the detected markers. The identifier is of type int\n  (e.g. std::vector ). For N detected markers, the size of ids is also N.\n  The identifiers have the same order than the markers in the imgPoints array.\n\n- **rejectedImgPoints**: `[Evision.Mat]`.\n\n  contains the imgPoints of those squares whose inner code has not a\n  correct codification. Useful for debugging purposes.\n\n Performs marker detection in the input image. Only markers included in the specific dictionary\n are searched. For each detected marker, it returns the 2D position of its corner in the image\n and its corresponding identifier.\n Note that this function does not perform pose estimation.\n**Note**: The function does not correct lens distortion or takes it into account. It's recommended to undistort\n input image with corresponding camera model, if camera parameters are known\n@sa undistort, estimatePoseSingleMarkers,  estimatePoseBoard\n\nPython prototype (for reference only):\n```python3\ndetectMarkers(image[, corners[, ids[, rejectedImgPoints]]]) -> corners, ids, rejectedImgPoints\n```","ref":"Evision.ArUco.ArucoDetector.html#detectMarkers/2"},{"type":"function","title":"Evision.ArUco.ArucoDetector.detectMarkers/3","doc":"Basic marker detection\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.ArucoDetector.t()`\n- **image**: `Evision.Mat`.\n\n  input image\n\n##### Return\n- **corners**: `[Evision.Mat]`.\n\n  vector of detected marker corners. For each marker, its four corners\n  are provided, (e.g std::vector  > ). For N detected markers,\n  the dimensions of this array is Nx4. The order of the corners is clockwise.\n\n- **ids**: `Evision.Mat.t()`.\n\n  vector of identifiers of the detected markers. The identifier is of type int\n  (e.g. std::vector ). For N detected markers, the size of ids is also N.\n  The identifiers have the same order than the markers in the imgPoints array.\n\n- **rejectedImgPoints**: `[Evision.Mat]`.\n\n  contains the imgPoints of those squares whose inner code has not a\n  correct codification. Useful for debugging purposes.\n\n Performs marker detection in the input image. Only markers included in the specific dictionary\n are searched. For each detected marker, it returns the 2D position of its corner in the image\n and its corresponding identifier.\n Note that this function does not perform pose estimation.\n**Note**: The function does not correct lens distortion or takes it into account. It's recommended to undistort\n input image with corresponding camera model, if camera parameters are known\n@sa undistort, estimatePoseSingleMarkers,  estimatePoseBoard\n\nPython prototype (for reference only):\n```python3\ndetectMarkers(image[, corners[, ids[, rejectedImgPoints]]]) -> corners, ids, rejectedImgPoints\n```","ref":"Evision.ArUco.ArucoDetector.html#detectMarkers/3"},{"type":"function","title":"Evision.ArUco.ArucoDetector.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.ArucoDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.ArUco.ArucoDetector.html#empty/1"},{"type":"function","title":"Evision.ArUco.ArucoDetector.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.ArucoDetector.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.ArUco.ArucoDetector.html#getDefaultName/1"},{"type":"function","title":"Evision.ArUco.ArucoDetector.getDetectorParameters/1","doc":"getDetectorParameters\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.ArucoDetector.t()`\n\n##### Return\n- **retval**: `DetectorParameters`\n\nPython prototype (for reference only):\n```python3\ngetDetectorParameters() -> retval\n```","ref":"Evision.ArUco.ArucoDetector.html#getDetectorParameters/1"},{"type":"function","title":"Evision.ArUco.ArucoDetector.getDictionary/1","doc":"getDictionary\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.ArucoDetector.t()`\n\n##### Return\n- **retval**: `Dictionary`\n\nPython prototype (for reference only):\n```python3\ngetDictionary() -> retval\n```","ref":"Evision.ArUco.ArucoDetector.html#getDictionary/1"},{"type":"function","title":"Evision.ArUco.ArucoDetector.getRefineParameters/1","doc":"getRefineParameters\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.ArucoDetector.t()`\n\n##### Return\n- **retval**: `RefineParameters`\n\nPython prototype (for reference only):\n```python3\ngetRefineParameters() -> retval\n```","ref":"Evision.ArUco.ArucoDetector.html#getRefineParameters/1"},{"type":"function","title":"Evision.ArUco.ArucoDetector.read/1","doc":"","ref":"Evision.ArUco.ArucoDetector.html#read/1"},{"type":"function","title":"Evision.ArUco.ArucoDetector.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.ArucoDetector.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.ArUco.ArucoDetector.html#read/2"},{"type":"function","title":"Evision.ArUco.ArucoDetector.refineDetectedMarkers/1","doc":"","ref":"Evision.ArUco.ArucoDetector.html#refineDetectedMarkers/1"},{"type":"function","title":"Evision.ArUco.ArucoDetector.refineDetectedMarkers/6","doc":"Refine not detected markers based on the already detected and the board layout\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.ArucoDetector.t()`\n- **image**: `Evision.Mat`.\n\n  input image\n\n- **board**: `Board`.\n\n  layout of markers in the board.\n\n##### Keyword Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  optional input 3x3 floating-point camera matrix\n  \\f$A = \\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$\n\n- **distCoeffs**: `Evision.Mat`.\n\n  optional vector of distortion coefficients\n  \\f$(k_1, k_2, p_1, p_2[, k_3[, k_4, k_5, k_6],[s_1, s_2, s_3, s_4]])\\f$ of 4, 5, 8 or 12 elements\n\n##### Return\n- **detectedCorners**: `[Evision.Mat]`.\n\n  vector of already detected marker corners.\n\n- **detectedIds**: `Evision.Mat.t()`.\n\n  vector of already detected marker identifiers.\n\n- **rejectedCorners**: `[Evision.Mat]`.\n\n  vector of rejected candidates during the marker detection process.\n\n- **recoveredIdxs**: `Evision.Mat.t()`.\n\n  Optional array to returns the indexes of the recovered candidates in the\n  original rejectedCorners array.\n\n This function tries to find markers that were not detected in the basic detecMarkers function.\n First, based on the current detected marker and the board layout, the function interpolates\n the position of the missing markers. Then it tries to find correspondence between the reprojected\n markers and the rejected candidates based on the minRepDistance and errorCorrectionRate parameters.\n If camera parameters and distortion coefficients are provided, missing markers are reprojected\n using projectPoint function. If not, missing marker projections are interpolated using global\n homography, and all the marker corners in the board must have the same Z coordinate.\n\nPython prototype (for reference only):\n```python3\nrefineDetectedMarkers(image, board, detectedCorners, detectedIds, rejectedCorners[, cameraMatrix[, distCoeffs[, recoveredIdxs]]]) -> detectedCorners, detectedIds, rejectedCorners, recoveredIdxs\n```","ref":"Evision.ArUco.ArucoDetector.html#refineDetectedMarkers/6"},{"type":"function","title":"Evision.ArUco.ArucoDetector.refineDetectedMarkers/7","doc":"Refine not detected markers based on the already detected and the board layout\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.ArucoDetector.t()`\n- **image**: `Evision.Mat`.\n\n  input image\n\n- **board**: `Board`.\n\n  layout of markers in the board.\n\n##### Keyword Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  optional input 3x3 floating-point camera matrix\n  \\f$A = \\vecthreethree{f_x}{0}{c_x}{0}{f_y}{c_y}{0}{0}{1}\\f$\n\n- **distCoeffs**: `Evision.Mat`.\n\n  optional vector of distortion coefficients\n  \\f$(k_1, k_2, p_1, p_2[, k_3[, k_4, k_5, k_6],[s_1, s_2, s_3, s_4]])\\f$ of 4, 5, 8 or 12 elements\n\n##### Return\n- **detectedCorners**: `[Evision.Mat]`.\n\n  vector of already detected marker corners.\n\n- **detectedIds**: `Evision.Mat.t()`.\n\n  vector of already detected marker identifiers.\n\n- **rejectedCorners**: `[Evision.Mat]`.\n\n  vector of rejected candidates during the marker detection process.\n\n- **recoveredIdxs**: `Evision.Mat.t()`.\n\n  Optional array to returns the indexes of the recovered candidates in the\n  original rejectedCorners array.\n\n This function tries to find markers that were not detected in the basic detecMarkers function.\n First, based on the current detected marker and the board layout, the function interpolates\n the position of the missing markers. Then it tries to find correspondence between the reprojected\n markers and the rejected candidates based on the minRepDistance and errorCorrectionRate parameters.\n If camera parameters and distortion coefficients are provided, missing markers are reprojected\n using projectPoint function. If not, missing marker projections are interpolated using global\n homography, and all the marker corners in the board must have the same Z coordinate.\n\nPython prototype (for reference only):\n```python3\nrefineDetectedMarkers(image, board, detectedCorners, detectedIds, rejectedCorners[, cameraMatrix[, distCoeffs[, recoveredIdxs]]]) -> detectedCorners, detectedIds, rejectedCorners, recoveredIdxs\n```","ref":"Evision.ArUco.ArucoDetector.html#refineDetectedMarkers/7"},{"type":"function","title":"Evision.ArUco.ArucoDetector.save/1","doc":"","ref":"Evision.ArUco.ArucoDetector.html#save/1"},{"type":"function","title":"Evision.ArUco.ArucoDetector.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.ArucoDetector.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.ArUco.ArucoDetector.html#save/2"},{"type":"function","title":"Evision.ArUco.ArucoDetector.setDetectorParameters/1","doc":"","ref":"Evision.ArUco.ArucoDetector.html#setDetectorParameters/1"},{"type":"function","title":"Evision.ArUco.ArucoDetector.setDetectorParameters/2","doc":"setDetectorParameters\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.ArucoDetector.t()`\n- **detectorParameters**: `DetectorParameters`\n\nPython prototype (for reference only):\n```python3\nsetDetectorParameters(detectorParameters) -> None\n```","ref":"Evision.ArUco.ArucoDetector.html#setDetectorParameters/2"},{"type":"function","title":"Evision.ArUco.ArucoDetector.setDictionary/1","doc":"","ref":"Evision.ArUco.ArucoDetector.html#setDictionary/1"},{"type":"function","title":"Evision.ArUco.ArucoDetector.setDictionary/2","doc":"setDictionary\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.ArucoDetector.t()`\n- **dictionary**: `Dictionary`\n\nPython prototype (for reference only):\n```python3\nsetDictionary(dictionary) -> None\n```","ref":"Evision.ArUco.ArucoDetector.html#setDictionary/2"},{"type":"function","title":"Evision.ArUco.ArucoDetector.setRefineParameters/1","doc":"","ref":"Evision.ArUco.ArucoDetector.html#setRefineParameters/1"},{"type":"function","title":"Evision.ArUco.ArucoDetector.setRefineParameters/2","doc":"setRefineParameters\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.ArucoDetector.t()`\n- **refineParameters**: `RefineParameters`\n\nPython prototype (for reference only):\n```python3\nsetRefineParameters(refineParameters) -> None\n```","ref":"Evision.ArUco.ArucoDetector.html#setRefineParameters/2"},{"type":"function","title":"Evision.ArUco.ArucoDetector.write/1","doc":"","ref":"Evision.ArUco.ArucoDetector.html#write/1"},{"type":"function","title":"Evision.ArUco.ArucoDetector.write/3","doc":"simplified API for language bindings\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.ArucoDetector.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.ArUco.ArucoDetector.html#write/3"},{"type":"type","title":"Evision.ArUco.ArucoDetector.t/0","doc":"Type that represents an `ArUco.ArucoDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ArUco.ArucoDetector.html#t:t/0"},{"type":"module","title":"Evision.ArUco.Board","doc":"","ref":"Evision.ArUco.Board.html"},{"type":"function","title":"Evision.ArUco.Board.board/1","doc":"","ref":"Evision.ArUco.Board.html#board/1"},{"type":"function","title":"Evision.ArUco.Board.board/3","doc":"Common Board constructor\n\n##### Positional Arguments\n- **objPoints**: `[Evision.Mat]`.\n\n  array of object points of all the marker corners in the board\n\n- **dictionary**: `Dictionary`.\n\n  the dictionary of markers employed for this board\n\n- **ids**: `Evision.Mat`.\n\n  vector of the identifiers of the markers in the board\n\n##### Return\n- **self**: `Board`\n\nPython prototype (for reference only):\n```python3\nBoard(objPoints, dictionary, ids) ->  \n```","ref":"Evision.ArUco.Board.html#board/3"},{"type":"function","title":"Evision.ArUco.Board.generateImage/1","doc":"","ref":"Evision.ArUco.Board.html#generateImage/1"},{"type":"function","title":"Evision.ArUco.Board.generateImage/2","doc":"Draw a planar board\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.Board.t()`\n- **outSize**: `Size`.\n\n  size of the output image in pixels.\n\n##### Keyword Arguments\n- **marginSize**: `integer()`.\n\n  minimum margins (in pixels) of the board in the output image\n\n- **borderBits**: `integer()`.\n\n  width of the marker borders.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  output image with the board. The size of this image will be outSize\n  and the board will be on the center, keeping the board proportions.\n\n This function return the image of the board, ready to be printed.\n\nPython prototype (for reference only):\n```python3\ngenerateImage(outSize[, img[, marginSize[, borderBits]]]) -> img\n```","ref":"Evision.ArUco.Board.html#generateImage/2"},{"type":"function","title":"Evision.ArUco.Board.generateImage/3","doc":"Draw a planar board\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.Board.t()`\n- **outSize**: `Size`.\n\n  size of the output image in pixels.\n\n##### Keyword Arguments\n- **marginSize**: `integer()`.\n\n  minimum margins (in pixels) of the board in the output image\n\n- **borderBits**: `integer()`.\n\n  width of the marker borders.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  output image with the board. The size of this image will be outSize\n  and the board will be on the center, keeping the board proportions.\n\n This function return the image of the board, ready to be printed.\n\nPython prototype (for reference only):\n```python3\ngenerateImage(outSize[, img[, marginSize[, borderBits]]]) -> img\n```","ref":"Evision.ArUco.Board.html#generateImage/3"},{"type":"function","title":"Evision.ArUco.Board.getDictionary/1","doc":"return the Dictionary of markers employed for this board\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.Board.t()`\n\n##### Return\n- **retval**: `Dictionary`\n\nPython prototype (for reference only):\n```python3\ngetDictionary() -> retval\n```","ref":"Evision.ArUco.Board.html#getDictionary/1"},{"type":"function","title":"Evision.ArUco.Board.getIds/1","doc":"vector of the identifiers of the markers in the board (should be the same size as objPoints)\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.Board.t()`\n\n##### Return\n- **retval**: `[integer()]`\n\n@return vector of the identifiers of the markers\n\nPython prototype (for reference only):\n```python3\ngetIds() -> retval\n```","ref":"Evision.ArUco.Board.html#getIds/1"},{"type":"function","title":"Evision.ArUco.Board.getObjPoints/1","doc":"return array of object points of all the marker corners in the board.\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.Board.t()`\n\n##### Return\n- **retval**: `[[Point3f]]`\n\n Each marker include its 4 corners in this order:\n- objPoints[i][0] - left-top point of i-th marker\n- objPoints[i][1] - right-top point of i-th marker\n- objPoints[i][2] - right-bottom point of i-th marker\n- objPoints[i][3] - left-bottom point of i-th marker\n\n Markers are placed in a certain order - row by row, left to right in every row. For M markers, the size is Mx4.\n\nPython prototype (for reference only):\n```python3\ngetObjPoints() -> retval\n```","ref":"Evision.ArUco.Board.html#getObjPoints/1"},{"type":"function","title":"Evision.ArUco.Board.getRightBottomCorner/1","doc":"get coordinate of the bottom right corner of the board, is set when calling the function create()\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.Board.t()`\n\n##### Return\n- **retval**: `Point3f`\n\nPython prototype (for reference only):\n```python3\ngetRightBottomCorner() -> retval\n```","ref":"Evision.ArUco.Board.html#getRightBottomCorner/1"},{"type":"function","title":"Evision.ArUco.Board.matchImagePoints/1","doc":"","ref":"Evision.ArUco.Board.html#matchImagePoints/1"},{"type":"function","title":"Evision.ArUco.Board.matchImagePoints/3","doc":"Given a board configuration and a set of detected markers, returns the corresponding\nimage points and object points, can be used in solvePnP()\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.Board.t()`\n- **detectedCorners**: `[Evision.Mat]`.\n\n  List of detected marker corners of the board.\n  For cv::Board and cv::GridBoard the method expects std::vector > or std::vector  with Aruco marker corners.\n  For cv::CharucoBoard the method expects std::vector  or Mat with ChAruco corners (chess board corners matched with Aruco markers).\n\n- **detectedIds**: `Evision.Mat`.\n\n  List of identifiers for each marker or charuco corner.\n  For any Board class the method expects std::vector  or Mat.\n\n##### Return\n- **objPoints**: `Evision.Mat.t()`.\n\n  Vector of marker points in the board coordinate space.\n  For any Board class the method expects std::vector  objectPoints or cv::Mat\n\n- **imgPoints**: `Evision.Mat.t()`.\n\n  Vector of marker points in the image coordinate space.\n  For any Board class the method expects std::vector  objectPoints or cv::Mat\n\n@sa solvePnP\n\nPython prototype (for reference only):\n```python3\nmatchImagePoints(detectedCorners, detectedIds[, objPoints[, imgPoints]]) -> objPoints, imgPoints\n```","ref":"Evision.ArUco.Board.html#matchImagePoints/3"},{"type":"function","title":"Evision.ArUco.Board.matchImagePoints/4","doc":"Given a board configuration and a set of detected markers, returns the corresponding\nimage points and object points, can be used in solvePnP()\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.Board.t()`\n- **detectedCorners**: `[Evision.Mat]`.\n\n  List of detected marker corners of the board.\n  For cv::Board and cv::GridBoard the method expects std::vector > or std::vector  with Aruco marker corners.\n  For cv::CharucoBoard the method expects std::vector  or Mat with ChAruco corners (chess board corners matched with Aruco markers).\n\n- **detectedIds**: `Evision.Mat`.\n\n  List of identifiers for each marker or charuco corner.\n  For any Board class the method expects std::vector  or Mat.\n\n##### Return\n- **objPoints**: `Evision.Mat.t()`.\n\n  Vector of marker points in the board coordinate space.\n  For any Board class the method expects std::vector  objectPoints or cv::Mat\n\n- **imgPoints**: `Evision.Mat.t()`.\n\n  Vector of marker points in the image coordinate space.\n  For any Board class the method expects std::vector  objectPoints or cv::Mat\n\n@sa solvePnP\n\nPython prototype (for reference only):\n```python3\nmatchImagePoints(detectedCorners, detectedIds[, objPoints[, imgPoints]]) -> objPoints, imgPoints\n```","ref":"Evision.ArUco.Board.html#matchImagePoints/4"},{"type":"type","title":"Evision.ArUco.Board.t/0","doc":"Type that represents an `ArUco.Board` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ArUco.Board.html#t:t/0"},{"type":"module","title":"Evision.ArUco.CharucoBoard","doc":"","ref":"Evision.ArUco.CharucoBoard.html"},{"type":"function","title":"Evision.ArUco.CharucoBoard.charucoBoard/1","doc":"","ref":"Evision.ArUco.CharucoBoard.html#charucoBoard/1"},{"type":"function","title":"Evision.ArUco.CharucoBoard.charucoBoard/4","doc":"CharucoBoard constructor\n\n##### Positional Arguments\n- **size**: `Size`.\n\n  number of chessboard squares in x and y directions\n\n- **squareLength**: `float`.\n\n  squareLength chessboard square side length (normally in meters)\n\n- **markerLength**: `float`.\n\n  marker side length (same unit than squareLength)\n\n- **dictionary**: `Dictionary`.\n\n  dictionary of markers indicating the type of markers\n\n##### Keyword Arguments\n- **ids**: `Evision.Mat`.\n\n  array of id used markers\n  The first markers in the dictionary are used to fill the white chessboard squares.\n\n##### Return\n- **self**: `Evision.ArUco.CharucoBoard.t()`\n\nPython prototype (for reference only):\n```python3\nCharucoBoard(size, squareLength, markerLength, dictionary[, ids]) ->  \n```","ref":"Evision.ArUco.CharucoBoard.html#charucoBoard/4"},{"type":"function","title":"Evision.ArUco.CharucoBoard.charucoBoard/5","doc":"CharucoBoard constructor\n\n##### Positional Arguments\n- **size**: `Size`.\n\n  number of chessboard squares in x and y directions\n\n- **squareLength**: `float`.\n\n  squareLength chessboard square side length (normally in meters)\n\n- **markerLength**: `float`.\n\n  marker side length (same unit than squareLength)\n\n- **dictionary**: `Dictionary`.\n\n  dictionary of markers indicating the type of markers\n\n##### Keyword Arguments\n- **ids**: `Evision.Mat`.\n\n  array of id used markers\n  The first markers in the dictionary are used to fill the white chessboard squares.\n\n##### Return\n- **self**: `Evision.ArUco.CharucoBoard.t()`\n\nPython prototype (for reference only):\n```python3\nCharucoBoard(size, squareLength, markerLength, dictionary[, ids]) ->  \n```","ref":"Evision.ArUco.CharucoBoard.html#charucoBoard/5"},{"type":"function","title":"Evision.ArUco.CharucoBoard.checkCharucoCornersCollinear/1","doc":"","ref":"Evision.ArUco.CharucoBoard.html#checkCharucoCornersCollinear/1"},{"type":"function","title":"Evision.ArUco.CharucoBoard.checkCharucoCornersCollinear/2","doc":"check whether the ChArUco markers are collinear\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoBoard.t()`\n- **charucoIds**: `Evision.Mat`.\n\n  list of identifiers for each corner in charucoCorners per frame.\n\n##### Return\n- **retval**: `bool`\n\n@return bool value, 1 (true) if detected corners form a line, 0 (false) if they do not.\n solvePnP, calibration functions will fail if the corners are collinear (true).\n The number of ids in charucoIDs should be <= the number of chessboard corners in the board.\n This functions checks whether the charuco corners are on a straight line (returns true, if so), or not (false).\n Axis parallel, as well as diagonal and other straight lines detected.  Degenerate cases:\n for number of charucoIDs <= 2,the function returns true.\n\nPython prototype (for reference only):\n```python3\ncheckCharucoCornersCollinear(charucoIds) -> retval\n```","ref":"Evision.ArUco.CharucoBoard.html#checkCharucoCornersCollinear/2"},{"type":"function","title":"Evision.ArUco.CharucoBoard.getChessboardCorners/1","doc":"get CharucoBoard::chessboardCorners\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoBoard.t()`\n\n##### Return\n- **retval**: `[Point3f]`\n\nPython prototype (for reference only):\n```python3\ngetChessboardCorners() -> retval\n```","ref":"Evision.ArUco.CharucoBoard.html#getChessboardCorners/1"},{"type":"function","title":"Evision.ArUco.CharucoBoard.getChessboardSize/1","doc":"getChessboardSize\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoBoard.t()`\n\n##### Return\n- **retval**: `Size`\n\nPython prototype (for reference only):\n```python3\ngetChessboardSize() -> retval\n```","ref":"Evision.ArUco.CharucoBoard.html#getChessboardSize/1"},{"type":"function","title":"Evision.ArUco.CharucoBoard.getLegacyPattern/1","doc":"getLegacyPattern\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoBoard.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetLegacyPattern() -> retval\n```","ref":"Evision.ArUco.CharucoBoard.html#getLegacyPattern/1"},{"type":"function","title":"Evision.ArUco.CharucoBoard.getMarkerLength/1","doc":"getMarkerLength\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoBoard.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetMarkerLength() -> retval\n```","ref":"Evision.ArUco.CharucoBoard.html#getMarkerLength/1"},{"type":"function","title":"Evision.ArUco.CharucoBoard.getSquareLength/1","doc":"getSquareLength\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoBoard.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetSquareLength() -> retval\n```","ref":"Evision.ArUco.CharucoBoard.html#getSquareLength/1"},{"type":"function","title":"Evision.ArUco.CharucoBoard.setLegacyPattern/1","doc":"","ref":"Evision.ArUco.CharucoBoard.html#setLegacyPattern/1"},{"type":"function","title":"Evision.ArUco.CharucoBoard.setLegacyPattern/2","doc":"set legacy chessboard pattern.\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoBoard.t()`\n- **legacyPattern**: `bool`\n\n Legacy setting creates chessboard patterns starting with a white box in the upper left corner\n if there is an even row count of chessboard boxes, otherwise it starts with a black box.\n This setting ensures compatibility to patterns created with OpenCV versions prior OpenCV 4.6.0.\n See https://github.com/opencv/opencv/issues/23152.\n Default value: false.\n\nPython prototype (for reference only):\n```python3\nsetLegacyPattern(legacyPattern) -> None\n```","ref":"Evision.ArUco.CharucoBoard.html#setLegacyPattern/2"},{"type":"type","title":"Evision.ArUco.CharucoBoard.t/0","doc":"Type that represents an `ArUco.CharucoBoard` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ArUco.CharucoBoard.html#t:t/0"},{"type":"module","title":"Evision.ArUco.CharucoDetector","doc":"","ref":"Evision.ArUco.CharucoDetector.html"},{"type":"function","title":"Evision.ArUco.CharucoDetector.charucoDetector/1","doc":"Basic CharucoDetector constructor\n\n##### Positional Arguments\n- **board**: `Evision.ArUco.CharucoBoard`.\n\n  ChAruco board\n\n##### Keyword Arguments\n- **charucoParams**: `CharucoParameters`.\n\n  charuco detection parameters\n\n- **detectorParams**: `DetectorParameters`.\n\n  marker detection parameters\n\n- **refineParams**: `RefineParameters`.\n\n  marker refine detection parameters\n\n##### Return\n- **self**: `CharucoDetector`\n\nPython prototype (for reference only):\n```python3\nCharucoDetector(board[, charucoParams[, detectorParams[, refineParams]]]) ->  \n```","ref":"Evision.ArUco.CharucoDetector.html#charucoDetector/1"},{"type":"function","title":"Evision.ArUco.CharucoDetector.charucoDetector/2","doc":"Basic CharucoDetector constructor\n\n##### Positional Arguments\n- **board**: `Evision.ArUco.CharucoBoard`.\n\n  ChAruco board\n\n##### Keyword Arguments\n- **charucoParams**: `CharucoParameters`.\n\n  charuco detection parameters\n\n- **detectorParams**: `DetectorParameters`.\n\n  marker detection parameters\n\n- **refineParams**: `RefineParameters`.\n\n  marker refine detection parameters\n\n##### Return\n- **self**: `CharucoDetector`\n\nPython prototype (for reference only):\n```python3\nCharucoDetector(board[, charucoParams[, detectorParams[, refineParams]]]) ->  \n```","ref":"Evision.ArUco.CharucoDetector.html#charucoDetector/2"},{"type":"function","title":"Evision.ArUco.CharucoDetector.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoDetector.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.ArUco.CharucoDetector.html#clear/1"},{"type":"function","title":"Evision.ArUco.CharucoDetector.detectBoard/1","doc":"","ref":"Evision.ArUco.CharucoDetector.html#detectBoard/1"},{"type":"function","title":"Evision.ArUco.CharucoDetector.detectBoard/2","doc":"detect aruco markers and interpolate position of ChArUco board corners\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoDetector.t()`\n- **image**: `Evision.Mat`.\n\n  input image necesary for corner refinement. Note that markers are not detected and\n  should be sent in corners and ids parameters.\n\n##### Return\n- **charucoCorners**: `Evision.Mat.t()`.\n\n  interpolated chessboard corners.\n\n- **charucoIds**: `Evision.Mat.t()`.\n\n  interpolated chessboard corners identifiers.\n\n- **markerCorners**: `[Evision.Mat]`.\n\n  vector of already detected markers corners. For each marker, its four\n  corners are provided, (e.g std::vector  > ). For N detected markers, the\n  dimensions of this array should be Nx4. The order of the corners should be clockwise.\n  If markerCorners and markerCorners are empty, the function detect aruco markers and ids.\n\n- **markerIds**: `Evision.Mat.t()`.\n\n  list of identifiers for each marker in corners.\n  If markerCorners and markerCorners are empty, the function detect aruco markers and ids.\n\n This function receives the detected markers and returns the 2D position of the chessboard corners\n from a ChArUco board using the detected Aruco markers.\n If markerCorners and markerCorners are empty, the detectMarkers() will run and detect aruco markers and ids.\n If camera parameters are provided, the process is based in an approximated pose estimation, else it is based on local homography.\n Only visible corners are returned. For each corner, its corresponding identifier is also returned in charucoIds.\n@sa findChessboardCorners\n**Note**: After OpenCV 4.6.0, there was an incompatible change in the ChArUco pattern generation algorithm for even row counts.\n Use cv::aruco::CharucoBoard::setLegacyPattern() to ensure compatibility with patterns created using OpenCV versions prior to 4.6.0.\n For more information, see the issue: https://github.com/opencv/opencv/issues/23152\n\nPython prototype (for reference only):\n```python3\ndetectBoard(image[, charucoCorners[, charucoIds[, markerCorners[, markerIds]]]]) -> charucoCorners, charucoIds, markerCorners, markerIds\n```","ref":"Evision.ArUco.CharucoDetector.html#detectBoard/2"},{"type":"function","title":"Evision.ArUco.CharucoDetector.detectBoard/3","doc":"detect aruco markers and interpolate position of ChArUco board corners\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoDetector.t()`\n- **image**: `Evision.Mat`.\n\n  input image necesary for corner refinement. Note that markers are not detected and\n  should be sent in corners and ids parameters.\n\n##### Return\n- **charucoCorners**: `Evision.Mat.t()`.\n\n  interpolated chessboard corners.\n\n- **charucoIds**: `Evision.Mat.t()`.\n\n  interpolated chessboard corners identifiers.\n\n- **markerCorners**: `[Evision.Mat]`.\n\n  vector of already detected markers corners. For each marker, its four\n  corners are provided, (e.g std::vector  > ). For N detected markers, the\n  dimensions of this array should be Nx4. The order of the corners should be clockwise.\n  If markerCorners and markerCorners are empty, the function detect aruco markers and ids.\n\n- **markerIds**: `Evision.Mat.t()`.\n\n  list of identifiers for each marker in corners.\n  If markerCorners and markerCorners are empty, the function detect aruco markers and ids.\n\n This function receives the detected markers and returns the 2D position of the chessboard corners\n from a ChArUco board using the detected Aruco markers.\n If markerCorners and markerCorners are empty, the detectMarkers() will run and detect aruco markers and ids.\n If camera parameters are provided, the process is based in an approximated pose estimation, else it is based on local homography.\n Only visible corners are returned. For each corner, its corresponding identifier is also returned in charucoIds.\n@sa findChessboardCorners\n**Note**: After OpenCV 4.6.0, there was an incompatible change in the ChArUco pattern generation algorithm for even row counts.\n Use cv::aruco::CharucoBoard::setLegacyPattern() to ensure compatibility with patterns created using OpenCV versions prior to 4.6.0.\n For more information, see the issue: https://github.com/opencv/opencv/issues/23152\n\nPython prototype (for reference only):\n```python3\ndetectBoard(image[, charucoCorners[, charucoIds[, markerCorners[, markerIds]]]]) -> charucoCorners, charucoIds, markerCorners, markerIds\n```","ref":"Evision.ArUco.CharucoDetector.html#detectBoard/3"},{"type":"function","title":"Evision.ArUco.CharucoDetector.detectDiamonds/1","doc":"","ref":"Evision.ArUco.CharucoDetector.html#detectDiamonds/1"},{"type":"function","title":"Evision.ArUco.CharucoDetector.detectDiamonds/2","doc":"Detect ChArUco Diamond markers\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoDetector.t()`\n- **image**: `Evision.Mat`.\n\n  input image necessary for corner subpixel.\n\n##### Return\n- **diamondCorners**: `[Evision.Mat]`.\n\n  output list of detected diamond corners (4 corners per diamond). The order\n  is the same than in marker corners: top left, top right, bottom right and bottom left. Similar\n  format than the corners returned by detectMarkers (e.g std::vector  > ).\n\n- **diamondIds**: `Evision.Mat.t()`.\n\n  ids of the diamonds in diamondCorners. The id of each diamond is in fact of\n  type Vec4i, so each diamond has 4 ids, which are the ids of the aruco markers composing the\n  diamond.\n\n- **markerCorners**: `[Evision.Mat]`.\n\n  list of detected marker corners from detectMarkers function.\n  If markerCorners and markerCorners are empty, the function detect aruco markers and ids.\n\n- **markerIds**: `Evision.Mat.t()`.\n\n  list of marker ids in markerCorners.\n  If markerCorners and markerCorners are empty, the function detect aruco markers and ids.\n\n This function detects Diamond markers from the previous detected ArUco markers. The diamonds\n are returned in the diamondCorners and diamondIds parameters. If camera calibration parameters\n are provided, the diamond search is based on reprojection. If not, diamond search is based on\n homography. Homography is faster than reprojection, but less accurate.\n\nPython prototype (for reference only):\n```python3\ndetectDiamonds(image[, diamondCorners[, diamondIds[, markerCorners[, markerIds]]]]) -> diamondCorners, diamondIds, markerCorners, markerIds\n```","ref":"Evision.ArUco.CharucoDetector.html#detectDiamonds/2"},{"type":"function","title":"Evision.ArUco.CharucoDetector.detectDiamonds/3","doc":"Detect ChArUco Diamond markers\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoDetector.t()`\n- **image**: `Evision.Mat`.\n\n  input image necessary for corner subpixel.\n\n##### Return\n- **diamondCorners**: `[Evision.Mat]`.\n\n  output list of detected diamond corners (4 corners per diamond). The order\n  is the same than in marker corners: top left, top right, bottom right and bottom left. Similar\n  format than the corners returned by detectMarkers (e.g std::vector  > ).\n\n- **diamondIds**: `Evision.Mat.t()`.\n\n  ids of the diamonds in diamondCorners. The id of each diamond is in fact of\n  type Vec4i, so each diamond has 4 ids, which are the ids of the aruco markers composing the\n  diamond.\n\n- **markerCorners**: `[Evision.Mat]`.\n\n  list of detected marker corners from detectMarkers function.\n  If markerCorners and markerCorners are empty, the function detect aruco markers and ids.\n\n- **markerIds**: `Evision.Mat.t()`.\n\n  list of marker ids in markerCorners.\n  If markerCorners and markerCorners are empty, the function detect aruco markers and ids.\n\n This function detects Diamond markers from the previous detected ArUco markers. The diamonds\n are returned in the diamondCorners and diamondIds parameters. If camera calibration parameters\n are provided, the diamond search is based on reprojection. If not, diamond search is based on\n homography. Homography is faster than reprojection, but less accurate.\n\nPython prototype (for reference only):\n```python3\ndetectDiamonds(image[, diamondCorners[, diamondIds[, markerCorners[, markerIds]]]]) -> diamondCorners, diamondIds, markerCorners, markerIds\n```","ref":"Evision.ArUco.CharucoDetector.html#detectDiamonds/3"},{"type":"function","title":"Evision.ArUco.CharucoDetector.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.ArUco.CharucoDetector.html#empty/1"},{"type":"function","title":"Evision.ArUco.CharucoDetector.getBoard/1","doc":"getBoard\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoDetector.t()`\n\n##### Return\n- **retval**: `Evision.ArUco.CharucoBoard.t()`\n\nPython prototype (for reference only):\n```python3\ngetBoard() -> retval\n```","ref":"Evision.ArUco.CharucoDetector.html#getBoard/1"},{"type":"function","title":"Evision.ArUco.CharucoDetector.getCharucoParameters/1","doc":"getCharucoParameters\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoDetector.t()`\n\n##### Return\n- **retval**: `CharucoParameters`\n\nPython prototype (for reference only):\n```python3\ngetCharucoParameters() -> retval\n```","ref":"Evision.ArUco.CharucoDetector.html#getCharucoParameters/1"},{"type":"function","title":"Evision.ArUco.CharucoDetector.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoDetector.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.ArUco.CharucoDetector.html#getDefaultName/1"},{"type":"function","title":"Evision.ArUco.CharucoDetector.getDetectorParameters/1","doc":"getDetectorParameters\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoDetector.t()`\n\n##### Return\n- **retval**: `DetectorParameters`\n\nPython prototype (for reference only):\n```python3\ngetDetectorParameters() -> retval\n```","ref":"Evision.ArUco.CharucoDetector.html#getDetectorParameters/1"},{"type":"function","title":"Evision.ArUco.CharucoDetector.getRefineParameters/1","doc":"getRefineParameters\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoDetector.t()`\n\n##### Return\n- **retval**: `RefineParameters`\n\nPython prototype (for reference only):\n```python3\ngetRefineParameters() -> retval\n```","ref":"Evision.ArUco.CharucoDetector.html#getRefineParameters/1"},{"type":"function","title":"Evision.ArUco.CharucoDetector.read/1","doc":"","ref":"Evision.ArUco.CharucoDetector.html#read/1"},{"type":"function","title":"Evision.ArUco.CharucoDetector.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoDetector.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.ArUco.CharucoDetector.html#read/2"},{"type":"function","title":"Evision.ArUco.CharucoDetector.save/1","doc":"","ref":"Evision.ArUco.CharucoDetector.html#save/1"},{"type":"function","title":"Evision.ArUco.CharucoDetector.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoDetector.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.ArUco.CharucoDetector.html#save/2"},{"type":"function","title":"Evision.ArUco.CharucoDetector.setBoard/1","doc":"","ref":"Evision.ArUco.CharucoDetector.html#setBoard/1"},{"type":"function","title":"Evision.ArUco.CharucoDetector.setBoard/2","doc":"setBoard\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoDetector.t()`\n- **board**: `Evision.ArUco.CharucoBoard`\n\nPython prototype (for reference only):\n```python3\nsetBoard(board) -> None\n```","ref":"Evision.ArUco.CharucoDetector.html#setBoard/2"},{"type":"function","title":"Evision.ArUco.CharucoDetector.setCharucoParameters/1","doc":"","ref":"Evision.ArUco.CharucoDetector.html#setCharucoParameters/1"},{"type":"function","title":"Evision.ArUco.CharucoDetector.setCharucoParameters/2","doc":"setCharucoParameters\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoDetector.t()`\n- **charucoParameters**: `CharucoParameters`\n\nPython prototype (for reference only):\n```python3\nsetCharucoParameters(charucoParameters) -> None\n```","ref":"Evision.ArUco.CharucoDetector.html#setCharucoParameters/2"},{"type":"function","title":"Evision.ArUco.CharucoDetector.setDetectorParameters/1","doc":"","ref":"Evision.ArUco.CharucoDetector.html#setDetectorParameters/1"},{"type":"function","title":"Evision.ArUco.CharucoDetector.setDetectorParameters/2","doc":"setDetectorParameters\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoDetector.t()`\n- **detectorParameters**: `DetectorParameters`\n\nPython prototype (for reference only):\n```python3\nsetDetectorParameters(detectorParameters) -> None\n```","ref":"Evision.ArUco.CharucoDetector.html#setDetectorParameters/2"},{"type":"function","title":"Evision.ArUco.CharucoDetector.setRefineParameters/1","doc":"","ref":"Evision.ArUco.CharucoDetector.html#setRefineParameters/1"},{"type":"function","title":"Evision.ArUco.CharucoDetector.setRefineParameters/2","doc":"setRefineParameters\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoDetector.t()`\n- **refineParameters**: `RefineParameters`\n\nPython prototype (for reference only):\n```python3\nsetRefineParameters(refineParameters) -> None\n```","ref":"Evision.ArUco.CharucoDetector.html#setRefineParameters/2"},{"type":"function","title":"Evision.ArUco.CharucoDetector.write/1","doc":"","ref":"Evision.ArUco.CharucoDetector.html#write/1"},{"type":"function","title":"Evision.ArUco.CharucoDetector.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoDetector.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.ArUco.CharucoDetector.html#write/2"},{"type":"function","title":"Evision.ArUco.CharucoDetector.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.CharucoDetector.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.ArUco.CharucoDetector.html#write/3"},{"type":"type","title":"Evision.ArUco.CharucoDetector.t/0","doc":"Type that represents an `ArUco.CharucoDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ArUco.CharucoDetector.html#t:t/0"},{"type":"module","title":"Evision.ArUco.CharucoParameters","doc":"","ref":"Evision.ArUco.CharucoParameters.html"},{"type":"function","title":"Evision.ArUco.CharucoParameters.charucoParameters/0","doc":"CharucoParameters\n##### Return\n- **self**: `CharucoParameters`\n\nPython prototype (for reference only):\n```python3\nCharucoParameters() ->  \n```","ref":"Evision.ArUco.CharucoParameters.html#charucoParameters/0"},{"type":"function","title":"Evision.ArUco.CharucoParameters.charucoParameters/1","doc":"","ref":"Evision.ArUco.CharucoParameters.html#charucoParameters/1"},{"type":"function","title":"Evision.ArUco.CharucoParameters.get_cameraMatrix/1","doc":"","ref":"Evision.ArUco.CharucoParameters.html#get_cameraMatrix/1"},{"type":"function","title":"Evision.ArUco.CharucoParameters.get_distCoeffs/1","doc":"","ref":"Evision.ArUco.CharucoParameters.html#get_distCoeffs/1"},{"type":"function","title":"Evision.ArUco.CharucoParameters.get_minMarkers/1","doc":"","ref":"Evision.ArUco.CharucoParameters.html#get_minMarkers/1"},{"type":"function","title":"Evision.ArUco.CharucoParameters.get_tryRefineMarkers/1","doc":"","ref":"Evision.ArUco.CharucoParameters.html#get_tryRefineMarkers/1"},{"type":"function","title":"Evision.ArUco.CharucoParameters.set_cameraMatrix/2","doc":"","ref":"Evision.ArUco.CharucoParameters.html#set_cameraMatrix/2"},{"type":"function","title":"Evision.ArUco.CharucoParameters.set_distCoeffs/2","doc":"","ref":"Evision.ArUco.CharucoParameters.html#set_distCoeffs/2"},{"type":"function","title":"Evision.ArUco.CharucoParameters.set_minMarkers/2","doc":"","ref":"Evision.ArUco.CharucoParameters.html#set_minMarkers/2"},{"type":"function","title":"Evision.ArUco.CharucoParameters.set_tryRefineMarkers/2","doc":"","ref":"Evision.ArUco.CharucoParameters.html#set_tryRefineMarkers/2"},{"type":"type","title":"Evision.ArUco.CharucoParameters.t/0","doc":"Type that represents an `ArUco.CharucoParameters` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ArUco.CharucoParameters.html#t:t/0"},{"type":"module","title":"Evision.ArUco.CornerRefineMethod","doc":"","ref":"Evision.ArUco.CornerRefineMethod.html"},{"type":"function","title":"Evision.ArUco.CornerRefineMethod.cv_CORNER_REFINE_APRILTAG/0","doc":"","ref":"Evision.ArUco.CornerRefineMethod.html#cv_CORNER_REFINE_APRILTAG/0"},{"type":"function","title":"Evision.ArUco.CornerRefineMethod.cv_CORNER_REFINE_CONTOUR/0","doc":"","ref":"Evision.ArUco.CornerRefineMethod.html#cv_CORNER_REFINE_CONTOUR/0"},{"type":"function","title":"Evision.ArUco.CornerRefineMethod.cv_CORNER_REFINE_NONE/0","doc":"","ref":"Evision.ArUco.CornerRefineMethod.html#cv_CORNER_REFINE_NONE/0"},{"type":"function","title":"Evision.ArUco.CornerRefineMethod.cv_CORNER_REFINE_SUBPIX/0","doc":"","ref":"Evision.ArUco.CornerRefineMethod.html#cv_CORNER_REFINE_SUBPIX/0"},{"type":"type","title":"Evision.ArUco.CornerRefineMethod.enum/0","doc":"","ref":"Evision.ArUco.CornerRefineMethod.html#t:enum/0"},{"type":"module","title":"Evision.ArUco.DetectorParameters","doc":"","ref":"Evision.ArUco.DetectorParameters.html"},{"type":"function","title":"Evision.ArUco.DetectorParameters.detectorParameters/0","doc":"DetectorParameters\n##### Return\n- **self**: `DetectorParameters`\n\nPython prototype (for reference only):\n```python3\nDetectorParameters() ->  \n```","ref":"Evision.ArUco.DetectorParameters.html#detectorParameters/0"},{"type":"function","title":"Evision.ArUco.DetectorParameters.detectorParameters/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#detectorParameters/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_adaptiveThreshConstant/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_adaptiveThreshConstant/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_adaptiveThreshWinSizeMax/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_adaptiveThreshWinSizeMax/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_adaptiveThreshWinSizeMin/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_adaptiveThreshWinSizeMin/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_adaptiveThreshWinSizeStep/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_adaptiveThreshWinSizeStep/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_aprilTagCriticalRad/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_aprilTagCriticalRad/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_aprilTagDeglitch/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_aprilTagDeglitch/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_aprilTagMaxLineFitMse/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_aprilTagMaxLineFitMse/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_aprilTagMaxNmaxima/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_aprilTagMaxNmaxima/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_aprilTagMinClusterPixels/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_aprilTagMinClusterPixels/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_aprilTagMinWhiteBlackDiff/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_aprilTagMinWhiteBlackDiff/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_aprilTagQuadDecimate/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_aprilTagQuadDecimate/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_aprilTagQuadSigma/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_aprilTagQuadSigma/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_cornerRefinementMaxIterations/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_cornerRefinementMaxIterations/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_cornerRefinementMethod/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_cornerRefinementMethod/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_cornerRefinementMinAccuracy/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_cornerRefinementMinAccuracy/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_cornerRefinementWinSize/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_cornerRefinementWinSize/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_detectInvertedMarker/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_detectInvertedMarker/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_errorCorrectionRate/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_errorCorrectionRate/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_markerBorderBits/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_markerBorderBits/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_maxErroneousBitsInBorderRate/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_maxErroneousBitsInBorderRate/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_maxMarkerPerimeterRate/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_maxMarkerPerimeterRate/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_minCornerDistanceRate/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_minCornerDistanceRate/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_minDistanceToBorder/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_minDistanceToBorder/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_minGroupDistance/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_minGroupDistance/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_minMarkerDistanceRate/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_minMarkerDistanceRate/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_minMarkerLengthRatioOriginalImg/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_minMarkerLengthRatioOriginalImg/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_minMarkerPerimeterRate/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_minMarkerPerimeterRate/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_minOtsuStdDev/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_minOtsuStdDev/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_minSideLengthCanonicalImg/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_minSideLengthCanonicalImg/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_perspectiveRemoveIgnoredMarginPerCell/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_perspectiveRemoveIgnoredMarginPerCell/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_perspectiveRemovePixelPerCell/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_perspectiveRemovePixelPerCell/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_polygonalApproxAccuracyRate/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_polygonalApproxAccuracyRate/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_relativeCornerRefinmentWinSize/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_relativeCornerRefinmentWinSize/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.get_useAruco3Detection/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#get_useAruco3Detection/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.readDetectorParameters/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#readDetectorParameters/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.readDetectorParameters/2","doc":"Read a new set of DetectorParameters from FileNode (use FileStorage.root()).\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.DetectorParameters.t()`\n- **func**: `Evision.FileNode`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nreadDetectorParameters(fn) -> retval\n```","ref":"Evision.ArUco.DetectorParameters.html#readDetectorParameters/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_adaptiveThreshConstant/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_adaptiveThreshConstant/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_adaptiveThreshWinSizeMax/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_adaptiveThreshWinSizeMax/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_adaptiveThreshWinSizeMin/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_adaptiveThreshWinSizeMin/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_adaptiveThreshWinSizeStep/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_adaptiveThreshWinSizeStep/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_aprilTagCriticalRad/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_aprilTagCriticalRad/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_aprilTagDeglitch/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_aprilTagDeglitch/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_aprilTagMaxLineFitMse/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_aprilTagMaxLineFitMse/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_aprilTagMaxNmaxima/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_aprilTagMaxNmaxima/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_aprilTagMinClusterPixels/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_aprilTagMinClusterPixels/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_aprilTagMinWhiteBlackDiff/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_aprilTagMinWhiteBlackDiff/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_aprilTagQuadDecimate/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_aprilTagQuadDecimate/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_aprilTagQuadSigma/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_aprilTagQuadSigma/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_cornerRefinementMaxIterations/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_cornerRefinementMaxIterations/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_cornerRefinementMethod/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_cornerRefinementMethod/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_cornerRefinementMinAccuracy/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_cornerRefinementMinAccuracy/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_cornerRefinementWinSize/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_cornerRefinementWinSize/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_detectInvertedMarker/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_detectInvertedMarker/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_errorCorrectionRate/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_errorCorrectionRate/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_markerBorderBits/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_markerBorderBits/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_maxErroneousBitsInBorderRate/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_maxErroneousBitsInBorderRate/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_maxMarkerPerimeterRate/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_maxMarkerPerimeterRate/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_minCornerDistanceRate/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_minCornerDistanceRate/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_minDistanceToBorder/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_minDistanceToBorder/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_minGroupDistance/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_minGroupDistance/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_minMarkerDistanceRate/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_minMarkerDistanceRate/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_minMarkerLengthRatioOriginalImg/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_minMarkerLengthRatioOriginalImg/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_minMarkerPerimeterRate/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_minMarkerPerimeterRate/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_minOtsuStdDev/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_minOtsuStdDev/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_minSideLengthCanonicalImg/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_minSideLengthCanonicalImg/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_perspectiveRemoveIgnoredMarginPerCell/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_perspectiveRemoveIgnoredMarginPerCell/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_perspectiveRemovePixelPerCell/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_perspectiveRemovePixelPerCell/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_polygonalApproxAccuracyRate/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_polygonalApproxAccuracyRate/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_relativeCornerRefinmentWinSize/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_relativeCornerRefinmentWinSize/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.set_useAruco3Detection/2","doc":"","ref":"Evision.ArUco.DetectorParameters.html#set_useAruco3Detection/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.writeDetectorParameters/1","doc":"","ref":"Evision.ArUco.DetectorParameters.html#writeDetectorParameters/1"},{"type":"function","title":"Evision.ArUco.DetectorParameters.writeDetectorParameters/2","doc":"Write a set of DetectorParameters to FileStorage\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.DetectorParameters.t()`\n- **fs**: `Evision.FileStorage`\n\n##### Keyword Arguments\n- **name**: `String`.\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nwriteDetectorParameters(fs[, name]) -> retval\n```","ref":"Evision.ArUco.DetectorParameters.html#writeDetectorParameters/2"},{"type":"function","title":"Evision.ArUco.DetectorParameters.writeDetectorParameters/3","doc":"Write a set of DetectorParameters to FileStorage\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.DetectorParameters.t()`\n- **fs**: `Evision.FileStorage`\n\n##### Keyword Arguments\n- **name**: `String`.\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nwriteDetectorParameters(fs[, name]) -> retval\n```","ref":"Evision.ArUco.DetectorParameters.html#writeDetectorParameters/3"},{"type":"type","title":"Evision.ArUco.DetectorParameters.t/0","doc":"Type that represents an `ArUco.DetectorParameters` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ArUco.DetectorParameters.html#t:t/0"},{"type":"module","title":"Evision.ArUco.Dictionary","doc":"","ref":"Evision.ArUco.Dictionary.html"},{"type":"function","title":"Evision.ArUco.Dictionary.dictionary/0","doc":"Dictionary\n##### Return\n- **self**: `Dictionary`\n\nPython prototype (for reference only):\n```python3\nDictionary() ->  \n```","ref":"Evision.ArUco.Dictionary.html#dictionary/0"},{"type":"function","title":"Evision.ArUco.Dictionary.dictionary/1","doc":"","ref":"Evision.ArUco.Dictionary.html#dictionary/1"},{"type":"function","title":"Evision.ArUco.Dictionary.dictionary/2","doc":"Basic ArUco dictionary constructor\n\n##### Positional Arguments\n- **bytesList**: `Evision.Mat`.\n\n  bits for all ArUco markers in dictionary see memory layout in the class description\n\n- **markerSize**: `integer()`.\n\n  ArUco marker size in units\n\n##### Keyword Arguments\n- **maxcorr**: `integer()`.\n\n  maximum number of bits that can be corrected\n\n##### Return\n- **self**: `Dictionary`\n\nPython prototype (for reference only):\n```python3\nDictionary(bytesList, _markerSize[, maxcorr]) ->  \n```","ref":"Evision.ArUco.Dictionary.html#dictionary/2"},{"type":"function","title":"Evision.ArUco.Dictionary.dictionary/3","doc":"Basic ArUco dictionary constructor\n\n##### Positional Arguments\n- **bytesList**: `Evision.Mat`.\n\n  bits for all ArUco markers in dictionary see memory layout in the class description\n\n- **markerSize**: `integer()`.\n\n  ArUco marker size in units\n\n##### Keyword Arguments\n- **maxcorr**: `integer()`.\n\n  maximum number of bits that can be corrected\n\n##### Return\n- **self**: `Dictionary`\n\nPython prototype (for reference only):\n```python3\nDictionary(bytesList, _markerSize[, maxcorr]) ->  \n```","ref":"Evision.ArUco.Dictionary.html#dictionary/3"},{"type":"function","title":"Evision.ArUco.Dictionary.generateImageMarker/1","doc":"","ref":"Evision.ArUco.Dictionary.html#generateImageMarker/1"},{"type":"function","title":"Evision.ArUco.Dictionary.generateImageMarker/3","doc":"Generate a canonical marker image\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.Dictionary.t()`\n- **id**: `integer()`\n- **sidePixels**: `integer()`\n\n##### Keyword Arguments\n- **borderBits**: `integer()`.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngenerateImageMarker(id, sidePixels[, _img[, borderBits]]) -> _img\n```","ref":"Evision.ArUco.Dictionary.html#generateImageMarker/3"},{"type":"function","title":"Evision.ArUco.Dictionary.generateImageMarker/4","doc":"Generate a canonical marker image\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.Dictionary.t()`\n- **id**: `integer()`\n- **sidePixels**: `integer()`\n\n##### Keyword Arguments\n- **borderBits**: `integer()`.\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngenerateImageMarker(id, sidePixels[, _img[, borderBits]]) -> _img\n```","ref":"Evision.ArUco.Dictionary.html#generateImageMarker/4"},{"type":"function","title":"Evision.ArUco.Dictionary.get_bytesList/1","doc":"","ref":"Evision.ArUco.Dictionary.html#get_bytesList/1"},{"type":"function","title":"Evision.ArUco.Dictionary.get_markerSize/1","doc":"","ref":"Evision.ArUco.Dictionary.html#get_markerSize/1"},{"type":"function","title":"Evision.ArUco.Dictionary.get_maxCorrectionBits/1","doc":"","ref":"Evision.ArUco.Dictionary.html#get_maxCorrectionBits/1"},{"type":"function","title":"Evision.ArUco.Dictionary.getBitsFromByteList/1","doc":"","ref":"Evision.ArUco.Dictionary.html#getBitsFromByteList/1"},{"type":"function","title":"Evision.ArUco.Dictionary.getBitsFromByteList/2","doc":"Transform list of bytes to matrix of bits\n\n##### Positional Arguments\n- **byteList**: `Evision.Mat`\n- **markerSize**: `integer()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetBitsFromByteList(byteList, markerSize) -> retval\n```","ref":"Evision.ArUco.Dictionary.html#getBitsFromByteList/2"},{"type":"function","title":"Evision.ArUco.Dictionary.getByteListFromBits/1","doc":"Transform matrix of bits to list of bytes with 4 marker rotations\n\n##### Positional Arguments\n- **bits**: `Evision.Mat`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetByteListFromBits(bits) -> retval\n```","ref":"Evision.ArUco.Dictionary.html#getByteListFromBits/1"},{"type":"function","title":"Evision.ArUco.Dictionary.getDistanceToId/1","doc":"","ref":"Evision.ArUco.Dictionary.html#getDistanceToId/1"},{"type":"function","title":"Evision.ArUco.Dictionary.getDistanceToId/3","doc":"Returns Hamming distance of the input bits to the specific id.\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.Dictionary.t()`\n- **bits**: `Evision.Mat`\n- **id**: `integer()`\n\n##### Keyword Arguments\n- **allRotations**: `bool`.\n\n##### Return\n- **retval**: `integer()`\n\n If `allRotations` flag is set, the four posible marker rotations are considered\n\nPython prototype (for reference only):\n```python3\ngetDistanceToId(bits, id[, allRotations]) -> retval\n```","ref":"Evision.ArUco.Dictionary.html#getDistanceToId/3"},{"type":"function","title":"Evision.ArUco.Dictionary.getDistanceToId/4","doc":"Returns Hamming distance of the input bits to the specific id.\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.Dictionary.t()`\n- **bits**: `Evision.Mat`\n- **id**: `integer()`\n\n##### Keyword Arguments\n- **allRotations**: `bool`.\n\n##### Return\n- **retval**: `integer()`\n\n If `allRotations` flag is set, the four posible marker rotations are considered\n\nPython prototype (for reference only):\n```python3\ngetDistanceToId(bits, id[, allRotations]) -> retval\n```","ref":"Evision.ArUco.Dictionary.html#getDistanceToId/4"},{"type":"function","title":"Evision.ArUco.Dictionary.identify/1","doc":"","ref":"Evision.ArUco.Dictionary.html#identify/1"},{"type":"function","title":"Evision.ArUco.Dictionary.identify/3","doc":"Given a matrix of bits. Returns whether if marker is identified or not.\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.Dictionary.t()`\n- **onlyBits**: `Evision.Mat`\n- **maxCorrectionRate**: `double`\n\n##### Return\n- **retval**: `bool`\n- **idx**: `integer()`\n- **rotation**: `integer()`\n\n Returns reference to the marker id in the dictionary (if any) and its rotation.\n\nPython prototype (for reference only):\n```python3\nidentify(onlyBits, maxCorrectionRate) -> retval, idx, rotation\n```","ref":"Evision.ArUco.Dictionary.html#identify/3"},{"type":"function","title":"Evision.ArUco.Dictionary.readDictionary/1","doc":"","ref":"Evision.ArUco.Dictionary.html#readDictionary/1"},{"type":"function","title":"Evision.ArUco.Dictionary.readDictionary/2","doc":"Read a new dictionary from FileNode.\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.Dictionary.t()`\n- **func**: `Evision.FileNode`\n\n##### Return\n- **retval**: `bool`\n\n Dictionary example in YAML format:\\n\n nmarkers: 35\\n\n markersize: 6\\n\n maxCorrectionBits: 5\\n\n marker_0: \"101011111011111001001001101100000000\"\\n\n ...\\n\n marker_34: \"011111010000111011111110110101100101\"\n\nPython prototype (for reference only):\n```python3\nreadDictionary(fn) -> retval\n```","ref":"Evision.ArUco.Dictionary.html#readDictionary/2"},{"type":"function","title":"Evision.ArUco.Dictionary.set_bytesList/2","doc":"","ref":"Evision.ArUco.Dictionary.html#set_bytesList/2"},{"type":"function","title":"Evision.ArUco.Dictionary.set_markerSize/2","doc":"","ref":"Evision.ArUco.Dictionary.html#set_markerSize/2"},{"type":"function","title":"Evision.ArUco.Dictionary.set_maxCorrectionBits/2","doc":"","ref":"Evision.ArUco.Dictionary.html#set_maxCorrectionBits/2"},{"type":"function","title":"Evision.ArUco.Dictionary.writeDictionary/1","doc":"","ref":"Evision.ArUco.Dictionary.html#writeDictionary/1"},{"type":"function","title":"Evision.ArUco.Dictionary.writeDictionary/2","doc":"Write a dictionary to FileStorage, format is the same as in readDictionary().\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.Dictionary.t()`\n- **fs**: `Evision.FileStorage`\n\n##### Keyword Arguments\n- **name**: `String`.\n\nPython prototype (for reference only):\n```python3\nwriteDictionary(fs[, name]) -> None\n```","ref":"Evision.ArUco.Dictionary.html#writeDictionary/2"},{"type":"function","title":"Evision.ArUco.Dictionary.writeDictionary/3","doc":"Write a dictionary to FileStorage, format is the same as in readDictionary().\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.Dictionary.t()`\n- **fs**: `Evision.FileStorage`\n\n##### Keyword Arguments\n- **name**: `String`.\n\nPython prototype (for reference only):\n```python3\nwriteDictionary(fs[, name]) -> None\n```","ref":"Evision.ArUco.Dictionary.html#writeDictionary/3"},{"type":"type","title":"Evision.ArUco.Dictionary.t/0","doc":"Type that represents an `ArUco.Dictionary` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ArUco.Dictionary.html#t:t/0"},{"type":"module","title":"Evision.ArUco.EstimateParameters","doc":"","ref":"Evision.ArUco.EstimateParameters.html"},{"type":"function","title":"Evision.ArUco.EstimateParameters.estimateParameters/0","doc":"EstimateParameters\n##### Return\n- **self**: `EstimateParameters`\n\nPython prototype (for reference only):\n```python3\nEstimateParameters() ->  \n```","ref":"Evision.ArUco.EstimateParameters.html#estimateParameters/0"},{"type":"function","title":"Evision.ArUco.EstimateParameters.estimateParameters/1","doc":"","ref":"Evision.ArUco.EstimateParameters.html#estimateParameters/1"},{"type":"function","title":"Evision.ArUco.EstimateParameters.get_pattern/1","doc":"","ref":"Evision.ArUco.EstimateParameters.html#get_pattern/1"},{"type":"function","title":"Evision.ArUco.EstimateParameters.get_solvePnPMethod/1","doc":"","ref":"Evision.ArUco.EstimateParameters.html#get_solvePnPMethod/1"},{"type":"function","title":"Evision.ArUco.EstimateParameters.get_useExtrinsicGuess/1","doc":"","ref":"Evision.ArUco.EstimateParameters.html#get_useExtrinsicGuess/1"},{"type":"function","title":"Evision.ArUco.EstimateParameters.set_pattern/2","doc":"","ref":"Evision.ArUco.EstimateParameters.html#set_pattern/2"},{"type":"function","title":"Evision.ArUco.EstimateParameters.set_solvePnPMethod/2","doc":"","ref":"Evision.ArUco.EstimateParameters.html#set_solvePnPMethod/2"},{"type":"function","title":"Evision.ArUco.EstimateParameters.set_useExtrinsicGuess/2","doc":"","ref":"Evision.ArUco.EstimateParameters.html#set_useExtrinsicGuess/2"},{"type":"type","title":"Evision.ArUco.EstimateParameters.t/0","doc":"Type that represents an `ArUco.EstimateParameters` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ArUco.EstimateParameters.html#t:t/0"},{"type":"module","title":"Evision.ArUco.GridBoard","doc":"","ref":"Evision.ArUco.GridBoard.html"},{"type":"function","title":"Evision.ArUco.GridBoard.getGridSize/1","doc":"getGridSize\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.GridBoard.t()`\n\n##### Return\n- **retval**: `Size`\n\nPython prototype (for reference only):\n```python3\ngetGridSize() -> retval\n```","ref":"Evision.ArUco.GridBoard.html#getGridSize/1"},{"type":"function","title":"Evision.ArUco.GridBoard.getMarkerLength/1","doc":"getMarkerLength\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.GridBoard.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetMarkerLength() -> retval\n```","ref":"Evision.ArUco.GridBoard.html#getMarkerLength/1"},{"type":"function","title":"Evision.ArUco.GridBoard.getMarkerSeparation/1","doc":"getMarkerSeparation\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.GridBoard.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetMarkerSeparation() -> retval\n```","ref":"Evision.ArUco.GridBoard.html#getMarkerSeparation/1"},{"type":"function","title":"Evision.ArUco.GridBoard.gridBoard/1","doc":"","ref":"Evision.ArUco.GridBoard.html#gridBoard/1"},{"type":"function","title":"Evision.ArUco.GridBoard.gridBoard/4","doc":"GridBoard constructor\n\n##### Positional Arguments\n- **size**: `Size`.\n\n  number of markers in x and y directions\n\n- **markerLength**: `float`.\n\n  marker side length (normally in meters)\n\n- **markerSeparation**: `float`.\n\n  separation between two markers (same unit as markerLength)\n\n- **dictionary**: `Dictionary`.\n\n  dictionary of markers indicating the type of markers\n\n##### Keyword Arguments\n- **ids**: `Evision.Mat`.\n\n  set of marker ids in dictionary to use on board.\n\n##### Return\n- **self**: `GridBoard`\n\nPython prototype (for reference only):\n```python3\nGridBoard(size, markerLength, markerSeparation, dictionary[, ids]) ->  \n```","ref":"Evision.ArUco.GridBoard.html#gridBoard/4"},{"type":"function","title":"Evision.ArUco.GridBoard.gridBoard/5","doc":"GridBoard constructor\n\n##### Positional Arguments\n- **size**: `Size`.\n\n  number of markers in x and y directions\n\n- **markerLength**: `float`.\n\n  marker side length (normally in meters)\n\n- **markerSeparation**: `float`.\n\n  separation between two markers (same unit as markerLength)\n\n- **dictionary**: `Dictionary`.\n\n  dictionary of markers indicating the type of markers\n\n##### Keyword Arguments\n- **ids**: `Evision.Mat`.\n\n  set of marker ids in dictionary to use on board.\n\n##### Return\n- **self**: `GridBoard`\n\nPython prototype (for reference only):\n```python3\nGridBoard(size, markerLength, markerSeparation, dictionary[, ids]) ->  \n```","ref":"Evision.ArUco.GridBoard.html#gridBoard/5"},{"type":"type","title":"Evision.ArUco.GridBoard.t/0","doc":"Type that represents an `ArUco.GridBoard` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ArUco.GridBoard.html#t:t/0"},{"type":"module","title":"Evision.ArUco.PatternPositionType","doc":"","ref":"Evision.ArUco.PatternPositionType.html"},{"type":"function","title":"Evision.ArUco.PatternPositionType.cv_ARUCO_CCW_CENTER/0","doc":"","ref":"Evision.ArUco.PatternPositionType.html#cv_ARUCO_CCW_CENTER/0"},{"type":"function","title":"Evision.ArUco.PatternPositionType.cv_ARUCO_CW_TOP_LEFT_CORNER/0","doc":"","ref":"Evision.ArUco.PatternPositionType.html#cv_ARUCO_CW_TOP_LEFT_CORNER/0"},{"type":"type","title":"Evision.ArUco.PatternPositionType.enum/0","doc":"","ref":"Evision.ArUco.PatternPositionType.html#t:enum/0"},{"type":"module","title":"Evision.ArUco.PredefinedDictionaryType","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html"},{"type":"function","title":"Evision.ArUco.PredefinedDictionaryType.cv_DICT_4X4_50/0","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html#cv_DICT_4X4_50/0"},{"type":"function","title":"Evision.ArUco.PredefinedDictionaryType.cv_DICT_4X4_100/0","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html#cv_DICT_4X4_100/0"},{"type":"function","title":"Evision.ArUco.PredefinedDictionaryType.cv_DICT_4X4_250/0","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html#cv_DICT_4X4_250/0"},{"type":"function","title":"Evision.ArUco.PredefinedDictionaryType.cv_DICT_4X4_1000/0","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html#cv_DICT_4X4_1000/0"},{"type":"function","title":"Evision.ArUco.PredefinedDictionaryType.cv_DICT_5X5_50/0","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html#cv_DICT_5X5_50/0"},{"type":"function","title":"Evision.ArUco.PredefinedDictionaryType.cv_DICT_5X5_100/0","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html#cv_DICT_5X5_100/0"},{"type":"function","title":"Evision.ArUco.PredefinedDictionaryType.cv_DICT_5X5_250/0","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html#cv_DICT_5X5_250/0"},{"type":"function","title":"Evision.ArUco.PredefinedDictionaryType.cv_DICT_5X5_1000/0","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html#cv_DICT_5X5_1000/0"},{"type":"function","title":"Evision.ArUco.PredefinedDictionaryType.cv_DICT_6X6_50/0","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html#cv_DICT_6X6_50/0"},{"type":"function","title":"Evision.ArUco.PredefinedDictionaryType.cv_DICT_6X6_100/0","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html#cv_DICT_6X6_100/0"},{"type":"function","title":"Evision.ArUco.PredefinedDictionaryType.cv_DICT_6X6_250/0","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html#cv_DICT_6X6_250/0"},{"type":"function","title":"Evision.ArUco.PredefinedDictionaryType.cv_DICT_6X6_1000/0","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html#cv_DICT_6X6_1000/0"},{"type":"function","title":"Evision.ArUco.PredefinedDictionaryType.cv_DICT_7X7_50/0","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html#cv_DICT_7X7_50/0"},{"type":"function","title":"Evision.ArUco.PredefinedDictionaryType.cv_DICT_7X7_100/0","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html#cv_DICT_7X7_100/0"},{"type":"function","title":"Evision.ArUco.PredefinedDictionaryType.cv_DICT_7X7_250/0","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html#cv_DICT_7X7_250/0"},{"type":"function","title":"Evision.ArUco.PredefinedDictionaryType.cv_DICT_7X7_1000/0","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html#cv_DICT_7X7_1000/0"},{"type":"function","title":"Evision.ArUco.PredefinedDictionaryType.cv_DICT_APRILTAG_16h5/0","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html#cv_DICT_APRILTAG_16h5/0"},{"type":"function","title":"Evision.ArUco.PredefinedDictionaryType.cv_DICT_APRILTAG_25h9/0","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html#cv_DICT_APRILTAG_25h9/0"},{"type":"function","title":"Evision.ArUco.PredefinedDictionaryType.cv_DICT_APRILTAG_36h10/0","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html#cv_DICT_APRILTAG_36h10/0"},{"type":"function","title":"Evision.ArUco.PredefinedDictionaryType.cv_DICT_APRILTAG_36h11/0","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html#cv_DICT_APRILTAG_36h11/0"},{"type":"function","title":"Evision.ArUco.PredefinedDictionaryType.cv_DICT_ARUCO_MIP_36h12/0","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html#cv_DICT_ARUCO_MIP_36h12/0"},{"type":"function","title":"Evision.ArUco.PredefinedDictionaryType.cv_DICT_ARUCO_ORIGINAL/0","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html#cv_DICT_ARUCO_ORIGINAL/0"},{"type":"type","title":"Evision.ArUco.PredefinedDictionaryType.enum/0","doc":"","ref":"Evision.ArUco.PredefinedDictionaryType.html#t:enum/0"},{"type":"module","title":"Evision.ArUco.RefineParameters","doc":"","ref":"Evision.ArUco.RefineParameters.html"},{"type":"function","title":"Evision.ArUco.RefineParameters.get_checkAllOrders/1","doc":"","ref":"Evision.ArUco.RefineParameters.html#get_checkAllOrders/1"},{"type":"function","title":"Evision.ArUco.RefineParameters.get_errorCorrectionRate/1","doc":"","ref":"Evision.ArUco.RefineParameters.html#get_errorCorrectionRate/1"},{"type":"function","title":"Evision.ArUco.RefineParameters.get_minRepDistance/1","doc":"","ref":"Evision.ArUco.RefineParameters.html#get_minRepDistance/1"},{"type":"function","title":"Evision.ArUco.RefineParameters.readRefineParameters/1","doc":"","ref":"Evision.ArUco.RefineParameters.html#readRefineParameters/1"},{"type":"function","title":"Evision.ArUco.RefineParameters.readRefineParameters/2","doc":"Read a new set of RefineParameters from FileNode (use FileStorage.root()).\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.RefineParameters.t()`\n- **func**: `Evision.FileNode`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nreadRefineParameters(fn) -> retval\n```","ref":"Evision.ArUco.RefineParameters.html#readRefineParameters/2"},{"type":"function","title":"Evision.ArUco.RefineParameters.refineParameters/0","doc":"RefineParameters\n##### Keyword Arguments\n- **minRepDistance**: `float`.\n- **errorCorrectionRate**: `float`.\n- **checkAllOrders**: `bool`.\n\n##### Return\n- **self**: `RefineParameters`\n\nPython prototype (for reference only):\n```python3\nRefineParameters([, minRepDistance[, errorCorrectionRate[, checkAllOrders]]]) ->  \n```","ref":"Evision.ArUco.RefineParameters.html#refineParameters/0"},{"type":"function","title":"Evision.ArUco.RefineParameters.refineParameters/1","doc":"RefineParameters\n##### Keyword Arguments\n- **minRepDistance**: `float`.\n- **errorCorrectionRate**: `float`.\n- **checkAllOrders**: `bool`.\n\n##### Return\n- **self**: `RefineParameters`\n\nPython prototype (for reference only):\n```python3\nRefineParameters([, minRepDistance[, errorCorrectionRate[, checkAllOrders]]]) ->  \n```","ref":"Evision.ArUco.RefineParameters.html#refineParameters/1"},{"type":"function","title":"Evision.ArUco.RefineParameters.set_checkAllOrders/2","doc":"","ref":"Evision.ArUco.RefineParameters.html#set_checkAllOrders/2"},{"type":"function","title":"Evision.ArUco.RefineParameters.set_errorCorrectionRate/2","doc":"","ref":"Evision.ArUco.RefineParameters.html#set_errorCorrectionRate/2"},{"type":"function","title":"Evision.ArUco.RefineParameters.set_minRepDistance/2","doc":"","ref":"Evision.ArUco.RefineParameters.html#set_minRepDistance/2"},{"type":"function","title":"Evision.ArUco.RefineParameters.writeRefineParameters/1","doc":"","ref":"Evision.ArUco.RefineParameters.html#writeRefineParameters/1"},{"type":"function","title":"Evision.ArUco.RefineParameters.writeRefineParameters/2","doc":"Write a set of RefineParameters to FileStorage\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.RefineParameters.t()`\n- **fs**: `Evision.FileStorage`\n\n##### Keyword Arguments\n- **name**: `String`.\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nwriteRefineParameters(fs[, name]) -> retval\n```","ref":"Evision.ArUco.RefineParameters.html#writeRefineParameters/2"},{"type":"function","title":"Evision.ArUco.RefineParameters.writeRefineParameters/3","doc":"Write a set of RefineParameters to FileStorage\n\n##### Positional Arguments\n- **self**: `Evision.ArUco.RefineParameters.t()`\n- **fs**: `Evision.FileStorage`\n\n##### Keyword Arguments\n- **name**: `String`.\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nwriteRefineParameters(fs[, name]) -> retval\n```","ref":"Evision.ArUco.RefineParameters.html#writeRefineParameters/3"},{"type":"type","title":"Evision.ArUco.RefineParameters.t/0","doc":"Type that represents an `ArUco.RefineParameters` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ArUco.RefineParameters.html#t:t/0"},{"type":"module","title":"Evision.AsyncArray","doc":"","ref":"Evision.AsyncArray.html"},{"type":"function","title":"Evision.AsyncArray.asyncArray/0","doc":"AsyncArray\n##### Return\n- **self**: `Evision.AsyncArray.t()`\n\nPython prototype (for reference only):\n```python3\nAsyncArray() ->  \n```","ref":"Evision.AsyncArray.html#asyncArray/0"},{"type":"function","title":"Evision.AsyncArray.asyncArray/1","doc":"","ref":"Evision.AsyncArray.html#asyncArray/1"},{"type":"function","title":"Evision.AsyncArray.get/1","doc":"get\n\n##### Positional Arguments\n- **self**: `Evision.AsyncArray.t()`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  destination array\n\nFetch the result.\n\nWaits for result until container has valid result.\nThrows exception if exception was stored as a result.\nThrows exception on invalid container state.\n**Note**: Result or stored exception can be fetched only once.\n\nPython prototype (for reference only):\n```python3\nget([, dst]) -> dst\n```","ref":"Evision.AsyncArray.html#get/1"},{"type":"function","title":"Evision.AsyncArray.get/2","doc":"#### Variant 1:\nget\n\n##### Positional Arguments\n- **self**: `Evision.AsyncArray.t()`\n- **timeoutNs**: `double`.\n\n  timeout in nanoseconds, -1 for infinite wait\n\n##### Return\n- **retval**: `bool`\n- **dst**: `Evision.Mat.t()`.\n\n  destination array\n\nRetrieving the result with timeout\n\n@returns true if result is ready, false if the timeout has expired\n**Note**: Result or stored exception can be fetched only once.\n\nPython prototype (for reference only):\n```python3\nget(timeoutNs[, dst]) -> retval, dst\n```\n#### Variant 2:\nget\n\n##### Positional Arguments\n- **self**: `Evision.AsyncArray.t()`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  destination array\n\nFetch the result.\n\nWaits for result until container has valid result.\nThrows exception if exception was stored as a result.\nThrows exception on invalid container state.\n**Note**: Result or stored exception can be fetched only once.\n\nPython prototype (for reference only):\n```python3\nget([, dst]) -> dst\n```","ref":"Evision.AsyncArray.html#get/2"},{"type":"function","title":"Evision.AsyncArray.get/3","doc":"get\n\n##### Positional Arguments\n- **self**: `Evision.AsyncArray.t()`\n- **timeoutNs**: `double`.\n\n  timeout in nanoseconds, -1 for infinite wait\n\n##### Return\n- **retval**: `bool`\n- **dst**: `Evision.Mat.t()`.\n\n  destination array\n\nRetrieving the result with timeout\n\n@returns true if result is ready, false if the timeout has expired\n**Note**: Result or stored exception can be fetched only once.\n\nPython prototype (for reference only):\n```python3\nget(timeoutNs[, dst]) -> retval, dst\n```","ref":"Evision.AsyncArray.html#get/3"},{"type":"function","title":"Evision.AsyncArray.release/1","doc":"release\n\n##### Positional Arguments\n- **self**: `Evision.AsyncArray.t()`\n\nPython prototype (for reference only):\n```python3\nrelease() -> None\n```","ref":"Evision.AsyncArray.html#release/1"},{"type":"function","title":"Evision.AsyncArray.valid/1","doc":"valid\n\n##### Positional Arguments\n- **self**: `Evision.AsyncArray.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nvalid() -> retval\n```","ref":"Evision.AsyncArray.html#valid/1"},{"type":"function","title":"Evision.AsyncArray.wait_for/1","doc":"","ref":"Evision.AsyncArray.html#wait_for/1"},{"type":"function","title":"Evision.AsyncArray.wait_for/2","doc":"wait_for\n\n##### Positional Arguments\n- **self**: `Evision.AsyncArray.t()`\n- **timeoutNs**: `double`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nwait_for(timeoutNs) -> retval\n```","ref":"Evision.AsyncArray.html#wait_for/2"},{"type":"type","title":"Evision.AsyncArray.t/0","doc":"Type that represents an `AsyncArray` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.AsyncArray.html#t:t/0"},{"type":"module","title":"Evision.BFMatcher","doc":"","ref":"Evision.BFMatcher.html"},{"type":"function","title":"Evision.BFMatcher.add/1","doc":"","ref":"Evision.BFMatcher.html#add/1"},{"type":"function","title":"Evision.BFMatcher.add/2","doc":"Adds descriptors to train a CPU(trainDescCollectionis) or GPU(utrainDescCollectionis) descriptor\ncollection.\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n- **descriptors**: `[Evision.Mat]`.\n\n  Descriptors to add. Each descriptors[i] is a set of descriptors from the same\n  train image.\n\nIf the collection is not empty, the new descriptors are added to existing train descriptors.\n\nPython prototype (for reference only):\n```python3\nadd(descriptors) -> None\n```","ref":"Evision.BFMatcher.html#add/2"},{"type":"function","title":"Evision.BFMatcher.bfMatcher/0","doc":"Brute-force matcher constructor (obsolete). Please use BFMatcher.create()\n##### Keyword Arguments\n- **normType**: `integer()`.\n- **crossCheck**: `bool`.\n\n##### Return\n- **self**: `Evision.BFMatcher.t()`\n\nPython prototype (for reference only):\n```python3\nBFMatcher([, normType[, crossCheck]]) ->  \n```","ref":"Evision.BFMatcher.html#bfMatcher/0"},{"type":"function","title":"Evision.BFMatcher.bfMatcher/1","doc":"Brute-force matcher constructor (obsolete). Please use BFMatcher.create()\n##### Keyword Arguments\n- **normType**: `integer()`.\n- **crossCheck**: `bool`.\n\n##### Return\n- **self**: `Evision.BFMatcher.t()`\n\nPython prototype (for reference only):\n```python3\nBFMatcher([, normType[, crossCheck]]) ->  \n```","ref":"Evision.BFMatcher.html#bfMatcher/1"},{"type":"function","title":"Evision.BFMatcher.clear/1","doc":"Clears the train descriptor collections.\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.BFMatcher.html#clear/1"},{"type":"function","title":"Evision.BFMatcher.clone/1","doc":"Clones the matcher.\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n\n##### Keyword Arguments\n- **emptyTrainData**: `bool`.\n\n  If emptyTrainData is false, the method creates a deep copy of the object,\n  that is, copies both parameters and train data. If emptyTrainData is true, the method creates an\n  object copy with the current parameters but with empty train data.\n\n##### Return\n- **retval**: `Evision.DescriptorMatcher.t()`\n\nPython prototype (for reference only):\n```python3\nclone([, emptyTrainData]) -> retval\n```","ref":"Evision.BFMatcher.html#clone/1"},{"type":"function","title":"Evision.BFMatcher.clone/2","doc":"Clones the matcher.\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n\n##### Keyword Arguments\n- **emptyTrainData**: `bool`.\n\n  If emptyTrainData is false, the method creates a deep copy of the object,\n  that is, copies both parameters and train data. If emptyTrainData is true, the method creates an\n  object copy with the current parameters but with empty train data.\n\n##### Return\n- **retval**: `Evision.DescriptorMatcher.t()`\n\nPython prototype (for reference only):\n```python3\nclone([, emptyTrainData]) -> retval\n```","ref":"Evision.BFMatcher.html#clone/2"},{"type":"function","title":"Evision.BFMatcher.create/0","doc":"Brute-force matcher create method.\n##### Keyword Arguments\n- **normType**: `integer()`.\n\n  One of NORM_L1, NORM_L2, NORM_HAMMING, NORM_HAMMING2. L1 and L2 norms are\n  preferable choices for SIFT and SURF descriptors, NORM_HAMMING should be used with ORB, BRISK and\n  BRIEF, NORM_HAMMING2 should be used with ORB when WTA_K==3 or 4 (see ORB::ORB constructor\n  description).\n\n- **crossCheck**: `bool`.\n\n  If it is false, this is will be default BFMatcher behaviour when it finds the k\n  nearest neighbors for each query descriptor. If crossCheck==true, then the knnMatch() method with\n  k=1 will only return pairs (i,j) such that for i-th query descriptor the j-th descriptor in the\n  matcher's collection is the nearest and vice versa, i.e. the BFMatcher will only return consistent\n  pairs. Such technique usually produces best results with minimal number of outliers when there are\n  enough matches. This is alternative to the ratio test, used by D. Lowe in SIFT paper.\n\n##### Return\n- **retval**: `Evision.BFMatcher.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, normType[, crossCheck]]) -> retval\n```","ref":"Evision.BFMatcher.html#create/0"},{"type":"function","title":"Evision.BFMatcher.create/1","doc":"Brute-force matcher create method.\n##### Keyword Arguments\n- **normType**: `integer()`.\n\n  One of NORM_L1, NORM_L2, NORM_HAMMING, NORM_HAMMING2. L1 and L2 norms are\n  preferable choices for SIFT and SURF descriptors, NORM_HAMMING should be used with ORB, BRISK and\n  BRIEF, NORM_HAMMING2 should be used with ORB when WTA_K==3 or 4 (see ORB::ORB constructor\n  description).\n\n- **crossCheck**: `bool`.\n\n  If it is false, this is will be default BFMatcher behaviour when it finds the k\n  nearest neighbors for each query descriptor. If crossCheck==true, then the knnMatch() method with\n  k=1 will only return pairs (i,j) such that for i-th query descriptor the j-th descriptor in the\n  matcher's collection is the nearest and vice versa, i.e. the BFMatcher will only return consistent\n  pairs. Such technique usually produces best results with minimal number of outliers when there are\n  enough matches. This is alternative to the ratio test, used by D. Lowe in SIFT paper.\n\n##### Return\n- **retval**: `Evision.BFMatcher.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, normType[, crossCheck]]) -> retval\n```","ref":"Evision.BFMatcher.html#create/1"},{"type":"function","title":"Evision.BFMatcher.empty/1","doc":"Returns true if there are no train descriptors in the both collections.\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.BFMatcher.html#empty/1"},{"type":"function","title":"Evision.BFMatcher.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.BFMatcher.html#getDefaultName/1"},{"type":"function","title":"Evision.BFMatcher.getTrainDescriptors/1","doc":"Returns a constant link to the train descriptor collection trainDescCollection .\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n\n##### Return\n- **retval**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\ngetTrainDescriptors() -> retval\n```","ref":"Evision.BFMatcher.html#getTrainDescriptors/1"},{"type":"function","title":"Evision.BFMatcher.isMaskSupported/1","doc":"Returns true if the descriptor matcher supports masking permissible matches.\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisMaskSupported() -> retval\n```","ref":"Evision.BFMatcher.html#isMaskSupported/1"},{"type":"function","title":"Evision.BFMatcher.knnMatch/1","doc":"","ref":"Evision.BFMatcher.html#knnMatch/1"},{"type":"function","title":"Evision.BFMatcher.knnMatch/3","doc":"knnMatch\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **k**: `integer()`.\n\n  Count of best matches found per each query descriptor or less if a query descriptor has\n  less than k possible matches in total.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Set of masks. Each masks[i] specifies permissible matches between the input query\n  descriptors and stored train descriptors from the i-th image trainDescCollection[i].\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Matches. Each matches[i] is k or less matches for the same query descriptor.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nknnMatch(queryDescriptors, k[, masks[, compactResult]]) -> matches\n```","ref":"Evision.BFMatcher.html#knnMatch/3"},{"type":"function","title":"Evision.BFMatcher.knnMatch/4","doc":"#### Variant 1:\nFinds the k best matches for each descriptor from a query set.\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **k**: `integer()`.\n\n  Count of best matches found per each query descriptor or less if a query descriptor has\n  less than k possible matches in total.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Matches. Each matches[i] is k or less matches for the same query descriptor.\n\nThese extended variants of DescriptorMatcher::match methods find several best matches for each query\ndescriptor. The matches are returned in the distance increasing order. See DescriptorMatcher::match\nfor the details about query and train descriptors.\n\nPython prototype (for reference only):\n```python3\nknnMatch(queryDescriptors, trainDescriptors, k[, mask[, compactResult]]) -> matches\n```\n#### Variant 2:\nknnMatch\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **k**: `integer()`.\n\n  Count of best matches found per each query descriptor or less if a query descriptor has\n  less than k possible matches in total.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Set of masks. Each masks[i] specifies permissible matches between the input query\n  descriptors and stored train descriptors from the i-th image trainDescCollection[i].\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Matches. Each matches[i] is k or less matches for the same query descriptor.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nknnMatch(queryDescriptors, k[, masks[, compactResult]]) -> matches\n```","ref":"Evision.BFMatcher.html#knnMatch/4"},{"type":"function","title":"Evision.BFMatcher.knnMatch/5","doc":"Finds the k best matches for each descriptor from a query set.\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **k**: `integer()`.\n\n  Count of best matches found per each query descriptor or less if a query descriptor has\n  less than k possible matches in total.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Matches. Each matches[i] is k or less matches for the same query descriptor.\n\nThese extended variants of DescriptorMatcher::match methods find several best matches for each query\ndescriptor. The matches are returned in the distance increasing order. See DescriptorMatcher::match\nfor the details about query and train descriptors.\n\nPython prototype (for reference only):\n```python3\nknnMatch(queryDescriptors, trainDescriptors, k[, mask[, compactResult]]) -> matches\n```","ref":"Evision.BFMatcher.html#knnMatch/5"},{"type":"function","title":"Evision.BFMatcher.match/1","doc":"","ref":"Evision.BFMatcher.html#match/1"},{"type":"function","title":"Evision.BFMatcher.match/2","doc":"match\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Set of masks. Each masks[i] specifies permissible matches between the input query\n  descriptors and stored train descriptors from the i-th image trainDescCollection[i].\n\n##### Return\n- **matches**: `[Evision.DMatch]`.\n\n  Matches. If a query descriptor is masked out in mask , no match is added for this\n  descriptor. So, matches size may be smaller than the query descriptors count.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmatch(queryDescriptors[, masks]) -> matches\n```","ref":"Evision.BFMatcher.html#match/2"},{"type":"function","title":"Evision.BFMatcher.match/3","doc":"#### Variant 1:\nFinds the best match for each descriptor from a query set.\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n##### Return\n- **matches**: `[Evision.DMatch]`.\n\n  Matches. If a query descriptor is masked out in mask , no match is added for this\n  descriptor. So, matches size may be smaller than the query descriptors count.\n\nIn the first variant of this method, the train descriptors are passed as an input argument. In the\nsecond variant of the method, train descriptors collection that was set by DescriptorMatcher::add is\nused. Optional mask (or masks) can be passed to specify which query and training descriptors can be\nmatched. Namely, queryDescriptors[i] can be matched with trainDescriptors[j] only if\nmask.at\\ (i,j) is non-zero.\n\nPython prototype (for reference only):\n```python3\nmatch(queryDescriptors, trainDescriptors[, mask]) -> matches\n```\n#### Variant 2:\nmatch\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Set of masks. Each masks[i] specifies permissible matches between the input query\n  descriptors and stored train descriptors from the i-th image trainDescCollection[i].\n\n##### Return\n- **matches**: `[Evision.DMatch]`.\n\n  Matches. If a query descriptor is masked out in mask , no match is added for this\n  descriptor. So, matches size may be smaller than the query descriptors count.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmatch(queryDescriptors[, masks]) -> matches\n```","ref":"Evision.BFMatcher.html#match/3"},{"type":"function","title":"Evision.BFMatcher.match/4","doc":"Finds the best match for each descriptor from a query set.\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n##### Return\n- **matches**: `[Evision.DMatch]`.\n\n  Matches. If a query descriptor is masked out in mask , no match is added for this\n  descriptor. So, matches size may be smaller than the query descriptors count.\n\nIn the first variant of this method, the train descriptors are passed as an input argument. In the\nsecond variant of the method, train descriptors collection that was set by DescriptorMatcher::add is\nused. Optional mask (or masks) can be passed to specify which query and training descriptors can be\nmatched. Namely, queryDescriptors[i] can be matched with trainDescriptors[j] only if\nmask.at\\ (i,j) is non-zero.\n\nPython prototype (for reference only):\n```python3\nmatch(queryDescriptors, trainDescriptors[, mask]) -> matches\n```","ref":"Evision.BFMatcher.html#match/4"},{"type":"function","title":"Evision.BFMatcher.radiusMatch/1","doc":"","ref":"Evision.BFMatcher.html#radiusMatch/1"},{"type":"function","title":"Evision.BFMatcher.radiusMatch/3","doc":"radiusMatch\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **maxDistance**: `float`.\n\n  Threshold for the distance between matched descriptors. Distance means here\n  metric distance (e.g. Hamming distance), not the distance between coordinates (which is measured\n  in Pixels)!\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Set of masks. Each masks[i] specifies permissible matches between the input query\n  descriptors and stored train descriptors from the i-th image trainDescCollection[i].\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Found matches.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nradiusMatch(queryDescriptors, maxDistance[, masks[, compactResult]]) -> matches\n```","ref":"Evision.BFMatcher.html#radiusMatch/3"},{"type":"function","title":"Evision.BFMatcher.radiusMatch/4","doc":"#### Variant 1:\nFor each query descriptor, finds the training descriptors not farther than the specified distance.\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **maxDistance**: `float`.\n\n  Threshold for the distance between matched descriptors. Distance means here\n  metric distance (e.g. Hamming distance), not the distance between coordinates (which is measured\n  in Pixels)!\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Found matches.\n\nFor each query descriptor, the methods find such training descriptors that the distance between the\nquery descriptor and the training descriptor is equal or smaller than maxDistance. Found matches are\nreturned in the distance increasing order.\n\nPython prototype (for reference only):\n```python3\nradiusMatch(queryDescriptors, trainDescriptors, maxDistance[, mask[, compactResult]]) -> matches\n```\n#### Variant 2:\nradiusMatch\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **maxDistance**: `float`.\n\n  Threshold for the distance between matched descriptors. Distance means here\n  metric distance (e.g. Hamming distance), not the distance between coordinates (which is measured\n  in Pixels)!\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Set of masks. Each masks[i] specifies permissible matches between the input query\n  descriptors and stored train descriptors from the i-th image trainDescCollection[i].\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Found matches.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nradiusMatch(queryDescriptors, maxDistance[, masks[, compactResult]]) -> matches\n```","ref":"Evision.BFMatcher.html#radiusMatch/4"},{"type":"function","title":"Evision.BFMatcher.radiusMatch/5","doc":"For each query descriptor, finds the training descriptors not farther than the specified distance.\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **maxDistance**: `float`.\n\n  Threshold for the distance between matched descriptors. Distance means here\n  metric distance (e.g. Hamming distance), not the distance between coordinates (which is measured\n  in Pixels)!\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Found matches.\n\nFor each query descriptor, the methods find such training descriptors that the distance between the\nquery descriptor and the training descriptor is equal or smaller than maxDistance. Found matches are\nreturned in the distance increasing order.\n\nPython prototype (for reference only):\n```python3\nradiusMatch(queryDescriptors, trainDescriptors, maxDistance[, mask[, compactResult]]) -> matches\n```","ref":"Evision.BFMatcher.html#radiusMatch/5"},{"type":"function","title":"Evision.BFMatcher.read/1","doc":"","ref":"Evision.BFMatcher.html#read/1"},{"type":"function","title":"Evision.BFMatcher.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.BFMatcher.html#read/2"},{"type":"function","title":"Evision.BFMatcher.save/1","doc":"","ref":"Evision.BFMatcher.html#save/1"},{"type":"function","title":"Evision.BFMatcher.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.BFMatcher.html#save/2"},{"type":"function","title":"Evision.BFMatcher.train/1","doc":"Trains a descriptor matcher\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n\nTrains a descriptor matcher (for example, the flann index). In all methods to match, the method\ntrain() is run every time before matching. Some descriptor matchers (for example, BruteForceMatcher)\nhave an empty implementation of this method. Other matchers really train their inner structures (for\nexample, FlannBasedMatcher trains flann::Index ).\n\nPython prototype (for reference only):\n```python3\ntrain() -> None\n```","ref":"Evision.BFMatcher.html#train/1"},{"type":"function","title":"Evision.BFMatcher.write/1","doc":"","ref":"Evision.BFMatcher.html#write/1"},{"type":"function","title":"Evision.BFMatcher.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.BFMatcher.html#write/2"},{"type":"function","title":"Evision.BFMatcher.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.BFMatcher.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.BFMatcher.html#write/3"},{"type":"type","title":"Evision.BFMatcher.t/0","doc":"Type that represents an `BFMatcher` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.BFMatcher.html#t:t/0"},{"type":"module","title":"Evision.BOWImgDescriptorExtractor","doc":"","ref":"Evision.BOWImgDescriptorExtractor.html"},{"type":"function","title":"Evision.BOWImgDescriptorExtractor.bowImgDescriptorExtractor/1","doc":"","ref":"Evision.BOWImgDescriptorExtractor.html#bowImgDescriptorExtractor/1"},{"type":"function","title":"Evision.BOWImgDescriptorExtractor.bowImgDescriptorExtractor/2","doc":"The constructor.\n\n##### Positional Arguments\n- **dextractor**: `Evision.Feature2D`.\n\n  Descriptor extractor that is used to compute descriptors for an input image and\n  its keypoints.\n\n- **dmatcher**: `Evision.DescriptorMatcher`.\n\n  Descriptor matcher that is used to find the nearest word of the trained vocabulary\n  for each keypoint descriptor of the image.\n\n##### Return\n- **self**: `Evision.BOWImgDescriptorExtractor.t()`\n\nPython prototype (for reference only):\n```python3\nBOWImgDescriptorExtractor(dextractor, dmatcher) ->  \n```","ref":"Evision.BOWImgDescriptorExtractor.html#bowImgDescriptorExtractor/2"},{"type":"function","title":"Evision.BOWImgDescriptorExtractor.compute/1","doc":"","ref":"Evision.BOWImgDescriptorExtractor.html#compute/1"},{"type":"function","title":"Evision.BOWImgDescriptorExtractor.compute/3","doc":"compute\n\n##### Positional Arguments\n- **self**: `Evision.BOWImgDescriptorExtractor.t()`\n- **image**: `Evision.Mat`\n- **keypoints**: `[Evision.KeyPoint]`\n\n##### Return\n- **imgDescriptor**: `Evision.Mat.t()`.\n\n  Computed output image descriptor.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, imgDescriptor]) -> imgDescriptor\n```","ref":"Evision.BOWImgDescriptorExtractor.html#compute/3"},{"type":"function","title":"Evision.BOWImgDescriptorExtractor.compute/4","doc":"compute\n\n##### Positional Arguments\n- **self**: `Evision.BOWImgDescriptorExtractor.t()`\n- **image**: `Evision.Mat`\n- **keypoints**: `[Evision.KeyPoint]`\n\n##### Return\n- **imgDescriptor**: `Evision.Mat.t()`.\n\n  Computed output image descriptor.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, imgDescriptor]) -> imgDescriptor\n```","ref":"Evision.BOWImgDescriptorExtractor.html#compute/4"},{"type":"function","title":"Evision.BOWImgDescriptorExtractor.descriptorSize/1","doc":"Returns an image descriptor size if the vocabulary is set. Otherwise, it returns 0.\n\n##### Positional Arguments\n- **self**: `Evision.BOWImgDescriptorExtractor.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.BOWImgDescriptorExtractor.html#descriptorSize/1"},{"type":"function","title":"Evision.BOWImgDescriptorExtractor.descriptorType/1","doc":"Returns an image descriptor type.\n\n##### Positional Arguments\n- **self**: `Evision.BOWImgDescriptorExtractor.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.BOWImgDescriptorExtractor.html#descriptorType/1"},{"type":"function","title":"Evision.BOWImgDescriptorExtractor.getVocabulary/1","doc":"Returns the set vocabulary.\n\n##### Positional Arguments\n- **self**: `Evision.BOWImgDescriptorExtractor.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetVocabulary() -> retval\n```","ref":"Evision.BOWImgDescriptorExtractor.html#getVocabulary/1"},{"type":"function","title":"Evision.BOWImgDescriptorExtractor.setVocabulary/1","doc":"","ref":"Evision.BOWImgDescriptorExtractor.html#setVocabulary/1"},{"type":"function","title":"Evision.BOWImgDescriptorExtractor.setVocabulary/2","doc":"Sets a visual vocabulary.\n\n##### Positional Arguments\n- **self**: `Evision.BOWImgDescriptorExtractor.t()`\n- **vocabulary**: `Evision.Mat`.\n\n  Vocabulary (can be trained using the inheritor of BOWTrainer ). Each row of the\n  vocabulary is a visual word (cluster center).\n\nPython prototype (for reference only):\n```python3\nsetVocabulary(vocabulary) -> None\n```","ref":"Evision.BOWImgDescriptorExtractor.html#setVocabulary/2"},{"type":"type","title":"Evision.BOWImgDescriptorExtractor.t/0","doc":"Type that represents an `BOWImgDescriptorExtractor` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.BOWImgDescriptorExtractor.html#t:t/0"},{"type":"module","title":"Evision.BOWKMeansTrainer","doc":"","ref":"Evision.BOWKMeansTrainer.html"},{"type":"function","title":"Evision.BOWKMeansTrainer.bowKMeansTrainer/1","doc":"The constructor.\n\n##### Positional Arguments\n- **clusterCount**: `integer()`\n\n##### Keyword Arguments\n- **termcrit**: `TermCriteria`.\n- **attempts**: `integer()`.\n- **flags**: `integer()`.\n\n##### Return\n- **self**: `Evision.BOWKMeansTrainer.t()`\n\n@see cv::kmeans\n\nPython prototype (for reference only):\n```python3\nBOWKMeansTrainer(clusterCount[, termcrit[, attempts[, flags]]]) ->  \n```","ref":"Evision.BOWKMeansTrainer.html#bowKMeansTrainer/1"},{"type":"function","title":"Evision.BOWKMeansTrainer.bowKMeansTrainer/2","doc":"The constructor.\n\n##### Positional Arguments\n- **clusterCount**: `integer()`\n\n##### Keyword Arguments\n- **termcrit**: `TermCriteria`.\n- **attempts**: `integer()`.\n- **flags**: `integer()`.\n\n##### Return\n- **self**: `Evision.BOWKMeansTrainer.t()`\n\n@see cv::kmeans\n\nPython prototype (for reference only):\n```python3\nBOWKMeansTrainer(clusterCount[, termcrit[, attempts[, flags]]]) ->  \n```","ref":"Evision.BOWKMeansTrainer.html#bowKMeansTrainer/2"},{"type":"function","title":"Evision.BOWKMeansTrainer.cluster/1","doc":"cluster\n\n##### Positional Arguments\n- **self**: `Evision.BOWKMeansTrainer.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ncluster() -> retval\n```","ref":"Evision.BOWKMeansTrainer.html#cluster/1"},{"type":"function","title":"Evision.BOWKMeansTrainer.cluster/2","doc":"cluster\n\n##### Positional Arguments\n- **self**: `Evision.BOWKMeansTrainer.t()`\n- **descriptors**: `Evision.Mat`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ncluster(descriptors) -> retval\n```","ref":"Evision.BOWKMeansTrainer.html#cluster/2"},{"type":"type","title":"Evision.BOWKMeansTrainer.t/0","doc":"Type that represents an `BOWKMeansTrainer` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.BOWKMeansTrainer.html#t:t/0"},{"type":"module","title":"Evision.BOWTrainer","doc":"","ref":"Evision.BOWTrainer.html"},{"type":"function","title":"Evision.BOWTrainer.add/1","doc":"","ref":"Evision.BOWTrainer.html#add/1"},{"type":"function","title":"Evision.BOWTrainer.add/2","doc":"Adds descriptors to a training set.\n\n##### Positional Arguments\n- **self**: `Evision.BOWTrainer.t()`\n- **descriptors**: `Evision.Mat`.\n\n  Descriptors to add to a training set. Each row of the descriptors matrix is a\n  descriptor.\n\nThe training set is clustered using clustermethod to construct the vocabulary.\n\nPython prototype (for reference only):\n```python3\nadd(descriptors) -> None\n```","ref":"Evision.BOWTrainer.html#add/2"},{"type":"function","title":"Evision.BOWTrainer.clear/1","doc":"clear\n\n##### Positional Arguments\n- **self**: `Evision.BOWTrainer.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.BOWTrainer.html#clear/1"},{"type":"function","title":"Evision.BOWTrainer.cluster/1","doc":"cluster\n\n##### Positional Arguments\n- **self**: `Evision.BOWTrainer.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncluster() -> retval\n```","ref":"Evision.BOWTrainer.html#cluster/1"},{"type":"function","title":"Evision.BOWTrainer.cluster/2","doc":"Clusters train descriptors.\n\n##### Positional Arguments\n- **self**: `Evision.BOWTrainer.t()`\n- **descriptors**: `Evision.Mat`.\n\n  Descriptors to cluster. Each row of the descriptors matrix is a descriptor.\n  Descriptors are not added to the inner train descriptor set.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nThe vocabulary consists of cluster centers. So, this method returns the vocabulary. In the first\nvariant of the method, train descriptors stored in the object are clustered. In the second variant,\ninput descriptors are clustered.\n\nPython prototype (for reference only):\n```python3\ncluster(descriptors) -> retval\n```","ref":"Evision.BOWTrainer.html#cluster/2"},{"type":"function","title":"Evision.BOWTrainer.descriptorsCount/1","doc":"Returns the count of all descriptors stored in the training set.\n\n##### Positional Arguments\n- **self**: `Evision.BOWTrainer.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorsCount() -> retval\n```","ref":"Evision.BOWTrainer.html#descriptorsCount/1"},{"type":"function","title":"Evision.BOWTrainer.getDescriptors/1","doc":"Returns a training set of descriptors.\n\n##### Positional Arguments\n- **self**: `Evision.BOWTrainer.t()`\n\n##### Return\n- **retval**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\ngetDescriptors() -> retval\n```","ref":"Evision.BOWTrainer.html#getDescriptors/1"},{"type":"type","title":"Evision.BOWTrainer.t/0","doc":"Type that represents an `BOWTrainer` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.BOWTrainer.html#t:t/0"},{"type":"module","title":"Evision.BRISK","doc":"","ref":"Evision.BRISK.html"},{"type":"function","title":"Evision.BRISK.compute/1","doc":"","ref":"Evision.BRISK.html#compute/1"},{"type":"function","title":"Evision.BRISK.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.BRISK.html#compute/3"},{"type":"function","title":"Evision.BRISK.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.BRISK.html#compute/4"},{"type":"function","title":"Evision.BRISK.create/0","doc":"The BRISK constructor\n##### Keyword Arguments\n- **thresh**: `integer()`.\n\n  AGAST detection threshold score.\n\n- **octaves**: `integer()`.\n\n  detection octaves. Use 0 to do single scale.\n\n- **patternScale**: `float`.\n\n  apply this scale to the pattern used for sampling the neighbourhood of a\n  keypoint.\n\n##### Return\n- **retval**: `Evision.BRISK.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, thresh[, octaves[, patternScale]]]) -> retval\n```","ref":"Evision.BRISK.html#create/0"},{"type":"function","title":"Evision.BRISK.create/1","doc":"The BRISK constructor\n##### Keyword Arguments\n- **thresh**: `integer()`.\n\n  AGAST detection threshold score.\n\n- **octaves**: `integer()`.\n\n  detection octaves. Use 0 to do single scale.\n\n- **patternScale**: `float`.\n\n  apply this scale to the pattern used for sampling the neighbourhood of a\n  keypoint.\n\n##### Return\n- **retval**: `Evision.BRISK.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, thresh[, octaves[, patternScale]]]) -> retval\n```","ref":"Evision.BRISK.html#create/1"},{"type":"function","title":"Evision.BRISK.create/2","doc":"The BRISK constructor for a custom pattern\n\n##### Positional Arguments\n- **radiusList**: `[float]`.\n\n  defines the radii (in pixels) where the samples around a keypoint are taken (for\n  keypoint scale 1).\n\n- **numberList**: `[integer()]`.\n\n  defines the number of sampling points on the sampling circle. Must be the same\n  size as radiusList..\n\n##### Keyword Arguments\n- **dMax**: `float`.\n\n  threshold for the short pairings used for descriptor formation (in pixels for keypoint\n  scale 1).\n\n- **dMin**: `float`.\n\n  threshold for the long pairings used for orientation determination (in pixels for\n  keypoint scale 1).\n\n- **indexChange**: `[integer()]`.\n\n  index remapping of the bits.\n\n##### Return\n- **retval**: `Evision.BRISK.t()`\n\nPython prototype (for reference only):\n```python3\ncreate(radiusList, numberList[, dMax[, dMin[, indexChange]]]) -> retval\n```","ref":"Evision.BRISK.html#create/2"},{"type":"function","title":"Evision.BRISK.create/3","doc":"The BRISK constructor for a custom pattern\n\n##### Positional Arguments\n- **radiusList**: `[float]`.\n\n  defines the radii (in pixels) where the samples around a keypoint are taken (for\n  keypoint scale 1).\n\n- **numberList**: `[integer()]`.\n\n  defines the number of sampling points on the sampling circle. Must be the same\n  size as radiusList..\n\n##### Keyword Arguments\n- **dMax**: `float`.\n\n  threshold for the short pairings used for descriptor formation (in pixels for keypoint\n  scale 1).\n\n- **dMin**: `float`.\n\n  threshold for the long pairings used for orientation determination (in pixels for\n  keypoint scale 1).\n\n- **indexChange**: `[integer()]`.\n\n  index remapping of the bits.\n\n##### Return\n- **retval**: `Evision.BRISK.t()`\n\nPython prototype (for reference only):\n```python3\ncreate(radiusList, numberList[, dMax[, dMin[, indexChange]]]) -> retval\n```","ref":"Evision.BRISK.html#create/3"},{"type":"function","title":"Evision.BRISK.create/4","doc":"The BRISK constructor for a custom pattern, detection threshold and octaves\n\n##### Positional Arguments\n- **thresh**: `integer()`.\n\n  AGAST detection threshold score.\n\n- **octaves**: `integer()`.\n\n  detection octaves. Use 0 to do single scale.\n\n- **radiusList**: `[float]`.\n\n  defines the radii (in pixels) where the samples around a keypoint are taken (for\n  keypoint scale 1).\n\n- **numberList**: `[integer()]`.\n\n  defines the number of sampling points on the sampling circle. Must be the same\n  size as radiusList..\n\n##### Keyword Arguments\n- **dMax**: `float`.\n\n  threshold for the short pairings used for descriptor formation (in pixels for keypoint\n  scale 1).\n\n- **dMin**: `float`.\n\n  threshold for the long pairings used for orientation determination (in pixels for\n  keypoint scale 1).\n\n- **indexChange**: `[integer()]`.\n\n  index remapping of the bits.\n\n##### Return\n- **retval**: `Evision.BRISK.t()`\n\nPython prototype (for reference only):\n```python3\ncreate(thresh, octaves, radiusList, numberList[, dMax[, dMin[, indexChange]]]) -> retval\n```","ref":"Evision.BRISK.html#create/4"},{"type":"function","title":"Evision.BRISK.create/5","doc":"The BRISK constructor for a custom pattern, detection threshold and octaves\n\n##### Positional Arguments\n- **thresh**: `integer()`.\n\n  AGAST detection threshold score.\n\n- **octaves**: `integer()`.\n\n  detection octaves. Use 0 to do single scale.\n\n- **radiusList**: `[float]`.\n\n  defines the radii (in pixels) where the samples around a keypoint are taken (for\n  keypoint scale 1).\n\n- **numberList**: `[integer()]`.\n\n  defines the number of sampling points on the sampling circle. Must be the same\n  size as radiusList..\n\n##### Keyword Arguments\n- **dMax**: `float`.\n\n  threshold for the short pairings used for descriptor formation (in pixels for keypoint\n  scale 1).\n\n- **dMin**: `float`.\n\n  threshold for the long pairings used for orientation determination (in pixels for\n  keypoint scale 1).\n\n- **indexChange**: `[integer()]`.\n\n  index remapping of the bits.\n\n##### Return\n- **retval**: `Evision.BRISK.t()`\n\nPython prototype (for reference only):\n```python3\ncreate(thresh, octaves, radiusList, numberList[, dMax[, dMin[, indexChange]]]) -> retval\n```","ref":"Evision.BRISK.html#create/5"},{"type":"function","title":"Evision.BRISK.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.BRISK.html#defaultNorm/1"},{"type":"function","title":"Evision.BRISK.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.BRISK.html#descriptorSize/1"},{"type":"function","title":"Evision.BRISK.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.BRISK.html#descriptorType/1"},{"type":"function","title":"Evision.BRISK.detect/1","doc":"","ref":"Evision.BRISK.html#detect/1"},{"type":"function","title":"Evision.BRISK.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.BRISK.html#detect/2"},{"type":"function","title":"Evision.BRISK.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.BRISK.html#detect/3"},{"type":"function","title":"Evision.BRISK.detectAndCompute/1","doc":"","ref":"Evision.BRISK.html#detectAndCompute/1"},{"type":"function","title":"Evision.BRISK.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.BRISK.html#detectAndCompute/3"},{"type":"function","title":"Evision.BRISK.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.BRISK.html#detectAndCompute/4"},{"type":"function","title":"Evision.BRISK.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.BRISK.html#empty/1"},{"type":"function","title":"Evision.BRISK.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.BRISK.html#getDefaultName/1"},{"type":"function","title":"Evision.BRISK.getOctaves/1","doc":"getOctaves\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetOctaves() -> retval\n```","ref":"Evision.BRISK.html#getOctaves/1"},{"type":"function","title":"Evision.BRISK.getPatternScale/1","doc":"getPatternScale\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetPatternScale() -> retval\n```","ref":"Evision.BRISK.html#getPatternScale/1"},{"type":"function","title":"Evision.BRISK.getThreshold/1","doc":"getThreshold\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetThreshold() -> retval\n```","ref":"Evision.BRISK.html#getThreshold/1"},{"type":"function","title":"Evision.BRISK.read/1","doc":"","ref":"Evision.BRISK.html#read/1"},{"type":"function","title":"Evision.BRISK.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.BRISK.html#read/2"},{"type":"function","title":"Evision.BRISK.setOctaves/1","doc":"","ref":"Evision.BRISK.html#setOctaves/1"},{"type":"function","title":"Evision.BRISK.setOctaves/2","doc":"Set detection octaves.\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n- **octaves**: `integer()`.\n\n  detection octaves. Use 0 to do single scale.\n\nPython prototype (for reference only):\n```python3\nsetOctaves(octaves) -> None\n```","ref":"Evision.BRISK.html#setOctaves/2"},{"type":"function","title":"Evision.BRISK.setPatternScale/1","doc":"","ref":"Evision.BRISK.html#setPatternScale/1"},{"type":"function","title":"Evision.BRISK.setPatternScale/2","doc":"Set detection patternScale.\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n- **patternScale**: `float`.\n\n  apply this scale to the pattern used for sampling the neighbourhood of a\n  keypoint.\n\nPython prototype (for reference only):\n```python3\nsetPatternScale(patternScale) -> None\n```","ref":"Evision.BRISK.html#setPatternScale/2"},{"type":"function","title":"Evision.BRISK.setThreshold/1","doc":"","ref":"Evision.BRISK.html#setThreshold/1"},{"type":"function","title":"Evision.BRISK.setThreshold/2","doc":"Set detection threshold.\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n- **threshold**: `integer()`.\n\n  AGAST detection threshold score.\n\nPython prototype (for reference only):\n```python3\nsetThreshold(threshold) -> None\n```","ref":"Evision.BRISK.html#setThreshold/2"},{"type":"function","title":"Evision.BRISK.write/1","doc":"","ref":"Evision.BRISK.html#write/1"},{"type":"function","title":"Evision.BRISK.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.BRISK.html#write/2"},{"type":"function","title":"Evision.BRISK.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.BRISK.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.BRISK.html#write/3"},{"type":"type","title":"Evision.BRISK.t/0","doc":"Type that represents an `BRISK` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.BRISK.html#t:t/0"},{"type":"module","title":"Evision.Backend","doc":"","ref":"Evision.Backend.html"},{"type":"function","title":"Evision.Backend.constant/3","doc":"Tensor with constant values.","ref":"Evision.Backend.html#constant/3"},{"type":"function","title":"Example - Evision.Backend.constant/3","doc":"Nx.tensor(1.0, backend: Evision.Backend)\n    #Nx.Tensor","ref":"Evision.Backend.html#constant/3-example"},{"type":"module","title":"Evision.BackgroundSubtractor","doc":"","ref":"Evision.BackgroundSubtractor.html"},{"type":"function","title":"Evision.BackgroundSubtractor.apply/1","doc":"","ref":"Evision.BackgroundSubtractor.html#apply/1"},{"type":"function","title":"Evision.BackgroundSubtractor.apply/2","doc":"Computes a foreground mask.\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractor.t()`\n- **image**: `Evision.Mat`.\n\n  Next video frame.\n\n##### Keyword Arguments\n- **learningRate**: `double`.\n\n  The value between 0 and 1 that indicates how fast the background model is\n  learnt. Negative parameter value makes the algorithm to use some automatically chosen learning\n  rate. 0 means that the background model is not updated at all, 1 means that the background model\n  is completely reinitialized from the last frame.\n\n##### Return\n- **fgmask**: `Evision.Mat.t()`.\n\n  The output foreground mask as an 8-bit binary image.\n\nPython prototype (for reference only):\n```python3\napply(image[, fgmask[, learningRate]]) -> fgmask\n```","ref":"Evision.BackgroundSubtractor.html#apply/2"},{"type":"function","title":"Evision.BackgroundSubtractor.apply/3","doc":"Computes a foreground mask.\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractor.t()`\n- **image**: `Evision.Mat`.\n\n  Next video frame.\n\n##### Keyword Arguments\n- **learningRate**: `double`.\n\n  The value between 0 and 1 that indicates how fast the background model is\n  learnt. Negative parameter value makes the algorithm to use some automatically chosen learning\n  rate. 0 means that the background model is not updated at all, 1 means that the background model\n  is completely reinitialized from the last frame.\n\n##### Return\n- **fgmask**: `Evision.Mat.t()`.\n\n  The output foreground mask as an 8-bit binary image.\n\nPython prototype (for reference only):\n```python3\napply(image[, fgmask[, learningRate]]) -> fgmask\n```","ref":"Evision.BackgroundSubtractor.html#apply/3"},{"type":"function","title":"Evision.BackgroundSubtractor.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractor.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.BackgroundSubtractor.html#clear/1"},{"type":"function","title":"Evision.BackgroundSubtractor.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractor.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.BackgroundSubtractor.html#empty/1"},{"type":"function","title":"Evision.BackgroundSubtractor.getBackgroundImage/1","doc":"Computes a background image.\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractor.t()`\n\n##### Return\n- **backgroundImage**: `Evision.Mat.t()`.\n\n  The output background image.\n\n**Note**: Sometimes the background image can be very blurry, as it contain the average background\nstatistics.\n\nPython prototype (for reference only):\n```python3\ngetBackgroundImage([, backgroundImage]) -> backgroundImage\n```","ref":"Evision.BackgroundSubtractor.html#getBackgroundImage/1"},{"type":"function","title":"Evision.BackgroundSubtractor.getBackgroundImage/2","doc":"Computes a background image.\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractor.t()`\n\n##### Return\n- **backgroundImage**: `Evision.Mat.t()`.\n\n  The output background image.\n\n**Note**: Sometimes the background image can be very blurry, as it contain the average background\nstatistics.\n\nPython prototype (for reference only):\n```python3\ngetBackgroundImage([, backgroundImage]) -> backgroundImage\n```","ref":"Evision.BackgroundSubtractor.html#getBackgroundImage/2"},{"type":"function","title":"Evision.BackgroundSubtractor.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractor.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.BackgroundSubtractor.html#getDefaultName/1"},{"type":"function","title":"Evision.BackgroundSubtractor.read/1","doc":"","ref":"Evision.BackgroundSubtractor.html#read/1"},{"type":"function","title":"Evision.BackgroundSubtractor.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractor.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.BackgroundSubtractor.html#read/2"},{"type":"function","title":"Evision.BackgroundSubtractor.save/1","doc":"","ref":"Evision.BackgroundSubtractor.html#save/1"},{"type":"function","title":"Evision.BackgroundSubtractor.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractor.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.BackgroundSubtractor.html#save/2"},{"type":"function","title":"Evision.BackgroundSubtractor.write/1","doc":"","ref":"Evision.BackgroundSubtractor.html#write/1"},{"type":"function","title":"Evision.BackgroundSubtractor.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractor.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.BackgroundSubtractor.html#write/2"},{"type":"function","title":"Evision.BackgroundSubtractor.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractor.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.BackgroundSubtractor.html#write/3"},{"type":"type","title":"Evision.BackgroundSubtractor.t/0","doc":"Type that represents an `BackgroundSubtractor` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.BackgroundSubtractor.html#t:t/0"},{"type":"module","title":"Evision.BackgroundSubtractorKNN","doc":"","ref":"Evision.BackgroundSubtractorKNN.html"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.apply/1","doc":"","ref":"Evision.BackgroundSubtractorKNN.html#apply/1"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.apply/2","doc":"Computes a foreground mask.\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n- **image**: `Evision.Mat`.\n\n  Next video frame.\n\n##### Keyword Arguments\n- **learningRate**: `double`.\n\n  The value between 0 and 1 that indicates how fast the background model is\n  learnt. Negative parameter value makes the algorithm to use some automatically chosen learning\n  rate. 0 means that the background model is not updated at all, 1 means that the background model\n  is completely reinitialized from the last frame.\n\n##### Return\n- **fgmask**: `Evision.Mat.t()`.\n\n  The output foreground mask as an 8-bit binary image.\n\nPython prototype (for reference only):\n```python3\napply(image[, fgmask[, learningRate]]) -> fgmask\n```","ref":"Evision.BackgroundSubtractorKNN.html#apply/2"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.apply/3","doc":"Computes a foreground mask.\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n- **image**: `Evision.Mat`.\n\n  Next video frame.\n\n##### Keyword Arguments\n- **learningRate**: `double`.\n\n  The value between 0 and 1 that indicates how fast the background model is\n  learnt. Negative parameter value makes the algorithm to use some automatically chosen learning\n  rate. 0 means that the background model is not updated at all, 1 means that the background model\n  is completely reinitialized from the last frame.\n\n##### Return\n- **fgmask**: `Evision.Mat.t()`.\n\n  The output foreground mask as an 8-bit binary image.\n\nPython prototype (for reference only):\n```python3\napply(image[, fgmask[, learningRate]]) -> fgmask\n```","ref":"Evision.BackgroundSubtractorKNN.html#apply/3"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.BackgroundSubtractorKNN.html#clear/1"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.BackgroundSubtractorKNN.html#empty/1"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.getBackgroundImage/1","doc":"Computes a background image.\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n\n##### Return\n- **backgroundImage**: `Evision.Mat.t()`.\n\n  The output background image.\n\n**Note**: Sometimes the background image can be very blurry, as it contain the average background\nstatistics.\n\nPython prototype (for reference only):\n```python3\ngetBackgroundImage([, backgroundImage]) -> backgroundImage\n```","ref":"Evision.BackgroundSubtractorKNN.html#getBackgroundImage/1"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.getBackgroundImage/2","doc":"Computes a background image.\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n\n##### Return\n- **backgroundImage**: `Evision.Mat.t()`.\n\n  The output background image.\n\n**Note**: Sometimes the background image can be very blurry, as it contain the average background\nstatistics.\n\nPython prototype (for reference only):\n```python3\ngetBackgroundImage([, backgroundImage]) -> backgroundImage\n```","ref":"Evision.BackgroundSubtractorKNN.html#getBackgroundImage/2"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.BackgroundSubtractorKNN.html#getDefaultName/1"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.getDetectShadows/1","doc":"Returns the shadow detection flag\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n\n##### Return\n- **retval**: `bool`\n\nIf true, the algorithm detects shadows and marks them. See createBackgroundSubtractorKNN for\ndetails.\n\nPython prototype (for reference only):\n```python3\ngetDetectShadows() -> retval\n```","ref":"Evision.BackgroundSubtractorKNN.html#getDetectShadows/1"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.getDist2Threshold/1","doc":"Returns the threshold on the squared distance between the pixel and the sample\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n\n##### Return\n- **retval**: `double`\n\nThe threshold on the squared distance between the pixel and the sample to decide whether a pixel is\nclose to a data sample.\n\nPython prototype (for reference only):\n```python3\ngetDist2Threshold() -> retval\n```","ref":"Evision.BackgroundSubtractorKNN.html#getDist2Threshold/1"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.getHistory/1","doc":"Returns the number of last frames that affect the background model\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetHistory() -> retval\n```","ref":"Evision.BackgroundSubtractorKNN.html#getHistory/1"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.getkNNSamples/1","doc":"Returns the number of neighbours, the k in the kNN.\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n\n##### Return\n- **retval**: `integer()`\n\nK is the number of samples that need to be within dist2Threshold in order to decide that that\npixel is matching the kNN background model.\n\nPython prototype (for reference only):\n```python3\ngetkNNSamples() -> retval\n```","ref":"Evision.BackgroundSubtractorKNN.html#getkNNSamples/1"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.getNSamples/1","doc":"Returns the number of data samples in the background model\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNSamples() -> retval\n```","ref":"Evision.BackgroundSubtractorKNN.html#getNSamples/1"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.getShadowThreshold/1","doc":"Returns the shadow threshold\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n\n##### Return\n- **retval**: `double`\n\nA shadow is detected if pixel is a darker version of the background. The shadow threshold (Tau in\nthe paper) is a threshold defining how much darker the shadow can be. Tau= 0.5 means that if a pixel\nis more than twice darker then it is not shadow. See Prati, Mikic, Trivedi and Cucchiara,\nDetecting Moving Shadows...*, IEEE PAMI,2003.\n\nPython prototype (for reference only):\n```python3\ngetShadowThreshold() -> retval\n```","ref":"Evision.BackgroundSubtractorKNN.html#getShadowThreshold/1"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.getShadowValue/1","doc":"Returns the shadow value\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n\n##### Return\n- **retval**: `integer()`\n\nShadow value is the value used to mark shadows in the foreground mask. Default value is 127. Value 0\nin the mask always means background, 255 means foreground.\n\nPython prototype (for reference only):\n```python3\ngetShadowValue() -> retval\n```","ref":"Evision.BackgroundSubtractorKNN.html#getShadowValue/1"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.read/1","doc":"","ref":"Evision.BackgroundSubtractorKNN.html#read/1"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.BackgroundSubtractorKNN.html#read/2"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.save/1","doc":"","ref":"Evision.BackgroundSubtractorKNN.html#save/1"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.BackgroundSubtractorKNN.html#save/2"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.setDetectShadows/1","doc":"","ref":"Evision.BackgroundSubtractorKNN.html#setDetectShadows/1"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.setDetectShadows/2","doc":"Enables or disables shadow detection\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n- **detectShadows**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetDetectShadows(detectShadows) -> None\n```","ref":"Evision.BackgroundSubtractorKNN.html#setDetectShadows/2"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.setDist2Threshold/1","doc":"","ref":"Evision.BackgroundSubtractorKNN.html#setDist2Threshold/1"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.setDist2Threshold/2","doc":"Sets the threshold on the squared distance\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n- **dist2Threshold**: `double`\n\nPython prototype (for reference only):\n```python3\nsetDist2Threshold(_dist2Threshold) -> None\n```","ref":"Evision.BackgroundSubtractorKNN.html#setDist2Threshold/2"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.setHistory/1","doc":"","ref":"Evision.BackgroundSubtractorKNN.html#setHistory/1"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.setHistory/2","doc":"Sets the number of last frames that affect the background model\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n- **history**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetHistory(history) -> None\n```","ref":"Evision.BackgroundSubtractorKNN.html#setHistory/2"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.setkNNSamples/1","doc":"","ref":"Evision.BackgroundSubtractorKNN.html#setkNNSamples/1"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.setkNNSamples/2","doc":"Sets the k in the kNN. How many nearest neighbours need to match.\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n- **nkNN**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetkNNSamples(_nkNN) -> None\n```","ref":"Evision.BackgroundSubtractorKNN.html#setkNNSamples/2"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.setNSamples/1","doc":"","ref":"Evision.BackgroundSubtractorKNN.html#setNSamples/1"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.setNSamples/2","doc":"Sets the number of data samples in the background model.\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n- **nN**: `integer()`\n\nThe model needs to be reinitalized to reserve memory.\n\nPython prototype (for reference only):\n```python3\nsetNSamples(_nN) -> None\n```","ref":"Evision.BackgroundSubtractorKNN.html#setNSamples/2"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.setShadowThreshold/1","doc":"","ref":"Evision.BackgroundSubtractorKNN.html#setShadowThreshold/1"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.setShadowThreshold/2","doc":"Sets the shadow threshold\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n- **threshold**: `double`\n\nPython prototype (for reference only):\n```python3\nsetShadowThreshold(threshold) -> None\n```","ref":"Evision.BackgroundSubtractorKNN.html#setShadowThreshold/2"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.setShadowValue/1","doc":"","ref":"Evision.BackgroundSubtractorKNN.html#setShadowValue/1"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.setShadowValue/2","doc":"Sets the shadow value\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n- **value**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetShadowValue(value) -> None\n```","ref":"Evision.BackgroundSubtractorKNN.html#setShadowValue/2"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.write/1","doc":"","ref":"Evision.BackgroundSubtractorKNN.html#write/1"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.BackgroundSubtractorKNN.html#write/2"},{"type":"function","title":"Evision.BackgroundSubtractorKNN.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorKNN.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.BackgroundSubtractorKNN.html#write/3"},{"type":"type","title":"Evision.BackgroundSubtractorKNN.t/0","doc":"Type that represents an `BackgroundSubtractorKNN` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.BackgroundSubtractorKNN.html#t:t/0"},{"type":"module","title":"Evision.BackgroundSubtractorMOG2","doc":"","ref":"Evision.BackgroundSubtractorMOG2.html"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.apply/1","doc":"","ref":"Evision.BackgroundSubtractorMOG2.html#apply/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.apply/2","doc":"Computes a foreground mask.\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n- **image**: `Evision.Mat`.\n\n  Next video frame. Floating point frame will be used without scaling and should be in range \\f$[0,255]\\f$.\n\n##### Keyword Arguments\n- **learningRate**: `double`.\n\n  The value between 0 and 1 that indicates how fast the background model is\n  learnt. Negative parameter value makes the algorithm to use some automatically chosen learning\n  rate. 0 means that the background model is not updated at all, 1 means that the background model\n  is completely reinitialized from the last frame.\n\n##### Return\n- **fgmask**: `Evision.Mat.t()`.\n\n  The output foreground mask as an 8-bit binary image.\n\nPython prototype (for reference only):\n```python3\napply(image[, fgmask[, learningRate]]) -> fgmask\n```","ref":"Evision.BackgroundSubtractorMOG2.html#apply/2"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.apply/3","doc":"Computes a foreground mask.\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n- **image**: `Evision.Mat`.\n\n  Next video frame. Floating point frame will be used without scaling and should be in range \\f$[0,255]\\f$.\n\n##### Keyword Arguments\n- **learningRate**: `double`.\n\n  The value between 0 and 1 that indicates how fast the background model is\n  learnt. Negative parameter value makes the algorithm to use some automatically chosen learning\n  rate. 0 means that the background model is not updated at all, 1 means that the background model\n  is completely reinitialized from the last frame.\n\n##### Return\n- **fgmask**: `Evision.Mat.t()`.\n\n  The output foreground mask as an 8-bit binary image.\n\nPython prototype (for reference only):\n```python3\napply(image[, fgmask[, learningRate]]) -> fgmask\n```","ref":"Evision.BackgroundSubtractorMOG2.html#apply/3"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.BackgroundSubtractorMOG2.html#clear/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.BackgroundSubtractorMOG2.html#empty/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.getBackgroundImage/1","doc":"Computes a background image.\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n\n##### Return\n- **backgroundImage**: `Evision.Mat.t()`.\n\n  The output background image.\n\n**Note**: Sometimes the background image can be very blurry, as it contain the average background\nstatistics.\n\nPython prototype (for reference only):\n```python3\ngetBackgroundImage([, backgroundImage]) -> backgroundImage\n```","ref":"Evision.BackgroundSubtractorMOG2.html#getBackgroundImage/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.getBackgroundImage/2","doc":"Computes a background image.\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n\n##### Return\n- **backgroundImage**: `Evision.Mat.t()`.\n\n  The output background image.\n\n**Note**: Sometimes the background image can be very blurry, as it contain the average background\nstatistics.\n\nPython prototype (for reference only):\n```python3\ngetBackgroundImage([, backgroundImage]) -> backgroundImage\n```","ref":"Evision.BackgroundSubtractorMOG2.html#getBackgroundImage/2"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.getBackgroundRatio/1","doc":"Returns the \"background ratio\" parameter of the algorithm\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n\n##### Return\n- **retval**: `double`\n\nIf a foreground pixel keeps semi-constant value for about backgroundRatio\\*history frames, it's\nconsidered background and added to the model as a center of a new component. It corresponds to TB\nparameter in the paper.\n\nPython prototype (for reference only):\n```python3\ngetBackgroundRatio() -> retval\n```","ref":"Evision.BackgroundSubtractorMOG2.html#getBackgroundRatio/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.getComplexityReductionThreshold/1","doc":"Returns the complexity reduction threshold\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n\n##### Return\n- **retval**: `double`\n\nThis parameter defines the number of samples needed to accept to prove the component exists. CT=0.05\nis a default value for all the samples. By setting CT=0 you get an algorithm very similar to the\nstandard Stauffer&Grimson algorithm.\n\nPython prototype (for reference only):\n```python3\ngetComplexityReductionThreshold() -> retval\n```","ref":"Evision.BackgroundSubtractorMOG2.html#getComplexityReductionThreshold/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.BackgroundSubtractorMOG2.html#getDefaultName/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.getDetectShadows/1","doc":"Returns the shadow detection flag\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n\n##### Return\n- **retval**: `bool`\n\nIf true, the algorithm detects shadows and marks them. See createBackgroundSubtractorMOG2 for\ndetails.\n\nPython prototype (for reference only):\n```python3\ngetDetectShadows() -> retval\n```","ref":"Evision.BackgroundSubtractorMOG2.html#getDetectShadows/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.getHistory/1","doc":"Returns the number of last frames that affect the background model\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetHistory() -> retval\n```","ref":"Evision.BackgroundSubtractorMOG2.html#getHistory/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.getNMixtures/1","doc":"Returns the number of gaussian components in the background model\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNMixtures() -> retval\n```","ref":"Evision.BackgroundSubtractorMOG2.html#getNMixtures/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.getShadowThreshold/1","doc":"Returns the shadow threshold\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n\n##### Return\n- **retval**: `double`\n\nA shadow is detected if pixel is a darker version of the background. The shadow threshold (Tau in\nthe paper) is a threshold defining how much darker the shadow can be. Tau= 0.5 means that if a pixel\nis more than twice darker then it is not shadow. See Prati, Mikic, Trivedi and Cucchiara,\nDetecting Moving Shadows...*, IEEE PAMI,2003.\n\nPython prototype (for reference only):\n```python3\ngetShadowThreshold() -> retval\n```","ref":"Evision.BackgroundSubtractorMOG2.html#getShadowThreshold/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.getShadowValue/1","doc":"Returns the shadow value\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n\n##### Return\n- **retval**: `integer()`\n\nShadow value is the value used to mark shadows in the foreground mask. Default value is 127. Value 0\nin the mask always means background, 255 means foreground.\n\nPython prototype (for reference only):\n```python3\ngetShadowValue() -> retval\n```","ref":"Evision.BackgroundSubtractorMOG2.html#getShadowValue/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.getVarInit/1","doc":"Returns the initial variance of each gaussian component\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetVarInit() -> retval\n```","ref":"Evision.BackgroundSubtractorMOG2.html#getVarInit/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.getVarMax/1","doc":"getVarMax\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetVarMax() -> retval\n```","ref":"Evision.BackgroundSubtractorMOG2.html#getVarMax/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.getVarMin/1","doc":"getVarMin\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetVarMin() -> retval\n```","ref":"Evision.BackgroundSubtractorMOG2.html#getVarMin/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.getVarThreshold/1","doc":"Returns the variance threshold for the pixel-model match\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n\n##### Return\n- **retval**: `double`\n\nThe main threshold on the squared Mahalanobis distance to decide if the sample is well described by\nthe background model or not. Related to Cthr from the paper.\n\nPython prototype (for reference only):\n```python3\ngetVarThreshold() -> retval\n```","ref":"Evision.BackgroundSubtractorMOG2.html#getVarThreshold/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.getVarThresholdGen/1","doc":"Returns the variance threshold for the pixel-model match used for new mixture component generation\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n\n##### Return\n- **retval**: `double`\n\nThreshold for the squared Mahalanobis distance that helps decide when a sample is close to the\nexisting components (corresponds to Tg in the paper). If a pixel is not close to any component, it\nis considered foreground or added as a new component. 3 sigma =\\> Tg=3\\*3=9 is default. A smaller Tg\nvalue generates more components. A higher Tg value may result in a small number of components but\nthey can grow too large.\n\nPython prototype (for reference only):\n```python3\ngetVarThresholdGen() -> retval\n```","ref":"Evision.BackgroundSubtractorMOG2.html#getVarThresholdGen/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.read/1","doc":"","ref":"Evision.BackgroundSubtractorMOG2.html#read/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.BackgroundSubtractorMOG2.html#read/2"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.save/1","doc":"","ref":"Evision.BackgroundSubtractorMOG2.html#save/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.BackgroundSubtractorMOG2.html#save/2"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setBackgroundRatio/1","doc":"","ref":"Evision.BackgroundSubtractorMOG2.html#setBackgroundRatio/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setBackgroundRatio/2","doc":"Sets the \"background ratio\" parameter of the algorithm\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n- **ratio**: `double`\n\nPython prototype (for reference only):\n```python3\nsetBackgroundRatio(ratio) -> None\n```","ref":"Evision.BackgroundSubtractorMOG2.html#setBackgroundRatio/2"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setComplexityReductionThreshold/1","doc":"","ref":"Evision.BackgroundSubtractorMOG2.html#setComplexityReductionThreshold/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setComplexityReductionThreshold/2","doc":"Sets the complexity reduction threshold\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n- **ct**: `double`\n\nPython prototype (for reference only):\n```python3\nsetComplexityReductionThreshold(ct) -> None\n```","ref":"Evision.BackgroundSubtractorMOG2.html#setComplexityReductionThreshold/2"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setDetectShadows/1","doc":"","ref":"Evision.BackgroundSubtractorMOG2.html#setDetectShadows/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setDetectShadows/2","doc":"Enables or disables shadow detection\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n- **detectShadows**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetDetectShadows(detectShadows) -> None\n```","ref":"Evision.BackgroundSubtractorMOG2.html#setDetectShadows/2"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setHistory/1","doc":"","ref":"Evision.BackgroundSubtractorMOG2.html#setHistory/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setHistory/2","doc":"Sets the number of last frames that affect the background model\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n- **history**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetHistory(history) -> None\n```","ref":"Evision.BackgroundSubtractorMOG2.html#setHistory/2"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setNMixtures/1","doc":"","ref":"Evision.BackgroundSubtractorMOG2.html#setNMixtures/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setNMixtures/2","doc":"Sets the number of gaussian components in the background model.\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n- **nmixtures**: `integer()`\n\nThe model needs to be reinitalized to reserve memory.\n\nPython prototype (for reference only):\n```python3\nsetNMixtures(nmixtures) -> None\n```","ref":"Evision.BackgroundSubtractorMOG2.html#setNMixtures/2"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setShadowThreshold/1","doc":"","ref":"Evision.BackgroundSubtractorMOG2.html#setShadowThreshold/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setShadowThreshold/2","doc":"Sets the shadow threshold\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n- **threshold**: `double`\n\nPython prototype (for reference only):\n```python3\nsetShadowThreshold(threshold) -> None\n```","ref":"Evision.BackgroundSubtractorMOG2.html#setShadowThreshold/2"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setShadowValue/1","doc":"","ref":"Evision.BackgroundSubtractorMOG2.html#setShadowValue/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setShadowValue/2","doc":"Sets the shadow value\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n- **value**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetShadowValue(value) -> None\n```","ref":"Evision.BackgroundSubtractorMOG2.html#setShadowValue/2"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setVarInit/1","doc":"","ref":"Evision.BackgroundSubtractorMOG2.html#setVarInit/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setVarInit/2","doc":"Sets the initial variance of each gaussian component\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n- **varInit**: `double`\n\nPython prototype (for reference only):\n```python3\nsetVarInit(varInit) -> None\n```","ref":"Evision.BackgroundSubtractorMOG2.html#setVarInit/2"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setVarMax/1","doc":"","ref":"Evision.BackgroundSubtractorMOG2.html#setVarMax/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setVarMax/2","doc":"setVarMax\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n- **varMax**: `double`\n\nPython prototype (for reference only):\n```python3\nsetVarMax(varMax) -> None\n```","ref":"Evision.BackgroundSubtractorMOG2.html#setVarMax/2"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setVarMin/1","doc":"","ref":"Evision.BackgroundSubtractorMOG2.html#setVarMin/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setVarMin/2","doc":"setVarMin\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n- **varMin**: `double`\n\nPython prototype (for reference only):\n```python3\nsetVarMin(varMin) -> None\n```","ref":"Evision.BackgroundSubtractorMOG2.html#setVarMin/2"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setVarThreshold/1","doc":"","ref":"Evision.BackgroundSubtractorMOG2.html#setVarThreshold/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setVarThreshold/2","doc":"Sets the variance threshold for the pixel-model match\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n- **varThreshold**: `double`\n\nPython prototype (for reference only):\n```python3\nsetVarThreshold(varThreshold) -> None\n```","ref":"Evision.BackgroundSubtractorMOG2.html#setVarThreshold/2"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setVarThresholdGen/1","doc":"","ref":"Evision.BackgroundSubtractorMOG2.html#setVarThresholdGen/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.setVarThresholdGen/2","doc":"Sets the variance threshold for the pixel-model match used for new mixture component generation\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n- **varThresholdGen**: `double`\n\nPython prototype (for reference only):\n```python3\nsetVarThresholdGen(varThresholdGen) -> None\n```","ref":"Evision.BackgroundSubtractorMOG2.html#setVarThresholdGen/2"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.write/1","doc":"","ref":"Evision.BackgroundSubtractorMOG2.html#write/1"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.BackgroundSubtractorMOG2.html#write/2"},{"type":"function","title":"Evision.BackgroundSubtractorMOG2.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.BackgroundSubtractorMOG2.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.BackgroundSubtractorMOG2.html#write/3"},{"type":"type","title":"Evision.BackgroundSubtractorMOG2.t/0","doc":"Type that represents an `BackgroundSubtractorMOG2` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.BackgroundSubtractorMOG2.html#t:t/0"},{"type":"module","title":"Evision.Barcode","doc":"","ref":"Evision.Barcode.html"},{"type":"type","title":"Evision.Barcode.t/0","doc":"Type that represents an `Barcode` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Barcode.html#t:t/0"},{"type":"module","title":"Evision.Barcode.BarcodeDetector","doc":"","ref":"Evision.Barcode.BarcodeDetector.html"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.barcodeDetector/0","doc":"Initialize the BarcodeDetector.\n##### Return\n- **self**: `BarcodeDetector`\n\nPython prototype (for reference only):\n```python3\nBarcodeDetector() ->  \n```","ref":"Evision.Barcode.BarcodeDetector.html#barcodeDetector/0"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.barcodeDetector/1","doc":"","ref":"Evision.Barcode.BarcodeDetector.html#barcodeDetector/1"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.barcodeDetector/2","doc":"Initialize the BarcodeDetector.\n\n##### Positional Arguments\n- **prototxt_path**: `string`.\n\n  prototxt file path for the super resolution model\n\n- **model_path**: `string`.\n\n  model file path for the super resolution model\n\n##### Return\n- **self**: `BarcodeDetector`\n\n Parameters allow to load _optional_ Super Resolution DNN model for better quality.\n\nPython prototype (for reference only):\n```python3\nBarcodeDetector(prototxt_path, model_path) ->  \n```","ref":"Evision.Barcode.BarcodeDetector.html#barcodeDetector/2"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.decode/1","doc":"","ref":"Evision.Barcode.BarcodeDetector.html#decode/1"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.decode/3","doc":"Decodes graphical code in image once it's found by the detect() method.\n\n##### Positional Arguments\n- **self**: `Evision.Barcode.BarcodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical code.\n\n- **points**: `Evision.Mat`.\n\n  Quadrangle vertices found by detect() method (or some other algorithm).\n\n##### Return\n- **retval**: `string`\n- **straight_code**: `Evision.Mat.t()`.\n\n  The optional output image containing binarized code, will be empty if not found.\n\nReturns UTF8-encoded output string or empty string if the code cannot be decoded.\n\nPython prototype (for reference only):\n```python3\ndecode(img, points[, straight_code]) -> retval, straight_code\n```","ref":"Evision.Barcode.BarcodeDetector.html#decode/3"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.decode/4","doc":"Decodes graphical code in image once it's found by the detect() method.\n\n##### Positional Arguments\n- **self**: `Evision.Barcode.BarcodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical code.\n\n- **points**: `Evision.Mat`.\n\n  Quadrangle vertices found by detect() method (or some other algorithm).\n\n##### Return\n- **retval**: `string`\n- **straight_code**: `Evision.Mat.t()`.\n\n  The optional output image containing binarized code, will be empty if not found.\n\nReturns UTF8-encoded output string or empty string if the code cannot be decoded.\n\nPython prototype (for reference only):\n```python3\ndecode(img, points[, straight_code]) -> retval, straight_code\n```","ref":"Evision.Barcode.BarcodeDetector.html#decode/4"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.decodeMulti/1","doc":"","ref":"Evision.Barcode.BarcodeDetector.html#decodeMulti/1"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.decodeMulti/3","doc":"Decodes graphical codes in image once it's found by the detect() method.\n\n##### Positional Arguments\n- **self**: `Evision.Barcode.BarcodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical codes.\n\n- **points**: `Evision.Mat`.\n\n  vector of Quadrangle vertices found by detect() method (or some other algorithm).\n\n##### Return\n- **retval**: `bool`\n- **decoded_info**: `[string]`.\n\n  UTF8-encoded output vector of string or empty vector of string if the codes cannot be decoded.\n\n- **straight_code**: `[Evision.Mat]`.\n\n  The optional output vector of images containing binarized codes\n\nPython prototype (for reference only):\n```python3\ndecodeMulti(img, points[, straight_code]) -> retval, decoded_info, straight_code\n```","ref":"Evision.Barcode.BarcodeDetector.html#decodeMulti/3"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.decodeMulti/4","doc":"Decodes graphical codes in image once it's found by the detect() method.\n\n##### Positional Arguments\n- **self**: `Evision.Barcode.BarcodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical codes.\n\n- **points**: `Evision.Mat`.\n\n  vector of Quadrangle vertices found by detect() method (or some other algorithm).\n\n##### Return\n- **retval**: `bool`\n- **decoded_info**: `[string]`.\n\n  UTF8-encoded output vector of string or empty vector of string if the codes cannot be decoded.\n\n- **straight_code**: `[Evision.Mat]`.\n\n  The optional output vector of images containing binarized codes\n\nPython prototype (for reference only):\n```python3\ndecodeMulti(img, points[, straight_code]) -> retval, decoded_info, straight_code\n```","ref":"Evision.Barcode.BarcodeDetector.html#decodeMulti/4"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.decodeWithType/1","doc":"","ref":"Evision.Barcode.BarcodeDetector.html#decodeWithType/1"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.decodeWithType/3","doc":"Decodes barcode in image once it's found by the detect() method.\n\n##### Positional Arguments\n- **self**: `Evision.Barcode.BarcodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing bar code.\n\n- **points**: `Evision.Mat`.\n\n  vector of rotated rectangle vertices found by detect() method (or some other algorithm).\n  For N detected barcodes, the dimensions of this array should be [N][4].\n  Order of four points in vector  is bottomLeft, topLeft, topRight, bottomRight.\n\n##### Return\n- **retval**: `bool`\n- **decoded_info**: `[string]`.\n\n  UTF8-encoded output vector of string or empty vector of string if the codes cannot be decoded.\n\n- **decoded_type**: `[string]`.\n\n  vector strings, specifies the type of these barcodes\n\n@return true if at least one valid barcode have been found\n\nPython prototype (for reference only):\n```python3\ndecodeWithType(img, points) -> retval, decoded_info, decoded_type\n```","ref":"Evision.Barcode.BarcodeDetector.html#decodeWithType/3"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.detect/1","doc":"","ref":"Evision.Barcode.BarcodeDetector.html#detect/1"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.detect/2","doc":"Detects graphical code in image and returns the quadrangle containing the code.\n\n##### Positional Arguments\n- **self**: `Evision.Barcode.BarcodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing (or not) graphical code.\n\n##### Return\n- **retval**: `bool`\n- **points**: `Evision.Mat.t()`.\n\n  Output vector of vertices of the minimum-area quadrangle containing the code.\n\nPython prototype (for reference only):\n```python3\ndetect(img[, points]) -> retval, points\n```","ref":"Evision.Barcode.BarcodeDetector.html#detect/2"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.detect/3","doc":"Detects graphical code in image and returns the quadrangle containing the code.\n\n##### Positional Arguments\n- **self**: `Evision.Barcode.BarcodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing (or not) graphical code.\n\n##### Return\n- **retval**: `bool`\n- **points**: `Evision.Mat.t()`.\n\n  Output vector of vertices of the minimum-area quadrangle containing the code.\n\nPython prototype (for reference only):\n```python3\ndetect(img[, points]) -> retval, points\n```","ref":"Evision.Barcode.BarcodeDetector.html#detect/3"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.detectAndDecode/1","doc":"","ref":"Evision.Barcode.BarcodeDetector.html#detectAndDecode/1"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.detectAndDecode/2","doc":"Both detects and decodes graphical code\n\n##### Positional Arguments\n- **self**: `Evision.Barcode.BarcodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical code.\n\n##### Return\n- **retval**: `string`\n- **points**: `Evision.Mat.t()`.\n\n  optional output array of vertices of the found graphical code quadrangle, will be empty if not found.\n\n- **straight_code**: `Evision.Mat.t()`.\n\n  The optional output image containing binarized code\n\nPython prototype (for reference only):\n```python3\ndetectAndDecode(img[, points[, straight_code]]) -> retval, points, straight_code\n```","ref":"Evision.Barcode.BarcodeDetector.html#detectAndDecode/2"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.detectAndDecode/3","doc":"Both detects and decodes graphical code\n\n##### Positional Arguments\n- **self**: `Evision.Barcode.BarcodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical code.\n\n##### Return\n- **retval**: `string`\n- **points**: `Evision.Mat.t()`.\n\n  optional output array of vertices of the found graphical code quadrangle, will be empty if not found.\n\n- **straight_code**: `Evision.Mat.t()`.\n\n  The optional output image containing binarized code\n\nPython prototype (for reference only):\n```python3\ndetectAndDecode(img[, points[, straight_code]]) -> retval, points, straight_code\n```","ref":"Evision.Barcode.BarcodeDetector.html#detectAndDecode/3"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.detectAndDecodeMulti/1","doc":"","ref":"Evision.Barcode.BarcodeDetector.html#detectAndDecodeMulti/1"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.detectAndDecodeMulti/2","doc":"Both detects and decodes graphical codes\n\n##### Positional Arguments\n- **self**: `Evision.Barcode.BarcodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical codes.\n\n##### Return\n- **retval**: `bool`\n- **decoded_info**: `[string]`.\n\n  UTF8-encoded output vector of string or empty vector of string if the codes cannot be decoded.\n\n- **points**: `Evision.Mat.t()`.\n\n  optional output vector of vertices of the found graphical code quadrangles. Will be empty if not found.\n\n- **straight_code**: `[Evision.Mat]`.\n\n  The optional vector of images containing binarized codes\n\n- If there are QR codes encoded with a Structured Append mode on the image and all of them detected and decoded correctly,\n  method writes a full message to position corresponds to 0-th code in a sequence. The rest of QR codes from the same sequence\n  have empty string.\n\nPython prototype (for reference only):\n```python3\ndetectAndDecodeMulti(img[, points[, straight_code]]) -> retval, decoded_info, points, straight_code\n```","ref":"Evision.Barcode.BarcodeDetector.html#detectAndDecodeMulti/2"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.detectAndDecodeMulti/3","doc":"Both detects and decodes graphical codes\n\n##### Positional Arguments\n- **self**: `Evision.Barcode.BarcodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical codes.\n\n##### Return\n- **retval**: `bool`\n- **decoded_info**: `[string]`.\n\n  UTF8-encoded output vector of string or empty vector of string if the codes cannot be decoded.\n\n- **points**: `Evision.Mat.t()`.\n\n  optional output vector of vertices of the found graphical code quadrangles. Will be empty if not found.\n\n- **straight_code**: `[Evision.Mat]`.\n\n  The optional vector of images containing binarized codes\n\n- If there are QR codes encoded with a Structured Append mode on the image and all of them detected and decoded correctly,\n  method writes a full message to position corresponds to 0-th code in a sequence. The rest of QR codes from the same sequence\n  have empty string.\n\nPython prototype (for reference only):\n```python3\ndetectAndDecodeMulti(img[, points[, straight_code]]) -> retval, decoded_info, points, straight_code\n```","ref":"Evision.Barcode.BarcodeDetector.html#detectAndDecodeMulti/3"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.detectAndDecodeWithType/1","doc":"","ref":"Evision.Barcode.BarcodeDetector.html#detectAndDecodeWithType/1"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.detectAndDecodeWithType/2","doc":"Both detects and decodes barcode\n\n##### Positional Arguments\n- **self**: `Evision.Barcode.BarcodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing barcode.\n\n##### Return\n- **retval**: `bool`\n- **decoded_info**: `[string]`.\n\n  UTF8-encoded output vector of string(s) or empty vector of string if the codes cannot be decoded.\n\n- **decoded_type**: `[string]`.\n\n  vector of strings, specifies the type of these barcodes\n\n- **points**: `Evision.Mat.t()`.\n\n  optional output vector of vertices of the found  barcode rectangle. Will be empty if not found.\n\n@return true if at least one valid barcode have been found\n\nPython prototype (for reference only):\n```python3\ndetectAndDecodeWithType(img[, points]) -> retval, decoded_info, decoded_type, points\n```","ref":"Evision.Barcode.BarcodeDetector.html#detectAndDecodeWithType/2"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.detectAndDecodeWithType/3","doc":"Both detects and decodes barcode\n\n##### Positional Arguments\n- **self**: `Evision.Barcode.BarcodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing barcode.\n\n##### Return\n- **retval**: `bool`\n- **decoded_info**: `[string]`.\n\n  UTF8-encoded output vector of string(s) or empty vector of string if the codes cannot be decoded.\n\n- **decoded_type**: `[string]`.\n\n  vector of strings, specifies the type of these barcodes\n\n- **points**: `Evision.Mat.t()`.\n\n  optional output vector of vertices of the found  barcode rectangle. Will be empty if not found.\n\n@return true if at least one valid barcode have been found\n\nPython prototype (for reference only):\n```python3\ndetectAndDecodeWithType(img[, points]) -> retval, decoded_info, decoded_type, points\n```","ref":"Evision.Barcode.BarcodeDetector.html#detectAndDecodeWithType/3"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.detectMulti/1","doc":"","ref":"Evision.Barcode.BarcodeDetector.html#detectMulti/1"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.detectMulti/2","doc":"Detects graphical codes in image and returns the vector of the quadrangles containing the codes.\n\n##### Positional Arguments\n- **self**: `Evision.Barcode.BarcodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing (or not) graphical codes.\n\n##### Return\n- **retval**: `bool`\n- **points**: `Evision.Mat.t()`.\n\n  Output vector of vector of vertices of the minimum-area quadrangle containing the codes.\n\nPython prototype (for reference only):\n```python3\ndetectMulti(img[, points]) -> retval, points\n```","ref":"Evision.Barcode.BarcodeDetector.html#detectMulti/2"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.detectMulti/3","doc":"Detects graphical codes in image and returns the vector of the quadrangles containing the codes.\n\n##### Positional Arguments\n- **self**: `Evision.Barcode.BarcodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing (or not) graphical codes.\n\n##### Return\n- **retval**: `bool`\n- **points**: `Evision.Mat.t()`.\n\n  Output vector of vector of vertices of the minimum-area quadrangle containing the codes.\n\nPython prototype (for reference only):\n```python3\ndetectMulti(img[, points]) -> retval, points\n```","ref":"Evision.Barcode.BarcodeDetector.html#detectMulti/3"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.getDetectorScales/1","doc":"Returns detector box filter sizes.\n\n##### Positional Arguments\n- **self**: `Evision.Barcode.BarcodeDetector.t()`\n\n##### Return\n- **sizes**: `[float]`.\n\n  output parameter for returning the sizes.\n\nPython prototype (for reference only):\n```python3\ngetDetectorScales() -> sizes\n```","ref":"Evision.Barcode.BarcodeDetector.html#getDetectorScales/1"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.getDownsamplingThreshold/1","doc":"Get detector downsampling threshold.\n\n##### Positional Arguments\n- **self**: `Evision.Barcode.BarcodeDetector.t()`\n\n##### Return\n- **retval**: `double`\n\n@return detector downsampling threshold\n\nPython prototype (for reference only):\n```python3\ngetDownsamplingThreshold() -> retval\n```","ref":"Evision.Barcode.BarcodeDetector.html#getDownsamplingThreshold/1"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.getGradientThreshold/1","doc":"Get detector gradient magnitude threshold.\n\n##### Positional Arguments\n- **self**: `Evision.Barcode.BarcodeDetector.t()`\n\n##### Return\n- **retval**: `double`\n\n@return detector gradient magnitude threshold.\n\nPython prototype (for reference only):\n```python3\ngetGradientThreshold() -> retval\n```","ref":"Evision.Barcode.BarcodeDetector.html#getGradientThreshold/1"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.setDetectorScales/1","doc":"","ref":"Evision.Barcode.BarcodeDetector.html#setDetectorScales/1"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.setDetectorScales/2","doc":"Set detector box filter sizes.\n\n##### Positional Arguments\n- **self**: `Evision.Barcode.BarcodeDetector.t()`\n- **sizes**: `[float]`.\n\n  box filter sizes, relative to minimum dimension of the image (default [0.01, 0.03, 0.06, 0.08])\n\n##### Return\n- **retval**: `BarcodeDetector`\n\n Adjusts the value and the number of box filters used in the detect step.\n The filter sizes directly correlate with the expected line widths for a barcode. Corresponds to expected barcode distance.\n If the downsampling limit is increased, filter sizes need to be adjusted in an inversely proportional way.\n\nPython prototype (for reference only):\n```python3\nsetDetectorScales(sizes) -> retval\n```","ref":"Evision.Barcode.BarcodeDetector.html#setDetectorScales/2"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.setDownsamplingThreshold/1","doc":"","ref":"Evision.Barcode.BarcodeDetector.html#setDownsamplingThreshold/1"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.setDownsamplingThreshold/2","doc":"Set detector downsampling threshold.\n\n##### Positional Arguments\n- **self**: `Evision.Barcode.BarcodeDetector.t()`\n- **thresh**: `double`.\n\n  downsampling limit to apply (default 512)\n\n##### Return\n- **retval**: `BarcodeDetector`\n\n By default, the detect method resizes the input image to this limit if the smallest image size is is greater than the threshold.\n Increasing this value can improve detection accuracy and the number of results at the expense of performance.\n Correlates with detector scales. Setting this to a large value will disable downsampling.\n@see `setDetectorScales/2`\n\nPython prototype (for reference only):\n```python3\nsetDownsamplingThreshold(thresh) -> retval\n```","ref":"Evision.Barcode.BarcodeDetector.html#setDownsamplingThreshold/2"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.setGradientThreshold/1","doc":"","ref":"Evision.Barcode.BarcodeDetector.html#setGradientThreshold/1"},{"type":"function","title":"Evision.Barcode.BarcodeDetector.setGradientThreshold/2","doc":"Set detector gradient magnitude threshold.\n\n##### Positional Arguments\n- **self**: `Evision.Barcode.BarcodeDetector.t()`\n- **thresh**: `double`.\n\n  gradient magnitude threshold (default 64).\n\n##### Return\n- **retval**: `BarcodeDetector`\n\n Sets the coherence threshold for detected bounding boxes.\n Increasing this value will generate a closer fitted bounding box width and can reduce false-positives.\n Values between 16 and 1024 generally work, while too high of a value will remove valid detections.\n\nPython prototype (for reference only):\n```python3\nsetGradientThreshold(thresh) -> retval\n```","ref":"Evision.Barcode.BarcodeDetector.html#setGradientThreshold/2"},{"type":"type","title":"Evision.Barcode.BarcodeDetector.t/0","doc":"Type that represents an `Barcode.BarcodeDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Barcode.BarcodeDetector.html#t:t/0"},{"type":"module","title":"Evision.BaseCascadeClassifier","doc":"","ref":"Evision.BaseCascadeClassifier.html"},{"type":"function","title":"Evision.BaseCascadeClassifier.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.BaseCascadeClassifier.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.BaseCascadeClassifier.html#clear/1"},{"type":"function","title":"Evision.BaseCascadeClassifier.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.BaseCascadeClassifier.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.BaseCascadeClassifier.html#empty/1"},{"type":"function","title":"Evision.BaseCascadeClassifier.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.BaseCascadeClassifier.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.BaseCascadeClassifier.html#getDefaultName/1"},{"type":"function","title":"Evision.BaseCascadeClassifier.read/1","doc":"","ref":"Evision.BaseCascadeClassifier.html#read/1"},{"type":"function","title":"Evision.BaseCascadeClassifier.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.BaseCascadeClassifier.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.BaseCascadeClassifier.html#read/2"},{"type":"function","title":"Evision.BaseCascadeClassifier.save/1","doc":"","ref":"Evision.BaseCascadeClassifier.html#save/1"},{"type":"function","title":"Evision.BaseCascadeClassifier.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.BaseCascadeClassifier.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.BaseCascadeClassifier.html#save/2"},{"type":"function","title":"Evision.BaseCascadeClassifier.write/1","doc":"","ref":"Evision.BaseCascadeClassifier.html#write/1"},{"type":"function","title":"Evision.BaseCascadeClassifier.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.BaseCascadeClassifier.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.BaseCascadeClassifier.html#write/2"},{"type":"function","title":"Evision.BaseCascadeClassifier.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.BaseCascadeClassifier.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.BaseCascadeClassifier.html#write/3"},{"type":"type","title":"Evision.BaseCascadeClassifier.t/0","doc":"Type that represents an `BaseCascadeClassifier` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.BaseCascadeClassifier.html#t:t/0"},{"type":"module","title":"Evision.BgSegm","doc":"","ref":"Evision.BgSegm.html"},{"type":"function","title":"Evision.BgSegm.createBackgroundSubtractorCNT/0","doc":"Creates a CNT Background Subtractor\n##### Keyword Arguments\n- **minPixelStability**: `integer()`.\n\n  number of frames with same pixel color to consider stable\n\n- **useHistory**: `bool`.\n\n  determines if we're giving a pixel credit for being stable for a long time\n\n- **maxPixelStability**: `integer()`.\n\n  maximum allowed credit for a pixel in history\n\n- **isParallel**: `bool`.\n\n  determines if we're parallelizing the algorithm\n\n##### Return\n- **retval**: `Evision.BgSegm.BackgroundSubtractorCNT.t()`\n\nPython prototype (for reference only):\n```python3\ncreateBackgroundSubtractorCNT([, minPixelStability[, useHistory[, maxPixelStability[, isParallel]]]]) -> retval\n```","ref":"Evision.BgSegm.html#createBackgroundSubtractorCNT/0"},{"type":"function","title":"Evision.BgSegm.createBackgroundSubtractorCNT/1","doc":"Creates a CNT Background Subtractor\n##### Keyword Arguments\n- **minPixelStability**: `integer()`.\n\n  number of frames with same pixel color to consider stable\n\n- **useHistory**: `bool`.\n\n  determines if we're giving a pixel credit for being stable for a long time\n\n- **maxPixelStability**: `integer()`.\n\n  maximum allowed credit for a pixel in history\n\n- **isParallel**: `bool`.\n\n  determines if we're parallelizing the algorithm\n\n##### Return\n- **retval**: `Evision.BgSegm.BackgroundSubtractorCNT.t()`\n\nPython prototype (for reference only):\n```python3\ncreateBackgroundSubtractorCNT([, minPixelStability[, useHistory[, maxPixelStability[, isParallel]]]]) -> retval\n```","ref":"Evision.BgSegm.html#createBackgroundSubtractorCNT/1"},{"type":"function","title":"Evision.BgSegm.createBackgroundSubtractorGMG/0","doc":"Creates a GMG Background Subtractor\n##### Keyword Arguments\n- **initializationFrames**: `integer()`.\n\n  number of frames used to initialize the background models.\n\n- **decisionThreshold**: `double`.\n\n  Threshold value, above which it is marked foreground, else background.\n\n##### Return\n- **retval**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n\nPython prototype (for reference only):\n```python3\ncreateBackgroundSubtractorGMG([, initializationFrames[, decisionThreshold]]) -> retval\n```","ref":"Evision.BgSegm.html#createBackgroundSubtractorGMG/0"},{"type":"function","title":"Evision.BgSegm.createBackgroundSubtractorGMG/1","doc":"Creates a GMG Background Subtractor\n##### Keyword Arguments\n- **initializationFrames**: `integer()`.\n\n  number of frames used to initialize the background models.\n\n- **decisionThreshold**: `double`.\n\n  Threshold value, above which it is marked foreground, else background.\n\n##### Return\n- **retval**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n\nPython prototype (for reference only):\n```python3\ncreateBackgroundSubtractorGMG([, initializationFrames[, decisionThreshold]]) -> retval\n```","ref":"Evision.BgSegm.html#createBackgroundSubtractorGMG/1"},{"type":"function","title":"Evision.BgSegm.createBackgroundSubtractorGSOC/0","doc":"Creates an instance of BackgroundSubtractorGSOC algorithm.\n##### Keyword Arguments\n- **mc**: `integer()`.\n\n  Whether to use camera motion compensation.\n\n- **nSamples**: `integer()`.\n\n  Number of samples to maintain at each point of the frame.\n\n- **replaceRate**: `float`.\n\n  Probability of replacing the old sample - how fast the model will update itself.\n\n- **propagationRate**: `float`.\n\n  Probability of propagating to neighbors.\n\n- **hitsThreshold**: `integer()`.\n\n  How many positives the sample must get before it will be considered as a possible replacement.\n\n- **alpha**: `float`.\n\n  Scale coefficient for threshold.\n\n- **beta**: `float`.\n\n  Bias coefficient for threshold.\n\n- **blinkingSupressionDecay**: `float`.\n\n  Blinking supression decay factor.\n\n- **blinkingSupressionMultiplier**: `float`.\n\n  Blinking supression multiplier.\n\n- **noiseRemovalThresholdFacBG**: `float`.\n\n  Strength of the noise removal for background points.\n\n- **noiseRemovalThresholdFacFG**: `float`.\n\n  Strength of the noise removal for foreground points.\n\n##### Return\n- **retval**: `Evision.BgSegm.BackgroundSubtractorGSOC.t()`\n\nImplementation of the different yet better algorithm which is called GSOC, as it was implemented during GSOC and was not originated from any paper.\n\nPython prototype (for reference only):\n```python3\ncreateBackgroundSubtractorGSOC([, mc[, nSamples[, replaceRate[, propagationRate[, hitsThreshold[, alpha[, beta[, blinkingSupressionDecay[, blinkingSupressionMultiplier[, noiseRemovalThresholdFacBG[, noiseRemovalThresholdFacFG]]]]]]]]]]]) -> retval\n```","ref":"Evision.BgSegm.html#createBackgroundSubtractorGSOC/0"},{"type":"function","title":"Evision.BgSegm.createBackgroundSubtractorGSOC/1","doc":"Creates an instance of BackgroundSubtractorGSOC algorithm.\n##### Keyword Arguments\n- **mc**: `integer()`.\n\n  Whether to use camera motion compensation.\n\n- **nSamples**: `integer()`.\n\n  Number of samples to maintain at each point of the frame.\n\n- **replaceRate**: `float`.\n\n  Probability of replacing the old sample - how fast the model will update itself.\n\n- **propagationRate**: `float`.\n\n  Probability of propagating to neighbors.\n\n- **hitsThreshold**: `integer()`.\n\n  How many positives the sample must get before it will be considered as a possible replacement.\n\n- **alpha**: `float`.\n\n  Scale coefficient for threshold.\n\n- **beta**: `float`.\n\n  Bias coefficient for threshold.\n\n- **blinkingSupressionDecay**: `float`.\n\n  Blinking supression decay factor.\n\n- **blinkingSupressionMultiplier**: `float`.\n\n  Blinking supression multiplier.\n\n- **noiseRemovalThresholdFacBG**: `float`.\n\n  Strength of the noise removal for background points.\n\n- **noiseRemovalThresholdFacFG**: `float`.\n\n  Strength of the noise removal for foreground points.\n\n##### Return\n- **retval**: `Evision.BgSegm.BackgroundSubtractorGSOC.t()`\n\nImplementation of the different yet better algorithm which is called GSOC, as it was implemented during GSOC and was not originated from any paper.\n\nPython prototype (for reference only):\n```python3\ncreateBackgroundSubtractorGSOC([, mc[, nSamples[, replaceRate[, propagationRate[, hitsThreshold[, alpha[, beta[, blinkingSupressionDecay[, blinkingSupressionMultiplier[, noiseRemovalThresholdFacBG[, noiseRemovalThresholdFacFG]]]]]]]]]]]) -> retval\n```","ref":"Evision.BgSegm.html#createBackgroundSubtractorGSOC/1"},{"type":"function","title":"Evision.BgSegm.createBackgroundSubtractorLSBP/0","doc":"Creates an instance of BackgroundSubtractorLSBP algorithm.\n##### Keyword Arguments\n- **mc**: `integer()`.\n\n  Whether to use camera motion compensation.\n\n- **nSamples**: `integer()`.\n\n  Number of samples to maintain at each point of the frame.\n\n- **lSBPRadius**: `integer()`.\n\n  LSBP descriptor radius.\n\n- **tlower**: `float`.\n\n  Lower bound for T-values. See @cite LGuo2016 for details.\n\n- **tupper**: `float`.\n\n  Upper bound for T-values. See @cite LGuo2016 for details.\n\n- **tinc**: `float`.\n\n  Increase step for T-values. See @cite LGuo2016 for details.\n\n- **tdec**: `float`.\n\n  Decrease step for T-values. See @cite LGuo2016 for details.\n\n- **rscale**: `float`.\n\n  Scale coefficient for threshold values.\n\n- **rincdec**: `float`.\n\n  Increase/Decrease step for threshold values.\n\n- **noiseRemovalThresholdFacBG**: `float`.\n\n  Strength of the noise removal for background points.\n\n- **noiseRemovalThresholdFacFG**: `float`.\n\n  Strength of the noise removal for foreground points.\n\n- **lSBPthreshold**: `integer()`.\n\n  Threshold for LSBP binary string.\n\n- **minCount**: `integer()`.\n\n  Minimal number of matches for sample to be considered as foreground.\n\n##### Return\n- **retval**: `Evision.BgSegm.BackgroundSubtractorLSBP.t()`\n\nBackground Subtraction using Local SVD Binary Pattern. More details about the algorithm can be found at @cite LGuo2016\n\nPython prototype (for reference only):\n```python3\ncreateBackgroundSubtractorLSBP([, mc[, nSamples[, LSBPRadius[, Tlower[, Tupper[, Tinc[, Tdec[, Rscale[, Rincdec[, noiseRemovalThresholdFacBG[, noiseRemovalThresholdFacFG[, LSBPthreshold[, minCount]]]]]]]]]]]]]) -> retval\n```","ref":"Evision.BgSegm.html#createBackgroundSubtractorLSBP/0"},{"type":"function","title":"Evision.BgSegm.createBackgroundSubtractorLSBP/1","doc":"Creates an instance of BackgroundSubtractorLSBP algorithm.\n##### Keyword Arguments\n- **mc**: `integer()`.\n\n  Whether to use camera motion compensation.\n\n- **nSamples**: `integer()`.\n\n  Number of samples to maintain at each point of the frame.\n\n- **lSBPRadius**: `integer()`.\n\n  LSBP descriptor radius.\n\n- **tlower**: `float`.\n\n  Lower bound for T-values. See @cite LGuo2016 for details.\n\n- **tupper**: `float`.\n\n  Upper bound for T-values. See @cite LGuo2016 for details.\n\n- **tinc**: `float`.\n\n  Increase step for T-values. See @cite LGuo2016 for details.\n\n- **tdec**: `float`.\n\n  Decrease step for T-values. See @cite LGuo2016 for details.\n\n- **rscale**: `float`.\n\n  Scale coefficient for threshold values.\n\n- **rincdec**: `float`.\n\n  Increase/Decrease step for threshold values.\n\n- **noiseRemovalThresholdFacBG**: `float`.\n\n  Strength of the noise removal for background points.\n\n- **noiseRemovalThresholdFacFG**: `float`.\n\n  Strength of the noise removal for foreground points.\n\n- **lSBPthreshold**: `integer()`.\n\n  Threshold for LSBP binary string.\n\n- **minCount**: `integer()`.\n\n  Minimal number of matches for sample to be considered as foreground.\n\n##### Return\n- **retval**: `Evision.BgSegm.BackgroundSubtractorLSBP.t()`\n\nBackground Subtraction using Local SVD Binary Pattern. More details about the algorithm can be found at @cite LGuo2016\n\nPython prototype (for reference only):\n```python3\ncreateBackgroundSubtractorLSBP([, mc[, nSamples[, LSBPRadius[, Tlower[, Tupper[, Tinc[, Tdec[, Rscale[, Rincdec[, noiseRemovalThresholdFacBG[, noiseRemovalThresholdFacFG[, LSBPthreshold[, minCount]]]]]]]]]]]]]) -> retval\n```","ref":"Evision.BgSegm.html#createBackgroundSubtractorLSBP/1"},{"type":"function","title":"Evision.BgSegm.createBackgroundSubtractorMOG/0","doc":"Creates mixture-of-gaussian background subtractor\n##### Keyword Arguments\n- **history**: `integer()`.\n\n  Length of the history.\n\n- **nmixtures**: `integer()`.\n\n  Number of Gaussian mixtures.\n\n- **backgroundRatio**: `double`.\n\n  Background ratio.\n\n- **noiseSigma**: `double`.\n\n  Noise strength (standard deviation of the brightness or each color channel). 0\n  means some automatic value.\n\n##### Return\n- **retval**: `Evision.BgSegm.BackgroundSubtractorMOG.t()`\n\nPython prototype (for reference only):\n```python3\ncreateBackgroundSubtractorMOG([, history[, nmixtures[, backgroundRatio[, noiseSigma]]]]) -> retval\n```","ref":"Evision.BgSegm.html#createBackgroundSubtractorMOG/0"},{"type":"function","title":"Evision.BgSegm.createBackgroundSubtractorMOG/1","doc":"Creates mixture-of-gaussian background subtractor\n##### Keyword Arguments\n- **history**: `integer()`.\n\n  Length of the history.\n\n- **nmixtures**: `integer()`.\n\n  Number of Gaussian mixtures.\n\n- **backgroundRatio**: `double`.\n\n  Background ratio.\n\n- **noiseSigma**: `double`.\n\n  Noise strength (standard deviation of the brightness or each color channel). 0\n  means some automatic value.\n\n##### Return\n- **retval**: `Evision.BgSegm.BackgroundSubtractorMOG.t()`\n\nPython prototype (for reference only):\n```python3\ncreateBackgroundSubtractorMOG([, history[, nmixtures[, backgroundRatio[, noiseSigma]]]]) -> retval\n```","ref":"Evision.BgSegm.html#createBackgroundSubtractorMOG/1"},{"type":"function","title":"Evision.BgSegm.createSyntheticSequenceGenerator/1","doc":"","ref":"Evision.BgSegm.html#createSyntheticSequenceGenerator/1"},{"type":"function","title":"Evision.BgSegm.createSyntheticSequenceGenerator/2","doc":"Creates an instance of SyntheticSequenceGenerator.\n\n##### Positional Arguments\n- **background**: `Evision.Mat`.\n\n  Background image for object.\n\n- **object**: `Evision.Mat`.\n\n  Object image which will move slowly over the background.\n\n##### Keyword Arguments\n- **amplitude**: `double`.\n\n  Amplitude of wave distortion applied to background.\n\n- **wavelength**: `double`.\n\n  Length of waves in distortion applied to background.\n\n- **wavespeed**: `double`.\n\n  How fast waves will move.\n\n- **objspeed**: `double`.\n\n  How fast object will fly over background.\n\n##### Return\n- **retval**: `Evision.BgSegm.SyntheticSequenceGenerator.t()`\n\nPython prototype (for reference only):\n```python3\ncreateSyntheticSequenceGenerator(background, object[, amplitude[, wavelength[, wavespeed[, objspeed]]]]) -> retval\n```","ref":"Evision.BgSegm.html#createSyntheticSequenceGenerator/2"},{"type":"function","title":"Evision.BgSegm.createSyntheticSequenceGenerator/3","doc":"Creates an instance of SyntheticSequenceGenerator.\n\n##### Positional Arguments\n- **background**: `Evision.Mat`.\n\n  Background image for object.\n\n- **object**: `Evision.Mat`.\n\n  Object image which will move slowly over the background.\n\n##### Keyword Arguments\n- **amplitude**: `double`.\n\n  Amplitude of wave distortion applied to background.\n\n- **wavelength**: `double`.\n\n  Length of waves in distortion applied to background.\n\n- **wavespeed**: `double`.\n\n  How fast waves will move.\n\n- **objspeed**: `double`.\n\n  How fast object will fly over background.\n\n##### Return\n- **retval**: `Evision.BgSegm.SyntheticSequenceGenerator.t()`\n\nPython prototype (for reference only):\n```python3\ncreateSyntheticSequenceGenerator(background, object[, amplitude[, wavelength[, wavespeed[, objspeed]]]]) -> retval\n```","ref":"Evision.BgSegm.html#createSyntheticSequenceGenerator/3"},{"type":"type","title":"Evision.BgSegm.t/0","doc":"Type that represents an `BgSegm` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.BgSegm.html#t:t/0"},{"type":"module","title":"Evision.BgSegm.BackgroundSubtractorCNT","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.apply/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#apply/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.apply/2","doc":"apply\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorCNT.t()`\n- **image**: `Evision.Mat`\n\n##### Keyword Arguments\n- **learningRate**: `double`.\n\n##### Return\n- **fgmask**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\napply(image[, fgmask[, learningRate]]) -> fgmask\n```","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#apply/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.apply/3","doc":"apply\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorCNT.t()`\n- **image**: `Evision.Mat`\n\n##### Keyword Arguments\n- **learningRate**: `double`.\n\n##### Return\n- **fgmask**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\napply(image[, fgmask[, learningRate]]) -> fgmask\n```","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#apply/3"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorCNT.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#clear/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorCNT.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#empty/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.getBackgroundImage/1","doc":"getBackgroundImage\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorCNT.t()`\n\n##### Return\n- **backgroundImage**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetBackgroundImage([, backgroundImage]) -> backgroundImage\n```","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#getBackgroundImage/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.getBackgroundImage/2","doc":"getBackgroundImage\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorCNT.t()`\n\n##### Return\n- **backgroundImage**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetBackgroundImage([, backgroundImage]) -> backgroundImage\n```","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#getBackgroundImage/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorCNT.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#getDefaultName/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.getIsParallel/1","doc":"Returns if we're parallelizing the algorithm.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorCNT.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetIsParallel() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#getIsParallel/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.getMaxPixelStability/1","doc":"Returns maximum allowed credit for a pixel in history.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorCNT.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxPixelStability() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#getMaxPixelStability/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.getMinPixelStability/1","doc":"Returns number of frames with same pixel color to consider stable.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorCNT.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMinPixelStability() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#getMinPixelStability/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.getUseHistory/1","doc":"Returns if we're giving a pixel credit for being stable for a long time.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorCNT.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetUseHistory() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#getUseHistory/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.read/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#read/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorCNT.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#read/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.save/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#save/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorCNT.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#save/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.setIsParallel/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#setIsParallel/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.setIsParallel/2","doc":"Sets if we're parallelizing the algorithm.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorCNT.t()`\n- **value**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetIsParallel(value) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#setIsParallel/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.setMaxPixelStability/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#setMaxPixelStability/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.setMaxPixelStability/2","doc":"Sets the maximum allowed credit for a pixel in history.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorCNT.t()`\n- **value**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxPixelStability(value) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#setMaxPixelStability/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.setMinPixelStability/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#setMinPixelStability/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.setMinPixelStability/2","doc":"Sets the number of frames with same pixel color to consider stable.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorCNT.t()`\n- **value**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMinPixelStability(value) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#setMinPixelStability/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.setUseHistory/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#setUseHistory/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.setUseHistory/2","doc":"Sets if we're giving a pixel credit for being stable for a long time.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorCNT.t()`\n- **value**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetUseHistory(value) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#setUseHistory/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.write/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#write/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorCNT.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#write/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorCNT.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorCNT.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#write/3"},{"type":"type","title":"Evision.BgSegm.BackgroundSubtractorCNT.t/0","doc":"Type that represents an `BgSegm.BackgroundSubtractorCNT` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.BgSegm.BackgroundSubtractorCNT.html#t:t/0"},{"type":"module","title":"Evision.BgSegm.BackgroundSubtractorGMG","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.apply/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#apply/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.apply/2","doc":"Computes a foreground mask.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n- **image**: `Evision.Mat`.\n\n  Next video frame.\n\n##### Keyword Arguments\n- **learningRate**: `double`.\n\n  The value between 0 and 1 that indicates how fast the background model is\n  learnt. Negative parameter value makes the algorithm to use some automatically chosen learning\n  rate. 0 means that the background model is not updated at all, 1 means that the background model\n  is completely reinitialized from the last frame.\n\n##### Return\n- **fgmask**: `Evision.Mat.t()`.\n\n  The output foreground mask as an 8-bit binary image.\n\nPython prototype (for reference only):\n```python3\napply(image[, fgmask[, learningRate]]) -> fgmask\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#apply/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.apply/3","doc":"Computes a foreground mask.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n- **image**: `Evision.Mat`.\n\n  Next video frame.\n\n##### Keyword Arguments\n- **learningRate**: `double`.\n\n  The value between 0 and 1 that indicates how fast the background model is\n  learnt. Negative parameter value makes the algorithm to use some automatically chosen learning\n  rate. 0 means that the background model is not updated at all, 1 means that the background model\n  is completely reinitialized from the last frame.\n\n##### Return\n- **fgmask**: `Evision.Mat.t()`.\n\n  The output foreground mask as an 8-bit binary image.\n\nPython prototype (for reference only):\n```python3\napply(image[, fgmask[, learningRate]]) -> fgmask\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#apply/3"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#clear/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#empty/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.getBackgroundImage/1","doc":"Computes a background image.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n\n##### Return\n- **backgroundImage**: `Evision.Mat.t()`.\n\n  The output background image.\n\n**Note**: Sometimes the background image can be very blurry, as it contain the average background\nstatistics.\n\nPython prototype (for reference only):\n```python3\ngetBackgroundImage([, backgroundImage]) -> backgroundImage\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#getBackgroundImage/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.getBackgroundImage/2","doc":"Computes a background image.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n\n##### Return\n- **backgroundImage**: `Evision.Mat.t()`.\n\n  The output background image.\n\n**Note**: Sometimes the background image can be very blurry, as it contain the average background\nstatistics.\n\nPython prototype (for reference only):\n```python3\ngetBackgroundImage([, backgroundImage]) -> backgroundImage\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#getBackgroundImage/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.getBackgroundPrior/1","doc":"Returns the prior probability that each individual pixel is a background pixel.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetBackgroundPrior() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#getBackgroundPrior/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.getDecisionThreshold/1","doc":"Returns the value of decision threshold.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n\n##### Return\n- **retval**: `double`\n\nDecision value is the value above which pixel is determined to be FG.\n\nPython prototype (for reference only):\n```python3\ngetDecisionThreshold() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#getDecisionThreshold/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.getDefaultLearningRate/1","doc":"Returns the learning rate of the algorithm.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n\n##### Return\n- **retval**: `double`\n\nIt lies between 0.0 and 1.0. It determines how quickly features are \"forgotten\" from\nhistograms.\n\nPython prototype (for reference only):\n```python3\ngetDefaultLearningRate() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#getDefaultLearningRate/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#getDefaultName/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.getMaxFeatures/1","doc":"Returns total number of distinct colors to maintain in histogram.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxFeatures() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#getMaxFeatures/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.getMaxVal/1","doc":"Returns the maximum value taken on by pixels in image sequence. e.g. 1.0 or 255.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxVal() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#getMaxVal/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.getMinVal/1","doc":"Returns the minimum value taken on by pixels in image sequence. Usually 0.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMinVal() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#getMinVal/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.getNumFrames/1","doc":"Returns the number of frames used to initialize background model.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNumFrames() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#getNumFrames/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.getQuantizationLevels/1","doc":"Returns the parameter used for quantization of color-space.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n\n##### Return\n- **retval**: `integer()`\n\nIt is the number of discrete levels in each channel to be used in histograms.\n\nPython prototype (for reference only):\n```python3\ngetQuantizationLevels() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#getQuantizationLevels/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.getSmoothingRadius/1","doc":"Returns the kernel radius used for morphological operations\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetSmoothingRadius() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#getSmoothingRadius/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.getUpdateBackgroundModel/1","doc":"Returns the status of background model update\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetUpdateBackgroundModel() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#getUpdateBackgroundModel/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.read/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#read/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#read/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.save/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#save/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#save/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.setBackgroundPrior/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#setBackgroundPrior/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.setBackgroundPrior/2","doc":"Sets the prior probability that each individual pixel is a background pixel.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n- **bgprior**: `double`\n\nPython prototype (for reference only):\n```python3\nsetBackgroundPrior(bgprior) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#setBackgroundPrior/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.setDecisionThreshold/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#setDecisionThreshold/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.setDecisionThreshold/2","doc":"Sets the value of decision threshold.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n- **thresh**: `double`\n\nPython prototype (for reference only):\n```python3\nsetDecisionThreshold(thresh) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#setDecisionThreshold/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.setDefaultLearningRate/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#setDefaultLearningRate/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.setDefaultLearningRate/2","doc":"Sets the learning rate of the algorithm.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n- **lr**: `double`\n\nPython prototype (for reference only):\n```python3\nsetDefaultLearningRate(lr) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#setDefaultLearningRate/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.setMaxFeatures/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#setMaxFeatures/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.setMaxFeatures/2","doc":"Sets total number of distinct colors to maintain in histogram.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n- **maxFeatures**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxFeatures(maxFeatures) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#setMaxFeatures/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.setMaxVal/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#setMaxVal/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.setMaxVal/2","doc":"Sets the maximum value taken on by pixels in image sequence.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxVal(val) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#setMaxVal/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.setMinVal/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#setMinVal/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.setMinVal/2","doc":"Sets the minimum value taken on by pixels in image sequence.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMinVal(val) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#setMinVal/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.setNumFrames/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#setNumFrames/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.setNumFrames/2","doc":"Sets the number of frames used to initialize background model.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n- **nframes**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNumFrames(nframes) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#setNumFrames/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.setQuantizationLevels/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#setQuantizationLevels/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.setQuantizationLevels/2","doc":"Sets the parameter used for quantization of color-space\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n- **nlevels**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetQuantizationLevels(nlevels) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#setQuantizationLevels/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.setSmoothingRadius/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#setSmoothingRadius/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.setSmoothingRadius/2","doc":"Sets the kernel radius used for morphological operations\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n- **radius**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetSmoothingRadius(radius) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#setSmoothingRadius/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.setUpdateBackgroundModel/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#setUpdateBackgroundModel/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.setUpdateBackgroundModel/2","doc":"Sets the status of background model update\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n- **update**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetUpdateBackgroundModel(update) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#setUpdateBackgroundModel/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.write/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#write/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#write/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGMG.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGMG.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#write/3"},{"type":"type","title":"Evision.BgSegm.BackgroundSubtractorGMG.t/0","doc":"Type that represents an `BgSegm.BackgroundSubtractorGMG` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.BgSegm.BackgroundSubtractorGMG.html#t:t/0"},{"type":"module","title":"Evision.BgSegm.BackgroundSubtractorGSOC","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorGSOC.html"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGSOC.apply/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorGSOC.html#apply/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGSOC.apply/2","doc":"apply\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGSOC.t()`\n- **image**: `Evision.Mat`\n\n##### Keyword Arguments\n- **learningRate**: `double`.\n\n##### Return\n- **fgmask**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\napply(image[, fgmask[, learningRate]]) -> fgmask\n```","ref":"Evision.BgSegm.BackgroundSubtractorGSOC.html#apply/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGSOC.apply/3","doc":"apply\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGSOC.t()`\n- **image**: `Evision.Mat`\n\n##### Keyword Arguments\n- **learningRate**: `double`.\n\n##### Return\n- **fgmask**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\napply(image[, fgmask[, learningRate]]) -> fgmask\n```","ref":"Evision.BgSegm.BackgroundSubtractorGSOC.html#apply/3"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGSOC.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGSOC.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorGSOC.html#clear/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGSOC.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGSOC.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorGSOC.html#empty/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGSOC.getBackgroundImage/1","doc":"getBackgroundImage\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGSOC.t()`\n\n##### Return\n- **backgroundImage**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetBackgroundImage([, backgroundImage]) -> backgroundImage\n```","ref":"Evision.BgSegm.BackgroundSubtractorGSOC.html#getBackgroundImage/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGSOC.getBackgroundImage/2","doc":"getBackgroundImage\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGSOC.t()`\n\n##### Return\n- **backgroundImage**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetBackgroundImage([, backgroundImage]) -> backgroundImage\n```","ref":"Evision.BgSegm.BackgroundSubtractorGSOC.html#getBackgroundImage/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGSOC.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGSOC.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorGSOC.html#getDefaultName/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGSOC.read/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorGSOC.html#read/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGSOC.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGSOC.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorGSOC.html#read/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGSOC.save/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorGSOC.html#save/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGSOC.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGSOC.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorGSOC.html#save/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGSOC.write/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorGSOC.html#write/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGSOC.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGSOC.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorGSOC.html#write/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorGSOC.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorGSOC.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorGSOC.html#write/3"},{"type":"type","title":"Evision.BgSegm.BackgroundSubtractorGSOC.t/0","doc":"Type that represents an `BgSegm.BackgroundSubtractorGSOC` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.BgSegm.BackgroundSubtractorGSOC.html#t:t/0"},{"type":"module","title":"Evision.BgSegm.BackgroundSubtractorLSBP","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorLSBP.html"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorLSBP.apply/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorLSBP.html#apply/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorLSBP.apply/2","doc":"apply\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorLSBP.t()`\n- **image**: `Evision.Mat`\n\n##### Keyword Arguments\n- **learningRate**: `double`.\n\n##### Return\n- **fgmask**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\napply(image[, fgmask[, learningRate]]) -> fgmask\n```","ref":"Evision.BgSegm.BackgroundSubtractorLSBP.html#apply/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorLSBP.apply/3","doc":"apply\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorLSBP.t()`\n- **image**: `Evision.Mat`\n\n##### Keyword Arguments\n- **learningRate**: `double`.\n\n##### Return\n- **fgmask**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\napply(image[, fgmask[, learningRate]]) -> fgmask\n```","ref":"Evision.BgSegm.BackgroundSubtractorLSBP.html#apply/3"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorLSBP.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorLSBP.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorLSBP.html#clear/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorLSBP.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorLSBP.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorLSBP.html#empty/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorLSBP.getBackgroundImage/1","doc":"getBackgroundImage\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorLSBP.t()`\n\n##### Return\n- **backgroundImage**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetBackgroundImage([, backgroundImage]) -> backgroundImage\n```","ref":"Evision.BgSegm.BackgroundSubtractorLSBP.html#getBackgroundImage/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorLSBP.getBackgroundImage/2","doc":"getBackgroundImage\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorLSBP.t()`\n\n##### Return\n- **backgroundImage**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetBackgroundImage([, backgroundImage]) -> backgroundImage\n```","ref":"Evision.BgSegm.BackgroundSubtractorLSBP.html#getBackgroundImage/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorLSBP.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorLSBP.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorLSBP.html#getDefaultName/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorLSBP.read/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorLSBP.html#read/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorLSBP.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorLSBP.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorLSBP.html#read/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorLSBP.save/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorLSBP.html#save/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorLSBP.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorLSBP.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorLSBP.html#save/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorLSBP.write/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorLSBP.html#write/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorLSBP.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorLSBP.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorLSBP.html#write/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorLSBP.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorLSBP.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorLSBP.html#write/3"},{"type":"type","title":"Evision.BgSegm.BackgroundSubtractorLSBP.t/0","doc":"Type that represents an `BgSegm.BackgroundSubtractorLSBP` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.BgSegm.BackgroundSubtractorLSBP.html#t:t/0"},{"type":"module","title":"Evision.BgSegm.BackgroundSubtractorLSBPDesc","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorLSBPDesc.html"},{"type":"type","title":"Evision.BgSegm.BackgroundSubtractorLSBPDesc.t/0","doc":"Type that represents an `BgSegm.BackgroundSubtractorLSBPDesc` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.BgSegm.BackgroundSubtractorLSBPDesc.html#t:t/0"},{"type":"module","title":"Evision.BgSegm.BackgroundSubtractorMOG","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.apply/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#apply/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.apply/2","doc":"Computes a foreground mask.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorMOG.t()`\n- **image**: `Evision.Mat`.\n\n  Next video frame.\n\n##### Keyword Arguments\n- **learningRate**: `double`.\n\n  The value between 0 and 1 that indicates how fast the background model is\n  learnt. Negative parameter value makes the algorithm to use some automatically chosen learning\n  rate. 0 means that the background model is not updated at all, 1 means that the background model\n  is completely reinitialized from the last frame.\n\n##### Return\n- **fgmask**: `Evision.Mat.t()`.\n\n  The output foreground mask as an 8-bit binary image.\n\nPython prototype (for reference only):\n```python3\napply(image[, fgmask[, learningRate]]) -> fgmask\n```","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#apply/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.apply/3","doc":"Computes a foreground mask.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorMOG.t()`\n- **image**: `Evision.Mat`.\n\n  Next video frame.\n\n##### Keyword Arguments\n- **learningRate**: `double`.\n\n  The value between 0 and 1 that indicates how fast the background model is\n  learnt. Negative parameter value makes the algorithm to use some automatically chosen learning\n  rate. 0 means that the background model is not updated at all, 1 means that the background model\n  is completely reinitialized from the last frame.\n\n##### Return\n- **fgmask**: `Evision.Mat.t()`.\n\n  The output foreground mask as an 8-bit binary image.\n\nPython prototype (for reference only):\n```python3\napply(image[, fgmask[, learningRate]]) -> fgmask\n```","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#apply/3"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorMOG.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#clear/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorMOG.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#empty/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.getBackgroundImage/1","doc":"Computes a background image.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorMOG.t()`\n\n##### Return\n- **backgroundImage**: `Evision.Mat.t()`.\n\n  The output background image.\n\n**Note**: Sometimes the background image can be very blurry, as it contain the average background\nstatistics.\n\nPython prototype (for reference only):\n```python3\ngetBackgroundImage([, backgroundImage]) -> backgroundImage\n```","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#getBackgroundImage/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.getBackgroundImage/2","doc":"Computes a background image.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorMOG.t()`\n\n##### Return\n- **backgroundImage**: `Evision.Mat.t()`.\n\n  The output background image.\n\n**Note**: Sometimes the background image can be very blurry, as it contain the average background\nstatistics.\n\nPython prototype (for reference only):\n```python3\ngetBackgroundImage([, backgroundImage]) -> backgroundImage\n```","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#getBackgroundImage/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.getBackgroundRatio/1","doc":"getBackgroundRatio\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorMOG.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetBackgroundRatio() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#getBackgroundRatio/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorMOG.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#getDefaultName/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.getHistory/1","doc":"getHistory\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorMOG.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetHistory() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#getHistory/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.getNMixtures/1","doc":"getNMixtures\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorMOG.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNMixtures() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#getNMixtures/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.getNoiseSigma/1","doc":"getNoiseSigma\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorMOG.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetNoiseSigma() -> retval\n```","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#getNoiseSigma/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.read/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#read/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorMOG.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#read/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.save/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#save/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorMOG.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#save/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.setBackgroundRatio/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#setBackgroundRatio/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.setBackgroundRatio/2","doc":"setBackgroundRatio\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorMOG.t()`\n- **backgroundRatio**: `double`\n\nPython prototype (for reference only):\n```python3\nsetBackgroundRatio(backgroundRatio) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#setBackgroundRatio/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.setHistory/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#setHistory/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.setHistory/2","doc":"setHistory\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorMOG.t()`\n- **nframes**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetHistory(nframes) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#setHistory/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.setNMixtures/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#setNMixtures/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.setNMixtures/2","doc":"setNMixtures\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorMOG.t()`\n- **nmix**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNMixtures(nmix) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#setNMixtures/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.setNoiseSigma/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#setNoiseSigma/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.setNoiseSigma/2","doc":"setNoiseSigma\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorMOG.t()`\n- **noiseSigma**: `double`\n\nPython prototype (for reference only):\n```python3\nsetNoiseSigma(noiseSigma) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#setNoiseSigma/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.write/1","doc":"","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#write/1"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorMOG.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#write/2"},{"type":"function","title":"Evision.BgSegm.BackgroundSubtractorMOG.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.BackgroundSubtractorMOG.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#write/3"},{"type":"type","title":"Evision.BgSegm.BackgroundSubtractorMOG.t/0","doc":"Type that represents an `BgSegm.BackgroundSubtractorMOG` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.BgSegm.BackgroundSubtractorMOG.html#t:t/0"},{"type":"module","title":"Evision.BgSegm.LSBPCameraMotionCompensation","doc":"","ref":"Evision.BgSegm.LSBPCameraMotionCompensation.html"},{"type":"function","title":"Evision.BgSegm.LSBPCameraMotionCompensation.cv_LSBP_CAMERA_MOTION_COMPENSATION_LK/0","doc":"","ref":"Evision.BgSegm.LSBPCameraMotionCompensation.html#cv_LSBP_CAMERA_MOTION_COMPENSATION_LK/0"},{"type":"function","title":"Evision.BgSegm.LSBPCameraMotionCompensation.cv_LSBP_CAMERA_MOTION_COMPENSATION_NONE/0","doc":"","ref":"Evision.BgSegm.LSBPCameraMotionCompensation.html#cv_LSBP_CAMERA_MOTION_COMPENSATION_NONE/0"},{"type":"type","title":"Evision.BgSegm.LSBPCameraMotionCompensation.enum/0","doc":"","ref":"Evision.BgSegm.LSBPCameraMotionCompensation.html#t:enum/0"},{"type":"module","title":"Evision.BgSegm.SyntheticSequenceGenerator","doc":"","ref":"Evision.BgSegm.SyntheticSequenceGenerator.html"},{"type":"function","title":"Evision.BgSegm.SyntheticSequenceGenerator.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.SyntheticSequenceGenerator.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.BgSegm.SyntheticSequenceGenerator.html#clear/1"},{"type":"function","title":"Evision.BgSegm.SyntheticSequenceGenerator.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.SyntheticSequenceGenerator.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.BgSegm.SyntheticSequenceGenerator.html#empty/1"},{"type":"function","title":"Evision.BgSegm.SyntheticSequenceGenerator.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.SyntheticSequenceGenerator.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.BgSegm.SyntheticSequenceGenerator.html#getDefaultName/1"},{"type":"function","title":"Evision.BgSegm.SyntheticSequenceGenerator.getNextFrame/1","doc":"Obtain the next frame in the sequence.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.SyntheticSequenceGenerator.t()`\n\n##### Return\n- **frame**: `Evision.Mat.t()`.\n\n  Output frame.\n\n- **gtMask**: `Evision.Mat.t()`.\n\n  Output ground-truth (reference) segmentation mask object/background.\n\nPython prototype (for reference only):\n```python3\ngetNextFrame([, frame[, gtMask]]) -> frame, gtMask\n```","ref":"Evision.BgSegm.SyntheticSequenceGenerator.html#getNextFrame/1"},{"type":"function","title":"Evision.BgSegm.SyntheticSequenceGenerator.getNextFrame/2","doc":"Obtain the next frame in the sequence.\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.SyntheticSequenceGenerator.t()`\n\n##### Return\n- **frame**: `Evision.Mat.t()`.\n\n  Output frame.\n\n- **gtMask**: `Evision.Mat.t()`.\n\n  Output ground-truth (reference) segmentation mask object/background.\n\nPython prototype (for reference only):\n```python3\ngetNextFrame([, frame[, gtMask]]) -> frame, gtMask\n```","ref":"Evision.BgSegm.SyntheticSequenceGenerator.html#getNextFrame/2"},{"type":"function","title":"Evision.BgSegm.SyntheticSequenceGenerator.read/1","doc":"","ref":"Evision.BgSegm.SyntheticSequenceGenerator.html#read/1"},{"type":"function","title":"Evision.BgSegm.SyntheticSequenceGenerator.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.SyntheticSequenceGenerator.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.BgSegm.SyntheticSequenceGenerator.html#read/2"},{"type":"function","title":"Evision.BgSegm.SyntheticSequenceGenerator.save/1","doc":"","ref":"Evision.BgSegm.SyntheticSequenceGenerator.html#save/1"},{"type":"function","title":"Evision.BgSegm.SyntheticSequenceGenerator.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.SyntheticSequenceGenerator.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.BgSegm.SyntheticSequenceGenerator.html#save/2"},{"type":"function","title":"Evision.BgSegm.SyntheticSequenceGenerator.syntheticSequenceGenerator/1","doc":"","ref":"Evision.BgSegm.SyntheticSequenceGenerator.html#syntheticSequenceGenerator/1"},{"type":"function","title":"Evision.BgSegm.SyntheticSequenceGenerator.syntheticSequenceGenerator/6","doc":"Creates an instance of SyntheticSequenceGenerator.\n\n##### Positional Arguments\n- **background**: `Evision.Mat`.\n\n  Background image for object.\n\n- **object**: `Evision.Mat`.\n\n  Object image which will move slowly over the background.\n\n- **amplitude**: `double`.\n\n  Amplitude of wave distortion applied to background.\n\n- **wavelength**: `double`.\n\n  Length of waves in distortion applied to background.\n\n- **wavespeed**: `double`.\n\n  How fast waves will move.\n\n- **objspeed**: `double`.\n\n  How fast object will fly over background.\n\n##### Return\n- **self**: `Evision.BgSegm.SyntheticSequenceGenerator.t()`\n\nPython prototype (for reference only):\n```python3\nSyntheticSequenceGenerator(background, object, amplitude, wavelength, wavespeed, objspeed) ->  \n```","ref":"Evision.BgSegm.SyntheticSequenceGenerator.html#syntheticSequenceGenerator/6"},{"type":"function","title":"Evision.BgSegm.SyntheticSequenceGenerator.write/1","doc":"","ref":"Evision.BgSegm.SyntheticSequenceGenerator.html#write/1"},{"type":"function","title":"Evision.BgSegm.SyntheticSequenceGenerator.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.SyntheticSequenceGenerator.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.BgSegm.SyntheticSequenceGenerator.html#write/2"},{"type":"function","title":"Evision.BgSegm.SyntheticSequenceGenerator.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.BgSegm.SyntheticSequenceGenerator.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.BgSegm.SyntheticSequenceGenerator.html#write/3"},{"type":"type","title":"Evision.BgSegm.SyntheticSequenceGenerator.t/0","doc":"Type that represents an `BgSegm.SyntheticSequenceGenerator` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.BgSegm.SyntheticSequenceGenerator.html#t:t/0"},{"type":"module","title":"Evision.Bioinspired","doc":"","ref":"Evision.Bioinspired.html"},{"type":"function","title":"Evision.Bioinspired.cv_RETINA_COLOR_BAYER/0","doc":"","ref":"Evision.Bioinspired.html#cv_RETINA_COLOR_BAYER/0"},{"type":"function","title":"Evision.Bioinspired.cv_RETINA_COLOR_DIAGONAL/0","doc":"","ref":"Evision.Bioinspired.html#cv_RETINA_COLOR_DIAGONAL/0"},{"type":"function","title":"Evision.Bioinspired.cv_RETINA_COLOR_RANDOM/0","doc":"","ref":"Evision.Bioinspired.html#cv_RETINA_COLOR_RANDOM/0"},{"type":"type","title":"Evision.Bioinspired.enum/0","doc":"","ref":"Evision.Bioinspired.html#t:enum/0"},{"type":"type","title":"Evision.Bioinspired.t/0","doc":"Type that represents an `Bioinspired` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Bioinspired.html#t:t/0"},{"type":"module","title":"Evision.Bioinspired.Retina","doc":"","ref":"Evision.Bioinspired.Retina.html"},{"type":"function","title":"Evision.Bioinspired.Retina.activateContoursProcessing/1","doc":"","ref":"Evision.Bioinspired.Retina.html#activateContoursProcessing/1"},{"type":"function","title":"Evision.Bioinspired.Retina.activateContoursProcessing/2","doc":"Activate/desactivate the Parvocellular pathway processing (contours information extraction), by\ndefault, it is activated\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n- **activate**: `bool`.\n\n  true if Parvocellular (contours information extraction) output should be\n  activated, false if not... if activated, the Parvocellular output can be retrieved using the\n  Retina::getParvo methods\n\nPython prototype (for reference only):\n```python3\nactivateContoursProcessing(activate) -> None\n```","ref":"Evision.Bioinspired.Retina.html#activateContoursProcessing/2"},{"type":"function","title":"Evision.Bioinspired.Retina.activateMovingContoursProcessing/1","doc":"","ref":"Evision.Bioinspired.Retina.html#activateMovingContoursProcessing/1"},{"type":"function","title":"Evision.Bioinspired.Retina.activateMovingContoursProcessing/2","doc":"Activate/desactivate the Magnocellular pathway processing (motion information extraction), by\ndefault, it is activated\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n- **activate**: `bool`.\n\n  true if Magnocellular output should be activated, false if not... if activated,\n  the Magnocellular output can be retrieved using the **getMagno** methods\n\nPython prototype (for reference only):\n```python3\nactivateMovingContoursProcessing(activate) -> None\n```","ref":"Evision.Bioinspired.Retina.html#activateMovingContoursProcessing/2"},{"type":"function","title":"Evision.Bioinspired.Retina.applyFastToneMapping/1","doc":"","ref":"Evision.Bioinspired.Retina.html#applyFastToneMapping/1"},{"type":"function","title":"Evision.Bioinspired.Retina.applyFastToneMapping/2","doc":"Method which processes an image in the aim to correct its luminance correct\nbacklight problems, enhance details in shadows.\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n- **inputImage**: `Evision.Mat`.\n\n  the input image to process (should be coded in float format : CV_32F,\n  CV_32FC1, CV_32F_C3, CV_32F_C4, the 4th channel won't be considered).\n\n##### Return\n- **outputToneMappedImage**: `Evision.Mat.t()`.\n\n  the output 8bit/channel tone mapped image (CV_8U or CV_8UC3 format).\n\nThis method is designed to perform High Dynamic Range image tone mapping (compress \\>8bit/pixel\nimages to 8bit/pixel). This is a simplified version of the Retina Parvocellular model\n(simplified version of the run/getParvo methods call) since it does not include the\nspatio-temporal filter modelling the Outer Plexiform Layer of the retina that performs spectral\nwhitening and many other stuff. However, it works great for tone mapping and in a faster way.\nCheck the demos and experiments section to see examples and the way to perform tone mapping\nusing the original retina model and the method.\n\nPython prototype (for reference only):\n```python3\napplyFastToneMapping(inputImage[, outputToneMappedImage]) -> outputToneMappedImage\n```","ref":"Evision.Bioinspired.Retina.html#applyFastToneMapping/2"},{"type":"function","title":"Evision.Bioinspired.Retina.applyFastToneMapping/3","doc":"Method which processes an image in the aim to correct its luminance correct\nbacklight problems, enhance details in shadows.\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n- **inputImage**: `Evision.Mat`.\n\n  the input image to process (should be coded in float format : CV_32F,\n  CV_32FC1, CV_32F_C3, CV_32F_C4, the 4th channel won't be considered).\n\n##### Return\n- **outputToneMappedImage**: `Evision.Mat.t()`.\n\n  the output 8bit/channel tone mapped image (CV_8U or CV_8UC3 format).\n\nThis method is designed to perform High Dynamic Range image tone mapping (compress \\>8bit/pixel\nimages to 8bit/pixel). This is a simplified version of the Retina Parvocellular model\n(simplified version of the run/getParvo methods call) since it does not include the\nspatio-temporal filter modelling the Outer Plexiform Layer of the retina that performs spectral\nwhitening and many other stuff. However, it works great for tone mapping and in a faster way.\nCheck the demos and experiments section to see examples and the way to perform tone mapping\nusing the original retina model and the method.\n\nPython prototype (for reference only):\n```python3\napplyFastToneMapping(inputImage[, outputToneMappedImage]) -> outputToneMappedImage\n```","ref":"Evision.Bioinspired.Retina.html#applyFastToneMapping/3"},{"type":"function","title":"Evision.Bioinspired.Retina.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Bioinspired.Retina.html#clear/1"},{"type":"function","title":"Evision.Bioinspired.Retina.clearBuffers/1","doc":"Clears all retina buffers\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n\n(equivalent to opening the eyes after a long period of eye close ;o) whatchout the temporal\ntransition occuring just after this method call.\n\nPython prototype (for reference only):\n```python3\nclearBuffers() -> None\n```","ref":"Evision.Bioinspired.Retina.html#clearBuffers/1"},{"type":"function","title":"Evision.Bioinspired.Retina.create/1","doc":"create\n\n##### Positional Arguments\n- **inputSize**: `Size`\n\n##### Return\n- **retval**: `Retina`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncreate(inputSize) -> retval\n```","ref":"Evision.Bioinspired.Retina.html#create/1"},{"type":"function","title":"Evision.Bioinspired.Retina.create/2","doc":"Constructors from standardized interfaces : retreive a smart pointer to a Retina instance\n\n##### Positional Arguments\n- **inputSize**: `Size`.\n\n  the input frame size\n\n- **colorMode**: `bool`.\n\n  the chosen processing mode : with or without color processing\n\n##### Keyword Arguments\n- **colorSamplingMethod**: `integer()`.\n\n  specifies which kind of color sampling will be used :\n  - cv::bioinspired::RETINA_COLOR_RANDOM: each pixel position is either R, G or B in a random choice\n  - cv::bioinspired::RETINA_COLOR_DIAGONAL: color sampling is RGBRGBRGB..., line 2 BRGBRGBRG..., line 3, GBRGBRGBR...\n  - cv::bioinspired::RETINA_COLOR_BAYER: standard bayer sampling\n\n- **useRetinaLogSampling**: `bool`.\n\n  activate retina log sampling, if true, the 2 following parameters can\n  be used\n\n- **reductionFactor**: `float`.\n\n  only usefull if param useRetinaLogSampling=true, specifies the reduction\n  factor of the output frame (as the center (fovea) is high resolution and corners can be\n  underscaled, then a reduction of the output is allowed without precision leak\n\n- **samplingStrength**: `float`.\n\n  only usefull if param useRetinaLogSampling=true, specifies the strength of\n  the log scale that is applied\n\n##### Return\n- **retval**: `Retina`\n\nPython prototype (for reference only):\n```python3\ncreate(inputSize, colorMode[, colorSamplingMethod[, useRetinaLogSampling[, reductionFactor[, samplingStrength]]]]) -> retval\n```","ref":"Evision.Bioinspired.Retina.html#create/2"},{"type":"function","title":"Evision.Bioinspired.Retina.create/3","doc":"Constructors from standardized interfaces : retreive a smart pointer to a Retina instance\n\n##### Positional Arguments\n- **inputSize**: `Size`.\n\n  the input frame size\n\n- **colorMode**: `bool`.\n\n  the chosen processing mode : with or without color processing\n\n##### Keyword Arguments\n- **colorSamplingMethod**: `integer()`.\n\n  specifies which kind of color sampling will be used :\n  - cv::bioinspired::RETINA_COLOR_RANDOM: each pixel position is either R, G or B in a random choice\n  - cv::bioinspired::RETINA_COLOR_DIAGONAL: color sampling is RGBRGBRGB..., line 2 BRGBRGBRG..., line 3, GBRGBRGBR...\n  - cv::bioinspired::RETINA_COLOR_BAYER: standard bayer sampling\n\n- **useRetinaLogSampling**: `bool`.\n\n  activate retina log sampling, if true, the 2 following parameters can\n  be used\n\n- **reductionFactor**: `float`.\n\n  only usefull if param useRetinaLogSampling=true, specifies the reduction\n  factor of the output frame (as the center (fovea) is high resolution and corners can be\n  underscaled, then a reduction of the output is allowed without precision leak\n\n- **samplingStrength**: `float`.\n\n  only usefull if param useRetinaLogSampling=true, specifies the strength of\n  the log scale that is applied\n\n##### Return\n- **retval**: `Retina`\n\nPython prototype (for reference only):\n```python3\ncreate(inputSize, colorMode[, colorSamplingMethod[, useRetinaLogSampling[, reductionFactor[, samplingStrength]]]]) -> retval\n```","ref":"Evision.Bioinspired.Retina.html#create/3"},{"type":"function","title":"Evision.Bioinspired.Retina.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Bioinspired.Retina.html#empty/1"},{"type":"function","title":"Evision.Bioinspired.Retina.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Bioinspired.Retina.html#getDefaultName/1"},{"type":"function","title":"Evision.Bioinspired.Retina.getInputSize/1","doc":"Retreive retina input buffer size\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n\n##### Return\n- **retval**: `Size`\n\n@return the retina input buffer size\n\nPython prototype (for reference only):\n```python3\ngetInputSize() -> retval\n```","ref":"Evision.Bioinspired.Retina.html#getInputSize/1"},{"type":"function","title":"Evision.Bioinspired.Retina.getMagno/1","doc":"Accessor of the motion channel of the retina (models peripheral vision).\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n\n##### Return\n- **retinaOutput_magno**: `Evision.Mat.t()`.\n\n  the output buffer (reallocated if necessary), format can be :\n  - a Mat, this output is rescaled for standard 8bits image processing use in OpenCV\n  - RAW methods actually return a 1D matrix (encoding is M1, M2,... Mn), this output is the\n    original retina filter model output, without any quantification or rescaling.\n\nWarning, getMagnoRAW methods return buffers that are not rescaled within range [0;255] while\nthe non RAW method allows a normalized matrix to be retrieved.\n@see getMagnoRAW\n\nPython prototype (for reference only):\n```python3\ngetMagno([, retinaOutput_magno]) -> retinaOutput_magno\n```","ref":"Evision.Bioinspired.Retina.html#getMagno/1"},{"type":"function","title":"Evision.Bioinspired.Retina.getMagno/2","doc":"Accessor of the motion channel of the retina (models peripheral vision).\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n\n##### Return\n- **retinaOutput_magno**: `Evision.Mat.t()`.\n\n  the output buffer (reallocated if necessary), format can be :\n  - a Mat, this output is rescaled for standard 8bits image processing use in OpenCV\n  - RAW methods actually return a 1D matrix (encoding is M1, M2,... Mn), this output is the\n    original retina filter model output, without any quantification or rescaling.\n\nWarning, getMagnoRAW methods return buffers that are not rescaled within range [0;255] while\nthe non RAW method allows a normalized matrix to be retrieved.\n@see getMagnoRAW\n\nPython prototype (for reference only):\n```python3\ngetMagno([, retinaOutput_magno]) -> retinaOutput_magno\n```","ref":"Evision.Bioinspired.Retina.html#getMagno/2"},{"type":"function","title":"Evision.Bioinspired.Retina.getMagnoRAW/1","doc":"getMagnoRAW\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ngetMagnoRAW() -> retval\n```","ref":"Evision.Bioinspired.Retina.html#getMagnoRAW/1"},{"type":"function","title":"Evision.Bioinspired.Retina.getOutputSize/1","doc":"Retreive retina output buffer size that can be different from the input if a spatial log\ntransformation is applied\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n\n##### Return\n- **retval**: `Size`\n\n@return the retina output buffer size\n\nPython prototype (for reference only):\n```python3\ngetOutputSize() -> retval\n```","ref":"Evision.Bioinspired.Retina.html#getOutputSize/1"},{"type":"function","title":"Evision.Bioinspired.Retina.getParvo/1","doc":"Accessor of the details channel of the retina (models foveal vision).\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n\n##### Return\n- **retinaOutput_parvo**: `Evision.Mat.t()`.\n\n  the output buffer (reallocated if necessary), format can be :\n  - a Mat, this output is rescaled for standard 8bits image processing use in OpenCV\n  - RAW methods actually return a 1D matrix (encoding is R1, R2, ... Rn, G1, G2, ..., Gn, B1,\n    B2, ...Bn), this output is the original retina filter model output, without any\n    quantification or rescaling.\n\nWarning, getParvoRAW methods return buffers that are not rescaled within range [0;255] while\nthe non RAW method allows a normalized matrix to be retrieved.\n@see getParvoRAW\n\nPython prototype (for reference only):\n```python3\ngetParvo([, retinaOutput_parvo]) -> retinaOutput_parvo\n```","ref":"Evision.Bioinspired.Retina.html#getParvo/1"},{"type":"function","title":"Evision.Bioinspired.Retina.getParvo/2","doc":"Accessor of the details channel of the retina (models foveal vision).\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n\n##### Return\n- **retinaOutput_parvo**: `Evision.Mat.t()`.\n\n  the output buffer (reallocated if necessary), format can be :\n  - a Mat, this output is rescaled for standard 8bits image processing use in OpenCV\n  - RAW methods actually return a 1D matrix (encoding is R1, R2, ... Rn, G1, G2, ..., Gn, B1,\n    B2, ...Bn), this output is the original retina filter model output, without any\n    quantification or rescaling.\n\nWarning, getParvoRAW methods return buffers that are not rescaled within range [0;255] while\nthe non RAW method allows a normalized matrix to be retrieved.\n@see getParvoRAW\n\nPython prototype (for reference only):\n```python3\ngetParvo([, retinaOutput_parvo]) -> retinaOutput_parvo\n```","ref":"Evision.Bioinspired.Retina.html#getParvo/2"},{"type":"function","title":"Evision.Bioinspired.Retina.getParvoRAW/1","doc":"getParvoRAW\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ngetParvoRAW() -> retval\n```","ref":"Evision.Bioinspired.Retina.html#getParvoRAW/1"},{"type":"function","title":"Evision.Bioinspired.Retina.printSetup/1","doc":"Outputs a string showing the used parameters setup\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n\n##### Return\n- **retval**: `String`\n\n@return a string which contains formated parameters information\n\nPython prototype (for reference only):\n```python3\nprintSetup() -> retval\n```","ref":"Evision.Bioinspired.Retina.html#printSetup/1"},{"type":"function","title":"Evision.Bioinspired.Retina.read/1","doc":"","ref":"Evision.Bioinspired.Retina.html#read/1"},{"type":"function","title":"Evision.Bioinspired.Retina.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Bioinspired.Retina.html#read/2"},{"type":"function","title":"Evision.Bioinspired.Retina.run/1","doc":"","ref":"Evision.Bioinspired.Retina.html#run/1"},{"type":"function","title":"Evision.Bioinspired.Retina.run/2","doc":"Method which allows retina to be applied on an input image,\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n- **inputImage**: `Evision.Mat`.\n\n  the input Mat image to be processed, can be gray level or BGR coded in any\n  format (from 8bit to 16bits)\n\nafter run, encapsulated retina module is ready to deliver its outputs using dedicated\nacccessors, see getParvo and getMagno methods\n\nPython prototype (for reference only):\n```python3\nrun(inputImage) -> None\n```","ref":"Evision.Bioinspired.Retina.html#run/2"},{"type":"function","title":"Evision.Bioinspired.Retina.save/1","doc":"","ref":"Evision.Bioinspired.Retina.html#save/1"},{"type":"function","title":"Evision.Bioinspired.Retina.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Bioinspired.Retina.html#save/2"},{"type":"function","title":"Evision.Bioinspired.Retina.setColorSaturation/1","doc":"Activate color saturation as the final step of the color demultiplexing process -\\> this\nsaturation is a sigmoide function applied to each channel of the demultiplexed image.\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n\n##### Keyword Arguments\n- **saturateColors**: `bool`.\n\n  boolean that activates color saturation (if true) or desactivate (if false)\n\n- **colorSaturationValue**: `float`.\n\n  the saturation factor : a simple factor applied on the chrominance\n  buffers\n\nPython prototype (for reference only):\n```python3\nsetColorSaturation([, saturateColors[, colorSaturationValue]]) -> None\n```","ref":"Evision.Bioinspired.Retina.html#setColorSaturation/1"},{"type":"function","title":"Evision.Bioinspired.Retina.setColorSaturation/2","doc":"Activate color saturation as the final step of the color demultiplexing process -\\> this\nsaturation is a sigmoide function applied to each channel of the demultiplexed image.\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n\n##### Keyword Arguments\n- **saturateColors**: `bool`.\n\n  boolean that activates color saturation (if true) or desactivate (if false)\n\n- **colorSaturationValue**: `float`.\n\n  the saturation factor : a simple factor applied on the chrominance\n  buffers\n\nPython prototype (for reference only):\n```python3\nsetColorSaturation([, saturateColors[, colorSaturationValue]]) -> None\n```","ref":"Evision.Bioinspired.Retina.html#setColorSaturation/2"},{"type":"function","title":"Evision.Bioinspired.Retina.setup/1","doc":"Try to open an XML retina parameters file to adjust current retina instance setup\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n\n##### Keyword Arguments\n- **retinaParameterFile**: `String`.\n\n  the parameters filename\n\n- **applyDefaultSetupOnFailure**: `bool`.\n\n  set to true if an error must be thrown on error\n\n- if the xml file does not exist, then default setup is applied\n- warning, Exceptions are thrown if read XML file is not valid\n\nYou can retrieve the current parameters structure using the method Retina::getParameters and update\nit before running method Retina::setup.\n\nPython prototype (for reference only):\n```python3\nsetup([, retinaParameterFile[, applyDefaultSetupOnFailure]]) -> None\n```","ref":"Evision.Bioinspired.Retina.html#setup/1"},{"type":"function","title":"Evision.Bioinspired.Retina.setup/2","doc":"Try to open an XML retina parameters file to adjust current retina instance setup\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n\n##### Keyword Arguments\n- **retinaParameterFile**: `String`.\n\n  the parameters filename\n\n- **applyDefaultSetupOnFailure**: `bool`.\n\n  set to true if an error must be thrown on error\n\n- if the xml file does not exist, then default setup is applied\n- warning, Exceptions are thrown if read XML file is not valid\n\nYou can retrieve the current parameters structure using the method Retina::getParameters and update\nit before running method Retina::setup.\n\nPython prototype (for reference only):\n```python3\nsetup([, retinaParameterFile[, applyDefaultSetupOnFailure]]) -> None\n```","ref":"Evision.Bioinspired.Retina.html#setup/2"},{"type":"function","title":"Evision.Bioinspired.Retina.setupIPLMagnoChannel/1","doc":"Set parameters values for the Inner Plexiform Layer (IPL) magnocellular channel\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n\n##### Keyword Arguments\n- **normaliseOutput**: `bool`.\n\n  specifies if (true) output is rescaled between 0 and 255 of not (false)\n\n- **parasolCells_beta**: `float`.\n\n  the low pass filter gain used for local contrast adaptation at the\n  IPL level of the retina (for ganglion cells local adaptation), typical value is 0\n\n- **parasolCells_tau**: `float`.\n\n  the low pass filter time constant used for local contrast adaptation\n  at the IPL level of the retina (for ganglion cells local adaptation), unit is frame, typical\n  value is 0 (immediate response)\n\n- **parasolCells_k**: `float`.\n\n  the low pass filter spatial constant used for local contrast adaptation\n  at the IPL level of the retina (for ganglion cells local adaptation), unit is pixels, typical\n  value is 5\n\n- **amacrinCellsTemporalCutFrequency**: `float`.\n\n  the time constant of the first order high pass fiter of\n  the magnocellular way (motion information channel), unit is frames, typical value is 1.2\n\n- **v0CompressionParameter**: `float`.\n\n  the compression strengh of the ganglion cells local adaptation\n  output, set a value between 0.6 and 1 for best results, a high value increases more the low\n  value sensitivity... and the output saturates faster, recommended value: 0.95\n\n- **localAdaptintegration_tau**: `float`.\n\n  specifies the temporal constant of the low pas filter\n  involved in the computation of the local \"motion mean\" for the local adaptation computation\n\n- **localAdaptintegration_k**: `float`.\n\n  specifies the spatial constant of the low pas filter involved\n  in the computation of the local \"motion mean\" for the local adaptation computation\n\nthis channel processes signals output from OPL processing stage in peripheral vision, it allows\nmotion information enhancement. It is decorrelated from the details channel. See reference\npapers for more details.\n\nPython prototype (for reference only):\n```python3\nsetupIPLMagnoChannel([, normaliseOutput[, parasolCells_beta[, parasolCells_tau[, parasolCells_k[, amacrinCellsTemporalCutFrequency[, V0CompressionParameter[, localAdaptintegration_tau[, localAdaptintegration_k]]]]]]]]) -> None\n```","ref":"Evision.Bioinspired.Retina.html#setupIPLMagnoChannel/1"},{"type":"function","title":"Evision.Bioinspired.Retina.setupIPLMagnoChannel/2","doc":"Set parameters values for the Inner Plexiform Layer (IPL) magnocellular channel\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n\n##### Keyword Arguments\n- **normaliseOutput**: `bool`.\n\n  specifies if (true) output is rescaled between 0 and 255 of not (false)\n\n- **parasolCells_beta**: `float`.\n\n  the low pass filter gain used for local contrast adaptation at the\n  IPL level of the retina (for ganglion cells local adaptation), typical value is 0\n\n- **parasolCells_tau**: `float`.\n\n  the low pass filter time constant used for local contrast adaptation\n  at the IPL level of the retina (for ganglion cells local adaptation), unit is frame, typical\n  value is 0 (immediate response)\n\n- **parasolCells_k**: `float`.\n\n  the low pass filter spatial constant used for local contrast adaptation\n  at the IPL level of the retina (for ganglion cells local adaptation), unit is pixels, typical\n  value is 5\n\n- **amacrinCellsTemporalCutFrequency**: `float`.\n\n  the time constant of the first order high pass fiter of\n  the magnocellular way (motion information channel), unit is frames, typical value is 1.2\n\n- **v0CompressionParameter**: `float`.\n\n  the compression strengh of the ganglion cells local adaptation\n  output, set a value between 0.6 and 1 for best results, a high value increases more the low\n  value sensitivity... and the output saturates faster, recommended value: 0.95\n\n- **localAdaptintegration_tau**: `float`.\n\n  specifies the temporal constant of the low pas filter\n  involved in the computation of the local \"motion mean\" for the local adaptation computation\n\n- **localAdaptintegration_k**: `float`.\n\n  specifies the spatial constant of the low pas filter involved\n  in the computation of the local \"motion mean\" for the local adaptation computation\n\nthis channel processes signals output from OPL processing stage in peripheral vision, it allows\nmotion information enhancement. It is decorrelated from the details channel. See reference\npapers for more details.\n\nPython prototype (for reference only):\n```python3\nsetupIPLMagnoChannel([, normaliseOutput[, parasolCells_beta[, parasolCells_tau[, parasolCells_k[, amacrinCellsTemporalCutFrequency[, V0CompressionParameter[, localAdaptintegration_tau[, localAdaptintegration_k]]]]]]]]) -> None\n```","ref":"Evision.Bioinspired.Retina.html#setupIPLMagnoChannel/2"},{"type":"function","title":"Evision.Bioinspired.Retina.setupOPLandIPLParvoChannel/1","doc":"Setup the OPL and IPL parvo channels (see biologocal model)\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n\n##### Keyword Arguments\n- **colorMode**: `bool`.\n\n  specifies if (true) color is processed of not (false) to then processing gray\n  level image\n\n- **normaliseOutput**: `bool`.\n\n  specifies if (true) output is rescaled between 0 and 255 of not (false)\n\n- **photoreceptorsLocalAdaptationSensitivity**: `float`.\n\n  the photoreceptors sensitivity renage is 0-1\n  (more log compression effect when value increases)\n\n- **photoreceptorsTemporalConstant**: `float`.\n\n  the time constant of the first order low pass filter of\n  the photoreceptors, use it to cut high temporal frequencies (noise or fast motion), unit is\n  frames, typical value is 1 frame\n\n- **photoreceptorsSpatialConstant**: `float`.\n\n  the spatial constant of the first order low pass filter of\n  the photoreceptors, use it to cut high spatial frequencies (noise or thick contours), unit is\n  pixels, typical value is 1 pixel\n\n- **horizontalCellsGain**: `float`.\n\n  gain of the horizontal cells network, if 0, then the mean value of\n  the output is zero, if the parameter is near 1, then, the luminance is not filtered and is\n  still reachable at the output, typicall value is 0\n\n- **hcellsTemporalConstant**: `float`.\n\n  the time constant of the first order low pass filter of the\n  horizontal cells, use it to cut low temporal frequencies (local luminance variations), unit is\n  frames, typical value is 1 frame, as the photoreceptors\n\n- **hcellsSpatialConstant**: `float`.\n\n  the spatial constant of the first order low pass filter of the\n  horizontal cells, use it to cut low spatial frequencies (local luminance), unit is pixels,\n  typical value is 5 pixel, this value is also used for local contrast computing when computing\n  the local contrast adaptation at the ganglion cells level (Inner Plexiform Layer parvocellular\n  channel model)\n\n- **ganglionCellsSensitivity**: `float`.\n\n  the compression strengh of the ganglion cells local adaptation\n  output, set a value between 0.6 and 1 for best results, a high value increases more the low\n  value sensitivity... and the output saturates faster, recommended value: 0.7\n\nOPL is referred as Outer Plexiform Layer of the retina, it allows the spatio-temporal filtering\nwhich withens the spectrum and reduces spatio-temporal noise while attenuating global luminance\n(low frequency energy) IPL parvo is the OPL next processing stage, it refers to a part of the\nInner Plexiform layer of the retina, it allows high contours sensitivity in foveal vision. See\nreference papers for more informations.\nfor more informations, please have a look at the paper Benoit A., Caplier A., Durette B., Herault, J., \"USING HUMAN VISUAL SYSTEM MODELING FOR BIO-INSPIRED LOW LEVEL IMAGE PROCESSING\", Elsevier, Computer Vision and Image Understanding 114 (2010), pp. 758-773, DOI: http://dx.doi.org/10.1016/j.cviu.2010.01.011\n\nPython prototype (for reference only):\n```python3\nsetupOPLandIPLParvoChannel([, colorMode[, normaliseOutput[, photoreceptorsLocalAdaptationSensitivity[, photoreceptorsTemporalConstant[, photoreceptorsSpatialConstant[, horizontalCellsGain[, HcellsTemporalConstant[, HcellsSpatialConstant[, ganglionCellsSensitivity]]]]]]]]]) -> None\n```","ref":"Evision.Bioinspired.Retina.html#setupOPLandIPLParvoChannel/1"},{"type":"function","title":"Evision.Bioinspired.Retina.setupOPLandIPLParvoChannel/2","doc":"Setup the OPL and IPL parvo channels (see biologocal model)\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n\n##### Keyword Arguments\n- **colorMode**: `bool`.\n\n  specifies if (true) color is processed of not (false) to then processing gray\n  level image\n\n- **normaliseOutput**: `bool`.\n\n  specifies if (true) output is rescaled between 0 and 255 of not (false)\n\n- **photoreceptorsLocalAdaptationSensitivity**: `float`.\n\n  the photoreceptors sensitivity renage is 0-1\n  (more log compression effect when value increases)\n\n- **photoreceptorsTemporalConstant**: `float`.\n\n  the time constant of the first order low pass filter of\n  the photoreceptors, use it to cut high temporal frequencies (noise or fast motion), unit is\n  frames, typical value is 1 frame\n\n- **photoreceptorsSpatialConstant**: `float`.\n\n  the spatial constant of the first order low pass filter of\n  the photoreceptors, use it to cut high spatial frequencies (noise or thick contours), unit is\n  pixels, typical value is 1 pixel\n\n- **horizontalCellsGain**: `float`.\n\n  gain of the horizontal cells network, if 0, then the mean value of\n  the output is zero, if the parameter is near 1, then, the luminance is not filtered and is\n  still reachable at the output, typicall value is 0\n\n- **hcellsTemporalConstant**: `float`.\n\n  the time constant of the first order low pass filter of the\n  horizontal cells, use it to cut low temporal frequencies (local luminance variations), unit is\n  frames, typical value is 1 frame, as the photoreceptors\n\n- **hcellsSpatialConstant**: `float`.\n\n  the spatial constant of the first order low pass filter of the\n  horizontal cells, use it to cut low spatial frequencies (local luminance), unit is pixels,\n  typical value is 5 pixel, this value is also used for local contrast computing when computing\n  the local contrast adaptation at the ganglion cells level (Inner Plexiform Layer parvocellular\n  channel model)\n\n- **ganglionCellsSensitivity**: `float`.\n\n  the compression strengh of the ganglion cells local adaptation\n  output, set a value between 0.6 and 1 for best results, a high value increases more the low\n  value sensitivity... and the output saturates faster, recommended value: 0.7\n\nOPL is referred as Outer Plexiform Layer of the retina, it allows the spatio-temporal filtering\nwhich withens the spectrum and reduces spatio-temporal noise while attenuating global luminance\n(low frequency energy) IPL parvo is the OPL next processing stage, it refers to a part of the\nInner Plexiform layer of the retina, it allows high contours sensitivity in foveal vision. See\nreference papers for more informations.\nfor more informations, please have a look at the paper Benoit A., Caplier A., Durette B., Herault, J., \"USING HUMAN VISUAL SYSTEM MODELING FOR BIO-INSPIRED LOW LEVEL IMAGE PROCESSING\", Elsevier, Computer Vision and Image Understanding 114 (2010), pp. 758-773, DOI: http://dx.doi.org/10.1016/j.cviu.2010.01.011\n\nPython prototype (for reference only):\n```python3\nsetupOPLandIPLParvoChannel([, colorMode[, normaliseOutput[, photoreceptorsLocalAdaptationSensitivity[, photoreceptorsTemporalConstant[, photoreceptorsSpatialConstant[, horizontalCellsGain[, HcellsTemporalConstant[, HcellsSpatialConstant[, ganglionCellsSensitivity]]]]]]]]]) -> None\n```","ref":"Evision.Bioinspired.Retina.html#setupOPLandIPLParvoChannel/2"},{"type":"function","title":"Evision.Bioinspired.Retina.write/1","doc":"","ref":"Evision.Bioinspired.Retina.html#write/1"},{"type":"function","title":"Evision.Bioinspired.Retina.write/2","doc":"Write xml/yml formated parameters information\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.Retina.t()`\n- **fs**: `String`.\n\n  the filename of the xml file that will be open and writen with formatted parameters\n  information\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Bioinspired.Retina.html#write/2"},{"type":"type","title":"Evision.Bioinspired.Retina.t/0","doc":"Type that represents an `Bioinspired.Retina` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Bioinspired.Retina.html#t:t/0"},{"type":"module","title":"Evision.Bioinspired.RetinaFastToneMapping","doc":"","ref":"Evision.Bioinspired.RetinaFastToneMapping.html"},{"type":"function","title":"Evision.Bioinspired.RetinaFastToneMapping.applyFastToneMapping/1","doc":"","ref":"Evision.Bioinspired.RetinaFastToneMapping.html#applyFastToneMapping/1"},{"type":"function","title":"Evision.Bioinspired.RetinaFastToneMapping.applyFastToneMapping/2","doc":"applies a luminance correction (initially High Dynamic Range (HDR) tone mapping)\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.RetinaFastToneMapping.t()`\n- **inputImage**: `Evision.Mat`.\n\n  the input image to process RGB or gray levels\n\n##### Return\n- **outputToneMappedImage**: `Evision.Mat.t()`.\n\n  the output tone mapped image\n\nusing only the 2 local adaptation stages of the retina parvocellular channel : photoreceptors\nlevel and ganlion cells level. Spatio temporal filtering is applied but limited to temporal\nsmoothing and eventually high frequencies attenuation. This is a lighter method than the one\navailable using the regular retina::run method. It is then faster but it does not include\ncomplete temporal filtering nor retina spectral whitening. Then, it can have a more limited\neffect on images with a very high dynamic range. This is an adptation of the original still\nimage HDR tone mapping algorithm of David Alleyson, Sabine Susstruck and Laurence Meylan's\nwork, please cite: -> Meylan L., Alleysson D., and Susstrunk S., A Model of Retinal Local\nAdaptation for the Tone Mapping of Color Filter Array Images, Journal of Optical Society of\nAmerica, A, Vol. 24, N 9, September, 1st, 2007, pp. 2807-2816\n\nPython prototype (for reference only):\n```python3\napplyFastToneMapping(inputImage[, outputToneMappedImage]) -> outputToneMappedImage\n```","ref":"Evision.Bioinspired.RetinaFastToneMapping.html#applyFastToneMapping/2"},{"type":"function","title":"Evision.Bioinspired.RetinaFastToneMapping.applyFastToneMapping/3","doc":"applies a luminance correction (initially High Dynamic Range (HDR) tone mapping)\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.RetinaFastToneMapping.t()`\n- **inputImage**: `Evision.Mat`.\n\n  the input image to process RGB or gray levels\n\n##### Return\n- **outputToneMappedImage**: `Evision.Mat.t()`.\n\n  the output tone mapped image\n\nusing only the 2 local adaptation stages of the retina parvocellular channel : photoreceptors\nlevel and ganlion cells level. Spatio temporal filtering is applied but limited to temporal\nsmoothing and eventually high frequencies attenuation. This is a lighter method than the one\navailable using the regular retina::run method. It is then faster but it does not include\ncomplete temporal filtering nor retina spectral whitening. Then, it can have a more limited\neffect on images with a very high dynamic range. This is an adptation of the original still\nimage HDR tone mapping algorithm of David Alleyson, Sabine Susstruck and Laurence Meylan's\nwork, please cite: -> Meylan L., Alleysson D., and Susstrunk S., A Model of Retinal Local\nAdaptation for the Tone Mapping of Color Filter Array Images, Journal of Optical Society of\nAmerica, A, Vol. 24, N 9, September, 1st, 2007, pp. 2807-2816\n\nPython prototype (for reference only):\n```python3\napplyFastToneMapping(inputImage[, outputToneMappedImage]) -> outputToneMappedImage\n```","ref":"Evision.Bioinspired.RetinaFastToneMapping.html#applyFastToneMapping/3"},{"type":"function","title":"Evision.Bioinspired.RetinaFastToneMapping.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.RetinaFastToneMapping.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Bioinspired.RetinaFastToneMapping.html#clear/1"},{"type":"function","title":"Evision.Bioinspired.RetinaFastToneMapping.create/1","doc":"create\n\n##### Positional Arguments\n- **inputSize**: `Size`\n\n##### Return\n- **retval**: `RetinaFastToneMapping`\n\nPython prototype (for reference only):\n```python3\ncreate(inputSize) -> retval\n```","ref":"Evision.Bioinspired.RetinaFastToneMapping.html#create/1"},{"type":"function","title":"Evision.Bioinspired.RetinaFastToneMapping.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.RetinaFastToneMapping.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Bioinspired.RetinaFastToneMapping.html#empty/1"},{"type":"function","title":"Evision.Bioinspired.RetinaFastToneMapping.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.RetinaFastToneMapping.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Bioinspired.RetinaFastToneMapping.html#getDefaultName/1"},{"type":"function","title":"Evision.Bioinspired.RetinaFastToneMapping.read/1","doc":"","ref":"Evision.Bioinspired.RetinaFastToneMapping.html#read/1"},{"type":"function","title":"Evision.Bioinspired.RetinaFastToneMapping.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.RetinaFastToneMapping.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Bioinspired.RetinaFastToneMapping.html#read/2"},{"type":"function","title":"Evision.Bioinspired.RetinaFastToneMapping.save/1","doc":"","ref":"Evision.Bioinspired.RetinaFastToneMapping.html#save/1"},{"type":"function","title":"Evision.Bioinspired.RetinaFastToneMapping.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.RetinaFastToneMapping.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Bioinspired.RetinaFastToneMapping.html#save/2"},{"type":"function","title":"Evision.Bioinspired.RetinaFastToneMapping.setup/1","doc":"updates tone mapping behaviors by adjusing the local luminance computation area\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.RetinaFastToneMapping.t()`\n\n##### Keyword Arguments\n- **photoreceptorsNeighborhoodRadius**: `float`.\n\n  the first stage local adaptation area\n\n- **ganglioncellsNeighborhoodRadius**: `float`.\n\n  the second stage local adaptation area\n\n- **meanLuminanceModulatorK**: `float`.\n\n  the factor applied to modulate the meanLuminance information\n  (default is 1, see reference paper)\n\nPython prototype (for reference only):\n```python3\nsetup([, photoreceptorsNeighborhoodRadius[, ganglioncellsNeighborhoodRadius[, meanLuminanceModulatorK]]]) -> None\n```","ref":"Evision.Bioinspired.RetinaFastToneMapping.html#setup/1"},{"type":"function","title":"Evision.Bioinspired.RetinaFastToneMapping.setup/2","doc":"updates tone mapping behaviors by adjusing the local luminance computation area\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.RetinaFastToneMapping.t()`\n\n##### Keyword Arguments\n- **photoreceptorsNeighborhoodRadius**: `float`.\n\n  the first stage local adaptation area\n\n- **ganglioncellsNeighborhoodRadius**: `float`.\n\n  the second stage local adaptation area\n\n- **meanLuminanceModulatorK**: `float`.\n\n  the factor applied to modulate the meanLuminance information\n  (default is 1, see reference paper)\n\nPython prototype (for reference only):\n```python3\nsetup([, photoreceptorsNeighborhoodRadius[, ganglioncellsNeighborhoodRadius[, meanLuminanceModulatorK]]]) -> None\n```","ref":"Evision.Bioinspired.RetinaFastToneMapping.html#setup/2"},{"type":"function","title":"Evision.Bioinspired.RetinaFastToneMapping.write/1","doc":"","ref":"Evision.Bioinspired.RetinaFastToneMapping.html#write/1"},{"type":"function","title":"Evision.Bioinspired.RetinaFastToneMapping.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.RetinaFastToneMapping.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Bioinspired.RetinaFastToneMapping.html#write/2"},{"type":"function","title":"Evision.Bioinspired.RetinaFastToneMapping.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.RetinaFastToneMapping.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Bioinspired.RetinaFastToneMapping.html#write/3"},{"type":"type","title":"Evision.Bioinspired.RetinaFastToneMapping.t/0","doc":"Type that represents an `Bioinspired.RetinaFastToneMapping` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Bioinspired.RetinaFastToneMapping.html#t:t/0"},{"type":"module","title":"Evision.Bioinspired.TransientAreasSegmentationModule","doc":"","ref":"Evision.Bioinspired.TransientAreasSegmentationModule.html"},{"type":"function","title":"Evision.Bioinspired.TransientAreasSegmentationModule.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.TransientAreasSegmentationModule.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Bioinspired.TransientAreasSegmentationModule.html#clear/1"},{"type":"function","title":"Evision.Bioinspired.TransientAreasSegmentationModule.clearAllBuffers/1","doc":"cleans all the buffers of the instance\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.TransientAreasSegmentationModule.t()`\n\nPython prototype (for reference only):\n```python3\nclearAllBuffers() -> None\n```","ref":"Evision.Bioinspired.TransientAreasSegmentationModule.html#clearAllBuffers/1"},{"type":"function","title":"Evision.Bioinspired.TransientAreasSegmentationModule.create/1","doc":"allocator\n\n##### Positional Arguments\n- **inputSize**: `Size`.\n\n  : size of the images input to segment (output will be the same size)\n\n##### Return\n- **retval**: `TransientAreasSegmentationModule`\n\nPython prototype (for reference only):\n```python3\ncreate(inputSize) -> retval\n```","ref":"Evision.Bioinspired.TransientAreasSegmentationModule.html#create/1"},{"type":"function","title":"Evision.Bioinspired.TransientAreasSegmentationModule.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.TransientAreasSegmentationModule.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Bioinspired.TransientAreasSegmentationModule.html#empty/1"},{"type":"function","title":"Evision.Bioinspired.TransientAreasSegmentationModule.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.TransientAreasSegmentationModule.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Bioinspired.TransientAreasSegmentationModule.html#getDefaultName/1"},{"type":"function","title":"Evision.Bioinspired.TransientAreasSegmentationModule.getSegmentationPicture/1","doc":"access function\nreturn the last segmentation result: a boolean picture which is resampled between 0 and 255 for a display purpose\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.TransientAreasSegmentationModule.t()`\n\n##### Return\n- **transientAreas**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetSegmentationPicture([, transientAreas]) -> transientAreas\n```","ref":"Evision.Bioinspired.TransientAreasSegmentationModule.html#getSegmentationPicture/1"},{"type":"function","title":"Evision.Bioinspired.TransientAreasSegmentationModule.getSegmentationPicture/2","doc":"access function\nreturn the last segmentation result: a boolean picture which is resampled between 0 and 255 for a display purpose\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.TransientAreasSegmentationModule.t()`\n\n##### Return\n- **transientAreas**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetSegmentationPicture([, transientAreas]) -> transientAreas\n```","ref":"Evision.Bioinspired.TransientAreasSegmentationModule.html#getSegmentationPicture/2"},{"type":"function","title":"Evision.Bioinspired.TransientAreasSegmentationModule.getSize/1","doc":"return the sze of the manage input and output images\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.TransientAreasSegmentationModule.t()`\n\n##### Return\n- **retval**: `Size`\n\nPython prototype (for reference only):\n```python3\ngetSize() -> retval\n```","ref":"Evision.Bioinspired.TransientAreasSegmentationModule.html#getSize/1"},{"type":"function","title":"Evision.Bioinspired.TransientAreasSegmentationModule.printSetup/1","doc":"parameters setup display method\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.TransientAreasSegmentationModule.t()`\n\n##### Return\n- **retval**: `String`\n\n@return a string which contains formatted parameters information\n\nPython prototype (for reference only):\n```python3\nprintSetup() -> retval\n```","ref":"Evision.Bioinspired.TransientAreasSegmentationModule.html#printSetup/1"},{"type":"function","title":"Evision.Bioinspired.TransientAreasSegmentationModule.read/1","doc":"","ref":"Evision.Bioinspired.TransientAreasSegmentationModule.html#read/1"},{"type":"function","title":"Evision.Bioinspired.TransientAreasSegmentationModule.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.TransientAreasSegmentationModule.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Bioinspired.TransientAreasSegmentationModule.html#read/2"},{"type":"function","title":"Evision.Bioinspired.TransientAreasSegmentationModule.run/1","doc":"","ref":"Evision.Bioinspired.TransientAreasSegmentationModule.html#run/1"},{"type":"function","title":"Evision.Bioinspired.TransientAreasSegmentationModule.run/2","doc":"main processing method, get result using methods getSegmentationPicture()\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.TransientAreasSegmentationModule.t()`\n- **inputToSegment**: `Evision.Mat`.\n\n  : the image to process, it must match the instance buffer size !\n\n##### Keyword Arguments\n- **channelIndex**: `integer()`.\n\n  : the channel to process in case of multichannel images\n\nPython prototype (for reference only):\n```python3\nrun(inputToSegment[, channelIndex]) -> None\n```","ref":"Evision.Bioinspired.TransientAreasSegmentationModule.html#run/2"},{"type":"function","title":"Evision.Bioinspired.TransientAreasSegmentationModule.run/3","doc":"main processing method, get result using methods getSegmentationPicture()\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.TransientAreasSegmentationModule.t()`\n- **inputToSegment**: `Evision.Mat`.\n\n  : the image to process, it must match the instance buffer size !\n\n##### Keyword Arguments\n- **channelIndex**: `integer()`.\n\n  : the channel to process in case of multichannel images\n\nPython prototype (for reference only):\n```python3\nrun(inputToSegment[, channelIndex]) -> None\n```","ref":"Evision.Bioinspired.TransientAreasSegmentationModule.html#run/3"},{"type":"function","title":"Evision.Bioinspired.TransientAreasSegmentationModule.save/1","doc":"","ref":"Evision.Bioinspired.TransientAreasSegmentationModule.html#save/1"},{"type":"function","title":"Evision.Bioinspired.TransientAreasSegmentationModule.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.TransientAreasSegmentationModule.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Bioinspired.TransientAreasSegmentationModule.html#save/2"},{"type":"function","title":"Evision.Bioinspired.TransientAreasSegmentationModule.setup/1","doc":"try to open an XML segmentation parameters file to adjust current segmentation instance setup\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.TransientAreasSegmentationModule.t()`\n\n##### Keyword Arguments\n- **segmentationParameterFile**: `String`.\n\n  : the parameters filename\n\n- **applyDefaultSetupOnFailure**: `bool`.\n\n  : set to true if an error must be thrown on error\n\n- if the xml file does not exist, then default setup is applied\n- warning, Exceptions are thrown if read XML file is not valid\n\nPython prototype (for reference only):\n```python3\nsetup([, segmentationParameterFile[, applyDefaultSetupOnFailure]]) -> None\n```","ref":"Evision.Bioinspired.TransientAreasSegmentationModule.html#setup/1"},{"type":"function","title":"Evision.Bioinspired.TransientAreasSegmentationModule.setup/2","doc":"try to open an XML segmentation parameters file to adjust current segmentation instance setup\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.TransientAreasSegmentationModule.t()`\n\n##### Keyword Arguments\n- **segmentationParameterFile**: `String`.\n\n  : the parameters filename\n\n- **applyDefaultSetupOnFailure**: `bool`.\n\n  : set to true if an error must be thrown on error\n\n- if the xml file does not exist, then default setup is applied\n- warning, Exceptions are thrown if read XML file is not valid\n\nPython prototype (for reference only):\n```python3\nsetup([, segmentationParameterFile[, applyDefaultSetupOnFailure]]) -> None\n```","ref":"Evision.Bioinspired.TransientAreasSegmentationModule.html#setup/2"},{"type":"function","title":"Evision.Bioinspired.TransientAreasSegmentationModule.write/1","doc":"","ref":"Evision.Bioinspired.TransientAreasSegmentationModule.html#write/1"},{"type":"function","title":"Evision.Bioinspired.TransientAreasSegmentationModule.write/2","doc":"write xml/yml formated parameters information\n\n##### Positional Arguments\n- **self**: `Evision.Bioinspired.TransientAreasSegmentationModule.t()`\n- **fs**: `String`.\n\n  : the filename of the xml file that will be open and writen with formatted parameters information\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Bioinspired.TransientAreasSegmentationModule.html#write/2"},{"type":"type","title":"Evision.Bioinspired.TransientAreasSegmentationModule.t/0","doc":"Type that represents an `Bioinspired.TransientAreasSegmentationModule` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Bioinspired.TransientAreasSegmentationModule.html#t:t/0"},{"type":"module","title":"Evision.BorderTypes","doc":"","ref":"Evision.BorderTypes.html"},{"type":"function","title":"Evision.BorderTypes.cv_BORDER_CONSTANT/0","doc":"","ref":"Evision.BorderTypes.html#cv_BORDER_CONSTANT/0"},{"type":"function","title":"Evision.BorderTypes.cv_BORDER_DEFAULT/0","doc":"","ref":"Evision.BorderTypes.html#cv_BORDER_DEFAULT/0"},{"type":"function","title":"Evision.BorderTypes.cv_BORDER_ISOLATED/0","doc":"","ref":"Evision.BorderTypes.html#cv_BORDER_ISOLATED/0"},{"type":"function","title":"Evision.BorderTypes.cv_BORDER_REFLECT101/0","doc":"","ref":"Evision.BorderTypes.html#cv_BORDER_REFLECT101/0"},{"type":"function","title":"Evision.BorderTypes.cv_BORDER_REFLECT/0","doc":"","ref":"Evision.BorderTypes.html#cv_BORDER_REFLECT/0"},{"type":"function","title":"Evision.BorderTypes.cv_BORDER_REFLECT_101/0","doc":"","ref":"Evision.BorderTypes.html#cv_BORDER_REFLECT_101/0"},{"type":"function","title":"Evision.BorderTypes.cv_BORDER_REPLICATE/0","doc":"","ref":"Evision.BorderTypes.html#cv_BORDER_REPLICATE/0"},{"type":"function","title":"Evision.BorderTypes.cv_BORDER_TRANSPARENT/0","doc":"","ref":"Evision.BorderTypes.html#cv_BORDER_TRANSPARENT/0"},{"type":"function","title":"Evision.BorderTypes.cv_BORDER_WRAP/0","doc":"","ref":"Evision.BorderTypes.html#cv_BORDER_WRAP/0"},{"type":"type","title":"Evision.BorderTypes.enum/0","doc":"","ref":"Evision.BorderTypes.html#t:enum/0"},{"type":"module","title":"Evision.CCM","doc":"","ref":"Evision.CCM.html"},{"type":"type","title":"Evision.CCM.t/0","doc":"Type that represents an `CCM` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CCM.html#t:t/0"},{"type":"module","title":"Evision.CCM.CCM_TYPE","doc":"","ref":"Evision.CCM.CCM_TYPE.html"},{"type":"function","title":"Evision.CCM.CCM_TYPE.cv_CCM_3x3/0","doc":"","ref":"Evision.CCM.CCM_TYPE.html#cv_CCM_3x3/0"},{"type":"function","title":"Evision.CCM.CCM_TYPE.cv_CCM_4x3/0","doc":"","ref":"Evision.CCM.CCM_TYPE.html#cv_CCM_4x3/0"},{"type":"type","title":"Evision.CCM.CCM_TYPE.enum/0","doc":"","ref":"Evision.CCM.CCM_TYPE.html#t:enum/0"},{"type":"module","title":"Evision.CCM.COLOR_SPACE","doc":"","ref":"Evision.CCM.COLOR_SPACE.html"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_AdobeRGB/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_AdobeRGB/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_AdobeRGBL/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_AdobeRGBL/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_AppleRGB/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_AppleRGB/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_AppleRGBL/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_AppleRGBL/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_DCI_P3_RGB/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_DCI_P3_RGB/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_DCI_P3_RGBL/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_DCI_P3_RGBL/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_Lab_A_2/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_Lab_A_2/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_Lab_A_10/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_Lab_A_10/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_Lab_D50_2/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_Lab_D50_2/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_Lab_D50_10/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_Lab_D50_10/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_Lab_D55_2/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_Lab_D55_2/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_Lab_D55_10/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_Lab_D55_10/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_Lab_D65_2/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_Lab_D65_2/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_Lab_D65_10/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_Lab_D65_10/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_Lab_D75_2/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_Lab_D75_2/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_Lab_D75_10/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_Lab_D75_10/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_Lab_E_2/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_Lab_E_2/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_Lab_E_10/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_Lab_E_10/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_ProPhotoRGB/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_ProPhotoRGB/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_ProPhotoRGBL/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_ProPhotoRGBL/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_REC_709_RGB/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_REC_709_RGB/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_REC_709_RGBL/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_REC_709_RGBL/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_REC_2020_RGB/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_REC_2020_RGB/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_REC_2020_RGBL/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_REC_2020_RGBL/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_sRGB/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_sRGB/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_sRGBL/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_sRGBL/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_WideGamutRGB/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_WideGamutRGB/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_WideGamutRGBL/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_WideGamutRGBL/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_XYZ_A_2/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_XYZ_A_2/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_XYZ_A_10/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_XYZ_A_10/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_XYZ_D50_2/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_XYZ_D50_2/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_XYZ_D50_10/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_XYZ_D50_10/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_XYZ_D55_2/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_XYZ_D55_2/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_XYZ_D55_10/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_XYZ_D55_10/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_XYZ_D65_2/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_XYZ_D65_2/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_XYZ_D65_10/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_XYZ_D65_10/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_XYZ_D75_2/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_XYZ_D75_2/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_XYZ_D75_10/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_XYZ_D75_10/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_XYZ_E_2/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_XYZ_E_2/0"},{"type":"function","title":"Evision.CCM.COLOR_SPACE.cv_COLOR_SPACE_XYZ_E_10/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#cv_COLOR_SPACE_XYZ_E_10/0"},{"type":"type","title":"Evision.CCM.COLOR_SPACE.enum/0","doc":"","ref":"Evision.CCM.COLOR_SPACE.html#t:enum/0"},{"type":"module","title":"Evision.CCM.CONST_COLOR","doc":"","ref":"Evision.CCM.CONST_COLOR.html"},{"type":"function","title":"Evision.CCM.CONST_COLOR.cv_COLORCHECKER_DigitalSG/0","doc":"","ref":"Evision.CCM.CONST_COLOR.html#cv_COLORCHECKER_DigitalSG/0"},{"type":"function","title":"Evision.CCM.CONST_COLOR.cv_COLORCHECKER_Macbeth/0","doc":"","ref":"Evision.CCM.CONST_COLOR.html#cv_COLORCHECKER_Macbeth/0"},{"type":"function","title":"Evision.CCM.CONST_COLOR.cv_COLORCHECKER_Vinyl/0","doc":"","ref":"Evision.CCM.CONST_COLOR.html#cv_COLORCHECKER_Vinyl/0"},{"type":"type","title":"Evision.CCM.CONST_COLOR.enum/0","doc":"","ref":"Evision.CCM.CONST_COLOR.html#t:enum/0"},{"type":"module","title":"Evision.CCM.ColorCorrectionModel","doc":"","ref":"Evision.CCM.ColorCorrectionModel.html"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.colorCorrectionModel/1","doc":"","ref":"Evision.CCM.ColorCorrectionModel.html#colorCorrectionModel/1"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.colorCorrectionModel/2","doc":"Color Correction Model\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  detected colors of ColorChecker patches;\\n\n  the color type is RGB not BGR, and the color values are in [0, 1];\n\n- **constcolor**: `CONST_COLOR`.\n\n  the Built-in color card\n\n##### Return\n- **self**: `ColorCorrectionModel`\n\nSupported list of color cards:\n- @ref COLORCHECKER_Macbeth, the Macbeth ColorChecker\n- @ref COLORCHECKER_Vinyl, the DKK ColorChecker\n- @ref COLORCHECKER_DigitalSG, the DigitalSG ColorChecker with 140 squares\n\nPython prototype (for reference only):\n```python3\nColorCorrectionModel(src, constcolor) ->  \n```","ref":"Evision.CCM.ColorCorrectionModel.html#colorCorrectionModel/2"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.colorCorrectionModel/3","doc":"Color Correction Model\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  detected colors of ColorChecker patches;\\n\n  the color type is RGB not BGR, and the color values are in [0, 1];\n\n- **colors**: `Evision.Mat`.\n\n  the reference color values, the color values are in [0, 1].\\n\n\n- **ref_cs**: `COLOR_SPACE`.\n\n  the corresponding color space\n  If the color type is some RGB, the format is RGB not BGR;\\n\n\n##### Return\n- **self**: `ColorCorrectionModel`\n\nPython prototype (for reference only):\n```python3\nColorCorrectionModel(src, colors, ref_cs) ->  \n```","ref":"Evision.CCM.ColorCorrectionModel.html#colorCorrectionModel/3"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.colorCorrectionModel/4","doc":"Color Correction Model\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  detected colors of ColorChecker patches;\\n\n  the color type is RGB not BGR, and the color values are in [0, 1];\n\n- **colors**: `Evision.Mat`.\n\n  the reference color values, the color values are in [0, 1].\n\n- **ref_cs**: `COLOR_SPACE`.\n\n  the corresponding color space\n  If the color type is some RGB, the format is RGB not BGR;\n\n- **colored**: `Evision.Mat`.\n\n  mask of colored color\n\n##### Return\n- **self**: `ColorCorrectionModel`\n\nPython prototype (for reference only):\n```python3\nColorCorrectionModel(src, colors, ref_cs, colored) ->  \n```","ref":"Evision.CCM.ColorCorrectionModel.html#colorCorrectionModel/4"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.get_dst_rgbl/1","doc":"get_dst_rgbl\n\n##### Positional Arguments\n- **self**: `Evision.CCM.ColorCorrectionModel.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nget_dst_rgbl() -> retval\n```","ref":"Evision.CCM.ColorCorrectionModel.html#get_dst_rgbl/1"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.get_src_rgbl/1","doc":"get_src_rgbl\n\n##### Positional Arguments\n- **self**: `Evision.CCM.ColorCorrectionModel.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nget_src_rgbl() -> retval\n```","ref":"Evision.CCM.ColorCorrectionModel.html#get_src_rgbl/1"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.getCCM/1","doc":"getCCM\n\n##### Positional Arguments\n- **self**: `Evision.CCM.ColorCorrectionModel.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetCCM() -> retval\n```","ref":"Evision.CCM.ColorCorrectionModel.html#getCCM/1"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.getLoss/1","doc":"getLoss\n\n##### Positional Arguments\n- **self**: `Evision.CCM.ColorCorrectionModel.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetLoss() -> retval\n```","ref":"Evision.CCM.ColorCorrectionModel.html#getLoss/1"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.getMask/1","doc":"getMask\n\n##### Positional Arguments\n- **self**: `Evision.CCM.ColorCorrectionModel.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetMask() -> retval\n```","ref":"Evision.CCM.ColorCorrectionModel.html#getMask/1"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.getWeights/1","doc":"getWeights\n\n##### Positional Arguments\n- **self**: `Evision.CCM.ColorCorrectionModel.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetWeights() -> retval\n```","ref":"Evision.CCM.ColorCorrectionModel.html#getWeights/1"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.infer/1","doc":"","ref":"Evision.CCM.ColorCorrectionModel.html#infer/1"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.infer/2","doc":"Infer using fitting ccm.\n\n##### Positional Arguments\n- **self**: `Evision.CCM.ColorCorrectionModel.t()`\n- **img**: `Evision.Mat`.\n\n  the input image.\n\n##### Keyword Arguments\n- **islinear**: `bool`.\n\n  default false.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n@return the output array.\n\nPython prototype (for reference only):\n```python3\ninfer(img[, islinear]) -> retval\n```","ref":"Evision.CCM.ColorCorrectionModel.html#infer/2"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.infer/3","doc":"Infer using fitting ccm.\n\n##### Positional Arguments\n- **self**: `Evision.CCM.ColorCorrectionModel.t()`\n- **img**: `Evision.Mat`.\n\n  the input image.\n\n##### Keyword Arguments\n- **islinear**: `bool`.\n\n  default false.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n@return the output array.\n\nPython prototype (for reference only):\n```python3\ninfer(img[, islinear]) -> retval\n```","ref":"Evision.CCM.ColorCorrectionModel.html#infer/3"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.run/1","doc":"make color correction\n\n##### Positional Arguments\n- **self**: `Evision.CCM.ColorCorrectionModel.t()`\n\nPython prototype (for reference only):\n```python3\nrun() -> None\n```","ref":"Evision.CCM.ColorCorrectionModel.html#run/1"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setCCM_TYPE/1","doc":"","ref":"Evision.CCM.ColorCorrectionModel.html#setCCM_TYPE/1"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setCCM_TYPE/2","doc":"set ccm_type\n\n##### Positional Arguments\n- **self**: `Evision.CCM.ColorCorrectionModel.t()`\n- **ccm_type**: `CCM_TYPE`.\n\n  the shape of color correction matrix(CCM);\\n\n  default: @ref CCM_3x3\n\nPython prototype (for reference only):\n```python3\nsetCCM_TYPE(ccm_type) -> None\n```","ref":"Evision.CCM.ColorCorrectionModel.html#setCCM_TYPE/2"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setColorSpace/1","doc":"","ref":"Evision.CCM.ColorCorrectionModel.html#setColorSpace/1"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setColorSpace/2","doc":"set ColorSpace\n\n##### Positional Arguments\n- **self**: `Evision.CCM.ColorCorrectionModel.t()`\n- **cs**: `COLOR_SPACE`.\n\n  the absolute color space that detected colors convert to;\\n\n  default: @ref COLOR_SPACE_sRGB\n\n**Note**: It should be some RGB color space;\nSupported list of color cards:\n- @ref COLOR_SPACE_sRGB\n- @ref COLOR_SPACE_AdobeRGB\n- @ref COLOR_SPACE_WideGamutRGB\n- @ref COLOR_SPACE_ProPhotoRGB\n- @ref COLOR_SPACE_DCI_P3_RGB\n- @ref COLOR_SPACE_AppleRGB\n- @ref COLOR_SPACE_REC_709_RGB\n- @ref COLOR_SPACE_REC_2020_RGB\n\nPython prototype (for reference only):\n```python3\nsetColorSpace(cs) -> None\n```","ref":"Evision.CCM.ColorCorrectionModel.html#setColorSpace/2"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setDistance/1","doc":"","ref":"Evision.CCM.ColorCorrectionModel.html#setDistance/1"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setDistance/2","doc":"set Distance\n\n##### Positional Arguments\n- **self**: `Evision.CCM.ColorCorrectionModel.t()`\n- **distance**: `DISTANCE_TYPE`.\n\n  the type of color distance;\\n\n  default: @ref DISTANCE_CIE2000\n\nPython prototype (for reference only):\n```python3\nsetDistance(distance) -> None\n```","ref":"Evision.CCM.ColorCorrectionModel.html#setDistance/2"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setEpsilon/1","doc":"","ref":"Evision.CCM.ColorCorrectionModel.html#setEpsilon/1"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setEpsilon/2","doc":"set Epsilon\n\n##### Positional Arguments\n- **self**: `Evision.CCM.ColorCorrectionModel.t()`\n- **epsilon**: `double`.\n\n  used in MinProblemSolver-DownhillSolver;\\n\n  Terminal criteria to the algorithm;\\n\n  default: 1e-4;\n\nPython prototype (for reference only):\n```python3\nsetEpsilon(epsilon) -> None\n```","ref":"Evision.CCM.ColorCorrectionModel.html#setEpsilon/2"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setInitialMethod/1","doc":"","ref":"Evision.CCM.ColorCorrectionModel.html#setInitialMethod/1"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setInitialMethod/2","doc":"set InitialMethod\n\n##### Positional Arguments\n- **self**: `Evision.CCM.ColorCorrectionModel.t()`\n- **initial_method_type**: `INITIAL_METHOD_TYPE`.\n\n  the method of calculating CCM initial value;\\n\n  default: INITIAL_METHOD_LEAST_SQUARE\n\nPython prototype (for reference only):\n```python3\nsetInitialMethod(initial_method_type) -> None\n```","ref":"Evision.CCM.ColorCorrectionModel.html#setInitialMethod/2"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setLinear/1","doc":"","ref":"Evision.CCM.ColorCorrectionModel.html#setLinear/1"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setLinear/2","doc":"set Linear\n\n##### Positional Arguments\n- **self**: `Evision.CCM.ColorCorrectionModel.t()`\n- **linear_type**: `LINEAR_TYPE`.\n\n  the method of linearization;\\n\n  default: @ref LINEARIZATION_GAMMA\n\nPython prototype (for reference only):\n```python3\nsetLinear(linear_type) -> None\n```","ref":"Evision.CCM.ColorCorrectionModel.html#setLinear/2"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setLinearDegree/1","doc":"","ref":"Evision.CCM.ColorCorrectionModel.html#setLinearDegree/1"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setLinearDegree/2","doc":"set degree\n\n##### Positional Arguments\n- **self**: `Evision.CCM.ColorCorrectionModel.t()`\n- **deg**: `integer()`.\n\n  the degree of linearization polynomial;\\n\n  default: 3\n\n**Note**: only valid when linear is set to\n- @ref LINEARIZATION_COLORPOLYFIT\n- @ref LINEARIZATION_GRAYPOLYFIT\n- @ref LINEARIZATION_COLORLOGPOLYFIT\n- @ref LINEARIZATION_GRAYLOGPOLYFIT\n\nPython prototype (for reference only):\n```python3\nsetLinearDegree(deg) -> None\n```","ref":"Evision.CCM.ColorCorrectionModel.html#setLinearDegree/2"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setLinearGamma/1","doc":"","ref":"Evision.CCM.ColorCorrectionModel.html#setLinearGamma/1"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setLinearGamma/2","doc":"set Gamma\n\n##### Positional Arguments\n- **self**: `Evision.CCM.ColorCorrectionModel.t()`\n- **gamma**: `double`.\n\n  the gamma value of gamma correction;\\n\n  default: 2.2;\n\n**Note**: only valid when linear is set to \"gamma\";\\n\n\nPython prototype (for reference only):\n```python3\nsetLinearGamma(gamma) -> None\n```","ref":"Evision.CCM.ColorCorrectionModel.html#setLinearGamma/2"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setMaxCount/1","doc":"","ref":"Evision.CCM.ColorCorrectionModel.html#setMaxCount/1"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setMaxCount/2","doc":"set MaxCount\n\n##### Positional Arguments\n- **self**: `Evision.CCM.ColorCorrectionModel.t()`\n- **max_count**: `integer()`.\n\n  used in MinProblemSolver-DownhillSolver;\\n\n  Terminal criteria to the algorithm;\\n\n  default: 5000;\n\nPython prototype (for reference only):\n```python3\nsetMaxCount(max_count) -> None\n```","ref":"Evision.CCM.ColorCorrectionModel.html#setMaxCount/2"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setSaturatedThreshold/1","doc":"","ref":"Evision.CCM.ColorCorrectionModel.html#setSaturatedThreshold/1"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setSaturatedThreshold/3","doc":"set SaturatedThreshold.\nThe colors in the closed interval [lower, upper] are reserved to participate\nin the calculation of the loss function and initialization parameters\n\n##### Positional Arguments\n- **self**: `Evision.CCM.ColorCorrectionModel.t()`\n- **lower**: `double`.\n\n  the lower threshold to determine saturation;\\n\n  default: 0;\n\n- **upper**: `double`.\n\n  the upper threshold to determine saturation;\\n\n  default: 0\n\nPython prototype (for reference only):\n```python3\nsetSaturatedThreshold(lower, upper) -> None\n```","ref":"Evision.CCM.ColorCorrectionModel.html#setSaturatedThreshold/3"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setWeightCoeff/1","doc":"","ref":"Evision.CCM.ColorCorrectionModel.html#setWeightCoeff/1"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setWeightCoeff/2","doc":"set WeightCoeff\n\n##### Positional Arguments\n- **self**: `Evision.CCM.ColorCorrectionModel.t()`\n- **weights_coeff**: `double`.\n\n  the exponent number of L* component of the reference color in CIE Lab color space;\\n\n  default: 0\n\nPython prototype (for reference only):\n```python3\nsetWeightCoeff(weights_coeff) -> None\n```","ref":"Evision.CCM.ColorCorrectionModel.html#setWeightCoeff/2"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setWeightsList/1","doc":"","ref":"Evision.CCM.ColorCorrectionModel.html#setWeightsList/1"},{"type":"function","title":"Evision.CCM.ColorCorrectionModel.setWeightsList/2","doc":"set WeightsList\n\n##### Positional Arguments\n- **self**: `Evision.CCM.ColorCorrectionModel.t()`\n- **weights_list**: `Evision.Mat`.\n\n  the list of weight of each color;\\n\n  default: empty array\n\nPython prototype (for reference only):\n```python3\nsetWeightsList(weights_list) -> None\n```","ref":"Evision.CCM.ColorCorrectionModel.html#setWeightsList/2"},{"type":"type","title":"Evision.CCM.ColorCorrectionModel.t/0","doc":"Type that represents an `CCM.ColorCorrectionModel` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CCM.ColorCorrectionModel.html#t:t/0"},{"type":"module","title":"Evision.CCM.DISTANCE_TYPE","doc":"","ref":"Evision.CCM.DISTANCE_TYPE.html"},{"type":"function","title":"Evision.CCM.DISTANCE_TYPE.cv_DISTANCE_CIE76/0","doc":"","ref":"Evision.CCM.DISTANCE_TYPE.html#cv_DISTANCE_CIE76/0"},{"type":"function","title":"Evision.CCM.DISTANCE_TYPE.cv_DISTANCE_CIE94_GRAPHIC_ARTS/0","doc":"","ref":"Evision.CCM.DISTANCE_TYPE.html#cv_DISTANCE_CIE94_GRAPHIC_ARTS/0"},{"type":"function","title":"Evision.CCM.DISTANCE_TYPE.cv_DISTANCE_CIE94_TEXTILES/0","doc":"","ref":"Evision.CCM.DISTANCE_TYPE.html#cv_DISTANCE_CIE94_TEXTILES/0"},{"type":"function","title":"Evision.CCM.DISTANCE_TYPE.cv_DISTANCE_CIE2000/0","doc":"","ref":"Evision.CCM.DISTANCE_TYPE.html#cv_DISTANCE_CIE2000/0"},{"type":"function","title":"Evision.CCM.DISTANCE_TYPE.cv_DISTANCE_CMC_1TO1/0","doc":"","ref":"Evision.CCM.DISTANCE_TYPE.html#cv_DISTANCE_CMC_1TO1/0"},{"type":"function","title":"Evision.CCM.DISTANCE_TYPE.cv_DISTANCE_CMC_2TO1/0","doc":"","ref":"Evision.CCM.DISTANCE_TYPE.html#cv_DISTANCE_CMC_2TO1/0"},{"type":"function","title":"Evision.CCM.DISTANCE_TYPE.cv_DISTANCE_RGB/0","doc":"","ref":"Evision.CCM.DISTANCE_TYPE.html#cv_DISTANCE_RGB/0"},{"type":"function","title":"Evision.CCM.DISTANCE_TYPE.cv_DISTANCE_RGBL/0","doc":"","ref":"Evision.CCM.DISTANCE_TYPE.html#cv_DISTANCE_RGBL/0"},{"type":"type","title":"Evision.CCM.DISTANCE_TYPE.enum/0","doc":"","ref":"Evision.CCM.DISTANCE_TYPE.html#t:enum/0"},{"type":"module","title":"Evision.CCM.INITIAL_METHOD_TYPE","doc":"","ref":"Evision.CCM.INITIAL_METHOD_TYPE.html"},{"type":"function","title":"Evision.CCM.INITIAL_METHOD_TYPE.cv_INITIAL_METHOD_LEAST_SQUARE/0","doc":"","ref":"Evision.CCM.INITIAL_METHOD_TYPE.html#cv_INITIAL_METHOD_LEAST_SQUARE/0"},{"type":"function","title":"Evision.CCM.INITIAL_METHOD_TYPE.cv_INITIAL_METHOD_WHITE_BALANCE/0","doc":"","ref":"Evision.CCM.INITIAL_METHOD_TYPE.html#cv_INITIAL_METHOD_WHITE_BALANCE/0"},{"type":"type","title":"Evision.CCM.INITIAL_METHOD_TYPE.enum/0","doc":"","ref":"Evision.CCM.INITIAL_METHOD_TYPE.html#t:enum/0"},{"type":"module","title":"Evision.CCM.LINEAR_TYPE","doc":"","ref":"Evision.CCM.LINEAR_TYPE.html"},{"type":"function","title":"Evision.CCM.LINEAR_TYPE.cv_LINEARIZATION_COLORLOGPOLYFIT/0","doc":"","ref":"Evision.CCM.LINEAR_TYPE.html#cv_LINEARIZATION_COLORLOGPOLYFIT/0"},{"type":"function","title":"Evision.CCM.LINEAR_TYPE.cv_LINEARIZATION_COLORPOLYFIT/0","doc":"","ref":"Evision.CCM.LINEAR_TYPE.html#cv_LINEARIZATION_COLORPOLYFIT/0"},{"type":"function","title":"Evision.CCM.LINEAR_TYPE.cv_LINEARIZATION_GAMMA/0","doc":"","ref":"Evision.CCM.LINEAR_TYPE.html#cv_LINEARIZATION_GAMMA/0"},{"type":"function","title":"Evision.CCM.LINEAR_TYPE.cv_LINEARIZATION_GRAYLOGPOLYFIT/0","doc":"","ref":"Evision.CCM.LINEAR_TYPE.html#cv_LINEARIZATION_GRAYLOGPOLYFIT/0"},{"type":"function","title":"Evision.CCM.LINEAR_TYPE.cv_LINEARIZATION_GRAYPOLYFIT/0","doc":"","ref":"Evision.CCM.LINEAR_TYPE.html#cv_LINEARIZATION_GRAYPOLYFIT/0"},{"type":"function","title":"Evision.CCM.LINEAR_TYPE.cv_LINEARIZATION_IDENTITY/0","doc":"","ref":"Evision.CCM.LINEAR_TYPE.html#cv_LINEARIZATION_IDENTITY/0"},{"type":"type","title":"Evision.CCM.LINEAR_TYPE.enum/0","doc":"","ref":"Evision.CCM.LINEAR_TYPE.html#t:enum/0"},{"type":"module","title":"Evision.CLAHE","doc":"","ref":"Evision.CLAHE.html"},{"type":"function","title":"Evision.CLAHE.apply/1","doc":"","ref":"Evision.CLAHE.html#apply/1"},{"type":"function","title":"Evision.CLAHE.apply/2","doc":"Equalizes the histogram of a grayscale image using Contrast Limited Adaptive Histogram Equalization.\n\n##### Positional Arguments\n- **self**: `Evision.CLAHE.t()`\n- **src**: `Evision.Mat`.\n\n  Source image of type CV_8UC1 or CV_16UC1.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image.\n\nPython prototype (for reference only):\n```python3\napply(src[, dst]) -> dst\n```","ref":"Evision.CLAHE.html#apply/2"},{"type":"function","title":"Evision.CLAHE.apply/3","doc":"Equalizes the histogram of a grayscale image using Contrast Limited Adaptive Histogram Equalization.\n\n##### Positional Arguments\n- **self**: `Evision.CLAHE.t()`\n- **src**: `Evision.Mat`.\n\n  Source image of type CV_8UC1 or CV_16UC1.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image.\n\nPython prototype (for reference only):\n```python3\napply(src[, dst]) -> dst\n```","ref":"Evision.CLAHE.html#apply/3"},{"type":"function","title":"Evision.CLAHE.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.CLAHE.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.CLAHE.html#clear/1"},{"type":"function","title":"Evision.CLAHE.collectGarbage/1","doc":"collectGarbage\n\n##### Positional Arguments\n- **self**: `Evision.CLAHE.t()`\n\nPython prototype (for reference only):\n```python3\ncollectGarbage() -> None\n```","ref":"Evision.CLAHE.html#collectGarbage/1"},{"type":"function","title":"Evision.CLAHE.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.CLAHE.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CLAHE.html#empty/1"},{"type":"function","title":"Evision.CLAHE.getClipLimit/1","doc":"getClipLimit\n\n##### Positional Arguments\n- **self**: `Evision.CLAHE.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetClipLimit() -> retval\n```","ref":"Evision.CLAHE.html#getClipLimit/1"},{"type":"function","title":"Evision.CLAHE.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CLAHE.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CLAHE.html#getDefaultName/1"},{"type":"function","title":"Evision.CLAHE.getTilesGridSize/1","doc":"getTilesGridSize\n\n##### Positional Arguments\n- **self**: `Evision.CLAHE.t()`\n\n##### Return\n- **retval**: `Size`\n\nPython prototype (for reference only):\n```python3\ngetTilesGridSize() -> retval\n```","ref":"Evision.CLAHE.html#getTilesGridSize/1"},{"type":"function","title":"Evision.CLAHE.read/1","doc":"","ref":"Evision.CLAHE.html#read/1"},{"type":"function","title":"Evision.CLAHE.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CLAHE.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.CLAHE.html#read/2"},{"type":"function","title":"Evision.CLAHE.save/1","doc":"","ref":"Evision.CLAHE.html#save/1"},{"type":"function","title":"Evision.CLAHE.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.CLAHE.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.CLAHE.html#save/2"},{"type":"function","title":"Evision.CLAHE.setClipLimit/1","doc":"","ref":"Evision.CLAHE.html#setClipLimit/1"},{"type":"function","title":"Evision.CLAHE.setClipLimit/2","doc":"Sets threshold for contrast limiting.\n\n##### Positional Arguments\n- **self**: `Evision.CLAHE.t()`\n- **clipLimit**: `double`.\n\n  threshold value.\n\nPython prototype (for reference only):\n```python3\nsetClipLimit(clipLimit) -> None\n```","ref":"Evision.CLAHE.html#setClipLimit/2"},{"type":"function","title":"Evision.CLAHE.setTilesGridSize/1","doc":"","ref":"Evision.CLAHE.html#setTilesGridSize/1"},{"type":"function","title":"Evision.CLAHE.setTilesGridSize/2","doc":"Sets size of grid for histogram equalization. Input image will be divided into\nequally sized rectangular tiles.\n\n##### Positional Arguments\n- **self**: `Evision.CLAHE.t()`\n- **tileGridSize**: `Size`.\n\n  defines the number of tiles in row and column.\n\nPython prototype (for reference only):\n```python3\nsetTilesGridSize(tileGridSize) -> None\n```","ref":"Evision.CLAHE.html#setTilesGridSize/2"},{"type":"function","title":"Evision.CLAHE.write/1","doc":"","ref":"Evision.CLAHE.html#write/1"},{"type":"function","title":"Evision.CLAHE.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CLAHE.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.CLAHE.html#write/2"},{"type":"function","title":"Evision.CLAHE.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CLAHE.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CLAHE.html#write/3"},{"type":"type","title":"Evision.CLAHE.t/0","doc":"Type that represents an `CLAHE` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CLAHE.html#t:t/0"},{"type":"module","title":"Evision.CUDA","doc":"","ref":"Evision.CUDA.html"},{"type":"function","title":"Evision.CUDA.abs/1","doc":"#### Variant 1:\nComputes an absolute value of each matrix element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source matrix.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix with the same size and type as src .\n\n@sa abs\n\nPython prototype (for reference only):\n```python3\nabs(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nComputes an absolute value of each matrix element.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix with the same size and type as src .\n\n@sa abs\n\nPython prototype (for reference only):\n```python3\nabs(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#abs/1"},{"type":"function","title":"Evision.CUDA.abs/2","doc":"#### Variant 1:\nComputes an absolute value of each matrix element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source matrix.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix with the same size and type as src .\n\n@sa abs\n\nPython prototype (for reference only):\n```python3\nabs(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nComputes an absolute value of each matrix element.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix with the same size and type as src .\n\n@sa abs\n\nPython prototype (for reference only):\n```python3\nabs(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#abs/2"},{"type":"function","title":"Evision.CUDA.absdiff/1","doc":"","ref":"Evision.CUDA.html#absdiff/1"},{"type":"function","title":"Evision.CUDA.absdiff/2","doc":"#### Variant 1:\nComputes per-element absolute difference of two matrices (or of a matrix and scalar).\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.Mat`.\n\n  Second source matrix or scalar.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix that has the same size and type as the input array(s).\n\n@sa absdiff\n\nPython prototype (for reference only):\n```python3\nabsdiff(src1, src2[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nComputes per-element absolute difference of two matrices (or of a matrix and scalar).\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second source matrix or scalar.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix that has the same size and type as the input array(s).\n\n@sa absdiff\n\nPython prototype (for reference only):\n```python3\nabsdiff(src1, src2[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#absdiff/2"},{"type":"function","title":"Evision.CUDA.absdiff/3","doc":"#### Variant 1:\nComputes per-element absolute difference of two matrices (or of a matrix and scalar).\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.Mat`.\n\n  Second source matrix or scalar.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix that has the same size and type as the input array(s).\n\n@sa absdiff\n\nPython prototype (for reference only):\n```python3\nabsdiff(src1, src2[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nComputes per-element absolute difference of two matrices (or of a matrix and scalar).\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second source matrix or scalar.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix that has the same size and type as the input array(s).\n\n@sa absdiff\n\nPython prototype (for reference only):\n```python3\nabsdiff(src1, src2[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#absdiff/3"},{"type":"function","title":"Evision.CUDA.absSum/1","doc":"#### Variant 1:\nReturns the sum of absolute values for matrix elements.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image of any depth except for CV_64F .\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  optional operation mask; it must have the same size as src1 and CV_8UC1 type.\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n\nPython prototype (for reference only):\n```python3\nabsSum(src[, mask]) -> retval\n```\n#### Variant 2:\nReturns the sum of absolute values for matrix elements.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image of any depth except for CV_64F .\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  optional operation mask; it must have the same size as src1 and CV_8UC1 type.\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n\nPython prototype (for reference only):\n```python3\nabsSum(src[, mask]) -> retval\n```","ref":"Evision.CUDA.html#absSum/1"},{"type":"function","title":"Evision.CUDA.absSum/2","doc":"#### Variant 1:\nReturns the sum of absolute values for matrix elements.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image of any depth except for CV_64F .\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  optional operation mask; it must have the same size as src1 and CV_8UC1 type.\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n\nPython prototype (for reference only):\n```python3\nabsSum(src[, mask]) -> retval\n```\n#### Variant 2:\nReturns the sum of absolute values for matrix elements.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image of any depth except for CV_64F .\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  optional operation mask; it must have the same size as src1 and CV_8UC1 type.\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n\nPython prototype (for reference only):\n```python3\nabsSum(src[, mask]) -> retval\n```","ref":"Evision.CUDA.html#absSum/2"},{"type":"function","title":"Evision.CUDA.add/1","doc":"","ref":"Evision.CUDA.html#add/1"},{"type":"function","title":"Evision.CUDA.add/2","doc":"#### Variant 1:\nComputes a matrix-matrix or matrix-scalar sum.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.Mat`.\n\n  Second source matrix or scalar. Matrix should have the same size and type as src1 .\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional operation mask, 8-bit single channel array, that specifies elements of the\n  destination array to be changed. The mask can be used only with single channel images.\n\n- **dtype**: `integer()`.\n\n  Optional depth of the output array.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix that has the same size and number of channels as the input array(s).\n  The depth is defined by dtype or src1 depth.\n\n@sa add\n\nPython prototype (for reference only):\n```python3\nadd(src1, src2[, dst[, mask[, dtype[, stream]]]]) -> dst\n```\n#### Variant 2:\nComputes a matrix-matrix or matrix-scalar sum.\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second source matrix or scalar. Matrix should have the same size and type as src1 .\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Optional operation mask, 8-bit single channel array, that specifies elements of the\n  destination array to be changed. The mask can be used only with single channel images.\n\n- **dtype**: `integer()`.\n\n  Optional depth of the output array.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix that has the same size and number of channels as the input array(s).\n  The depth is defined by dtype or src1 depth.\n\n@sa add\n\nPython prototype (for reference only):\n```python3\nadd(src1, src2[, dst[, mask[, dtype[, stream]]]]) -> dst\n```","ref":"Evision.CUDA.html#add/2"},{"type":"function","title":"Evision.CUDA.add/3","doc":"#### Variant 1:\nComputes a matrix-matrix or matrix-scalar sum.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.Mat`.\n\n  Second source matrix or scalar. Matrix should have the same size and type as src1 .\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional operation mask, 8-bit single channel array, that specifies elements of the\n  destination array to be changed. The mask can be used only with single channel images.\n\n- **dtype**: `integer()`.\n\n  Optional depth of the output array.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix that has the same size and number of channels as the input array(s).\n  The depth is defined by dtype or src1 depth.\n\n@sa add\n\nPython prototype (for reference only):\n```python3\nadd(src1, src2[, dst[, mask[, dtype[, stream]]]]) -> dst\n```\n#### Variant 2:\nComputes a matrix-matrix or matrix-scalar sum.\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second source matrix or scalar. Matrix should have the same size and type as src1 .\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Optional operation mask, 8-bit single channel array, that specifies elements of the\n  destination array to be changed. The mask can be used only with single channel images.\n\n- **dtype**: `integer()`.\n\n  Optional depth of the output array.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix that has the same size and number of channels as the input array(s).\n  The depth is defined by dtype or src1 depth.\n\n@sa add\n\nPython prototype (for reference only):\n```python3\nadd(src1, src2[, dst[, mask[, dtype[, stream]]]]) -> dst\n```","ref":"Evision.CUDA.html#add/3"},{"type":"function","title":"Evision.CUDA.addWeighted/1","doc":"","ref":"Evision.CUDA.html#addWeighted/1"},{"type":"function","title":"Evision.CUDA.addWeighted/5","doc":"#### Variant 1:\nComputes the weighted sum of two arrays.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First source array.\n\n- **alpha**: `double`.\n\n  Weight for the first array elements.\n\n- **src2**: `Evision.Mat`.\n\n  Second source array of the same size and channel number as src1 .\n\n- **beta**: `double`.\n\n  Weight for the second array elements.\n\n- **gamma**: `double`.\n\n  Scalar added to each sum.\n\n##### Keyword Arguments\n- **dtype**: `integer()`.\n\n  Optional depth of the destination array. When both input arrays have the same depth,\n  dtype can be set to -1, which will be equivalent to src1.depth().\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination array that has the same size and number of channels as the input arrays.\n\nThe function addWeighted calculates the weighted sum of two arrays as follows:\n\\f[\\texttt{dst} (I)= \\texttt{saturate} ( \\texttt{src1} (I)\\* \\texttt{alpha} +  \\texttt{src2} (I)\\* \\texttt{beta} +  \\texttt{gamma} )\\f]\nwhere I is a multi-dimensional index of array elements. In case of multi-channel arrays, each\nchannel is processed independently.\n@sa addWeighted\n\nPython prototype (for reference only):\n```python3\naddWeighted(src1, alpha, src2, beta, gamma[, dst[, dtype[, stream]]]) -> dst\n```\n#### Variant 2:\nComputes the weighted sum of two arrays.\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First source array.\n\n- **alpha**: `double`.\n\n  Weight for the first array elements.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second source array of the same size and channel number as src1 .\n\n- **beta**: `double`.\n\n  Weight for the second array elements.\n\n- **gamma**: `double`.\n\n  Scalar added to each sum.\n\n##### Keyword Arguments\n- **dtype**: `integer()`.\n\n  Optional depth of the destination array. When both input arrays have the same depth,\n  dtype can be set to -1, which will be equivalent to src1.depth().\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination array that has the same size and number of channels as the input arrays.\n\nThe function addWeighted calculates the weighted sum of two arrays as follows:\n\\f[\\texttt{dst} (I)= \\texttt{saturate} ( \\texttt{src1} (I)\\* \\texttt{alpha} +  \\texttt{src2} (I)\\* \\texttt{beta} +  \\texttt{gamma} )\\f]\nwhere I is a multi-dimensional index of array elements. In case of multi-channel arrays, each\nchannel is processed independently.\n@sa addWeighted\n\nPython prototype (for reference only):\n```python3\naddWeighted(src1, alpha, src2, beta, gamma[, dst[, dtype[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#addWeighted/5"},{"type":"function","title":"Evision.CUDA.addWeighted/6","doc":"#### Variant 1:\nComputes the weighted sum of two arrays.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First source array.\n\n- **alpha**: `double`.\n\n  Weight for the first array elements.\n\n- **src2**: `Evision.Mat`.\n\n  Second source array of the same size and channel number as src1 .\n\n- **beta**: `double`.\n\n  Weight for the second array elements.\n\n- **gamma**: `double`.\n\n  Scalar added to each sum.\n\n##### Keyword Arguments\n- **dtype**: `integer()`.\n\n  Optional depth of the destination array. When both input arrays have the same depth,\n  dtype can be set to -1, which will be equivalent to src1.depth().\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination array that has the same size and number of channels as the input arrays.\n\nThe function addWeighted calculates the weighted sum of two arrays as follows:\n\\f[\\texttt{dst} (I)= \\texttt{saturate} ( \\texttt{src1} (I)\\* \\texttt{alpha} +  \\texttt{src2} (I)\\* \\texttt{beta} +  \\texttt{gamma} )\\f]\nwhere I is a multi-dimensional index of array elements. In case of multi-channel arrays, each\nchannel is processed independently.\n@sa addWeighted\n\nPython prototype (for reference only):\n```python3\naddWeighted(src1, alpha, src2, beta, gamma[, dst[, dtype[, stream]]]) -> dst\n```\n#### Variant 2:\nComputes the weighted sum of two arrays.\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First source array.\n\n- **alpha**: `double`.\n\n  Weight for the first array elements.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second source array of the same size and channel number as src1 .\n\n- **beta**: `double`.\n\n  Weight for the second array elements.\n\n- **gamma**: `double`.\n\n  Scalar added to each sum.\n\n##### Keyword Arguments\n- **dtype**: `integer()`.\n\n  Optional depth of the destination array. When both input arrays have the same depth,\n  dtype can be set to -1, which will be equivalent to src1.depth().\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination array that has the same size and number of channels as the input arrays.\n\nThe function addWeighted calculates the weighted sum of two arrays as follows:\n\\f[\\texttt{dst} (I)= \\texttt{saturate} ( \\texttt{src1} (I)\\* \\texttt{alpha} +  \\texttt{src2} (I)\\* \\texttt{beta} +  \\texttt{gamma} )\\f]\nwhere I is a multi-dimensional index of array elements. In case of multi-channel arrays, each\nchannel is processed independently.\n@sa addWeighted\n\nPython prototype (for reference only):\n```python3\naddWeighted(src1, alpha, src2, beta, gamma[, dst[, dtype[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#addWeighted/6"},{"type":"function","title":"Evision.CUDA.alphaComp/1","doc":"","ref":"Evision.CUDA.html#alphaComp/1"},{"type":"function","title":"Evision.CUDA.alphaComp/3","doc":"#### Variant 1:\nComposites two images using alpha opacity values contained in each image.\n\n##### Positional Arguments\n- **img1**: `Evision.Mat`.\n\n  First image. Supports CV_8UC4 , CV_16UC4 , CV_32SC4 and CV_32FC4 types.\n\n- **img2**: `Evision.Mat`.\n\n  Second image. Must have the same size and the same type as img1 .\n\n- **alpha_op**: `integer()`.\n\n  Flag specifying the alpha-blending operation:\n  - **ALPHA_OVER**\n  - **ALPHA_IN**\n  - **ALPHA_OUT**\n  - **ALPHA_ATOP**\n  - **ALPHA_XOR**\n  - **ALPHA_PLUS**\n  - **ALPHA_OVER_PREMUL**\n  - **ALPHA_IN_PREMUL**\n  - **ALPHA_OUT_PREMUL**\n  - **ALPHA_ATOP_PREMUL**\n  - **ALPHA_XOR_PREMUL**\n  - **ALPHA_PLUS_PREMUL**\n  - **ALPHA_PREMUL**\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image.\n\n**Note**: \n- An example demonstrating the use of alphaComp can be found at\n  opencv_source_code/samples/gpu/alpha_comp.cpp\n\nPython prototype (for reference only):\n```python3\nalphaComp(img1, img2, alpha_op[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nComposites two images using alpha opacity values contained in each image.\n\n##### Positional Arguments\n- **img1**: `Evision.CUDA.GpuMat.t()`.\n\n  First image. Supports CV_8UC4 , CV_16UC4 , CV_32SC4 and CV_32FC4 types.\n\n- **img2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second image. Must have the same size and the same type as img1 .\n\n- **alpha_op**: `integer()`.\n\n  Flag specifying the alpha-blending operation:\n  - **ALPHA_OVER**\n  - **ALPHA_IN**\n  - **ALPHA_OUT**\n  - **ALPHA_ATOP**\n  - **ALPHA_XOR**\n  - **ALPHA_PLUS**\n  - **ALPHA_OVER_PREMUL**\n  - **ALPHA_IN_PREMUL**\n  - **ALPHA_OUT_PREMUL**\n  - **ALPHA_ATOP_PREMUL**\n  - **ALPHA_XOR_PREMUL**\n  - **ALPHA_PLUS_PREMUL**\n  - **ALPHA_PREMUL**\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image.\n\n**Note**: \n- An example demonstrating the use of alphaComp can be found at\n  opencv_source_code/samples/gpu/alpha_comp.cpp\n\nPython prototype (for reference only):\n```python3\nalphaComp(img1, img2, alpha_op[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#alphaComp/3"},{"type":"function","title":"Evision.CUDA.alphaComp/4","doc":"#### Variant 1:\nComposites two images using alpha opacity values contained in each image.\n\n##### Positional Arguments\n- **img1**: `Evision.Mat`.\n\n  First image. Supports CV_8UC4 , CV_16UC4 , CV_32SC4 and CV_32FC4 types.\n\n- **img2**: `Evision.Mat`.\n\n  Second image. Must have the same size and the same type as img1 .\n\n- **alpha_op**: `integer()`.\n\n  Flag specifying the alpha-blending operation:\n  - **ALPHA_OVER**\n  - **ALPHA_IN**\n  - **ALPHA_OUT**\n  - **ALPHA_ATOP**\n  - **ALPHA_XOR**\n  - **ALPHA_PLUS**\n  - **ALPHA_OVER_PREMUL**\n  - **ALPHA_IN_PREMUL**\n  - **ALPHA_OUT_PREMUL**\n  - **ALPHA_ATOP_PREMUL**\n  - **ALPHA_XOR_PREMUL**\n  - **ALPHA_PLUS_PREMUL**\n  - **ALPHA_PREMUL**\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image.\n\n**Note**: \n- An example demonstrating the use of alphaComp can be found at\n  opencv_source_code/samples/gpu/alpha_comp.cpp\n\nPython prototype (for reference only):\n```python3\nalphaComp(img1, img2, alpha_op[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nComposites two images using alpha opacity values contained in each image.\n\n##### Positional Arguments\n- **img1**: `Evision.CUDA.GpuMat.t()`.\n\n  First image. Supports CV_8UC4 , CV_16UC4 , CV_32SC4 and CV_32FC4 types.\n\n- **img2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second image. Must have the same size and the same type as img1 .\n\n- **alpha_op**: `integer()`.\n\n  Flag specifying the alpha-blending operation:\n  - **ALPHA_OVER**\n  - **ALPHA_IN**\n  - **ALPHA_OUT**\n  - **ALPHA_ATOP**\n  - **ALPHA_XOR**\n  - **ALPHA_PLUS**\n  - **ALPHA_OVER_PREMUL**\n  - **ALPHA_IN_PREMUL**\n  - **ALPHA_OUT_PREMUL**\n  - **ALPHA_ATOP_PREMUL**\n  - **ALPHA_XOR_PREMUL**\n  - **ALPHA_PLUS_PREMUL**\n  - **ALPHA_PREMUL**\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image.\n\n**Note**: \n- An example demonstrating the use of alphaComp can be found at\n  opencv_source_code/samples/gpu/alpha_comp.cpp\n\nPython prototype (for reference only):\n```python3\nalphaComp(img1, img2, alpha_op[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#alphaComp/4"},{"type":"function","title":"Evision.CUDA.bilateralFilter/1","doc":"","ref":"Evision.CUDA.html#bilateralFilter/1"},{"type":"function","title":"Evision.CUDA.bilateralFilter/4","doc":"#### Variant 1:\nPerforms bilateral filtering of passed image\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. Supports only (channels != 2 && depth() != CV_8S && depth() != CV_32S\n  && depth() != CV_64F).\n\n- **kernel_size**: `integer()`.\n\n  Kernel window size.\n\n- **sigma_color**: `float`.\n\n  Filter sigma in the color space.\n\n- **sigma_spatial**: `float`.\n\n  Filter sigma in the coordinate space.\n\n##### Keyword Arguments\n- **borderMode**: `integer()`.\n\n  Border type. See borderInterpolate for details. BORDER_REFLECT101 ,\n  BORDER_REPLICATE , BORDER_CONSTANT , BORDER_REFLECT and BORDER_WRAP are supported for now.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination imagwe.\n\n@sa bilateralFilter\n\nPython prototype (for reference only):\n```python3\nbilateralFilter(src, kernel_size, sigma_color, sigma_spatial[, dst[, borderMode[, stream]]]) -> dst\n```\n#### Variant 2:\nPerforms bilateral filtering of passed image\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. Supports only (channels != 2 && depth() != CV_8S && depth() != CV_32S\n  && depth() != CV_64F).\n\n- **kernel_size**: `integer()`.\n\n  Kernel window size.\n\n- **sigma_color**: `float`.\n\n  Filter sigma in the color space.\n\n- **sigma_spatial**: `float`.\n\n  Filter sigma in the coordinate space.\n\n##### Keyword Arguments\n- **borderMode**: `integer()`.\n\n  Border type. See borderInterpolate for details. BORDER_REFLECT101 ,\n  BORDER_REPLICATE , BORDER_CONSTANT , BORDER_REFLECT and BORDER_WRAP are supported for now.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination imagwe.\n\n@sa bilateralFilter\n\nPython prototype (for reference only):\n```python3\nbilateralFilter(src, kernel_size, sigma_color, sigma_spatial[, dst[, borderMode[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#bilateralFilter/4"},{"type":"function","title":"Evision.CUDA.bilateralFilter/5","doc":"#### Variant 1:\nPerforms bilateral filtering of passed image\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. Supports only (channels != 2 && depth() != CV_8S && depth() != CV_32S\n  && depth() != CV_64F).\n\n- **kernel_size**: `integer()`.\n\n  Kernel window size.\n\n- **sigma_color**: `float`.\n\n  Filter sigma in the color space.\n\n- **sigma_spatial**: `float`.\n\n  Filter sigma in the coordinate space.\n\n##### Keyword Arguments\n- **borderMode**: `integer()`.\n\n  Border type. See borderInterpolate for details. BORDER_REFLECT101 ,\n  BORDER_REPLICATE , BORDER_CONSTANT , BORDER_REFLECT and BORDER_WRAP are supported for now.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination imagwe.\n\n@sa bilateralFilter\n\nPython prototype (for reference only):\n```python3\nbilateralFilter(src, kernel_size, sigma_color, sigma_spatial[, dst[, borderMode[, stream]]]) -> dst\n```\n#### Variant 2:\nPerforms bilateral filtering of passed image\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. Supports only (channels != 2 && depth() != CV_8S && depth() != CV_32S\n  && depth() != CV_64F).\n\n- **kernel_size**: `integer()`.\n\n  Kernel window size.\n\n- **sigma_color**: `float`.\n\n  Filter sigma in the color space.\n\n- **sigma_spatial**: `float`.\n\n  Filter sigma in the coordinate space.\n\n##### Keyword Arguments\n- **borderMode**: `integer()`.\n\n  Border type. See borderInterpolate for details. BORDER_REFLECT101 ,\n  BORDER_REPLICATE , BORDER_CONSTANT , BORDER_REFLECT and BORDER_WRAP are supported for now.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination imagwe.\n\n@sa bilateralFilter\n\nPython prototype (for reference only):\n```python3\nbilateralFilter(src, kernel_size, sigma_color, sigma_spatial[, dst[, borderMode[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#bilateralFilter/5"},{"type":"function","title":"Evision.CUDA.blendLinear/1","doc":"","ref":"Evision.CUDA.html#blendLinear/1"},{"type":"function","title":"Evision.CUDA.blendLinear/4","doc":"#### Variant 1:\nPerforms linear blending of two images.\n\n##### Positional Arguments\n- **img1**: `Evision.Mat`.\n\n  First image. Supports only CV_8U and CV_32F depth.\n\n- **img2**: `Evision.Mat`.\n\n  Second image. Must have the same size and the same type as img1 .\n\n- **weights1**: `Evision.Mat`.\n\n  Weights for first image. Must have tha same size as img1 . Supports only CV_32F\n  type.\n\n- **weights2**: `Evision.Mat`.\n\n  Weights for second image. Must have tha same size as img2 . Supports only CV_32F\n  type.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **result**: `Evision.Mat.t()`.\n\n  Destination image.\n\nPython prototype (for reference only):\n```python3\nblendLinear(img1, img2, weights1, weights2[, result[, stream]]) -> result\n```\n#### Variant 2:\nPerforms linear blending of two images.\n\n##### Positional Arguments\n- **img1**: `Evision.CUDA.GpuMat.t()`.\n\n  First image. Supports only CV_8U and CV_32F depth.\n\n- **img2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second image. Must have the same size and the same type as img1 .\n\n- **weights1**: `Evision.CUDA.GpuMat.t()`.\n\n  Weights for first image. Must have tha same size as img1 . Supports only CV_32F\n  type.\n\n- **weights2**: `Evision.CUDA.GpuMat.t()`.\n\n  Weights for second image. Must have tha same size as img2 . Supports only CV_32F\n  type.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **result**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image.\n\nPython prototype (for reference only):\n```python3\nblendLinear(img1, img2, weights1, weights2[, result[, stream]]) -> result\n```","ref":"Evision.CUDA.html#blendLinear/4"},{"type":"function","title":"Evision.CUDA.blendLinear/5","doc":"#### Variant 1:\nPerforms linear blending of two images.\n\n##### Positional Arguments\n- **img1**: `Evision.Mat`.\n\n  First image. Supports only CV_8U and CV_32F depth.\n\n- **img2**: `Evision.Mat`.\n\n  Second image. Must have the same size and the same type as img1 .\n\n- **weights1**: `Evision.Mat`.\n\n  Weights for first image. Must have tha same size as img1 . Supports only CV_32F\n  type.\n\n- **weights2**: `Evision.Mat`.\n\n  Weights for second image. Must have tha same size as img2 . Supports only CV_32F\n  type.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **result**: `Evision.Mat.t()`.\n\n  Destination image.\n\nPython prototype (for reference only):\n```python3\nblendLinear(img1, img2, weights1, weights2[, result[, stream]]) -> result\n```\n#### Variant 2:\nPerforms linear blending of two images.\n\n##### Positional Arguments\n- **img1**: `Evision.CUDA.GpuMat.t()`.\n\n  First image. Supports only CV_8U and CV_32F depth.\n\n- **img2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second image. Must have the same size and the same type as img1 .\n\n- **weights1**: `Evision.CUDA.GpuMat.t()`.\n\n  Weights for first image. Must have tha same size as img1 . Supports only CV_32F\n  type.\n\n- **weights2**: `Evision.CUDA.GpuMat.t()`.\n\n  Weights for second image. Must have tha same size as img2 . Supports only CV_32F\n  type.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **result**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image.\n\nPython prototype (for reference only):\n```python3\nblendLinear(img1, img2, weights1, weights2[, result[, stream]]) -> result\n```","ref":"Evision.CUDA.html#blendLinear/5"},{"type":"function","title":"Evision.CUDA.buildWarpAffineMaps/1","doc":"","ref":"Evision.CUDA.html#buildWarpAffineMaps/1"},{"type":"function","title":"Evision.CUDA.buildWarpAffineMaps/3","doc":"buildWarpAffineMaps\n\n##### Positional Arguments\n- **m**: `Evision.Mat`\n- **inverse**: `bool`\n- **dsize**: `Size`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **xmap**: `Evision.CUDA.GpuMat.t()`.\n- **ymap**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\nbuildWarpAffineMaps(M, inverse, dsize[, xmap[, ymap[, stream]]]) -> xmap, ymap\n```","ref":"Evision.CUDA.html#buildWarpAffineMaps/3"},{"type":"function","title":"Evision.CUDA.buildWarpAffineMaps/4","doc":"buildWarpAffineMaps\n\n##### Positional Arguments\n- **m**: `Evision.Mat`\n- **inverse**: `bool`\n- **dsize**: `Size`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **xmap**: `Evision.CUDA.GpuMat.t()`.\n- **ymap**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\nbuildWarpAffineMaps(M, inverse, dsize[, xmap[, ymap[, stream]]]) -> xmap, ymap\n```","ref":"Evision.CUDA.html#buildWarpAffineMaps/4"},{"type":"function","title":"Evision.CUDA.buildWarpPerspectiveMaps/1","doc":"","ref":"Evision.CUDA.html#buildWarpPerspectiveMaps/1"},{"type":"function","title":"Evision.CUDA.buildWarpPerspectiveMaps/3","doc":"buildWarpPerspectiveMaps\n\n##### Positional Arguments\n- **m**: `Evision.Mat`\n- **inverse**: `bool`\n- **dsize**: `Size`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **xmap**: `Evision.CUDA.GpuMat.t()`.\n- **ymap**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\nbuildWarpPerspectiveMaps(M, inverse, dsize[, xmap[, ymap[, stream]]]) -> xmap, ymap\n```","ref":"Evision.CUDA.html#buildWarpPerspectiveMaps/3"},{"type":"function","title":"Evision.CUDA.buildWarpPerspectiveMaps/4","doc":"buildWarpPerspectiveMaps\n\n##### Positional Arguments\n- **m**: `Evision.Mat`\n- **inverse**: `bool`\n- **dsize**: `Size`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **xmap**: `Evision.CUDA.GpuMat.t()`.\n- **ymap**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\nbuildWarpPerspectiveMaps(M, inverse, dsize[, xmap[, ymap[, stream]]]) -> xmap, ymap\n```","ref":"Evision.CUDA.html#buildWarpPerspectiveMaps/4"},{"type":"function","title":"Evision.CUDA.calcAbsSum/1","doc":"#### Variant 1:\ncalcAbsSum\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalcAbsSum(src[, dst[, mask[, stream]]]) -> dst\n```\n#### Variant 2:\ncalcAbsSum\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalcAbsSum(src[, dst[, mask[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#calcAbsSum/1"},{"type":"function","title":"Evision.CUDA.calcAbsSum/2","doc":"#### Variant 1:\ncalcAbsSum\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalcAbsSum(src[, dst[, mask[, stream]]]) -> dst\n```\n#### Variant 2:\ncalcAbsSum\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalcAbsSum(src[, dst[, mask[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#calcAbsSum/2"},{"type":"function","title":"Evision.CUDA.calcHist/1","doc":"#### Variant 1:\nCalculates histogram for one channel 8-bit image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image with CV_8UC1 type.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **hist**: `Evision.Mat.t()`.\n\n  Destination histogram with one row, 256 columns, and the CV_32SC1 type.\n\nPython prototype (for reference only):\n```python3\ncalcHist(src[, hist[, stream]]) -> hist\n```\n#### Variant 2:\nCalculates histogram for one channel 8-bit image.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image with CV_8UC1 type.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **hist**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination histogram with one row, 256 columns, and the CV_32SC1 type.\n\nPython prototype (for reference only):\n```python3\ncalcHist(src[, hist[, stream]]) -> hist\n```","ref":"Evision.CUDA.html#calcHist/1"},{"type":"function","title":"Evision.CUDA.calcHist/2","doc":"#### Variant 1:\nCalculates histogram for one channel 8-bit image confined in given mask.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image with CV_8UC1 type.\n\n- **mask**: `Evision.Mat`.\n\n  A mask image same size as src and of type CV_8UC1.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **hist**: `Evision.Mat.t()`.\n\n  Destination histogram with one row, 256 columns, and the CV_32SC1 type.\n\nPython prototype (for reference only):\n```python3\ncalcHist(src, mask[, hist[, stream]]) -> hist\n```\n#### Variant 2:\nCalculates histogram for one channel 8-bit image confined in given mask.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image with CV_8UC1 type.\n\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  A mask image same size as src and of type CV_8UC1.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **hist**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination histogram with one row, 256 columns, and the CV_32SC1 type.\n\nPython prototype (for reference only):\n```python3\ncalcHist(src, mask[, hist[, stream]]) -> hist\n```\n#### Variant 3:\nCalculates histogram for one channel 8-bit image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image with CV_8UC1 type.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **hist**: `Evision.Mat.t()`.\n\n  Destination histogram with one row, 256 columns, and the CV_32SC1 type.\n\nPython prototype (for reference only):\n```python3\ncalcHist(src[, hist[, stream]]) -> hist\n```\n#### Variant 4:\nCalculates histogram for one channel 8-bit image.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image with CV_8UC1 type.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **hist**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination histogram with one row, 256 columns, and the CV_32SC1 type.\n\nPython prototype (for reference only):\n```python3\ncalcHist(src[, hist[, stream]]) -> hist\n```","ref":"Evision.CUDA.html#calcHist/2"},{"type":"function","title":"Evision.CUDA.calcHist/3","doc":"#### Variant 1:\nCalculates histogram for one channel 8-bit image confined in given mask.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image with CV_8UC1 type.\n\n- **mask**: `Evision.Mat`.\n\n  A mask image same size as src and of type CV_8UC1.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **hist**: `Evision.Mat.t()`.\n\n  Destination histogram with one row, 256 columns, and the CV_32SC1 type.\n\nPython prototype (for reference only):\n```python3\ncalcHist(src, mask[, hist[, stream]]) -> hist\n```\n#### Variant 2:\nCalculates histogram for one channel 8-bit image confined in given mask.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image with CV_8UC1 type.\n\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  A mask image same size as src and of type CV_8UC1.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **hist**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination histogram with one row, 256 columns, and the CV_32SC1 type.\n\nPython prototype (for reference only):\n```python3\ncalcHist(src, mask[, hist[, stream]]) -> hist\n```","ref":"Evision.CUDA.html#calcHist/3"},{"type":"function","title":"Evision.CUDA.calcNorm/1","doc":"","ref":"Evision.CUDA.html#calcNorm/1"},{"type":"function","title":"Evision.CUDA.calcNorm/2","doc":"#### Variant 1:\ncalcNorm\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n- **normType**: `integer()`\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalcNorm(src, normType[, dst[, mask[, stream]]]) -> dst\n```\n#### Variant 2:\ncalcNorm\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n- **normType**: `integer()`\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalcNorm(src, normType[, dst[, mask[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#calcNorm/2"},{"type":"function","title":"Evision.CUDA.calcNorm/3","doc":"#### Variant 1:\ncalcNorm\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n- **normType**: `integer()`\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalcNorm(src, normType[, dst[, mask[, stream]]]) -> dst\n```\n#### Variant 2:\ncalcNorm\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n- **normType**: `integer()`\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalcNorm(src, normType[, dst[, mask[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#calcNorm/3"},{"type":"function","title":"Evision.CUDA.calcNormDiff/1","doc":"","ref":"Evision.CUDA.html#calcNormDiff/1"},{"type":"function","title":"Evision.CUDA.calcNormDiff/2","doc":"#### Variant 1:\ncalcNormDiff\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`\n- **src2**: `Evision.Mat`\n\n##### Keyword Arguments\n- **normType**: `integer()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalcNormDiff(src1, src2[, dst[, normType[, stream]]]) -> dst\n```\n#### Variant 2:\ncalcNormDiff\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`\n- **src2**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **normType**: `integer()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalcNormDiff(src1, src2[, dst[, normType[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#calcNormDiff/2"},{"type":"function","title":"Evision.CUDA.calcNormDiff/3","doc":"#### Variant 1:\ncalcNormDiff\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`\n- **src2**: `Evision.Mat`\n\n##### Keyword Arguments\n- **normType**: `integer()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalcNormDiff(src1, src2[, dst[, normType[, stream]]]) -> dst\n```\n#### Variant 2:\ncalcNormDiff\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`\n- **src2**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **normType**: `integer()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalcNormDiff(src1, src2[, dst[, normType[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#calcNormDiff/3"},{"type":"function","title":"Evision.CUDA.calcSqrSum/1","doc":"#### Variant 1:\ncalcSqrSum\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalcSqrSum(src[, dst[, mask[, stream]]]) -> dst\n```\n#### Variant 2:\ncalcSqrSum\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalcSqrSum(src[, dst[, mask[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#calcSqrSum/1"},{"type":"function","title":"Evision.CUDA.calcSqrSum/2","doc":"#### Variant 1:\ncalcSqrSum\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalcSqrSum(src[, dst[, mask[, stream]]]) -> dst\n```\n#### Variant 2:\ncalcSqrSum\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalcSqrSum(src[, dst[, mask[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#calcSqrSum/2"},{"type":"function","title":"Evision.CUDA.calcSum/1","doc":"#### Variant 1:\ncalcSum\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalcSum(src[, dst[, mask[, stream]]]) -> dst\n```\n#### Variant 2:\ncalcSum\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalcSum(src[, dst[, mask[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#calcSum/1"},{"type":"function","title":"Evision.CUDA.calcSum/2","doc":"#### Variant 1:\ncalcSum\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalcSum(src[, dst[, mask[, stream]]]) -> dst\n```\n#### Variant 2:\ncalcSum\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncalcSum(src[, dst[, mask[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#calcSum/2"},{"type":"function","title":"Evision.CUDA.cartToPolar/1","doc":"","ref":"Evision.CUDA.html#cartToPolar/1"},{"type":"function","title":"Evision.CUDA.cartToPolar/2","doc":"#### Variant 1:\nConverts Cartesian coordinates into polar.\n\n##### Positional Arguments\n- **x**: `Evision.Mat`.\n\n  Source matrix containing real components ( CV_32FC1 ).\n\n- **y**: `Evision.Mat`.\n\n  Source matrix containing imaginary components ( CV_32FC1 ).\n\n##### Keyword Arguments\n- **angleInDegrees**: `bool`.\n\n  Flag for angles that must be evaluated in degrees.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **magnitude**: `Evision.Mat.t()`.\n\n  Destination matrix of float magnitudes ( CV_32FC1 ).\n\n- **angle**: `Evision.Mat.t()`.\n\n  Destination matrix of angles ( CV_32FC1 ).\n\n@sa cartToPolar\n\nPython prototype (for reference only):\n```python3\ncartToPolar(x, y[, magnitude[, angle[, angleInDegrees[, stream]]]]) -> magnitude, angle\n```\n#### Variant 2:\nConverts Cartesian coordinates into polar.\n\n##### Positional Arguments\n- **x**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix containing real components ( CV_32FC1 ).\n\n- **y**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix containing imaginary components ( CV_32FC1 ).\n\n##### Keyword Arguments\n- **angleInDegrees**: `bool`.\n\n  Flag for angles that must be evaluated in degrees.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **magnitude**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix of float magnitudes ( CV_32FC1 ).\n\n- **angle**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix of angles ( CV_32FC1 ).\n\n@sa cartToPolar\n\nPython prototype (for reference only):\n```python3\ncartToPolar(x, y[, magnitude[, angle[, angleInDegrees[, stream]]]]) -> magnitude, angle\n```","ref":"Evision.CUDA.html#cartToPolar/2"},{"type":"function","title":"Evision.CUDA.cartToPolar/3","doc":"#### Variant 1:\nConverts Cartesian coordinates into polar.\n\n##### Positional Arguments\n- **x**: `Evision.Mat`.\n\n  Source matrix containing real components ( CV_32FC1 ).\n\n- **y**: `Evision.Mat`.\n\n  Source matrix containing imaginary components ( CV_32FC1 ).\n\n##### Keyword Arguments\n- **angleInDegrees**: `bool`.\n\n  Flag for angles that must be evaluated in degrees.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **magnitude**: `Evision.Mat.t()`.\n\n  Destination matrix of float magnitudes ( CV_32FC1 ).\n\n- **angle**: `Evision.Mat.t()`.\n\n  Destination matrix of angles ( CV_32FC1 ).\n\n@sa cartToPolar\n\nPython prototype (for reference only):\n```python3\ncartToPolar(x, y[, magnitude[, angle[, angleInDegrees[, stream]]]]) -> magnitude, angle\n```\n#### Variant 2:\nConverts Cartesian coordinates into polar.\n\n##### Positional Arguments\n- **x**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix containing real components ( CV_32FC1 ).\n\n- **y**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix containing imaginary components ( CV_32FC1 ).\n\n##### Keyword Arguments\n- **angleInDegrees**: `bool`.\n\n  Flag for angles that must be evaluated in degrees.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **magnitude**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix of float magnitudes ( CV_32FC1 ).\n\n- **angle**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix of angles ( CV_32FC1 ).\n\n@sa cartToPolar\n\nPython prototype (for reference only):\n```python3\ncartToPolar(x, y[, magnitude[, angle[, angleInDegrees[, stream]]]]) -> magnitude, angle\n```","ref":"Evision.CUDA.html#cartToPolar/3"},{"type":"function","title":"Evision.CUDA.compare/1","doc":"","ref":"Evision.CUDA.html#compare/1"},{"type":"function","title":"Evision.CUDA.compare/3","doc":"#### Variant 1:\nCompares elements of two matrices (or of a matrix and scalar).\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.Mat`.\n\n  Second source matrix or scalar.\n\n- **cmpop**: `integer()`.\n\n  Flag specifying the relation between the elements to be checked:\n  - **CMP_EQ:** a(.) == b(.)\n  - **CMP_GT:** a(.) \\> b(.)\n  - **CMP_GE:** a(.) \\>= b(.)\n  - **CMP_LT:** a(.) \\  dst\n```\n#### Variant 2:\nCompares elements of two matrices (or of a matrix and scalar).\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second source matrix or scalar.\n\n- **cmpop**: `integer()`.\n\n  Flag specifying the relation between the elements to be checked:\n  - **CMP_EQ:** a(.) == b(.)\n  - **CMP_GT:** a(.) \\> b(.)\n  - **CMP_GE:** a(.) \\>= b(.)\n  - **CMP_LT:** a(.) \\  dst\n```","ref":"Evision.CUDA.html#compare/3"},{"type":"function","title":"Evision.CUDA.compare/4","doc":"#### Variant 1:\nCompares elements of two matrices (or of a matrix and scalar).\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.Mat`.\n\n  Second source matrix or scalar.\n\n- **cmpop**: `integer()`.\n\n  Flag specifying the relation between the elements to be checked:\n  - **CMP_EQ:** a(.) == b(.)\n  - **CMP_GT:** a(.) \\> b(.)\n  - **CMP_GE:** a(.) \\>= b(.)\n  - **CMP_LT:** a(.) \\  dst\n```\n#### Variant 2:\nCompares elements of two matrices (or of a matrix and scalar).\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second source matrix or scalar.\n\n- **cmpop**: `integer()`.\n\n  Flag specifying the relation between the elements to be checked:\n  - **CMP_EQ:** a(.) == b(.)\n  - **CMP_GT:** a(.) \\> b(.)\n  - **CMP_GE:** a(.) \\>= b(.)\n  - **CMP_LT:** a(.) \\  dst\n```","ref":"Evision.CUDA.html#compare/4"},{"type":"function","title":"Evision.CUDA.connectedComponents/1","doc":"#### Variant 1:\nconnectedComponents\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  The 8-bit single-channel image to be labeled.\n\n##### Keyword Arguments\n- **connectivity**: `integer()`.\n\n  Connectivity to use for the labeling procedure. 8 for 8-way connectivity is supported.\n\n- **ltype**: `integer()`.\n\n  Output image label type. Currently CV_32S is supported.\n\n##### Return\n- **labels**: `Evision.Mat.t()`.\n\n  Destination labeled image.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nconnectedComponents(image[, labels[, connectivity[, ltype]]]) -> labels\n```\n#### Variant 2:\nconnectedComponents\n\n##### Positional Arguments\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  The 8-bit single-channel image to be labeled.\n\n##### Keyword Arguments\n- **connectivity**: `integer()`.\n\n  Connectivity to use for the labeling procedure. 8 for 8-way connectivity is supported.\n\n- **ltype**: `integer()`.\n\n  Output image label type. Currently CV_32S is supported.\n\n##### Return\n- **labels**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination labeled image.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nconnectedComponents(image[, labels[, connectivity[, ltype]]]) -> labels\n```","ref":"Evision.CUDA.html#connectedComponents/1"},{"type":"function","title":"Evision.CUDA.connectedComponents/2","doc":"#### Variant 1:\nconnectedComponents\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  The 8-bit single-channel image to be labeled.\n\n##### Keyword Arguments\n- **connectivity**: `integer()`.\n\n  Connectivity to use for the labeling procedure. 8 for 8-way connectivity is supported.\n\n- **ltype**: `integer()`.\n\n  Output image label type. Currently CV_32S is supported.\n\n##### Return\n- **labels**: `Evision.Mat.t()`.\n\n  Destination labeled image.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nconnectedComponents(image[, labels[, connectivity[, ltype]]]) -> labels\n```\n#### Variant 2:\nconnectedComponents\n\n##### Positional Arguments\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  The 8-bit single-channel image to be labeled.\n\n##### Keyword Arguments\n- **connectivity**: `integer()`.\n\n  Connectivity to use for the labeling procedure. 8 for 8-way connectivity is supported.\n\n- **ltype**: `integer()`.\n\n  Output image label type. Currently CV_32S is supported.\n\n##### Return\n- **labels**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination labeled image.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nconnectedComponents(image[, labels[, connectivity[, ltype]]]) -> labels\n```","ref":"Evision.CUDA.html#connectedComponents/2"},{"type":"function","title":"Evision.CUDA.connectedComponentsWithAlgorithm/1","doc":"","ref":"Evision.CUDA.html#connectedComponentsWithAlgorithm/1"},{"type":"function","title":"Evision.CUDA.connectedComponentsWithAlgorithm/4","doc":"#### Variant 1:\nComputes the Connected Components Labeled image of a binary image.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  The 8-bit single-channel image to be labeled.\n\n- **connectivity**: `integer()`.\n\n  Connectivity to use for the labeling procedure. 8 for 8-way connectivity is supported.\n\n- **ltype**: `integer()`.\n\n  Output image label type. Currently CV_32S is supported.\n\n- **ccltype**: `cuda_ConnectedComponentsAlgorithmsTypes`.\n\n  Connected components algorithm type (see the #ConnectedComponentsAlgorithmsTypes).\n\n##### Return\n- **labels**: `Evision.Mat.t()`.\n\n  Destination labeled image.\n\nThe function takes as input a binary image and performs Connected Components Labeling. The output\nis an image where each Connected Component is assigned a unique label (integer value).\nltype specifies the output label image type, an important consideration based on the total\nnumber of labels or alternatively the total number of pixels in the source image.\nccltype specifies the connected components labeling algorithm to use, currently\nBKE @cite Allegretti2019 is supported, see the #ConnectedComponentsAlgorithmsTypes\nfor details. Note that labels in the output are not required to be sequential.\n\n**Note**: A sample program demonstrating Connected Components Labeling in CUDA can be found at\\n\nopencv_contrib_source_code/modules/cudaimgproc/samples/connected_components.cpp\n\nPython prototype (for reference only):\n```python3\nconnectedComponentsWithAlgorithm(image, connectivity, ltype, ccltype[, labels]) -> labels\n```\n#### Variant 2:\nComputes the Connected Components Labeled image of a binary image.\n\n##### Positional Arguments\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  The 8-bit single-channel image to be labeled.\n\n- **connectivity**: `integer()`.\n\n  Connectivity to use for the labeling procedure. 8 for 8-way connectivity is supported.\n\n- **ltype**: `integer()`.\n\n  Output image label type. Currently CV_32S is supported.\n\n- **ccltype**: `cuda_ConnectedComponentsAlgorithmsTypes`.\n\n  Connected components algorithm type (see the #ConnectedComponentsAlgorithmsTypes).\n\n##### Return\n- **labels**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination labeled image.\n\nThe function takes as input a binary image and performs Connected Components Labeling. The output\nis an image where each Connected Component is assigned a unique label (integer value).\nltype specifies the output label image type, an important consideration based on the total\nnumber of labels or alternatively the total number of pixels in the source image.\nccltype specifies the connected components labeling algorithm to use, currently\nBKE @cite Allegretti2019 is supported, see the #ConnectedComponentsAlgorithmsTypes\nfor details. Note that labels in the output are not required to be sequential.\n\n**Note**: A sample program demonstrating Connected Components Labeling in CUDA can be found at\\n\nopencv_contrib_source_code/modules/cudaimgproc/samples/connected_components.cpp\n\nPython prototype (for reference only):\n```python3\nconnectedComponentsWithAlgorithm(image, connectivity, ltype, ccltype[, labels]) -> labels\n```","ref":"Evision.CUDA.html#connectedComponentsWithAlgorithm/4"},{"type":"function","title":"Evision.CUDA.connectedComponentsWithAlgorithm/5","doc":"#### Variant 1:\nComputes the Connected Components Labeled image of a binary image.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  The 8-bit single-channel image to be labeled.\n\n- **connectivity**: `integer()`.\n\n  Connectivity to use for the labeling procedure. 8 for 8-way connectivity is supported.\n\n- **ltype**: `integer()`.\n\n  Output image label type. Currently CV_32S is supported.\n\n- **ccltype**: `cuda_ConnectedComponentsAlgorithmsTypes`.\n\n  Connected components algorithm type (see the #ConnectedComponentsAlgorithmsTypes).\n\n##### Return\n- **labels**: `Evision.Mat.t()`.\n\n  Destination labeled image.\n\nThe function takes as input a binary image and performs Connected Components Labeling. The output\nis an image where each Connected Component is assigned a unique label (integer value).\nltype specifies the output label image type, an important consideration based on the total\nnumber of labels or alternatively the total number of pixels in the source image.\nccltype specifies the connected components labeling algorithm to use, currently\nBKE @cite Allegretti2019 is supported, see the #ConnectedComponentsAlgorithmsTypes\nfor details. Note that labels in the output are not required to be sequential.\n\n**Note**: A sample program demonstrating Connected Components Labeling in CUDA can be found at\\n\nopencv_contrib_source_code/modules/cudaimgproc/samples/connected_components.cpp\n\nPython prototype (for reference only):\n```python3\nconnectedComponentsWithAlgorithm(image, connectivity, ltype, ccltype[, labels]) -> labels\n```\n#### Variant 2:\nComputes the Connected Components Labeled image of a binary image.\n\n##### Positional Arguments\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  The 8-bit single-channel image to be labeled.\n\n- **connectivity**: `integer()`.\n\n  Connectivity to use for the labeling procedure. 8 for 8-way connectivity is supported.\n\n- **ltype**: `integer()`.\n\n  Output image label type. Currently CV_32S is supported.\n\n- **ccltype**: `cuda_ConnectedComponentsAlgorithmsTypes`.\n\n  Connected components algorithm type (see the #ConnectedComponentsAlgorithmsTypes).\n\n##### Return\n- **labels**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination labeled image.\n\nThe function takes as input a binary image and performs Connected Components Labeling. The output\nis an image where each Connected Component is assigned a unique label (integer value).\nltype specifies the output label image type, an important consideration based on the total\nnumber of labels or alternatively the total number of pixels in the source image.\nccltype specifies the connected components labeling algorithm to use, currently\nBKE @cite Allegretti2019 is supported, see the #ConnectedComponentsAlgorithmsTypes\nfor details. Note that labels in the output are not required to be sequential.\n\n**Note**: A sample program demonstrating Connected Components Labeling in CUDA can be found at\\n\nopencv_contrib_source_code/modules/cudaimgproc/samples/connected_components.cpp\n\nPython prototype (for reference only):\n```python3\nconnectedComponentsWithAlgorithm(image, connectivity, ltype, ccltype[, labels]) -> labels\n```","ref":"Evision.CUDA.html#connectedComponentsWithAlgorithm/5"},{"type":"function","title":"Evision.CUDA.convertSpatialMoments/1","doc":"","ref":"Evision.CUDA.html#convertSpatialMoments/1"},{"type":"function","title":"Evision.CUDA.convertSpatialMoments/3","doc":"Converts the spatial image moments returned from cuda::spatialMoments to cv::Moments.\n\n##### Positional Arguments\n- **spatialMoments**: `Evision.Mat`.\n\n  Spatial moments returned from cuda::spatialMoments.\n\n- **order**: `MomentsOrder`.\n\n  Order used when calculating image moments with cuda::spatialMoments.\n\n- **momentsType**: `integer()`.\n\n  Precision used when calculating image moments with cuda::spatialMoments.\n\n##### Return\n- **retval**: `Moments`\n\n@returns cv::Moments.\n@sa cuda::spatialMoments, cuda::moments, cuda::convertSpatialMoments, cuda::numMoments, cuda::MomentsOrder\n\nPython prototype (for reference only):\n```python3\nconvertSpatialMoments(spatialMoments, order, momentsType) -> retval\n```","ref":"Evision.CUDA.html#convertSpatialMoments/3"},{"type":"function","title":"Evision.CUDA.copyMakeBorder/1","doc":"","ref":"Evision.CUDA.html#copyMakeBorder/1"},{"type":"function","title":"Evision.CUDA.copyMakeBorder/6","doc":"#### Variant 1:\nForms a border around an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. CV_8UC1 , CV_8UC4 , CV_32SC1 , and CV_32FC1 types are supported.\n\n- **top**: `integer()`.\n\n  Number of top pixels\n\n- **bottom**: `integer()`.\n\n  Number of bottom pixels\n\n- **left**: `integer()`.\n\n  Number of left pixels\n\n- **right**: `integer()`.\n\n  Number of pixels in each direction from the source image rectangle to extrapolate.\n  For example: top=1, bottom=1, left=1, right=1 mean that 1 pixel-wide border needs to be built.\n\n- **borderType**: `integer()`.\n\n  Border type. See borderInterpolate for details. BORDER_REFLECT101 ,\n  BORDER_REPLICATE , BORDER_CONSTANT , BORDER_REFLECT and BORDER_WRAP are supported for now.\n\n##### Keyword Arguments\n- **value**: `Evision.scalar()`.\n\n  Border value.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image with the same type as src. The size is\n  Size(src.cols+left+right, src.rows+top+bottom) .\n\nPython prototype (for reference only):\n```python3\ncopyMakeBorder(src, top, bottom, left, right, borderType[, dst[, value[, stream]]]) -> dst\n```\n#### Variant 2:\nForms a border around an image.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. CV_8UC1 , CV_8UC4 , CV_32SC1 , and CV_32FC1 types are supported.\n\n- **top**: `integer()`.\n\n  Number of top pixels\n\n- **bottom**: `integer()`.\n\n  Number of bottom pixels\n\n- **left**: `integer()`.\n\n  Number of left pixels\n\n- **right**: `integer()`.\n\n  Number of pixels in each direction from the source image rectangle to extrapolate.\n  For example: top=1, bottom=1, left=1, right=1 mean that 1 pixel-wide border needs to be built.\n\n- **borderType**: `integer()`.\n\n  Border type. See borderInterpolate for details. BORDER_REFLECT101 ,\n  BORDER_REPLICATE , BORDER_CONSTANT , BORDER_REFLECT and BORDER_WRAP are supported for now.\n\n##### Keyword Arguments\n- **value**: `Evision.scalar()`.\n\n  Border value.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image with the same type as src. The size is\n  Size(src.cols+left+right, src.rows+top+bottom) .\n\nPython prototype (for reference only):\n```python3\ncopyMakeBorder(src, top, bottom, left, right, borderType[, dst[, value[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#copyMakeBorder/6"},{"type":"function","title":"Evision.CUDA.copyMakeBorder/7","doc":"#### Variant 1:\nForms a border around an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. CV_8UC1 , CV_8UC4 , CV_32SC1 , and CV_32FC1 types are supported.\n\n- **top**: `integer()`.\n\n  Number of top pixels\n\n- **bottom**: `integer()`.\n\n  Number of bottom pixels\n\n- **left**: `integer()`.\n\n  Number of left pixels\n\n- **right**: `integer()`.\n\n  Number of pixels in each direction from the source image rectangle to extrapolate.\n  For example: top=1, bottom=1, left=1, right=1 mean that 1 pixel-wide border needs to be built.\n\n- **borderType**: `integer()`.\n\n  Border type. See borderInterpolate for details. BORDER_REFLECT101 ,\n  BORDER_REPLICATE , BORDER_CONSTANT , BORDER_REFLECT and BORDER_WRAP are supported for now.\n\n##### Keyword Arguments\n- **value**: `Evision.scalar()`.\n\n  Border value.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image with the same type as src. The size is\n  Size(src.cols+left+right, src.rows+top+bottom) .\n\nPython prototype (for reference only):\n```python3\ncopyMakeBorder(src, top, bottom, left, right, borderType[, dst[, value[, stream]]]) -> dst\n```\n#### Variant 2:\nForms a border around an image.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. CV_8UC1 , CV_8UC4 , CV_32SC1 , and CV_32FC1 types are supported.\n\n- **top**: `integer()`.\n\n  Number of top pixels\n\n- **bottom**: `integer()`.\n\n  Number of bottom pixels\n\n- **left**: `integer()`.\n\n  Number of left pixels\n\n- **right**: `integer()`.\n\n  Number of pixels in each direction from the source image rectangle to extrapolate.\n  For example: top=1, bottom=1, left=1, right=1 mean that 1 pixel-wide border needs to be built.\n\n- **borderType**: `integer()`.\n\n  Border type. See borderInterpolate for details. BORDER_REFLECT101 ,\n  BORDER_REPLICATE , BORDER_CONSTANT , BORDER_REFLECT and BORDER_WRAP are supported for now.\n\n##### Keyword Arguments\n- **value**: `Evision.scalar()`.\n\n  Border value.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image with the same type as src. The size is\n  Size(src.cols+left+right, src.rows+top+bottom) .\n\nPython prototype (for reference only):\n```python3\ncopyMakeBorder(src, top, bottom, left, right, borderType[, dst[, value[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#copyMakeBorder/7"},{"type":"function","title":"Evision.CUDA.countNonZero/1","doc":"#### Variant 1:\ncountNonZero\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncountNonZero(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\ncountNonZero\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncountNonZero(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#countNonZero/1"},{"type":"function","title":"Evision.CUDA.countNonZero/2","doc":"#### Variant 1:\ncountNonZero\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncountNonZero(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\ncountNonZero\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncountNonZero(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#countNonZero/2"},{"type":"function","title":"Evision.CUDA.createBackgroundSubtractorMOG2/0","doc":"Creates MOG2 Background Subtractor\n##### Keyword Arguments\n- **history**: `integer()`.\n\n  Length of the history.\n\n- **varThreshold**: `double`.\n\n  Threshold on the squared Mahalanobis distance between the pixel and the model\n  to decide whether a pixel is well described by the background model. This parameter does not\n  affect the background update.\n\n- **detectShadows**: `bool`.\n\n  If true, the algorithm will detect shadows and mark them. It decreases the\n  speed a bit, so if you do not need this feature, set the parameter to false.\n\n##### Return\n- **retval**: `Evision.CUDA.BackgroundSubtractorMOG2.t()`\n\nPython prototype (for reference only):\n```python3\ncreateBackgroundSubtractorMOG2([, history[, varThreshold[, detectShadows]]]) -> retval\n```","ref":"Evision.CUDA.html#createBackgroundSubtractorMOG2/0"},{"type":"function","title":"Evision.CUDA.createBackgroundSubtractorMOG2/1","doc":"Creates MOG2 Background Subtractor\n##### Keyword Arguments\n- **history**: `integer()`.\n\n  Length of the history.\n\n- **varThreshold**: `double`.\n\n  Threshold on the squared Mahalanobis distance between the pixel and the model\n  to decide whether a pixel is well described by the background model. This parameter does not\n  affect the background update.\n\n- **detectShadows**: `bool`.\n\n  If true, the algorithm will detect shadows and mark them. It decreases the\n  speed a bit, so if you do not need this feature, set the parameter to false.\n\n##### Return\n- **retval**: `Evision.CUDA.BackgroundSubtractorMOG2.t()`\n\nPython prototype (for reference only):\n```python3\ncreateBackgroundSubtractorMOG2([, history[, varThreshold[, detectShadows]]]) -> retval\n```","ref":"Evision.CUDA.html#createBackgroundSubtractorMOG2/1"},{"type":"function","title":"Evision.CUDA.createBackgroundSubtractorMOG/0","doc":"Creates mixture-of-gaussian background subtractor\n##### Keyword Arguments\n- **history**: `integer()`.\n\n  Length of the history.\n\n- **nmixtures**: `integer()`.\n\n  Number of Gaussian mixtures.\n\n- **backgroundRatio**: `double`.\n\n  Background ratio.\n\n- **noiseSigma**: `double`.\n\n  Noise strength (standard deviation of the brightness or each color channel). 0\n  means some automatic value.\n\n##### Return\n- **retval**: `Evision.CUDA.BackgroundSubtractorMOG.t()`\n\nPython prototype (for reference only):\n```python3\ncreateBackgroundSubtractorMOG([, history[, nmixtures[, backgroundRatio[, noiseSigma]]]]) -> retval\n```","ref":"Evision.CUDA.html#createBackgroundSubtractorMOG/0"},{"type":"function","title":"Evision.CUDA.createBackgroundSubtractorMOG/1","doc":"Creates mixture-of-gaussian background subtractor\n##### Keyword Arguments\n- **history**: `integer()`.\n\n  Length of the history.\n\n- **nmixtures**: `integer()`.\n\n  Number of Gaussian mixtures.\n\n- **backgroundRatio**: `double`.\n\n  Background ratio.\n\n- **noiseSigma**: `double`.\n\n  Noise strength (standard deviation of the brightness or each color channel). 0\n  means some automatic value.\n\n##### Return\n- **retval**: `Evision.CUDA.BackgroundSubtractorMOG.t()`\n\nPython prototype (for reference only):\n```python3\ncreateBackgroundSubtractorMOG([, history[, nmixtures[, backgroundRatio[, noiseSigma]]]]) -> retval\n```","ref":"Evision.CUDA.html#createBackgroundSubtractorMOG/1"},{"type":"function","title":"Evision.CUDA.createBoxFilter/1","doc":"","ref":"Evision.CUDA.html#createBoxFilter/1"},{"type":"function","title":"Evision.CUDA.createBoxFilter/3","doc":"Creates a normalized 2D box filter.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input image type. Only CV_8UC1, CV_8UC4 and CV_32FC1 are supported for now.\n\n- **dstType**: `integer()`.\n\n  Output image type. Only the same type as src is supported for now.\n\n- **ksize**: `Size`.\n\n  Kernel size.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor point. The default value Point(-1, -1) means that the anchor is at the kernel\n  center.\n\n- **borderMode**: `integer()`.\n\n  Pixel extrapolation method. For details, see borderInterpolate .\n\n- **borderVal**: `Evision.scalar()`.\n\n  Default border value.\n\n##### Return\n- **retval**: `Filter`\n\n@sa boxFilter\n\nPython prototype (for reference only):\n```python3\ncreateBoxFilter(srcType, dstType, ksize[, anchor[, borderMode[, borderVal]]]) -> retval\n```","ref":"Evision.CUDA.html#createBoxFilter/3"},{"type":"function","title":"Evision.CUDA.createBoxFilter/4","doc":"Creates a normalized 2D box filter.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input image type. Only CV_8UC1, CV_8UC4 and CV_32FC1 are supported for now.\n\n- **dstType**: `integer()`.\n\n  Output image type. Only the same type as src is supported for now.\n\n- **ksize**: `Size`.\n\n  Kernel size.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor point. The default value Point(-1, -1) means that the anchor is at the kernel\n  center.\n\n- **borderMode**: `integer()`.\n\n  Pixel extrapolation method. For details, see borderInterpolate .\n\n- **borderVal**: `Evision.scalar()`.\n\n  Default border value.\n\n##### Return\n- **retval**: `Filter`\n\n@sa boxFilter\n\nPython prototype (for reference only):\n```python3\ncreateBoxFilter(srcType, dstType, ksize[, anchor[, borderMode[, borderVal]]]) -> retval\n```","ref":"Evision.CUDA.html#createBoxFilter/4"},{"type":"function","title":"Evision.CUDA.createBoxMaxFilter/1","doc":"","ref":"Evision.CUDA.html#createBoxMaxFilter/1"},{"type":"function","title":"Evision.CUDA.createBoxMaxFilter/2","doc":"Creates the maximum filter.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input/output image type. Only CV_8UC1 and CV_8UC4 are supported.\n\n- **ksize**: `Size`.\n\n  Kernel size.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor point. The default value (-1) means that the anchor is at the kernel center.\n\n- **borderMode**: `integer()`.\n\n  Pixel extrapolation method. For details, see borderInterpolate .\n\n- **borderVal**: `Evision.scalar()`.\n\n  Default border value.\n\n##### Return\n- **retval**: `Filter`\n\nPython prototype (for reference only):\n```python3\ncreateBoxMaxFilter(srcType, ksize[, anchor[, borderMode[, borderVal]]]) -> retval\n```","ref":"Evision.CUDA.html#createBoxMaxFilter/2"},{"type":"function","title":"Evision.CUDA.createBoxMaxFilter/3","doc":"Creates the maximum filter.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input/output image type. Only CV_8UC1 and CV_8UC4 are supported.\n\n- **ksize**: `Size`.\n\n  Kernel size.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor point. The default value (-1) means that the anchor is at the kernel center.\n\n- **borderMode**: `integer()`.\n\n  Pixel extrapolation method. For details, see borderInterpolate .\n\n- **borderVal**: `Evision.scalar()`.\n\n  Default border value.\n\n##### Return\n- **retval**: `Filter`\n\nPython prototype (for reference only):\n```python3\ncreateBoxMaxFilter(srcType, ksize[, anchor[, borderMode[, borderVal]]]) -> retval\n```","ref":"Evision.CUDA.html#createBoxMaxFilter/3"},{"type":"function","title":"Evision.CUDA.createBoxMinFilter/1","doc":"","ref":"Evision.CUDA.html#createBoxMinFilter/1"},{"type":"function","title":"Evision.CUDA.createBoxMinFilter/2","doc":"Creates the minimum filter.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input/output image type. Only CV_8UC1 and CV_8UC4 are supported.\n\n- **ksize**: `Size`.\n\n  Kernel size.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor point. The default value (-1) means that the anchor is at the kernel center.\n\n- **borderMode**: `integer()`.\n\n  Pixel extrapolation method. For details, see borderInterpolate .\n\n- **borderVal**: `Evision.scalar()`.\n\n  Default border value.\n\n##### Return\n- **retval**: `Filter`\n\nPython prototype (for reference only):\n```python3\ncreateBoxMinFilter(srcType, ksize[, anchor[, borderMode[, borderVal]]]) -> retval\n```","ref":"Evision.CUDA.html#createBoxMinFilter/2"},{"type":"function","title":"Evision.CUDA.createBoxMinFilter/3","doc":"Creates the minimum filter.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input/output image type. Only CV_8UC1 and CV_8UC4 are supported.\n\n- **ksize**: `Size`.\n\n  Kernel size.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor point. The default value (-1) means that the anchor is at the kernel center.\n\n- **borderMode**: `integer()`.\n\n  Pixel extrapolation method. For details, see borderInterpolate .\n\n- **borderVal**: `Evision.scalar()`.\n\n  Default border value.\n\n##### Return\n- **retval**: `Filter`\n\nPython prototype (for reference only):\n```python3\ncreateBoxMinFilter(srcType, ksize[, anchor[, borderMode[, borderVal]]]) -> retval\n```","ref":"Evision.CUDA.html#createBoxMinFilter/3"},{"type":"function","title":"Evision.CUDA.createCannyEdgeDetector/1","doc":"","ref":"Evision.CUDA.html#createCannyEdgeDetector/1"},{"type":"function","title":"Evision.CUDA.createCannyEdgeDetector/2","doc":"Creates implementation for cuda::CannyEdgeDetector .\n\n##### Positional Arguments\n- **low_thresh**: `double`.\n\n  First threshold for the hysteresis procedure.\n\n- **high_thresh**: `double`.\n\n  Second threshold for the hysteresis procedure.\n\n##### Keyword Arguments\n- **apperture_size**: `integer()`.\n\n  Aperture size for the Sobel operator.\n\n- **l2gradient**: `bool`.\n\n  Flag indicating whether a more accurate \\f$L_2\\f$ norm\n  \\f$=\\sqrt{(dI/dx)^2 + (dI/dy)^2}\\f$ should be used to compute the image gradient magnitude (\n  L2gradient=true ), or a faster default \\f$L_1\\f$ norm \\f$=|dI/dx|+|dI/dy|\\f$ is enough ( L2gradient=false\n  ).\n\n##### Return\n- **retval**: `CannyEdgeDetector`\n\nPython prototype (for reference only):\n```python3\ncreateCannyEdgeDetector(low_thresh, high_thresh[, apperture_size[, L2gradient]]) -> retval\n```","ref":"Evision.CUDA.html#createCannyEdgeDetector/2"},{"type":"function","title":"Evision.CUDA.createCannyEdgeDetector/3","doc":"Creates implementation for cuda::CannyEdgeDetector .\n\n##### Positional Arguments\n- **low_thresh**: `double`.\n\n  First threshold for the hysteresis procedure.\n\n- **high_thresh**: `double`.\n\n  Second threshold for the hysteresis procedure.\n\n##### Keyword Arguments\n- **apperture_size**: `integer()`.\n\n  Aperture size for the Sobel operator.\n\n- **l2gradient**: `bool`.\n\n  Flag indicating whether a more accurate \\f$L_2\\f$ norm\n  \\f$=\\sqrt{(dI/dx)^2 + (dI/dy)^2}\\f$ should be used to compute the image gradient magnitude (\n  L2gradient=true ), or a faster default \\f$L_1\\f$ norm \\f$=|dI/dx|+|dI/dy|\\f$ is enough ( L2gradient=false\n  ).\n\n##### Return\n- **retval**: `CannyEdgeDetector`\n\nPython prototype (for reference only):\n```python3\ncreateCannyEdgeDetector(low_thresh, high_thresh[, apperture_size[, L2gradient]]) -> retval\n```","ref":"Evision.CUDA.html#createCannyEdgeDetector/3"},{"type":"function","title":"Evision.CUDA.createCLAHE/0","doc":"Creates implementation for cuda::CLAHE .\n##### Keyword Arguments\n- **clipLimit**: `double`.\n\n  Threshold for contrast limiting.\n\n- **tileGridSize**: `Size`.\n\n  Size of grid for histogram equalization. Input image will be divided into\n  equally sized rectangular tiles. tileGridSize defines the number of tiles in row and column.\n\n##### Return\n- **retval**: `Evision.CUDA.CLAHE.t()`\n\nPython prototype (for reference only):\n```python3\ncreateCLAHE([, clipLimit[, tileGridSize]]) -> retval\n```","ref":"Evision.CUDA.html#createCLAHE/0"},{"type":"function","title":"Evision.CUDA.createCLAHE/1","doc":"Creates implementation for cuda::CLAHE .\n##### Keyword Arguments\n- **clipLimit**: `double`.\n\n  Threshold for contrast limiting.\n\n- **tileGridSize**: `Size`.\n\n  Size of grid for histogram equalization. Input image will be divided into\n  equally sized rectangular tiles. tileGridSize defines the number of tiles in row and column.\n\n##### Return\n- **retval**: `Evision.CUDA.CLAHE.t()`\n\nPython prototype (for reference only):\n```python3\ncreateCLAHE([, clipLimit[, tileGridSize]]) -> retval\n```","ref":"Evision.CUDA.html#createCLAHE/1"},{"type":"function","title":"Evision.CUDA.createColumnSumFilter/1","doc":"","ref":"Evision.CUDA.html#createColumnSumFilter/1"},{"type":"function","title":"Evision.CUDA.createColumnSumFilter/3","doc":"Creates a vertical 1D box filter.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input image type. Only CV_8UC1 type is supported for now.\n\n- **dstType**: `integer()`.\n\n  Output image type. Only CV_32FC1 type is supported for now.\n\n- **ksize**: `integer()`.\n\n  Kernel size.\n\n##### Keyword Arguments\n- **anchor**: `integer()`.\n\n  Anchor point. The default value (-1) means that the anchor is at the kernel center.\n\n- **borderMode**: `integer()`.\n\n  Pixel extrapolation method. For details, see borderInterpolate .\n\n- **borderVal**: `Evision.scalar()`.\n\n  Default border value.\n\n##### Return\n- **retval**: `Filter`\n\nPython prototype (for reference only):\n```python3\ncreateColumnSumFilter(srcType, dstType, ksize[, anchor[, borderMode[, borderVal]]]) -> retval\n```","ref":"Evision.CUDA.html#createColumnSumFilter/3"},{"type":"function","title":"Evision.CUDA.createColumnSumFilter/4","doc":"Creates a vertical 1D box filter.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input image type. Only CV_8UC1 type is supported for now.\n\n- **dstType**: `integer()`.\n\n  Output image type. Only CV_32FC1 type is supported for now.\n\n- **ksize**: `integer()`.\n\n  Kernel size.\n\n##### Keyword Arguments\n- **anchor**: `integer()`.\n\n  Anchor point. The default value (-1) means that the anchor is at the kernel center.\n\n- **borderMode**: `integer()`.\n\n  Pixel extrapolation method. For details, see borderInterpolate .\n\n- **borderVal**: `Evision.scalar()`.\n\n  Default border value.\n\n##### Return\n- **retval**: `Filter`\n\nPython prototype (for reference only):\n```python3\ncreateColumnSumFilter(srcType, dstType, ksize[, anchor[, borderMode[, borderVal]]]) -> retval\n```","ref":"Evision.CUDA.html#createColumnSumFilter/4"},{"type":"function","title":"Evision.CUDA.createContinuous/1","doc":"","ref":"Evision.CUDA.html#createContinuous/1"},{"type":"function","title":"Evision.CUDA.createContinuous/3","doc":"Creates a continuous matrix.\n\n##### Positional Arguments\n- **rows**: `integer()`.\n\n  Row count.\n\n- **cols**: `integer()`.\n\n  Column count.\n\n- **type**: `integer()`.\n\n  Type of the matrix.\n\n##### Return\n- **arr**: `Evision.Mat.t()`.\n\n  Destination matrix. This parameter changes only if it has a proper type and area (\n  \\f$\\texttt{rows} \\times \\texttt{cols}\\f$ ).\n\nMatrix is called continuous if its elements are stored continuously, that is, without gaps at the\nend of each row.\n\nPython prototype (for reference only):\n```python3\ncreateContinuous(rows, cols, type[, arr]) -> arr\n```","ref":"Evision.CUDA.html#createContinuous/3"},{"type":"function","title":"Evision.CUDA.createContinuous/4","doc":"Creates a continuous matrix.\n\n##### Positional Arguments\n- **rows**: `integer()`.\n\n  Row count.\n\n- **cols**: `integer()`.\n\n  Column count.\n\n- **type**: `integer()`.\n\n  Type of the matrix.\n\n##### Return\n- **arr**: `Evision.Mat.t()`.\n\n  Destination matrix. This parameter changes only if it has a proper type and area (\n  \\f$\\texttt{rows} \\times \\texttt{cols}\\f$ ).\n\nMatrix is called continuous if its elements are stored continuously, that is, without gaps at the\nend of each row.\n\nPython prototype (for reference only):\n```python3\ncreateContinuous(rows, cols, type[, arr]) -> arr\n```","ref":"Evision.CUDA.html#createContinuous/4"},{"type":"function","title":"Evision.CUDA.createConvolution/0","doc":"Creates implementation for cuda::Convolution .\n##### Keyword Arguments\n- **user_block_size**: `Size`.\n\n  Block size. If you leave default value Size(0,0) then automatic\n  estimation of block size will be used (which is optimized for speed). By varying user_block_size\n  you can reduce memory requirements at the cost of speed.\n\n##### Return\n- **retval**: `Convolution`\n\nPython prototype (for reference only):\n```python3\ncreateConvolution([, user_block_size]) -> retval\n```","ref":"Evision.CUDA.html#createConvolution/0"},{"type":"function","title":"Evision.CUDA.createConvolution/1","doc":"Creates implementation for cuda::Convolution .\n##### Keyword Arguments\n- **user_block_size**: `Size`.\n\n  Block size. If you leave default value Size(0,0) then automatic\n  estimation of block size will be used (which is optimized for speed). By varying user_block_size\n  you can reduce memory requirements at the cost of speed.\n\n##### Return\n- **retval**: `Convolution`\n\nPython prototype (for reference only):\n```python3\ncreateConvolution([, user_block_size]) -> retval\n```","ref":"Evision.CUDA.html#createConvolution/1"},{"type":"function","title":"Evision.CUDA.createDerivFilter/1","doc":"","ref":"Evision.CUDA.html#createDerivFilter/1"},{"type":"function","title":"Evision.CUDA.createDerivFilter/5","doc":"Creates a generalized Deriv operator.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Source image type.\n\n- **dstType**: `integer()`.\n\n  Destination array type.\n\n- **dx**: `integer()`.\n\n  Derivative order in respect of x.\n\n- **dy**: `integer()`.\n\n  Derivative order in respect of y.\n\n- **ksize**: `integer()`.\n\n  Aperture size. See getDerivKernels for details.\n\n##### Keyword Arguments\n- **normalize**: `bool`.\n\n  Flag indicating whether to normalize (scale down) the filter coefficients or not.\n  See getDerivKernels for details.\n\n- **scale**: `double`.\n\n  Optional scale factor for the computed derivative values. By default, no scaling is\n  applied. For details, see getDerivKernels .\n\n- **rowBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the vertical direction. For details, see\n  borderInterpolate.\n\n- **columnBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the horizontal direction.\n\n##### Return\n- **retval**: `Filter`\n\nPython prototype (for reference only):\n```python3\ncreateDerivFilter(srcType, dstType, dx, dy, ksize[, normalize[, scale[, rowBorderMode[, columnBorderMode]]]]) -> retval\n```","ref":"Evision.CUDA.html#createDerivFilter/5"},{"type":"function","title":"Evision.CUDA.createDerivFilter/6","doc":"Creates a generalized Deriv operator.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Source image type.\n\n- **dstType**: `integer()`.\n\n  Destination array type.\n\n- **dx**: `integer()`.\n\n  Derivative order in respect of x.\n\n- **dy**: `integer()`.\n\n  Derivative order in respect of y.\n\n- **ksize**: `integer()`.\n\n  Aperture size. See getDerivKernels for details.\n\n##### Keyword Arguments\n- **normalize**: `bool`.\n\n  Flag indicating whether to normalize (scale down) the filter coefficients or not.\n  See getDerivKernels for details.\n\n- **scale**: `double`.\n\n  Optional scale factor for the computed derivative values. By default, no scaling is\n  applied. For details, see getDerivKernels .\n\n- **rowBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the vertical direction. For details, see\n  borderInterpolate.\n\n- **columnBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the horizontal direction.\n\n##### Return\n- **retval**: `Filter`\n\nPython prototype (for reference only):\n```python3\ncreateDerivFilter(srcType, dstType, dx, dy, ksize[, normalize[, scale[, rowBorderMode[, columnBorderMode]]]]) -> retval\n```","ref":"Evision.CUDA.html#createDerivFilter/6"},{"type":"function","title":"Evision.CUDA.createDFT/1","doc":"","ref":"Evision.CUDA.html#createDFT/1"},{"type":"function","title":"Evision.CUDA.createDFT/2","doc":"Creates implementation for cuda::DFT.\n\n##### Positional Arguments\n- **dft_size**: `Size`.\n\n  The image size.\n\n- **flags**: `integer()`.\n\n  Optional flags:\n  - **DFT_ROWS** transforms each individual row of the source matrix.\n  - **DFT_SCALE** scales the result: divide it by the number of elements in the transform\n    (obtained from dft_size ).\n  - **DFT_INVERSE** inverts DFT. Use for complex-complex cases (real-complex and complex-real\n    cases are always forward and inverse, respectively).\n  - **DFT_COMPLEX_INPUT** Specifies that inputs will be complex with 2 channels.\n  - **DFT_REAL_OUTPUT** specifies the output as real. The source matrix is the result of\n    real-complex transform, so the destination matrix must be real.\n\n##### Return\n- **retval**: `DFT`\n\nPython prototype (for reference only):\n```python3\ncreateDFT(dft_size, flags) -> retval\n```","ref":"Evision.CUDA.html#createDFT/2"},{"type":"function","title":"Evision.CUDA.createDisparityBilateralFilter/0","doc":"Creates DisparityBilateralFilter object.\n##### Keyword Arguments\n- **ndisp**: `integer()`.\n\n  Number of disparities.\n\n- **radius**: `integer()`.\n\n  Filter radius.\n\n- **iters**: `integer()`.\n\n  Number of iterations.\n\n##### Return\n- **retval**: `Evision.CUDA.DisparityBilateralFilter.t()`\n\nPython prototype (for reference only):\n```python3\ncreateDisparityBilateralFilter([, ndisp[, radius[, iters]]]) -> retval\n```","ref":"Evision.CUDA.html#createDisparityBilateralFilter/0"},{"type":"function","title":"Evision.CUDA.createDisparityBilateralFilter/1","doc":"Creates DisparityBilateralFilter object.\n##### Keyword Arguments\n- **ndisp**: `integer()`.\n\n  Number of disparities.\n\n- **radius**: `integer()`.\n\n  Filter radius.\n\n- **iters**: `integer()`.\n\n  Number of iterations.\n\n##### Return\n- **retval**: `Evision.CUDA.DisparityBilateralFilter.t()`\n\nPython prototype (for reference only):\n```python3\ncreateDisparityBilateralFilter([, ndisp[, radius[, iters]]]) -> retval\n```","ref":"Evision.CUDA.html#createDisparityBilateralFilter/1"},{"type":"function","title":"Evision.CUDA.createGaussianFilter/1","doc":"","ref":"Evision.CUDA.html#createGaussianFilter/1"},{"type":"function","title":"Evision.CUDA.createGaussianFilter/4","doc":"Creates a Gaussian filter.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Source image type.\n\n- **dstType**: `integer()`.\n\n  Destination array type.\n\n- **ksize**: `Size`.\n\n  Aperture size. See getGaussianKernel for details.\n\n- **sigma1**: `double`.\n\n  Gaussian sigma in the horizontal direction. See getGaussianKernel for details.\n\n##### Keyword Arguments\n- **sigma2**: `double`.\n\n  Gaussian sigma in the vertical direction. If 0, then\n  \\f$\\texttt{sigma2}\\leftarrow\\texttt{sigma1}\\f$ .\n\n- **rowBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the vertical direction. For details, see\n  borderInterpolate.\n\n- **columnBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the horizontal direction.\n\n##### Return\n- **retval**: `Filter`\n\n@sa GaussianBlur\n\nPython prototype (for reference only):\n```python3\ncreateGaussianFilter(srcType, dstType, ksize, sigma1[, sigma2[, rowBorderMode[, columnBorderMode]]]) -> retval\n```","ref":"Evision.CUDA.html#createGaussianFilter/4"},{"type":"function","title":"Evision.CUDA.createGaussianFilter/5","doc":"Creates a Gaussian filter.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Source image type.\n\n- **dstType**: `integer()`.\n\n  Destination array type.\n\n- **ksize**: `Size`.\n\n  Aperture size. See getGaussianKernel for details.\n\n- **sigma1**: `double`.\n\n  Gaussian sigma in the horizontal direction. See getGaussianKernel for details.\n\n##### Keyword Arguments\n- **sigma2**: `double`.\n\n  Gaussian sigma in the vertical direction. If 0, then\n  \\f$\\texttt{sigma2}\\leftarrow\\texttt{sigma1}\\f$ .\n\n- **rowBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the vertical direction. For details, see\n  borderInterpolate.\n\n- **columnBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the horizontal direction.\n\n##### Return\n- **retval**: `Filter`\n\n@sa GaussianBlur\n\nPython prototype (for reference only):\n```python3\ncreateGaussianFilter(srcType, dstType, ksize, sigma1[, sigma2[, rowBorderMode[, columnBorderMode]]]) -> retval\n```","ref":"Evision.CUDA.html#createGaussianFilter/5"},{"type":"function","title":"Evision.CUDA.createGeneralizedHoughBallard/0","doc":"Creates implementation for generalized hough transform from @cite Ballard1981 .\n##### Return\n- **retval**: `Evision.GeneralizedHoughBallard.t()`\n\nPython prototype (for reference only):\n```python3\ncreateGeneralizedHoughBallard() -> retval\n```","ref":"Evision.CUDA.html#createGeneralizedHoughBallard/0"},{"type":"function","title":"Evision.CUDA.createGeneralizedHoughBallard/1","doc":"","ref":"Evision.CUDA.html#createGeneralizedHoughBallard/1"},{"type":"function","title":"Evision.CUDA.createGeneralizedHoughGuil/0","doc":"Creates implementation for generalized hough transform from @cite Guil1999 .\n##### Return\n- **retval**: `Evision.GeneralizedHoughGuil.t()`\n\nPython prototype (for reference only):\n```python3\ncreateGeneralizedHoughGuil() -> retval\n```","ref":"Evision.CUDA.html#createGeneralizedHoughGuil/0"},{"type":"function","title":"Evision.CUDA.createGeneralizedHoughGuil/1","doc":"","ref":"Evision.CUDA.html#createGeneralizedHoughGuil/1"},{"type":"function","title":"Evision.CUDA.createGoodFeaturesToTrackDetector/1","doc":"Creates implementation for cuda::CornersDetector .\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input source type. Only CV_8UC1 and CV_32FC1 are supported for now.\n\n##### Keyword Arguments\n- **maxCorners**: `integer()`.\n\n  Maximum number of corners to return. If there are more corners than are found,\n  the strongest of them is returned.\n\n- **qualityLevel**: `double`.\n\n  Parameter characterizing the minimal accepted quality of image corners. The\n  parameter value is multiplied by the best corner quality measure, which is the minimal eigenvalue\n  (see cornerMinEigenVal ) or the Harris function response (see cornerHarris ). The corners with the\n  quality measure less than the product are rejected. For example, if the best corner has the\n  quality measure = 1500, and the qualityLevel=0.01 , then all the corners with the quality measure\n  less than 15 are rejected.\n\n- **minDistance**: `double`.\n\n  Minimum possible Euclidean distance between the returned corners.\n\n- **blockSize**: `integer()`.\n\n  Size of an average block for computing a derivative covariation matrix over each\n  pixel neighborhood. See cornerEigenValsAndVecs .\n\n- **useHarrisDetector**: `bool`.\n\n  Parameter indicating whether to use a Harris detector (see cornerHarris)\n  or cornerMinEigenVal.\n\n- **harrisK**: `double`.\n\n  Free parameter of the Harris detector.\n\n##### Return\n- **retval**: `CornersDetector`\n\nPython prototype (for reference only):\n```python3\ncreateGoodFeaturesToTrackDetector(srcType[, maxCorners[, qualityLevel[, minDistance[, blockSize[, useHarrisDetector[, harrisK]]]]]]) -> retval\n```","ref":"Evision.CUDA.html#createGoodFeaturesToTrackDetector/1"},{"type":"function","title":"Evision.CUDA.createGoodFeaturesToTrackDetector/2","doc":"Creates implementation for cuda::CornersDetector .\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input source type. Only CV_8UC1 and CV_32FC1 are supported for now.\n\n##### Keyword Arguments\n- **maxCorners**: `integer()`.\n\n  Maximum number of corners to return. If there are more corners than are found,\n  the strongest of them is returned.\n\n- **qualityLevel**: `double`.\n\n  Parameter characterizing the minimal accepted quality of image corners. The\n  parameter value is multiplied by the best corner quality measure, which is the minimal eigenvalue\n  (see cornerMinEigenVal ) or the Harris function response (see cornerHarris ). The corners with the\n  quality measure less than the product are rejected. For example, if the best corner has the\n  quality measure = 1500, and the qualityLevel=0.01 , then all the corners with the quality measure\n  less than 15 are rejected.\n\n- **minDistance**: `double`.\n\n  Minimum possible Euclidean distance between the returned corners.\n\n- **blockSize**: `integer()`.\n\n  Size of an average block for computing a derivative covariation matrix over each\n  pixel neighborhood. See cornerEigenValsAndVecs .\n\n- **useHarrisDetector**: `bool`.\n\n  Parameter indicating whether to use a Harris detector (see cornerHarris)\n  or cornerMinEigenVal.\n\n- **harrisK**: `double`.\n\n  Free parameter of the Harris detector.\n\n##### Return\n- **retval**: `CornersDetector`\n\nPython prototype (for reference only):\n```python3\ncreateGoodFeaturesToTrackDetector(srcType[, maxCorners[, qualityLevel[, minDistance[, blockSize[, useHarrisDetector[, harrisK]]]]]]) -> retval\n```","ref":"Evision.CUDA.html#createGoodFeaturesToTrackDetector/2"},{"type":"function","title":"Evision.CUDA.createGpuMatFromCudaMemory/1","doc":"","ref":"Evision.CUDA.html#createGpuMatFromCudaMemory/1"},{"type":"function","title":"Evision.CUDA.createGpuMatFromCudaMemory/3","doc":"createGpuMatFromCudaMemory\n\n##### Positional Arguments\n- **size**: `Size`.\n\n  2D array size: Size(cols, rows). In the Size() constructor, the number of rows and the number of columns go in the reverse order.\n\n- **type**: `integer()`.\n\n  Type of the matrix.\n\n- **cudaMemoryAddress**: `size_t`.\n\n  Address of the allocated GPU memory on the device. This does not allocate matrix data. Instead, it just initializes the matrix header that points to the specified \\a cudaMemoryAddress, which means that no data is copied. This operation is very efficient and can be used to process external data using OpenCV functions. The external data is not automatically deallocated, so you should take care of it.\n\n##### Keyword Arguments\n- **step**: `size_t`.\n\n  Number of bytes each matrix row occupies. The value should include the padding bytes at the end of each row, if any. If the parameter is missing (set to Mat::AUTO_STEP ), no padding is assumed and the actual step is calculated as cols*elemSize(). See GpuMat::elemSize.\n\n##### Return\n- **retval**: `Evision.CUDA.GpuMat.t()`\n\nHas overloading in C++\n\n**Note**: Overload for generation of bindings only, not exported or intended for use internally from C++.\n\nPython prototype (for reference only):\n```python3\ncreateGpuMatFromCudaMemory(size, type, cudaMemoryAddress[, step]) -> retval\n```","ref":"Evision.CUDA.html#createGpuMatFromCudaMemory/3"},{"type":"function","title":"Evision.CUDA.createGpuMatFromCudaMemory/4","doc":"#### Variant 1:\nBindings overload to create a GpuMat from existing GPU memory.\n\n##### Positional Arguments\n- **rows**: `integer()`.\n\n  Row count.\n\n- **cols**: `integer()`.\n\n  Column count.\n\n- **type**: `integer()`.\n\n  Type of the matrix.\n\n- **cudaMemoryAddress**: `size_t`.\n\n  Address of the allocated GPU memory on the device. This does not allocate matrix data. Instead, it just initializes the matrix header that points to the specified \\a cudaMemoryAddress, which means that no data is copied. This operation is very efficient and can be used to process external data using OpenCV functions. The external data is not automatically deallocated, so you should take care of it.\n\n##### Keyword Arguments\n- **step**: `size_t`.\n\n  Number of bytes each matrix row occupies. The value should include the padding bytes at the end of each row, if any. If the parameter is missing (set to Mat::AUTO_STEP ), no padding is assumed and the actual step is calculated as cols*elemSize(). See GpuMat::elemSize.\n\n##### Return\n- **retval**: `Evision.CUDA.GpuMat.t()`\n\n**Note**: Overload for generation of bindings only, not exported or intended for use internally from C++.\n\nPython prototype (for reference only):\n```python3\ncreateGpuMatFromCudaMemory(rows, cols, type, cudaMemoryAddress[, step]) -> retval\n```\n#### Variant 2:\ncreateGpuMatFromCudaMemory\n\n##### Positional Arguments\n- **size**: `Size`.\n\n  2D array size: Size(cols, rows). In the Size() constructor, the number of rows and the number of columns go in the reverse order.\n\n- **type**: `integer()`.\n\n  Type of the matrix.\n\n- **cudaMemoryAddress**: `size_t`.\n\n  Address of the allocated GPU memory on the device. This does not allocate matrix data. Instead, it just initializes the matrix header that points to the specified \\a cudaMemoryAddress, which means that no data is copied. This operation is very efficient and can be used to process external data using OpenCV functions. The external data is not automatically deallocated, so you should take care of it.\n\n##### Keyword Arguments\n- **step**: `size_t`.\n\n  Number of bytes each matrix row occupies. The value should include the padding bytes at the end of each row, if any. If the parameter is missing (set to Mat::AUTO_STEP ), no padding is assumed and the actual step is calculated as cols*elemSize(). See GpuMat::elemSize.\n\n##### Return\n- **retval**: `Evision.CUDA.GpuMat.t()`\n\nHas overloading in C++\n\n**Note**: Overload for generation of bindings only, not exported or intended for use internally from C++.\n\nPython prototype (for reference only):\n```python3\ncreateGpuMatFromCudaMemory(size, type, cudaMemoryAddress[, step]) -> retval\n```","ref":"Evision.CUDA.html#createGpuMatFromCudaMemory/4"},{"type":"function","title":"Evision.CUDA.createGpuMatFromCudaMemory/5","doc":"Bindings overload to create a GpuMat from existing GPU memory.\n\n##### Positional Arguments\n- **rows**: `integer()`.\n\n  Row count.\n\n- **cols**: `integer()`.\n\n  Column count.\n\n- **type**: `integer()`.\n\n  Type of the matrix.\n\n- **cudaMemoryAddress**: `size_t`.\n\n  Address of the allocated GPU memory on the device. This does not allocate matrix data. Instead, it just initializes the matrix header that points to the specified \\a cudaMemoryAddress, which means that no data is copied. This operation is very efficient and can be used to process external data using OpenCV functions. The external data is not automatically deallocated, so you should take care of it.\n\n##### Keyword Arguments\n- **step**: `size_t`.\n\n  Number of bytes each matrix row occupies. The value should include the padding bytes at the end of each row, if any. If the parameter is missing (set to Mat::AUTO_STEP ), no padding is assumed and the actual step is calculated as cols*elemSize(). See GpuMat::elemSize.\n\n##### Return\n- **retval**: `Evision.CUDA.GpuMat.t()`\n\n**Note**: Overload for generation of bindings only, not exported or intended for use internally from C++.\n\nPython prototype (for reference only):\n```python3\ncreateGpuMatFromCudaMemory(rows, cols, type, cudaMemoryAddress[, step]) -> retval\n```","ref":"Evision.CUDA.html#createGpuMatFromCudaMemory/5"},{"type":"function","title":"Evision.CUDA.createHarrisCorner/1","doc":"","ref":"Evision.CUDA.html#createHarrisCorner/1"},{"type":"function","title":"Evision.CUDA.createHarrisCorner/4","doc":"Creates implementation for Harris cornerness criteria.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input source type. Only CV_8UC1 and CV_32FC1 are supported for now.\n\n- **blockSize**: `integer()`.\n\n  Neighborhood size.\n\n- **ksize**: `integer()`.\n\n  Aperture parameter for the Sobel operator.\n\n- **k**: `double`.\n\n  Harris detector free parameter.\n\n##### Keyword Arguments\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method. Only BORDER_REFLECT101 and BORDER_REPLICATE are\n  supported for now.\n\n##### Return\n- **retval**: `CornernessCriteria`\n\n@sa cornerHarris\n\nPython prototype (for reference only):\n```python3\ncreateHarrisCorner(srcType, blockSize, ksize, k[, borderType]) -> retval\n```","ref":"Evision.CUDA.html#createHarrisCorner/4"},{"type":"function","title":"Evision.CUDA.createHarrisCorner/5","doc":"Creates implementation for Harris cornerness criteria.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input source type. Only CV_8UC1 and CV_32FC1 are supported for now.\n\n- **blockSize**: `integer()`.\n\n  Neighborhood size.\n\n- **ksize**: `integer()`.\n\n  Aperture parameter for the Sobel operator.\n\n- **k**: `double`.\n\n  Harris detector free parameter.\n\n##### Keyword Arguments\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method. Only BORDER_REFLECT101 and BORDER_REPLICATE are\n  supported for now.\n\n##### Return\n- **retval**: `CornernessCriteria`\n\n@sa cornerHarris\n\nPython prototype (for reference only):\n```python3\ncreateHarrisCorner(srcType, blockSize, ksize, k[, borderType]) -> retval\n```","ref":"Evision.CUDA.html#createHarrisCorner/5"},{"type":"function","title":"Evision.CUDA.createHoughCirclesDetector/1","doc":"","ref":"Evision.CUDA.html#createHoughCirclesDetector/1"},{"type":"function","title":"Evision.CUDA.createHoughCirclesDetector/6","doc":"Creates implementation for cuda::HoughCirclesDetector .\n\n##### Positional Arguments\n- **dp**: `float`.\n\n  Inverse ratio of the accumulator resolution to the image resolution. For example, if\n  dp=1 , the accumulator has the same resolution as the input image. If dp=2 , the accumulator has\n  half as big width and height.\n\n- **minDist**: `float`.\n\n  Minimum distance between the centers of the detected circles. If the parameter is\n  too small, multiple neighbor circles may be falsely detected in addition to a true one. If it is\n  too large, some circles may be missed.\n\n- **cannyThreshold**: `integer()`.\n\n  The higher threshold of the two passed to Canny edge detector (the lower one\n  is twice smaller).\n\n- **votesThreshold**: `integer()`.\n\n  The accumulator threshold for the circle centers at the detection stage. The\n  smaller it is, the more false circles may be detected.\n\n- **minRadius**: `integer()`.\n\n  Minimum circle radius.\n\n- **maxRadius**: `integer()`.\n\n  Maximum circle radius.\n\n##### Keyword Arguments\n- **maxCircles**: `integer()`.\n\n  Maximum number of output circles.\n\n##### Return\n- **retval**: `HoughCirclesDetector`\n\nPython prototype (for reference only):\n```python3\ncreateHoughCirclesDetector(dp, minDist, cannyThreshold, votesThreshold, minRadius, maxRadius[, maxCircles]) -> retval\n```","ref":"Evision.CUDA.html#createHoughCirclesDetector/6"},{"type":"function","title":"Evision.CUDA.createHoughCirclesDetector/7","doc":"Creates implementation for cuda::HoughCirclesDetector .\n\n##### Positional Arguments\n- **dp**: `float`.\n\n  Inverse ratio of the accumulator resolution to the image resolution. For example, if\n  dp=1 , the accumulator has the same resolution as the input image. If dp=2 , the accumulator has\n  half as big width and height.\n\n- **minDist**: `float`.\n\n  Minimum distance between the centers of the detected circles. If the parameter is\n  too small, multiple neighbor circles may be falsely detected in addition to a true one. If it is\n  too large, some circles may be missed.\n\n- **cannyThreshold**: `integer()`.\n\n  The higher threshold of the two passed to Canny edge detector (the lower one\n  is twice smaller).\n\n- **votesThreshold**: `integer()`.\n\n  The accumulator threshold for the circle centers at the detection stage. The\n  smaller it is, the more false circles may be detected.\n\n- **minRadius**: `integer()`.\n\n  Minimum circle radius.\n\n- **maxRadius**: `integer()`.\n\n  Maximum circle radius.\n\n##### Keyword Arguments\n- **maxCircles**: `integer()`.\n\n  Maximum number of output circles.\n\n##### Return\n- **retval**: `HoughCirclesDetector`\n\nPython prototype (for reference only):\n```python3\ncreateHoughCirclesDetector(dp, minDist, cannyThreshold, votesThreshold, minRadius, maxRadius[, maxCircles]) -> retval\n```","ref":"Evision.CUDA.html#createHoughCirclesDetector/7"},{"type":"function","title":"Evision.CUDA.createHoughLinesDetector/1","doc":"","ref":"Evision.CUDA.html#createHoughLinesDetector/1"},{"type":"function","title":"Evision.CUDA.createHoughLinesDetector/3","doc":"Creates implementation for cuda::HoughLinesDetector .\n\n##### Positional Arguments\n- **rho**: `float`.\n\n  Distance resolution of the accumulator in pixels.\n\n- **theta**: `float`.\n\n  Angle resolution of the accumulator in radians.\n\n- **threshold**: `integer()`.\n\n  Accumulator threshold parameter. Only those lines are returned that get enough\n  votes ( \\f$>\\texttt{threshold}\\f$ ).\n\n##### Keyword Arguments\n- **doSort**: `bool`.\n\n  Performs lines sort by votes.\n\n- **maxLines**: `integer()`.\n\n  Maximum number of output lines.\n\n##### Return\n- **retval**: `HoughLinesDetector`\n\nPython prototype (for reference only):\n```python3\ncreateHoughLinesDetector(rho, theta, threshold[, doSort[, maxLines]]) -> retval\n```","ref":"Evision.CUDA.html#createHoughLinesDetector/3"},{"type":"function","title":"Evision.CUDA.createHoughLinesDetector/4","doc":"Creates implementation for cuda::HoughLinesDetector .\n\n##### Positional Arguments\n- **rho**: `float`.\n\n  Distance resolution of the accumulator in pixels.\n\n- **theta**: `float`.\n\n  Angle resolution of the accumulator in radians.\n\n- **threshold**: `integer()`.\n\n  Accumulator threshold parameter. Only those lines are returned that get enough\n  votes ( \\f$>\\texttt{threshold}\\f$ ).\n\n##### Keyword Arguments\n- **doSort**: `bool`.\n\n  Performs lines sort by votes.\n\n- **maxLines**: `integer()`.\n\n  Maximum number of output lines.\n\n##### Return\n- **retval**: `HoughLinesDetector`\n\nPython prototype (for reference only):\n```python3\ncreateHoughLinesDetector(rho, theta, threshold[, doSort[, maxLines]]) -> retval\n```","ref":"Evision.CUDA.html#createHoughLinesDetector/4"},{"type":"function","title":"Evision.CUDA.createHoughSegmentDetector/1","doc":"","ref":"Evision.CUDA.html#createHoughSegmentDetector/1"},{"type":"function","title":"Evision.CUDA.createHoughSegmentDetector/4","doc":"Creates implementation for cuda::HoughSegmentDetector .\n\n##### Positional Arguments\n- **rho**: `float`.\n\n  Distance resolution of the accumulator in pixels.\n\n- **theta**: `float`.\n\n  Angle resolution of the accumulator in radians.\n\n- **minLineLength**: `integer()`.\n\n  Minimum line length. Line segments shorter than that are rejected.\n\n- **maxLineGap**: `integer()`.\n\n  Maximum allowed gap between points on the same line to link them.\n\n##### Keyword Arguments\n- **maxLines**: `integer()`.\n\n  Maximum number of output lines.\n\n- **threshold**: `integer()`.\n\n  %Accumulator threshold parameter. Only those lines are returned that get enough\n  votes ( \\f$>\\texttt{threshold}\\f$ ).\n\n##### Return\n- **retval**: `HoughSegmentDetector`\n\nPython prototype (for reference only):\n```python3\ncreateHoughSegmentDetector(rho, theta, minLineLength, maxLineGap[, maxLines[, threshold]]) -> retval\n```","ref":"Evision.CUDA.html#createHoughSegmentDetector/4"},{"type":"function","title":"Evision.CUDA.createHoughSegmentDetector/5","doc":"Creates implementation for cuda::HoughSegmentDetector .\n\n##### Positional Arguments\n- **rho**: `float`.\n\n  Distance resolution of the accumulator in pixels.\n\n- **theta**: `float`.\n\n  Angle resolution of the accumulator in radians.\n\n- **minLineLength**: `integer()`.\n\n  Minimum line length. Line segments shorter than that are rejected.\n\n- **maxLineGap**: `integer()`.\n\n  Maximum allowed gap between points on the same line to link them.\n\n##### Keyword Arguments\n- **maxLines**: `integer()`.\n\n  Maximum number of output lines.\n\n- **threshold**: `integer()`.\n\n  %Accumulator threshold parameter. Only those lines are returned that get enough\n  votes ( \\f$>\\texttt{threshold}\\f$ ).\n\n##### Return\n- **retval**: `HoughSegmentDetector`\n\nPython prototype (for reference only):\n```python3\ncreateHoughSegmentDetector(rho, theta, minLineLength, maxLineGap[, maxLines[, threshold]]) -> retval\n```","ref":"Evision.CUDA.html#createHoughSegmentDetector/5"},{"type":"function","title":"Evision.CUDA.createLaplacianFilter/1","doc":"","ref":"Evision.CUDA.html#createLaplacianFilter/1"},{"type":"function","title":"Evision.CUDA.createLaplacianFilter/2","doc":"Creates a Laplacian operator.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input image type. Supports CV_8U , CV_16U and CV_32F one and four channel image.\n\n- **dstType**: `integer()`.\n\n  Output image type. Only the same type as src is supported for now.\n\n##### Keyword Arguments\n- **ksize**: `integer()`.\n\n  Aperture size used to compute the second-derivative filters (see getDerivKernels). It\n  must be positive and odd. Only ksize = 1 and ksize = 3 are supported.\n\n- **scale**: `double`.\n\n  Optional scale factor for the computed Laplacian values. By default, no scaling is\n  applied (see getDerivKernels ).\n\n- **borderMode**: `integer()`.\n\n  Pixel extrapolation method. For details, see borderInterpolate .\n\n- **borderVal**: `Evision.scalar()`.\n\n  Default border value.\n\n##### Return\n- **retval**: `Filter`\n\n@sa Laplacian\n\nPython prototype (for reference only):\n```python3\ncreateLaplacianFilter(srcType, dstType[, ksize[, scale[, borderMode[, borderVal]]]]) -> retval\n```","ref":"Evision.CUDA.html#createLaplacianFilter/2"},{"type":"function","title":"Evision.CUDA.createLaplacianFilter/3","doc":"Creates a Laplacian operator.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input image type. Supports CV_8U , CV_16U and CV_32F one and four channel image.\n\n- **dstType**: `integer()`.\n\n  Output image type. Only the same type as src is supported for now.\n\n##### Keyword Arguments\n- **ksize**: `integer()`.\n\n  Aperture size used to compute the second-derivative filters (see getDerivKernels). It\n  must be positive and odd. Only ksize = 1 and ksize = 3 are supported.\n\n- **scale**: `double`.\n\n  Optional scale factor for the computed Laplacian values. By default, no scaling is\n  applied (see getDerivKernels ).\n\n- **borderMode**: `integer()`.\n\n  Pixel extrapolation method. For details, see borderInterpolate .\n\n- **borderVal**: `Evision.scalar()`.\n\n  Default border value.\n\n##### Return\n- **retval**: `Filter`\n\n@sa Laplacian\n\nPython prototype (for reference only):\n```python3\ncreateLaplacianFilter(srcType, dstType[, ksize[, scale[, borderMode[, borderVal]]]]) -> retval\n```","ref":"Evision.CUDA.html#createLaplacianFilter/3"},{"type":"function","title":"Evision.CUDA.createLinearFilter/1","doc":"","ref":"Evision.CUDA.html#createLinearFilter/1"},{"type":"function","title":"Evision.CUDA.createLinearFilter/3","doc":"#### Variant 1:\nCreates a non-separable linear 2D filter.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input image type. Supports CV_8U , CV_16U and CV_32F one and four channel image.\n\n- **dstType**: `integer()`.\n\n  Output image type. Only the same type as src is supported for now.\n\n- **kernel**: `Evision.Mat`.\n\n  2D array of filter coefficients.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor point. The default value Point(-1, -1) means that the anchor is at the kernel\n  center.\n\n- **borderMode**: `integer()`.\n\n  Pixel extrapolation method. For details, see borderInterpolate .\n\n- **borderVal**: `Evision.scalar()`.\n\n  Default border value.\n\n##### Return\n- **retval**: `Filter`\n\n@sa filter2D\n\nPython prototype (for reference only):\n```python3\ncreateLinearFilter(srcType, dstType, kernel[, anchor[, borderMode[, borderVal]]]) -> retval\n```\n#### Variant 2:\nCreates a non-separable linear 2D filter.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input image type. Supports CV_8U , CV_16U and CV_32F one and four channel image.\n\n- **dstType**: `integer()`.\n\n  Output image type. Only the same type as src is supported for now.\n\n- **kernel**: `Evision.CUDA.GpuMat.t()`.\n\n  2D array of filter coefficients.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor point. The default value Point(-1, -1) means that the anchor is at the kernel\n  center.\n\n- **borderMode**: `integer()`.\n\n  Pixel extrapolation method. For details, see borderInterpolate .\n\n- **borderVal**: `Evision.scalar()`.\n\n  Default border value.\n\n##### Return\n- **retval**: `Filter`\n\n@sa filter2D\n\nPython prototype (for reference only):\n```python3\ncreateLinearFilter(srcType, dstType, kernel[, anchor[, borderMode[, borderVal]]]) -> retval\n```","ref":"Evision.CUDA.html#createLinearFilter/3"},{"type":"function","title":"Evision.CUDA.createLinearFilter/4","doc":"#### Variant 1:\nCreates a non-separable linear 2D filter.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input image type. Supports CV_8U , CV_16U and CV_32F one and four channel image.\n\n- **dstType**: `integer()`.\n\n  Output image type. Only the same type as src is supported for now.\n\n- **kernel**: `Evision.Mat`.\n\n  2D array of filter coefficients.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor point. The default value Point(-1, -1) means that the anchor is at the kernel\n  center.\n\n- **borderMode**: `integer()`.\n\n  Pixel extrapolation method. For details, see borderInterpolate .\n\n- **borderVal**: `Evision.scalar()`.\n\n  Default border value.\n\n##### Return\n- **retval**: `Filter`\n\n@sa filter2D\n\nPython prototype (for reference only):\n```python3\ncreateLinearFilter(srcType, dstType, kernel[, anchor[, borderMode[, borderVal]]]) -> retval\n```\n#### Variant 2:\nCreates a non-separable linear 2D filter.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input image type. Supports CV_8U , CV_16U and CV_32F one and four channel image.\n\n- **dstType**: `integer()`.\n\n  Output image type. Only the same type as src is supported for now.\n\n- **kernel**: `Evision.CUDA.GpuMat.t()`.\n\n  2D array of filter coefficients.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor point. The default value Point(-1, -1) means that the anchor is at the kernel\n  center.\n\n- **borderMode**: `integer()`.\n\n  Pixel extrapolation method. For details, see borderInterpolate .\n\n- **borderVal**: `Evision.scalar()`.\n\n  Default border value.\n\n##### Return\n- **retval**: `Filter`\n\n@sa filter2D\n\nPython prototype (for reference only):\n```python3\ncreateLinearFilter(srcType, dstType, kernel[, anchor[, borderMode[, borderVal]]]) -> retval\n```","ref":"Evision.CUDA.html#createLinearFilter/4"},{"type":"function","title":"Evision.CUDA.createLookUpTable/1","doc":"#### Variant 1:\nCreates implementation for cuda::LookUpTable .\n\n##### Positional Arguments\n- **lut**: `Evision.Mat`.\n\n  Look-up table of 256 elements. It is a continuous CV_8U matrix.\n\n##### Return\n- **retval**: `LookUpTable`\n\nPython prototype (for reference only):\n```python3\ncreateLookUpTable(lut) -> retval\n```\n#### Variant 2:\nCreates implementation for cuda::LookUpTable .\n\n##### Positional Arguments\n- **lut**: `Evision.CUDA.GpuMat.t()`.\n\n  Look-up table of 256 elements. It is a continuous CV_8U matrix.\n\n##### Return\n- **retval**: `LookUpTable`\n\nPython prototype (for reference only):\n```python3\ncreateLookUpTable(lut) -> retval\n```","ref":"Evision.CUDA.html#createLookUpTable/1"},{"type":"function","title":"Evision.CUDA.createMedianFilter/1","doc":"","ref":"Evision.CUDA.html#createMedianFilter/1"},{"type":"function","title":"Evision.CUDA.createMedianFilter/2","doc":"Performs median filtering for each point of the source image.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  type of of source image. Only CV_8UC1 images are supported for now.\n\n- **windowSize**: `integer()`.\n\n  Size of the kernerl used for the filtering. Uses a (windowSize x windowSize) filter.\n\n##### Keyword Arguments\n- **partition**: `integer()`.\n\n  Specifies the parallel granularity of the workload. This parameter should be used GPU experts when optimizing performance.\n\n##### Return\n- **retval**: `Filter`\n\nOutputs an image that has been filtered using a median-filtering formulation.\nDetails on this algorithm can be found in:\nGreen, O., 2017. \"Efficient scalable median filtering using histogram-based operations\",\nIEEE Transactions on Image Processing, 27(5), pp.2217-2228.\n\nPython prototype (for reference only):\n```python3\ncreateMedianFilter(srcType, windowSize[, partition]) -> retval\n```","ref":"Evision.CUDA.html#createMedianFilter/2"},{"type":"function","title":"Evision.CUDA.createMedianFilter/3","doc":"Performs median filtering for each point of the source image.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  type of of source image. Only CV_8UC1 images are supported for now.\n\n- **windowSize**: `integer()`.\n\n  Size of the kernerl used for the filtering. Uses a (windowSize x windowSize) filter.\n\n##### Keyword Arguments\n- **partition**: `integer()`.\n\n  Specifies the parallel granularity of the workload. This parameter should be used GPU experts when optimizing performance.\n\n##### Return\n- **retval**: `Filter`\n\nOutputs an image that has been filtered using a median-filtering formulation.\nDetails on this algorithm can be found in:\nGreen, O., 2017. \"Efficient scalable median filtering using histogram-based operations\",\nIEEE Transactions on Image Processing, 27(5), pp.2217-2228.\n\nPython prototype (for reference only):\n```python3\ncreateMedianFilter(srcType, windowSize[, partition]) -> retval\n```","ref":"Evision.CUDA.html#createMedianFilter/3"},{"type":"function","title":"Evision.CUDA.createMinEigenValCorner/1","doc":"","ref":"Evision.CUDA.html#createMinEigenValCorner/1"},{"type":"function","title":"Evision.CUDA.createMinEigenValCorner/3","doc":"Creates implementation for the minimum eigen value of a 2x2 derivative covariation matrix (the\ncornerness criteria).\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input source type. Only CV_8UC1 and CV_32FC1 are supported for now.\n\n- **blockSize**: `integer()`.\n\n  Neighborhood size.\n\n- **ksize**: `integer()`.\n\n  Aperture parameter for the Sobel operator.\n\n##### Keyword Arguments\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method. Only BORDER_REFLECT101 and BORDER_REPLICATE are\n  supported for now.\n\n##### Return\n- **retval**: `CornernessCriteria`\n\n@sa cornerMinEigenVal\n\nPython prototype (for reference only):\n```python3\ncreateMinEigenValCorner(srcType, blockSize, ksize[, borderType]) -> retval\n```","ref":"Evision.CUDA.html#createMinEigenValCorner/3"},{"type":"function","title":"Evision.CUDA.createMinEigenValCorner/4","doc":"Creates implementation for the minimum eigen value of a 2x2 derivative covariation matrix (the\ncornerness criteria).\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input source type. Only CV_8UC1 and CV_32FC1 are supported for now.\n\n- **blockSize**: `integer()`.\n\n  Neighborhood size.\n\n- **ksize**: `integer()`.\n\n  Aperture parameter for the Sobel operator.\n\n##### Keyword Arguments\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method. Only BORDER_REFLECT101 and BORDER_REPLICATE are\n  supported for now.\n\n##### Return\n- **retval**: `CornernessCriteria`\n\n@sa cornerMinEigenVal\n\nPython prototype (for reference only):\n```python3\ncreateMinEigenValCorner(srcType, blockSize, ksize[, borderType]) -> retval\n```","ref":"Evision.CUDA.html#createMinEigenValCorner/4"},{"type":"function","title":"Evision.CUDA.createMorphologyFilter/1","doc":"","ref":"Evision.CUDA.html#createMorphologyFilter/1"},{"type":"function","title":"Evision.CUDA.createMorphologyFilter/3","doc":"#### Variant 1:\nCreates a 2D morphological filter.\n\n##### Positional Arguments\n- **op**: `integer()`.\n\n  Type of morphological operation. The following types are possible:\n  - **MORPH_ERODE** erode\n  - **MORPH_DILATE** dilate\n  - **MORPH_OPEN** opening\n  - **MORPH_CLOSE** closing\n  - **MORPH_GRADIENT** morphological gradient\n  - **MORPH_TOPHAT** \"top hat\"\n  - **MORPH_BLACKHAT** \"black hat\"\n\n- **srcType**: `integer()`.\n\n  Input/output image type. Only CV_8UC1, CV_8UC4, CV_32FC1 and CV_32FC4 are supported.\n\n- **kernel**: `Evision.Mat`.\n\n  2D 8-bit structuring element for the morphological operation.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor position within the structuring element. Negative values mean that the anchor\n  is at the center.\n\n- **iterations**: `integer()`.\n\n  Number of times erosion and dilation to be applied.\n\n##### Return\n- **retval**: `Filter`\n\n@sa morphologyEx\n\nPython prototype (for reference only):\n```python3\ncreateMorphologyFilter(op, srcType, kernel[, anchor[, iterations]]) -> retval\n```\n#### Variant 2:\nCreates a 2D morphological filter.\n\n##### Positional Arguments\n- **op**: `integer()`.\n\n  Type of morphological operation. The following types are possible:\n  - **MORPH_ERODE** erode\n  - **MORPH_DILATE** dilate\n  - **MORPH_OPEN** opening\n  - **MORPH_CLOSE** closing\n  - **MORPH_GRADIENT** morphological gradient\n  - **MORPH_TOPHAT** \"top hat\"\n  - **MORPH_BLACKHAT** \"black hat\"\n\n- **srcType**: `integer()`.\n\n  Input/output image type. Only CV_8UC1, CV_8UC4, CV_32FC1 and CV_32FC4 are supported.\n\n- **kernel**: `Evision.CUDA.GpuMat.t()`.\n\n  2D 8-bit structuring element for the morphological operation.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor position within the structuring element. Negative values mean that the anchor\n  is at the center.\n\n- **iterations**: `integer()`.\n\n  Number of times erosion and dilation to be applied.\n\n##### Return\n- **retval**: `Filter`\n\n@sa morphologyEx\n\nPython prototype (for reference only):\n```python3\ncreateMorphologyFilter(op, srcType, kernel[, anchor[, iterations]]) -> retval\n```","ref":"Evision.CUDA.html#createMorphologyFilter/3"},{"type":"function","title":"Evision.CUDA.createMorphologyFilter/4","doc":"#### Variant 1:\nCreates a 2D morphological filter.\n\n##### Positional Arguments\n- **op**: `integer()`.\n\n  Type of morphological operation. The following types are possible:\n  - **MORPH_ERODE** erode\n  - **MORPH_DILATE** dilate\n  - **MORPH_OPEN** opening\n  - **MORPH_CLOSE** closing\n  - **MORPH_GRADIENT** morphological gradient\n  - **MORPH_TOPHAT** \"top hat\"\n  - **MORPH_BLACKHAT** \"black hat\"\n\n- **srcType**: `integer()`.\n\n  Input/output image type. Only CV_8UC1, CV_8UC4, CV_32FC1 and CV_32FC4 are supported.\n\n- **kernel**: `Evision.Mat`.\n\n  2D 8-bit structuring element for the morphological operation.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor position within the structuring element. Negative values mean that the anchor\n  is at the center.\n\n- **iterations**: `integer()`.\n\n  Number of times erosion and dilation to be applied.\n\n##### Return\n- **retval**: `Filter`\n\n@sa morphologyEx\n\nPython prototype (for reference only):\n```python3\ncreateMorphologyFilter(op, srcType, kernel[, anchor[, iterations]]) -> retval\n```\n#### Variant 2:\nCreates a 2D morphological filter.\n\n##### Positional Arguments\n- **op**: `integer()`.\n\n  Type of morphological operation. The following types are possible:\n  - **MORPH_ERODE** erode\n  - **MORPH_DILATE** dilate\n  - **MORPH_OPEN** opening\n  - **MORPH_CLOSE** closing\n  - **MORPH_GRADIENT** morphological gradient\n  - **MORPH_TOPHAT** \"top hat\"\n  - **MORPH_BLACKHAT** \"black hat\"\n\n- **srcType**: `integer()`.\n\n  Input/output image type. Only CV_8UC1, CV_8UC4, CV_32FC1 and CV_32FC4 are supported.\n\n- **kernel**: `Evision.CUDA.GpuMat.t()`.\n\n  2D 8-bit structuring element for the morphological operation.\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor position within the structuring element. Negative values mean that the anchor\n  is at the center.\n\n- **iterations**: `integer()`.\n\n  Number of times erosion and dilation to be applied.\n\n##### Return\n- **retval**: `Filter`\n\n@sa morphologyEx\n\nPython prototype (for reference only):\n```python3\ncreateMorphologyFilter(op, srcType, kernel[, anchor[, iterations]]) -> retval\n```","ref":"Evision.CUDA.html#createMorphologyFilter/4"},{"type":"function","title":"Evision.CUDA.createRowSumFilter/1","doc":"","ref":"Evision.CUDA.html#createRowSumFilter/1"},{"type":"function","title":"Evision.CUDA.createRowSumFilter/3","doc":"Creates a horizontal 1D box filter.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input image type. Only CV_8UC1 type is supported for now.\n\n- **dstType**: `integer()`.\n\n  Output image type. Only CV_32FC1 type is supported for now.\n\n- **ksize**: `integer()`.\n\n  Kernel size.\n\n##### Keyword Arguments\n- **anchor**: `integer()`.\n\n  Anchor point. The default value (-1) means that the anchor is at the kernel center.\n\n- **borderMode**: `integer()`.\n\n  Pixel extrapolation method. For details, see borderInterpolate .\n\n- **borderVal**: `Evision.scalar()`.\n\n  Default border value.\n\n##### Return\n- **retval**: `Filter`\n\nPython prototype (for reference only):\n```python3\ncreateRowSumFilter(srcType, dstType, ksize[, anchor[, borderMode[, borderVal]]]) -> retval\n```","ref":"Evision.CUDA.html#createRowSumFilter/3"},{"type":"function","title":"Evision.CUDA.createRowSumFilter/4","doc":"Creates a horizontal 1D box filter.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input image type. Only CV_8UC1 type is supported for now.\n\n- **dstType**: `integer()`.\n\n  Output image type. Only CV_32FC1 type is supported for now.\n\n- **ksize**: `integer()`.\n\n  Kernel size.\n\n##### Keyword Arguments\n- **anchor**: `integer()`.\n\n  Anchor point. The default value (-1) means that the anchor is at the kernel center.\n\n- **borderMode**: `integer()`.\n\n  Pixel extrapolation method. For details, see borderInterpolate .\n\n- **borderVal**: `Evision.scalar()`.\n\n  Default border value.\n\n##### Return\n- **retval**: `Filter`\n\nPython prototype (for reference only):\n```python3\ncreateRowSumFilter(srcType, dstType, ksize[, anchor[, borderMode[, borderVal]]]) -> retval\n```","ref":"Evision.CUDA.html#createRowSumFilter/4"},{"type":"function","title":"Evision.CUDA.createScharrFilter/1","doc":"","ref":"Evision.CUDA.html#createScharrFilter/1"},{"type":"function","title":"Evision.CUDA.createScharrFilter/4","doc":"Creates a vertical or horizontal Scharr operator.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Source image type.\n\n- **dstType**: `integer()`.\n\n  Destination array type.\n\n- **dx**: `integer()`.\n\n  Order of the derivative x.\n\n- **dy**: `integer()`.\n\n  Order of the derivative y.\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Optional scale factor for the computed derivative values. By default, no scaling is\n  applied. See getDerivKernels for details.\n\n- **rowBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the vertical direction. For details, see\n  borderInterpolate.\n\n- **columnBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the horizontal direction.\n\n##### Return\n- **retval**: `Filter`\n\n@sa Scharr\n\nPython prototype (for reference only):\n```python3\ncreateScharrFilter(srcType, dstType, dx, dy[, scale[, rowBorderMode[, columnBorderMode]]]) -> retval\n```","ref":"Evision.CUDA.html#createScharrFilter/4"},{"type":"function","title":"Evision.CUDA.createScharrFilter/5","doc":"Creates a vertical or horizontal Scharr operator.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Source image type.\n\n- **dstType**: `integer()`.\n\n  Destination array type.\n\n- **dx**: `integer()`.\n\n  Order of the derivative x.\n\n- **dy**: `integer()`.\n\n  Order of the derivative y.\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Optional scale factor for the computed derivative values. By default, no scaling is\n  applied. See getDerivKernels for details.\n\n- **rowBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the vertical direction. For details, see\n  borderInterpolate.\n\n- **columnBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the horizontal direction.\n\n##### Return\n- **retval**: `Filter`\n\n@sa Scharr\n\nPython prototype (for reference only):\n```python3\ncreateScharrFilter(srcType, dstType, dx, dy[, scale[, rowBorderMode[, columnBorderMode]]]) -> retval\n```","ref":"Evision.CUDA.html#createScharrFilter/5"},{"type":"function","title":"Evision.CUDA.createSeparableLinearFilter/1","doc":"","ref":"Evision.CUDA.html#createSeparableLinearFilter/1"},{"type":"function","title":"Evision.CUDA.createSeparableLinearFilter/4","doc":"#### Variant 1:\nCreates a separable linear filter.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Source array type.\n\n- **dstType**: `integer()`.\n\n  Destination array type.\n\n- **rowKernel**: `Evision.Mat`.\n\n  Horizontal filter coefficients. Support kernels with size \\<= 32 .\n\n- **columnKernel**: `Evision.Mat`.\n\n  Vertical filter coefficients. Support kernels with size \\<= 32 .\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor position within the kernel. Negative values mean that anchor is positioned at\n  the aperture center.\n\n- **rowBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the vertical direction For details, see\n  borderInterpolate.\n\n- **columnBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the horizontal direction.\n\n##### Return\n- **retval**: `Filter`\n\n@sa sepFilter2D\n\nPython prototype (for reference only):\n```python3\ncreateSeparableLinearFilter(srcType, dstType, rowKernel, columnKernel[, anchor[, rowBorderMode[, columnBorderMode]]]) -> retval\n```\n#### Variant 2:\nCreates a separable linear filter.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Source array type.\n\n- **dstType**: `integer()`.\n\n  Destination array type.\n\n- **rowKernel**: `Evision.CUDA.GpuMat.t()`.\n\n  Horizontal filter coefficients. Support kernels with size \\<= 32 .\n\n- **columnKernel**: `Evision.CUDA.GpuMat.t()`.\n\n  Vertical filter coefficients. Support kernels with size \\<= 32 .\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor position within the kernel. Negative values mean that anchor is positioned at\n  the aperture center.\n\n- **rowBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the vertical direction For details, see\n  borderInterpolate.\n\n- **columnBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the horizontal direction.\n\n##### Return\n- **retval**: `Filter`\n\n@sa sepFilter2D\n\nPython prototype (for reference only):\n```python3\ncreateSeparableLinearFilter(srcType, dstType, rowKernel, columnKernel[, anchor[, rowBorderMode[, columnBorderMode]]]) -> retval\n```","ref":"Evision.CUDA.html#createSeparableLinearFilter/4"},{"type":"function","title":"Evision.CUDA.createSeparableLinearFilter/5","doc":"#### Variant 1:\nCreates a separable linear filter.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Source array type.\n\n- **dstType**: `integer()`.\n\n  Destination array type.\n\n- **rowKernel**: `Evision.Mat`.\n\n  Horizontal filter coefficients. Support kernels with size \\<= 32 .\n\n- **columnKernel**: `Evision.Mat`.\n\n  Vertical filter coefficients. Support kernels with size \\<= 32 .\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor position within the kernel. Negative values mean that anchor is positioned at\n  the aperture center.\n\n- **rowBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the vertical direction For details, see\n  borderInterpolate.\n\n- **columnBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the horizontal direction.\n\n##### Return\n- **retval**: `Filter`\n\n@sa sepFilter2D\n\nPython prototype (for reference only):\n```python3\ncreateSeparableLinearFilter(srcType, dstType, rowKernel, columnKernel[, anchor[, rowBorderMode[, columnBorderMode]]]) -> retval\n```\n#### Variant 2:\nCreates a separable linear filter.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Source array type.\n\n- **dstType**: `integer()`.\n\n  Destination array type.\n\n- **rowKernel**: `Evision.CUDA.GpuMat.t()`.\n\n  Horizontal filter coefficients. Support kernels with size \\<= 32 .\n\n- **columnKernel**: `Evision.CUDA.GpuMat.t()`.\n\n  Vertical filter coefficients. Support kernels with size \\<= 32 .\n\n##### Keyword Arguments\n- **anchor**: `Point`.\n\n  Anchor position within the kernel. Negative values mean that anchor is positioned at\n  the aperture center.\n\n- **rowBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the vertical direction For details, see\n  borderInterpolate.\n\n- **columnBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the horizontal direction.\n\n##### Return\n- **retval**: `Filter`\n\n@sa sepFilter2D\n\nPython prototype (for reference only):\n```python3\ncreateSeparableLinearFilter(srcType, dstType, rowKernel, columnKernel[, anchor[, rowBorderMode[, columnBorderMode]]]) -> retval\n```","ref":"Evision.CUDA.html#createSeparableLinearFilter/5"},{"type":"function","title":"Evision.CUDA.createSobelFilter/1","doc":"","ref":"Evision.CUDA.html#createSobelFilter/1"},{"type":"function","title":"Evision.CUDA.createSobelFilter/4","doc":"Creates a Sobel operator.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Source image type.\n\n- **dstType**: `integer()`.\n\n  Destination array type.\n\n- **dx**: `integer()`.\n\n  Derivative order in respect of x.\n\n- **dy**: `integer()`.\n\n  Derivative order in respect of y.\n\n##### Keyword Arguments\n- **ksize**: `integer()`.\n\n  Size of the extended Sobel kernel. Possible values are 1, 3, 5 or 7.\n\n- **scale**: `double`.\n\n  Optional scale factor for the computed derivative values. By default, no scaling is\n  applied. For details, see getDerivKernels .\n\n- **rowBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the vertical direction. For details, see\n  borderInterpolate.\n\n- **columnBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the horizontal direction.\n\n##### Return\n- **retval**: `Filter`\n\n@sa Sobel\n\nPython prototype (for reference only):\n```python3\ncreateSobelFilter(srcType, dstType, dx, dy[, ksize[, scale[, rowBorderMode[, columnBorderMode]]]]) -> retval\n```","ref":"Evision.CUDA.html#createSobelFilter/4"},{"type":"function","title":"Evision.CUDA.createSobelFilter/5","doc":"Creates a Sobel operator.\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Source image type.\n\n- **dstType**: `integer()`.\n\n  Destination array type.\n\n- **dx**: `integer()`.\n\n  Derivative order in respect of x.\n\n- **dy**: `integer()`.\n\n  Derivative order in respect of y.\n\n##### Keyword Arguments\n- **ksize**: `integer()`.\n\n  Size of the extended Sobel kernel. Possible values are 1, 3, 5 or 7.\n\n- **scale**: `double`.\n\n  Optional scale factor for the computed derivative values. By default, no scaling is\n  applied. For details, see getDerivKernels .\n\n- **rowBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the vertical direction. For details, see\n  borderInterpolate.\n\n- **columnBorderMode**: `integer()`.\n\n  Pixel extrapolation method in the horizontal direction.\n\n##### Return\n- **retval**: `Filter`\n\n@sa Sobel\n\nPython prototype (for reference only):\n```python3\ncreateSobelFilter(srcType, dstType, dx, dy[, ksize[, scale[, rowBorderMode[, columnBorderMode]]]]) -> retval\n```","ref":"Evision.CUDA.html#createSobelFilter/5"},{"type":"function","title":"Evision.CUDA.createStereoBeliefPropagation/0","doc":"Creates StereoBeliefPropagation object.\n##### Keyword Arguments\n- **ndisp**: `integer()`.\n\n  Number of disparities.\n\n- **iters**: `integer()`.\n\n  Number of BP iterations on each level.\n\n- **levels**: `integer()`.\n\n  Number of levels.\n\n- **msg_type**: `integer()`.\n\n  Type for messages. CV_16SC1 and CV_32FC1 types are supported.\n\n##### Return\n- **retval**: `Evision.CUDA.StereoBeliefPropagation.t()`\n\nPython prototype (for reference only):\n```python3\ncreateStereoBeliefPropagation([, ndisp[, iters[, levels[, msg_type]]]]) -> retval\n```","ref":"Evision.CUDA.html#createStereoBeliefPropagation/0"},{"type":"function","title":"Evision.CUDA.createStereoBeliefPropagation/1","doc":"Creates StereoBeliefPropagation object.\n##### Keyword Arguments\n- **ndisp**: `integer()`.\n\n  Number of disparities.\n\n- **iters**: `integer()`.\n\n  Number of BP iterations on each level.\n\n- **levels**: `integer()`.\n\n  Number of levels.\n\n- **msg_type**: `integer()`.\n\n  Type for messages. CV_16SC1 and CV_32FC1 types are supported.\n\n##### Return\n- **retval**: `Evision.CUDA.StereoBeliefPropagation.t()`\n\nPython prototype (for reference only):\n```python3\ncreateStereoBeliefPropagation([, ndisp[, iters[, levels[, msg_type]]]]) -> retval\n```","ref":"Evision.CUDA.html#createStereoBeliefPropagation/1"},{"type":"function","title":"Evision.CUDA.createStereoBM/0","doc":"Creates StereoBM object.\n##### Keyword Arguments\n- **numDisparities**: `integer()`.\n\n  the disparity search range. For each pixel algorithm will find the best\n  disparity from 0 (default minimum disparity) to numDisparities. The search range can then be\n  shifted by changing the minimum disparity.\n\n- **blockSize**: `integer()`.\n\n  the linear size of the blocks compared by the algorithm. The size should be odd\n  (as the block is centered at the current pixel). Larger block size implies smoother, though less\n  accurate disparity map. Smaller block size gives more detailed disparity map, but there is higher\n  chance for algorithm to find a wrong correspondence.\n\n##### Return\n- **retval**: `Evision.CUDA.StereoBM.t()`\n\nPython prototype (for reference only):\n```python3\ncreateStereoBM([, numDisparities[, blockSize]]) -> retval\n```","ref":"Evision.CUDA.html#createStereoBM/0"},{"type":"function","title":"Evision.CUDA.createStereoBM/1","doc":"Creates StereoBM object.\n##### Keyword Arguments\n- **numDisparities**: `integer()`.\n\n  the disparity search range. For each pixel algorithm will find the best\n  disparity from 0 (default minimum disparity) to numDisparities. The search range can then be\n  shifted by changing the minimum disparity.\n\n- **blockSize**: `integer()`.\n\n  the linear size of the blocks compared by the algorithm. The size should be odd\n  (as the block is centered at the current pixel). Larger block size implies smoother, though less\n  accurate disparity map. Smaller block size gives more detailed disparity map, but there is higher\n  chance for algorithm to find a wrong correspondence.\n\n##### Return\n- **retval**: `Evision.CUDA.StereoBM.t()`\n\nPython prototype (for reference only):\n```python3\ncreateStereoBM([, numDisparities[, blockSize]]) -> retval\n```","ref":"Evision.CUDA.html#createStereoBM/1"},{"type":"function","title":"Evision.CUDA.createStereoConstantSpaceBP/0","doc":"Creates StereoConstantSpaceBP object.\n##### Keyword Arguments\n- **ndisp**: `integer()`.\n\n  Number of disparities.\n\n- **iters**: `integer()`.\n\n  Number of BP iterations on each level.\n\n- **levels**: `integer()`.\n\n  Number of levels.\n\n- **nr_plane**: `integer()`.\n\n  Number of disparity levels on the first level.\n\n- **msg_type**: `integer()`.\n\n  Type for messages. CV_16SC1 and CV_32FC1 types are supported.\n\n##### Return\n- **retval**: `Evision.CUDA.StereoConstantSpaceBP.t()`\n\nPython prototype (for reference only):\n```python3\ncreateStereoConstantSpaceBP([, ndisp[, iters[, levels[, nr_plane[, msg_type]]]]]) -> retval\n```","ref":"Evision.CUDA.html#createStereoConstantSpaceBP/0"},{"type":"function","title":"Evision.CUDA.createStereoConstantSpaceBP/1","doc":"Creates StereoConstantSpaceBP object.\n##### Keyword Arguments\n- **ndisp**: `integer()`.\n\n  Number of disparities.\n\n- **iters**: `integer()`.\n\n  Number of BP iterations on each level.\n\n- **levels**: `integer()`.\n\n  Number of levels.\n\n- **nr_plane**: `integer()`.\n\n  Number of disparity levels on the first level.\n\n- **msg_type**: `integer()`.\n\n  Type for messages. CV_16SC1 and CV_32FC1 types are supported.\n\n##### Return\n- **retval**: `Evision.CUDA.StereoConstantSpaceBP.t()`\n\nPython prototype (for reference only):\n```python3\ncreateStereoConstantSpaceBP([, ndisp[, iters[, levels[, nr_plane[, msg_type]]]]]) -> retval\n```","ref":"Evision.CUDA.html#createStereoConstantSpaceBP/1"},{"type":"function","title":"Evision.CUDA.createStereoSGM/0","doc":"Creates StereoSGM object.\n##### Keyword Arguments\n- **minDisparity**: `integer()`.\n\n  Minimum possible disparity value. Normally, it is zero but sometimes rectification algorithms can shift images, so this parameter needs to be adjusted accordingly.\n\n- **numDisparities**: `integer()`.\n\n  Maximum disparity minus minimum disparity. The value must be 64, 128 or 256.\n\n- **p1**: `integer()`.\n\n  The first parameter controlling the disparity smoothness.This parameter is used for the case of slanted surfaces (not fronto parallel).\n\n- **p2**: `integer()`.\n\n  The second parameter controlling the disparity smoothness.This parameter is used for \"solving\" the depth discontinuities problem.\n\n- **uniquenessRatio**: `integer()`.\n\n  Margin in percentage by which the best (minimum) computed cost function\n  value should \"win\" the second best value to consider the found match correct. Normally, a value\n  within the 5-15 range is good enough.\n\n- **mode**: `integer()`.\n\n  Set it to StereoSGM::MODE_HH to run the full-scale two-pass dynamic programming algorithm.\n  It will consume O(W\\*H\\*numDisparities) bytes. By default, it is set to StereoSGM::MODE_HH4.\n\n##### Return\n- **retval**: `Evision.CUDA.StereoSGM.t()`\n\nPython prototype (for reference only):\n```python3\ncreateStereoSGM([, minDisparity[, numDisparities[, P1[, P2[, uniquenessRatio[, mode]]]]]]) -> retval\n```","ref":"Evision.CUDA.html#createStereoSGM/0"},{"type":"function","title":"Evision.CUDA.createStereoSGM/1","doc":"Creates StereoSGM object.\n##### Keyword Arguments\n- **minDisparity**: `integer()`.\n\n  Minimum possible disparity value. Normally, it is zero but sometimes rectification algorithms can shift images, so this parameter needs to be adjusted accordingly.\n\n- **numDisparities**: `integer()`.\n\n  Maximum disparity minus minimum disparity. The value must be 64, 128 or 256.\n\n- **p1**: `integer()`.\n\n  The first parameter controlling the disparity smoothness.This parameter is used for the case of slanted surfaces (not fronto parallel).\n\n- **p2**: `integer()`.\n\n  The second parameter controlling the disparity smoothness.This parameter is used for \"solving\" the depth discontinuities problem.\n\n- **uniquenessRatio**: `integer()`.\n\n  Margin in percentage by which the best (minimum) computed cost function\n  value should \"win\" the second best value to consider the found match correct. Normally, a value\n  within the 5-15 range is good enough.\n\n- **mode**: `integer()`.\n\n  Set it to StereoSGM::MODE_HH to run the full-scale two-pass dynamic programming algorithm.\n  It will consume O(W\\*H\\*numDisparities) bytes. By default, it is set to StereoSGM::MODE_HH4.\n\n##### Return\n- **retval**: `Evision.CUDA.StereoSGM.t()`\n\nPython prototype (for reference only):\n```python3\ncreateStereoSGM([, minDisparity[, numDisparities[, P1[, P2[, uniquenessRatio[, mode]]]]]]) -> retval\n```","ref":"Evision.CUDA.html#createStereoSGM/1"},{"type":"function","title":"Evision.CUDA.createTemplateMatching/1","doc":"","ref":"Evision.CUDA.html#createTemplateMatching/1"},{"type":"function","title":"Evision.CUDA.createTemplateMatching/2","doc":"Creates implementation for cuda::TemplateMatching .\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input source type. CV_32F and CV_8U depth images (1..4 channels) are supported\n  for now.\n\n- **method**: `integer()`.\n\n  Specifies the way to compare the template with the image.\n\n##### Keyword Arguments\n- **user_block_size**: `Size`.\n\n  You can use field user_block_size to set specific block size. If you\n  leave its default value Size(0,0) then automatic estimation of block size will be used (which is\n  optimized for speed). By varying user_block_size you can reduce memory requirements at the cost\n  of speed.\n\n##### Return\n- **retval**: `TemplateMatching`\n\nThe following methods are supported for the CV_8U depth images for now:\n- CV_TM_SQDIFF\n- CV_TM_SQDIFF_NORMED\n- CV_TM_CCORR\n- CV_TM_CCORR_NORMED\n- CV_TM_CCOEFF\n- CV_TM_CCOEFF_NORMED\n\nThe following methods are supported for the CV_32F images for now:\n- CV_TM_SQDIFF\n- CV_TM_CCORR\n\n@sa matchTemplate\n\nPython prototype (for reference only):\n```python3\ncreateTemplateMatching(srcType, method[, user_block_size]) -> retval\n```","ref":"Evision.CUDA.html#createTemplateMatching/2"},{"type":"function","title":"Evision.CUDA.createTemplateMatching/3","doc":"Creates implementation for cuda::TemplateMatching .\n\n##### Positional Arguments\n- **srcType**: `integer()`.\n\n  Input source type. CV_32F and CV_8U depth images (1..4 channels) are supported\n  for now.\n\n- **method**: `integer()`.\n\n  Specifies the way to compare the template with the image.\n\n##### Keyword Arguments\n- **user_block_size**: `Size`.\n\n  You can use field user_block_size to set specific block size. If you\n  leave its default value Size(0,0) then automatic estimation of block size will be used (which is\n  optimized for speed). By varying user_block_size you can reduce memory requirements at the cost\n  of speed.\n\n##### Return\n- **retval**: `TemplateMatching`\n\nThe following methods are supported for the CV_8U depth images for now:\n- CV_TM_SQDIFF\n- CV_TM_SQDIFF_NORMED\n- CV_TM_CCORR\n- CV_TM_CCORR_NORMED\n- CV_TM_CCOEFF\n- CV_TM_CCOEFF_NORMED\n\nThe following methods are supported for the CV_32F images for now:\n- CV_TM_SQDIFF\n- CV_TM_CCORR\n\n@sa matchTemplate\n\nPython prototype (for reference only):\n```python3\ncreateTemplateMatching(srcType, method[, user_block_size]) -> retval\n```","ref":"Evision.CUDA.html#createTemplateMatching/3"},{"type":"function","title":"Evision.CUDA.cvtColor/1","doc":"","ref":"Evision.CUDA.html#cvtColor/1"},{"type":"function","title":"Evision.CUDA.cvtColor/2","doc":"#### Variant 1:\nConverts an image from one color space to another.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image with CV_8U , CV_16U , or CV_32F depth and 1, 3, or 4 channels.\n\n- **code**: `integer()`.\n\n  Color space conversion code. For details, see cvtColor .\n\n##### Keyword Arguments\n- **dcn**: `integer()`.\n\n  Number of channels in the destination image. If the parameter is 0, the number of the\n  channels is derived automatically from src and the code .\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image.\n\n3-channel color spaces (like HSV, XYZ, and so on) can be stored in a 4-channel image for better\nperformance.\n@sa cvtColor\n\nPython prototype (for reference only):\n```python3\ncvtColor(src, code[, dst[, dcn[, stream]]]) -> dst\n```\n#### Variant 2:\nConverts an image from one color space to another.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image with CV_8U , CV_16U , or CV_32F depth and 1, 3, or 4 channels.\n\n- **code**: `integer()`.\n\n  Color space conversion code. For details, see cvtColor .\n\n##### Keyword Arguments\n- **dcn**: `integer()`.\n\n  Number of channels in the destination image. If the parameter is 0, the number of the\n  channels is derived automatically from src and the code .\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image.\n\n3-channel color spaces (like HSV, XYZ, and so on) can be stored in a 4-channel image for better\nperformance.\n@sa cvtColor\n\nPython prototype (for reference only):\n```python3\ncvtColor(src, code[, dst[, dcn[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#cvtColor/2"},{"type":"function","title":"Evision.CUDA.cvtColor/3","doc":"#### Variant 1:\nConverts an image from one color space to another.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image with CV_8U , CV_16U , or CV_32F depth and 1, 3, or 4 channels.\n\n- **code**: `integer()`.\n\n  Color space conversion code. For details, see cvtColor .\n\n##### Keyword Arguments\n- **dcn**: `integer()`.\n\n  Number of channels in the destination image. If the parameter is 0, the number of the\n  channels is derived automatically from src and the code .\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image.\n\n3-channel color spaces (like HSV, XYZ, and so on) can be stored in a 4-channel image for better\nperformance.\n@sa cvtColor\n\nPython prototype (for reference only):\n```python3\ncvtColor(src, code[, dst[, dcn[, stream]]]) -> dst\n```\n#### Variant 2:\nConverts an image from one color space to another.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image with CV_8U , CV_16U , or CV_32F depth and 1, 3, or 4 channels.\n\n- **code**: `integer()`.\n\n  Color space conversion code. For details, see cvtColor .\n\n##### Keyword Arguments\n- **dcn**: `integer()`.\n\n  Number of channels in the destination image. If the parameter is 0, the number of the\n  channels is derived automatically from src and the code .\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image.\n\n3-channel color spaces (like HSV, XYZ, and so on) can be stored in a 4-channel image for better\nperformance.\n@sa cvtColor\n\nPython prototype (for reference only):\n```python3\ncvtColor(src, code[, dst[, dcn[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#cvtColor/3"},{"type":"function","title":"Evision.CUDA.demosaicing/1","doc":"","ref":"Evision.CUDA.html#demosaicing/1"},{"type":"function","title":"Evision.CUDA.demosaicing/2","doc":"#### Variant 1:\nConverts an image from Bayer pattern to RGB or grayscale.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image (8-bit or 16-bit single channel).\n\n- **code**: `integer()`.\n\n  Color space conversion code (see the description below).\n\n##### Keyword Arguments\n- **dcn**: `integer()`.\n\n  Number of channels in the destination image. If the parameter is 0, the number of the\n  channels is derived automatically from src and the code .\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image.\n\nThe function can do the following transformations:\n- Demosaicing using bilinear interpolation\n\n> -   COLOR_BayerBG2GRAY , COLOR_BayerGB2GRAY , COLOR_BayerRG2GRAY , COLOR_BayerGR2GRAY\n> -   COLOR_BayerBG2BGR , COLOR_BayerGB2BGR , COLOR_BayerRG2BGR , COLOR_BayerGR2BGR\n- Demosaicing using Malvar-He-Cutler algorithm (@cite MHT2011)\n\n> -   COLOR_BayerBG2GRAY_MHT , COLOR_BayerGB2GRAY_MHT , COLOR_BayerRG2GRAY_MHT ,\n>     COLOR_BayerGR2GRAY_MHT\n> -   COLOR_BayerBG2BGR_MHT , COLOR_BayerGB2BGR_MHT , COLOR_BayerRG2BGR_MHT ,\n>     COLOR_BayerGR2BGR_MHT\n@sa cvtColor\n\nPython prototype (for reference only):\n```python3\ndemosaicing(src, code[, dst[, dcn[, stream]]]) -> dst\n```\n#### Variant 2:\nConverts an image from Bayer pattern to RGB or grayscale.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image (8-bit or 16-bit single channel).\n\n- **code**: `integer()`.\n\n  Color space conversion code (see the description below).\n\n##### Keyword Arguments\n- **dcn**: `integer()`.\n\n  Number of channels in the destination image. If the parameter is 0, the number of the\n  channels is derived automatically from src and the code .\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image.\n\nThe function can do the following transformations:\n- Demosaicing using bilinear interpolation\n\n> -   COLOR_BayerBG2GRAY , COLOR_BayerGB2GRAY , COLOR_BayerRG2GRAY , COLOR_BayerGR2GRAY\n> -   COLOR_BayerBG2BGR , COLOR_BayerGB2BGR , COLOR_BayerRG2BGR , COLOR_BayerGR2BGR\n- Demosaicing using Malvar-He-Cutler algorithm (@cite MHT2011)\n\n> -   COLOR_BayerBG2GRAY_MHT , COLOR_BayerGB2GRAY_MHT , COLOR_BayerRG2GRAY_MHT ,\n>     COLOR_BayerGR2GRAY_MHT\n> -   COLOR_BayerBG2BGR_MHT , COLOR_BayerGB2BGR_MHT , COLOR_BayerRG2BGR_MHT ,\n>     COLOR_BayerGR2BGR_MHT\n@sa cvtColor\n\nPython prototype (for reference only):\n```python3\ndemosaicing(src, code[, dst[, dcn[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#demosaicing/2"},{"type":"function","title":"Evision.CUDA.demosaicing/3","doc":"#### Variant 1:\nConverts an image from Bayer pattern to RGB or grayscale.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image (8-bit or 16-bit single channel).\n\n- **code**: `integer()`.\n\n  Color space conversion code (see the description below).\n\n##### Keyword Arguments\n- **dcn**: `integer()`.\n\n  Number of channels in the destination image. If the parameter is 0, the number of the\n  channels is derived automatically from src and the code .\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image.\n\nThe function can do the following transformations:\n- Demosaicing using bilinear interpolation\n\n> -   COLOR_BayerBG2GRAY , COLOR_BayerGB2GRAY , COLOR_BayerRG2GRAY , COLOR_BayerGR2GRAY\n> -   COLOR_BayerBG2BGR , COLOR_BayerGB2BGR , COLOR_BayerRG2BGR , COLOR_BayerGR2BGR\n- Demosaicing using Malvar-He-Cutler algorithm (@cite MHT2011)\n\n> -   COLOR_BayerBG2GRAY_MHT , COLOR_BayerGB2GRAY_MHT , COLOR_BayerRG2GRAY_MHT ,\n>     COLOR_BayerGR2GRAY_MHT\n> -   COLOR_BayerBG2BGR_MHT , COLOR_BayerGB2BGR_MHT , COLOR_BayerRG2BGR_MHT ,\n>     COLOR_BayerGR2BGR_MHT\n@sa cvtColor\n\nPython prototype (for reference only):\n```python3\ndemosaicing(src, code[, dst[, dcn[, stream]]]) -> dst\n```\n#### Variant 2:\nConverts an image from Bayer pattern to RGB or grayscale.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image (8-bit or 16-bit single channel).\n\n- **code**: `integer()`.\n\n  Color space conversion code (see the description below).\n\n##### Keyword Arguments\n- **dcn**: `integer()`.\n\n  Number of channels in the destination image. If the parameter is 0, the number of the\n  channels is derived automatically from src and the code .\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image.\n\nThe function can do the following transformations:\n- Demosaicing using bilinear interpolation\n\n> -   COLOR_BayerBG2GRAY , COLOR_BayerGB2GRAY , COLOR_BayerRG2GRAY , COLOR_BayerGR2GRAY\n> -   COLOR_BayerBG2BGR , COLOR_BayerGB2BGR , COLOR_BayerRG2BGR , COLOR_BayerGR2BGR\n- Demosaicing using Malvar-He-Cutler algorithm (@cite MHT2011)\n\n> -   COLOR_BayerBG2GRAY_MHT , COLOR_BayerGB2GRAY_MHT , COLOR_BayerRG2GRAY_MHT ,\n>     COLOR_BayerGR2GRAY_MHT\n> -   COLOR_BayerBG2BGR_MHT , COLOR_BayerGB2BGR_MHT , COLOR_BayerRG2BGR_MHT ,\n>     COLOR_BayerGR2BGR_MHT\n@sa cvtColor\n\nPython prototype (for reference only):\n```python3\ndemosaicing(src, code[, dst[, dcn[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#demosaicing/3"},{"type":"function","title":"Evision.CUDA.dft/1","doc":"","ref":"Evision.CUDA.html#dft/1"},{"type":"function","title":"Evision.CUDA.dft/2","doc":"#### Variant 1:\nPerforms a forward or inverse discrete Fourier transform (1D or 2D) of the floating point matrix.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source matrix (real or complex).\n\n- **dft_size**: `Size`.\n\n  Size of a discrete Fourier transform.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Optional flags:\n  - **DFT_ROWS** transforms each individual row of the source matrix.\n  - **DFT_SCALE** scales the result: divide it by the number of elements in the transform\n    (obtained from dft_size ).\n  - **DFT_INVERSE** inverts DFT. Use for complex-complex cases (real-complex and complex-real\n    cases are always forward and inverse, respectively).\n  - **DFT_COMPLEX_INPUT** Specifies that input is complex input with 2 channels.\n  - **DFT_REAL_OUTPUT** specifies the output as real. The source matrix is the result of\n    real-complex transform, so the destination matrix must be real.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix (real or complex).\n\nUse to handle real matrices ( CV32FC1 ) and complex matrices in the interleaved format ( CV32FC2 ).\nThe source matrix should be continuous, otherwise reallocation and data copying is performed. The\nfunction chooses an operation mode depending on the flags, size, and channel count of the source\nmatrix:\n- If the source matrix is complex and the output is not specified as real, the destination\n  matrix is complex and has the dft_size size and CV_32FC2 type. The destination matrix\n  contains a full result of the DFT (forward or inverse).\n\n- If the source matrix is complex and the output is specified as real, the function assumes that\n  its input is the result of the forward transform (see the next item). The destination matrix\n  has the dft_size size and CV_32FC1 type. It contains the result of the inverse DFT.\n\n- If the source matrix is real (its type is CV_32FC1 ), forward DFT is performed. The result of\n  the DFT is packed into complex ( CV_32FC2 ) matrix. So, the width of the destination matrix\n  is dft_size.width / 2 + 1 . But if the source is a single column, the height is reduced\n  instead of the width.\n\n@sa dft\n\nPython prototype (for reference only):\n```python3\ndft(src, dft_size[, dst[, flags[, stream]]]) -> dst\n```\n#### Variant 2:\nPerforms a forward or inverse discrete Fourier transform (1D or 2D) of the floating point matrix.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix (real or complex).\n\n- **dft_size**: `Size`.\n\n  Size of a discrete Fourier transform.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Optional flags:\n  - **DFT_ROWS** transforms each individual row of the source matrix.\n  - **DFT_SCALE** scales the result: divide it by the number of elements in the transform\n    (obtained from dft_size ).\n  - **DFT_INVERSE** inverts DFT. Use for complex-complex cases (real-complex and complex-real\n    cases are always forward and inverse, respectively).\n  - **DFT_COMPLEX_INPUT** Specifies that input is complex input with 2 channels.\n  - **DFT_REAL_OUTPUT** specifies the output as real. The source matrix is the result of\n    real-complex transform, so the destination matrix must be real.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix (real or complex).\n\nUse to handle real matrices ( CV32FC1 ) and complex matrices in the interleaved format ( CV32FC2 ).\nThe source matrix should be continuous, otherwise reallocation and data copying is performed. The\nfunction chooses an operation mode depending on the flags, size, and channel count of the source\nmatrix:\n- If the source matrix is complex and the output is not specified as real, the destination\n  matrix is complex and has the dft_size size and CV_32FC2 type. The destination matrix\n  contains a full result of the DFT (forward or inverse).\n\n- If the source matrix is complex and the output is specified as real, the function assumes that\n  its input is the result of the forward transform (see the next item). The destination matrix\n  has the dft_size size and CV_32FC1 type. It contains the result of the inverse DFT.\n\n- If the source matrix is real (its type is CV_32FC1 ), forward DFT is performed. The result of\n  the DFT is packed into complex ( CV_32FC2 ) matrix. So, the width of the destination matrix\n  is dft_size.width / 2 + 1 . But if the source is a single column, the height is reduced\n  instead of the width.\n\n@sa dft\n\nPython prototype (for reference only):\n```python3\ndft(src, dft_size[, dst[, flags[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#dft/2"},{"type":"function","title":"Evision.CUDA.dft/3","doc":"#### Variant 1:\nPerforms a forward or inverse discrete Fourier transform (1D or 2D) of the floating point matrix.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source matrix (real or complex).\n\n- **dft_size**: `Size`.\n\n  Size of a discrete Fourier transform.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Optional flags:\n  - **DFT_ROWS** transforms each individual row of the source matrix.\n  - **DFT_SCALE** scales the result: divide it by the number of elements in the transform\n    (obtained from dft_size ).\n  - **DFT_INVERSE** inverts DFT. Use for complex-complex cases (real-complex and complex-real\n    cases are always forward and inverse, respectively).\n  - **DFT_COMPLEX_INPUT** Specifies that input is complex input with 2 channels.\n  - **DFT_REAL_OUTPUT** specifies the output as real. The source matrix is the result of\n    real-complex transform, so the destination matrix must be real.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix (real or complex).\n\nUse to handle real matrices ( CV32FC1 ) and complex matrices in the interleaved format ( CV32FC2 ).\nThe source matrix should be continuous, otherwise reallocation and data copying is performed. The\nfunction chooses an operation mode depending on the flags, size, and channel count of the source\nmatrix:\n- If the source matrix is complex and the output is not specified as real, the destination\n  matrix is complex and has the dft_size size and CV_32FC2 type. The destination matrix\n  contains a full result of the DFT (forward or inverse).\n\n- If the source matrix is complex and the output is specified as real, the function assumes that\n  its input is the result of the forward transform (see the next item). The destination matrix\n  has the dft_size size and CV_32FC1 type. It contains the result of the inverse DFT.\n\n- If the source matrix is real (its type is CV_32FC1 ), forward DFT is performed. The result of\n  the DFT is packed into complex ( CV_32FC2 ) matrix. So, the width of the destination matrix\n  is dft_size.width / 2 + 1 . But if the source is a single column, the height is reduced\n  instead of the width.\n\n@sa dft\n\nPython prototype (for reference only):\n```python3\ndft(src, dft_size[, dst[, flags[, stream]]]) -> dst\n```\n#### Variant 2:\nPerforms a forward or inverse discrete Fourier transform (1D or 2D) of the floating point matrix.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix (real or complex).\n\n- **dft_size**: `Size`.\n\n  Size of a discrete Fourier transform.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Optional flags:\n  - **DFT_ROWS** transforms each individual row of the source matrix.\n  - **DFT_SCALE** scales the result: divide it by the number of elements in the transform\n    (obtained from dft_size ).\n  - **DFT_INVERSE** inverts DFT. Use for complex-complex cases (real-complex and complex-real\n    cases are always forward and inverse, respectively).\n  - **DFT_COMPLEX_INPUT** Specifies that input is complex input with 2 channels.\n  - **DFT_REAL_OUTPUT** specifies the output as real. The source matrix is the result of\n    real-complex transform, so the destination matrix must be real.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix (real or complex).\n\nUse to handle real matrices ( CV32FC1 ) and complex matrices in the interleaved format ( CV32FC2 ).\nThe source matrix should be continuous, otherwise reallocation and data copying is performed. The\nfunction chooses an operation mode depending on the flags, size, and channel count of the source\nmatrix:\n- If the source matrix is complex and the output is not specified as real, the destination\n  matrix is complex and has the dft_size size and CV_32FC2 type. The destination matrix\n  contains a full result of the DFT (forward or inverse).\n\n- If the source matrix is complex and the output is specified as real, the function assumes that\n  its input is the result of the forward transform (see the next item). The destination matrix\n  has the dft_size size and CV_32FC1 type. It contains the result of the inverse DFT.\n\n- If the source matrix is real (its type is CV_32FC1 ), forward DFT is performed. The result of\n  the DFT is packed into complex ( CV_32FC2 ) matrix. So, the width of the destination matrix\n  is dft_size.width / 2 + 1 . But if the source is a single column, the height is reduced\n  instead of the width.\n\n@sa dft\n\nPython prototype (for reference only):\n```python3\ndft(src, dft_size[, dst[, flags[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#dft/3"},{"type":"function","title":"Evision.CUDA.divide/1","doc":"","ref":"Evision.CUDA.html#divide/1"},{"type":"function","title":"Evision.CUDA.divide/2","doc":"#### Variant 1:\nComputes a matrix-matrix or matrix-scalar division.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First source matrix or a scalar.\n\n- **src2**: `Evision.Mat`.\n\n  Second source matrix or scalar.\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Optional scale factor.\n\n- **dtype**: `integer()`.\n\n  Optional depth of the output array.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix that has the same size and number of channels as the input array(s).\n  The depth is defined by dtype or src1 depth.\n\nThis function, in contrast to divide, uses a round-down rounding mode.\n@sa divide\n\nPython prototype (for reference only):\n```python3\ndivide(src1, src2[, dst[, scale[, dtype[, stream]]]]) -> dst\n```\n#### Variant 2:\nComputes a matrix-matrix or matrix-scalar division.\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First source matrix or a scalar.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second source matrix or scalar.\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Optional scale factor.\n\n- **dtype**: `integer()`.\n\n  Optional depth of the output array.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix that has the same size and number of channels as the input array(s).\n  The depth is defined by dtype or src1 depth.\n\nThis function, in contrast to divide, uses a round-down rounding mode.\n@sa divide\n\nPython prototype (for reference only):\n```python3\ndivide(src1, src2[, dst[, scale[, dtype[, stream]]]]) -> dst\n```","ref":"Evision.CUDA.html#divide/2"},{"type":"function","title":"Evision.CUDA.divide/3","doc":"#### Variant 1:\nComputes a matrix-matrix or matrix-scalar division.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First source matrix or a scalar.\n\n- **src2**: `Evision.Mat`.\n\n  Second source matrix or scalar.\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Optional scale factor.\n\n- **dtype**: `integer()`.\n\n  Optional depth of the output array.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix that has the same size and number of channels as the input array(s).\n  The depth is defined by dtype or src1 depth.\n\nThis function, in contrast to divide, uses a round-down rounding mode.\n@sa divide\n\nPython prototype (for reference only):\n```python3\ndivide(src1, src2[, dst[, scale[, dtype[, stream]]]]) -> dst\n```\n#### Variant 2:\nComputes a matrix-matrix or matrix-scalar division.\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First source matrix or a scalar.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second source matrix or scalar.\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Optional scale factor.\n\n- **dtype**: `integer()`.\n\n  Optional depth of the output array.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix that has the same size and number of channels as the input array(s).\n  The depth is defined by dtype or src1 depth.\n\nThis function, in contrast to divide, uses a round-down rounding mode.\n@sa divide\n\nPython prototype (for reference only):\n```python3\ndivide(src1, src2[, dst[, scale[, dtype[, stream]]]]) -> dst\n```","ref":"Evision.CUDA.html#divide/3"},{"type":"function","title":"Evision.CUDA.drawColorDisp/1","doc":"","ref":"Evision.CUDA.html#drawColorDisp/1"},{"type":"function","title":"Evision.CUDA.drawColorDisp/2","doc":"#### Variant 1:\nColors a disparity image.\n\n##### Positional Arguments\n- **src_disp**: `Evision.Mat`.\n\n  Input single-channel 8-bit unsigned, 16-bit signed, 32-bit signed or 32-bit\n  floating-point disparity image. If 16-bit signed format is used, the values are assumed to have no\n  fractional bits.\n\n- **ndisp**: `integer()`.\n\n  Number of disparities.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst_disp**: `Evision.Mat.t()`.\n\n  Output disparity image. It has the same size as src_disp. The type is CV_8UC4\n  in BGRA format (alpha = 255).\n\nThis function draws a colored disparity map by converting disparity values from [0..ndisp) interval\nfirst to HSV color space (where different disparity values correspond to different hues) and then\nconverting the pixels to RGB for visualization.\n\nPython prototype (for reference only):\n```python3\ndrawColorDisp(src_disp, ndisp[, dst_disp[, stream]]) -> dst_disp\n```\n#### Variant 2:\nColors a disparity image.\n\n##### Positional Arguments\n- **src_disp**: `Evision.CUDA.GpuMat.t()`.\n\n  Input single-channel 8-bit unsigned, 16-bit signed, 32-bit signed or 32-bit\n  floating-point disparity image. If 16-bit signed format is used, the values are assumed to have no\n  fractional bits.\n\n- **ndisp**: `integer()`.\n\n  Number of disparities.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst_disp**: `Evision.CUDA.GpuMat.t()`.\n\n  Output disparity image. It has the same size as src_disp. The type is CV_8UC4\n  in BGRA format (alpha = 255).\n\nThis function draws a colored disparity map by converting disparity values from [0..ndisp) interval\nfirst to HSV color space (where different disparity values correspond to different hues) and then\nconverting the pixels to RGB for visualization.\n\nPython prototype (for reference only):\n```python3\ndrawColorDisp(src_disp, ndisp[, dst_disp[, stream]]) -> dst_disp\n```","ref":"Evision.CUDA.html#drawColorDisp/2"},{"type":"function","title":"Evision.CUDA.drawColorDisp/3","doc":"#### Variant 1:\nColors a disparity image.\n\n##### Positional Arguments\n- **src_disp**: `Evision.Mat`.\n\n  Input single-channel 8-bit unsigned, 16-bit signed, 32-bit signed or 32-bit\n  floating-point disparity image. If 16-bit signed format is used, the values are assumed to have no\n  fractional bits.\n\n- **ndisp**: `integer()`.\n\n  Number of disparities.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst_disp**: `Evision.Mat.t()`.\n\n  Output disparity image. It has the same size as src_disp. The type is CV_8UC4\n  in BGRA format (alpha = 255).\n\nThis function draws a colored disparity map by converting disparity values from [0..ndisp) interval\nfirst to HSV color space (where different disparity values correspond to different hues) and then\nconverting the pixels to RGB for visualization.\n\nPython prototype (for reference only):\n```python3\ndrawColorDisp(src_disp, ndisp[, dst_disp[, stream]]) -> dst_disp\n```\n#### Variant 2:\nColors a disparity image.\n\n##### Positional Arguments\n- **src_disp**: `Evision.CUDA.GpuMat.t()`.\n\n  Input single-channel 8-bit unsigned, 16-bit signed, 32-bit signed or 32-bit\n  floating-point disparity image. If 16-bit signed format is used, the values are assumed to have no\n  fractional bits.\n\n- **ndisp**: `integer()`.\n\n  Number of disparities.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst_disp**: `Evision.CUDA.GpuMat.t()`.\n\n  Output disparity image. It has the same size as src_disp. The type is CV_8UC4\n  in BGRA format (alpha = 255).\n\nThis function draws a colored disparity map by converting disparity values from [0..ndisp) interval\nfirst to HSV color space (where different disparity values correspond to different hues) and then\nconverting the pixels to RGB for visualization.\n\nPython prototype (for reference only):\n```python3\ndrawColorDisp(src_disp, ndisp[, dst_disp[, stream]]) -> dst_disp\n```","ref":"Evision.CUDA.html#drawColorDisp/3"},{"type":"function","title":"Evision.CUDA.ensureSizeIsEnough/1","doc":"","ref":"Evision.CUDA.html#ensureSizeIsEnough/1"},{"type":"function","title":"Evision.CUDA.ensureSizeIsEnough/3","doc":"Ensures that the size of a matrix is big enough and the matrix has a proper type.\n\n##### Positional Arguments\n- **rows**: `integer()`.\n\n  Minimum desired number of rows.\n\n- **cols**: `integer()`.\n\n  Minimum desired number of columns.\n\n- **type**: `integer()`.\n\n  Desired matrix type.\n\n##### Return\n- **arr**: `Evision.Mat.t()`.\n\n  Destination matrix.\n\nThe function does not reallocate memory if the matrix has proper attributes already.\n\nPython prototype (for reference only):\n```python3\nensureSizeIsEnough(rows, cols, type[, arr]) -> arr\n```","ref":"Evision.CUDA.html#ensureSizeIsEnough/3"},{"type":"function","title":"Evision.CUDA.ensureSizeIsEnough/4","doc":"Ensures that the size of a matrix is big enough and the matrix has a proper type.\n\n##### Positional Arguments\n- **rows**: `integer()`.\n\n  Minimum desired number of rows.\n\n- **cols**: `integer()`.\n\n  Minimum desired number of columns.\n\n- **type**: `integer()`.\n\n  Desired matrix type.\n\n##### Return\n- **arr**: `Evision.Mat.t()`.\n\n  Destination matrix.\n\nThe function does not reallocate memory if the matrix has proper attributes already.\n\nPython prototype (for reference only):\n```python3\nensureSizeIsEnough(rows, cols, type[, arr]) -> arr\n```","ref":"Evision.CUDA.html#ensureSizeIsEnough/4"},{"type":"function","title":"Evision.CUDA.equalizeHist/1","doc":"#### Variant 1:\nEqualizes the histogram of a grayscale image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image with CV_8UC1 type.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image.\n\n@sa equalizeHist\n\nPython prototype (for reference only):\n```python3\nequalizeHist(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nEqualizes the histogram of a grayscale image.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image with CV_8UC1 type.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image.\n\n@sa equalizeHist\n\nPython prototype (for reference only):\n```python3\nequalizeHist(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#equalizeHist/1"},{"type":"function","title":"Evision.CUDA.equalizeHist/2","doc":"#### Variant 1:\nEqualizes the histogram of a grayscale image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image with CV_8UC1 type.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image.\n\n@sa equalizeHist\n\nPython prototype (for reference only):\n```python3\nequalizeHist(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nEqualizes the histogram of a grayscale image.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image with CV_8UC1 type.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image.\n\n@sa equalizeHist\n\nPython prototype (for reference only):\n```python3\nequalizeHist(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#equalizeHist/2"},{"type":"function","title":"Evision.CUDA.evenLevels/1","doc":"","ref":"Evision.CUDA.html#evenLevels/1"},{"type":"function","title":"Evision.CUDA.evenLevels/3","doc":"Computes levels with even distribution.\n\n##### Positional Arguments\n- **nLevels**: `integer()`.\n\n  Number of computed levels. nLevels must be at least 2.\n\n- **lowerLevel**: `integer()`.\n\n  Lower boundary value of the lowest level.\n\n- **upperLevel**: `integer()`.\n\n  Upper boundary value of the greatest level.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **levels**: `Evision.Mat.t()`.\n\n  Destination array. levels has 1 row, nLevels columns, and the CV_32SC1 type.\n\nPython prototype (for reference only):\n```python3\nevenLevels(nLevels, lowerLevel, upperLevel[, levels[, stream]]) -> levels\n```","ref":"Evision.CUDA.html#evenLevels/3"},{"type":"function","title":"Evision.CUDA.evenLevels/4","doc":"Computes levels with even distribution.\n\n##### Positional Arguments\n- **nLevels**: `integer()`.\n\n  Number of computed levels. nLevels must be at least 2.\n\n- **lowerLevel**: `integer()`.\n\n  Lower boundary value of the lowest level.\n\n- **upperLevel**: `integer()`.\n\n  Upper boundary value of the greatest level.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **levels**: `Evision.Mat.t()`.\n\n  Destination array. levels has 1 row, nLevels columns, and the CV_32SC1 type.\n\nPython prototype (for reference only):\n```python3\nevenLevels(nLevels, lowerLevel, upperLevel[, levels[, stream]]) -> levels\n```","ref":"Evision.CUDA.html#evenLevels/4"},{"type":"function","title":"Evision.CUDA.exp/1","doc":"#### Variant 1:\nComputes an exponent of each matrix element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source matrix.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix with the same size and type as src .\n\n@sa exp\n\nPython prototype (for reference only):\n```python3\nexp(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nComputes an exponent of each matrix element.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix with the same size and type as src .\n\n@sa exp\n\nPython prototype (for reference only):\n```python3\nexp(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#exp/1"},{"type":"function","title":"Evision.CUDA.exp/2","doc":"#### Variant 1:\nComputes an exponent of each matrix element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source matrix.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix with the same size and type as src .\n\n@sa exp\n\nPython prototype (for reference only):\n```python3\nexp(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nComputes an exponent of each matrix element.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix with the same size and type as src .\n\n@sa exp\n\nPython prototype (for reference only):\n```python3\nexp(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#exp/2"},{"type":"function","title":"Evision.CUDA.fastNlMeansDenoising/1","doc":"","ref":"Evision.CUDA.html#fastNlMeansDenoising/1"},{"type":"function","title":"Evision.CUDA.fastNlMeansDenoising/2","doc":"Perform image denoising using Non-local Means Denoising algorithm\n  with several computational\noptimizations. Noise expected to be a gaussian white noise\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Input 8-bit 1-channel, 2-channel or 3-channel image.\n\n- **h**: `float`.\n\n  Parameter regulating filter strength. Big h value perfectly removes noise but also\n  removes image details, smaller h value preserves details but also preserves some noise\n\n##### Keyword Arguments\n- **search_window**: `integer()`.\n\n  Size in pixels of the window that is used to compute weighted average for\n  given pixel. Should be odd. Affect performance linearly: greater search_window - greater\n  denoising time. Recommended value 21 pixels\n\n- **block_size**: `integer()`.\n\n  Size in pixels of the template patch that is used to compute weights. Should be\n  odd. Recommended value 7 pixels\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous invocations.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Output image with the same size and type as src .\n\nThis function expected to be applied to grayscale images. For colored images look at\nFastNonLocalMeansDenoising::labMethod.\n@sa\nfastNlMeansDenoising\n\nPython prototype (for reference only):\n```python3\nfastNlMeansDenoising(src, h[, dst[, search_window[, block_size[, stream]]]]) -> dst\n```","ref":"Evision.CUDA.html#fastNlMeansDenoising/2"},{"type":"function","title":"Evision.CUDA.fastNlMeansDenoising/3","doc":"Perform image denoising using Non-local Means Denoising algorithm\n  with several computational\noptimizations. Noise expected to be a gaussian white noise\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Input 8-bit 1-channel, 2-channel or 3-channel image.\n\n- **h**: `float`.\n\n  Parameter regulating filter strength. Big h value perfectly removes noise but also\n  removes image details, smaller h value preserves details but also preserves some noise\n\n##### Keyword Arguments\n- **search_window**: `integer()`.\n\n  Size in pixels of the window that is used to compute weighted average for\n  given pixel. Should be odd. Affect performance linearly: greater search_window - greater\n  denoising time. Recommended value 21 pixels\n\n- **block_size**: `integer()`.\n\n  Size in pixels of the template patch that is used to compute weights. Should be\n  odd. Recommended value 7 pixels\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous invocations.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Output image with the same size and type as src .\n\nThis function expected to be applied to grayscale images. For colored images look at\nFastNonLocalMeansDenoising::labMethod.\n@sa\nfastNlMeansDenoising\n\nPython prototype (for reference only):\n```python3\nfastNlMeansDenoising(src, h[, dst[, search_window[, block_size[, stream]]]]) -> dst\n```","ref":"Evision.CUDA.html#fastNlMeansDenoising/3"},{"type":"function","title":"Evision.CUDA.fastNlMeansDenoisingColored/1","doc":"","ref":"Evision.CUDA.html#fastNlMeansDenoisingColored/1"},{"type":"function","title":"Evision.CUDA.fastNlMeansDenoisingColored/3","doc":"Modification of fastNlMeansDenoising function for colored images\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Input 8-bit 3-channel image.\n\n- **h_luminance**: `float`.\n\n  Parameter regulating filter strength. Big h value perfectly removes noise but\n  also removes image details, smaller h value preserves details but also preserves some noise\n\n- **photo_render**: `float`.\n\n  float The same as h but for color components. For most images value equals 10 will be\n  enough to remove colored noise and do not distort colors\n\n##### Keyword Arguments\n- **search_window**: `integer()`.\n\n  Size in pixels of the window that is used to compute weighted average for\n  given pixel. Should be odd. Affect performance linearly: greater search_window - greater\n  denoising time. Recommended value 21 pixels\n\n- **block_size**: `integer()`.\n\n  Size in pixels of the template patch that is used to compute weights. Should be\n  odd. Recommended value 7 pixels\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous invocations.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Output image with the same size and type as src .\n\nThe function converts image to CIELAB colorspace and then separately denoise L and AB components\nwith given h parameters using FastNonLocalMeansDenoising::simpleMethod function.\n@sa\nfastNlMeansDenoisingColored\n\nPython prototype (for reference only):\n```python3\nfastNlMeansDenoisingColored(src, h_luminance, photo_render[, dst[, search_window[, block_size[, stream]]]]) -> dst\n```","ref":"Evision.CUDA.html#fastNlMeansDenoisingColored/3"},{"type":"function","title":"Evision.CUDA.fastNlMeansDenoisingColored/4","doc":"Modification of fastNlMeansDenoising function for colored images\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Input 8-bit 3-channel image.\n\n- **h_luminance**: `float`.\n\n  Parameter regulating filter strength. Big h value perfectly removes noise but\n  also removes image details, smaller h value preserves details but also preserves some noise\n\n- **photo_render**: `float`.\n\n  float The same as h but for color components. For most images value equals 10 will be\n  enough to remove colored noise and do not distort colors\n\n##### Keyword Arguments\n- **search_window**: `integer()`.\n\n  Size in pixels of the window that is used to compute weighted average for\n  given pixel. Should be odd. Affect performance linearly: greater search_window - greater\n  denoising time. Recommended value 21 pixels\n\n- **block_size**: `integer()`.\n\n  Size in pixels of the template patch that is used to compute weights. Should be\n  odd. Recommended value 7 pixels\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous invocations.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Output image with the same size and type as src .\n\nThe function converts image to CIELAB colorspace and then separately denoise L and AB components\nwith given h parameters using FastNonLocalMeansDenoising::simpleMethod function.\n@sa\nfastNlMeansDenoisingColored\n\nPython prototype (for reference only):\n```python3\nfastNlMeansDenoisingColored(src, h_luminance, photo_render[, dst[, search_window[, block_size[, stream]]]]) -> dst\n```","ref":"Evision.CUDA.html#fastNlMeansDenoisingColored/4"},{"type":"function","title":"Evision.CUDA.findMinMax/1","doc":"#### Variant 1:\nfindMinMax\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nfindMinMax(src[, dst[, mask[, stream]]]) -> dst\n```\n#### Variant 2:\nfindMinMax\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nfindMinMax(src[, dst[, mask[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#findMinMax/1"},{"type":"function","title":"Evision.CUDA.findMinMax/2","doc":"#### Variant 1:\nfindMinMax\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nfindMinMax(src[, dst[, mask[, stream]]]) -> dst\n```\n#### Variant 2:\nfindMinMax\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nfindMinMax(src[, dst[, mask[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#findMinMax/2"},{"type":"function","title":"Evision.CUDA.findMinMaxLoc/1","doc":"#### Variant 1:\nfindMinMaxLoc\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **minMaxVals**: `Evision.Mat.t()`.\n- **loc**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nfindMinMaxLoc(src[, minMaxVals[, loc[, mask[, stream]]]]) -> minMaxVals, loc\n```\n#### Variant 2:\nfindMinMaxLoc\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **minMaxVals**: `Evision.CUDA.GpuMat.t()`.\n- **loc**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nfindMinMaxLoc(src[, minMaxVals[, loc[, mask[, stream]]]]) -> minMaxVals, loc\n```","ref":"Evision.CUDA.html#findMinMaxLoc/1"},{"type":"function","title":"Evision.CUDA.findMinMaxLoc/2","doc":"#### Variant 1:\nfindMinMaxLoc\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **minMaxVals**: `Evision.Mat.t()`.\n- **loc**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nfindMinMaxLoc(src[, minMaxVals[, loc[, mask[, stream]]]]) -> minMaxVals, loc\n```\n#### Variant 2:\nfindMinMaxLoc\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **minMaxVals**: `Evision.CUDA.GpuMat.t()`.\n- **loc**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nfindMinMaxLoc(src[, minMaxVals[, loc[, mask[, stream]]]]) -> minMaxVals, loc\n```","ref":"Evision.CUDA.html#findMinMaxLoc/2"},{"type":"function","title":"Evision.CUDA.flip/1","doc":"","ref":"Evision.CUDA.html#flip/1"},{"type":"function","title":"Evision.CUDA.flip/2","doc":"#### Variant 1:\nFlips a 2D matrix around vertical, horizontal, or both axes.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source matrix. Supports 1, 3 and 4 channels images with CV_8U, CV_16U, CV_32S or\n  CV_32F depth.\n\n- **flipCode**: `integer()`.\n\n  Flip mode for the source:\n  - 0 Flips around x-axis.\n  - \\> 0 Flips around y-axis.\n  - \\< 0 Flips around both axes.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix.\n\n@sa flip\n\nPython prototype (for reference only):\n```python3\nflip(src, flipCode[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nFlips a 2D matrix around vertical, horizontal, or both axes.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix. Supports 1, 3 and 4 channels images with CV_8U, CV_16U, CV_32S or\n  CV_32F depth.\n\n- **flipCode**: `integer()`.\n\n  Flip mode for the source:\n  - 0 Flips around x-axis.\n  - \\> 0 Flips around y-axis.\n  - \\< 0 Flips around both axes.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix.\n\n@sa flip\n\nPython prototype (for reference only):\n```python3\nflip(src, flipCode[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#flip/2"},{"type":"function","title":"Evision.CUDA.flip/3","doc":"#### Variant 1:\nFlips a 2D matrix around vertical, horizontal, or both axes.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source matrix. Supports 1, 3 and 4 channels images with CV_8U, CV_16U, CV_32S or\n  CV_32F depth.\n\n- **flipCode**: `integer()`.\n\n  Flip mode for the source:\n  - 0 Flips around x-axis.\n  - \\> 0 Flips around y-axis.\n  - \\< 0 Flips around both axes.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix.\n\n@sa flip\n\nPython prototype (for reference only):\n```python3\nflip(src, flipCode[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nFlips a 2D matrix around vertical, horizontal, or both axes.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix. Supports 1, 3 and 4 channels images with CV_8U, CV_16U, CV_32S or\n  CV_32F depth.\n\n- **flipCode**: `integer()`.\n\n  Flip mode for the source:\n  - 0 Flips around x-axis.\n  - \\> 0 Flips around y-axis.\n  - \\< 0 Flips around both axes.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix.\n\n@sa flip\n\nPython prototype (for reference only):\n```python3\nflip(src, flipCode[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#flip/3"},{"type":"function","title":"Evision.CUDA.gammaCorrection/1","doc":"#### Variant 1:\nRoutines for correcting image color gamma.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image (3- or 4-channel 8 bit).\n\n##### Keyword Arguments\n- **forward**: `bool`.\n\n  true for forward gamma correction or false for inverse gamma correction.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image.\n\nPython prototype (for reference only):\n```python3\ngammaCorrection(src[, dst[, forward[, stream]]]) -> dst\n```\n#### Variant 2:\nRoutines for correcting image color gamma.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image (3- or 4-channel 8 bit).\n\n##### Keyword Arguments\n- **forward**: `bool`.\n\n  true for forward gamma correction or false for inverse gamma correction.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image.\n\nPython prototype (for reference only):\n```python3\ngammaCorrection(src[, dst[, forward[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#gammaCorrection/1"},{"type":"function","title":"Evision.CUDA.gammaCorrection/2","doc":"#### Variant 1:\nRoutines for correcting image color gamma.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image (3- or 4-channel 8 bit).\n\n##### Keyword Arguments\n- **forward**: `bool`.\n\n  true for forward gamma correction or false for inverse gamma correction.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image.\n\nPython prototype (for reference only):\n```python3\ngammaCorrection(src[, dst[, forward[, stream]]]) -> dst\n```\n#### Variant 2:\nRoutines for correcting image color gamma.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image (3- or 4-channel 8 bit).\n\n##### Keyword Arguments\n- **forward**: `bool`.\n\n  true for forward gamma correction or false for inverse gamma correction.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image.\n\nPython prototype (for reference only):\n```python3\ngammaCorrection(src[, dst[, forward[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#gammaCorrection/2"},{"type":"function","title":"Evision.CUDA.gemm/1","doc":"","ref":"Evision.CUDA.html#gemm/1"},{"type":"function","title":"Evision.CUDA.gemm/5","doc":"#### Variant 1:\nPerforms generalized matrix multiplication.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First multiplied input matrix that should have CV_32FC1 , CV_64FC1 , CV_32FC2 , or\n  CV_64FC2 type.\n\n- **src2**: `Evision.Mat`.\n\n  Second multiplied input matrix of the same type as src1 .\n\n- **alpha**: `double`.\n\n  Weight of the matrix product.\n\n- **src3**: `Evision.Mat`.\n\n  Third optional delta matrix added to the matrix product. It should have the same type\n  as src1 and src2 .\n\n- **beta**: `double`.\n\n  Weight of src3 .\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Operation flags:\n  - **GEMM_1_T** transpose src1\n  - **GEMM_2_T** transpose src2\n  - **GEMM_3_T** transpose src3\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix. It has the proper size and the same type as input matrices.\n\nThe function performs generalized matrix multiplication similar to the gemm functions in BLAS level\n3. For example, gemm(src1, src2, alpha, src3, beta, dst, GEMM_1_T + GEMM_3_T) corresponds to\n\\f[\\texttt{dst} =  \\texttt{alpha} \\cdot \\texttt{src1} ^T  \\cdot \\texttt{src2} +  \\texttt{beta} \\cdot \\texttt{src3} ^T\\f]\n**Note**: Transposition operation doesn't support CV_64FC2 input type.\n@sa gemm\n\nPython prototype (for reference only):\n```python3\ngemm(src1, src2, alpha, src3, beta[, dst[, flags[, stream]]]) -> dst\n```\n#### Variant 2:\nPerforms generalized matrix multiplication.\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First multiplied input matrix that should have CV_32FC1 , CV_64FC1 , CV_32FC2 , or\n  CV_64FC2 type.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second multiplied input matrix of the same type as src1 .\n\n- **alpha**: `double`.\n\n  Weight of the matrix product.\n\n- **src3**: `Evision.CUDA.GpuMat.t()`.\n\n  Third optional delta matrix added to the matrix product. It should have the same type\n  as src1 and src2 .\n\n- **beta**: `double`.\n\n  Weight of src3 .\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Operation flags:\n  - **GEMM_1_T** transpose src1\n  - **GEMM_2_T** transpose src2\n  - **GEMM_3_T** transpose src3\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix. It has the proper size and the same type as input matrices.\n\nThe function performs generalized matrix multiplication similar to the gemm functions in BLAS level\n3. For example, gemm(src1, src2, alpha, src3, beta, dst, GEMM_1_T + GEMM_3_T) corresponds to\n\\f[\\texttt{dst} =  \\texttt{alpha} \\cdot \\texttt{src1} ^T  \\cdot \\texttt{src2} +  \\texttt{beta} \\cdot \\texttt{src3} ^T\\f]\n**Note**: Transposition operation doesn't support CV_64FC2 input type.\n@sa gemm\n\nPython prototype (for reference only):\n```python3\ngemm(src1, src2, alpha, src3, beta[, dst[, flags[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#gemm/5"},{"type":"function","title":"Evision.CUDA.gemm/6","doc":"#### Variant 1:\nPerforms generalized matrix multiplication.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First multiplied input matrix that should have CV_32FC1 , CV_64FC1 , CV_32FC2 , or\n  CV_64FC2 type.\n\n- **src2**: `Evision.Mat`.\n\n  Second multiplied input matrix of the same type as src1 .\n\n- **alpha**: `double`.\n\n  Weight of the matrix product.\n\n- **src3**: `Evision.Mat`.\n\n  Third optional delta matrix added to the matrix product. It should have the same type\n  as src1 and src2 .\n\n- **beta**: `double`.\n\n  Weight of src3 .\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Operation flags:\n  - **GEMM_1_T** transpose src1\n  - **GEMM_2_T** transpose src2\n  - **GEMM_3_T** transpose src3\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix. It has the proper size and the same type as input matrices.\n\nThe function performs generalized matrix multiplication similar to the gemm functions in BLAS level\n3. For example, gemm(src1, src2, alpha, src3, beta, dst, GEMM_1_T + GEMM_3_T) corresponds to\n\\f[\\texttt{dst} =  \\texttt{alpha} \\cdot \\texttt{src1} ^T  \\cdot \\texttt{src2} +  \\texttt{beta} \\cdot \\texttt{src3} ^T\\f]\n**Note**: Transposition operation doesn't support CV_64FC2 input type.\n@sa gemm\n\nPython prototype (for reference only):\n```python3\ngemm(src1, src2, alpha, src3, beta[, dst[, flags[, stream]]]) -> dst\n```\n#### Variant 2:\nPerforms generalized matrix multiplication.\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First multiplied input matrix that should have CV_32FC1 , CV_64FC1 , CV_32FC2 , or\n  CV_64FC2 type.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second multiplied input matrix of the same type as src1 .\n\n- **alpha**: `double`.\n\n  Weight of the matrix product.\n\n- **src3**: `Evision.CUDA.GpuMat.t()`.\n\n  Third optional delta matrix added to the matrix product. It should have the same type\n  as src1 and src2 .\n\n- **beta**: `double`.\n\n  Weight of src3 .\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Operation flags:\n  - **GEMM_1_T** transpose src1\n  - **GEMM_2_T** transpose src2\n  - **GEMM_3_T** transpose src3\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix. It has the proper size and the same type as input matrices.\n\nThe function performs generalized matrix multiplication similar to the gemm functions in BLAS level\n3. For example, gemm(src1, src2, alpha, src3, beta, dst, GEMM_1_T + GEMM_3_T) corresponds to\n\\f[\\texttt{dst} =  \\texttt{alpha} \\cdot \\texttt{src1} ^T  \\cdot \\texttt{src2} +  \\texttt{beta} \\cdot \\texttt{src3} ^T\\f]\n**Note**: Transposition operation doesn't support CV_64FC2 input type.\n@sa gemm\n\nPython prototype (for reference only):\n```python3\ngemm(src1, src2, alpha, src3, beta[, dst[, flags[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#gemm/6"},{"type":"function","title":"Evision.CUDA.getCudaEnabledDeviceCount/0","doc":"Returns the number of installed CUDA-enabled devices.\n##### Return\n- **retval**: `integer()`\n\nUse this function before any other CUDA functions calls. If OpenCV is compiled without CUDA support,\nthis function returns 0. If the CUDA driver is not installed, or is incompatible, this function\nreturns -1.\n\nPython prototype (for reference only):\n```python3\ngetCudaEnabledDeviceCount() -> retval\n```","ref":"Evision.CUDA.html#getCudaEnabledDeviceCount/0"},{"type":"function","title":"Evision.CUDA.getCudaEnabledDeviceCount/1","doc":"","ref":"Evision.CUDA.html#getCudaEnabledDeviceCount/1"},{"type":"function","title":"Evision.CUDA.getDevice/0","doc":"Returns the current device index set by cuda::setDevice or initialized by default.\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetDevice() -> retval\n```","ref":"Evision.CUDA.html#getDevice/0"},{"type":"function","title":"Evision.CUDA.getDevice/1","doc":"","ref":"Evision.CUDA.html#getDevice/1"},{"type":"function","title":"Evision.CUDA.histEven/1","doc":"","ref":"Evision.CUDA.html#histEven/1"},{"type":"function","title":"Evision.CUDA.histEven/4","doc":"#### Variant 1:\nCalculates a histogram with evenly distributed bins.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. CV_8U, CV_16U, or CV_16S depth and 1 or 4 channels are supported. For\n  a four-channel image, all channels are processed separately.\n\n- **histSize**: `integer()`.\n\n  Size of the histogram.\n\n- **lowerLevel**: `integer()`.\n\n  Lower boundary of lowest-level bin.\n\n- **upperLevel**: `integer()`.\n\n  Upper boundary of highest-level bin.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **hist**: `Evision.Mat.t()`.\n\n  Destination histogram with one row, histSize columns, and the CV_32S type.\n\nPython prototype (for reference only):\n```python3\nhistEven(src, histSize, lowerLevel, upperLevel[, hist[, stream]]) -> hist\n```\n#### Variant 2:\nCalculates a histogram with evenly distributed bins.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. CV_8U, CV_16U, or CV_16S depth and 1 or 4 channels are supported. For\n  a four-channel image, all channels are processed separately.\n\n- **histSize**: `integer()`.\n\n  Size of the histogram.\n\n- **lowerLevel**: `integer()`.\n\n  Lower boundary of lowest-level bin.\n\n- **upperLevel**: `integer()`.\n\n  Upper boundary of highest-level bin.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **hist**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination histogram with one row, histSize columns, and the CV_32S type.\n\nPython prototype (for reference only):\n```python3\nhistEven(src, histSize, lowerLevel, upperLevel[, hist[, stream]]) -> hist\n```","ref":"Evision.CUDA.html#histEven/4"},{"type":"function","title":"Evision.CUDA.histEven/5","doc":"#### Variant 1:\nCalculates a histogram with evenly distributed bins.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. CV_8U, CV_16U, or CV_16S depth and 1 or 4 channels are supported. For\n  a four-channel image, all channels are processed separately.\n\n- **histSize**: `integer()`.\n\n  Size of the histogram.\n\n- **lowerLevel**: `integer()`.\n\n  Lower boundary of lowest-level bin.\n\n- **upperLevel**: `integer()`.\n\n  Upper boundary of highest-level bin.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **hist**: `Evision.Mat.t()`.\n\n  Destination histogram with one row, histSize columns, and the CV_32S type.\n\nPython prototype (for reference only):\n```python3\nhistEven(src, histSize, lowerLevel, upperLevel[, hist[, stream]]) -> hist\n```\n#### Variant 2:\nCalculates a histogram with evenly distributed bins.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. CV_8U, CV_16U, or CV_16S depth and 1 or 4 channels are supported. For\n  a four-channel image, all channels are processed separately.\n\n- **histSize**: `integer()`.\n\n  Size of the histogram.\n\n- **lowerLevel**: `integer()`.\n\n  Lower boundary of lowest-level bin.\n\n- **upperLevel**: `integer()`.\n\n  Upper boundary of highest-level bin.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **hist**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination histogram with one row, histSize columns, and the CV_32S type.\n\nPython prototype (for reference only):\n```python3\nhistEven(src, histSize, lowerLevel, upperLevel[, hist[, stream]]) -> hist\n```\n#### Variant 3:\nhistEven\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n- **hist**: `GpuMat*`\n- **histSize**: `int*`\n- **lowerLevel**: `int*`\n- **upperLevel**: `int*`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nhistEven(src, hist, histSize, lowerLevel, upperLevel[, stream]) -> None\n```\n#### Variant 4:\nhistEven\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n- **hist**: `GpuMat*`\n- **histSize**: `int*`\n- **lowerLevel**: `int*`\n- **upperLevel**: `int*`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nhistEven(src, hist, histSize, lowerLevel, upperLevel[, stream]) -> None\n```","ref":"Evision.CUDA.html#histEven/5"},{"type":"function","title":"Evision.CUDA.histEven/6","doc":"#### Variant 1:\nhistEven\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n- **hist**: `GpuMat*`\n- **histSize**: `int*`\n- **lowerLevel**: `int*`\n- **upperLevel**: `int*`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nhistEven(src, hist, histSize, lowerLevel, upperLevel[, stream]) -> None\n```\n#### Variant 2:\nhistEven\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n- **hist**: `GpuMat*`\n- **histSize**: `int*`\n- **lowerLevel**: `int*`\n- **upperLevel**: `int*`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nhistEven(src, hist, histSize, lowerLevel, upperLevel[, stream]) -> None\n```","ref":"Evision.CUDA.html#histEven/6"},{"type":"function","title":"Evision.CUDA.histRange/1","doc":"","ref":"Evision.CUDA.html#histRange/1"},{"type":"function","title":"Evision.CUDA.histRange/2","doc":"#### Variant 1:\nCalculates a histogram with bins determined by the levels array.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. CV_8U , CV_16U , or CV_16S depth and 1 or 4 channels are supported.\n  For a four-channel image, all channels are processed separately.\n\n- **levels**: `Evision.Mat`.\n\n  Number of levels in the histogram.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **hist**: `Evision.Mat.t()`.\n\n  Destination histogram with one row, (levels.cols-1) columns, and the CV_32SC1 type.\n\nPython prototype (for reference only):\n```python3\nhistRange(src, levels[, hist[, stream]]) -> hist\n```\n#### Variant 2:\nCalculates a histogram with bins determined by the levels array.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. CV_8U , CV_16U , or CV_16S depth and 1 or 4 channels are supported.\n  For a four-channel image, all channels are processed separately.\n\n- **levels**: `Evision.CUDA.GpuMat.t()`.\n\n  Number of levels in the histogram.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **hist**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination histogram with one row, (levels.cols-1) columns, and the CV_32SC1 type.\n\nPython prototype (for reference only):\n```python3\nhistRange(src, levels[, hist[, stream]]) -> hist\n```","ref":"Evision.CUDA.html#histRange/2"},{"type":"function","title":"Evision.CUDA.histRange/3","doc":"#### Variant 1:\nCalculates a histogram with bins determined by the levels array.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. CV_8U , CV_16U , or CV_16S depth and 1 or 4 channels are supported.\n  For a four-channel image, all channels are processed separately.\n\n- **levels**: `Evision.Mat`.\n\n  Number of levels in the histogram.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **hist**: `Evision.Mat.t()`.\n\n  Destination histogram with one row, (levels.cols-1) columns, and the CV_32SC1 type.\n\nPython prototype (for reference only):\n```python3\nhistRange(src, levels[, hist[, stream]]) -> hist\n```\n#### Variant 2:\nCalculates a histogram with bins determined by the levels array.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. CV_8U , CV_16U , or CV_16S depth and 1 or 4 channels are supported.\n  For a four-channel image, all channels are processed separately.\n\n- **levels**: `Evision.CUDA.GpuMat.t()`.\n\n  Number of levels in the histogram.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **hist**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination histogram with one row, (levels.cols-1) columns, and the CV_32SC1 type.\n\nPython prototype (for reference only):\n```python3\nhistRange(src, levels[, hist[, stream]]) -> hist\n```\n#### Variant 3:\nhistRange\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n- **hist**: `GpuMat*`\n- **levels**: `GpuMat*`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nhistRange(src, hist, levels[, stream]) -> None\n```\n#### Variant 4:\nhistRange\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n- **hist**: `GpuMat*`\n- **levels**: `GpuMat*`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nhistRange(src, hist, levels[, stream]) -> None\n```","ref":"Evision.CUDA.html#histRange/3"},{"type":"function","title":"Evision.CUDA.histRange/4","doc":"#### Variant 1:\nhistRange\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n- **hist**: `GpuMat*`\n- **levels**: `GpuMat*`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nhistRange(src, hist, levels[, stream]) -> None\n```\n#### Variant 2:\nhistRange\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n- **hist**: `GpuMat*`\n- **levels**: `GpuMat*`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nhistRange(src, hist, levels[, stream]) -> None\n```","ref":"Evision.CUDA.html#histRange/4"},{"type":"function","title":"Evision.CUDA.inRange/1","doc":"","ref":"Evision.CUDA.html#inRange/1"},{"type":"function","title":"Evision.CUDA.inRange/3","doc":"#### Variant 1:\nChecks if array elements lie between two scalars.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  first input array.\n\n- **lowerb**: `Evision.scalar()`.\n\n  inclusive lower boundary cv::Scalar.\n\n- **upperb**: `Evision.scalar()`.\n\n  inclusive upper boundary cv::Scalar.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size as src and CV_8U type.\n\nThe function checks the range as follows:\n- For every element of a single-channel input array:\n  \\f[\\texttt{dst} (I)= \\texttt{lowerb}\\_0  \\leq \\texttt{src} (I)\\_0 \\leq  \\texttt{upperb}\\_0\\f]\n\n- For two-channel arrays:\n  \\f[\\texttt{dst} (I)= \\texttt{lowerb}\\_0  \\leq \\texttt{src} (I)\\_0 \\leq  \\texttt{upperb}\\_0  \\land \\texttt{lowerb}\\_1  \\leq \\texttt{src} (I)\\_1 \\leq  \\texttt{upperb}\\_1\\f]\n\n- and so forth.\n\nThat is, dst (I) is set to 255 (all 1 -bits) if src (I) is within the\nspecified 1D, 2D, 3D, ... box and 0 otherwise.\nNote that unlike the CPU inRange, this does NOT accept an array for lowerb or\nupperb, only a cv::Scalar.\n\n@sa cv::inRange\n\nPython prototype (for reference only):\n```python3\ninRange(src, lowerb, upperb[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nChecks if array elements lie between two scalars.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  first input array.\n\n- **lowerb**: `Evision.scalar()`.\n\n  inclusive lower boundary cv::Scalar.\n\n- **upperb**: `Evision.scalar()`.\n\n  inclusive upper boundary cv::Scalar.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  output array of the same size as src and CV_8U type.\n\nThe function checks the range as follows:\n- For every element of a single-channel input array:\n  \\f[\\texttt{dst} (I)= \\texttt{lowerb}\\_0  \\leq \\texttt{src} (I)\\_0 \\leq  \\texttt{upperb}\\_0\\f]\n\n- For two-channel arrays:\n  \\f[\\texttt{dst} (I)= \\texttt{lowerb}\\_0  \\leq \\texttt{src} (I)\\_0 \\leq  \\texttt{upperb}\\_0  \\land \\texttt{lowerb}\\_1  \\leq \\texttt{src} (I)\\_1 \\leq  \\texttt{upperb}\\_1\\f]\n\n- and so forth.\n\nThat is, dst (I) is set to 255 (all 1 -bits) if src (I) is within the\nspecified 1D, 2D, 3D, ... box and 0 otherwise.\nNote that unlike the CPU inRange, this does NOT accept an array for lowerb or\nupperb, only a cv::Scalar.\n\n@sa cv::inRange\n\nPython prototype (for reference only):\n```python3\ninRange(src, lowerb, upperb[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#inRange/3"},{"type":"function","title":"Evision.CUDA.inRange/4","doc":"#### Variant 1:\nChecks if array elements lie between two scalars.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  first input array.\n\n- **lowerb**: `Evision.scalar()`.\n\n  inclusive lower boundary cv::Scalar.\n\n- **upperb**: `Evision.scalar()`.\n\n  inclusive upper boundary cv::Scalar.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output array of the same size as src and CV_8U type.\n\nThe function checks the range as follows:\n- For every element of a single-channel input array:\n  \\f[\\texttt{dst} (I)= \\texttt{lowerb}\\_0  \\leq \\texttt{src} (I)\\_0 \\leq  \\texttt{upperb}\\_0\\f]\n\n- For two-channel arrays:\n  \\f[\\texttt{dst} (I)= \\texttt{lowerb}\\_0  \\leq \\texttt{src} (I)\\_0 \\leq  \\texttt{upperb}\\_0  \\land \\texttt{lowerb}\\_1  \\leq \\texttt{src} (I)\\_1 \\leq  \\texttt{upperb}\\_1\\f]\n\n- and so forth.\n\nThat is, dst (I) is set to 255 (all 1 -bits) if src (I) is within the\nspecified 1D, 2D, 3D, ... box and 0 otherwise.\nNote that unlike the CPU inRange, this does NOT accept an array for lowerb or\nupperb, only a cv::Scalar.\n\n@sa cv::inRange\n\nPython prototype (for reference only):\n```python3\ninRange(src, lowerb, upperb[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nChecks if array elements lie between two scalars.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  first input array.\n\n- **lowerb**: `Evision.scalar()`.\n\n  inclusive lower boundary cv::Scalar.\n\n- **upperb**: `Evision.scalar()`.\n\n  inclusive upper boundary cv::Scalar.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  output array of the same size as src and CV_8U type.\n\nThe function checks the range as follows:\n- For every element of a single-channel input array:\n  \\f[\\texttt{dst} (I)= \\texttt{lowerb}\\_0  \\leq \\texttt{src} (I)\\_0 \\leq  \\texttt{upperb}\\_0\\f]\n\n- For two-channel arrays:\n  \\f[\\texttt{dst} (I)= \\texttt{lowerb}\\_0  \\leq \\texttt{src} (I)\\_0 \\leq  \\texttt{upperb}\\_0  \\land \\texttt{lowerb}\\_1  \\leq \\texttt{src} (I)\\_1 \\leq  \\texttt{upperb}\\_1\\f]\n\n- and so forth.\n\nThat is, dst (I) is set to 255 (all 1 -bits) if src (I) is within the\nspecified 1D, 2D, 3D, ... box and 0 otherwise.\nNote that unlike the CPU inRange, this does NOT accept an array for lowerb or\nupperb, only a cv::Scalar.\n\n@sa cv::inRange\n\nPython prototype (for reference only):\n```python3\ninRange(src, lowerb, upperb[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#inRange/4"},{"type":"function","title":"Evision.CUDA.integral/1","doc":"#### Variant 1:\nComputes an integral image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. Only CV_8UC1 images are supported for now.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **sum**: `Evision.Mat.t()`.\n\n  Integral image containing 32-bit unsigned integer values packed into CV_32SC1 .\n\n@sa integral\n\nPython prototype (for reference only):\n```python3\nintegral(src[, sum[, stream]]) -> sum\n```\n#### Variant 2:\nComputes an integral image.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. Only CV_8UC1 images are supported for now.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **sum**: `Evision.CUDA.GpuMat.t()`.\n\n  Integral image containing 32-bit unsigned integer values packed into CV_32SC1 .\n\n@sa integral\n\nPython prototype (for reference only):\n```python3\nintegral(src[, sum[, stream]]) -> sum\n```","ref":"Evision.CUDA.html#integral/1"},{"type":"function","title":"Evision.CUDA.integral/2","doc":"#### Variant 1:\nComputes an integral image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. Only CV_8UC1 images are supported for now.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **sum**: `Evision.Mat.t()`.\n\n  Integral image containing 32-bit unsigned integer values packed into CV_32SC1 .\n\n@sa integral\n\nPython prototype (for reference only):\n```python3\nintegral(src[, sum[, stream]]) -> sum\n```\n#### Variant 2:\nComputes an integral image.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. Only CV_8UC1 images are supported for now.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **sum**: `Evision.CUDA.GpuMat.t()`.\n\n  Integral image containing 32-bit unsigned integer values packed into CV_32SC1 .\n\n@sa integral\n\nPython prototype (for reference only):\n```python3\nintegral(src[, sum[, stream]]) -> sum\n```","ref":"Evision.CUDA.html#integral/2"},{"type":"function","title":"Evision.CUDA.log/1","doc":"#### Variant 1:\nComputes a natural logarithm of absolute value of each matrix element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source matrix.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix with the same size and type as src .\n\n@sa log\n\nPython prototype (for reference only):\n```python3\nlog(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nComputes a natural logarithm of absolute value of each matrix element.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix with the same size and type as src .\n\n@sa log\n\nPython prototype (for reference only):\n```python3\nlog(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#log/1"},{"type":"function","title":"Evision.CUDA.log/2","doc":"#### Variant 1:\nComputes a natural logarithm of absolute value of each matrix element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source matrix.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix with the same size and type as src .\n\n@sa log\n\nPython prototype (for reference only):\n```python3\nlog(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nComputes a natural logarithm of absolute value of each matrix element.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix with the same size and type as src .\n\n@sa log\n\nPython prototype (for reference only):\n```python3\nlog(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#log/2"},{"type":"function","title":"Evision.CUDA.lshift/1","doc":"","ref":"Evision.CUDA.html#lshift/1"},{"type":"function","title":"Evision.CUDA.lshift/2","doc":"#### Variant 1:\nPerforms pixel by pixel right left of an image by a constant value.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source matrix. Supports 1, 3 and 4 channels images with CV_8U , CV_16U or CV_32S\n  depth.\n\n- **val**: `Evision.scalar()`.\n\n  Constant values, one per channel.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix with the same size and type as src .\n\nPython prototype (for reference only):\n```python3\nlshift(src, val[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nPerforms pixel by pixel right left of an image by a constant value.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix. Supports 1, 3 and 4 channels images with CV_8U , CV_16U or CV_32S\n  depth.\n\n- **val**: `Evision.scalar()`.\n\n  Constant values, one per channel.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix with the same size and type as src .\n\nPython prototype (for reference only):\n```python3\nlshift(src, val[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#lshift/2"},{"type":"function","title":"Evision.CUDA.lshift/3","doc":"#### Variant 1:\nPerforms pixel by pixel right left of an image by a constant value.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source matrix. Supports 1, 3 and 4 channels images with CV_8U , CV_16U or CV_32S\n  depth.\n\n- **val**: `Evision.scalar()`.\n\n  Constant values, one per channel.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix with the same size and type as src .\n\nPython prototype (for reference only):\n```python3\nlshift(src, val[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nPerforms pixel by pixel right left of an image by a constant value.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix. Supports 1, 3 and 4 channels images with CV_8U , CV_16U or CV_32S\n  depth.\n\n- **val**: `Evision.scalar()`.\n\n  Constant values, one per channel.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix with the same size and type as src .\n\nPython prototype (for reference only):\n```python3\nlshift(src, val[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#lshift/3"},{"type":"function","title":"Evision.CUDA.magnitude/1","doc":"#### Variant 1:\nComputes magnitudes of complex matrix elements.\n\n##### Positional Arguments\n- **xy**: `Evision.Mat`.\n\n  Source complex matrix in the interleaved format ( CV_32FC2 ).\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **magnitude**: `Evision.Mat.t()`.\n\n  Destination matrix of float magnitudes ( CV_32FC1 ).\n\n@sa magnitude\n\nPython prototype (for reference only):\n```python3\nmagnitude(xy[, magnitude[, stream]]) -> magnitude\n```\n#### Variant 2:\nComputes magnitudes of complex matrix elements.\n\n##### Positional Arguments\n- **xy**: `Evision.CUDA.GpuMat.t()`.\n\n  Source complex matrix in the interleaved format ( CV_32FC2 ).\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **magnitude**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix of float magnitudes ( CV_32FC1 ).\n\n@sa magnitude\n\nPython prototype (for reference only):\n```python3\nmagnitude(xy[, magnitude[, stream]]) -> magnitude\n```","ref":"Evision.CUDA.html#magnitude/1"},{"type":"function","title":"Evision.CUDA.magnitude/2","doc":"#### Variant 1:\nmagnitude\n\n##### Positional Arguments\n- **x**: `Evision.Mat`.\n\n  Source matrix containing real components ( CV_32FC1 ).\n\n- **y**: `Evision.Mat`.\n\n  Source matrix containing imaginary components ( CV_32FC1 ).\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **magnitude**: `Evision.Mat.t()`.\n\n  Destination matrix of float magnitudes ( CV_32FC1 ).\n\nHas overloading in C++\n\ncomputes magnitude of each (x(i), y(i)) vector\nsupports only floating-point source\n\nPython prototype (for reference only):\n```python3\nmagnitude(x, y[, magnitude[, stream]]) -> magnitude\n```\n#### Variant 2:\nmagnitude\n\n##### Positional Arguments\n- **x**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix containing real components ( CV_32FC1 ).\n\n- **y**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix containing imaginary components ( CV_32FC1 ).\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **magnitude**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix of float magnitudes ( CV_32FC1 ).\n\nHas overloading in C++\n\ncomputes magnitude of each (x(i), y(i)) vector\nsupports only floating-point source\n\nPython prototype (for reference only):\n```python3\nmagnitude(x, y[, magnitude[, stream]]) -> magnitude\n```\n#### Variant 3:\nComputes magnitudes of complex matrix elements.\n\n##### Positional Arguments\n- **xy**: `Evision.Mat`.\n\n  Source complex matrix in the interleaved format ( CV_32FC2 ).\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **magnitude**: `Evision.Mat.t()`.\n\n  Destination matrix of float magnitudes ( CV_32FC1 ).\n\n@sa magnitude\n\nPython prototype (for reference only):\n```python3\nmagnitude(xy[, magnitude[, stream]]) -> magnitude\n```\n#### Variant 4:\nComputes magnitudes of complex matrix elements.\n\n##### Positional Arguments\n- **xy**: `Evision.CUDA.GpuMat.t()`.\n\n  Source complex matrix in the interleaved format ( CV_32FC2 ).\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **magnitude**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix of float magnitudes ( CV_32FC1 ).\n\n@sa magnitude\n\nPython prototype (for reference only):\n```python3\nmagnitude(xy[, magnitude[, stream]]) -> magnitude\n```","ref":"Evision.CUDA.html#magnitude/2"},{"type":"function","title":"Evision.CUDA.magnitude/3","doc":"#### Variant 1:\nmagnitude\n\n##### Positional Arguments\n- **x**: `Evision.Mat`.\n\n  Source matrix containing real components ( CV_32FC1 ).\n\n- **y**: `Evision.Mat`.\n\n  Source matrix containing imaginary components ( CV_32FC1 ).\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **magnitude**: `Evision.Mat.t()`.\n\n  Destination matrix of float magnitudes ( CV_32FC1 ).\n\nHas overloading in C++\n\ncomputes magnitude of each (x(i), y(i)) vector\nsupports only floating-point source\n\nPython prototype (for reference only):\n```python3\nmagnitude(x, y[, magnitude[, stream]]) -> magnitude\n```\n#### Variant 2:\nmagnitude\n\n##### Positional Arguments\n- **x**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix containing real components ( CV_32FC1 ).\n\n- **y**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix containing imaginary components ( CV_32FC1 ).\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **magnitude**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix of float magnitudes ( CV_32FC1 ).\n\nHas overloading in C++\n\ncomputes magnitude of each (x(i), y(i)) vector\nsupports only floating-point source\n\nPython prototype (for reference only):\n```python3\nmagnitude(x, y[, magnitude[, stream]]) -> magnitude\n```","ref":"Evision.CUDA.html#magnitude/3"},{"type":"function","title":"Evision.CUDA.magnitudeSqr/1","doc":"#### Variant 1:\nComputes squared magnitudes of complex matrix elements.\n\n##### Positional Arguments\n- **xy**: `Evision.Mat`.\n\n  Source complex matrix in the interleaved format ( CV_32FC2 ).\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **magnitude**: `Evision.Mat.t()`.\n\n  Destination matrix of float magnitude squares ( CV_32FC1 ).\n\nPython prototype (for reference only):\n```python3\nmagnitudeSqr(xy[, magnitude[, stream]]) -> magnitude\n```\n#### Variant 2:\nComputes squared magnitudes of complex matrix elements.\n\n##### Positional Arguments\n- **xy**: `Evision.CUDA.GpuMat.t()`.\n\n  Source complex matrix in the interleaved format ( CV_32FC2 ).\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **magnitude**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix of float magnitude squares ( CV_32FC1 ).\n\nPython prototype (for reference only):\n```python3\nmagnitudeSqr(xy[, magnitude[, stream]]) -> magnitude\n```","ref":"Evision.CUDA.html#magnitudeSqr/1"},{"type":"function","title":"Evision.CUDA.magnitudeSqr/2","doc":"#### Variant 1:\nmagnitudeSqr\n\n##### Positional Arguments\n- **x**: `Evision.Mat`.\n\n  Source matrix containing real components ( CV_32FC1 ).\n\n- **y**: `Evision.Mat`.\n\n  Source matrix containing imaginary components ( CV_32FC1 ).\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **magnitude**: `Evision.Mat.t()`.\n\n  Destination matrix of float magnitude squares ( CV_32FC1 ).\n\nHas overloading in C++\n\ncomputes squared magnitude of each (x(i), y(i)) vector\nsupports only floating-point source\n\nPython prototype (for reference only):\n```python3\nmagnitudeSqr(x, y[, magnitude[, stream]]) -> magnitude\n```\n#### Variant 2:\nmagnitudeSqr\n\n##### Positional Arguments\n- **x**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix containing real components ( CV_32FC1 ).\n\n- **y**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix containing imaginary components ( CV_32FC1 ).\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **magnitude**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix of float magnitude squares ( CV_32FC1 ).\n\nHas overloading in C++\n\ncomputes squared magnitude of each (x(i), y(i)) vector\nsupports only floating-point source\n\nPython prototype (for reference only):\n```python3\nmagnitudeSqr(x, y[, magnitude[, stream]]) -> magnitude\n```\n#### Variant 3:\nComputes squared magnitudes of complex matrix elements.\n\n##### Positional Arguments\n- **xy**: `Evision.Mat`.\n\n  Source complex matrix in the interleaved format ( CV_32FC2 ).\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **magnitude**: `Evision.Mat.t()`.\n\n  Destination matrix of float magnitude squares ( CV_32FC1 ).\n\nPython prototype (for reference only):\n```python3\nmagnitudeSqr(xy[, magnitude[, stream]]) -> magnitude\n```\n#### Variant 4:\nComputes squared magnitudes of complex matrix elements.\n\n##### Positional Arguments\n- **xy**: `Evision.CUDA.GpuMat.t()`.\n\n  Source complex matrix in the interleaved format ( CV_32FC2 ).\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **magnitude**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix of float magnitude squares ( CV_32FC1 ).\n\nPython prototype (for reference only):\n```python3\nmagnitudeSqr(xy[, magnitude[, stream]]) -> magnitude\n```","ref":"Evision.CUDA.html#magnitudeSqr/2"},{"type":"function","title":"Evision.CUDA.magnitudeSqr/3","doc":"#### Variant 1:\nmagnitudeSqr\n\n##### Positional Arguments\n- **x**: `Evision.Mat`.\n\n  Source matrix containing real components ( CV_32FC1 ).\n\n- **y**: `Evision.Mat`.\n\n  Source matrix containing imaginary components ( CV_32FC1 ).\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **magnitude**: `Evision.Mat.t()`.\n\n  Destination matrix of float magnitude squares ( CV_32FC1 ).\n\nHas overloading in C++\n\ncomputes squared magnitude of each (x(i), y(i)) vector\nsupports only floating-point source\n\nPython prototype (for reference only):\n```python3\nmagnitudeSqr(x, y[, magnitude[, stream]]) -> magnitude\n```\n#### Variant 2:\nmagnitudeSqr\n\n##### Positional Arguments\n- **x**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix containing real components ( CV_32FC1 ).\n\n- **y**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix containing imaginary components ( CV_32FC1 ).\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **magnitude**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix of float magnitude squares ( CV_32FC1 ).\n\nHas overloading in C++\n\ncomputes squared magnitude of each (x(i), y(i)) vector\nsupports only floating-point source\n\nPython prototype (for reference only):\n```python3\nmagnitudeSqr(x, y[, magnitude[, stream]]) -> magnitude\n```","ref":"Evision.CUDA.html#magnitudeSqr/3"},{"type":"function","title":"Evision.CUDA.max/1","doc":"","ref":"Evision.CUDA.html#max/1"},{"type":"function","title":"Evision.CUDA.max/2","doc":"#### Variant 1:\nComputes the per-element maximum of two matrices (or a matrix and a scalar).\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.Mat`.\n\n  Second source matrix or scalar.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix that has the same size and type as the input array(s).\n\n@sa max\n\nPython prototype (for reference only):\n```python3\nmax(src1, src2[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nComputes the per-element maximum of two matrices (or a matrix and a scalar).\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second source matrix or scalar.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix that has the same size and type as the input array(s).\n\n@sa max\n\nPython prototype (for reference only):\n```python3\nmax(src1, src2[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#max/2"},{"type":"function","title":"Evision.CUDA.max/3","doc":"#### Variant 1:\nComputes the per-element maximum of two matrices (or a matrix and a scalar).\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.Mat`.\n\n  Second source matrix or scalar.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix that has the same size and type as the input array(s).\n\n@sa max\n\nPython prototype (for reference only):\n```python3\nmax(src1, src2[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nComputes the per-element maximum of two matrices (or a matrix and a scalar).\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second source matrix or scalar.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix that has the same size and type as the input array(s).\n\n@sa max\n\nPython prototype (for reference only):\n```python3\nmax(src1, src2[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#max/3"},{"type":"function","title":"Evision.CUDA.meanShiftFiltering/1","doc":"","ref":"Evision.CUDA.html#meanShiftFiltering/1"},{"type":"function","title":"Evision.CUDA.meanShiftFiltering/3","doc":"#### Variant 1:\nPerforms mean-shift filtering for each point of the source image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. Only CV_8UC4 images are supported for now.\n\n- **sp**: `integer()`.\n\n  Spatial window radius.\n\n- **sr**: `integer()`.\n\n  Color window radius.\n\n##### Keyword Arguments\n- **criteria**: `TermCriteria`.\n\n  Termination criteria. See TermCriteria.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image containing the color of mapped points. It has the same size and type\n  as src .\n\nIt maps each point of the source image into another point. As a result, you have a new color and new\nposition of each point.\n\nPython prototype (for reference only):\n```python3\nmeanShiftFiltering(src, sp, sr[, dst[, criteria[, stream]]]) -> dst\n```\n#### Variant 2:\nPerforms mean-shift filtering for each point of the source image.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. Only CV_8UC4 images are supported for now.\n\n- **sp**: `integer()`.\n\n  Spatial window radius.\n\n- **sr**: `integer()`.\n\n  Color window radius.\n\n##### Keyword Arguments\n- **criteria**: `TermCriteria`.\n\n  Termination criteria. See TermCriteria.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image containing the color of mapped points. It has the same size and type\n  as src .\n\nIt maps each point of the source image into another point. As a result, you have a new color and new\nposition of each point.\n\nPython prototype (for reference only):\n```python3\nmeanShiftFiltering(src, sp, sr[, dst[, criteria[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#meanShiftFiltering/3"},{"type":"function","title":"Evision.CUDA.meanShiftFiltering/4","doc":"#### Variant 1:\nPerforms mean-shift filtering for each point of the source image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. Only CV_8UC4 images are supported for now.\n\n- **sp**: `integer()`.\n\n  Spatial window radius.\n\n- **sr**: `integer()`.\n\n  Color window radius.\n\n##### Keyword Arguments\n- **criteria**: `TermCriteria`.\n\n  Termination criteria. See TermCriteria.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image containing the color of mapped points. It has the same size and type\n  as src .\n\nIt maps each point of the source image into another point. As a result, you have a new color and new\nposition of each point.\n\nPython prototype (for reference only):\n```python3\nmeanShiftFiltering(src, sp, sr[, dst[, criteria[, stream]]]) -> dst\n```\n#### Variant 2:\nPerforms mean-shift filtering for each point of the source image.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. Only CV_8UC4 images are supported for now.\n\n- **sp**: `integer()`.\n\n  Spatial window radius.\n\n- **sr**: `integer()`.\n\n  Color window radius.\n\n##### Keyword Arguments\n- **criteria**: `TermCriteria`.\n\n  Termination criteria. See TermCriteria.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image containing the color of mapped points. It has the same size and type\n  as src .\n\nIt maps each point of the source image into another point. As a result, you have a new color and new\nposition of each point.\n\nPython prototype (for reference only):\n```python3\nmeanShiftFiltering(src, sp, sr[, dst[, criteria[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#meanShiftFiltering/4"},{"type":"function","title":"Evision.CUDA.meanShiftProc/1","doc":"","ref":"Evision.CUDA.html#meanShiftProc/1"},{"type":"function","title":"Evision.CUDA.meanShiftProc/3","doc":"#### Variant 1:\nPerforms a mean-shift procedure and stores information about processed points (their colors and\npositions) in two images.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. Only CV_8UC4 images are supported for now.\n\n- **sp**: `integer()`.\n\n  Spatial window radius.\n\n- **sr**: `integer()`.\n\n  Color window radius.\n\n##### Keyword Arguments\n- **criteria**: `TermCriteria`.\n\n  Termination criteria. See TermCriteria.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dstr**: `Evision.Mat.t()`.\n\n  Destination image containing the color of mapped points. The size and type is the same\n  as src .\n\n- **dstsp**: `Evision.Mat.t()`.\n\n  Destination image containing the position of mapped points. The size is the same as\n  src size. The type is CV_16SC2 .\n\n@sa cuda::meanShiftFiltering\n\nPython prototype (for reference only):\n```python3\nmeanShiftProc(src, sp, sr[, dstr[, dstsp[, criteria[, stream]]]]) -> dstr, dstsp\n```\n#### Variant 2:\nPerforms a mean-shift procedure and stores information about processed points (their colors and\npositions) in two images.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. Only CV_8UC4 images are supported for now.\n\n- **sp**: `integer()`.\n\n  Spatial window radius.\n\n- **sr**: `integer()`.\n\n  Color window radius.\n\n##### Keyword Arguments\n- **criteria**: `TermCriteria`.\n\n  Termination criteria. See TermCriteria.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dstr**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image containing the color of mapped points. The size and type is the same\n  as src .\n\n- **dstsp**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image containing the position of mapped points. The size is the same as\n  src size. The type is CV_16SC2 .\n\n@sa cuda::meanShiftFiltering\n\nPython prototype (for reference only):\n```python3\nmeanShiftProc(src, sp, sr[, dstr[, dstsp[, criteria[, stream]]]]) -> dstr, dstsp\n```","ref":"Evision.CUDA.html#meanShiftProc/3"},{"type":"function","title":"Evision.CUDA.meanShiftProc/4","doc":"#### Variant 1:\nPerforms a mean-shift procedure and stores information about processed points (their colors and\npositions) in two images.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. Only CV_8UC4 images are supported for now.\n\n- **sp**: `integer()`.\n\n  Spatial window radius.\n\n- **sr**: `integer()`.\n\n  Color window radius.\n\n##### Keyword Arguments\n- **criteria**: `TermCriteria`.\n\n  Termination criteria. See TermCriteria.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dstr**: `Evision.Mat.t()`.\n\n  Destination image containing the color of mapped points. The size and type is the same\n  as src .\n\n- **dstsp**: `Evision.Mat.t()`.\n\n  Destination image containing the position of mapped points. The size is the same as\n  src size. The type is CV_16SC2 .\n\n@sa cuda::meanShiftFiltering\n\nPython prototype (for reference only):\n```python3\nmeanShiftProc(src, sp, sr[, dstr[, dstsp[, criteria[, stream]]]]) -> dstr, dstsp\n```\n#### Variant 2:\nPerforms a mean-shift procedure and stores information about processed points (their colors and\npositions) in two images.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. Only CV_8UC4 images are supported for now.\n\n- **sp**: `integer()`.\n\n  Spatial window radius.\n\n- **sr**: `integer()`.\n\n  Color window radius.\n\n##### Keyword Arguments\n- **criteria**: `TermCriteria`.\n\n  Termination criteria. See TermCriteria.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dstr**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image containing the color of mapped points. The size and type is the same\n  as src .\n\n- **dstsp**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image containing the position of mapped points. The size is the same as\n  src size. The type is CV_16SC2 .\n\n@sa cuda::meanShiftFiltering\n\nPython prototype (for reference only):\n```python3\nmeanShiftProc(src, sp, sr[, dstr[, dstsp[, criteria[, stream]]]]) -> dstr, dstsp\n```","ref":"Evision.CUDA.html#meanShiftProc/4"},{"type":"function","title":"Evision.CUDA.meanShiftSegmentation/1","doc":"","ref":"Evision.CUDA.html#meanShiftSegmentation/1"},{"type":"function","title":"Evision.CUDA.meanShiftSegmentation/4","doc":"#### Variant 1:\nPerforms a mean-shift segmentation of the source image and eliminates small segments.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. Only CV_8UC4 images are supported for now.\n\n- **sp**: `integer()`.\n\n  Spatial window radius.\n\n- **sr**: `integer()`.\n\n  Color window radius.\n\n- **minsize**: `integer()`.\n\n  Minimum segment size. Smaller segments are merged.\n\n##### Keyword Arguments\n- **criteria**: `TermCriteria`.\n\n  Termination criteria. See TermCriteria.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Segmented image with the same size and type as src (host or gpu memory).\n\nPython prototype (for reference only):\n```python3\nmeanShiftSegmentation(src, sp, sr, minsize[, dst[, criteria[, stream]]]) -> dst\n```\n#### Variant 2:\nPerforms a mean-shift segmentation of the source image and eliminates small segments.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. Only CV_8UC4 images are supported for now.\n\n- **sp**: `integer()`.\n\n  Spatial window radius.\n\n- **sr**: `integer()`.\n\n  Color window radius.\n\n- **minsize**: `integer()`.\n\n  Minimum segment size. Smaller segments are merged.\n\n##### Keyword Arguments\n- **criteria**: `TermCriteria`.\n\n  Termination criteria. See TermCriteria.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Segmented image with the same size and type as src (host or gpu memory).\n\nPython prototype (for reference only):\n```python3\nmeanShiftSegmentation(src, sp, sr, minsize[, dst[, criteria[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#meanShiftSegmentation/4"},{"type":"function","title":"Evision.CUDA.meanShiftSegmentation/5","doc":"#### Variant 1:\nPerforms a mean-shift segmentation of the source image and eliminates small segments.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. Only CV_8UC4 images are supported for now.\n\n- **sp**: `integer()`.\n\n  Spatial window radius.\n\n- **sr**: `integer()`.\n\n  Color window radius.\n\n- **minsize**: `integer()`.\n\n  Minimum segment size. Smaller segments are merged.\n\n##### Keyword Arguments\n- **criteria**: `TermCriteria`.\n\n  Termination criteria. See TermCriteria.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Segmented image with the same size and type as src (host or gpu memory).\n\nPython prototype (for reference only):\n```python3\nmeanShiftSegmentation(src, sp, sr, minsize[, dst[, criteria[, stream]]]) -> dst\n```\n#### Variant 2:\nPerforms a mean-shift segmentation of the source image and eliminates small segments.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. Only CV_8UC4 images are supported for now.\n\n- **sp**: `integer()`.\n\n  Spatial window radius.\n\n- **sr**: `integer()`.\n\n  Color window radius.\n\n- **minsize**: `integer()`.\n\n  Minimum segment size. Smaller segments are merged.\n\n##### Keyword Arguments\n- **criteria**: `TermCriteria`.\n\n  Termination criteria. See TermCriteria.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Segmented image with the same size and type as src (host or gpu memory).\n\nPython prototype (for reference only):\n```python3\nmeanShiftSegmentation(src, sp, sr, minsize[, dst[, criteria[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#meanShiftSegmentation/5"},{"type":"function","title":"Evision.CUDA.meanStdDev/1","doc":"#### Variant 1:\nmeanStdDev\n\n##### Positional Arguments\n- **mtx**: `Evision.Mat`.\n\n  Source matrix. CV_8UC1 and CV_32FC1 matrices are supported for now.\n\n##### Return\n- **mean**: `Evision.scalar().t()`.\n\n  Mean value.\n\n- **stddev**: `Evision.scalar().t()`.\n\n  Standard deviation value.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmeanStdDev(mtx) -> mean, stddev\n```\n#### Variant 2:\nmeanStdDev\n\n##### Positional Arguments\n- **mtx**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix. CV_8UC1 and CV_32FC1 matrices are supported for now.\n\n##### Return\n- **mean**: `Evision.scalar().t()`.\n\n  Mean value.\n\n- **stddev**: `Evision.scalar().t()`.\n\n  Standard deviation value.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmeanStdDev(mtx) -> mean, stddev\n```","ref":"Evision.CUDA.html#meanStdDev/1"},{"type":"function","title":"Evision.CUDA.meanStdDev/2","doc":"#### Variant 1:\nmeanStdDev\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source matrix. CV_8UC1 and CV_32FC1 matrices are supported for now.\n\n- **mask**: `Evision.Mat`.\n\n  Operation mask.\n\n##### Return\n- **mean**: `Evision.scalar().t()`.\n\n  Mean value.\n\n- **stddev**: `Evision.scalar().t()`.\n\n  Standard deviation value.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmeanStdDev(src, mask) -> mean, stddev\n```\n#### Variant 2:\nmeanStdDev\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix. CV_8UC1 and CV_32FC1 matrices are supported for now.\n\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Operation mask.\n\n##### Return\n- **mean**: `Evision.scalar().t()`.\n\n  Mean value.\n\n- **stddev**: `Evision.scalar().t()`.\n\n  Standard deviation value.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmeanStdDev(src, mask) -> mean, stddev\n```","ref":"Evision.CUDA.html#meanStdDev/2"},{"type":"function","title":"Evision.CUDA.merge/1","doc":"merge\n\n##### Positional Arguments\n- **src**: `[Evision.CUDA.GpuMat]`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmerge(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#merge/1"},{"type":"function","title":"Evision.CUDA.merge/2","doc":"merge\n\n##### Positional Arguments\n- **src**: `[Evision.CUDA.GpuMat]`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmerge(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#merge/2"},{"type":"function","title":"Evision.CUDA.min/1","doc":"","ref":"Evision.CUDA.html#min/1"},{"type":"function","title":"Evision.CUDA.min/2","doc":"#### Variant 1:\nComputes the per-element minimum of two matrices (or a matrix and a scalar).\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.Mat`.\n\n  Second source matrix or scalar.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix that has the same size and type as the input array(s).\n\n@sa min\n\nPython prototype (for reference only):\n```python3\nmin(src1, src2[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nComputes the per-element minimum of two matrices (or a matrix and a scalar).\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second source matrix or scalar.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix that has the same size and type as the input array(s).\n\n@sa min\n\nPython prototype (for reference only):\n```python3\nmin(src1, src2[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#min/2"},{"type":"function","title":"Evision.CUDA.min/3","doc":"#### Variant 1:\nComputes the per-element minimum of two matrices (or a matrix and a scalar).\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.Mat`.\n\n  Second source matrix or scalar.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix that has the same size and type as the input array(s).\n\n@sa min\n\nPython prototype (for reference only):\n```python3\nmin(src1, src2[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nComputes the per-element minimum of two matrices (or a matrix and a scalar).\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second source matrix or scalar.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix that has the same size and type as the input array(s).\n\n@sa min\n\nPython prototype (for reference only):\n```python3\nmin(src1, src2[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#min/3"},{"type":"function","title":"Evision.CUDA.minMax/1","doc":"#### Variant 1:\nFinds global minimum and maximum matrix elements and returns their values.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Single-channel source image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional mask to select a sub-matrix.\n\n##### Return\n- **minVal**: `double*`.\n\n  Pointer to the returned minimum value. Use NULL if not required.\n\n- **maxVal**: `double*`.\n\n  Pointer to the returned maximum value. Use NULL if not required.\n\nThe function does not work with CV_64F images on GPUs with the compute capability \\< 1.3.\n@sa minMaxLoc\n\nPython prototype (for reference only):\n```python3\nminMax(src[, mask]) -> minVal, maxVal\n```\n#### Variant 2:\nFinds global minimum and maximum matrix elements and returns their values.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Single-channel source image.\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Optional mask to select a sub-matrix.\n\n##### Return\n- **minVal**: `double*`.\n\n  Pointer to the returned minimum value. Use NULL if not required.\n\n- **maxVal**: `double*`.\n\n  Pointer to the returned maximum value. Use NULL if not required.\n\nThe function does not work with CV_64F images on GPUs with the compute capability \\< 1.3.\n@sa minMaxLoc\n\nPython prototype (for reference only):\n```python3\nminMax(src[, mask]) -> minVal, maxVal\n```","ref":"Evision.CUDA.html#minMax/1"},{"type":"function","title":"Evision.CUDA.minMax/2","doc":"#### Variant 1:\nFinds global minimum and maximum matrix elements and returns their values.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Single-channel source image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional mask to select a sub-matrix.\n\n##### Return\n- **minVal**: `double*`.\n\n  Pointer to the returned minimum value. Use NULL if not required.\n\n- **maxVal**: `double*`.\n\n  Pointer to the returned maximum value. Use NULL if not required.\n\nThe function does not work with CV_64F images on GPUs with the compute capability \\< 1.3.\n@sa minMaxLoc\n\nPython prototype (for reference only):\n```python3\nminMax(src[, mask]) -> minVal, maxVal\n```\n#### Variant 2:\nFinds global minimum and maximum matrix elements and returns their values.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Single-channel source image.\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Optional mask to select a sub-matrix.\n\n##### Return\n- **minVal**: `double*`.\n\n  Pointer to the returned minimum value. Use NULL if not required.\n\n- **maxVal**: `double*`.\n\n  Pointer to the returned maximum value. Use NULL if not required.\n\nThe function does not work with CV_64F images on GPUs with the compute capability \\< 1.3.\n@sa minMaxLoc\n\nPython prototype (for reference only):\n```python3\nminMax(src[, mask]) -> minVal, maxVal\n```","ref":"Evision.CUDA.html#minMax/2"},{"type":"function","title":"Evision.CUDA.minMaxLoc/1","doc":"#### Variant 1:\nFinds global minimum and maximum matrix elements and returns their values with locations.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Single-channel source image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional mask to select a sub-matrix.\n\n##### Return\n- **minVal**: `double*`.\n\n  Pointer to the returned minimum value. Use NULL if not required.\n\n- **maxVal**: `double*`.\n\n  Pointer to the returned maximum value. Use NULL if not required.\n\n- **minLoc**: `Point*`.\n\n  Pointer to the returned minimum location. Use NULL if not required.\n\n- **maxLoc**: `Point*`.\n\n  Pointer to the returned maximum location. Use NULL if not required.\n\nThe function does not work with CV_64F images on GPU with the compute capability \\< 1.3.\n@sa minMaxLoc\n\nPython prototype (for reference only):\n```python3\nminMaxLoc(src[, mask]) -> minVal, maxVal, minLoc, maxLoc\n```\n#### Variant 2:\nFinds global minimum and maximum matrix elements and returns their values with locations.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Single-channel source image.\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Optional mask to select a sub-matrix.\n\n##### Return\n- **minVal**: `double*`.\n\n  Pointer to the returned minimum value. Use NULL if not required.\n\n- **maxVal**: `double*`.\n\n  Pointer to the returned maximum value. Use NULL if not required.\n\n- **minLoc**: `Point*`.\n\n  Pointer to the returned minimum location. Use NULL if not required.\n\n- **maxLoc**: `Point*`.\n\n  Pointer to the returned maximum location. Use NULL if not required.\n\nThe function does not work with CV_64F images on GPU with the compute capability \\< 1.3.\n@sa minMaxLoc\n\nPython prototype (for reference only):\n```python3\nminMaxLoc(src[, mask]) -> minVal, maxVal, minLoc, maxLoc\n```","ref":"Evision.CUDA.html#minMaxLoc/1"},{"type":"function","title":"Evision.CUDA.minMaxLoc/2","doc":"#### Variant 1:\nFinds global minimum and maximum matrix elements and returns their values with locations.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Single-channel source image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional mask to select a sub-matrix.\n\n##### Return\n- **minVal**: `double*`.\n\n  Pointer to the returned minimum value. Use NULL if not required.\n\n- **maxVal**: `double*`.\n\n  Pointer to the returned maximum value. Use NULL if not required.\n\n- **minLoc**: `Point*`.\n\n  Pointer to the returned minimum location. Use NULL if not required.\n\n- **maxLoc**: `Point*`.\n\n  Pointer to the returned maximum location. Use NULL if not required.\n\nThe function does not work with CV_64F images on GPU with the compute capability \\< 1.3.\n@sa minMaxLoc\n\nPython prototype (for reference only):\n```python3\nminMaxLoc(src[, mask]) -> minVal, maxVal, minLoc, maxLoc\n```\n#### Variant 2:\nFinds global minimum and maximum matrix elements and returns their values with locations.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Single-channel source image.\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Optional mask to select a sub-matrix.\n\n##### Return\n- **minVal**: `double*`.\n\n  Pointer to the returned minimum value. Use NULL if not required.\n\n- **maxVal**: `double*`.\n\n  Pointer to the returned maximum value. Use NULL if not required.\n\n- **minLoc**: `Point*`.\n\n  Pointer to the returned minimum location. Use NULL if not required.\n\n- **maxLoc**: `Point*`.\n\n  Pointer to the returned maximum location. Use NULL if not required.\n\nThe function does not work with CV_64F images on GPU with the compute capability \\< 1.3.\n@sa minMaxLoc\n\nPython prototype (for reference only):\n```python3\nminMaxLoc(src[, mask]) -> minVal, maxVal, minLoc, maxLoc\n```","ref":"Evision.CUDA.html#minMaxLoc/2"},{"type":"function","title":"Evision.CUDA.moments/1","doc":"#### Variant 1:\nCalculates all of the moments up to the 3rd order of a rasterized shape.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Raster image (single-channel 2D array).\n\n##### Keyword Arguments\n- **binaryImage**: `bool`.\n\n  If it is true, all non-zero image pixels are treated as 1's.\n\n- **order**: `MomentsOrder`.\n\n  Order of largest moments to calculate with lower order moments requiring less computation.\n\n- **momentsType**: `integer()`.\n\n  Precision to use when calculating moments. Available types are \\ref CV_32F and \\ref CV_64F with the performance of \\ref CV_32F an order of magnitude greater than \\ref CV_64F. If the image is small the accuracy from \\ref CV_32F can be equal or very close to \\ref CV_64F.\n\n##### Return\n- **retval**: `Moments`\n\nThe function computes moments, up to the 3rd order, of a rasterized shape. The\nresults are returned in the structure cv::Moments.\n\n**Note**: For maximum performance use the asynchronous version cuda::spatialMoments() as this version interally allocates and deallocates both GpuMat and HostMem to respectively perform the calculation on the device and download the result to the host.\nThe costly HostMem allocation cannot be avoided however the GpuMat device allocation can be by using BufferPool, e.g.\n```\nsetBufferPoolUsage(true);\nsetBufferPoolConfig(getDevice(), numMoments(order) * ((momentsType == CV_64F) ? sizeof(double) : sizeof(float)), 1);\n```\nsee the \\a CUDA_TEST_P(Moments, Accuracy) test inside opencv_contrib_source_code/modules/cudaimgproc/test/test_moments.cpp for an example.\n@returns cv::Moments.\n@sa cuda::spatialMoments, cuda::convertSpatialMoments, cuda::numMoments, cuda::MomentsOrder\n\nPython prototype (for reference only):\n```python3\nmoments(src[, binaryImage[, order[, momentsType]]]) -> retval\n```\n#### Variant 2:\nCalculates all of the moments up to the 3rd order of a rasterized shape.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Raster image (single-channel 2D array).\n\n##### Keyword Arguments\n- **binaryImage**: `bool`.\n\n  If it is true, all non-zero image pixels are treated as 1's.\n\n- **order**: `MomentsOrder`.\n\n  Order of largest moments to calculate with lower order moments requiring less computation.\n\n- **momentsType**: `integer()`.\n\n  Precision to use when calculating moments. Available types are \\ref CV_32F and \\ref CV_64F with the performance of \\ref CV_32F an order of magnitude greater than \\ref CV_64F. If the image is small the accuracy from \\ref CV_32F can be equal or very close to \\ref CV_64F.\n\n##### Return\n- **retval**: `Moments`\n\nThe function computes moments, up to the 3rd order, of a rasterized shape. The\nresults are returned in the structure cv::Moments.\n\n**Note**: For maximum performance use the asynchronous version cuda::spatialMoments() as this version interally allocates and deallocates both GpuMat and HostMem to respectively perform the calculation on the device and download the result to the host.\nThe costly HostMem allocation cannot be avoided however the GpuMat device allocation can be by using BufferPool, e.g.\n```\nsetBufferPoolUsage(true);\nsetBufferPoolConfig(getDevice(), numMoments(order) * ((momentsType == CV_64F) ? sizeof(double) : sizeof(float)), 1);\n```\nsee the \\a CUDA_TEST_P(Moments, Accuracy) test inside opencv_contrib_source_code/modules/cudaimgproc/test/test_moments.cpp for an example.\n@returns cv::Moments.\n@sa cuda::spatialMoments, cuda::convertSpatialMoments, cuda::numMoments, cuda::MomentsOrder\n\nPython prototype (for reference only):\n```python3\nmoments(src[, binaryImage[, order[, momentsType]]]) -> retval\n```","ref":"Evision.CUDA.html#moments/1"},{"type":"function","title":"Evision.CUDA.moments/2","doc":"#### Variant 1:\nCalculates all of the moments up to the 3rd order of a rasterized shape.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Raster image (single-channel 2D array).\n\n##### Keyword Arguments\n- **binaryImage**: `bool`.\n\n  If it is true, all non-zero image pixels are treated as 1's.\n\n- **order**: `MomentsOrder`.\n\n  Order of largest moments to calculate with lower order moments requiring less computation.\n\n- **momentsType**: `integer()`.\n\n  Precision to use when calculating moments. Available types are \\ref CV_32F and \\ref CV_64F with the performance of \\ref CV_32F an order of magnitude greater than \\ref CV_64F. If the image is small the accuracy from \\ref CV_32F can be equal or very close to \\ref CV_64F.\n\n##### Return\n- **retval**: `Moments`\n\nThe function computes moments, up to the 3rd order, of a rasterized shape. The\nresults are returned in the structure cv::Moments.\n\n**Note**: For maximum performance use the asynchronous version cuda::spatialMoments() as this version interally allocates and deallocates both GpuMat and HostMem to respectively perform the calculation on the device and download the result to the host.\nThe costly HostMem allocation cannot be avoided however the GpuMat device allocation can be by using BufferPool, e.g.\n```\nsetBufferPoolUsage(true);\nsetBufferPoolConfig(getDevice(), numMoments(order) * ((momentsType == CV_64F) ? sizeof(double) : sizeof(float)), 1);\n```\nsee the \\a CUDA_TEST_P(Moments, Accuracy) test inside opencv_contrib_source_code/modules/cudaimgproc/test/test_moments.cpp for an example.\n@returns cv::Moments.\n@sa cuda::spatialMoments, cuda::convertSpatialMoments, cuda::numMoments, cuda::MomentsOrder\n\nPython prototype (for reference only):\n```python3\nmoments(src[, binaryImage[, order[, momentsType]]]) -> retval\n```\n#### Variant 2:\nCalculates all of the moments up to the 3rd order of a rasterized shape.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Raster image (single-channel 2D array).\n\n##### Keyword Arguments\n- **binaryImage**: `bool`.\n\n  If it is true, all non-zero image pixels are treated as 1's.\n\n- **order**: `MomentsOrder`.\n\n  Order of largest moments to calculate with lower order moments requiring less computation.\n\n- **momentsType**: `integer()`.\n\n  Precision to use when calculating moments. Available types are \\ref CV_32F and \\ref CV_64F with the performance of \\ref CV_32F an order of magnitude greater than \\ref CV_64F. If the image is small the accuracy from \\ref CV_32F can be equal or very close to \\ref CV_64F.\n\n##### Return\n- **retval**: `Moments`\n\nThe function computes moments, up to the 3rd order, of a rasterized shape. The\nresults are returned in the structure cv::Moments.\n\n**Note**: For maximum performance use the asynchronous version cuda::spatialMoments() as this version interally allocates and deallocates both GpuMat and HostMem to respectively perform the calculation on the device and download the result to the host.\nThe costly HostMem allocation cannot be avoided however the GpuMat device allocation can be by using BufferPool, e.g.\n```\nsetBufferPoolUsage(true);\nsetBufferPoolConfig(getDevice(), numMoments(order) * ((momentsType == CV_64F) ? sizeof(double) : sizeof(float)), 1);\n```\nsee the \\a CUDA_TEST_P(Moments, Accuracy) test inside opencv_contrib_source_code/modules/cudaimgproc/test/test_moments.cpp for an example.\n@returns cv::Moments.\n@sa cuda::spatialMoments, cuda::convertSpatialMoments, cuda::numMoments, cuda::MomentsOrder\n\nPython prototype (for reference only):\n```python3\nmoments(src[, binaryImage[, order[, momentsType]]]) -> retval\n```","ref":"Evision.CUDA.html#moments/2"},{"type":"function","title":"Evision.CUDA.mulAndScaleSpectrums/1","doc":"","ref":"Evision.CUDA.html#mulAndScaleSpectrums/1"},{"type":"function","title":"Evision.CUDA.mulAndScaleSpectrums/4","doc":"#### Variant 1:\nPerforms a per-element multiplication of two Fourier spectrums and scales the result.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First spectrum.\n\n- **src2**: `Evision.Mat`.\n\n  Second spectrum with the same size and type as a .\n\n- **flags**: `integer()`.\n\n  Mock parameter used for CPU/CUDA interfaces similarity, simply add a `0` value.\n\n- **scale**: `float`.\n\n  Scale constant.\n\n##### Keyword Arguments\n- **conjB**: `bool`.\n\n  Optional flag to specify if the second spectrum needs to be conjugated before the\n  multiplication.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination spectrum.\n\nOnly full (not packed) CV_32FC2 complex spectrums in the interleaved format are supported for now.\n@sa mulSpectrums\n\nPython prototype (for reference only):\n```python3\nmulAndScaleSpectrums(src1, src2, flags, scale[, dst[, conjB[, stream]]]) -> dst\n```\n#### Variant 2:\nPerforms a per-element multiplication of two Fourier spectrums and scales the result.\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First spectrum.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second spectrum with the same size and type as a .\n\n- **flags**: `integer()`.\n\n  Mock parameter used for CPU/CUDA interfaces similarity, simply add a `0` value.\n\n- **scale**: `float`.\n\n  Scale constant.\n\n##### Keyword Arguments\n- **conjB**: `bool`.\n\n  Optional flag to specify if the second spectrum needs to be conjugated before the\n  multiplication.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination spectrum.\n\nOnly full (not packed) CV_32FC2 complex spectrums in the interleaved format are supported for now.\n@sa mulSpectrums\n\nPython prototype (for reference only):\n```python3\nmulAndScaleSpectrums(src1, src2, flags, scale[, dst[, conjB[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#mulAndScaleSpectrums/4"},{"type":"function","title":"Evision.CUDA.mulAndScaleSpectrums/5","doc":"#### Variant 1:\nPerforms a per-element multiplication of two Fourier spectrums and scales the result.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First spectrum.\n\n- **src2**: `Evision.Mat`.\n\n  Second spectrum with the same size and type as a .\n\n- **flags**: `integer()`.\n\n  Mock parameter used for CPU/CUDA interfaces similarity, simply add a `0` value.\n\n- **scale**: `float`.\n\n  Scale constant.\n\n##### Keyword Arguments\n- **conjB**: `bool`.\n\n  Optional flag to specify if the second spectrum needs to be conjugated before the\n  multiplication.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination spectrum.\n\nOnly full (not packed) CV_32FC2 complex spectrums in the interleaved format are supported for now.\n@sa mulSpectrums\n\nPython prototype (for reference only):\n```python3\nmulAndScaleSpectrums(src1, src2, flags, scale[, dst[, conjB[, stream]]]) -> dst\n```\n#### Variant 2:\nPerforms a per-element multiplication of two Fourier spectrums and scales the result.\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First spectrum.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second spectrum with the same size and type as a .\n\n- **flags**: `integer()`.\n\n  Mock parameter used for CPU/CUDA interfaces similarity, simply add a `0` value.\n\n- **scale**: `float`.\n\n  Scale constant.\n\n##### Keyword Arguments\n- **conjB**: `bool`.\n\n  Optional flag to specify if the second spectrum needs to be conjugated before the\n  multiplication.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination spectrum.\n\nOnly full (not packed) CV_32FC2 complex spectrums in the interleaved format are supported for now.\n@sa mulSpectrums\n\nPython prototype (for reference only):\n```python3\nmulAndScaleSpectrums(src1, src2, flags, scale[, dst[, conjB[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#mulAndScaleSpectrums/5"},{"type":"function","title":"Evision.CUDA.mulSpectrums/1","doc":"","ref":"Evision.CUDA.html#mulSpectrums/1"},{"type":"function","title":"Evision.CUDA.mulSpectrums/3","doc":"#### Variant 1:\nPerforms a per-element multiplication of two Fourier spectrums.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First spectrum.\n\n- **src2**: `Evision.Mat`.\n\n  Second spectrum with the same size and type as a .\n\n- **flags**: `integer()`.\n\n  Mock parameter used for CPU/CUDA interfaces similarity.\n\n##### Keyword Arguments\n- **conjB**: `bool`.\n\n  Optional flag to specify if the second spectrum needs to be conjugated before the\n  multiplication.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination spectrum.\n\nOnly full (not packed) CV_32FC2 complex spectrums in the interleaved format are supported for now.\n@sa mulSpectrums\n\nPython prototype (for reference only):\n```python3\nmulSpectrums(src1, src2, flags[, dst[, conjB[, stream]]]) -> dst\n```\n#### Variant 2:\nPerforms a per-element multiplication of two Fourier spectrums.\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First spectrum.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second spectrum with the same size and type as a .\n\n- **flags**: `integer()`.\n\n  Mock parameter used for CPU/CUDA interfaces similarity.\n\n##### Keyword Arguments\n- **conjB**: `bool`.\n\n  Optional flag to specify if the second spectrum needs to be conjugated before the\n  multiplication.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination spectrum.\n\nOnly full (not packed) CV_32FC2 complex spectrums in the interleaved format are supported for now.\n@sa mulSpectrums\n\nPython prototype (for reference only):\n```python3\nmulSpectrums(src1, src2, flags[, dst[, conjB[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#mulSpectrums/3"},{"type":"function","title":"Evision.CUDA.mulSpectrums/4","doc":"#### Variant 1:\nPerforms a per-element multiplication of two Fourier spectrums.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First spectrum.\n\n- **src2**: `Evision.Mat`.\n\n  Second spectrum with the same size and type as a .\n\n- **flags**: `integer()`.\n\n  Mock parameter used for CPU/CUDA interfaces similarity.\n\n##### Keyword Arguments\n- **conjB**: `bool`.\n\n  Optional flag to specify if the second spectrum needs to be conjugated before the\n  multiplication.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination spectrum.\n\nOnly full (not packed) CV_32FC2 complex spectrums in the interleaved format are supported for now.\n@sa mulSpectrums\n\nPython prototype (for reference only):\n```python3\nmulSpectrums(src1, src2, flags[, dst[, conjB[, stream]]]) -> dst\n```\n#### Variant 2:\nPerforms a per-element multiplication of two Fourier spectrums.\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First spectrum.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second spectrum with the same size and type as a .\n\n- **flags**: `integer()`.\n\n  Mock parameter used for CPU/CUDA interfaces similarity.\n\n##### Keyword Arguments\n- **conjB**: `bool`.\n\n  Optional flag to specify if the second spectrum needs to be conjugated before the\n  multiplication.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination spectrum.\n\nOnly full (not packed) CV_32FC2 complex spectrums in the interleaved format are supported for now.\n@sa mulSpectrums\n\nPython prototype (for reference only):\n```python3\nmulSpectrums(src1, src2, flags[, dst[, conjB[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#mulSpectrums/4"},{"type":"function","title":"Evision.CUDA.multiply/1","doc":"","ref":"Evision.CUDA.html#multiply/1"},{"type":"function","title":"Evision.CUDA.multiply/2","doc":"#### Variant 1:\nComputes a matrix-matrix or matrix-scalar per-element product.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.Mat`.\n\n  Second source matrix or scalar.\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Optional scale factor.\n\n- **dtype**: `integer()`.\n\n  Optional depth of the output array.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix that has the same size and number of channels as the input array(s).\n  The depth is defined by dtype or src1 depth.\n\n@sa multiply\n\nPython prototype (for reference only):\n```python3\nmultiply(src1, src2[, dst[, scale[, dtype[, stream]]]]) -> dst\n```\n#### Variant 2:\nComputes a matrix-matrix or matrix-scalar per-element product.\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second source matrix or scalar.\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Optional scale factor.\n\n- **dtype**: `integer()`.\n\n  Optional depth of the output array.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix that has the same size and number of channels as the input array(s).\n  The depth is defined by dtype or src1 depth.\n\n@sa multiply\n\nPython prototype (for reference only):\n```python3\nmultiply(src1, src2[, dst[, scale[, dtype[, stream]]]]) -> dst\n```","ref":"Evision.CUDA.html#multiply/2"},{"type":"function","title":"Evision.CUDA.multiply/3","doc":"#### Variant 1:\nComputes a matrix-matrix or matrix-scalar per-element product.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.Mat`.\n\n  Second source matrix or scalar.\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Optional scale factor.\n\n- **dtype**: `integer()`.\n\n  Optional depth of the output array.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix that has the same size and number of channels as the input array(s).\n  The depth is defined by dtype or src1 depth.\n\n@sa multiply\n\nPython prototype (for reference only):\n```python3\nmultiply(src1, src2[, dst[, scale[, dtype[, stream]]]]) -> dst\n```\n#### Variant 2:\nComputes a matrix-matrix or matrix-scalar per-element product.\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second source matrix or scalar.\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Optional scale factor.\n\n- **dtype**: `integer()`.\n\n  Optional depth of the output array.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix that has the same size and number of channels as the input array(s).\n  The depth is defined by dtype or src1 depth.\n\n@sa multiply\n\nPython prototype (for reference only):\n```python3\nmultiply(src1, src2[, dst[, scale[, dtype[, stream]]]]) -> dst\n```","ref":"Evision.CUDA.html#multiply/3"},{"type":"function","title":"Evision.CUDA.nonLocalMeans/1","doc":"","ref":"Evision.CUDA.html#nonLocalMeans/1"},{"type":"function","title":"Evision.CUDA.nonLocalMeans/2","doc":"Performs pure non local means denoising without any simplification, and thus it is not fast.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. Supports only CV_8UC1, CV_8UC2 and CV_8UC3.\n\n- **h**: `float`.\n\n  Filter sigma regulating filter strength for color.\n\n##### Keyword Arguments\n- **search_window**: `integer()`.\n\n  Size of search window.\n\n- **block_size**: `integer()`.\n\n  Size of block used for computing weights.\n\n- **borderMode**: `integer()`.\n\n  Border type. See borderInterpolate for details. BORDER_REFLECT101 ,\n  BORDER_REPLICATE , BORDER_CONSTANT , BORDER_REFLECT and BORDER_WRAP are supported for now.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image.\n\n@sa\nfastNlMeansDenoising\n\nPython prototype (for reference only):\n```python3\nnonLocalMeans(src, h[, dst[, search_window[, block_size[, borderMode[, stream]]]]]) -> dst\n```","ref":"Evision.CUDA.html#nonLocalMeans/2"},{"type":"function","title":"Evision.CUDA.nonLocalMeans/3","doc":"Performs pure non local means denoising without any simplification, and thus it is not fast.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. Supports only CV_8UC1, CV_8UC2 and CV_8UC3.\n\n- **h**: `float`.\n\n  Filter sigma regulating filter strength for color.\n\n##### Keyword Arguments\n- **search_window**: `integer()`.\n\n  Size of search window.\n\n- **block_size**: `integer()`.\n\n  Size of block used for computing weights.\n\n- **borderMode**: `integer()`.\n\n  Border type. See borderInterpolate for details. BORDER_REFLECT101 ,\n  BORDER_REPLICATE , BORDER_CONSTANT , BORDER_REFLECT and BORDER_WRAP are supported for now.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image.\n\n@sa\nfastNlMeansDenoising\n\nPython prototype (for reference only):\n```python3\nnonLocalMeans(src, h[, dst[, search_window[, block_size[, borderMode[, stream]]]]]) -> dst\n```","ref":"Evision.CUDA.html#nonLocalMeans/3"},{"type":"function","title":"Evision.CUDA.norm/1","doc":"","ref":"Evision.CUDA.html#norm/1"},{"type":"function","title":"Evision.CUDA.norm/2","doc":"#### Variant 1:\nReturns the difference of two matrices.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  Source matrix. Any matrices except 64F are supported.\n\n- **src2**: `Evision.Mat`.\n\n  Second source matrix (if any) with the same size and type as src1.\n\n##### Keyword Arguments\n- **normType**: `integer()`.\n\n  Norm type. NORM_L1 , NORM_L2 , and NORM_INF are supported for now.\n\n##### Return\n- **retval**: `double`\n\n@sa norm\n\nPython prototype (for reference only):\n```python3\nnorm(src1, src2[, normType]) -> retval\n```\n#### Variant 2:\nReturns the difference of two matrices.\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix. Any matrices except 64F are supported.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second source matrix (if any) with the same size and type as src1.\n\n##### Keyword Arguments\n- **normType**: `integer()`.\n\n  Norm type. NORM_L1 , NORM_L2 , and NORM_INF are supported for now.\n\n##### Return\n- **retval**: `double`\n\n@sa norm\n\nPython prototype (for reference only):\n```python3\nnorm(src1, src2[, normType]) -> retval\n```\n#### Variant 3:\nReturns the norm of a matrix (or difference of two matrices).\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  Source matrix. Any matrices except 64F are supported.\n\n- **normType**: `integer()`.\n\n  Norm type. NORM_L1 , NORM_L2 , and NORM_INF are supported for now.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  optional operation mask; it must have the same size as src1 and CV_8UC1 type.\n\n##### Return\n- **retval**: `double`\n\n@sa norm\n\nPython prototype (for reference only):\n```python3\nnorm(src1, normType[, mask]) -> retval\n```\n#### Variant 4:\nReturns the norm of a matrix (or difference of two matrices).\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix. Any matrices except 64F are supported.\n\n- **normType**: `integer()`.\n\n  Norm type. NORM_L1 , NORM_L2 , and NORM_INF are supported for now.\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  optional operation mask; it must have the same size as src1 and CV_8UC1 type.\n\n##### Return\n- **retval**: `double`\n\n@sa norm\n\nPython prototype (for reference only):\n```python3\nnorm(src1, normType[, mask]) -> retval\n```","ref":"Evision.CUDA.html#norm/2"},{"type":"function","title":"Evision.CUDA.norm/3","doc":"#### Variant 1:\nReturns the difference of two matrices.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  Source matrix. Any matrices except 64F are supported.\n\n- **src2**: `Evision.Mat`.\n\n  Second source matrix (if any) with the same size and type as src1.\n\n##### Keyword Arguments\n- **normType**: `integer()`.\n\n  Norm type. NORM_L1 , NORM_L2 , and NORM_INF are supported for now.\n\n##### Return\n- **retval**: `double`\n\n@sa norm\n\nPython prototype (for reference only):\n```python3\nnorm(src1, src2[, normType]) -> retval\n```\n#### Variant 2:\nReturns the difference of two matrices.\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix. Any matrices except 64F are supported.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second source matrix (if any) with the same size and type as src1.\n\n##### Keyword Arguments\n- **normType**: `integer()`.\n\n  Norm type. NORM_L1 , NORM_L2 , and NORM_INF are supported for now.\n\n##### Return\n- **retval**: `double`\n\n@sa norm\n\nPython prototype (for reference only):\n```python3\nnorm(src1, src2[, normType]) -> retval\n```\n#### Variant 3:\nReturns the norm of a matrix (or difference of two matrices).\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  Source matrix. Any matrices except 64F are supported.\n\n- **normType**: `integer()`.\n\n  Norm type. NORM_L1 , NORM_L2 , and NORM_INF are supported for now.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  optional operation mask; it must have the same size as src1 and CV_8UC1 type.\n\n##### Return\n- **retval**: `double`\n\n@sa norm\n\nPython prototype (for reference only):\n```python3\nnorm(src1, normType[, mask]) -> retval\n```\n#### Variant 4:\nReturns the norm of a matrix (or difference of two matrices).\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix. Any matrices except 64F are supported.\n\n- **normType**: `integer()`.\n\n  Norm type. NORM_L1 , NORM_L2 , and NORM_INF are supported for now.\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  optional operation mask; it must have the same size as src1 and CV_8UC1 type.\n\n##### Return\n- **retval**: `double`\n\n@sa norm\n\nPython prototype (for reference only):\n```python3\nnorm(src1, normType[, mask]) -> retval\n```","ref":"Evision.CUDA.html#norm/3"},{"type":"function","title":"Evision.CUDA.normalize/1","doc":"","ref":"Evision.CUDA.html#normalize/1"},{"type":"function","title":"Evision.CUDA.normalize/5","doc":"#### Variant 1:\nNormalizes the norm or value range of an array.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input array.\n\n- **alpha**: `double`.\n\n  Norm value to normalize to or the lower range boundary in case of the range\n  normalization.\n\n- **beta**: `double`.\n\n  Upper range boundary in case of the range normalization; it is not used for the norm\n  normalization.\n\n- **norm_type**: `integer()`.\n\n  Normalization type ( NORM_MINMAX , NORM_L2 , NORM_L1 or NORM_INF ).\n\n- **dtype**: `integer()`.\n\n  When negative, the output array has the same type as src; otherwise, it has the same\n  number of channels as src and the depth =CV_MAT_DEPTH(dtype).\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional operation mask.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output array of the same size as src .\n\n@sa normalize\n\nPython prototype (for reference only):\n```python3\nnormalize(src, alpha, beta, norm_type, dtype[, dst[, mask[, stream]]]) -> dst\n```\n#### Variant 2:\nNormalizes the norm or value range of an array.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Input array.\n\n- **alpha**: `double`.\n\n  Norm value to normalize to or the lower range boundary in case of the range\n  normalization.\n\n- **beta**: `double`.\n\n  Upper range boundary in case of the range normalization; it is not used for the norm\n  normalization.\n\n- **norm_type**: `integer()`.\n\n  Normalization type ( NORM_MINMAX , NORM_L2 , NORM_L1 or NORM_INF ).\n\n- **dtype**: `integer()`.\n\n  When negative, the output array has the same type as src; otherwise, it has the same\n  number of channels as src and the depth =CV_MAT_DEPTH(dtype).\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Optional operation mask.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Output array of the same size as src .\n\n@sa normalize\n\nPython prototype (for reference only):\n```python3\nnormalize(src, alpha, beta, norm_type, dtype[, dst[, mask[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#normalize/5"},{"type":"function","title":"Evision.CUDA.normalize/6","doc":"#### Variant 1:\nNormalizes the norm or value range of an array.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input array.\n\n- **alpha**: `double`.\n\n  Norm value to normalize to or the lower range boundary in case of the range\n  normalization.\n\n- **beta**: `double`.\n\n  Upper range boundary in case of the range normalization; it is not used for the norm\n  normalization.\n\n- **norm_type**: `integer()`.\n\n  Normalization type ( NORM_MINMAX , NORM_L2 , NORM_L1 or NORM_INF ).\n\n- **dtype**: `integer()`.\n\n  When negative, the output array has the same type as src; otherwise, it has the same\n  number of channels as src and the depth =CV_MAT_DEPTH(dtype).\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional operation mask.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output array of the same size as src .\n\n@sa normalize\n\nPython prototype (for reference only):\n```python3\nnormalize(src, alpha, beta, norm_type, dtype[, dst[, mask[, stream]]]) -> dst\n```\n#### Variant 2:\nNormalizes the norm or value range of an array.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Input array.\n\n- **alpha**: `double`.\n\n  Norm value to normalize to or the lower range boundary in case of the range\n  normalization.\n\n- **beta**: `double`.\n\n  Upper range boundary in case of the range normalization; it is not used for the norm\n  normalization.\n\n- **norm_type**: `integer()`.\n\n  Normalization type ( NORM_MINMAX , NORM_L2 , NORM_L1 or NORM_INF ).\n\n- **dtype**: `integer()`.\n\n  When negative, the output array has the same type as src; otherwise, it has the same\n  number of channels as src and the depth =CV_MAT_DEPTH(dtype).\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Optional operation mask.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Output array of the same size as src .\n\n@sa normalize\n\nPython prototype (for reference only):\n```python3\nnormalize(src, alpha, beta, norm_type, dtype[, dst[, mask[, stream]]]) -> dst\n```","ref":"Evision.CUDA.html#normalize/6"},{"type":"function","title":"Evision.CUDA.numMoments/1","doc":"Returns the number of image moments less than or equal to the largest image moments \\a order.\n\n##### Positional Arguments\n- **order**: `MomentsOrder`.\n\n  Order of largest moments to calculate with lower order moments requiring less computation.\n\n##### Return\n- **retval**: `integer()`\n\n@returns number of image moments.\n@sa cuda::spatialMoments, cuda::moments, cuda::MomentsOrder\n\nPython prototype (for reference only):\n```python3\nnumMoments(order) -> retval\n```","ref":"Evision.CUDA.html#numMoments/1"},{"type":"function","title":"Evision.CUDA.phase/1","doc":"","ref":"Evision.CUDA.html#phase/1"},{"type":"function","title":"Evision.CUDA.phase/2","doc":"#### Variant 1:\nComputes polar angles of complex matrix elements.\n\n##### Positional Arguments\n- **x**: `Evision.Mat`.\n\n  Source matrix containing real components ( CV_32FC1 ).\n\n- **y**: `Evision.Mat`.\n\n  Source matrix containing imaginary components ( CV_32FC1 ).\n\n##### Keyword Arguments\n- **angleInDegrees**: `bool`.\n\n  Flag for angles that must be evaluated in degrees.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **angle**: `Evision.Mat.t()`.\n\n  Destination matrix of angles ( CV_32FC1 ).\n\n@sa phase\n\nPython prototype (for reference only):\n```python3\nphase(x, y[, angle[, angleInDegrees[, stream]]]) -> angle\n```\n#### Variant 2:\nComputes polar angles of complex matrix elements.\n\n##### Positional Arguments\n- **x**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix containing real components ( CV_32FC1 ).\n\n- **y**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix containing imaginary components ( CV_32FC1 ).\n\n##### Keyword Arguments\n- **angleInDegrees**: `bool`.\n\n  Flag for angles that must be evaluated in degrees.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **angle**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix of angles ( CV_32FC1 ).\n\n@sa phase\n\nPython prototype (for reference only):\n```python3\nphase(x, y[, angle[, angleInDegrees[, stream]]]) -> angle\n```","ref":"Evision.CUDA.html#phase/2"},{"type":"function","title":"Evision.CUDA.phase/3","doc":"#### Variant 1:\nComputes polar angles of complex matrix elements.\n\n##### Positional Arguments\n- **x**: `Evision.Mat`.\n\n  Source matrix containing real components ( CV_32FC1 ).\n\n- **y**: `Evision.Mat`.\n\n  Source matrix containing imaginary components ( CV_32FC1 ).\n\n##### Keyword Arguments\n- **angleInDegrees**: `bool`.\n\n  Flag for angles that must be evaluated in degrees.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **angle**: `Evision.Mat.t()`.\n\n  Destination matrix of angles ( CV_32FC1 ).\n\n@sa phase\n\nPython prototype (for reference only):\n```python3\nphase(x, y[, angle[, angleInDegrees[, stream]]]) -> angle\n```\n#### Variant 2:\nComputes polar angles of complex matrix elements.\n\n##### Positional Arguments\n- **x**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix containing real components ( CV_32FC1 ).\n\n- **y**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix containing imaginary components ( CV_32FC1 ).\n\n##### Keyword Arguments\n- **angleInDegrees**: `bool`.\n\n  Flag for angles that must be evaluated in degrees.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **angle**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix of angles ( CV_32FC1 ).\n\n@sa phase\n\nPython prototype (for reference only):\n```python3\nphase(x, y[, angle[, angleInDegrees[, stream]]]) -> angle\n```","ref":"Evision.CUDA.html#phase/3"},{"type":"function","title":"Evision.CUDA.polarToCart/1","doc":"","ref":"Evision.CUDA.html#polarToCart/1"},{"type":"function","title":"Evision.CUDA.polarToCart/2","doc":"#### Variant 1:\nConverts polar coordinates into Cartesian.\n\n##### Positional Arguments\n- **magnitude**: `Evision.Mat`.\n\n  Source matrix containing magnitudes ( CV_32FC1 or CV_64FC1 ).\n\n- **angle**: `Evision.Mat`.\n\n  Source matrix containing angles ( same type as magnitude ).\n\n##### Keyword Arguments\n- **angleInDegrees**: `bool`.\n\n  Flag that indicates angles in degrees.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **x**: `Evision.Mat.t()`.\n\n  Destination matrix of real components ( same type as magnitude ).\n\n- **y**: `Evision.Mat.t()`.\n\n  Destination matrix of imaginary components ( same type as magnitude ).\n\nPython prototype (for reference only):\n```python3\npolarToCart(magnitude, angle[, x[, y[, angleInDegrees[, stream]]]]) -> x, y\n```\n#### Variant 2:\nConverts polar coordinates into Cartesian.\n\n##### Positional Arguments\n- **magnitude**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix containing magnitudes ( CV_32FC1 or CV_64FC1 ).\n\n- **angle**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix containing angles ( same type as magnitude ).\n\n##### Keyword Arguments\n- **angleInDegrees**: `bool`.\n\n  Flag that indicates angles in degrees.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **x**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix of real components ( same type as magnitude ).\n\n- **y**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix of imaginary components ( same type as magnitude ).\n\nPython prototype (for reference only):\n```python3\npolarToCart(magnitude, angle[, x[, y[, angleInDegrees[, stream]]]]) -> x, y\n```","ref":"Evision.CUDA.html#polarToCart/2"},{"type":"function","title":"Evision.CUDA.polarToCart/3","doc":"#### Variant 1:\nConverts polar coordinates into Cartesian.\n\n##### Positional Arguments\n- **magnitude**: `Evision.Mat`.\n\n  Source matrix containing magnitudes ( CV_32FC1 or CV_64FC1 ).\n\n- **angle**: `Evision.Mat`.\n\n  Source matrix containing angles ( same type as magnitude ).\n\n##### Keyword Arguments\n- **angleInDegrees**: `bool`.\n\n  Flag that indicates angles in degrees.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **x**: `Evision.Mat.t()`.\n\n  Destination matrix of real components ( same type as magnitude ).\n\n- **y**: `Evision.Mat.t()`.\n\n  Destination matrix of imaginary components ( same type as magnitude ).\n\nPython prototype (for reference only):\n```python3\npolarToCart(magnitude, angle[, x[, y[, angleInDegrees[, stream]]]]) -> x, y\n```\n#### Variant 2:\nConverts polar coordinates into Cartesian.\n\n##### Positional Arguments\n- **magnitude**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix containing magnitudes ( CV_32FC1 or CV_64FC1 ).\n\n- **angle**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix containing angles ( same type as magnitude ).\n\n##### Keyword Arguments\n- **angleInDegrees**: `bool`.\n\n  Flag that indicates angles in degrees.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **x**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix of real components ( same type as magnitude ).\n\n- **y**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix of imaginary components ( same type as magnitude ).\n\nPython prototype (for reference only):\n```python3\npolarToCart(magnitude, angle[, x[, y[, angleInDegrees[, stream]]]]) -> x, y\n```","ref":"Evision.CUDA.html#polarToCart/3"},{"type":"function","title":"Evision.CUDA.pow/1","doc":"","ref":"Evision.CUDA.html#pow/1"},{"type":"function","title":"Evision.CUDA.pow/2","doc":"#### Variant 1:\nRaises every matrix element to a power.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source matrix.\n\n- **power**: `double`.\n\n  Exponent of power.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix with the same size and type as src .\n\nThe function pow raises every element of the input matrix to power :\n\\f[\\texttt{dst} (I) =  \\fork{\\texttt{src}(I)^power}{if \\texttt{power} is integer}{|\\texttt{src}(I)|^power}{otherwise}\\f]\n@sa pow\n\nPython prototype (for reference only):\n```python3\npow(src, power[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nRaises every matrix element to a power.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix.\n\n- **power**: `double`.\n\n  Exponent of power.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix with the same size and type as src .\n\nThe function pow raises every element of the input matrix to power :\n\\f[\\texttt{dst} (I) =  \\fork{\\texttt{src}(I)^power}{if \\texttt{power} is integer}{|\\texttt{src}(I)|^power}{otherwise}\\f]\n@sa pow\n\nPython prototype (for reference only):\n```python3\npow(src, power[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#pow/2"},{"type":"function","title":"Evision.CUDA.pow/3","doc":"#### Variant 1:\nRaises every matrix element to a power.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source matrix.\n\n- **power**: `double`.\n\n  Exponent of power.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix with the same size and type as src .\n\nThe function pow raises every element of the input matrix to power :\n\\f[\\texttt{dst} (I) =  \\fork{\\texttt{src}(I)^power}{if \\texttt{power} is integer}{|\\texttt{src}(I)|^power}{otherwise}\\f]\n@sa pow\n\nPython prototype (for reference only):\n```python3\npow(src, power[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nRaises every matrix element to a power.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix.\n\n- **power**: `double`.\n\n  Exponent of power.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix with the same size and type as src .\n\nThe function pow raises every element of the input matrix to power :\n\\f[\\texttt{dst} (I) =  \\fork{\\texttt{src}(I)^power}{if \\texttt{power} is integer}{|\\texttt{src}(I)|^power}{otherwise}\\f]\n@sa pow\n\nPython prototype (for reference only):\n```python3\npow(src, power[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#pow/3"},{"type":"function","title":"Evision.CUDA.printCudaDeviceInfo/1","doc":"printCudaDeviceInfo\n\n##### Positional Arguments\n- **device**: `integer()`\n\nPython prototype (for reference only):\n```python3\nprintCudaDeviceInfo(device) -> None\n```","ref":"Evision.CUDA.html#printCudaDeviceInfo/1"},{"type":"function","title":"Evision.CUDA.printShortCudaDeviceInfo/1","doc":"printShortCudaDeviceInfo\n\n##### Positional Arguments\n- **device**: `integer()`\n\nPython prototype (for reference only):\n```python3\nprintShortCudaDeviceInfo(device) -> None\n```","ref":"Evision.CUDA.html#printShortCudaDeviceInfo/1"},{"type":"function","title":"Evision.CUDA.pyrDown/1","doc":"#### Variant 1:\nSmoothes an image and downsamples it.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image. Will have Size((src.cols+1)/2, (src.rows+1)/2) size and the same\n  type as src .\n\n@sa pyrDown\n\nPython prototype (for reference only):\n```python3\npyrDown(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nSmoothes an image and downsamples it.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image. Will have Size((src.cols+1)/2, (src.rows+1)/2) size and the same\n  type as src .\n\n@sa pyrDown\n\nPython prototype (for reference only):\n```python3\npyrDown(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#pyrDown/1"},{"type":"function","title":"Evision.CUDA.pyrDown/2","doc":"#### Variant 1:\nSmoothes an image and downsamples it.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image. Will have Size((src.cols+1)/2, (src.rows+1)/2) size and the same\n  type as src .\n\n@sa pyrDown\n\nPython prototype (for reference only):\n```python3\npyrDown(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nSmoothes an image and downsamples it.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image. Will have Size((src.cols+1)/2, (src.rows+1)/2) size and the same\n  type as src .\n\n@sa pyrDown\n\nPython prototype (for reference only):\n```python3\npyrDown(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#pyrDown/2"},{"type":"function","title":"Evision.CUDA.pyrUp/1","doc":"#### Variant 1:\nUpsamples an image and then smoothes it.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image. Will have Size(src.cols\\*2, src.rows\\*2) size and the same type as\n  src .\n\nPython prototype (for reference only):\n```python3\npyrUp(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nUpsamples an image and then smoothes it.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image. Will have Size(src.cols\\*2, src.rows\\*2) size and the same type as\n  src .\n\nPython prototype (for reference only):\n```python3\npyrUp(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#pyrUp/1"},{"type":"function","title":"Evision.CUDA.pyrUp/2","doc":"#### Variant 1:\nUpsamples an image and then smoothes it.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image. Will have Size(src.cols\\*2, src.rows\\*2) size and the same type as\n  src .\n\nPython prototype (for reference only):\n```python3\npyrUp(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nUpsamples an image and then smoothes it.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image. Will have Size(src.cols\\*2, src.rows\\*2) size and the same type as\n  src .\n\nPython prototype (for reference only):\n```python3\npyrUp(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#pyrUp/2"},{"type":"function","title":"Evision.CUDA.rectStdDev/1","doc":"","ref":"Evision.CUDA.html#rectStdDev/1"},{"type":"function","title":"Evision.CUDA.rectStdDev/3","doc":"#### Variant 1:\nComputes a standard deviation of integral images.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. Only the CV_32SC1 type is supported.\n\n- **sqr**: `Evision.Mat`.\n\n  Squared source image. Only the CV_32FC1 type is supported.\n\n- **rect**: `Rect`.\n\n  Rectangular window.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image with the same type and size as src.\n\nPython prototype (for reference only):\n```python3\nrectStdDev(src, sqr, rect[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nComputes a standard deviation of integral images.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. Only the CV_32SC1 type is supported.\n\n- **sqr**: `Evision.CUDA.GpuMat.t()`.\n\n  Squared source image. Only the CV_32FC1 type is supported.\n\n- **rect**: `Rect`.\n\n  Rectangular window.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image with the same type and size as src.\n\nPython prototype (for reference only):\n```python3\nrectStdDev(src, sqr, rect[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#rectStdDev/3"},{"type":"function","title":"Evision.CUDA.rectStdDev/4","doc":"#### Variant 1:\nComputes a standard deviation of integral images.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. Only the CV_32SC1 type is supported.\n\n- **sqr**: `Evision.Mat`.\n\n  Squared source image. Only the CV_32FC1 type is supported.\n\n- **rect**: `Rect`.\n\n  Rectangular window.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image with the same type and size as src.\n\nPython prototype (for reference only):\n```python3\nrectStdDev(src, sqr, rect[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nComputes a standard deviation of integral images.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. Only the CV_32SC1 type is supported.\n\n- **sqr**: `Evision.CUDA.GpuMat.t()`.\n\n  Squared source image. Only the CV_32FC1 type is supported.\n\n- **rect**: `Rect`.\n\n  Rectangular window.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image with the same type and size as src.\n\nPython prototype (for reference only):\n```python3\nrectStdDev(src, sqr, rect[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#rectStdDev/4"},{"type":"function","title":"Evision.CUDA.reduce/1","doc":"","ref":"Evision.CUDA.html#reduce/1"},{"type":"function","title":"Evision.CUDA.reduce/3","doc":"#### Variant 1:\nReduces a matrix to a vector.\n\n##### Positional Arguments\n- **mtx**: `Evision.Mat`.\n\n  Source 2D matrix.\n\n- **dim**: `integer()`.\n\n  Dimension index along which the matrix is reduced. 0 means that the matrix is reduced\n  to a single row. 1 means that the matrix is reduced to a single column.\n\n- **reduceOp**: `integer()`.\n\n  Reduction operation that could be one of the following:\n  - **REDUCE_SUM** The output is the sum of all rows/columns of the matrix.\n  - **REDUCE_AVG** The output is the mean vector of all rows/columns of the matrix.\n  - **REDUCE_MAX** The output is the maximum (column/row-wise) of all rows/columns of the\n    matrix.\n  - **REDUCE_MIN** The output is the minimum (column/row-wise) of all rows/columns of the\n    matrix.\n\n##### Keyword Arguments\n- **dtype**: `integer()`.\n\n  When it is negative, the destination vector will have the same type as the source\n  matrix. Otherwise, its type will be CV_MAKE_TYPE(CV_MAT_DEPTH(dtype), mtx.channels()) .\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **vec**: `Evision.Mat.t()`.\n\n  Destination vector. Its size and type is defined by dim and dtype parameters.\n\nThe function reduce reduces the matrix to a vector by treating the matrix rows/columns as a set of\n1D vectors and performing the specified operation on the vectors until a single row/column is\nobtained. For example, the function can be used to compute horizontal and vertical projections of a\nraster image. In case of REDUCE_SUM and REDUCE_AVG , the output may have a larger element\nbit-depth to preserve accuracy. And multi-channel arrays are also supported in these two reduction\nmodes.\n@sa reduce\n\nPython prototype (for reference only):\n```python3\nreduce(mtx, dim, reduceOp[, vec[, dtype[, stream]]]) -> vec\n```\n#### Variant 2:\nReduces a matrix to a vector.\n\n##### Positional Arguments\n- **mtx**: `Evision.CUDA.GpuMat.t()`.\n\n  Source 2D matrix.\n\n- **dim**: `integer()`.\n\n  Dimension index along which the matrix is reduced. 0 means that the matrix is reduced\n  to a single row. 1 means that the matrix is reduced to a single column.\n\n- **reduceOp**: `integer()`.\n\n  Reduction operation that could be one of the following:\n  - **REDUCE_SUM** The output is the sum of all rows/columns of the matrix.\n  - **REDUCE_AVG** The output is the mean vector of all rows/columns of the matrix.\n  - **REDUCE_MAX** The output is the maximum (column/row-wise) of all rows/columns of the\n    matrix.\n  - **REDUCE_MIN** The output is the minimum (column/row-wise) of all rows/columns of the\n    matrix.\n\n##### Keyword Arguments\n- **dtype**: `integer()`.\n\n  When it is negative, the destination vector will have the same type as the source\n  matrix. Otherwise, its type will be CV_MAKE_TYPE(CV_MAT_DEPTH(dtype), mtx.channels()) .\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **vec**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination vector. Its size and type is defined by dim and dtype parameters.\n\nThe function reduce reduces the matrix to a vector by treating the matrix rows/columns as a set of\n1D vectors and performing the specified operation on the vectors until a single row/column is\nobtained. For example, the function can be used to compute horizontal and vertical projections of a\nraster image. In case of REDUCE_SUM and REDUCE_AVG , the output may have a larger element\nbit-depth to preserve accuracy. And multi-channel arrays are also supported in these two reduction\nmodes.\n@sa reduce\n\nPython prototype (for reference only):\n```python3\nreduce(mtx, dim, reduceOp[, vec[, dtype[, stream]]]) -> vec\n```","ref":"Evision.CUDA.html#reduce/3"},{"type":"function","title":"Evision.CUDA.reduce/4","doc":"#### Variant 1:\nReduces a matrix to a vector.\n\n##### Positional Arguments\n- **mtx**: `Evision.Mat`.\n\n  Source 2D matrix.\n\n- **dim**: `integer()`.\n\n  Dimension index along which the matrix is reduced. 0 means that the matrix is reduced\n  to a single row. 1 means that the matrix is reduced to a single column.\n\n- **reduceOp**: `integer()`.\n\n  Reduction operation that could be one of the following:\n  - **REDUCE_SUM** The output is the sum of all rows/columns of the matrix.\n  - **REDUCE_AVG** The output is the mean vector of all rows/columns of the matrix.\n  - **REDUCE_MAX** The output is the maximum (column/row-wise) of all rows/columns of the\n    matrix.\n  - **REDUCE_MIN** The output is the minimum (column/row-wise) of all rows/columns of the\n    matrix.\n\n##### Keyword Arguments\n- **dtype**: `integer()`.\n\n  When it is negative, the destination vector will have the same type as the source\n  matrix. Otherwise, its type will be CV_MAKE_TYPE(CV_MAT_DEPTH(dtype), mtx.channels()) .\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **vec**: `Evision.Mat.t()`.\n\n  Destination vector. Its size and type is defined by dim and dtype parameters.\n\nThe function reduce reduces the matrix to a vector by treating the matrix rows/columns as a set of\n1D vectors and performing the specified operation on the vectors until a single row/column is\nobtained. For example, the function can be used to compute horizontal and vertical projections of a\nraster image. In case of REDUCE_SUM and REDUCE_AVG , the output may have a larger element\nbit-depth to preserve accuracy. And multi-channel arrays are also supported in these two reduction\nmodes.\n@sa reduce\n\nPython prototype (for reference only):\n```python3\nreduce(mtx, dim, reduceOp[, vec[, dtype[, stream]]]) -> vec\n```\n#### Variant 2:\nReduces a matrix to a vector.\n\n##### Positional Arguments\n- **mtx**: `Evision.CUDA.GpuMat.t()`.\n\n  Source 2D matrix.\n\n- **dim**: `integer()`.\n\n  Dimension index along which the matrix is reduced. 0 means that the matrix is reduced\n  to a single row. 1 means that the matrix is reduced to a single column.\n\n- **reduceOp**: `integer()`.\n\n  Reduction operation that could be one of the following:\n  - **REDUCE_SUM** The output is the sum of all rows/columns of the matrix.\n  - **REDUCE_AVG** The output is the mean vector of all rows/columns of the matrix.\n  - **REDUCE_MAX** The output is the maximum (column/row-wise) of all rows/columns of the\n    matrix.\n  - **REDUCE_MIN** The output is the minimum (column/row-wise) of all rows/columns of the\n    matrix.\n\n##### Keyword Arguments\n- **dtype**: `integer()`.\n\n  When it is negative, the destination vector will have the same type as the source\n  matrix. Otherwise, its type will be CV_MAKE_TYPE(CV_MAT_DEPTH(dtype), mtx.channels()) .\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **vec**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination vector. Its size and type is defined by dim and dtype parameters.\n\nThe function reduce reduces the matrix to a vector by treating the matrix rows/columns as a set of\n1D vectors and performing the specified operation on the vectors until a single row/column is\nobtained. For example, the function can be used to compute horizontal and vertical projections of a\nraster image. In case of REDUCE_SUM and REDUCE_AVG , the output may have a larger element\nbit-depth to preserve accuracy. And multi-channel arrays are also supported in these two reduction\nmodes.\n@sa reduce\n\nPython prototype (for reference only):\n```python3\nreduce(mtx, dim, reduceOp[, vec[, dtype[, stream]]]) -> vec\n```","ref":"Evision.CUDA.html#reduce/4"},{"type":"function","title":"Evision.CUDA.registerPageLocked/1","doc":"Page-locks the memory of matrix and maps it for the device(s).\n\n##### Positional Arguments\n- **m**: `Evision.Mat`.\n\n  Input matrix.\n\nPython prototype (for reference only):\n```python3\nregisterPageLocked(m) -> None\n```","ref":"Evision.CUDA.html#registerPageLocked/1"},{"type":"function","title":"Evision.CUDA.remap/1","doc":"","ref":"Evision.CUDA.html#remap/1"},{"type":"function","title":"Evision.CUDA.remap/4","doc":"#### Variant 1:\nApplies a generic geometrical transformation to an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image.\n\n- **xmap**: `Evision.Mat`.\n\n  X values. Only CV_32FC1 type is supported.\n\n- **ymap**: `Evision.Mat`.\n\n  Y values. Only CV_32FC1 type is supported.\n\n- **interpolation**: `integer()`.\n\n  Interpolation method (see resize ). INTER_NEAREST , INTER_LINEAR and\n  INTER_CUBIC are supported for now.\n\n##### Keyword Arguments\n- **borderMode**: `integer()`.\n\n  Pixel extrapolation method (see borderInterpolate ). BORDER_REFLECT101 ,\n  BORDER_REPLICATE , BORDER_CONSTANT , BORDER_REFLECT and BORDER_WRAP are supported for now.\n\n- **borderValue**: `Evision.scalar()`.\n\n  Value used in case of a constant border. By default, it is 0.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image with the size the same as xmap and the type the same as src .\n\nThe function transforms the source image using the specified map:\n\\f[\\texttt{dst} (x,y) =  \\texttt{src} (xmap(x,y), ymap(x,y))\\f]\nValues of pixels with non-integer coordinates are computed using the bilinear interpolation.\n@sa remap\n\nPython prototype (for reference only):\n```python3\nremap(src, xmap, ymap, interpolation[, dst[, borderMode[, borderValue[, stream]]]]) -> dst\n```\n#### Variant 2:\nApplies a generic geometrical transformation to an image.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image.\n\n- **xmap**: `Evision.CUDA.GpuMat.t()`.\n\n  X values. Only CV_32FC1 type is supported.\n\n- **ymap**: `Evision.CUDA.GpuMat.t()`.\n\n  Y values. Only CV_32FC1 type is supported.\n\n- **interpolation**: `integer()`.\n\n  Interpolation method (see resize ). INTER_NEAREST , INTER_LINEAR and\n  INTER_CUBIC are supported for now.\n\n##### Keyword Arguments\n- **borderMode**: `integer()`.\n\n  Pixel extrapolation method (see borderInterpolate ). BORDER_REFLECT101 ,\n  BORDER_REPLICATE , BORDER_CONSTANT , BORDER_REFLECT and BORDER_WRAP are supported for now.\n\n- **borderValue**: `Evision.scalar()`.\n\n  Value used in case of a constant border. By default, it is 0.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image with the size the same as xmap and the type the same as src .\n\nThe function transforms the source image using the specified map:\n\\f[\\texttt{dst} (x,y) =  \\texttt{src} (xmap(x,y), ymap(x,y))\\f]\nValues of pixels with non-integer coordinates are computed using the bilinear interpolation.\n@sa remap\n\nPython prototype (for reference only):\n```python3\nremap(src, xmap, ymap, interpolation[, dst[, borderMode[, borderValue[, stream]]]]) -> dst\n```","ref":"Evision.CUDA.html#remap/4"},{"type":"function","title":"Evision.CUDA.remap/5","doc":"#### Variant 1:\nApplies a generic geometrical transformation to an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image.\n\n- **xmap**: `Evision.Mat`.\n\n  X values. Only CV_32FC1 type is supported.\n\n- **ymap**: `Evision.Mat`.\n\n  Y values. Only CV_32FC1 type is supported.\n\n- **interpolation**: `integer()`.\n\n  Interpolation method (see resize ). INTER_NEAREST , INTER_LINEAR and\n  INTER_CUBIC are supported for now.\n\n##### Keyword Arguments\n- **borderMode**: `integer()`.\n\n  Pixel extrapolation method (see borderInterpolate ). BORDER_REFLECT101 ,\n  BORDER_REPLICATE , BORDER_CONSTANT , BORDER_REFLECT and BORDER_WRAP are supported for now.\n\n- **borderValue**: `Evision.scalar()`.\n\n  Value used in case of a constant border. By default, it is 0.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image with the size the same as xmap and the type the same as src .\n\nThe function transforms the source image using the specified map:\n\\f[\\texttt{dst} (x,y) =  \\texttt{src} (xmap(x,y), ymap(x,y))\\f]\nValues of pixels with non-integer coordinates are computed using the bilinear interpolation.\n@sa remap\n\nPython prototype (for reference only):\n```python3\nremap(src, xmap, ymap, interpolation[, dst[, borderMode[, borderValue[, stream]]]]) -> dst\n```\n#### Variant 2:\nApplies a generic geometrical transformation to an image.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image.\n\n- **xmap**: `Evision.CUDA.GpuMat.t()`.\n\n  X values. Only CV_32FC1 type is supported.\n\n- **ymap**: `Evision.CUDA.GpuMat.t()`.\n\n  Y values. Only CV_32FC1 type is supported.\n\n- **interpolation**: `integer()`.\n\n  Interpolation method (see resize ). INTER_NEAREST , INTER_LINEAR and\n  INTER_CUBIC are supported for now.\n\n##### Keyword Arguments\n- **borderMode**: `integer()`.\n\n  Pixel extrapolation method (see borderInterpolate ). BORDER_REFLECT101 ,\n  BORDER_REPLICATE , BORDER_CONSTANT , BORDER_REFLECT and BORDER_WRAP are supported for now.\n\n- **borderValue**: `Evision.scalar()`.\n\n  Value used in case of a constant border. By default, it is 0.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image with the size the same as xmap and the type the same as src .\n\nThe function transforms the source image using the specified map:\n\\f[\\texttt{dst} (x,y) =  \\texttt{src} (xmap(x,y), ymap(x,y))\\f]\nValues of pixels with non-integer coordinates are computed using the bilinear interpolation.\n@sa remap\n\nPython prototype (for reference only):\n```python3\nremap(src, xmap, ymap, interpolation[, dst[, borderMode[, borderValue[, stream]]]]) -> dst\n```","ref":"Evision.CUDA.html#remap/5"},{"type":"function","title":"Evision.CUDA.reprojectImageTo3D/1","doc":"","ref":"Evision.CUDA.html#reprojectImageTo3D/1"},{"type":"function","title":"Evision.CUDA.reprojectImageTo3D/2","doc":"Reprojects a disparity image to 3D space.\n\n##### Positional Arguments\n- **disp**: `Evision.CUDA.GpuMat.t()`.\n\n  Input single-channel 8-bit unsigned, 16-bit signed, 32-bit signed or 32-bit\n  floating-point disparity image. If 16-bit signed format is used, the values are assumed to have no\n  fractional bits.\n\n- **q**: `Evision.Mat`.\n\n  \\f$4 \\times 4\\f$ perspective transformation matrix that can be obtained via stereoRectify .\n\n##### Keyword Arguments\n- **dst_cn**: `integer()`.\n\n  The number of channels for output image. Can be 3 or 4.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **xyzw**: `Evision.CUDA.GpuMat.t()`.\n\n  Output 3- or 4-channel floating-point image of the same size as disp . Each element of\n  xyzw(x,y) contains 3D coordinates (x,y,z) or (x,y,z,1) of the point (x,y) , computed from the\n  disparity map.\n\n@sa reprojectImageTo3D\n\nPython prototype (for reference only):\n```python3\nreprojectImageTo3D(disp, Q[, xyzw[, dst_cn[, stream]]]) -> xyzw\n```","ref":"Evision.CUDA.html#reprojectImageTo3D/2"},{"type":"function","title":"Evision.CUDA.reprojectImageTo3D/3","doc":"Reprojects a disparity image to 3D space.\n\n##### Positional Arguments\n- **disp**: `Evision.CUDA.GpuMat.t()`.\n\n  Input single-channel 8-bit unsigned, 16-bit signed, 32-bit signed or 32-bit\n  floating-point disparity image. If 16-bit signed format is used, the values are assumed to have no\n  fractional bits.\n\n- **q**: `Evision.Mat`.\n\n  \\f$4 \\times 4\\f$ perspective transformation matrix that can be obtained via stereoRectify .\n\n##### Keyword Arguments\n- **dst_cn**: `integer()`.\n\n  The number of channels for output image. Can be 3 or 4.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **xyzw**: `Evision.CUDA.GpuMat.t()`.\n\n  Output 3- or 4-channel floating-point image of the same size as disp . Each element of\n  xyzw(x,y) contains 3D coordinates (x,y,z) or (x,y,z,1) of the point (x,y) , computed from the\n  disparity map.\n\n@sa reprojectImageTo3D\n\nPython prototype (for reference only):\n```python3\nreprojectImageTo3D(disp, Q[, xyzw[, dst_cn[, stream]]]) -> xyzw\n```","ref":"Evision.CUDA.html#reprojectImageTo3D/3"},{"type":"function","title":"Evision.CUDA.resetDevice/0","doc":"Explicitly destroys and cleans up all resources associated with the current device in the current\nprocess.\n\nAny subsequent API call to this device will reinitialize the device.\n\nPython prototype (for reference only):\n```python3\nresetDevice() -> None\n```","ref":"Evision.CUDA.html#resetDevice/0"},{"type":"function","title":"Evision.CUDA.resetDevice/1","doc":"","ref":"Evision.CUDA.html#resetDevice/1"},{"type":"function","title":"Evision.CUDA.resize/1","doc":"","ref":"Evision.CUDA.html#resize/1"},{"type":"function","title":"Evision.CUDA.resize/2","doc":"#### Variant 1:\nResizes an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image.\n\n- **dsize**: `Size`.\n\n  Destination image size. If it is zero, it is computed as:\n  \\f[\\texttt{dsize = Size(round(fx*src.cols), round(fy*src.rows))}\\f]\n  Either dsize or both fx and fy must be non-zero.\n\n##### Keyword Arguments\n- **fx**: `double`.\n\n  Scale factor along the horizontal axis. If it is zero, it is computed as:\n  \\f[\\texttt{(double)dsize.width/src.cols}\\f]\n\n- **fy**: `double`.\n\n  Scale factor along the vertical axis. If it is zero, it is computed as:\n  \\f[\\texttt{(double)dsize.height/src.rows}\\f]\n\n- **interpolation**: `integer()`.\n\n  Interpolation method. INTER_NEAREST , INTER_LINEAR and INTER_CUBIC are\n  supported for now.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image with the same type as src . The size is dsize (when it is non-zero)\n  or the size is computed from src.size() , fx , and fy .\n\n@sa resize\n\nPython prototype (for reference only):\n```python3\nresize(src, dsize[, dst[, fx[, fy[, interpolation[, stream]]]]]) -> dst\n```\n#### Variant 2:\nResizes an image.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image.\n\n- **dsize**: `Size`.\n\n  Destination image size. If it is zero, it is computed as:\n  \\f[\\texttt{dsize = Size(round(fx*src.cols), round(fy*src.rows))}\\f]\n  Either dsize or both fx and fy must be non-zero.\n\n##### Keyword Arguments\n- **fx**: `double`.\n\n  Scale factor along the horizontal axis. If it is zero, it is computed as:\n  \\f[\\texttt{(double)dsize.width/src.cols}\\f]\n\n- **fy**: `double`.\n\n  Scale factor along the vertical axis. If it is zero, it is computed as:\n  \\f[\\texttt{(double)dsize.height/src.rows}\\f]\n\n- **interpolation**: `integer()`.\n\n  Interpolation method. INTER_NEAREST , INTER_LINEAR and INTER_CUBIC are\n  supported for now.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image with the same type as src . The size is dsize (when it is non-zero)\n  or the size is computed from src.size() , fx , and fy .\n\n@sa resize\n\nPython prototype (for reference only):\n```python3\nresize(src, dsize[, dst[, fx[, fy[, interpolation[, stream]]]]]) -> dst\n```","ref":"Evision.CUDA.html#resize/2"},{"type":"function","title":"Evision.CUDA.resize/3","doc":"#### Variant 1:\nResizes an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image.\n\n- **dsize**: `Size`.\n\n  Destination image size. If it is zero, it is computed as:\n  \\f[\\texttt{dsize = Size(round(fx*src.cols), round(fy*src.rows))}\\f]\n  Either dsize or both fx and fy must be non-zero.\n\n##### Keyword Arguments\n- **fx**: `double`.\n\n  Scale factor along the horizontal axis. If it is zero, it is computed as:\n  \\f[\\texttt{(double)dsize.width/src.cols}\\f]\n\n- **fy**: `double`.\n\n  Scale factor along the vertical axis. If it is zero, it is computed as:\n  \\f[\\texttt{(double)dsize.height/src.rows}\\f]\n\n- **interpolation**: `integer()`.\n\n  Interpolation method. INTER_NEAREST , INTER_LINEAR and INTER_CUBIC are\n  supported for now.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image with the same type as src . The size is dsize (when it is non-zero)\n  or the size is computed from src.size() , fx , and fy .\n\n@sa resize\n\nPython prototype (for reference only):\n```python3\nresize(src, dsize[, dst[, fx[, fy[, interpolation[, stream]]]]]) -> dst\n```\n#### Variant 2:\nResizes an image.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image.\n\n- **dsize**: `Size`.\n\n  Destination image size. If it is zero, it is computed as:\n  \\f[\\texttt{dsize = Size(round(fx*src.cols), round(fy*src.rows))}\\f]\n  Either dsize or both fx and fy must be non-zero.\n\n##### Keyword Arguments\n- **fx**: `double`.\n\n  Scale factor along the horizontal axis. If it is zero, it is computed as:\n  \\f[\\texttt{(double)dsize.width/src.cols}\\f]\n\n- **fy**: `double`.\n\n  Scale factor along the vertical axis. If it is zero, it is computed as:\n  \\f[\\texttt{(double)dsize.height/src.rows}\\f]\n\n- **interpolation**: `integer()`.\n\n  Interpolation method. INTER_NEAREST , INTER_LINEAR and INTER_CUBIC are\n  supported for now.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image with the same type as src . The size is dsize (when it is non-zero)\n  or the size is computed from src.size() , fx , and fy .\n\n@sa resize\n\nPython prototype (for reference only):\n```python3\nresize(src, dsize[, dst[, fx[, fy[, interpolation[, stream]]]]]) -> dst\n```","ref":"Evision.CUDA.html#resize/3"},{"type":"function","title":"Evision.CUDA.rotate/1","doc":"","ref":"Evision.CUDA.html#rotate/1"},{"type":"function","title":"Evision.CUDA.rotate/3","doc":"#### Variant 1:\nRotates an image around the origin (0,0) and then shifts it.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. Supports 1, 3 or 4 channels images with CV_8U , CV_16U or CV_32F\n  depth.\n\n- **dsize**: `Size`.\n\n  Size of the destination image.\n\n- **angle**: `double`.\n\n  Angle of rotation in degrees.\n\n##### Keyword Arguments\n- **xShift**: `double`.\n\n  Shift along the horizontal axis.\n\n- **yShift**: `double`.\n\n  Shift along the vertical axis.\n\n- **interpolation**: `integer()`.\n\n  Interpolation method. Only INTER_NEAREST , INTER_LINEAR , and INTER_CUBIC\n  are supported.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image with the same type as src . The size is dsize .\n\n@sa cuda::warpAffine\n\nPython prototype (for reference only):\n```python3\nrotate(src, dsize, angle[, dst[, xShift[, yShift[, interpolation[, stream]]]]]) -> dst\n```\n#### Variant 2:\nRotates an image around the origin (0,0) and then shifts it.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. Supports 1, 3 or 4 channels images with CV_8U , CV_16U or CV_32F\n  depth.\n\n- **dsize**: `Size`.\n\n  Size of the destination image.\n\n- **angle**: `double`.\n\n  Angle of rotation in degrees.\n\n##### Keyword Arguments\n- **xShift**: `double`.\n\n  Shift along the horizontal axis.\n\n- **yShift**: `double`.\n\n  Shift along the vertical axis.\n\n- **interpolation**: `integer()`.\n\n  Interpolation method. Only INTER_NEAREST , INTER_LINEAR , and INTER_CUBIC\n  are supported.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image with the same type as src . The size is dsize .\n\n@sa cuda::warpAffine\n\nPython prototype (for reference only):\n```python3\nrotate(src, dsize, angle[, dst[, xShift[, yShift[, interpolation[, stream]]]]]) -> dst\n```","ref":"Evision.CUDA.html#rotate/3"},{"type":"function","title":"Evision.CUDA.rotate/4","doc":"#### Variant 1:\nRotates an image around the origin (0,0) and then shifts it.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. Supports 1, 3 or 4 channels images with CV_8U , CV_16U or CV_32F\n  depth.\n\n- **dsize**: `Size`.\n\n  Size of the destination image.\n\n- **angle**: `double`.\n\n  Angle of rotation in degrees.\n\n##### Keyword Arguments\n- **xShift**: `double`.\n\n  Shift along the horizontal axis.\n\n- **yShift**: `double`.\n\n  Shift along the vertical axis.\n\n- **interpolation**: `integer()`.\n\n  Interpolation method. Only INTER_NEAREST , INTER_LINEAR , and INTER_CUBIC\n  are supported.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image with the same type as src . The size is dsize .\n\n@sa cuda::warpAffine\n\nPython prototype (for reference only):\n```python3\nrotate(src, dsize, angle[, dst[, xShift[, yShift[, interpolation[, stream]]]]]) -> dst\n```\n#### Variant 2:\nRotates an image around the origin (0,0) and then shifts it.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. Supports 1, 3 or 4 channels images with CV_8U , CV_16U or CV_32F\n  depth.\n\n- **dsize**: `Size`.\n\n  Size of the destination image.\n\n- **angle**: `double`.\n\n  Angle of rotation in degrees.\n\n##### Keyword Arguments\n- **xShift**: `double`.\n\n  Shift along the horizontal axis.\n\n- **yShift**: `double`.\n\n  Shift along the vertical axis.\n\n- **interpolation**: `integer()`.\n\n  Interpolation method. Only INTER_NEAREST , INTER_LINEAR , and INTER_CUBIC\n  are supported.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image with the same type as src . The size is dsize .\n\n@sa cuda::warpAffine\n\nPython prototype (for reference only):\n```python3\nrotate(src, dsize, angle[, dst[, xShift[, yShift[, interpolation[, stream]]]]]) -> dst\n```","ref":"Evision.CUDA.html#rotate/4"},{"type":"function","title":"Evision.CUDA.rshift/1","doc":"","ref":"Evision.CUDA.html#rshift/1"},{"type":"function","title":"Evision.CUDA.rshift/2","doc":"#### Variant 1:\nPerforms pixel by pixel right shift of an image by a constant value.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source matrix. Supports 1, 3 and 4 channels images with integers elements.\n\n- **val**: `Evision.scalar()`.\n\n  Constant values, one per channel.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix with the same size and type as src .\n\nPython prototype (for reference only):\n```python3\nrshift(src, val[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nPerforms pixel by pixel right shift of an image by a constant value.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix. Supports 1, 3 and 4 channels images with integers elements.\n\n- **val**: `Evision.scalar()`.\n\n  Constant values, one per channel.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix with the same size and type as src .\n\nPython prototype (for reference only):\n```python3\nrshift(src, val[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#rshift/2"},{"type":"function","title":"Evision.CUDA.rshift/3","doc":"#### Variant 1:\nPerforms pixel by pixel right shift of an image by a constant value.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source matrix. Supports 1, 3 and 4 channels images with integers elements.\n\n- **val**: `Evision.scalar()`.\n\n  Constant values, one per channel.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix with the same size and type as src .\n\nPython prototype (for reference only):\n```python3\nrshift(src, val[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nPerforms pixel by pixel right shift of an image by a constant value.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix. Supports 1, 3 and 4 channels images with integers elements.\n\n- **val**: `Evision.scalar()`.\n\n  Constant values, one per channel.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix with the same size and type as src .\n\nPython prototype (for reference only):\n```python3\nrshift(src, val[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#rshift/3"},{"type":"function","title":"Evision.CUDA.setBufferPoolConfig/1","doc":"","ref":"Evision.CUDA.html#setBufferPoolConfig/1"},{"type":"function","title":"Evision.CUDA.setBufferPoolConfig/3","doc":"setBufferPoolConfig\n\n##### Positional Arguments\n- **deviceId**: `integer()`\n- **stackSize**: `size_t`\n- **stackCount**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetBufferPoolConfig(deviceId, stackSize, stackCount) -> None\n```","ref":"Evision.CUDA.html#setBufferPoolConfig/3"},{"type":"function","title":"Evision.CUDA.setBufferPoolUsage/1","doc":"setBufferPoolUsage\n\n##### Positional Arguments\n- **on**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetBufferPoolUsage(on) -> None\n```","ref":"Evision.CUDA.html#setBufferPoolUsage/1"},{"type":"function","title":"Evision.CUDA.setDevice/1","doc":"Sets a device and initializes it for the current thread.\n\n##### Positional Arguments\n- **device**: `integer()`.\n\n  System index of a CUDA device starting with 0.\n\nIf the call of this function is omitted, a default device is initialized at the fist CUDA usage.\n\nPython prototype (for reference only):\n```python3\nsetDevice(device) -> None\n```","ref":"Evision.CUDA.html#setDevice/1"},{"type":"function","title":"Evision.CUDA.spatialMoments/1","doc":"#### Variant 1:\nCalculates all of the spatial moments up to the 3rd order of a rasterized shape.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Raster image (single-channel 2D array).\n\n##### Keyword Arguments\n- **binaryImage**: `bool`.\n\n  If it is true, all non-zero image pixels are treated as 1's.\n\n- **order**: `MomentsOrder`.\n\n  Order of largest moments to calculate with lower order moments requiring less computation.\n\n- **momentsType**: `integer()`.\n\n  Precision to use when calculating moments. Available types are \\ref CV_32F and \\ref CV_64F with the performance of \\ref CV_32F an order of magnitude greater than \\ref CV_64F. If the image is small the accuracy from \\ref CV_32F can be equal or very close to \\ref CV_64F.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **moments**: `Evision.Mat.t()`.\n\nAsynchronous version of cuda::moments() which only calculates the spatial (not centralized or normalized) moments, up to the 3rd order, of a rasterized shape.\nEach moment is returned as a column entry in the 1D \\a moments array.\n\n**Note**: For maximum performance pre-allocate a 1D GpuMat for \\a moments of the correct type and size large enough to store the all the image moments of up to the desired \\a order. e.g. With \\a order === MomentsOrder::SECOND_ORDER_MOMENTS and \\a momentsType == \\ref CV_32F \\a moments can be allocated as\n```\nGpuMat momentsDevice(1,numMoments(MomentsOrder::SECOND_ORDER_MOMENTS),CV_32F)\n```\nThe central and normalized moments can easily be calculated on the host by downloading the \\a moments array and using the cuda::convertSpatialMoments helper function. e.g.\n```\nHostMem spatialMomentsHostMem(1, numMoments(MomentsOrder::SECOND_ORDER_MOMENTS), CV_32F);\nspatialMomentsDevice.download(spatialMomentsHostMem, stream);\nstream.waitForCompletion();\nMat spatialMoments = spatialMomentsHostMem.createMatHeader();\ncv::Moments cvMoments = convertSpatialMoments (spatialMoments, order);\n```\nsee the \\a CUDA_TEST_P(Moments, Async) test inside opencv_contrib_source_code/modules/cudaimgproc/test/test_moments.cpp for an example.\n@sa cuda::moments, cuda::convertSpatialMoments, cuda::numMoments, cuda::MomentsOrder\n\nPython prototype (for reference only):\n```python3\nspatialMoments(src[, moments[, binaryImage[, order[, momentsType[, stream]]]]]) -> moments\n```\n#### Variant 2:\nCalculates all of the spatial moments up to the 3rd order of a rasterized shape.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Raster image (single-channel 2D array).\n\n##### Keyword Arguments\n- **binaryImage**: `bool`.\n\n  If it is true, all non-zero image pixels are treated as 1's.\n\n- **order**: `MomentsOrder`.\n\n  Order of largest moments to calculate with lower order moments requiring less computation.\n\n- **momentsType**: `integer()`.\n\n  Precision to use when calculating moments. Available types are \\ref CV_32F and \\ref CV_64F with the performance of \\ref CV_32F an order of magnitude greater than \\ref CV_64F. If the image is small the accuracy from \\ref CV_32F can be equal or very close to \\ref CV_64F.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **moments**: `Evision.CUDA.GpuMat.t()`.\n\nAsynchronous version of cuda::moments() which only calculates the spatial (not centralized or normalized) moments, up to the 3rd order, of a rasterized shape.\nEach moment is returned as a column entry in the 1D \\a moments array.\n\n**Note**: For maximum performance pre-allocate a 1D GpuMat for \\a moments of the correct type and size large enough to store the all the image moments of up to the desired \\a order. e.g. With \\a order === MomentsOrder::SECOND_ORDER_MOMENTS and \\a momentsType == \\ref CV_32F \\a moments can be allocated as\n```\nGpuMat momentsDevice(1,numMoments(MomentsOrder::SECOND_ORDER_MOMENTS),CV_32F)\n```\nThe central and normalized moments can easily be calculated on the host by downloading the \\a moments array and using the cuda::convertSpatialMoments helper function. e.g.\n```\nHostMem spatialMomentsHostMem(1, numMoments(MomentsOrder::SECOND_ORDER_MOMENTS), CV_32F);\nspatialMomentsDevice.download(spatialMomentsHostMem, stream);\nstream.waitForCompletion();\nMat spatialMoments = spatialMomentsHostMem.createMatHeader();\ncv::Moments cvMoments = convertSpatialMoments (spatialMoments, order);\n```\nsee the \\a CUDA_TEST_P(Moments, Async) test inside opencv_contrib_source_code/modules/cudaimgproc/test/test_moments.cpp for an example.\n@sa cuda::moments, cuda::convertSpatialMoments, cuda::numMoments, cuda::MomentsOrder\n\nPython prototype (for reference only):\n```python3\nspatialMoments(src[, moments[, binaryImage[, order[, momentsType[, stream]]]]]) -> moments\n```","ref":"Evision.CUDA.html#spatialMoments/1"},{"type":"function","title":"Evision.CUDA.spatialMoments/2","doc":"#### Variant 1:\nCalculates all of the spatial moments up to the 3rd order of a rasterized shape.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Raster image (single-channel 2D array).\n\n##### Keyword Arguments\n- **binaryImage**: `bool`.\n\n  If it is true, all non-zero image pixels are treated as 1's.\n\n- **order**: `MomentsOrder`.\n\n  Order of largest moments to calculate with lower order moments requiring less computation.\n\n- **momentsType**: `integer()`.\n\n  Precision to use when calculating moments. Available types are \\ref CV_32F and \\ref CV_64F with the performance of \\ref CV_32F an order of magnitude greater than \\ref CV_64F. If the image is small the accuracy from \\ref CV_32F can be equal or very close to \\ref CV_64F.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **moments**: `Evision.Mat.t()`.\n\nAsynchronous version of cuda::moments() which only calculates the spatial (not centralized or normalized) moments, up to the 3rd order, of a rasterized shape.\nEach moment is returned as a column entry in the 1D \\a moments array.\n\n**Note**: For maximum performance pre-allocate a 1D GpuMat for \\a moments of the correct type and size large enough to store the all the image moments of up to the desired \\a order. e.g. With \\a order === MomentsOrder::SECOND_ORDER_MOMENTS and \\a momentsType == \\ref CV_32F \\a moments can be allocated as\n```\nGpuMat momentsDevice(1,numMoments(MomentsOrder::SECOND_ORDER_MOMENTS),CV_32F)\n```\nThe central and normalized moments can easily be calculated on the host by downloading the \\a moments array and using the cuda::convertSpatialMoments helper function. e.g.\n```\nHostMem spatialMomentsHostMem(1, numMoments(MomentsOrder::SECOND_ORDER_MOMENTS), CV_32F);\nspatialMomentsDevice.download(spatialMomentsHostMem, stream);\nstream.waitForCompletion();\nMat spatialMoments = spatialMomentsHostMem.createMatHeader();\ncv::Moments cvMoments = convertSpatialMoments (spatialMoments, order);\n```\nsee the \\a CUDA_TEST_P(Moments, Async) test inside opencv_contrib_source_code/modules/cudaimgproc/test/test_moments.cpp for an example.\n@sa cuda::moments, cuda::convertSpatialMoments, cuda::numMoments, cuda::MomentsOrder\n\nPython prototype (for reference only):\n```python3\nspatialMoments(src[, moments[, binaryImage[, order[, momentsType[, stream]]]]]) -> moments\n```\n#### Variant 2:\nCalculates all of the spatial moments up to the 3rd order of a rasterized shape.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Raster image (single-channel 2D array).\n\n##### Keyword Arguments\n- **binaryImage**: `bool`.\n\n  If it is true, all non-zero image pixels are treated as 1's.\n\n- **order**: `MomentsOrder`.\n\n  Order of largest moments to calculate with lower order moments requiring less computation.\n\n- **momentsType**: `integer()`.\n\n  Precision to use when calculating moments. Available types are \\ref CV_32F and \\ref CV_64F with the performance of \\ref CV_32F an order of magnitude greater than \\ref CV_64F. If the image is small the accuracy from \\ref CV_32F can be equal or very close to \\ref CV_64F.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **moments**: `Evision.CUDA.GpuMat.t()`.\n\nAsynchronous version of cuda::moments() which only calculates the spatial (not centralized or normalized) moments, up to the 3rd order, of a rasterized shape.\nEach moment is returned as a column entry in the 1D \\a moments array.\n\n**Note**: For maximum performance pre-allocate a 1D GpuMat for \\a moments of the correct type and size large enough to store the all the image moments of up to the desired \\a order. e.g. With \\a order === MomentsOrder::SECOND_ORDER_MOMENTS and \\a momentsType == \\ref CV_32F \\a moments can be allocated as\n```\nGpuMat momentsDevice(1,numMoments(MomentsOrder::SECOND_ORDER_MOMENTS),CV_32F)\n```\nThe central and normalized moments can easily be calculated on the host by downloading the \\a moments array and using the cuda::convertSpatialMoments helper function. e.g.\n```\nHostMem spatialMomentsHostMem(1, numMoments(MomentsOrder::SECOND_ORDER_MOMENTS), CV_32F);\nspatialMomentsDevice.download(spatialMomentsHostMem, stream);\nstream.waitForCompletion();\nMat spatialMoments = spatialMomentsHostMem.createMatHeader();\ncv::Moments cvMoments = convertSpatialMoments (spatialMoments, order);\n```\nsee the \\a CUDA_TEST_P(Moments, Async) test inside opencv_contrib_source_code/modules/cudaimgproc/test/test_moments.cpp for an example.\n@sa cuda::moments, cuda::convertSpatialMoments, cuda::numMoments, cuda::MomentsOrder\n\nPython prototype (for reference only):\n```python3\nspatialMoments(src[, moments[, binaryImage[, order[, momentsType[, stream]]]]]) -> moments\n```","ref":"Evision.CUDA.html#spatialMoments/2"},{"type":"function","title":"Evision.CUDA.split/1","doc":"#### Variant 1:\nsplit\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `[Evision.CUDA.GpuMat]`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nsplit(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nsplit\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `[Evision.CUDA.GpuMat]`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nsplit(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#split/1"},{"type":"function","title":"Evision.CUDA.split/2","doc":"#### Variant 1:\nsplit\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `[Evision.CUDA.GpuMat]`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nsplit(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nsplit\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `[Evision.CUDA.GpuMat]`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nsplit(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#split/2"},{"type":"function","title":"Evision.CUDA.sqr/1","doc":"#### Variant 1:\nComputes a square value of each matrix element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source matrix.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix with the same size and type as src .\n\nPython prototype (for reference only):\n```python3\nsqr(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nComputes a square value of each matrix element.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix with the same size and type as src .\n\nPython prototype (for reference only):\n```python3\nsqr(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#sqr/1"},{"type":"function","title":"Evision.CUDA.sqr/2","doc":"#### Variant 1:\nComputes a square value of each matrix element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source matrix.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix with the same size and type as src .\n\nPython prototype (for reference only):\n```python3\nsqr(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nComputes a square value of each matrix element.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix with the same size and type as src .\n\nPython prototype (for reference only):\n```python3\nsqr(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#sqr/2"},{"type":"function","title":"Evision.CUDA.sqrIntegral/1","doc":"#### Variant 1:\nComputes a squared integral image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. Only CV_8UC1 images are supported for now.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **sqsum**: `Evision.Mat.t()`.\n\n  Squared integral image containing 64-bit unsigned integer values packed into\n  CV_64FC1 .\n\nPython prototype (for reference only):\n```python3\nsqrIntegral(src[, sqsum[, stream]]) -> sqsum\n```\n#### Variant 2:\nComputes a squared integral image.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. Only CV_8UC1 images are supported for now.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **sqsum**: `Evision.CUDA.GpuMat.t()`.\n\n  Squared integral image containing 64-bit unsigned integer values packed into\n  CV_64FC1 .\n\nPython prototype (for reference only):\n```python3\nsqrIntegral(src[, sqsum[, stream]]) -> sqsum\n```","ref":"Evision.CUDA.html#sqrIntegral/1"},{"type":"function","title":"Evision.CUDA.sqrIntegral/2","doc":"#### Variant 1:\nComputes a squared integral image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. Only CV_8UC1 images are supported for now.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **sqsum**: `Evision.Mat.t()`.\n\n  Squared integral image containing 64-bit unsigned integer values packed into\n  CV_64FC1 .\n\nPython prototype (for reference only):\n```python3\nsqrIntegral(src[, sqsum[, stream]]) -> sqsum\n```\n#### Variant 2:\nComputes a squared integral image.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. Only CV_8UC1 images are supported for now.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **sqsum**: `Evision.CUDA.GpuMat.t()`.\n\n  Squared integral image containing 64-bit unsigned integer values packed into\n  CV_64FC1 .\n\nPython prototype (for reference only):\n```python3\nsqrIntegral(src[, sqsum[, stream]]) -> sqsum\n```","ref":"Evision.CUDA.html#sqrIntegral/2"},{"type":"function","title":"Evision.CUDA.sqrSum/1","doc":"#### Variant 1:\nReturns the squared sum of matrix elements.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image of any depth except for CV_64F .\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  optional operation mask; it must have the same size as src1 and CV_8UC1 type.\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n\nPython prototype (for reference only):\n```python3\nsqrSum(src[, mask]) -> retval\n```\n#### Variant 2:\nReturns the squared sum of matrix elements.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image of any depth except for CV_64F .\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  optional operation mask; it must have the same size as src1 and CV_8UC1 type.\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n\nPython prototype (for reference only):\n```python3\nsqrSum(src[, mask]) -> retval\n```","ref":"Evision.CUDA.html#sqrSum/1"},{"type":"function","title":"Evision.CUDA.sqrSum/2","doc":"#### Variant 1:\nReturns the squared sum of matrix elements.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image of any depth except for CV_64F .\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  optional operation mask; it must have the same size as src1 and CV_8UC1 type.\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n\nPython prototype (for reference only):\n```python3\nsqrSum(src[, mask]) -> retval\n```\n#### Variant 2:\nReturns the squared sum of matrix elements.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image of any depth except for CV_64F .\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  optional operation mask; it must have the same size as src1 and CV_8UC1 type.\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n\nPython prototype (for reference only):\n```python3\nsqrSum(src[, mask]) -> retval\n```","ref":"Evision.CUDA.html#sqrSum/2"},{"type":"function","title":"Evision.CUDA.sqrt/1","doc":"#### Variant 1:\nComputes a square root of each matrix element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source matrix.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix with the same size and type as src .\n\n@sa sqrt\n\nPython prototype (for reference only):\n```python3\nsqrt(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nComputes a square root of each matrix element.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix with the same size and type as src .\n\n@sa sqrt\n\nPython prototype (for reference only):\n```python3\nsqrt(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#sqrt/1"},{"type":"function","title":"Evision.CUDA.sqrt/2","doc":"#### Variant 1:\nComputes a square root of each matrix element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source matrix.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix with the same size and type as src .\n\n@sa sqrt\n\nPython prototype (for reference only):\n```python3\nsqrt(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nComputes a square root of each matrix element.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix with the same size and type as src .\n\n@sa sqrt\n\nPython prototype (for reference only):\n```python3\nsqrt(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#sqrt/2"},{"type":"function","title":"Evision.CUDA.subtract/1","doc":"","ref":"Evision.CUDA.html#subtract/1"},{"type":"function","title":"Evision.CUDA.subtract/2","doc":"#### Variant 1:\nComputes a matrix-matrix or matrix-scalar difference.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.Mat`.\n\n  Second source matrix or scalar. Matrix should have the same size and type as src1 .\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional operation mask, 8-bit single channel array, that specifies elements of the\n  destination array to be changed. The mask can be used only with single channel images.\n\n- **dtype**: `integer()`.\n\n  Optional depth of the output array.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix that has the same size and number of channels as the input array(s).\n  The depth is defined by dtype or src1 depth.\n\n@sa subtract\n\nPython prototype (for reference only):\n```python3\nsubtract(src1, src2[, dst[, mask[, dtype[, stream]]]]) -> dst\n```\n#### Variant 2:\nComputes a matrix-matrix or matrix-scalar difference.\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second source matrix or scalar. Matrix should have the same size and type as src1 .\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Optional operation mask, 8-bit single channel array, that specifies elements of the\n  destination array to be changed. The mask can be used only with single channel images.\n\n- **dtype**: `integer()`.\n\n  Optional depth of the output array.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix that has the same size and number of channels as the input array(s).\n  The depth is defined by dtype or src1 depth.\n\n@sa subtract\n\nPython prototype (for reference only):\n```python3\nsubtract(src1, src2[, dst[, mask[, dtype[, stream]]]]) -> dst\n```","ref":"Evision.CUDA.html#subtract/2"},{"type":"function","title":"Evision.CUDA.subtract/3","doc":"#### Variant 1:\nComputes a matrix-matrix or matrix-scalar difference.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.Mat`.\n\n  Second source matrix or scalar. Matrix should have the same size and type as src1 .\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional operation mask, 8-bit single channel array, that specifies elements of the\n  destination array to be changed. The mask can be used only with single channel images.\n\n- **dtype**: `integer()`.\n\n  Optional depth of the output array.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix that has the same size and number of channels as the input array(s).\n  The depth is defined by dtype or src1 depth.\n\n@sa subtract\n\nPython prototype (for reference only):\n```python3\nsubtract(src1, src2[, dst[, mask[, dtype[, stream]]]]) -> dst\n```\n#### Variant 2:\nComputes a matrix-matrix or matrix-scalar difference.\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  First source matrix or scalar.\n\n- **src2**: `Evision.CUDA.GpuMat.t()`.\n\n  Second source matrix or scalar. Matrix should have the same size and type as src1 .\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Optional operation mask, 8-bit single channel array, that specifies elements of the\n  destination array to be changed. The mask can be used only with single channel images.\n\n- **dtype**: `integer()`.\n\n  Optional depth of the output array.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix that has the same size and number of channels as the input array(s).\n  The depth is defined by dtype or src1 depth.\n\n@sa subtract\n\nPython prototype (for reference only):\n```python3\nsubtract(src1, src2[, dst[, mask[, dtype[, stream]]]]) -> dst\n```","ref":"Evision.CUDA.html#subtract/3"},{"type":"function","title":"Evision.CUDA.sum/1","doc":"#### Variant 1:\nReturns the sum of matrix elements.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image of any depth except for CV_64F .\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  optional operation mask; it must have the same size as src1 and CV_8UC1 type.\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n\n@sa sum\n\nPython prototype (for reference only):\n```python3\nsum(src[, mask]) -> retval\n```\n#### Variant 2:\nReturns the sum of matrix elements.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image of any depth except for CV_64F .\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  optional operation mask; it must have the same size as src1 and CV_8UC1 type.\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n\n@sa sum\n\nPython prototype (for reference only):\n```python3\nsum(src[, mask]) -> retval\n```","ref":"Evision.CUDA.html#sum/1"},{"type":"function","title":"Evision.CUDA.sum/2","doc":"#### Variant 1:\nReturns the sum of matrix elements.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image of any depth except for CV_64F .\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  optional operation mask; it must have the same size as src1 and CV_8UC1 type.\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n\n@sa sum\n\nPython prototype (for reference only):\n```python3\nsum(src[, mask]) -> retval\n```\n#### Variant 2:\nReturns the sum of matrix elements.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image of any depth except for CV_64F .\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  optional operation mask; it must have the same size as src1 and CV_8UC1 type.\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n\n@sa sum\n\nPython prototype (for reference only):\n```python3\nsum(src[, mask]) -> retval\n```","ref":"Evision.CUDA.html#sum/2"},{"type":"function","title":"Evision.CUDA.threshold/1","doc":"","ref":"Evision.CUDA.html#threshold/1"},{"type":"function","title":"Evision.CUDA.threshold/4","doc":"#### Variant 1:\nApplies a fixed-level threshold to each array element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source array (single-channel).\n\n- **thresh**: `double`.\n\n  Threshold value.\n\n- **maxval**: `double`.\n\n  Maximum value to use with THRESH_BINARY and THRESH_BINARY_INV threshold types.\n\n- **type**: `integer()`.\n\n  Threshold type. For details, see threshold . The THRESH_OTSU and THRESH_TRIANGLE\n  threshold types are not supported.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **retval**: `double`\n- **dst**: `Evision.Mat.t()`.\n\n  Destination array with the same size and type as src .\n\n@sa threshold\n\nPython prototype (for reference only):\n```python3\nthreshold(src, thresh, maxval, type[, dst[, stream]]) -> retval, dst\n```\n#### Variant 2:\nApplies a fixed-level threshold to each array element.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source array (single-channel).\n\n- **thresh**: `double`.\n\n  Threshold value.\n\n- **maxval**: `double`.\n\n  Maximum value to use with THRESH_BINARY and THRESH_BINARY_INV threshold types.\n\n- **type**: `integer()`.\n\n  Threshold type. For details, see threshold . The THRESH_OTSU and THRESH_TRIANGLE\n  threshold types are not supported.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **retval**: `double`\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination array with the same size and type as src .\n\n@sa threshold\n\nPython prototype (for reference only):\n```python3\nthreshold(src, thresh, maxval, type[, dst[, stream]]) -> retval, dst\n```","ref":"Evision.CUDA.html#threshold/4"},{"type":"function","title":"Evision.CUDA.threshold/5","doc":"#### Variant 1:\nApplies a fixed-level threshold to each array element.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source array (single-channel).\n\n- **thresh**: `double`.\n\n  Threshold value.\n\n- **maxval**: `double`.\n\n  Maximum value to use with THRESH_BINARY and THRESH_BINARY_INV threshold types.\n\n- **type**: `integer()`.\n\n  Threshold type. For details, see threshold . The THRESH_OTSU and THRESH_TRIANGLE\n  threshold types are not supported.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **retval**: `double`\n- **dst**: `Evision.Mat.t()`.\n\n  Destination array with the same size and type as src .\n\n@sa threshold\n\nPython prototype (for reference only):\n```python3\nthreshold(src, thresh, maxval, type[, dst[, stream]]) -> retval, dst\n```\n#### Variant 2:\nApplies a fixed-level threshold to each array element.\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source array (single-channel).\n\n- **thresh**: `double`.\n\n  Threshold value.\n\n- **maxval**: `double`.\n\n  Maximum value to use with THRESH_BINARY and THRESH_BINARY_INV threshold types.\n\n- **type**: `integer()`.\n\n  Threshold type. For details, see threshold . The THRESH_OTSU and THRESH_TRIANGLE\n  threshold types are not supported.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **retval**: `double`\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination array with the same size and type as src .\n\n@sa threshold\n\nPython prototype (for reference only):\n```python3\nthreshold(src, thresh, maxval, type[, dst[, stream]]) -> retval, dst\n```","ref":"Evision.CUDA.html#threshold/5"},{"type":"function","title":"Evision.CUDA.transpose/1","doc":"#### Variant 1:\nTransposes a matrix.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  Source matrix. 1-, 4-, 8-byte element sizes are supported for now.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix.\n\n@sa transpose\n\nPython prototype (for reference only):\n```python3\ntranspose(src1[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nTransposes a matrix.\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix. 1-, 4-, 8-byte element sizes are supported for now.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix.\n\n@sa transpose\n\nPython prototype (for reference only):\n```python3\ntranspose(src1[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#transpose/1"},{"type":"function","title":"Evision.CUDA.transpose/2","doc":"#### Variant 1:\nTransposes a matrix.\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`.\n\n  Source matrix. 1-, 4-, 8-byte element sizes are supported for now.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix.\n\n@sa transpose\n\nPython prototype (for reference only):\n```python3\ntranspose(src1[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nTransposes a matrix.\n\n##### Positional Arguments\n- **src1**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix. 1-, 4-, 8-byte element sizes are supported for now.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix.\n\n@sa transpose\n\nPython prototype (for reference only):\n```python3\ntranspose(src1[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.html#transpose/2"},{"type":"function","title":"Evision.CUDA.unregisterPageLocked/1","doc":"Unmaps the memory of matrix and makes it pageable again.\n\n##### Positional Arguments\n- **m**: `Evision.Mat`.\n\n  Input matrix.\n\nPython prototype (for reference only):\n```python3\nunregisterPageLocked(m) -> None\n```","ref":"Evision.CUDA.html#unregisterPageLocked/1"},{"type":"function","title":"Evision.CUDA.warpAffine/1","doc":"","ref":"Evision.CUDA.html#warpAffine/1"},{"type":"function","title":"Evision.CUDA.warpAffine/3","doc":"#### Variant 1:\nwarpAffine\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n- **m**: `Evision.Mat`\n- **dsize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **borderMode**: `integer()`.\n- **borderValue**: `Evision.scalar()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nwarpAffine(src, M, dsize[, dst[, flags[, borderMode[, borderValue[, stream]]]]]) -> dst\n```\n#### Variant 2:\nwarpAffine\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n- **m**: `Evision.Mat`\n- **dsize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **borderMode**: `integer()`.\n- **borderValue**: `Evision.scalar()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\nwarpAffine(src, M, dsize[, dst[, flags[, borderMode[, borderValue[, stream]]]]]) -> dst\n```","ref":"Evision.CUDA.html#warpAffine/3"},{"type":"function","title":"Evision.CUDA.warpAffine/4","doc":"#### Variant 1:\nwarpAffine\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n- **m**: `Evision.Mat`\n- **dsize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **borderMode**: `integer()`.\n- **borderValue**: `Evision.scalar()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nwarpAffine(src, M, dsize[, dst[, flags[, borderMode[, borderValue[, stream]]]]]) -> dst\n```\n#### Variant 2:\nwarpAffine\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n- **m**: `Evision.Mat`\n- **dsize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **borderMode**: `integer()`.\n- **borderValue**: `Evision.scalar()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\nwarpAffine(src, M, dsize[, dst[, flags[, borderMode[, borderValue[, stream]]]]]) -> dst\n```","ref":"Evision.CUDA.html#warpAffine/4"},{"type":"function","title":"Evision.CUDA.warpPerspective/1","doc":"","ref":"Evision.CUDA.html#warpPerspective/1"},{"type":"function","title":"Evision.CUDA.warpPerspective/3","doc":"#### Variant 1:\nwarpPerspective\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n- **m**: `Evision.Mat`\n- **dsize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **borderMode**: `integer()`.\n- **borderValue**: `Evision.scalar()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nwarpPerspective(src, M, dsize[, dst[, flags[, borderMode[, borderValue[, stream]]]]]) -> dst\n```\n#### Variant 2:\nwarpPerspective\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n- **m**: `Evision.Mat`\n- **dsize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **borderMode**: `integer()`.\n- **borderValue**: `Evision.scalar()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\nwarpPerspective(src, M, dsize[, dst[, flags[, borderMode[, borderValue[, stream]]]]]) -> dst\n```","ref":"Evision.CUDA.html#warpPerspective/3"},{"type":"function","title":"Evision.CUDA.warpPerspective/4","doc":"#### Variant 1:\nwarpPerspective\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n- **m**: `Evision.Mat`\n- **dsize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **borderMode**: `integer()`.\n- **borderValue**: `Evision.scalar()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nwarpPerspective(src, M, dsize[, dst[, flags[, borderMode[, borderValue[, stream]]]]]) -> dst\n```\n#### Variant 2:\nwarpPerspective\n\n##### Positional Arguments\n- **src**: `Evision.CUDA.GpuMat.t()`\n- **m**: `Evision.Mat`\n- **dsize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **borderMode**: `integer()`.\n- **borderValue**: `Evision.scalar()`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\nwarpPerspective(src, M, dsize[, dst[, flags[, borderMode[, borderValue[, stream]]]]]) -> dst\n```","ref":"Evision.CUDA.html#warpPerspective/4"},{"type":"function","title":"Evision.CUDA.wrapStream/1","doc":"Bindings overload to create a Stream object from the address stored in an existing CUDA Runtime API stream pointer (cudaStream_t).\n\n##### Positional Arguments\n- **cudaStreamMemoryAddress**: `size_t`.\n\n  Memory address stored in a CUDA Runtime API stream pointer (cudaStream_t). The created Stream object does not perform any allocation or deallocation and simply wraps existing raw CUDA Runtime API stream pointer.\n\n##### Return\n- **retval**: `Evision.CUDA.Stream.t()`\n\n**Note**: Overload for generation of bindings only, not exported or intended for use internally from C++.\n\nPython prototype (for reference only):\n```python3\nwrapStream(cudaStreamMemoryAddress) -> retval\n```","ref":"Evision.CUDA.html#wrapStream/1"},{"type":"type","title":"Evision.CUDA.t/0","doc":"Type that represents an `CUDA` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.html#t:t/0"},{"type":"module","title":"Evision.CUDA.AlphaCompTypes","doc":"","ref":"Evision.CUDA.AlphaCompTypes.html"},{"type":"function","title":"Evision.CUDA.AlphaCompTypes.cv_ALPHA_ATOP/0","doc":"","ref":"Evision.CUDA.AlphaCompTypes.html#cv_ALPHA_ATOP/0"},{"type":"function","title":"Evision.CUDA.AlphaCompTypes.cv_ALPHA_ATOP_PREMUL/0","doc":"","ref":"Evision.CUDA.AlphaCompTypes.html#cv_ALPHA_ATOP_PREMUL/0"},{"type":"function","title":"Evision.CUDA.AlphaCompTypes.cv_ALPHA_IN/0","doc":"","ref":"Evision.CUDA.AlphaCompTypes.html#cv_ALPHA_IN/0"},{"type":"function","title":"Evision.CUDA.AlphaCompTypes.cv_ALPHA_IN_PREMUL/0","doc":"","ref":"Evision.CUDA.AlphaCompTypes.html#cv_ALPHA_IN_PREMUL/0"},{"type":"function","title":"Evision.CUDA.AlphaCompTypes.cv_ALPHA_OUT/0","doc":"","ref":"Evision.CUDA.AlphaCompTypes.html#cv_ALPHA_OUT/0"},{"type":"function","title":"Evision.CUDA.AlphaCompTypes.cv_ALPHA_OUT_PREMUL/0","doc":"","ref":"Evision.CUDA.AlphaCompTypes.html#cv_ALPHA_OUT_PREMUL/0"},{"type":"function","title":"Evision.CUDA.AlphaCompTypes.cv_ALPHA_OVER/0","doc":"","ref":"Evision.CUDA.AlphaCompTypes.html#cv_ALPHA_OVER/0"},{"type":"function","title":"Evision.CUDA.AlphaCompTypes.cv_ALPHA_OVER_PREMUL/0","doc":"","ref":"Evision.CUDA.AlphaCompTypes.html#cv_ALPHA_OVER_PREMUL/0"},{"type":"function","title":"Evision.CUDA.AlphaCompTypes.cv_ALPHA_PLUS/0","doc":"","ref":"Evision.CUDA.AlphaCompTypes.html#cv_ALPHA_PLUS/0"},{"type":"function","title":"Evision.CUDA.AlphaCompTypes.cv_ALPHA_PLUS_PREMUL/0","doc":"","ref":"Evision.CUDA.AlphaCompTypes.html#cv_ALPHA_PLUS_PREMUL/0"},{"type":"function","title":"Evision.CUDA.AlphaCompTypes.cv_ALPHA_PREMUL/0","doc":"","ref":"Evision.CUDA.AlphaCompTypes.html#cv_ALPHA_PREMUL/0"},{"type":"function","title":"Evision.CUDA.AlphaCompTypes.cv_ALPHA_XOR/0","doc":"","ref":"Evision.CUDA.AlphaCompTypes.html#cv_ALPHA_XOR/0"},{"type":"function","title":"Evision.CUDA.AlphaCompTypes.cv_ALPHA_XOR_PREMUL/0","doc":"","ref":"Evision.CUDA.AlphaCompTypes.html#cv_ALPHA_XOR_PREMUL/0"},{"type":"type","title":"Evision.CUDA.AlphaCompTypes.enum/0","doc":"","ref":"Evision.CUDA.AlphaCompTypes.html#t:enum/0"},{"type":"module","title":"Evision.CUDA.BackgroundSubtractorMOG","doc":"","ref":"Evision.CUDA.BackgroundSubtractorMOG.html"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.apply/1","doc":"","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#apply/1"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.apply/4","doc":"#### Variant 1:\napply\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG.t()`\n- **image**: `Evision.Mat`\n- **learningRate**: `double`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **fgmask**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\napply(image, learningRate, stream[, fgmask]) -> fgmask\n```\n#### Variant 2:\napply\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`\n- **learningRate**: `double`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **fgmask**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\napply(image, learningRate, stream[, fgmask]) -> fgmask\n```","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#apply/4"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.apply/5","doc":"#### Variant 1:\napply\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG.t()`\n- **image**: `Evision.Mat`\n- **learningRate**: `double`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **fgmask**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\napply(image, learningRate, stream[, fgmask]) -> fgmask\n```\n#### Variant 2:\napply\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`\n- **learningRate**: `double`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **fgmask**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\napply(image, learningRate, stream[, fgmask]) -> fgmask\n```","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#apply/5"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#clear/1"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#empty/1"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.getBackgroundImage/1","doc":"","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#getBackgroundImage/1"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.getBackgroundImage/2","doc":"getBackgroundImage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG.t()`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **backgroundImage**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetBackgroundImage(stream[, backgroundImage]) -> backgroundImage\n```","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#getBackgroundImage/2"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.getBackgroundImage/3","doc":"getBackgroundImage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG.t()`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **backgroundImage**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetBackgroundImage(stream[, backgroundImage]) -> backgroundImage\n```","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#getBackgroundImage/3"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.getBackgroundRatio/1","doc":"getBackgroundRatio\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetBackgroundRatio() -> retval\n```","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#getBackgroundRatio/1"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#getDefaultName/1"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.getHistory/1","doc":"getHistory\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetHistory() -> retval\n```","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#getHistory/1"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.getNMixtures/1","doc":"getNMixtures\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNMixtures() -> retval\n```","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#getNMixtures/1"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.getNoiseSigma/1","doc":"getNoiseSigma\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetNoiseSigma() -> retval\n```","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#getNoiseSigma/1"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.read/1","doc":"","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#read/1"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#read/2"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.save/1","doc":"","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#save/1"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#save/2"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.setBackgroundRatio/1","doc":"","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#setBackgroundRatio/1"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.setBackgroundRatio/2","doc":"setBackgroundRatio\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG.t()`\n- **backgroundRatio**: `double`\n\nPython prototype (for reference only):\n```python3\nsetBackgroundRatio(backgroundRatio) -> None\n```","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#setBackgroundRatio/2"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.setHistory/1","doc":"","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#setHistory/1"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.setHistory/2","doc":"setHistory\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG.t()`\n- **nframes**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetHistory(nframes) -> None\n```","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#setHistory/2"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.setNMixtures/1","doc":"","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#setNMixtures/1"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.setNMixtures/2","doc":"setNMixtures\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG.t()`\n- **nmix**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNMixtures(nmix) -> None\n```","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#setNMixtures/2"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.setNoiseSigma/1","doc":"","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#setNoiseSigma/1"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.setNoiseSigma/2","doc":"setNoiseSigma\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG.t()`\n- **noiseSigma**: `double`\n\nPython prototype (for reference only):\n```python3\nsetNoiseSigma(noiseSigma) -> None\n```","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#setNoiseSigma/2"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.write/1","doc":"","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#write/1"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#write/2"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#write/3"},{"type":"type","title":"Evision.CUDA.BackgroundSubtractorMOG.t/0","doc":"Type that represents an `CUDA.BackgroundSubtractorMOG` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.BackgroundSubtractorMOG.html#t:t/0"},{"type":"module","title":"Evision.CUDA.BackgroundSubtractorMOG2","doc":"","ref":"Evision.CUDA.BackgroundSubtractorMOG2.html"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG2.apply/1","doc":"","ref":"Evision.CUDA.BackgroundSubtractorMOG2.html#apply/1"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG2.apply/4","doc":"#### Variant 1:\napply\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG2.t()`\n- **image**: `Evision.Mat`\n- **learningRate**: `double`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **fgmask**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\napply(image, learningRate, stream[, fgmask]) -> fgmask\n```\n#### Variant 2:\napply\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG2.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`\n- **learningRate**: `double`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **fgmask**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\napply(image, learningRate, stream[, fgmask]) -> fgmask\n```","ref":"Evision.CUDA.BackgroundSubtractorMOG2.html#apply/4"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG2.apply/5","doc":"#### Variant 1:\napply\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG2.t()`\n- **image**: `Evision.Mat`\n- **learningRate**: `double`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **fgmask**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\napply(image, learningRate, stream[, fgmask]) -> fgmask\n```\n#### Variant 2:\napply\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG2.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`\n- **learningRate**: `double`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **fgmask**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\napply(image, learningRate, stream[, fgmask]) -> fgmask\n```","ref":"Evision.CUDA.BackgroundSubtractorMOG2.html#apply/5"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG2.getBackgroundImage/1","doc":"","ref":"Evision.CUDA.BackgroundSubtractorMOG2.html#getBackgroundImage/1"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG2.getBackgroundImage/2","doc":"getBackgroundImage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG2.t()`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **backgroundImage**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetBackgroundImage(stream[, backgroundImage]) -> backgroundImage\n```","ref":"Evision.CUDA.BackgroundSubtractorMOG2.html#getBackgroundImage/2"},{"type":"function","title":"Evision.CUDA.BackgroundSubtractorMOG2.getBackgroundImage/3","doc":"getBackgroundImage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BackgroundSubtractorMOG2.t()`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **backgroundImage**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetBackgroundImage(stream[, backgroundImage]) -> backgroundImage\n```","ref":"Evision.CUDA.BackgroundSubtractorMOG2.html#getBackgroundImage/3"},{"type":"type","title":"Evision.CUDA.BackgroundSubtractorMOG2.t/0","doc":"Type that represents an `CUDA.BackgroundSubtractorMOG2` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.BackgroundSubtractorMOG2.html#t:t/0"},{"type":"module","title":"Evision.CUDA.BufferPool","doc":"","ref":"Evision.CUDA.BufferPool.html"},{"type":"function","title":"Evision.CUDA.BufferPool.bufferPool/1","doc":"BufferPool\n\n##### Positional Arguments\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **self**: `Evision.CUDA.BufferPool.t()`\n\nPython prototype (for reference only):\n```python3\nBufferPool(stream) ->  \n```","ref":"Evision.CUDA.BufferPool.html#bufferPool/1"},{"type":"function","title":"Evision.CUDA.BufferPool.getAllocator/1","doc":"getAllocator\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BufferPool.t()`\n\n##### Return\n- **retval**: `GpuMat::Allocator`\n\nPython prototype (for reference only):\n```python3\ngetAllocator() -> retval\n```","ref":"Evision.CUDA.BufferPool.html#getAllocator/1"},{"type":"function","title":"Evision.CUDA.BufferPool.getBuffer/1","doc":"","ref":"Evision.CUDA.BufferPool.html#getBuffer/1"},{"type":"function","title":"Evision.CUDA.BufferPool.getBuffer/3","doc":"getBuffer\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BufferPool.t()`\n- **size**: `Size`\n- **type**: `integer()`\n\n##### Return\n- **retval**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\ngetBuffer(size, type) -> retval\n```","ref":"Evision.CUDA.BufferPool.html#getBuffer/3"},{"type":"function","title":"Evision.CUDA.BufferPool.getBuffer/4","doc":"getBuffer\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.BufferPool.t()`\n- **rows**: `integer()`\n- **cols**: `integer()`\n- **type**: `integer()`\n\n##### Return\n- **retval**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\ngetBuffer(rows, cols, type) -> retval\n```","ref":"Evision.CUDA.BufferPool.html#getBuffer/4"},{"type":"type","title":"Evision.CUDA.BufferPool.t/0","doc":"Type that represents an `CUDA.BufferPool` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.BufferPool.html#t:t/0"},{"type":"module","title":"Evision.CUDA.CLAHE","doc":"","ref":"Evision.CUDA.CLAHE.html"},{"type":"function","title":"Evision.CUDA.CLAHE.apply/1","doc":"","ref":"Evision.CUDA.CLAHE.html#apply/1"},{"type":"function","title":"Evision.CUDA.CLAHE.apply/3","doc":"#### Variant 1:\nEqualizes the histogram of a grayscale image using Contrast Limited Adaptive Histogram Equalization.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CLAHE.t()`\n- **src**: `Evision.Mat`.\n\n  Source image with CV_8UC1 type.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image.\n\nPython prototype (for reference only):\n```python3\napply(src, stream[, dst]) -> dst\n```\n#### Variant 2:\nEqualizes the histogram of a grayscale image using Contrast Limited Adaptive Histogram Equalization.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CLAHE.t()`\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image with CV_8UC1 type.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image.\n\nPython prototype (for reference only):\n```python3\napply(src, stream[, dst]) -> dst\n```","ref":"Evision.CUDA.CLAHE.html#apply/3"},{"type":"function","title":"Evision.CUDA.CLAHE.apply/4","doc":"#### Variant 1:\nEqualizes the histogram of a grayscale image using Contrast Limited Adaptive Histogram Equalization.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CLAHE.t()`\n- **src**: `Evision.Mat`.\n\n  Source image with CV_8UC1 type.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image.\n\nPython prototype (for reference only):\n```python3\napply(src, stream[, dst]) -> dst\n```\n#### Variant 2:\nEqualizes the histogram of a grayscale image using Contrast Limited Adaptive Histogram Equalization.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CLAHE.t()`\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image with CV_8UC1 type.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image.\n\nPython prototype (for reference only):\n```python3\napply(src, stream[, dst]) -> dst\n```","ref":"Evision.CUDA.CLAHE.html#apply/4"},{"type":"type","title":"Evision.CUDA.CLAHE.t/0","doc":"Type that represents an `CUDA.CLAHE` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.CLAHE.html#t:t/0"},{"type":"module","title":"Evision.CUDA.CannyEdgeDetector","doc":"","ref":"Evision.CUDA.CannyEdgeDetector.html"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CannyEdgeDetector.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.CUDA.CannyEdgeDetector.html#clear/1"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.detect/1","doc":"","ref":"Evision.CUDA.CannyEdgeDetector.html#detect/1"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.detect/2","doc":"#### Variant 1:\nFinds edges in an image using the @cite Canny86 algorithm.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CannyEdgeDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Single-channel 8-bit input image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **edges**: `Evision.Mat.t()`.\n\n  Output edge map. It has the same size and type as image.\n\nPython prototype (for reference only):\n```python3\ndetect(image[, edges[, stream]]) -> edges\n```\n#### Variant 2:\nFinds edges in an image using the @cite Canny86 algorithm.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CannyEdgeDetector.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Single-channel 8-bit input image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **edges**: `Evision.CUDA.GpuMat.t()`.\n\n  Output edge map. It has the same size and type as image.\n\nPython prototype (for reference only):\n```python3\ndetect(image[, edges[, stream]]) -> edges\n```","ref":"Evision.CUDA.CannyEdgeDetector.html#detect/2"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CannyEdgeDetector.t()`\n- **dx**: `Evision.Mat`.\n\n  First derivative of image in the vertical direction. Support only CV_32S type.\n\n- **dy**: `Evision.Mat`.\n\n  First derivative of image in the horizontal direction. Support only CV_32S type.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **edges**: `Evision.Mat.t()`.\n\n  Output edge map. It has the same size and type as image.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(dx, dy[, edges[, stream]]) -> edges\n```\n#### Variant 2:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CannyEdgeDetector.t()`\n- **dx**: `Evision.CUDA.GpuMat.t()`.\n\n  First derivative of image in the vertical direction. Support only CV_32S type.\n\n- **dy**: `Evision.CUDA.GpuMat.t()`.\n\n  First derivative of image in the horizontal direction. Support only CV_32S type.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **edges**: `Evision.CUDA.GpuMat.t()`.\n\n  Output edge map. It has the same size and type as image.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(dx, dy[, edges[, stream]]) -> edges\n```\n#### Variant 3:\nFinds edges in an image using the @cite Canny86 algorithm.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CannyEdgeDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Single-channel 8-bit input image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **edges**: `Evision.Mat.t()`.\n\n  Output edge map. It has the same size and type as image.\n\nPython prototype (for reference only):\n```python3\ndetect(image[, edges[, stream]]) -> edges\n```\n#### Variant 4:\nFinds edges in an image using the @cite Canny86 algorithm.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CannyEdgeDetector.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Single-channel 8-bit input image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **edges**: `Evision.CUDA.GpuMat.t()`.\n\n  Output edge map. It has the same size and type as image.\n\nPython prototype (for reference only):\n```python3\ndetect(image[, edges[, stream]]) -> edges\n```","ref":"Evision.CUDA.CannyEdgeDetector.html#detect/3"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.detect/4","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CannyEdgeDetector.t()`\n- **dx**: `Evision.Mat`.\n\n  First derivative of image in the vertical direction. Support only CV_32S type.\n\n- **dy**: `Evision.Mat`.\n\n  First derivative of image in the horizontal direction. Support only CV_32S type.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **edges**: `Evision.Mat.t()`.\n\n  Output edge map. It has the same size and type as image.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(dx, dy[, edges[, stream]]) -> edges\n```\n#### Variant 2:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CannyEdgeDetector.t()`\n- **dx**: `Evision.CUDA.GpuMat.t()`.\n\n  First derivative of image in the vertical direction. Support only CV_32S type.\n\n- **dy**: `Evision.CUDA.GpuMat.t()`.\n\n  First derivative of image in the horizontal direction. Support only CV_32S type.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **edges**: `Evision.CUDA.GpuMat.t()`.\n\n  Output edge map. It has the same size and type as image.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(dx, dy[, edges[, stream]]) -> edges\n```","ref":"Evision.CUDA.CannyEdgeDetector.html#detect/4"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CannyEdgeDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CUDA.CannyEdgeDetector.html#empty/1"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.getAppertureSize/1","doc":"getAppertureSize\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CannyEdgeDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetAppertureSize() -> retval\n```","ref":"Evision.CUDA.CannyEdgeDetector.html#getAppertureSize/1"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CannyEdgeDetector.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CUDA.CannyEdgeDetector.html#getDefaultName/1"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.getHighThreshold/1","doc":"getHighThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CannyEdgeDetector.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetHighThreshold() -> retval\n```","ref":"Evision.CUDA.CannyEdgeDetector.html#getHighThreshold/1"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.getL2Gradient/1","doc":"getL2Gradient\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CannyEdgeDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetL2Gradient() -> retval\n```","ref":"Evision.CUDA.CannyEdgeDetector.html#getL2Gradient/1"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.getLowThreshold/1","doc":"getLowThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CannyEdgeDetector.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetLowThreshold() -> retval\n```","ref":"Evision.CUDA.CannyEdgeDetector.html#getLowThreshold/1"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.read/1","doc":"","ref":"Evision.CUDA.CannyEdgeDetector.html#read/1"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CannyEdgeDetector.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.CUDA.CannyEdgeDetector.html#read/2"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.save/1","doc":"","ref":"Evision.CUDA.CannyEdgeDetector.html#save/1"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CannyEdgeDetector.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.CUDA.CannyEdgeDetector.html#save/2"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.setAppertureSize/1","doc":"","ref":"Evision.CUDA.CannyEdgeDetector.html#setAppertureSize/1"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.setAppertureSize/2","doc":"setAppertureSize\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CannyEdgeDetector.t()`\n- **apperture_size**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetAppertureSize(apperture_size) -> None\n```","ref":"Evision.CUDA.CannyEdgeDetector.html#setAppertureSize/2"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.setHighThreshold/1","doc":"","ref":"Evision.CUDA.CannyEdgeDetector.html#setHighThreshold/1"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.setHighThreshold/2","doc":"setHighThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CannyEdgeDetector.t()`\n- **high_thresh**: `double`\n\nPython prototype (for reference only):\n```python3\nsetHighThreshold(high_thresh) -> None\n```","ref":"Evision.CUDA.CannyEdgeDetector.html#setHighThreshold/2"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.setL2Gradient/1","doc":"","ref":"Evision.CUDA.CannyEdgeDetector.html#setL2Gradient/1"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.setL2Gradient/2","doc":"setL2Gradient\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CannyEdgeDetector.t()`\n- **l2gradient**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetL2Gradient(L2gradient) -> None\n```","ref":"Evision.CUDA.CannyEdgeDetector.html#setL2Gradient/2"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.setLowThreshold/1","doc":"","ref":"Evision.CUDA.CannyEdgeDetector.html#setLowThreshold/1"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.setLowThreshold/2","doc":"setLowThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CannyEdgeDetector.t()`\n- **low_thresh**: `double`\n\nPython prototype (for reference only):\n```python3\nsetLowThreshold(low_thresh) -> None\n```","ref":"Evision.CUDA.CannyEdgeDetector.html#setLowThreshold/2"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.write/1","doc":"","ref":"Evision.CUDA.CannyEdgeDetector.html#write/1"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CannyEdgeDetector.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.CUDA.CannyEdgeDetector.html#write/2"},{"type":"function","title":"Evision.CUDA.CannyEdgeDetector.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CannyEdgeDetector.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CUDA.CannyEdgeDetector.html#write/3"},{"type":"type","title":"Evision.CUDA.CannyEdgeDetector.t/0","doc":"Type that represents an `CUDA.CannyEdgeDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.CannyEdgeDetector.html#t:t/0"},{"type":"module","title":"Evision.CUDA.CascadeClassifier","doc":"","ref":"Evision.CUDA.CascadeClassifier.html"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.CUDA.CascadeClassifier.html#clear/1"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.convert/1","doc":"","ref":"Evision.CUDA.CascadeClassifier.html#convert/1"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.convert/2","doc":"Converts objects array from internal representation to standard vector.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n- **objects**: `[Rect]`.\n\n  Resulting array.\n\n##### Return\n- **gpu_objects**: `Evision.Mat.t()`.\n\n  Objects array in internal representation.\n\nPython prototype (for reference only):\n```python3\nconvert(objects[, gpu_objects]) -> gpu_objects\n```","ref":"Evision.CUDA.CascadeClassifier.html#convert/2"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.convert/3","doc":"Converts objects array from internal representation to standard vector.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n- **objects**: `[Rect]`.\n\n  Resulting array.\n\n##### Return\n- **gpu_objects**: `Evision.Mat.t()`.\n\n  Objects array in internal representation.\n\nPython prototype (for reference only):\n```python3\nconvert(objects[, gpu_objects]) -> gpu_objects\n```","ref":"Evision.CUDA.CascadeClassifier.html#convert/3"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.create/1","doc":"Loads the classifier from a file. Cascade type is detected automatically by constructor parameter.\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  Name of the file from which the classifier is loaded. Only the old haar classifier\n  (trained by the haar training application) and NVIDIA's nvbin are supported for HAAR and only new\n  type of OpenCV XML cascade supported for LBP. The working haar models can be found at opencv_folder/data/haarcascades_cuda/\n\n##### Return\n- **retval**: `Evision.CUDA.CascadeClassifier.t()`\n\nPython prototype (for reference only):\n```python3\ncreate(filename) -> retval\n```","ref":"Evision.CUDA.CascadeClassifier.html#create/1"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.detectMultiScale/1","doc":"","ref":"Evision.CUDA.CascadeClassifier.html#detectMultiScale/1"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.detectMultiScale/2","doc":"#### Variant 1:\nDetects objects of different sizes in the input image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n- **image**: `Evision.Mat`.\n\n  Matrix of type CV_8U containing an image where objects should be detected.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **objects**: `Evision.Mat.t()`.\n\n  Buffer to store detected objects (rectangles).\n\nTo get final array of detected objects use CascadeClassifier::convert method.\n```\nPtr  cascade_gpu = cuda::CascadeClassifier::create(...);\nMat image_cpu = imread(...)\nGpuMat image_gpu(image_cpu);\nGpuMat objbuf;\ncascade_gpu->detectMultiScale(image_gpu, objbuf);\nstd::vector  faces;\ncascade_gpu->convert(objbuf, faces);\nfor(int i = 0; i   objects\n```\n#### Variant 2:\nDetects objects of different sizes in the input image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Matrix of type CV_8U containing an image where objects should be detected.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **objects**: `Evision.CUDA.GpuMat.t()`.\n\n  Buffer to store detected objects (rectangles).\n\nTo get final array of detected objects use CascadeClassifier::convert method.\n```\nPtr  cascade_gpu = cuda::CascadeClassifier::create(...);\nMat image_cpu = imread(...)\nGpuMat image_gpu(image_cpu);\nGpuMat objbuf;\ncascade_gpu->detectMultiScale(image_gpu, objbuf);\nstd::vector  faces;\ncascade_gpu->convert(objbuf, faces);\nfor(int i = 0; i   objects\n```","ref":"Evision.CUDA.CascadeClassifier.html#detectMultiScale/2"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.detectMultiScale/3","doc":"#### Variant 1:\nDetects objects of different sizes in the input image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n- **image**: `Evision.Mat`.\n\n  Matrix of type CV_8U containing an image where objects should be detected.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **objects**: `Evision.Mat.t()`.\n\n  Buffer to store detected objects (rectangles).\n\nTo get final array of detected objects use CascadeClassifier::convert method.\n```\nPtr  cascade_gpu = cuda::CascadeClassifier::create(...);\nMat image_cpu = imread(...)\nGpuMat image_gpu(image_cpu);\nGpuMat objbuf;\ncascade_gpu->detectMultiScale(image_gpu, objbuf);\nstd::vector  faces;\ncascade_gpu->convert(objbuf, faces);\nfor(int i = 0; i   objects\n```\n#### Variant 2:\nDetects objects of different sizes in the input image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Matrix of type CV_8U containing an image where objects should be detected.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **objects**: `Evision.CUDA.GpuMat.t()`.\n\n  Buffer to store detected objects (rectangles).\n\nTo get final array of detected objects use CascadeClassifier::convert method.\n```\nPtr  cascade_gpu = cuda::CascadeClassifier::create(...);\nMat image_cpu = imread(...)\nGpuMat image_gpu(image_cpu);\nGpuMat objbuf;\ncascade_gpu->detectMultiScale(image_gpu, objbuf);\nstd::vector  faces;\ncascade_gpu->convert(objbuf, faces);\nfor(int i = 0; i   objects\n```","ref":"Evision.CUDA.CascadeClassifier.html#detectMultiScale/3"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CUDA.CascadeClassifier.html#empty/1"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.getClassifierSize/1","doc":"getClassifierSize\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n\n##### Return\n- **retval**: `Size`\n\nPython prototype (for reference only):\n```python3\ngetClassifierSize() -> retval\n```","ref":"Evision.CUDA.CascadeClassifier.html#getClassifierSize/1"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CUDA.CascadeClassifier.html#getDefaultName/1"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.getFindLargestObject/1","doc":"getFindLargestObject\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetFindLargestObject() -> retval\n```","ref":"Evision.CUDA.CascadeClassifier.html#getFindLargestObject/1"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.getMaxNumObjects/1","doc":"getMaxNumObjects\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxNumObjects() -> retval\n```","ref":"Evision.CUDA.CascadeClassifier.html#getMaxNumObjects/1"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.getMaxObjectSize/1","doc":"getMaxObjectSize\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n\n##### Return\n- **retval**: `Size`\n\nPython prototype (for reference only):\n```python3\ngetMaxObjectSize() -> retval\n```","ref":"Evision.CUDA.CascadeClassifier.html#getMaxObjectSize/1"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.getMinNeighbors/1","doc":"getMinNeighbors\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMinNeighbors() -> retval\n```","ref":"Evision.CUDA.CascadeClassifier.html#getMinNeighbors/1"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.getMinObjectSize/1","doc":"getMinObjectSize\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n\n##### Return\n- **retval**: `Size`\n\nPython prototype (for reference only):\n```python3\ngetMinObjectSize() -> retval\n```","ref":"Evision.CUDA.CascadeClassifier.html#getMinObjectSize/1"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.getScaleFactor/1","doc":"getScaleFactor\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetScaleFactor() -> retval\n```","ref":"Evision.CUDA.CascadeClassifier.html#getScaleFactor/1"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.read/1","doc":"","ref":"Evision.CUDA.CascadeClassifier.html#read/1"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.CUDA.CascadeClassifier.html#read/2"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.save/1","doc":"","ref":"Evision.CUDA.CascadeClassifier.html#save/1"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.CUDA.CascadeClassifier.html#save/2"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.setFindLargestObject/1","doc":"","ref":"Evision.CUDA.CascadeClassifier.html#setFindLargestObject/1"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.setFindLargestObject/2","doc":"setFindLargestObject\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n- **findLargestObject**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetFindLargestObject(findLargestObject) -> None\n```","ref":"Evision.CUDA.CascadeClassifier.html#setFindLargestObject/2"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.setMaxNumObjects/1","doc":"","ref":"Evision.CUDA.CascadeClassifier.html#setMaxNumObjects/1"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.setMaxNumObjects/2","doc":"setMaxNumObjects\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n- **maxNumObjects**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxNumObjects(maxNumObjects) -> None\n```","ref":"Evision.CUDA.CascadeClassifier.html#setMaxNumObjects/2"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.setMaxObjectSize/1","doc":"","ref":"Evision.CUDA.CascadeClassifier.html#setMaxObjectSize/1"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.setMaxObjectSize/2","doc":"setMaxObjectSize\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n- **maxObjectSize**: `Size`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nsetMaxObjectSize(maxObjectSize) -> None\n```","ref":"Evision.CUDA.CascadeClassifier.html#setMaxObjectSize/2"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.setMinNeighbors/1","doc":"","ref":"Evision.CUDA.CascadeClassifier.html#setMinNeighbors/1"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.setMinNeighbors/2","doc":"setMinNeighbors\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n- **minNeighbors**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMinNeighbors(minNeighbors) -> None\n```","ref":"Evision.CUDA.CascadeClassifier.html#setMinNeighbors/2"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.setMinObjectSize/1","doc":"","ref":"Evision.CUDA.CascadeClassifier.html#setMinObjectSize/1"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.setMinObjectSize/2","doc":"setMinObjectSize\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n- **minSize**: `Size`\n\nPython prototype (for reference only):\n```python3\nsetMinObjectSize(minSize) -> None\n```","ref":"Evision.CUDA.CascadeClassifier.html#setMinObjectSize/2"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.setScaleFactor/1","doc":"","ref":"Evision.CUDA.CascadeClassifier.html#setScaleFactor/1"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.setScaleFactor/2","doc":"setScaleFactor\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n- **scaleFactor**: `double`\n\nPython prototype (for reference only):\n```python3\nsetScaleFactor(scaleFactor) -> None\n```","ref":"Evision.CUDA.CascadeClassifier.html#setScaleFactor/2"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.write/1","doc":"","ref":"Evision.CUDA.CascadeClassifier.html#write/1"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.CUDA.CascadeClassifier.html#write/2"},{"type":"function","title":"Evision.CUDA.CascadeClassifier.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CascadeClassifier.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CUDA.CascadeClassifier.html#write/3"},{"type":"type","title":"Evision.CUDA.CascadeClassifier.t/0","doc":"Type that represents an `CUDA.CascadeClassifier` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.CascadeClassifier.html#t:t/0"},{"type":"module","title":"Evision.CUDA.ConnectedComponentsAlgorithmsTypes","doc":"","ref":"Evision.CUDA.ConnectedComponentsAlgorithmsTypes.html"},{"type":"function","title":"Evision.CUDA.ConnectedComponentsAlgorithmsTypes.cv_CCL_BKE/0","doc":"","ref":"Evision.CUDA.ConnectedComponentsAlgorithmsTypes.html#cv_CCL_BKE/0"},{"type":"function","title":"Evision.CUDA.ConnectedComponentsAlgorithmsTypes.cv_CCL_DEFAULT/0","doc":"","ref":"Evision.CUDA.ConnectedComponentsAlgorithmsTypes.html#cv_CCL_DEFAULT/0"},{"type":"type","title":"Evision.CUDA.ConnectedComponentsAlgorithmsTypes.enum/0","doc":"","ref":"Evision.CUDA.ConnectedComponentsAlgorithmsTypes.html#t:enum/0"},{"type":"module","title":"Evision.CUDA.Convolution","doc":"","ref":"Evision.CUDA.Convolution.html"},{"type":"function","title":"Evision.CUDA.Convolution.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Convolution.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.CUDA.Convolution.html#clear/1"},{"type":"function","title":"Evision.CUDA.Convolution.convolve/1","doc":"","ref":"Evision.CUDA.Convolution.html#convolve/1"},{"type":"function","title":"Evision.CUDA.Convolution.convolve/3","doc":"#### Variant 1:\nComputes a convolution (or cross-correlation) of two images.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Convolution.t()`\n- **image**: `Evision.Mat`.\n\n  Source image. Only CV_32FC1 images are supported for now.\n\n- **templ**: `Evision.Mat`.\n\n  Template image. The size is not greater than the image size. The type is the same as\n  image .\n\n##### Keyword Arguments\n- **ccorr**: `bool`.\n\n  Flags to evaluate cross-correlation instead of convolution.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **result**: `Evision.Mat.t()`.\n\n  Result image. If image is *W x H* and templ is *w x h*, then result must be *W-w+1 x\n  H-h+1*.\n\nPython prototype (for reference only):\n```python3\nconvolve(image, templ[, result[, ccorr[, stream]]]) -> result\n```\n#### Variant 2:\nComputes a convolution (or cross-correlation) of two images.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Convolution.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. Only CV_32FC1 images are supported for now.\n\n- **templ**: `Evision.CUDA.GpuMat.t()`.\n\n  Template image. The size is not greater than the image size. The type is the same as\n  image .\n\n##### Keyword Arguments\n- **ccorr**: `bool`.\n\n  Flags to evaluate cross-correlation instead of convolution.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **result**: `Evision.CUDA.GpuMat.t()`.\n\n  Result image. If image is *W x H* and templ is *w x h*, then result must be *W-w+1 x\n  H-h+1*.\n\nPython prototype (for reference only):\n```python3\nconvolve(image, templ[, result[, ccorr[, stream]]]) -> result\n```","ref":"Evision.CUDA.Convolution.html#convolve/3"},{"type":"function","title":"Evision.CUDA.Convolution.convolve/4","doc":"#### Variant 1:\nComputes a convolution (or cross-correlation) of two images.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Convolution.t()`\n- **image**: `Evision.Mat`.\n\n  Source image. Only CV_32FC1 images are supported for now.\n\n- **templ**: `Evision.Mat`.\n\n  Template image. The size is not greater than the image size. The type is the same as\n  image .\n\n##### Keyword Arguments\n- **ccorr**: `bool`.\n\n  Flags to evaluate cross-correlation instead of convolution.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **result**: `Evision.Mat.t()`.\n\n  Result image. If image is *W x H* and templ is *w x h*, then result must be *W-w+1 x\n  H-h+1*.\n\nPython prototype (for reference only):\n```python3\nconvolve(image, templ[, result[, ccorr[, stream]]]) -> result\n```\n#### Variant 2:\nComputes a convolution (or cross-correlation) of two images.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Convolution.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. Only CV_32FC1 images are supported for now.\n\n- **templ**: `Evision.CUDA.GpuMat.t()`.\n\n  Template image. The size is not greater than the image size. The type is the same as\n  image .\n\n##### Keyword Arguments\n- **ccorr**: `bool`.\n\n  Flags to evaluate cross-correlation instead of convolution.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **result**: `Evision.CUDA.GpuMat.t()`.\n\n  Result image. If image is *W x H* and templ is *w x h*, then result must be *W-w+1 x\n  H-h+1*.\n\nPython prototype (for reference only):\n```python3\nconvolve(image, templ[, result[, ccorr[, stream]]]) -> result\n```","ref":"Evision.CUDA.Convolution.html#convolve/4"},{"type":"function","title":"Evision.CUDA.Convolution.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Convolution.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CUDA.Convolution.html#empty/1"},{"type":"function","title":"Evision.CUDA.Convolution.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Convolution.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CUDA.Convolution.html#getDefaultName/1"},{"type":"function","title":"Evision.CUDA.Convolution.read/1","doc":"","ref":"Evision.CUDA.Convolution.html#read/1"},{"type":"function","title":"Evision.CUDA.Convolution.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Convolution.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.CUDA.Convolution.html#read/2"},{"type":"function","title":"Evision.CUDA.Convolution.save/1","doc":"","ref":"Evision.CUDA.Convolution.html#save/1"},{"type":"function","title":"Evision.CUDA.Convolution.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Convolution.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.CUDA.Convolution.html#save/2"},{"type":"function","title":"Evision.CUDA.Convolution.write/1","doc":"","ref":"Evision.CUDA.Convolution.html#write/1"},{"type":"function","title":"Evision.CUDA.Convolution.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Convolution.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.CUDA.Convolution.html#write/2"},{"type":"function","title":"Evision.CUDA.Convolution.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Convolution.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CUDA.Convolution.html#write/3"},{"type":"type","title":"Evision.CUDA.Convolution.t/0","doc":"Type that represents an `CUDA.Convolution` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.Convolution.html#t:t/0"},{"type":"module","title":"Evision.CUDA.CornernessCriteria","doc":"","ref":"Evision.CUDA.CornernessCriteria.html"},{"type":"function","title":"Evision.CUDA.CornernessCriteria.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornernessCriteria.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.CUDA.CornernessCriteria.html#clear/1"},{"type":"function","title":"Evision.CUDA.CornernessCriteria.compute/1","doc":"","ref":"Evision.CUDA.CornernessCriteria.html#compute/1"},{"type":"function","title":"Evision.CUDA.CornernessCriteria.compute/2","doc":"#### Variant 1:\nComputes the cornerness criteria at each image pixel.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornernessCriteria.t()`\n- **src**: `Evision.Mat`.\n\n  Source image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image containing cornerness values. It will have the same size as src and\n  CV_32FC1 type.\n\nPython prototype (for reference only):\n```python3\ncompute(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nComputes the cornerness criteria at each image pixel.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornernessCriteria.t()`\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image containing cornerness values. It will have the same size as src and\n  CV_32FC1 type.\n\nPython prototype (for reference only):\n```python3\ncompute(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.CornernessCriteria.html#compute/2"},{"type":"function","title":"Evision.CUDA.CornernessCriteria.compute/3","doc":"#### Variant 1:\nComputes the cornerness criteria at each image pixel.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornernessCriteria.t()`\n- **src**: `Evision.Mat`.\n\n  Source image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image containing cornerness values. It will have the same size as src and\n  CV_32FC1 type.\n\nPython prototype (for reference only):\n```python3\ncompute(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nComputes the cornerness criteria at each image pixel.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornernessCriteria.t()`\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination image containing cornerness values. It will have the same size as src and\n  CV_32FC1 type.\n\nPython prototype (for reference only):\n```python3\ncompute(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.CornernessCriteria.html#compute/3"},{"type":"function","title":"Evision.CUDA.CornernessCriteria.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornernessCriteria.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CUDA.CornernessCriteria.html#empty/1"},{"type":"function","title":"Evision.CUDA.CornernessCriteria.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornernessCriteria.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CUDA.CornernessCriteria.html#getDefaultName/1"},{"type":"function","title":"Evision.CUDA.CornernessCriteria.read/1","doc":"","ref":"Evision.CUDA.CornernessCriteria.html#read/1"},{"type":"function","title":"Evision.CUDA.CornernessCriteria.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornernessCriteria.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.CUDA.CornernessCriteria.html#read/2"},{"type":"function","title":"Evision.CUDA.CornernessCriteria.save/1","doc":"","ref":"Evision.CUDA.CornernessCriteria.html#save/1"},{"type":"function","title":"Evision.CUDA.CornernessCriteria.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornernessCriteria.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.CUDA.CornernessCriteria.html#save/2"},{"type":"function","title":"Evision.CUDA.CornernessCriteria.write/1","doc":"","ref":"Evision.CUDA.CornernessCriteria.html#write/1"},{"type":"function","title":"Evision.CUDA.CornernessCriteria.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornernessCriteria.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.CUDA.CornernessCriteria.html#write/2"},{"type":"function","title":"Evision.CUDA.CornernessCriteria.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornernessCriteria.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CUDA.CornernessCriteria.html#write/3"},{"type":"type","title":"Evision.CUDA.CornernessCriteria.t/0","doc":"Type that represents an `CUDA.CornernessCriteria` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.CornernessCriteria.html#t:t/0"},{"type":"module","title":"Evision.CUDA.CornersDetector","doc":"","ref":"Evision.CUDA.CornersDetector.html"},{"type":"function","title":"Evision.CUDA.CornersDetector.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornersDetector.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.CUDA.CornersDetector.html#clear/1"},{"type":"function","title":"Evision.CUDA.CornersDetector.detect/1","doc":"","ref":"Evision.CUDA.CornersDetector.html#detect/1"},{"type":"function","title":"Evision.CUDA.CornersDetector.detect/2","doc":"#### Variant 1:\nDetermines strong corners on an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornersDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Input 8-bit or floating-point 32-bit, single-channel image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional region of interest. If the image is not empty (it needs to have the type\n  CV_8UC1 and the same size as image ), it specifies the region in which the corners are detected.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **corners**: `Evision.Mat.t()`.\n\n  Output vector of detected corners (1-row matrix with CV_32FC2 type with corners\n  positions).\n\nPython prototype (for reference only):\n```python3\ndetect(image[, corners[, mask[, stream]]]) -> corners\n```\n#### Variant 2:\nDetermines strong corners on an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornersDetector.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Input 8-bit or floating-point 32-bit, single-channel image.\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Optional region of interest. If the image is not empty (it needs to have the type\n  CV_8UC1 and the same size as image ), it specifies the region in which the corners are detected.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **corners**: `Evision.CUDA.GpuMat.t()`.\n\n  Output vector of detected corners (1-row matrix with CV_32FC2 type with corners\n  positions).\n\nPython prototype (for reference only):\n```python3\ndetect(image[, corners[, mask[, stream]]]) -> corners\n```","ref":"Evision.CUDA.CornersDetector.html#detect/2"},{"type":"function","title":"Evision.CUDA.CornersDetector.detect/3","doc":"#### Variant 1:\nDetermines strong corners on an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornersDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Input 8-bit or floating-point 32-bit, single-channel image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Optional region of interest. If the image is not empty (it needs to have the type\n  CV_8UC1 and the same size as image ), it specifies the region in which the corners are detected.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **corners**: `Evision.Mat.t()`.\n\n  Output vector of detected corners (1-row matrix with CV_32FC2 type with corners\n  positions).\n\nPython prototype (for reference only):\n```python3\ndetect(image[, corners[, mask[, stream]]]) -> corners\n```\n#### Variant 2:\nDetermines strong corners on an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornersDetector.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Input 8-bit or floating-point 32-bit, single-channel image.\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Optional region of interest. If the image is not empty (it needs to have the type\n  CV_8UC1 and the same size as image ), it specifies the region in which the corners are detected.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **corners**: `Evision.CUDA.GpuMat.t()`.\n\n  Output vector of detected corners (1-row matrix with CV_32FC2 type with corners\n  positions).\n\nPython prototype (for reference only):\n```python3\ndetect(image[, corners[, mask[, stream]]]) -> corners\n```","ref":"Evision.CUDA.CornersDetector.html#detect/3"},{"type":"function","title":"Evision.CUDA.CornersDetector.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornersDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CUDA.CornersDetector.html#empty/1"},{"type":"function","title":"Evision.CUDA.CornersDetector.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornersDetector.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CUDA.CornersDetector.html#getDefaultName/1"},{"type":"function","title":"Evision.CUDA.CornersDetector.read/1","doc":"","ref":"Evision.CUDA.CornersDetector.html#read/1"},{"type":"function","title":"Evision.CUDA.CornersDetector.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornersDetector.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.CUDA.CornersDetector.html#read/2"},{"type":"function","title":"Evision.CUDA.CornersDetector.save/1","doc":"","ref":"Evision.CUDA.CornersDetector.html#save/1"},{"type":"function","title":"Evision.CUDA.CornersDetector.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornersDetector.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.CUDA.CornersDetector.html#save/2"},{"type":"function","title":"Evision.CUDA.CornersDetector.setMaxCorners/1","doc":"","ref":"Evision.CUDA.CornersDetector.html#setMaxCorners/1"},{"type":"function","title":"Evision.CUDA.CornersDetector.setMaxCorners/2","doc":"setMaxCorners\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornersDetector.t()`\n- **maxCorners**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxCorners(maxCorners) -> None\n```","ref":"Evision.CUDA.CornersDetector.html#setMaxCorners/2"},{"type":"function","title":"Evision.CUDA.CornersDetector.setMinDistance/1","doc":"","ref":"Evision.CUDA.CornersDetector.html#setMinDistance/1"},{"type":"function","title":"Evision.CUDA.CornersDetector.setMinDistance/2","doc":"setMinDistance\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornersDetector.t()`\n- **minDistance**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMinDistance(minDistance) -> None\n```","ref":"Evision.CUDA.CornersDetector.html#setMinDistance/2"},{"type":"function","title":"Evision.CUDA.CornersDetector.write/1","doc":"","ref":"Evision.CUDA.CornersDetector.html#write/1"},{"type":"function","title":"Evision.CUDA.CornersDetector.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornersDetector.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.CUDA.CornersDetector.html#write/2"},{"type":"function","title":"Evision.CUDA.CornersDetector.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.CornersDetector.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CUDA.CornersDetector.html#write/3"},{"type":"type","title":"Evision.CUDA.CornersDetector.t/0","doc":"Type that represents an `CUDA.CornersDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.CornersDetector.html#t:t/0"},{"type":"module","title":"Evision.CUDA.DFT","doc":"","ref":"Evision.CUDA.DFT.html"},{"type":"function","title":"Evision.CUDA.DFT.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DFT.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.CUDA.DFT.html#clear/1"},{"type":"function","title":"Evision.CUDA.DFT.compute/1","doc":"","ref":"Evision.CUDA.DFT.html#compute/1"},{"type":"function","title":"Evision.CUDA.DFT.compute/2","doc":"#### Variant 1:\nComputes an FFT of a given image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DFT.t()`\n- **image**: `Evision.Mat`.\n\n  Source image. Only CV_32FC1 images are supported for now.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **result**: `Evision.Mat.t()`.\n\n  Result image.\n\nPython prototype (for reference only):\n```python3\ncompute(image[, result[, stream]]) -> result\n```\n#### Variant 2:\nComputes an FFT of a given image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DFT.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. Only CV_32FC1 images are supported for now.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **result**: `Evision.CUDA.GpuMat.t()`.\n\n  Result image.\n\nPython prototype (for reference only):\n```python3\ncompute(image[, result[, stream]]) -> result\n```","ref":"Evision.CUDA.DFT.html#compute/2"},{"type":"function","title":"Evision.CUDA.DFT.compute/3","doc":"#### Variant 1:\nComputes an FFT of a given image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DFT.t()`\n- **image**: `Evision.Mat`.\n\n  Source image. Only CV_32FC1 images are supported for now.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **result**: `Evision.Mat.t()`.\n\n  Result image.\n\nPython prototype (for reference only):\n```python3\ncompute(image[, result[, stream]]) -> result\n```\n#### Variant 2:\nComputes an FFT of a given image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DFT.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. Only CV_32FC1 images are supported for now.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **result**: `Evision.CUDA.GpuMat.t()`.\n\n  Result image.\n\nPython prototype (for reference only):\n```python3\ncompute(image[, result[, stream]]) -> result\n```","ref":"Evision.CUDA.DFT.html#compute/3"},{"type":"function","title":"Evision.CUDA.DFT.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DFT.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CUDA.DFT.html#empty/1"},{"type":"function","title":"Evision.CUDA.DFT.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DFT.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CUDA.DFT.html#getDefaultName/1"},{"type":"function","title":"Evision.CUDA.DFT.read/1","doc":"","ref":"Evision.CUDA.DFT.html#read/1"},{"type":"function","title":"Evision.CUDA.DFT.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DFT.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.CUDA.DFT.html#read/2"},{"type":"function","title":"Evision.CUDA.DFT.save/1","doc":"","ref":"Evision.CUDA.DFT.html#save/1"},{"type":"function","title":"Evision.CUDA.DFT.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DFT.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.CUDA.DFT.html#save/2"},{"type":"function","title":"Evision.CUDA.DFT.write/1","doc":"","ref":"Evision.CUDA.DFT.html#write/1"},{"type":"function","title":"Evision.CUDA.DFT.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DFT.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.CUDA.DFT.html#write/2"},{"type":"function","title":"Evision.CUDA.DFT.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DFT.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CUDA.DFT.html#write/3"},{"type":"type","title":"Evision.CUDA.DFT.t/0","doc":"Type that represents an `CUDA.DFT` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.DFT.html#t:t/0"},{"type":"module","title":"Evision.CUDA.DemosaicTypes","doc":"","ref":"Evision.CUDA.DemosaicTypes.html"},{"type":"function","title":"Evision.CUDA.DemosaicTypes.cv_COLOR_BayerBG2BGR_MHT/0","doc":"","ref":"Evision.CUDA.DemosaicTypes.html#cv_COLOR_BayerBG2BGR_MHT/0"},{"type":"function","title":"Evision.CUDA.DemosaicTypes.cv_COLOR_BayerBG2GRAY_MHT/0","doc":"","ref":"Evision.CUDA.DemosaicTypes.html#cv_COLOR_BayerBG2GRAY_MHT/0"},{"type":"function","title":"Evision.CUDA.DemosaicTypes.cv_COLOR_BayerBG2RGB_MHT/0","doc":"","ref":"Evision.CUDA.DemosaicTypes.html#cv_COLOR_BayerBG2RGB_MHT/0"},{"type":"function","title":"Evision.CUDA.DemosaicTypes.cv_COLOR_BayerGB2BGR_MHT/0","doc":"","ref":"Evision.CUDA.DemosaicTypes.html#cv_COLOR_BayerGB2BGR_MHT/0"},{"type":"function","title":"Evision.CUDA.DemosaicTypes.cv_COLOR_BayerGB2GRAY_MHT/0","doc":"","ref":"Evision.CUDA.DemosaicTypes.html#cv_COLOR_BayerGB2GRAY_MHT/0"},{"type":"function","title":"Evision.CUDA.DemosaicTypes.cv_COLOR_BayerGB2RGB_MHT/0","doc":"","ref":"Evision.CUDA.DemosaicTypes.html#cv_COLOR_BayerGB2RGB_MHT/0"},{"type":"function","title":"Evision.CUDA.DemosaicTypes.cv_COLOR_BayerGR2BGR_MHT/0","doc":"","ref":"Evision.CUDA.DemosaicTypes.html#cv_COLOR_BayerGR2BGR_MHT/0"},{"type":"function","title":"Evision.CUDA.DemosaicTypes.cv_COLOR_BayerGR2GRAY_MHT/0","doc":"","ref":"Evision.CUDA.DemosaicTypes.html#cv_COLOR_BayerGR2GRAY_MHT/0"},{"type":"function","title":"Evision.CUDA.DemosaicTypes.cv_COLOR_BayerGR2RGB_MHT/0","doc":"","ref":"Evision.CUDA.DemosaicTypes.html#cv_COLOR_BayerGR2RGB_MHT/0"},{"type":"function","title":"Evision.CUDA.DemosaicTypes.cv_COLOR_BayerRG2BGR_MHT/0","doc":"","ref":"Evision.CUDA.DemosaicTypes.html#cv_COLOR_BayerRG2BGR_MHT/0"},{"type":"function","title":"Evision.CUDA.DemosaicTypes.cv_COLOR_BayerRG2GRAY_MHT/0","doc":"","ref":"Evision.CUDA.DemosaicTypes.html#cv_COLOR_BayerRG2GRAY_MHT/0"},{"type":"function","title":"Evision.CUDA.DemosaicTypes.cv_COLOR_BayerRG2RGB_MHT/0","doc":"","ref":"Evision.CUDA.DemosaicTypes.html#cv_COLOR_BayerRG2RGB_MHT/0"},{"type":"type","title":"Evision.CUDA.DemosaicTypes.enum/0","doc":"","ref":"Evision.CUDA.DemosaicTypes.html#t:enum/0"},{"type":"module","title":"Evision.CUDA.DescriptorMatcher","doc":"","ref":"Evision.CUDA.DescriptorMatcher.html"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.add/1","doc":"","ref":"Evision.CUDA.DescriptorMatcher.html#add/1"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.add/2","doc":"Adds descriptors to train a descriptor collection.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **descriptors**: `[Evision.CUDA.GpuMat]`.\n\n  Descriptors to add. Each descriptors[i] is a set of descriptors from the same\n  train image.\n\nIf the collection is not empty, the new descriptors are added to existing train descriptors.\n\nPython prototype (for reference only):\n```python3\nadd(descriptors) -> None\n```","ref":"Evision.CUDA.DescriptorMatcher.html#add/2"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.clear/1","doc":"Clears the train descriptor collection.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.CUDA.DescriptorMatcher.html#clear/1"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.createBFMatcher/0","doc":"Brute-force descriptor matcher.\n##### Keyword Arguments\n- **normType**: `integer()`.\n\n  One of NORM_L1, NORM_L2, NORM_HAMMING. L1 and L2 norms are\n  preferable choices for SIFT and SURF descriptors, NORM_HAMMING should be used with ORB, BRISK and\n  BRIEF).\n\n##### Return\n- **retval**: `Evision.CUDA.DescriptorMatcher.t()`\n\nFor each descriptor in the first set, this matcher finds the closest descriptor in the second set\nby trying each one. This descriptor matcher supports masking permissible matches of descriptor\nsets.\n\nPython prototype (for reference only):\n```python3\ncreateBFMatcher([, normType]) -> retval\n```","ref":"Evision.CUDA.DescriptorMatcher.html#createBFMatcher/0"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.createBFMatcher/1","doc":"Brute-force descriptor matcher.\n##### Keyword Arguments\n- **normType**: `integer()`.\n\n  One of NORM_L1, NORM_L2, NORM_HAMMING. L1 and L2 norms are\n  preferable choices for SIFT and SURF descriptors, NORM_HAMMING should be used with ORB, BRISK and\n  BRIEF).\n\n##### Return\n- **retval**: `Evision.CUDA.DescriptorMatcher.t()`\n\nFor each descriptor in the first set, this matcher finds the closest descriptor in the second set\nby trying each one. This descriptor matcher supports masking permissible matches of descriptor\nsets.\n\nPython prototype (for reference only):\n```python3\ncreateBFMatcher([, normType]) -> retval\n```","ref":"Evision.CUDA.DescriptorMatcher.html#createBFMatcher/1"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.empty/1","doc":"Returns true if there are no train descriptors in the collection.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CUDA.DescriptorMatcher.html#empty/1"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CUDA.DescriptorMatcher.html#getDefaultName/1"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.getTrainDescriptors/1","doc":"Returns a constant link to the train descriptor collection.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n\n##### Return\n- **retval**: `[Evision.CUDA.GpuMat]`\n\nPython prototype (for reference only):\n```python3\ngetTrainDescriptors() -> retval\n```","ref":"Evision.CUDA.DescriptorMatcher.html#getTrainDescriptors/1"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.isMaskSupported/1","doc":"Returns true if the descriptor matcher supports masking permissible matches.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisMaskSupported() -> retval\n```","ref":"Evision.CUDA.DescriptorMatcher.html#isMaskSupported/1"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.knnMatch/1","doc":"","ref":"Evision.CUDA.DescriptorMatcher.html#knnMatch/1"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.knnMatch/3","doc":"#### Variant 1:\nknnMatch\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`\n- **k**: `integer()`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n- **compactResult**: `bool`.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nknnMatch(queryDescriptors, k[, masks[, compactResult]]) -> matches\n```\n#### Variant 2:\nknnMatch\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`\n- **k**: `integer()`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n- **compactResult**: `bool`.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nknnMatch(queryDescriptors, k[, masks[, compactResult]]) -> matches\n```","ref":"Evision.CUDA.DescriptorMatcher.html#knnMatch/3"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.knnMatch/4","doc":"#### Variant 1:\nFinds the k best matches for each descriptor from a query set (blocking version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **k**: `integer()`.\n\n  Count of best matches found per each query descriptor or less if a query descriptor has\n  less than k possible matches in total.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Matches. Each matches[i] is k or less matches for the same query descriptor.\n\nThese extended variants of DescriptorMatcher::match methods find several best matches for each query\ndescriptor. The matches are returned in the distance increasing order. See DescriptorMatcher::match\nfor the details about query and train descriptors.\n\nPython prototype (for reference only):\n```python3\nknnMatch(queryDescriptors, trainDescriptors, k[, mask[, compactResult]]) -> matches\n```\n#### Variant 2:\nFinds the k best matches for each descriptor from a query set (blocking version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **k**: `integer()`.\n\n  Count of best matches found per each query descriptor or less if a query descriptor has\n  less than k possible matches in total.\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Matches. Each matches[i] is k or less matches for the same query descriptor.\n\nThese extended variants of DescriptorMatcher::match methods find several best matches for each query\ndescriptor. The matches are returned in the distance increasing order. See DescriptorMatcher::match\nfor the details about query and train descriptors.\n\nPython prototype (for reference only):\n```python3\nknnMatch(queryDescriptors, trainDescriptors, k[, mask[, compactResult]]) -> matches\n```\n#### Variant 3:\nknnMatch\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`\n- **k**: `integer()`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n- **compactResult**: `bool`.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nknnMatch(queryDescriptors, k[, masks[, compactResult]]) -> matches\n```\n#### Variant 4:\nknnMatch\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`\n- **k**: `integer()`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n- **compactResult**: `bool`.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nknnMatch(queryDescriptors, k[, masks[, compactResult]]) -> matches\n```","ref":"Evision.CUDA.DescriptorMatcher.html#knnMatch/4"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.knnMatch/5","doc":"#### Variant 1:\nFinds the k best matches for each descriptor from a query set (blocking version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **k**: `integer()`.\n\n  Count of best matches found per each query descriptor or less if a query descriptor has\n  less than k possible matches in total.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Matches. Each matches[i] is k or less matches for the same query descriptor.\n\nThese extended variants of DescriptorMatcher::match methods find several best matches for each query\ndescriptor. The matches are returned in the distance increasing order. See DescriptorMatcher::match\nfor the details about query and train descriptors.\n\nPython prototype (for reference only):\n```python3\nknnMatch(queryDescriptors, trainDescriptors, k[, mask[, compactResult]]) -> matches\n```\n#### Variant 2:\nFinds the k best matches for each descriptor from a query set (blocking version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **k**: `integer()`.\n\n  Count of best matches found per each query descriptor or less if a query descriptor has\n  less than k possible matches in total.\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Matches. Each matches[i] is k or less matches for the same query descriptor.\n\nThese extended variants of DescriptorMatcher::match methods find several best matches for each query\ndescriptor. The matches are returned in the distance increasing order. See DescriptorMatcher::match\nfor the details about query and train descriptors.\n\nPython prototype (for reference only):\n```python3\nknnMatch(queryDescriptors, trainDescriptors, k[, mask[, compactResult]]) -> matches\n```","ref":"Evision.CUDA.DescriptorMatcher.html#knnMatch/5"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.knnMatchAsync/1","doc":"","ref":"Evision.CUDA.DescriptorMatcher.html#knnMatchAsync/1"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.knnMatchAsync/3","doc":"#### Variant 1:\nknnMatchAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`\n- **k**: `integer()`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **matches**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nknnMatchAsync(queryDescriptors, k[, matches[, masks[, stream]]]) -> matches\n```\n#### Variant 2:\nknnMatchAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`\n- **k**: `integer()`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **matches**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nknnMatchAsync(queryDescriptors, k[, matches[, masks[, stream]]]) -> matches\n```","ref":"Evision.CUDA.DescriptorMatcher.html#knnMatchAsync/3"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.knnMatchAsync/4","doc":"#### Variant 1:\nFinds the k best matches for each descriptor from a query set (asynchronous version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **k**: `integer()`.\n\n  Count of best matches found per each query descriptor or less if a query descriptor has\n  less than k possible matches in total.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **matches**: `Evision.Mat.t()`.\n\n  Matches array stored in GPU memory. Internal representation is not defined.\n  Use DescriptorMatcher::knnMatchConvert method to retrieve results in standard representation.\n\nThese extended variants of DescriptorMatcher::matchAsync methods find several best matches for each query\ndescriptor. The matches are returned in the distance increasing order. See DescriptorMatcher::matchAsync\nfor the details about query and train descriptors.\n\nPython prototype (for reference only):\n```python3\nknnMatchAsync(queryDescriptors, trainDescriptors, k[, matches[, mask[, stream]]]) -> matches\n```\n#### Variant 2:\nFinds the k best matches for each descriptor from a query set (asynchronous version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **k**: `integer()`.\n\n  Count of best matches found per each query descriptor or less if a query descriptor has\n  less than k possible matches in total.\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **matches**: `Evision.CUDA.GpuMat.t()`.\n\n  Matches array stored in GPU memory. Internal representation is not defined.\n  Use DescriptorMatcher::knnMatchConvert method to retrieve results in standard representation.\n\nThese extended variants of DescriptorMatcher::matchAsync methods find several best matches for each query\ndescriptor. The matches are returned in the distance increasing order. See DescriptorMatcher::matchAsync\nfor the details about query and train descriptors.\n\nPython prototype (for reference only):\n```python3\nknnMatchAsync(queryDescriptors, trainDescriptors, k[, matches[, mask[, stream]]]) -> matches\n```\n#### Variant 3:\nknnMatchAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`\n- **k**: `integer()`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **matches**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nknnMatchAsync(queryDescriptors, k[, matches[, masks[, stream]]]) -> matches\n```\n#### Variant 4:\nknnMatchAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`\n- **k**: `integer()`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **matches**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nknnMatchAsync(queryDescriptors, k[, matches[, masks[, stream]]]) -> matches\n```","ref":"Evision.CUDA.DescriptorMatcher.html#knnMatchAsync/4"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.knnMatchAsync/5","doc":"#### Variant 1:\nFinds the k best matches for each descriptor from a query set (asynchronous version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **k**: `integer()`.\n\n  Count of best matches found per each query descriptor or less if a query descriptor has\n  less than k possible matches in total.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **matches**: `Evision.Mat.t()`.\n\n  Matches array stored in GPU memory. Internal representation is not defined.\n  Use DescriptorMatcher::knnMatchConvert method to retrieve results in standard representation.\n\nThese extended variants of DescriptorMatcher::matchAsync methods find several best matches for each query\ndescriptor. The matches are returned in the distance increasing order. See DescriptorMatcher::matchAsync\nfor the details about query and train descriptors.\n\nPython prototype (for reference only):\n```python3\nknnMatchAsync(queryDescriptors, trainDescriptors, k[, matches[, mask[, stream]]]) -> matches\n```\n#### Variant 2:\nFinds the k best matches for each descriptor from a query set (asynchronous version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **k**: `integer()`.\n\n  Count of best matches found per each query descriptor or less if a query descriptor has\n  less than k possible matches in total.\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **matches**: `Evision.CUDA.GpuMat.t()`.\n\n  Matches array stored in GPU memory. Internal representation is not defined.\n  Use DescriptorMatcher::knnMatchConvert method to retrieve results in standard representation.\n\nThese extended variants of DescriptorMatcher::matchAsync methods find several best matches for each query\ndescriptor. The matches are returned in the distance increasing order. See DescriptorMatcher::matchAsync\nfor the details about query and train descriptors.\n\nPython prototype (for reference only):\n```python3\nknnMatchAsync(queryDescriptors, trainDescriptors, k[, matches[, mask[, stream]]]) -> matches\n```","ref":"Evision.CUDA.DescriptorMatcher.html#knnMatchAsync/5"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.knnMatchConvert/1","doc":"","ref":"Evision.CUDA.DescriptorMatcher.html#knnMatchConvert/1"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.knnMatchConvert/2","doc":"#### Variant 1:\nConverts matches array from internal representation to standard matches vector.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **gpu_matches**: `Evision.Mat`.\n\n  Matches, returned from DescriptorMatcher::knnMatchAsync.\n\n##### Keyword Arguments\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Vector of DMatch objects.\n\nThe method is supposed to be used with DescriptorMatcher::knnMatchAsync to get final result.\nCall this method only after DescriptorMatcher::knnMatchAsync is completed (ie. after synchronization).\n\nPython prototype (for reference only):\n```python3\nknnMatchConvert(gpu_matches[, compactResult]) -> matches\n```\n#### Variant 2:\nConverts matches array from internal representation to standard matches vector.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **gpu_matches**: `Evision.CUDA.GpuMat.t()`.\n\n  Matches, returned from DescriptorMatcher::knnMatchAsync.\n\n##### Keyword Arguments\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Vector of DMatch objects.\n\nThe method is supposed to be used with DescriptorMatcher::knnMatchAsync to get final result.\nCall this method only after DescriptorMatcher::knnMatchAsync is completed (ie. after synchronization).\n\nPython prototype (for reference only):\n```python3\nknnMatchConvert(gpu_matches[, compactResult]) -> matches\n```","ref":"Evision.CUDA.DescriptorMatcher.html#knnMatchConvert/2"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.knnMatchConvert/3","doc":"#### Variant 1:\nConverts matches array from internal representation to standard matches vector.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **gpu_matches**: `Evision.Mat`.\n\n  Matches, returned from DescriptorMatcher::knnMatchAsync.\n\n##### Keyword Arguments\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Vector of DMatch objects.\n\nThe method is supposed to be used with DescriptorMatcher::knnMatchAsync to get final result.\nCall this method only after DescriptorMatcher::knnMatchAsync is completed (ie. after synchronization).\n\nPython prototype (for reference only):\n```python3\nknnMatchConvert(gpu_matches[, compactResult]) -> matches\n```\n#### Variant 2:\nConverts matches array from internal representation to standard matches vector.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **gpu_matches**: `Evision.CUDA.GpuMat.t()`.\n\n  Matches, returned from DescriptorMatcher::knnMatchAsync.\n\n##### Keyword Arguments\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Vector of DMatch objects.\n\nThe method is supposed to be used with DescriptorMatcher::knnMatchAsync to get final result.\nCall this method only after DescriptorMatcher::knnMatchAsync is completed (ie. after synchronization).\n\nPython prototype (for reference only):\n```python3\nknnMatchConvert(gpu_matches[, compactResult]) -> matches\n```","ref":"Evision.CUDA.DescriptorMatcher.html#knnMatchConvert/3"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.match/1","doc":"","ref":"Evision.CUDA.DescriptorMatcher.html#match/1"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.match/2","doc":"#### Variant 1:\nmatch\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n\n##### Return\n- **matches**: `[Evision.DMatch]`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmatch(queryDescriptors[, masks]) -> matches\n```\n#### Variant 2:\nmatch\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n\n##### Return\n- **matches**: `[Evision.DMatch]`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmatch(queryDescriptors[, masks]) -> matches\n```","ref":"Evision.CUDA.DescriptorMatcher.html#match/2"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.match/3","doc":"#### Variant 1:\nFinds the best match for each descriptor from a query set (blocking version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n##### Return\n- **matches**: `[Evision.DMatch]`.\n\n  Matches. If a query descriptor is masked out in mask , no match is added for this\n  descriptor. So, matches size may be smaller than the query descriptors count.\n\nIn the first variant of this method, the train descriptors are passed as an input argument. In the\nsecond variant of the method, train descriptors collection that was set by DescriptorMatcher::add is\nused. Optional mask (or masks) can be passed to specify which query and training descriptors can be\nmatched. Namely, queryDescriptors[i] can be matched with trainDescriptors[j] only if\nmask.at\\ (i,j) is non-zero.\n\nPython prototype (for reference only):\n```python3\nmatch(queryDescriptors, trainDescriptors[, mask]) -> matches\n```\n#### Variant 2:\nFinds the best match for each descriptor from a query set (blocking version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n##### Return\n- **matches**: `[Evision.DMatch]`.\n\n  Matches. If a query descriptor is masked out in mask , no match is added for this\n  descriptor. So, matches size may be smaller than the query descriptors count.\n\nIn the first variant of this method, the train descriptors are passed as an input argument. In the\nsecond variant of the method, train descriptors collection that was set by DescriptorMatcher::add is\nused. Optional mask (or masks) can be passed to specify which query and training descriptors can be\nmatched. Namely, queryDescriptors[i] can be matched with trainDescriptors[j] only if\nmask.at\\ (i,j) is non-zero.\n\nPython prototype (for reference only):\n```python3\nmatch(queryDescriptors, trainDescriptors[, mask]) -> matches\n```\n#### Variant 3:\nmatch\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n\n##### Return\n- **matches**: `[Evision.DMatch]`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmatch(queryDescriptors[, masks]) -> matches\n```\n#### Variant 4:\nmatch\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n\n##### Return\n- **matches**: `[Evision.DMatch]`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmatch(queryDescriptors[, masks]) -> matches\n```","ref":"Evision.CUDA.DescriptorMatcher.html#match/3"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.match/4","doc":"#### Variant 1:\nFinds the best match for each descriptor from a query set (blocking version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n##### Return\n- **matches**: `[Evision.DMatch]`.\n\n  Matches. If a query descriptor is masked out in mask , no match is added for this\n  descriptor. So, matches size may be smaller than the query descriptors count.\n\nIn the first variant of this method, the train descriptors are passed as an input argument. In the\nsecond variant of the method, train descriptors collection that was set by DescriptorMatcher::add is\nused. Optional mask (or masks) can be passed to specify which query and training descriptors can be\nmatched. Namely, queryDescriptors[i] can be matched with trainDescriptors[j] only if\nmask.at\\ (i,j) is non-zero.\n\nPython prototype (for reference only):\n```python3\nmatch(queryDescriptors, trainDescriptors[, mask]) -> matches\n```\n#### Variant 2:\nFinds the best match for each descriptor from a query set (blocking version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n##### Return\n- **matches**: `[Evision.DMatch]`.\n\n  Matches. If a query descriptor is masked out in mask , no match is added for this\n  descriptor. So, matches size may be smaller than the query descriptors count.\n\nIn the first variant of this method, the train descriptors are passed as an input argument. In the\nsecond variant of the method, train descriptors collection that was set by DescriptorMatcher::add is\nused. Optional mask (or masks) can be passed to specify which query and training descriptors can be\nmatched. Namely, queryDescriptors[i] can be matched with trainDescriptors[j] only if\nmask.at\\ (i,j) is non-zero.\n\nPython prototype (for reference only):\n```python3\nmatch(queryDescriptors, trainDescriptors[, mask]) -> matches\n```","ref":"Evision.CUDA.DescriptorMatcher.html#match/4"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.matchAsync/1","doc":"","ref":"Evision.CUDA.DescriptorMatcher.html#matchAsync/1"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.matchAsync/2","doc":"#### Variant 1:\nmatchAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **matches**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmatchAsync(queryDescriptors[, matches[, masks[, stream]]]) -> matches\n```\n#### Variant 2:\nmatchAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **matches**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmatchAsync(queryDescriptors[, matches[, masks[, stream]]]) -> matches\n```","ref":"Evision.CUDA.DescriptorMatcher.html#matchAsync/2"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.matchAsync/3","doc":"#### Variant 1:\nFinds the best match for each descriptor from a query set (asynchronous version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **matches**: `Evision.Mat.t()`.\n\n  Matches array stored in GPU memory. Internal representation is not defined.\n  Use DescriptorMatcher::matchConvert method to retrieve results in standard representation.\n\nIn the first variant of this method, the train descriptors are passed as an input argument. In the\nsecond variant of the method, train descriptors collection that was set by DescriptorMatcher::add is\nused. Optional mask (or masks) can be passed to specify which query and training descriptors can be\nmatched. Namely, queryDescriptors[i] can be matched with trainDescriptors[j] only if\nmask.at\\ (i,j) is non-zero.\n\nPython prototype (for reference only):\n```python3\nmatchAsync(queryDescriptors, trainDescriptors[, matches[, mask[, stream]]]) -> matches\n```\n#### Variant 2:\nFinds the best match for each descriptor from a query set (asynchronous version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **matches**: `Evision.CUDA.GpuMat.t()`.\n\n  Matches array stored in GPU memory. Internal representation is not defined.\n  Use DescriptorMatcher::matchConvert method to retrieve results in standard representation.\n\nIn the first variant of this method, the train descriptors are passed as an input argument. In the\nsecond variant of the method, train descriptors collection that was set by DescriptorMatcher::add is\nused. Optional mask (or masks) can be passed to specify which query and training descriptors can be\nmatched. Namely, queryDescriptors[i] can be matched with trainDescriptors[j] only if\nmask.at\\ (i,j) is non-zero.\n\nPython prototype (for reference only):\n```python3\nmatchAsync(queryDescriptors, trainDescriptors[, matches[, mask[, stream]]]) -> matches\n```\n#### Variant 3:\nmatchAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **matches**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmatchAsync(queryDescriptors[, matches[, masks[, stream]]]) -> matches\n```\n#### Variant 4:\nmatchAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **matches**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmatchAsync(queryDescriptors[, matches[, masks[, stream]]]) -> matches\n```","ref":"Evision.CUDA.DescriptorMatcher.html#matchAsync/3"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.matchAsync/4","doc":"#### Variant 1:\nFinds the best match for each descriptor from a query set (asynchronous version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **matches**: `Evision.Mat.t()`.\n\n  Matches array stored in GPU memory. Internal representation is not defined.\n  Use DescriptorMatcher::matchConvert method to retrieve results in standard representation.\n\nIn the first variant of this method, the train descriptors are passed as an input argument. In the\nsecond variant of the method, train descriptors collection that was set by DescriptorMatcher::add is\nused. Optional mask (or masks) can be passed to specify which query and training descriptors can be\nmatched. Namely, queryDescriptors[i] can be matched with trainDescriptors[j] only if\nmask.at\\ (i,j) is non-zero.\n\nPython prototype (for reference only):\n```python3\nmatchAsync(queryDescriptors, trainDescriptors[, matches[, mask[, stream]]]) -> matches\n```\n#### Variant 2:\nFinds the best match for each descriptor from a query set (asynchronous version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **matches**: `Evision.CUDA.GpuMat.t()`.\n\n  Matches array stored in GPU memory. Internal representation is not defined.\n  Use DescriptorMatcher::matchConvert method to retrieve results in standard representation.\n\nIn the first variant of this method, the train descriptors are passed as an input argument. In the\nsecond variant of the method, train descriptors collection that was set by DescriptorMatcher::add is\nused. Optional mask (or masks) can be passed to specify which query and training descriptors can be\nmatched. Namely, queryDescriptors[i] can be matched with trainDescriptors[j] only if\nmask.at\\ (i,j) is non-zero.\n\nPython prototype (for reference only):\n```python3\nmatchAsync(queryDescriptors, trainDescriptors[, matches[, mask[, stream]]]) -> matches\n```","ref":"Evision.CUDA.DescriptorMatcher.html#matchAsync/4"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.matchConvert/1","doc":"","ref":"Evision.CUDA.DescriptorMatcher.html#matchConvert/1"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.matchConvert/2","doc":"#### Variant 1:\nConverts matches array from internal representation to standard matches vector.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **gpu_matches**: `Evision.Mat`.\n\n  Matches, returned from DescriptorMatcher::matchAsync.\n\n##### Return\n- **matches**: `[Evision.DMatch]`.\n\n  Vector of DMatch objects.\n\nThe method is supposed to be used with DescriptorMatcher::matchAsync to get final result.\nCall this method only after DescriptorMatcher::matchAsync is completed (ie. after synchronization).\n\nPython prototype (for reference only):\n```python3\nmatchConvert(gpu_matches) -> matches\n```\n#### Variant 2:\nConverts matches array from internal representation to standard matches vector.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **gpu_matches**: `Evision.CUDA.GpuMat.t()`.\n\n  Matches, returned from DescriptorMatcher::matchAsync.\n\n##### Return\n- **matches**: `[Evision.DMatch]`.\n\n  Vector of DMatch objects.\n\nThe method is supposed to be used with DescriptorMatcher::matchAsync to get final result.\nCall this method only after DescriptorMatcher::matchAsync is completed (ie. after synchronization).\n\nPython prototype (for reference only):\n```python3\nmatchConvert(gpu_matches) -> matches\n```","ref":"Evision.CUDA.DescriptorMatcher.html#matchConvert/2"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.radiusMatch/1","doc":"","ref":"Evision.CUDA.DescriptorMatcher.html#radiusMatch/1"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.radiusMatch/3","doc":"#### Variant 1:\nradiusMatch\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`\n- **maxDistance**: `float`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n- **compactResult**: `bool`.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nradiusMatch(queryDescriptors, maxDistance[, masks[, compactResult]]) -> matches\n```\n#### Variant 2:\nradiusMatch\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`\n- **maxDistance**: `float`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n- **compactResult**: `bool`.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nradiusMatch(queryDescriptors, maxDistance[, masks[, compactResult]]) -> matches\n```","ref":"Evision.CUDA.DescriptorMatcher.html#radiusMatch/3"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.radiusMatch/4","doc":"#### Variant 1:\nFor each query descriptor, finds the training descriptors not farther than the specified distance (blocking version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **maxDistance**: `float`.\n\n  Threshold for the distance between matched descriptors. Distance means here\n  metric distance (e.g. Hamming distance), not the distance between coordinates (which is measured\n  in Pixels)!\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Found matches.\n\nFor each query descriptor, the methods find such training descriptors that the distance between the\nquery descriptor and the training descriptor is equal or smaller than maxDistance. Found matches are\nreturned in the distance increasing order.\n\nPython prototype (for reference only):\n```python3\nradiusMatch(queryDescriptors, trainDescriptors, maxDistance[, mask[, compactResult]]) -> matches\n```\n#### Variant 2:\nFor each query descriptor, finds the training descriptors not farther than the specified distance (blocking version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **maxDistance**: `float`.\n\n  Threshold for the distance between matched descriptors. Distance means here\n  metric distance (e.g. Hamming distance), not the distance between coordinates (which is measured\n  in Pixels)!\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Found matches.\n\nFor each query descriptor, the methods find such training descriptors that the distance between the\nquery descriptor and the training descriptor is equal or smaller than maxDistance. Found matches are\nreturned in the distance increasing order.\n\nPython prototype (for reference only):\n```python3\nradiusMatch(queryDescriptors, trainDescriptors, maxDistance[, mask[, compactResult]]) -> matches\n```\n#### Variant 3:\nradiusMatch\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`\n- **maxDistance**: `float`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n- **compactResult**: `bool`.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nradiusMatch(queryDescriptors, maxDistance[, masks[, compactResult]]) -> matches\n```\n#### Variant 4:\nradiusMatch\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`\n- **maxDistance**: `float`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n- **compactResult**: `bool`.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nradiusMatch(queryDescriptors, maxDistance[, masks[, compactResult]]) -> matches\n```","ref":"Evision.CUDA.DescriptorMatcher.html#radiusMatch/4"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.radiusMatch/5","doc":"#### Variant 1:\nFor each query descriptor, finds the training descriptors not farther than the specified distance (blocking version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **maxDistance**: `float`.\n\n  Threshold for the distance between matched descriptors. Distance means here\n  metric distance (e.g. Hamming distance), not the distance between coordinates (which is measured\n  in Pixels)!\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Found matches.\n\nFor each query descriptor, the methods find such training descriptors that the distance between the\nquery descriptor and the training descriptor is equal or smaller than maxDistance. Found matches are\nreturned in the distance increasing order.\n\nPython prototype (for reference only):\n```python3\nradiusMatch(queryDescriptors, trainDescriptors, maxDistance[, mask[, compactResult]]) -> matches\n```\n#### Variant 2:\nFor each query descriptor, finds the training descriptors not farther than the specified distance (blocking version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **maxDistance**: `float`.\n\n  Threshold for the distance between matched descriptors. Distance means here\n  metric distance (e.g. Hamming distance), not the distance between coordinates (which is measured\n  in Pixels)!\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Found matches.\n\nFor each query descriptor, the methods find such training descriptors that the distance between the\nquery descriptor and the training descriptor is equal or smaller than maxDistance. Found matches are\nreturned in the distance increasing order.\n\nPython prototype (for reference only):\n```python3\nradiusMatch(queryDescriptors, trainDescriptors, maxDistance[, mask[, compactResult]]) -> matches\n```","ref":"Evision.CUDA.DescriptorMatcher.html#radiusMatch/5"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.radiusMatchAsync/1","doc":"","ref":"Evision.CUDA.DescriptorMatcher.html#radiusMatchAsync/1"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.radiusMatchAsync/3","doc":"#### Variant 1:\nradiusMatchAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`\n- **maxDistance**: `float`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **matches**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nradiusMatchAsync(queryDescriptors, maxDistance[, matches[, masks[, stream]]]) -> matches\n```\n#### Variant 2:\nradiusMatchAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`\n- **maxDistance**: `float`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **matches**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nradiusMatchAsync(queryDescriptors, maxDistance[, matches[, masks[, stream]]]) -> matches\n```","ref":"Evision.CUDA.DescriptorMatcher.html#radiusMatchAsync/3"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.radiusMatchAsync/4","doc":"#### Variant 1:\nFor each query descriptor, finds the training descriptors not farther than the specified distance (asynchronous version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **maxDistance**: `float`.\n\n  Threshold for the distance between matched descriptors. Distance means here\n  metric distance (e.g. Hamming distance), not the distance between coordinates (which is measured\n  in Pixels)!\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **matches**: `Evision.Mat.t()`.\n\n  Matches array stored in GPU memory. Internal representation is not defined.\n  Use DescriptorMatcher::radiusMatchConvert method to retrieve results in standard representation.\n\nFor each query descriptor, the methods find such training descriptors that the distance between the\nquery descriptor and the training descriptor is equal or smaller than maxDistance. Found matches are\nreturned in the distance increasing order.\n\nPython prototype (for reference only):\n```python3\nradiusMatchAsync(queryDescriptors, trainDescriptors, maxDistance[, matches[, mask[, stream]]]) -> matches\n```\n#### Variant 2:\nFor each query descriptor, finds the training descriptors not farther than the specified distance (asynchronous version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **maxDistance**: `float`.\n\n  Threshold for the distance between matched descriptors. Distance means here\n  metric distance (e.g. Hamming distance), not the distance between coordinates (which is measured\n  in Pixels)!\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **matches**: `Evision.CUDA.GpuMat.t()`.\n\n  Matches array stored in GPU memory. Internal representation is not defined.\n  Use DescriptorMatcher::radiusMatchConvert method to retrieve results in standard representation.\n\nFor each query descriptor, the methods find such training descriptors that the distance between the\nquery descriptor and the training descriptor is equal or smaller than maxDistance. Found matches are\nreturned in the distance increasing order.\n\nPython prototype (for reference only):\n```python3\nradiusMatchAsync(queryDescriptors, trainDescriptors, maxDistance[, matches[, mask[, stream]]]) -> matches\n```\n#### Variant 3:\nradiusMatchAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`\n- **maxDistance**: `float`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **matches**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nradiusMatchAsync(queryDescriptors, maxDistance[, matches[, masks[, stream]]]) -> matches\n```\n#### Variant 4:\nradiusMatchAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`\n- **maxDistance**: `float`\n\n##### Keyword Arguments\n- **masks**: `[Evision.CUDA.GpuMat]`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **matches**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nradiusMatchAsync(queryDescriptors, maxDistance[, matches[, masks[, stream]]]) -> matches\n```","ref":"Evision.CUDA.DescriptorMatcher.html#radiusMatchAsync/4"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.radiusMatchAsync/5","doc":"#### Variant 1:\nFor each query descriptor, finds the training descriptors not farther than the specified distance (asynchronous version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **maxDistance**: `float`.\n\n  Threshold for the distance between matched descriptors. Distance means here\n  metric distance (e.g. Hamming distance), not the distance between coordinates (which is measured\n  in Pixels)!\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **matches**: `Evision.Mat.t()`.\n\n  Matches array stored in GPU memory. Internal representation is not defined.\n  Use DescriptorMatcher::radiusMatchConvert method to retrieve results in standard representation.\n\nFor each query descriptor, the methods find such training descriptors that the distance between the\nquery descriptor and the training descriptor is equal or smaller than maxDistance. Found matches are\nreturned in the distance increasing order.\n\nPython prototype (for reference only):\n```python3\nradiusMatchAsync(queryDescriptors, trainDescriptors, maxDistance[, matches[, mask[, stream]]]) -> matches\n```\n#### Variant 2:\nFor each query descriptor, finds the training descriptors not farther than the specified distance (asynchronous version).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **maxDistance**: `float`.\n\n  Threshold for the distance between matched descriptors. Distance means here\n  metric distance (e.g. Hamming distance), not the distance between coordinates (which is measured\n  in Pixels)!\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **matches**: `Evision.CUDA.GpuMat.t()`.\n\n  Matches array stored in GPU memory. Internal representation is not defined.\n  Use DescriptorMatcher::radiusMatchConvert method to retrieve results in standard representation.\n\nFor each query descriptor, the methods find such training descriptors that the distance between the\nquery descriptor and the training descriptor is equal or smaller than maxDistance. Found matches are\nreturned in the distance increasing order.\n\nPython prototype (for reference only):\n```python3\nradiusMatchAsync(queryDescriptors, trainDescriptors, maxDistance[, matches[, mask[, stream]]]) -> matches\n```","ref":"Evision.CUDA.DescriptorMatcher.html#radiusMatchAsync/5"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.radiusMatchConvert/1","doc":"","ref":"Evision.CUDA.DescriptorMatcher.html#radiusMatchConvert/1"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.radiusMatchConvert/2","doc":"#### Variant 1:\nConverts matches array from internal representation to standard matches vector.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **gpu_matches**: `Evision.Mat`.\n\n  Matches, returned from DescriptorMatcher::radiusMatchAsync.\n\n##### Keyword Arguments\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Vector of DMatch objects.\n\nThe method is supposed to be used with DescriptorMatcher::radiusMatchAsync to get final result.\nCall this method only after DescriptorMatcher::radiusMatchAsync is completed (ie. after synchronization).\n\nPython prototype (for reference only):\n```python3\nradiusMatchConvert(gpu_matches[, compactResult]) -> matches\n```\n#### Variant 2:\nConverts matches array from internal representation to standard matches vector.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **gpu_matches**: `Evision.CUDA.GpuMat.t()`.\n\n  Matches, returned from DescriptorMatcher::radiusMatchAsync.\n\n##### Keyword Arguments\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Vector of DMatch objects.\n\nThe method is supposed to be used with DescriptorMatcher::radiusMatchAsync to get final result.\nCall this method only after DescriptorMatcher::radiusMatchAsync is completed (ie. after synchronization).\n\nPython prototype (for reference only):\n```python3\nradiusMatchConvert(gpu_matches[, compactResult]) -> matches\n```","ref":"Evision.CUDA.DescriptorMatcher.html#radiusMatchConvert/2"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.radiusMatchConvert/3","doc":"#### Variant 1:\nConverts matches array from internal representation to standard matches vector.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **gpu_matches**: `Evision.Mat`.\n\n  Matches, returned from DescriptorMatcher::radiusMatchAsync.\n\n##### Keyword Arguments\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Vector of DMatch objects.\n\nThe method is supposed to be used with DescriptorMatcher::radiusMatchAsync to get final result.\nCall this method only after DescriptorMatcher::radiusMatchAsync is completed (ie. after synchronization).\n\nPython prototype (for reference only):\n```python3\nradiusMatchConvert(gpu_matches[, compactResult]) -> matches\n```\n#### Variant 2:\nConverts matches array from internal representation to standard matches vector.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **gpu_matches**: `Evision.CUDA.GpuMat.t()`.\n\n  Matches, returned from DescriptorMatcher::radiusMatchAsync.\n\n##### Keyword Arguments\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Vector of DMatch objects.\n\nThe method is supposed to be used with DescriptorMatcher::radiusMatchAsync to get final result.\nCall this method only after DescriptorMatcher::radiusMatchAsync is completed (ie. after synchronization).\n\nPython prototype (for reference only):\n```python3\nradiusMatchConvert(gpu_matches[, compactResult]) -> matches\n```","ref":"Evision.CUDA.DescriptorMatcher.html#radiusMatchConvert/3"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.read/1","doc":"","ref":"Evision.CUDA.DescriptorMatcher.html#read/1"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.CUDA.DescriptorMatcher.html#read/2"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.save/1","doc":"","ref":"Evision.CUDA.DescriptorMatcher.html#save/1"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.CUDA.DescriptorMatcher.html#save/2"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.train/1","doc":"Trains a descriptor matcher.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n\nTrains a descriptor matcher (for example, the flann index). In all methods to match, the method\ntrain() is run every time before matching.\n\nPython prototype (for reference only):\n```python3\ntrain() -> None\n```","ref":"Evision.CUDA.DescriptorMatcher.html#train/1"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.write/1","doc":"","ref":"Evision.CUDA.DescriptorMatcher.html#write/1"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.CUDA.DescriptorMatcher.html#write/2"},{"type":"function","title":"Evision.CUDA.DescriptorMatcher.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DescriptorMatcher.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CUDA.DescriptorMatcher.html#write/3"},{"type":"type","title":"Evision.CUDA.DescriptorMatcher.t/0","doc":"Type that represents an `CUDA.DescriptorMatcher` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.DescriptorMatcher.html#t:t/0"},{"type":"module","title":"Evision.CUDA.DeviceInfo","doc":"","ref":"Evision.CUDA.DeviceInfo.html"},{"type":"function","title":"Evision.CUDA.DeviceInfo.asyncEngineCount/1","doc":"asyncEngineCount\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nasyncEngineCount() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#asyncEngineCount/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.canMapHostMemory/1","doc":"canMapHostMemory\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ncanMapHostMemory() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#canMapHostMemory/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.clockRate/1","doc":"clockRate\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nclockRate() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#clockRate/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.computeMode/1","doc":"computeMode\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `DeviceInfo::ComputeMode`\n\nPython prototype (for reference only):\n```python3\ncomputeMode() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#computeMode/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.concurrentKernels/1","doc":"concurrentKernels\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nconcurrentKernels() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#concurrentKernels/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.deviceID/1","doc":"Returns system index of the CUDA device starting with 0.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndeviceID() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#deviceID/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.deviceInfo/0","doc":"DeviceInfo\n##### Return\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\nPython prototype (for reference only):\n```python3\nDeviceInfo() ->  \n```","ref":"Evision.CUDA.DeviceInfo.html#deviceInfo/0"},{"type":"function","title":"Evision.CUDA.DeviceInfo.deviceInfo/1","doc":"The constructors.\n\n##### Positional Arguments\n- **device_id**: `integer()`.\n\n  System index of the CUDA device starting with 0.\n\n##### Return\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\nConstructs the DeviceInfo object for the specified device. If device_id parameter is missed, it\nconstructs an object for the current device.\n\nPython prototype (for reference only):\n```python3\nDeviceInfo(device_id) ->  \n```","ref":"Evision.CUDA.DeviceInfo.html#deviceInfo/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.eccEnabled/1","doc":"ECCEnabled\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nECCEnabled() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#eccEnabled/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.freeMemory/1","doc":"freeMemory\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nfreeMemory() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#freeMemory/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.integrated/1","doc":"integrated\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nintegrated() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#integrated/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.isCompatible/1","doc":"Checks the CUDA module and device compatibility.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `bool`\n\nThis function returns true if the CUDA module can be run on the specified device. Otherwise, it\nreturns false .\n\nPython prototype (for reference only):\n```python3\nisCompatible() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#isCompatible/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.kernelExecTimeoutEnabled/1","doc":"kernelExecTimeoutEnabled\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nkernelExecTimeoutEnabled() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#kernelExecTimeoutEnabled/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.l2CacheSize/1","doc":"l2CacheSize\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nl2CacheSize() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#l2CacheSize/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.majorVersion/1","doc":"majorVersion\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nmajorVersion() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#majorVersion/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.maxGridSize/1","doc":"maxGridSize\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `Vec3i`\n\nPython prototype (for reference only):\n```python3\nmaxGridSize() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#maxGridSize/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.maxSurface1D/1","doc":"maxSurface1D\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nmaxSurface1D() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#maxSurface1D/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.maxSurface1DLayered/1","doc":"maxSurface1DLayered\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `Vec2i`\n\nPython prototype (for reference only):\n```python3\nmaxSurface1DLayered() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#maxSurface1DLayered/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.maxSurface2D/1","doc":"maxSurface2D\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `Vec2i`\n\nPython prototype (for reference only):\n```python3\nmaxSurface2D() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#maxSurface2D/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.maxSurface2DLayered/1","doc":"maxSurface2DLayered\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `Vec3i`\n\nPython prototype (for reference only):\n```python3\nmaxSurface2DLayered() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#maxSurface2DLayered/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.maxSurface3D/1","doc":"maxSurface3D\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `Vec3i`\n\nPython prototype (for reference only):\n```python3\nmaxSurface3D() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#maxSurface3D/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.maxSurfaceCubemap/1","doc":"maxSurfaceCubemap\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nmaxSurfaceCubemap() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#maxSurfaceCubemap/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.maxSurfaceCubemapLayered/1","doc":"maxSurfaceCubemapLayered\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `Vec2i`\n\nPython prototype (for reference only):\n```python3\nmaxSurfaceCubemapLayered() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#maxSurfaceCubemapLayered/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.maxTexture1D/1","doc":"maxTexture1D\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nmaxTexture1D() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#maxTexture1D/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.maxTexture1DLayered/1","doc":"maxTexture1DLayered\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `Vec2i`\n\nPython prototype (for reference only):\n```python3\nmaxTexture1DLayered() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#maxTexture1DLayered/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.maxTexture1DLinear/1","doc":"maxTexture1DLinear\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nmaxTexture1DLinear() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#maxTexture1DLinear/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.maxTexture1DMipmap/1","doc":"maxTexture1DMipmap\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nmaxTexture1DMipmap() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#maxTexture1DMipmap/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.maxTexture2D/1","doc":"maxTexture2D\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `Vec2i`\n\nPython prototype (for reference only):\n```python3\nmaxTexture2D() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#maxTexture2D/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.maxTexture2DGather/1","doc":"maxTexture2DGather\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `Vec2i`\n\nPython prototype (for reference only):\n```python3\nmaxTexture2DGather() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#maxTexture2DGather/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.maxTexture2DLayered/1","doc":"maxTexture2DLayered\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `Vec3i`\n\nPython prototype (for reference only):\n```python3\nmaxTexture2DLayered() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#maxTexture2DLayered/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.maxTexture2DLinear/1","doc":"maxTexture2DLinear\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `Vec3i`\n\nPython prototype (for reference only):\n```python3\nmaxTexture2DLinear() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#maxTexture2DLinear/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.maxTexture2DMipmap/1","doc":"maxTexture2DMipmap\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `Vec2i`\n\nPython prototype (for reference only):\n```python3\nmaxTexture2DMipmap() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#maxTexture2DMipmap/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.maxTexture3D/1","doc":"maxTexture3D\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `Vec3i`\n\nPython prototype (for reference only):\n```python3\nmaxTexture3D() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#maxTexture3D/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.maxTextureCubemap/1","doc":"maxTextureCubemap\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nmaxTextureCubemap() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#maxTextureCubemap/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.maxTextureCubemapLayered/1","doc":"maxTextureCubemapLayered\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `Vec2i`\n\nPython prototype (for reference only):\n```python3\nmaxTextureCubemapLayered() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#maxTextureCubemapLayered/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.maxThreadsDim/1","doc":"maxThreadsDim\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `Vec3i`\n\nPython prototype (for reference only):\n```python3\nmaxThreadsDim() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#maxThreadsDim/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.maxThreadsPerBlock/1","doc":"maxThreadsPerBlock\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nmaxThreadsPerBlock() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#maxThreadsPerBlock/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.maxThreadsPerMultiProcessor/1","doc":"maxThreadsPerMultiProcessor\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nmaxThreadsPerMultiProcessor() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#maxThreadsPerMultiProcessor/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.memoryBusWidth/1","doc":"memoryBusWidth\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nmemoryBusWidth() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#memoryBusWidth/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.memoryClockRate/1","doc":"memoryClockRate\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nmemoryClockRate() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#memoryClockRate/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.memPitch/1","doc":"memPitch\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nmemPitch() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#memPitch/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.minorVersion/1","doc":"minorVersion\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nminorVersion() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#minorVersion/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.multiProcessorCount/1","doc":"multiProcessorCount\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nmultiProcessorCount() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#multiProcessorCount/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.pciBusID/1","doc":"pciBusID\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\npciBusID() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#pciBusID/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.pciDeviceID/1","doc":"pciDeviceID\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\npciDeviceID() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#pciDeviceID/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.pciDomainID/1","doc":"pciDomainID\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\npciDomainID() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#pciDomainID/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.queryMemory/1","doc":"","ref":"Evision.CUDA.DeviceInfo.html#queryMemory/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.queryMemory/3","doc":"queryMemory\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n- **totalMemory**: `size_t`\n- **freeMemory**: `size_t`\n\nPython prototype (for reference only):\n```python3\nqueryMemory(totalMemory, freeMemory) -> None\n```","ref":"Evision.CUDA.DeviceInfo.html#queryMemory/3"},{"type":"function","title":"Evision.CUDA.DeviceInfo.regsPerBlock/1","doc":"regsPerBlock\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nregsPerBlock() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#regsPerBlock/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.sharedMemPerBlock/1","doc":"sharedMemPerBlock\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nsharedMemPerBlock() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#sharedMemPerBlock/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.surfaceAlignment/1","doc":"surfaceAlignment\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nsurfaceAlignment() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#surfaceAlignment/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.tccDriver/1","doc":"tccDriver\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntccDriver() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#tccDriver/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.textureAlignment/1","doc":"textureAlignment\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\ntextureAlignment() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#textureAlignment/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.texturePitchAlignment/1","doc":"texturePitchAlignment\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\ntexturePitchAlignment() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#texturePitchAlignment/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.totalConstMem/1","doc":"totalConstMem\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\ntotalConstMem() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#totalConstMem/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.totalGlobalMem/1","doc":"totalGlobalMem\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\ntotalGlobalMem() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#totalGlobalMem/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.totalMemory/1","doc":"totalMemory\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\ntotalMemory() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#totalMemory/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.unifiedAddressing/1","doc":"unifiedAddressing\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nunifiedAddressing() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#unifiedAddressing/1"},{"type":"function","title":"Evision.CUDA.DeviceInfo.warpSize/1","doc":"warpSize\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DeviceInfo.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nwarpSize() -> retval\n```","ref":"Evision.CUDA.DeviceInfo.html#warpSize/1"},{"type":"type","title":"Evision.CUDA.DeviceInfo.t/0","doc":"Type that represents an `CUDA.DeviceInfo` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.DeviceInfo.html#t:t/0"},{"type":"module","title":"Evision.CUDA.DeviceInfo.ComputeMode","doc":"","ref":"Evision.CUDA.DeviceInfo.ComputeMode.html"},{"type":"function","title":"Evision.CUDA.DeviceInfo.ComputeMode.cv_ComputeModeDefault/0","doc":"","ref":"Evision.CUDA.DeviceInfo.ComputeMode.html#cv_ComputeModeDefault/0"},{"type":"function","title":"Evision.CUDA.DeviceInfo.ComputeMode.cv_ComputeModeExclusive/0","doc":"","ref":"Evision.CUDA.DeviceInfo.ComputeMode.html#cv_ComputeModeExclusive/0"},{"type":"function","title":"Evision.CUDA.DeviceInfo.ComputeMode.cv_ComputeModeExclusiveProcess/0","doc":"","ref":"Evision.CUDA.DeviceInfo.ComputeMode.html#cv_ComputeModeExclusiveProcess/0"},{"type":"function","title":"Evision.CUDA.DeviceInfo.ComputeMode.cv_ComputeModeProhibited/0","doc":"","ref":"Evision.CUDA.DeviceInfo.ComputeMode.html#cv_ComputeModeProhibited/0"},{"type":"type","title":"Evision.CUDA.DeviceInfo.ComputeMode.enum/0","doc":"","ref":"Evision.CUDA.DeviceInfo.ComputeMode.html#t:enum/0"},{"type":"module","title":"Evision.CUDA.DisparityBilateralFilter","doc":"","ref":"Evision.CUDA.DisparityBilateralFilter.html"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.apply/1","doc":"","ref":"Evision.CUDA.DisparityBilateralFilter.html#apply/1"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.apply/3","doc":"#### Variant 1:\nRefines a disparity map using joint bilateral filtering.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DisparityBilateralFilter.t()`\n- **disparity**: `Evision.Mat`.\n\n  Input disparity map. CV_8UC1 and CV_16SC1 types are supported.\n\n- **image**: `Evision.Mat`.\n\n  Input image. CV_8UC1 and CV_8UC3 types are supported.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination disparity map. It has the same size and type as disparity .\n\nPython prototype (for reference only):\n```python3\napply(disparity, image[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nRefines a disparity map using joint bilateral filtering.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DisparityBilateralFilter.t()`\n- **disparity**: `Evision.CUDA.GpuMat.t()`.\n\n  Input disparity map. CV_8UC1 and CV_16SC1 types are supported.\n\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Input image. CV_8UC1 and CV_8UC3 types are supported.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination disparity map. It has the same size and type as disparity .\n\nPython prototype (for reference only):\n```python3\napply(disparity, image[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.DisparityBilateralFilter.html#apply/3"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.apply/4","doc":"#### Variant 1:\nRefines a disparity map using joint bilateral filtering.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DisparityBilateralFilter.t()`\n- **disparity**: `Evision.Mat`.\n\n  Input disparity map. CV_8UC1 and CV_16SC1 types are supported.\n\n- **image**: `Evision.Mat`.\n\n  Input image. CV_8UC1 and CV_8UC3 types are supported.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination disparity map. It has the same size and type as disparity .\n\nPython prototype (for reference only):\n```python3\napply(disparity, image[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nRefines a disparity map using joint bilateral filtering.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DisparityBilateralFilter.t()`\n- **disparity**: `Evision.CUDA.GpuMat.t()`.\n\n  Input disparity map. CV_8UC1 and CV_16SC1 types are supported.\n\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Input image. CV_8UC1 and CV_8UC3 types are supported.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination disparity map. It has the same size and type as disparity .\n\nPython prototype (for reference only):\n```python3\napply(disparity, image[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.DisparityBilateralFilter.html#apply/4"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DisparityBilateralFilter.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.CUDA.DisparityBilateralFilter.html#clear/1"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DisparityBilateralFilter.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CUDA.DisparityBilateralFilter.html#empty/1"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DisparityBilateralFilter.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CUDA.DisparityBilateralFilter.html#getDefaultName/1"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.getEdgeThreshold/1","doc":"getEdgeThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DisparityBilateralFilter.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetEdgeThreshold() -> retval\n```","ref":"Evision.CUDA.DisparityBilateralFilter.html#getEdgeThreshold/1"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.getMaxDiscThreshold/1","doc":"getMaxDiscThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DisparityBilateralFilter.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxDiscThreshold() -> retval\n```","ref":"Evision.CUDA.DisparityBilateralFilter.html#getMaxDiscThreshold/1"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.getNumDisparities/1","doc":"getNumDisparities\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DisparityBilateralFilter.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNumDisparities() -> retval\n```","ref":"Evision.CUDA.DisparityBilateralFilter.html#getNumDisparities/1"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.getNumIters/1","doc":"getNumIters\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DisparityBilateralFilter.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNumIters() -> retval\n```","ref":"Evision.CUDA.DisparityBilateralFilter.html#getNumIters/1"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.getRadius/1","doc":"getRadius\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DisparityBilateralFilter.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetRadius() -> retval\n```","ref":"Evision.CUDA.DisparityBilateralFilter.html#getRadius/1"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.getSigmaRange/1","doc":"getSigmaRange\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DisparityBilateralFilter.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetSigmaRange() -> retval\n```","ref":"Evision.CUDA.DisparityBilateralFilter.html#getSigmaRange/1"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.read/1","doc":"","ref":"Evision.CUDA.DisparityBilateralFilter.html#read/1"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DisparityBilateralFilter.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.CUDA.DisparityBilateralFilter.html#read/2"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.save/1","doc":"","ref":"Evision.CUDA.DisparityBilateralFilter.html#save/1"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DisparityBilateralFilter.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.CUDA.DisparityBilateralFilter.html#save/2"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.setEdgeThreshold/1","doc":"","ref":"Evision.CUDA.DisparityBilateralFilter.html#setEdgeThreshold/1"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.setEdgeThreshold/2","doc":"setEdgeThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DisparityBilateralFilter.t()`\n- **edge_threshold**: `double`\n\nPython prototype (for reference only):\n```python3\nsetEdgeThreshold(edge_threshold) -> None\n```","ref":"Evision.CUDA.DisparityBilateralFilter.html#setEdgeThreshold/2"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.setMaxDiscThreshold/1","doc":"","ref":"Evision.CUDA.DisparityBilateralFilter.html#setMaxDiscThreshold/1"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.setMaxDiscThreshold/2","doc":"setMaxDiscThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DisparityBilateralFilter.t()`\n- **max_disc_threshold**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxDiscThreshold(max_disc_threshold) -> None\n```","ref":"Evision.CUDA.DisparityBilateralFilter.html#setMaxDiscThreshold/2"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.setNumDisparities/1","doc":"","ref":"Evision.CUDA.DisparityBilateralFilter.html#setNumDisparities/1"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.setNumDisparities/2","doc":"setNumDisparities\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DisparityBilateralFilter.t()`\n- **numDisparities**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNumDisparities(numDisparities) -> None\n```","ref":"Evision.CUDA.DisparityBilateralFilter.html#setNumDisparities/2"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.setNumIters/1","doc":"","ref":"Evision.CUDA.DisparityBilateralFilter.html#setNumIters/1"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.setNumIters/2","doc":"setNumIters\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DisparityBilateralFilter.t()`\n- **iters**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNumIters(iters) -> None\n```","ref":"Evision.CUDA.DisparityBilateralFilter.html#setNumIters/2"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.setRadius/1","doc":"","ref":"Evision.CUDA.DisparityBilateralFilter.html#setRadius/1"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.setRadius/2","doc":"setRadius\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DisparityBilateralFilter.t()`\n- **radius**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetRadius(radius) -> None\n```","ref":"Evision.CUDA.DisparityBilateralFilter.html#setRadius/2"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.setSigmaRange/1","doc":"","ref":"Evision.CUDA.DisparityBilateralFilter.html#setSigmaRange/1"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.setSigmaRange/2","doc":"setSigmaRange\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DisparityBilateralFilter.t()`\n- **sigma_range**: `double`\n\nPython prototype (for reference only):\n```python3\nsetSigmaRange(sigma_range) -> None\n```","ref":"Evision.CUDA.DisparityBilateralFilter.html#setSigmaRange/2"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.write/1","doc":"","ref":"Evision.CUDA.DisparityBilateralFilter.html#write/1"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DisparityBilateralFilter.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.CUDA.DisparityBilateralFilter.html#write/2"},{"type":"function","title":"Evision.CUDA.DisparityBilateralFilter.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.DisparityBilateralFilter.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CUDA.DisparityBilateralFilter.html#write/3"},{"type":"type","title":"Evision.CUDA.DisparityBilateralFilter.t/0","doc":"Type that represents an `CUDA.DisparityBilateralFilter` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.DisparityBilateralFilter.html#t:t/0"},{"type":"module","title":"Evision.CUDA.Event","doc":"","ref":"Evision.CUDA.Event.html"},{"type":"function","title":"Evision.CUDA.Event.elapsedTime/1","doc":"","ref":"Evision.CUDA.Event.html#elapsedTime/1"},{"type":"function","title":"Evision.CUDA.Event.elapsedTime/2","doc":"elapsedTime\n\n##### Positional Arguments\n- **start**: `Evision.CUDA.Event.t()`\n- **end_arg**: `Evision.CUDA.Event.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\nelapsedTime(start, end) -> retval\n```","ref":"Evision.CUDA.Event.html#elapsedTime/2"},{"type":"function","title":"Evision.CUDA.Event.event/0","doc":"Event\n##### Keyword Arguments\n- **flags**: `Event_CreateFlags`.\n\n##### Return\n- **self**: `Evision.CUDA.Event.t()`\n\nPython prototype (for reference only):\n```python3\nEvent([, flags]) ->  \n```","ref":"Evision.CUDA.Event.html#event/0"},{"type":"function","title":"Evision.CUDA.Event.event/1","doc":"Event\n##### Keyword Arguments\n- **flags**: `Event_CreateFlags`.\n\n##### Return\n- **self**: `Evision.CUDA.Event.t()`\n\nPython prototype (for reference only):\n```python3\nEvent([, flags]) ->  \n```","ref":"Evision.CUDA.Event.html#event/1"},{"type":"function","title":"Evision.CUDA.Event.queryIfComplete/1","doc":"queryIfComplete\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Event.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nqueryIfComplete() -> retval\n```","ref":"Evision.CUDA.Event.html#queryIfComplete/1"},{"type":"function","title":"Evision.CUDA.Event.record/1","doc":"record\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Event.t()`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\nPython prototype (for reference only):\n```python3\nrecord([, stream]) -> None\n```","ref":"Evision.CUDA.Event.html#record/1"},{"type":"function","title":"Evision.CUDA.Event.record/2","doc":"record\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Event.t()`\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\nPython prototype (for reference only):\n```python3\nrecord([, stream]) -> None\n```","ref":"Evision.CUDA.Event.html#record/2"},{"type":"function","title":"Evision.CUDA.Event.waitForCompletion/1","doc":"waitForCompletion\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Event.t()`\n\nPython prototype (for reference only):\n```python3\nwaitForCompletion() -> None\n```","ref":"Evision.CUDA.Event.html#waitForCompletion/1"},{"type":"type","title":"Evision.CUDA.Event.t/0","doc":"Type that represents an `CUDA.Event` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.Event.html#t:t/0"},{"type":"module","title":"Evision.CUDA.Event.CreateFlags","doc":"","ref":"Evision.CUDA.Event.CreateFlags.html"},{"type":"function","title":"Evision.CUDA.Event.CreateFlags.cv_BLOCKING_SYNC/0","doc":"","ref":"Evision.CUDA.Event.CreateFlags.html#cv_BLOCKING_SYNC/0"},{"type":"function","title":"Evision.CUDA.Event.CreateFlags.cv_DEFAULT/0","doc":"","ref":"Evision.CUDA.Event.CreateFlags.html#cv_DEFAULT/0"},{"type":"function","title":"Evision.CUDA.Event.CreateFlags.cv_DISABLE_TIMING/0","doc":"","ref":"Evision.CUDA.Event.CreateFlags.html#cv_DISABLE_TIMING/0"},{"type":"function","title":"Evision.CUDA.Event.CreateFlags.cv_INTERPROCESS/0","doc":"","ref":"Evision.CUDA.Event.CreateFlags.html#cv_INTERPROCESS/0"},{"type":"type","title":"Evision.CUDA.Event.CreateFlags.enum/0","doc":"","ref":"Evision.CUDA.Event.CreateFlags.html#t:enum/0"},{"type":"module","title":"Evision.CUDA.FastFeatureDetector","doc":"","ref":"Evision.CUDA.FastFeatureDetector.html"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.compute/1","doc":"","ref":"Evision.CUDA.FastFeatureDetector.html#compute/1"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.FastFeatureDetector.html#compute/3"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.FastFeatureDetector.html#compute/4"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.computeAsync/1","doc":"","ref":"Evision.CUDA.FastFeatureDetector.html#computeAsync/1"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.computeAsync/2","doc":"#### Variant 1:\nComputes the descriptors for a set of keypoints detected in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.Mat.t()`.\n\n  Input collection of keypoints.\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. Row j is the descriptor for j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncomputeAsync(image[, keypoints[, descriptors[, stream]]]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.CUDA.GpuMat.t()`.\n\n  Input collection of keypoints.\n\n- **descriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Computed descriptors. Row j is the descriptor for j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncomputeAsync(image[, keypoints[, descriptors[, stream]]]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.FastFeatureDetector.html#computeAsync/2"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.computeAsync/3","doc":"#### Variant 1:\nComputes the descriptors for a set of keypoints detected in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.Mat.t()`.\n\n  Input collection of keypoints.\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. Row j is the descriptor for j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncomputeAsync(image[, keypoints[, descriptors[, stream]]]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.CUDA.GpuMat.t()`.\n\n  Input collection of keypoints.\n\n- **descriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Computed descriptors. Row j is the descriptor for j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncomputeAsync(image[, keypoints[, descriptors[, stream]]]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.FastFeatureDetector.html#computeAsync/3"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.convert/1","doc":"","ref":"Evision.CUDA.FastFeatureDetector.html#convert/1"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.convert/2","doc":"#### Variant 1:\nconvert\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **gpu_keypoints**: `Evision.Mat`\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n\nConverts keypoints array from internal representation to standard vector.\n\nPython prototype (for reference only):\n```python3\nconvert(gpu_keypoints) -> keypoints\n```\n#### Variant 2:\nconvert\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **gpu_keypoints**: `Evision.CUDA.GpuMat.t()`\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n\nConverts keypoints array from internal representation to standard vector.\n\nPython prototype (for reference only):\n```python3\nconvert(gpu_keypoints) -> keypoints\n```","ref":"Evision.CUDA.FastFeatureDetector.html#convert/2"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.create/0","doc":"create\n##### Keyword Arguments\n- **threshold**: `integer()`.\n- **nonmaxSuppression**: `bool`.\n- **type**: `integer()`.\n- **max_npoints**: `integer()`.\n\n##### Return\n- **retval**: `Evision.CUDA.FastFeatureDetector.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, threshold[, nonmaxSuppression[, type[, max_npoints]]]]) -> retval\n```","ref":"Evision.CUDA.FastFeatureDetector.html#create/0"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.create/1","doc":"create\n##### Keyword Arguments\n- **threshold**: `integer()`.\n- **nonmaxSuppression**: `bool`.\n- **type**: `integer()`.\n- **max_npoints**: `integer()`.\n\n##### Return\n- **retval**: `Evision.CUDA.FastFeatureDetector.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, threshold[, nonmaxSuppression[, type[, max_npoints]]]]) -> retval\n```","ref":"Evision.CUDA.FastFeatureDetector.html#create/1"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.CUDA.FastFeatureDetector.html#defaultNorm/1"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.CUDA.FastFeatureDetector.html#descriptorSize/1"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.CUDA.FastFeatureDetector.html#descriptorType/1"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.detect/1","doc":"","ref":"Evision.CUDA.FastFeatureDetector.html#detect/1"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.CUDA.FastFeatureDetector.html#detect/2"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.CUDA.FastFeatureDetector.html#detect/3"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.detectAndCompute/1","doc":"","ref":"Evision.CUDA.FastFeatureDetector.html#detectAndCompute/1"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.FastFeatureDetector.html#detectAndCompute/3"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.FastFeatureDetector.html#detectAndCompute/4"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.detectAndComputeAsync/1","doc":"","ref":"Evision.CUDA.FastFeatureDetector.html#detectAndComputeAsync/1"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.detectAndComputeAsync/3","doc":"#### Variant 1:\ndetectAndComputeAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **keypoints**: `Evision.Mat.t()`.\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors.\n\nPython prototype (for reference only):\n```python3\ndetectAndComputeAsync(image, mask[, keypoints[, descriptors[, useProvidedKeypoints[, stream]]]]) -> keypoints, descriptors\n```\n#### Variant 2:\ndetectAndComputeAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`\n- **mask**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **keypoints**: `Evision.CUDA.GpuMat.t()`.\n- **descriptors**: `Evision.CUDA.GpuMat.t()`.\n\nDetects keypoints and computes the descriptors.\n\nPython prototype (for reference only):\n```python3\ndetectAndComputeAsync(image, mask[, keypoints[, descriptors[, useProvidedKeypoints[, stream]]]]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.FastFeatureDetector.html#detectAndComputeAsync/3"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.detectAndComputeAsync/4","doc":"#### Variant 1:\ndetectAndComputeAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **keypoints**: `Evision.Mat.t()`.\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors.\n\nPython prototype (for reference only):\n```python3\ndetectAndComputeAsync(image, mask[, keypoints[, descriptors[, useProvidedKeypoints[, stream]]]]) -> keypoints, descriptors\n```\n#### Variant 2:\ndetectAndComputeAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`\n- **mask**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **keypoints**: `Evision.CUDA.GpuMat.t()`.\n- **descriptors**: `Evision.CUDA.GpuMat.t()`.\n\nDetects keypoints and computes the descriptors.\n\nPython prototype (for reference only):\n```python3\ndetectAndComputeAsync(image, mask[, keypoints[, descriptors[, useProvidedKeypoints[, stream]]]]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.FastFeatureDetector.html#detectAndComputeAsync/4"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.detectAsync/1","doc":"","ref":"Evision.CUDA.FastFeatureDetector.html#detectAsync/1"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.detectAsync/2","doc":"#### Variant 1:\nDetects keypoints in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.Mat.t()`.\n\n  The detected keypoints.\n\nPython prototype (for reference only):\n```python3\ndetectAsync(image[, keypoints[, mask[, stream]]]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.CUDA.GpuMat.t()`.\n\n  The detected keypoints.\n\nPython prototype (for reference only):\n```python3\ndetectAsync(image[, keypoints[, mask[, stream]]]) -> keypoints\n```","ref":"Evision.CUDA.FastFeatureDetector.html#detectAsync/2"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.detectAsync/3","doc":"#### Variant 1:\nDetects keypoints in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.Mat.t()`.\n\n  The detected keypoints.\n\nPython prototype (for reference only):\n```python3\ndetectAsync(image[, keypoints[, mask[, stream]]]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.CUDA.GpuMat.t()`.\n\n  The detected keypoints.\n\nPython prototype (for reference only):\n```python3\ndetectAsync(image[, keypoints[, mask[, stream]]]) -> keypoints\n```","ref":"Evision.CUDA.FastFeatureDetector.html#detectAsync/3"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CUDA.FastFeatureDetector.html#empty/1"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CUDA.FastFeatureDetector.html#getDefaultName/1"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.getMaxNumPoints/1","doc":"getMaxNumPoints\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxNumPoints() -> retval\n```","ref":"Evision.CUDA.FastFeatureDetector.html#getMaxNumPoints/1"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.read/1","doc":"","ref":"Evision.CUDA.FastFeatureDetector.html#read/1"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.CUDA.FastFeatureDetector.html#read/2"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.setMaxNumPoints/1","doc":"","ref":"Evision.CUDA.FastFeatureDetector.html#setMaxNumPoints/1"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.setMaxNumPoints/2","doc":"setMaxNumPoints\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **max_npoints**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxNumPoints(max_npoints) -> None\n```","ref":"Evision.CUDA.FastFeatureDetector.html#setMaxNumPoints/2"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.setThreshold/1","doc":"","ref":"Evision.CUDA.FastFeatureDetector.html#setThreshold/1"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.setThreshold/2","doc":"setThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **threshold**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetThreshold(threshold) -> None\n```","ref":"Evision.CUDA.FastFeatureDetector.html#setThreshold/2"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.write/1","doc":"","ref":"Evision.CUDA.FastFeatureDetector.html#write/1"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.CUDA.FastFeatureDetector.html#write/2"},{"type":"function","title":"Evision.CUDA.FastFeatureDetector.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.FastFeatureDetector.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CUDA.FastFeatureDetector.html#write/3"},{"type":"type","title":"Evision.CUDA.FastFeatureDetector.t/0","doc":"Type that represents an `CUDA.FastFeatureDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.FastFeatureDetector.html#t:t/0"},{"type":"module","title":"Evision.CUDA.Feature2DAsync","doc":"","ref":"Evision.CUDA.Feature2DAsync.html"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.compute/1","doc":"","ref":"Evision.CUDA.Feature2DAsync.html#compute/1"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.Feature2DAsync.html#compute/3"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.Feature2DAsync.html#compute/4"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.computeAsync/1","doc":"","ref":"Evision.CUDA.Feature2DAsync.html#computeAsync/1"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.computeAsync/2","doc":"#### Variant 1:\nComputes the descriptors for a set of keypoints detected in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.Mat.t()`.\n\n  Input collection of keypoints.\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. Row j is the descriptor for j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncomputeAsync(image[, keypoints[, descriptors[, stream]]]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.CUDA.GpuMat.t()`.\n\n  Input collection of keypoints.\n\n- **descriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Computed descriptors. Row j is the descriptor for j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncomputeAsync(image[, keypoints[, descriptors[, stream]]]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.Feature2DAsync.html#computeAsync/2"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.computeAsync/3","doc":"#### Variant 1:\nComputes the descriptors for a set of keypoints detected in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.Mat.t()`.\n\n  Input collection of keypoints.\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. Row j is the descriptor for j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncomputeAsync(image[, keypoints[, descriptors[, stream]]]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.CUDA.GpuMat.t()`.\n\n  Input collection of keypoints.\n\n- **descriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Computed descriptors. Row j is the descriptor for j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncomputeAsync(image[, keypoints[, descriptors[, stream]]]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.Feature2DAsync.html#computeAsync/3"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.convert/1","doc":"","ref":"Evision.CUDA.Feature2DAsync.html#convert/1"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.convert/2","doc":"#### Variant 1:\nconvert\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **gpu_keypoints**: `Evision.Mat`\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n\nConverts keypoints array from internal representation to standard vector.\n\nPython prototype (for reference only):\n```python3\nconvert(gpu_keypoints) -> keypoints\n```\n#### Variant 2:\nconvert\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **gpu_keypoints**: `Evision.CUDA.GpuMat.t()`\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n\nConverts keypoints array from internal representation to standard vector.\n\nPython prototype (for reference only):\n```python3\nconvert(gpu_keypoints) -> keypoints\n```","ref":"Evision.CUDA.Feature2DAsync.html#convert/2"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.CUDA.Feature2DAsync.html#defaultNorm/1"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.CUDA.Feature2DAsync.html#descriptorSize/1"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.CUDA.Feature2DAsync.html#descriptorType/1"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.detect/1","doc":"","ref":"Evision.CUDA.Feature2DAsync.html#detect/1"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.CUDA.Feature2DAsync.html#detect/2"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.CUDA.Feature2DAsync.html#detect/3"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.detectAndCompute/1","doc":"","ref":"Evision.CUDA.Feature2DAsync.html#detectAndCompute/1"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.Feature2DAsync.html#detectAndCompute/3"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.Feature2DAsync.html#detectAndCompute/4"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.detectAndComputeAsync/1","doc":"","ref":"Evision.CUDA.Feature2DAsync.html#detectAndComputeAsync/1"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.detectAndComputeAsync/3","doc":"#### Variant 1:\ndetectAndComputeAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **keypoints**: `Evision.Mat.t()`.\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors.\n\nPython prototype (for reference only):\n```python3\ndetectAndComputeAsync(image, mask[, keypoints[, descriptors[, useProvidedKeypoints[, stream]]]]) -> keypoints, descriptors\n```\n#### Variant 2:\ndetectAndComputeAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`\n- **mask**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **keypoints**: `Evision.CUDA.GpuMat.t()`.\n- **descriptors**: `Evision.CUDA.GpuMat.t()`.\n\nDetects keypoints and computes the descriptors.\n\nPython prototype (for reference only):\n```python3\ndetectAndComputeAsync(image, mask[, keypoints[, descriptors[, useProvidedKeypoints[, stream]]]]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.Feature2DAsync.html#detectAndComputeAsync/3"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.detectAndComputeAsync/4","doc":"#### Variant 1:\ndetectAndComputeAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **keypoints**: `Evision.Mat.t()`.\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors.\n\nPython prototype (for reference only):\n```python3\ndetectAndComputeAsync(image, mask[, keypoints[, descriptors[, useProvidedKeypoints[, stream]]]]) -> keypoints, descriptors\n```\n#### Variant 2:\ndetectAndComputeAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`\n- **mask**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **keypoints**: `Evision.CUDA.GpuMat.t()`.\n- **descriptors**: `Evision.CUDA.GpuMat.t()`.\n\nDetects keypoints and computes the descriptors.\n\nPython prototype (for reference only):\n```python3\ndetectAndComputeAsync(image, mask[, keypoints[, descriptors[, useProvidedKeypoints[, stream]]]]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.Feature2DAsync.html#detectAndComputeAsync/4"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.detectAsync/1","doc":"","ref":"Evision.CUDA.Feature2DAsync.html#detectAsync/1"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.detectAsync/2","doc":"#### Variant 1:\nDetects keypoints in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.Mat.t()`.\n\n  The detected keypoints.\n\nPython prototype (for reference only):\n```python3\ndetectAsync(image[, keypoints[, mask[, stream]]]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.CUDA.GpuMat.t()`.\n\n  The detected keypoints.\n\nPython prototype (for reference only):\n```python3\ndetectAsync(image[, keypoints[, mask[, stream]]]) -> keypoints\n```","ref":"Evision.CUDA.Feature2DAsync.html#detectAsync/2"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.detectAsync/3","doc":"#### Variant 1:\nDetects keypoints in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.Mat.t()`.\n\n  The detected keypoints.\n\nPython prototype (for reference only):\n```python3\ndetectAsync(image[, keypoints[, mask[, stream]]]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.CUDA.GpuMat.t()`.\n\n  The detected keypoints.\n\nPython prototype (for reference only):\n```python3\ndetectAsync(image[, keypoints[, mask[, stream]]]) -> keypoints\n```","ref":"Evision.CUDA.Feature2DAsync.html#detectAsync/3"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CUDA.Feature2DAsync.html#empty/1"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CUDA.Feature2DAsync.html#getDefaultName/1"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.read/1","doc":"","ref":"Evision.CUDA.Feature2DAsync.html#read/1"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.CUDA.Feature2DAsync.html#read/2"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.write/1","doc":"","ref":"Evision.CUDA.Feature2DAsync.html#write/1"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.CUDA.Feature2DAsync.html#write/2"},{"type":"function","title":"Evision.CUDA.Feature2DAsync.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Feature2DAsync.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CUDA.Feature2DAsync.html#write/3"},{"type":"type","title":"Evision.CUDA.Feature2DAsync.t/0","doc":"Type that represents an `CUDA.Feature2DAsync` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.Feature2DAsync.html#t:t/0"},{"type":"module","title":"Evision.CUDA.FeatureSet","doc":"","ref":"Evision.CUDA.FeatureSet.html"},{"type":"function","title":"Evision.CUDA.FeatureSet.cv_DYNAMIC_PARALLELISM/0","doc":"","ref":"Evision.CUDA.FeatureSet.html#cv_DYNAMIC_PARALLELISM/0"},{"type":"function","title":"Evision.CUDA.FeatureSet.cv_FEATURE_SET_COMPUTE_10/0","doc":"","ref":"Evision.CUDA.FeatureSet.html#cv_FEATURE_SET_COMPUTE_10/0"},{"type":"function","title":"Evision.CUDA.FeatureSet.cv_FEATURE_SET_COMPUTE_11/0","doc":"","ref":"Evision.CUDA.FeatureSet.html#cv_FEATURE_SET_COMPUTE_11/0"},{"type":"function","title":"Evision.CUDA.FeatureSet.cv_FEATURE_SET_COMPUTE_12/0","doc":"","ref":"Evision.CUDA.FeatureSet.html#cv_FEATURE_SET_COMPUTE_12/0"},{"type":"function","title":"Evision.CUDA.FeatureSet.cv_FEATURE_SET_COMPUTE_13/0","doc":"","ref":"Evision.CUDA.FeatureSet.html#cv_FEATURE_SET_COMPUTE_13/0"},{"type":"function","title":"Evision.CUDA.FeatureSet.cv_FEATURE_SET_COMPUTE_20/0","doc":"","ref":"Evision.CUDA.FeatureSet.html#cv_FEATURE_SET_COMPUTE_20/0"},{"type":"function","title":"Evision.CUDA.FeatureSet.cv_FEATURE_SET_COMPUTE_21/0","doc":"","ref":"Evision.CUDA.FeatureSet.html#cv_FEATURE_SET_COMPUTE_21/0"},{"type":"function","title":"Evision.CUDA.FeatureSet.cv_FEATURE_SET_COMPUTE_30/0","doc":"","ref":"Evision.CUDA.FeatureSet.html#cv_FEATURE_SET_COMPUTE_30/0"},{"type":"function","title":"Evision.CUDA.FeatureSet.cv_FEATURE_SET_COMPUTE_32/0","doc":"","ref":"Evision.CUDA.FeatureSet.html#cv_FEATURE_SET_COMPUTE_32/0"},{"type":"function","title":"Evision.CUDA.FeatureSet.cv_FEATURE_SET_COMPUTE_35/0","doc":"","ref":"Evision.CUDA.FeatureSet.html#cv_FEATURE_SET_COMPUTE_35/0"},{"type":"function","title":"Evision.CUDA.FeatureSet.cv_FEATURE_SET_COMPUTE_50/0","doc":"","ref":"Evision.CUDA.FeatureSet.html#cv_FEATURE_SET_COMPUTE_50/0"},{"type":"function","title":"Evision.CUDA.FeatureSet.cv_GLOBAL_ATOMICS/0","doc":"","ref":"Evision.CUDA.FeatureSet.html#cv_GLOBAL_ATOMICS/0"},{"type":"function","title":"Evision.CUDA.FeatureSet.cv_NATIVE_DOUBLE/0","doc":"","ref":"Evision.CUDA.FeatureSet.html#cv_NATIVE_DOUBLE/0"},{"type":"function","title":"Evision.CUDA.FeatureSet.cv_SHARED_ATOMICS/0","doc":"","ref":"Evision.CUDA.FeatureSet.html#cv_SHARED_ATOMICS/0"},{"type":"function","title":"Evision.CUDA.FeatureSet.cv_WARP_SHUFFLE_FUNCTIONS/0","doc":"","ref":"Evision.CUDA.FeatureSet.html#cv_WARP_SHUFFLE_FUNCTIONS/0"},{"type":"type","title":"Evision.CUDA.FeatureSet.enum/0","doc":"","ref":"Evision.CUDA.FeatureSet.html#t:enum/0"},{"type":"module","title":"Evision.CUDA.Filter","doc":"","ref":"Evision.CUDA.Filter.html"},{"type":"function","title":"Evision.CUDA.Filter.apply/1","doc":"","ref":"Evision.CUDA.Filter.html#apply/1"},{"type":"function","title":"Evision.CUDA.Filter.apply/2","doc":"#### Variant 1:\nApplies the specified filter to the image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Filter.t()`\n- **src**: `Evision.Mat`.\n\n  Input image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image.\n\nPython prototype (for reference only):\n```python3\napply(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nApplies the specified filter to the image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Filter.t()`\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Input image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Output image.\n\nPython prototype (for reference only):\n```python3\napply(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.Filter.html#apply/2"},{"type":"function","title":"Evision.CUDA.Filter.apply/3","doc":"#### Variant 1:\nApplies the specified filter to the image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Filter.t()`\n- **src**: `Evision.Mat`.\n\n  Input image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image.\n\nPython prototype (for reference only):\n```python3\napply(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nApplies the specified filter to the image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Filter.t()`\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Input image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Output image.\n\nPython prototype (for reference only):\n```python3\napply(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.Filter.html#apply/3"},{"type":"function","title":"Evision.CUDA.Filter.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Filter.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.CUDA.Filter.html#clear/1"},{"type":"function","title":"Evision.CUDA.Filter.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Filter.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CUDA.Filter.html#empty/1"},{"type":"function","title":"Evision.CUDA.Filter.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Filter.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CUDA.Filter.html#getDefaultName/1"},{"type":"function","title":"Evision.CUDA.Filter.read/1","doc":"","ref":"Evision.CUDA.Filter.html#read/1"},{"type":"function","title":"Evision.CUDA.Filter.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Filter.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.CUDA.Filter.html#read/2"},{"type":"function","title":"Evision.CUDA.Filter.save/1","doc":"","ref":"Evision.CUDA.Filter.html#save/1"},{"type":"function","title":"Evision.CUDA.Filter.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Filter.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.CUDA.Filter.html#save/2"},{"type":"function","title":"Evision.CUDA.Filter.write/1","doc":"","ref":"Evision.CUDA.Filter.html#write/1"},{"type":"function","title":"Evision.CUDA.Filter.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Filter.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.CUDA.Filter.html#write/2"},{"type":"function","title":"Evision.CUDA.Filter.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Filter.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CUDA.Filter.html#write/3"},{"type":"type","title":"Evision.CUDA.Filter.t/0","doc":"Type that represents an `CUDA.Filter` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.Filter.html#t:t/0"},{"type":"module","title":"Evision.CUDA.GpuData","doc":"","ref":"Evision.CUDA.GpuData.html"},{"type":"type","title":"Evision.CUDA.GpuData.t/0","doc":"Type that represents an `CUDA.GpuData` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.GpuData.html#t:t/0"},{"type":"module","title":"Evision.CUDA.GpuMat","doc":"","ref":"Evision.CUDA.GpuMat.html"},{"type":"function","title":"Evision.CUDA.GpuMat.adjustROI/1","doc":"","ref":"Evision.CUDA.GpuMat.html#adjustROI/1"},{"type":"function","title":"Evision.CUDA.GpuMat.adjustROI/5","doc":"adjustROI\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **dtop**: `integer()`\n- **dbottom**: `integer()`\n- **dleft**: `integer()`\n- **dright**: `integer()`\n\n##### Return\n- **retval**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nadjustROI(dtop, dbottom, dleft, dright) -> retval\n```","ref":"Evision.CUDA.GpuMat.html#adjustROI/5"},{"type":"function","title":"Evision.CUDA.GpuMat.assignTo/1","doc":"","ref":"Evision.CUDA.GpuMat.html#assignTo/1"},{"type":"function","title":"Evision.CUDA.GpuMat.assignTo/2","doc":"assignTo\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **m**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **type**: `integer()`.\n\nPython prototype (for reference only):\n```python3\nassignTo(m[, type]) -> None\n```","ref":"Evision.CUDA.GpuMat.html#assignTo/2"},{"type":"function","title":"Evision.CUDA.GpuMat.assignTo/3","doc":"assignTo\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **m**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **type**: `integer()`.\n\nPython prototype (for reference only):\n```python3\nassignTo(m[, type]) -> None\n```","ref":"Evision.CUDA.GpuMat.html#assignTo/3"},{"type":"function","title":"Evision.CUDA.GpuMat.channels/1","doc":"channels\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nchannels() -> retval\n```","ref":"Evision.CUDA.GpuMat.html#channels/1"},{"type":"function","title":"Evision.CUDA.GpuMat.clone/1","doc":"clone\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n\n##### Return\n- **retval**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nclone() -> retval\n```","ref":"Evision.CUDA.GpuMat.html#clone/1"},{"type":"function","title":"Evision.CUDA.GpuMat.col/1","doc":"","ref":"Evision.CUDA.GpuMat.html#col/1"},{"type":"function","title":"Evision.CUDA.GpuMat.col/2","doc":"col\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **x**: `integer()`\n\n##### Return\n- **retval**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\ncol(x) -> retval\n```","ref":"Evision.CUDA.GpuMat.html#col/2"},{"type":"function","title":"Evision.CUDA.GpuMat.colRange/1","doc":"","ref":"Evision.CUDA.GpuMat.html#colRange/1"},{"type":"function","title":"Evision.CUDA.GpuMat.colRange/2","doc":"colRange\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **r**: `Range`\n\n##### Return\n- **retval**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\ncolRange(r) -> retval\n```","ref":"Evision.CUDA.GpuMat.html#colRange/2"},{"type":"function","title":"Evision.CUDA.GpuMat.colRange/3","doc":"colRange\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **startcol**: `integer()`\n- **endcol**: `integer()`\n\n##### Return\n- **retval**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\ncolRange(startcol, endcol) -> retval\n```","ref":"Evision.CUDA.GpuMat.html#colRange/3"},{"type":"function","title":"Evision.CUDA.GpuMat.convertTo/1","doc":"","ref":"Evision.CUDA.GpuMat.html#convertTo/1"},{"type":"function","title":"Evision.CUDA.GpuMat.convertTo/2","doc":"convertTo\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **rtype**: `integer()`\n\n##### Keyword Arguments\n- **alpha**: `double`.\n- **beta**: `double`.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\nconvertTo(rtype[, dst[, alpha[, beta]]]) -> dst\n```","ref":"Evision.CUDA.GpuMat.html#convertTo/2"},{"type":"function","title":"Evision.CUDA.GpuMat.convertTo/3","doc":"#### Variant 1:\nconvertTo\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **rtype**: `integer()`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\nconvertTo(rtype, stream[, dst]) -> dst\n```\n#### Variant 2:\nconvertTo\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **rtype**: `integer()`\n\n##### Keyword Arguments\n- **alpha**: `double`.\n- **beta**: `double`.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\nconvertTo(rtype[, dst[, alpha[, beta]]]) -> dst\n```","ref":"Evision.CUDA.GpuMat.html#convertTo/3"},{"type":"function","title":"Evision.CUDA.GpuMat.convertTo/4","doc":"convertTo\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **rtype**: `integer()`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\nconvertTo(rtype, stream[, dst]) -> dst\n```","ref":"Evision.CUDA.GpuMat.html#convertTo/4"},{"type":"function","title":"Evision.CUDA.GpuMat.convertTo/5","doc":"convertTo\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **rtype**: `integer()`\n- **alpha**: `double`\n- **beta**: `double`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\nconvertTo(rtype, alpha, beta, stream[, dst]) -> dst\n```","ref":"Evision.CUDA.GpuMat.html#convertTo/5"},{"type":"function","title":"Evision.CUDA.GpuMat.convertTo/6","doc":"convertTo\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **rtype**: `integer()`\n- **alpha**: `double`\n- **beta**: `double`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\nconvertTo(rtype, alpha, beta, stream[, dst]) -> dst\n```","ref":"Evision.CUDA.GpuMat.html#convertTo/6"},{"type":"function","title":"Evision.CUDA.GpuMat.copyTo/1","doc":"copyTo\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\ncopyTo([, dst]) -> dst\n```","ref":"Evision.CUDA.GpuMat.html#copyTo/1"},{"type":"function","title":"Evision.CUDA.GpuMat.copyTo/2","doc":"#### Variant 1:\ncopyTo\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **mask**: `Evision.CUDA.GpuMat.t()`\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\ncopyTo(mask[, dst]) -> dst\n```\n#### Variant 2:\ncopyTo\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\ncopyTo(stream[, dst]) -> dst\n```\n#### Variant 3:\ncopyTo\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\ncopyTo([, dst]) -> dst\n```","ref":"Evision.CUDA.GpuMat.html#copyTo/2"},{"type":"function","title":"Evision.CUDA.GpuMat.copyTo/3","doc":"#### Variant 1:\ncopyTo\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **mask**: `Evision.CUDA.GpuMat.t()`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\ncopyTo(mask, stream[, dst]) -> dst\n```\n#### Variant 2:\ncopyTo\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **mask**: `Evision.CUDA.GpuMat.t()`\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\ncopyTo(mask[, dst]) -> dst\n```\n#### Variant 3:\ncopyTo\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\ncopyTo(stream[, dst]) -> dst\n```","ref":"Evision.CUDA.GpuMat.html#copyTo/3"},{"type":"function","title":"Evision.CUDA.GpuMat.copyTo/4","doc":"copyTo\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **mask**: `Evision.CUDA.GpuMat.t()`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\ncopyTo(mask, stream[, dst]) -> dst\n```","ref":"Evision.CUDA.GpuMat.html#copyTo/4"},{"type":"function","title":"Evision.CUDA.GpuMat.create/1","doc":"","ref":"Evision.CUDA.GpuMat.html#create/1"},{"type":"function","title":"Evision.CUDA.GpuMat.create/3","doc":"create\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **size**: `Size`\n- **type**: `integer()`\n\nPython prototype (for reference only):\n```python3\ncreate(size, type) -> None\n```","ref":"Evision.CUDA.GpuMat.html#create/3"},{"type":"function","title":"Evision.CUDA.GpuMat.create/4","doc":"create\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **rows**: `integer()`\n- **cols**: `integer()`\n- **type**: `integer()`\n\nPython prototype (for reference only):\n```python3\ncreate(rows, cols, type) -> None\n```","ref":"Evision.CUDA.GpuMat.html#create/4"},{"type":"function","title":"Evision.CUDA.GpuMat.cudaPtr/1","doc":"cudaPtr\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n\n##### Return\n- **retval**: `void*`\n\nPython prototype (for reference only):\n```python3\ncudaPtr() -> retval\n```","ref":"Evision.CUDA.GpuMat.html#cudaPtr/1"},{"type":"function","title":"Evision.CUDA.GpuMat.defaultAllocator/0","doc":"defaultAllocator\n##### Return\n- **retval**: `GpuMat::Allocator*`\n\nPython prototype (for reference only):\n```python3\ndefaultAllocator() -> retval\n```","ref":"Evision.CUDA.GpuMat.html#defaultAllocator/0"},{"type":"function","title":"Evision.CUDA.GpuMat.defaultAllocator/1","doc":"","ref":"Evision.CUDA.GpuMat.html#defaultAllocator/1"},{"type":"function","title":"Evision.CUDA.GpuMat.depth/1","doc":"depth\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndepth() -> retval\n```","ref":"Evision.CUDA.GpuMat.html#depth/1"},{"type":"function","title":"Evision.CUDA.GpuMat.download/1","doc":"Performs data download from GpuMat (Blocking call)\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nThis function copies data from device memory to host memory. As being a blocking call, it is\nguaranteed that the copy operation is finished when this function returns.\n\nPython prototype (for reference only):\n```python3\ndownload([, dst]) -> dst\n```","ref":"Evision.CUDA.GpuMat.html#download/1"},{"type":"function","title":"Evision.CUDA.GpuMat.download/2","doc":"#### Variant 1:\nPerforms data download from GpuMat (Non-Blocking call)\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nThis function copies data from device memory to host memory. As being a non-blocking call, this\nfunction may return even if the copy operation is not finished.\nThe copy operation may be overlapped with operations in other non-default streams if \\p stream is\nnot the default stream and \\p dst is HostMem allocated with HostMem::PAGE_LOCKED option.\n\nPython prototype (for reference only):\n```python3\ndownload(stream[, dst]) -> dst\n```\n#### Variant 2:\nPerforms data download from GpuMat (Blocking call)\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nThis function copies data from device memory to host memory. As being a blocking call, it is\nguaranteed that the copy operation is finished when this function returns.\n\nPython prototype (for reference only):\n```python3\ndownload([, dst]) -> dst\n```","ref":"Evision.CUDA.GpuMat.html#download/2"},{"type":"function","title":"Evision.CUDA.GpuMat.download/3","doc":"Performs data download from GpuMat (Non-Blocking call)\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nThis function copies data from device memory to host memory. As being a non-blocking call, this\nfunction may return even if the copy operation is not finished.\nThe copy operation may be overlapped with operations in other non-default streams if \\p stream is\nnot the default stream and \\p dst is HostMem allocated with HostMem::PAGE_LOCKED option.\n\nPython prototype (for reference only):\n```python3\ndownload(stream[, dst]) -> dst\n```","ref":"Evision.CUDA.GpuMat.html#download/3"},{"type":"function","title":"Evision.CUDA.GpuMat.elemSize1/1","doc":"elemSize1\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nelemSize1() -> retval\n```","ref":"Evision.CUDA.GpuMat.html#elemSize1/1"},{"type":"function","title":"Evision.CUDA.GpuMat.elemSize/1","doc":"elemSize\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nelemSize() -> retval\n```","ref":"Evision.CUDA.GpuMat.html#elemSize/1"},{"type":"function","title":"Evision.CUDA.GpuMat.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CUDA.GpuMat.html#empty/1"},{"type":"function","title":"Evision.CUDA.GpuMat.from_pointer/2","doc":"Create CUDA GpuMat from a shared CUDA device pointer with new shape\n\n##### Positional Arguments\n\n- **handle**, either an `%Evision.IPCHandle.Local{}` or an `%Evision.IPCHandle.CUDA{}`.\n\n- **new_shape**, `tuple()`\n\n  The shape of the shared image. It's expected to be either\n  \n  - `{height, width, channels}`, for any 2D image that has 1 or multiple channels\n  - `{height, width}`, for any 1-channel 2D image\n  - `{rows}`","ref":"Evision.CUDA.GpuMat.html#from_pointer/2"},{"type":"function","title":"Evision.CUDA.GpuMat.from_pointer/4","doc":"Create CUDA GpuMat from a shared CUDA device pointer\n\n##### Positional Arguments\n\n- **device_pointer**, `list(integer())`.\n\n  This can be either a local pointer or an IPC pointer.\n  \n  However, please note that IPC pointers have to be generated from \n  another OS process (Erlang process doesn't count).\n\n- **dtype**, `tuple() | atom()`\n\n  Data type.\n  \n- **shape**, `tuple()`\n\n  The shape of the shared image. It's expected to be either\n  \n  - `{height, width, channels}`, for any 2D image that has 1 or multiple channels\n  - `{height, width}`, for any 1-channel 2D image\n  - `{rows}`\n  \n##### Keyword Arguments\n\n- **device_id**, `non_neg_integer`. \n\n  GPU Device ID, default to `0`.","ref":"Evision.CUDA.GpuMat.html#from_pointer/4"},{"type":"function","title":"Evision.CUDA.GpuMat.get_step/1","doc":"","ref":"Evision.CUDA.GpuMat.html#get_step/1"},{"type":"function","title":"Evision.CUDA.GpuMat.gpuMat/0","doc":"GpuMat\n##### Keyword Arguments\n- **allocator**: `GpuMat_Allocator*`.\n\n##### Return\n- **self**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nGpuMat([, allocator]) ->  \n```","ref":"Evision.CUDA.GpuMat.html#gpuMat/0"},{"type":"function","title":"Evision.CUDA.GpuMat.gpuMat/1","doc":"#### Variant 1:\nGpuMat\n\n##### Positional Arguments\n- **arr**: `Evision.Mat`\n\n##### Keyword Arguments\n- **allocator**: `GpuMat_Allocator*`.\n\n##### Return\n- **self**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nGpuMat(arr[, allocator]) ->  \n```\n#### Variant 2:\nGpuMat\n\n##### Positional Arguments\n- **arr**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **allocator**: `GpuMat_Allocator*`.\n\n##### Return\n- **self**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nGpuMat(arr[, allocator]) ->  \n```\n#### Variant 3:\nGpuMat\n\n##### Positional Arguments\n- **m**: `Evision.CUDA.GpuMat.t()`\n\n##### Return\n- **self**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nGpuMat(m) ->  \n```\n#### Variant 4:\nGpuMat\n##### Keyword Arguments\n- **allocator**: `GpuMat_Allocator*`.\n\n##### Return\n- **self**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nGpuMat([, allocator]) ->  \n```","ref":"Evision.CUDA.GpuMat.html#gpuMat/1"},{"type":"function","title":"Evision.CUDA.GpuMat.gpuMat/2","doc":"#### Variant 1:\nGpuMat\n\n##### Positional Arguments\n- **m**: `Evision.CUDA.GpuMat.t()`\n- **roi**: `Rect`\n\n##### Return\n- **self**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nGpuMat(m, roi) ->  \n```\n#### Variant 2:\nGpuMat\n\n##### Positional Arguments\n- **size**: `Size`\n- **type**: `integer()`\n\n##### Keyword Arguments\n- **allocator**: `GpuMat_Allocator*`.\n\n##### Return\n- **self**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nGpuMat(size, type[, allocator]) ->  \n```\n#### Variant 3:\nGpuMat\n\n##### Positional Arguments\n- **arr**: `Evision.Mat`\n\n##### Keyword Arguments\n- **allocator**: `GpuMat_Allocator*`.\n\n##### Return\n- **self**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nGpuMat(arr[, allocator]) ->  \n```\n#### Variant 4:\nGpuMat\n\n##### Positional Arguments\n- **arr**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **allocator**: `GpuMat_Allocator*`.\n\n##### Return\n- **self**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nGpuMat(arr[, allocator]) ->  \n```","ref":"Evision.CUDA.GpuMat.html#gpuMat/2"},{"type":"function","title":"Evision.CUDA.GpuMat.gpuMat/3","doc":"#### Variant 1:\nGpuMat\n\n##### Positional Arguments\n- **m**: `Evision.CUDA.GpuMat.t()`\n- **rowRange**: `Range`\n- **colRange**: `Range`\n\n##### Return\n- **self**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nGpuMat(m, rowRange, colRange) ->  \n```\n#### Variant 2:\nGpuMat\n\n##### Positional Arguments\n- **size**: `Size`\n- **type**: `integer()`\n- **s**: `Evision.scalar()`\n\n##### Keyword Arguments\n- **allocator**: `GpuMat_Allocator*`.\n\n##### Return\n- **self**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nGpuMat(size, type, s[, allocator]) ->  \n```\n#### Variant 3:\nGpuMat\n\n##### Positional Arguments\n- **rows**: `integer()`\n- **cols**: `integer()`\n- **type**: `integer()`\n\n##### Keyword Arguments\n- **allocator**: `GpuMat_Allocator*`.\n\n##### Return\n- **self**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nGpuMat(rows, cols, type[, allocator]) ->  \n```\n#### Variant 4:\nGpuMat\n\n##### Positional Arguments\n- **size**: `Size`\n- **type**: `integer()`\n\n##### Keyword Arguments\n- **allocator**: `GpuMat_Allocator*`.\n\n##### Return\n- **self**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nGpuMat(size, type[, allocator]) ->  \n```","ref":"Evision.CUDA.GpuMat.html#gpuMat/3"},{"type":"function","title":"Evision.CUDA.GpuMat.gpuMat/4","doc":"#### Variant 1:\nGpuMat\n\n##### Positional Arguments\n- **rows**: `integer()`\n- **cols**: `integer()`\n- **type**: `integer()`\n- **s**: `Evision.scalar()`\n\n##### Keyword Arguments\n- **allocator**: `GpuMat_Allocator*`.\n\n##### Return\n- **self**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nGpuMat(rows, cols, type, s[, allocator]) ->  \n```\n#### Variant 2:\nGpuMat\n\n##### Positional Arguments\n- **size**: `Size`\n- **type**: `integer()`\n- **s**: `Evision.scalar()`\n\n##### Keyword Arguments\n- **allocator**: `GpuMat_Allocator*`.\n\n##### Return\n- **self**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nGpuMat(size, type, s[, allocator]) ->  \n```\n#### Variant 3:\nGpuMat\n\n##### Positional Arguments\n- **rows**: `integer()`\n- **cols**: `integer()`\n- **type**: `integer()`\n\n##### Keyword Arguments\n- **allocator**: `GpuMat_Allocator*`.\n\n##### Return\n- **self**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nGpuMat(rows, cols, type[, allocator]) ->  \n```","ref":"Evision.CUDA.GpuMat.html#gpuMat/4"},{"type":"function","title":"Evision.CUDA.GpuMat.gpuMat/5","doc":"GpuMat\n\n##### Positional Arguments\n- **rows**: `integer()`\n- **cols**: `integer()`\n- **type**: `integer()`\n- **s**: `Evision.scalar()`\n\n##### Keyword Arguments\n- **allocator**: `GpuMat_Allocator*`.\n\n##### Return\n- **self**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nGpuMat(rows, cols, type, s[, allocator]) ->  \n```","ref":"Evision.CUDA.GpuMat.html#gpuMat/5"},{"type":"function","title":"Evision.CUDA.GpuMat.isContinuous/1","doc":"isContinuous\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisContinuous() -> retval\n```","ref":"Evision.CUDA.GpuMat.html#isContinuous/1"},{"type":"function","title":"Evision.CUDA.GpuMat.locateROI/1","doc":"","ref":"Evision.CUDA.GpuMat.html#locateROI/1"},{"type":"function","title":"Evision.CUDA.GpuMat.locateROI/3","doc":"locateROI\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **wholeSize**: `Size`\n- **ofs**: `Point`\n\nPython prototype (for reference only):\n```python3\nlocateROI(wholeSize, ofs) -> None\n```","ref":"Evision.CUDA.GpuMat.html#locateROI/3"},{"type":"function","title":"Evision.CUDA.GpuMat.release/1","doc":"release\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nrelease() -> None\n```","ref":"Evision.CUDA.GpuMat.html#release/1"},{"type":"function","title":"Evision.CUDA.GpuMat.reshape/1","doc":"","ref":"Evision.CUDA.GpuMat.html#reshape/1"},{"type":"function","title":"Evision.CUDA.GpuMat.reshape/2","doc":"reshape\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **cn**: `integer()`\n\n##### Keyword Arguments\n- **rows**: `integer()`.\n\n##### Return\n- **retval**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nreshape(cn[, rows]) -> retval\n```","ref":"Evision.CUDA.GpuMat.html#reshape/2"},{"type":"function","title":"Evision.CUDA.GpuMat.reshape/3","doc":"reshape\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **cn**: `integer()`\n\n##### Keyword Arguments\n- **rows**: `integer()`.\n\n##### Return\n- **retval**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nreshape(cn[, rows]) -> retval\n```","ref":"Evision.CUDA.GpuMat.html#reshape/3"},{"type":"function","title":"Evision.CUDA.GpuMat.row/1","doc":"","ref":"Evision.CUDA.GpuMat.html#row/1"},{"type":"function","title":"Evision.CUDA.GpuMat.row/2","doc":"row\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **y**: `integer()`\n\n##### Return\n- **retval**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nrow(y) -> retval\n```","ref":"Evision.CUDA.GpuMat.html#row/2"},{"type":"function","title":"Evision.CUDA.GpuMat.rowRange/1","doc":"","ref":"Evision.CUDA.GpuMat.html#rowRange/1"},{"type":"function","title":"Evision.CUDA.GpuMat.rowRange/2","doc":"rowRange\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **r**: `Range`\n\n##### Return\n- **retval**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nrowRange(r) -> retval\n```","ref":"Evision.CUDA.GpuMat.html#rowRange/2"},{"type":"function","title":"Evision.CUDA.GpuMat.rowRange/3","doc":"rowRange\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **startrow**: `integer()`\n- **endrow**: `integer()`\n\n##### Return\n- **retval**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nrowRange(startrow, endrow) -> retval\n```","ref":"Evision.CUDA.GpuMat.html#rowRange/3"},{"type":"function","title":"Evision.CUDA.GpuMat.setDefaultAllocator/1","doc":"setDefaultAllocator\n\n##### Positional Arguments\n- **allocator**: `GpuMat_Allocator*`\n\nPython prototype (for reference only):\n```python3\nsetDefaultAllocator(allocator) -> None\n```","ref":"Evision.CUDA.GpuMat.html#setDefaultAllocator/1"},{"type":"function","title":"Evision.CUDA.GpuMat.setTo/1","doc":"","ref":"Evision.CUDA.GpuMat.html#setTo/1"},{"type":"function","title":"Evision.CUDA.GpuMat.setTo/2","doc":"setTo\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **s**: `Evision.scalar()`\n\n##### Return\n- **retval**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nsetTo(s) -> retval\n```","ref":"Evision.CUDA.GpuMat.html#setTo/2"},{"type":"function","title":"Evision.CUDA.GpuMat.setTo/3","doc":"#### Variant 1:\nsetTo\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **s**: `Evision.scalar()`\n- **mask**: `Evision.Mat`\n\n##### Return\n- **retval**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nsetTo(s, mask) -> retval\n```\n#### Variant 2:\nsetTo\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **s**: `Evision.scalar()`\n- **mask**: `Evision.CUDA.GpuMat.t()`\n\n##### Return\n- **retval**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nsetTo(s, mask) -> retval\n```\n#### Variant 3:\nsetTo\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **s**: `Evision.scalar()`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **retval**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nsetTo(s, stream) -> retval\n```","ref":"Evision.CUDA.GpuMat.html#setTo/3"},{"type":"function","title":"Evision.CUDA.GpuMat.setTo/4","doc":"#### Variant 1:\nsetTo\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **s**: `Evision.scalar()`\n- **mask**: `Evision.Mat`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **retval**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nsetTo(s, mask, stream) -> retval\n```\n#### Variant 2:\nsetTo\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **s**: `Evision.scalar()`\n- **mask**: `Evision.CUDA.GpuMat.t()`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **retval**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nsetTo(s, mask, stream) -> retval\n```","ref":"Evision.CUDA.GpuMat.html#setTo/4"},{"type":"function","title":"Evision.CUDA.GpuMat.size/1","doc":"size\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n\n##### Return\n- **retval**: `Size`\n\nPython prototype (for reference only):\n```python3\nsize() -> retval\n```","ref":"Evision.CUDA.GpuMat.html#size/1"},{"type":"function","title":"Evision.CUDA.GpuMat.step1/1","doc":"step1\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nstep1() -> retval\n```","ref":"Evision.CUDA.GpuMat.html#step1/1"},{"type":"function","title":"Evision.CUDA.GpuMat.swap/1","doc":"","ref":"Evision.CUDA.GpuMat.html#swap/1"},{"type":"function","title":"Evision.CUDA.GpuMat.swap/2","doc":"swap\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **mat**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nswap(mat) -> None\n```","ref":"Evision.CUDA.GpuMat.html#swap/2"},{"type":"function","title":"Evision.CUDA.GpuMat.to_pointer/1","doc":"Get raw pointers\n\n##### Positional Arguments\n\n- **self**. `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n\n- **mode**, one of `:local`, `:cuda_ipc`.\n\n  - `:local`: Get a local CUDA pointer that can be used within current OS process.\n  - `:cuda_ipc`: Get a CUDA IPC pointer that can be used across OS processes.\n  - `:host_ipc`: Get a host IPC pointer that can be used across OS processes.\n\n  Defaults to `:local`.","ref":"Evision.CUDA.GpuMat.html#to_pointer/1"},{"type":"function","title":"Evision.CUDA.GpuMat.to_pointer/2","doc":"","ref":"Evision.CUDA.GpuMat.html#to_pointer/2"},{"type":"function","title":"Evision.CUDA.GpuMat.type/1","doc":"type\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ntype() -> retval\n```","ref":"Evision.CUDA.GpuMat.html#type/1"},{"type":"function","title":"Evision.CUDA.GpuMat.updateContinuityFlag/1","doc":"updateContinuityFlag\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nupdateContinuityFlag() -> None\n```","ref":"Evision.CUDA.GpuMat.html#updateContinuityFlag/1"},{"type":"function","title":"Evision.CUDA.GpuMat.upload/1","doc":"","ref":"Evision.CUDA.GpuMat.html#upload/1"},{"type":"function","title":"Evision.CUDA.GpuMat.upload/2","doc":"#### Variant 1:\nPerforms data upload to GpuMat (Blocking call)\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **arr**: `Evision.Mat`\n\nThis function copies data from host memory to device memory. As being a blocking call, it is\nguaranteed that the copy operation is finished when this function returns.\n\nPython prototype (for reference only):\n```python3\nupload(arr) -> None\n```\n#### Variant 2:\nPerforms data upload to GpuMat (Blocking call)\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **arr**: `Evision.CUDA.GpuMat.t()`\n\nThis function copies data from host memory to device memory. As being a blocking call, it is\nguaranteed that the copy operation is finished when this function returns.\n\nPython prototype (for reference only):\n```python3\nupload(arr) -> None\n```","ref":"Evision.CUDA.GpuMat.html#upload/2"},{"type":"function","title":"Evision.CUDA.GpuMat.upload/3","doc":"#### Variant 1:\nPerforms data upload to GpuMat (Non-Blocking call)\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **arr**: `Evision.Mat`\n- **stream**: `Evision.CUDA.Stream.t()`\n\nThis function copies data from host memory to device memory. As being a non-blocking call, this\nfunction may return even if the copy operation is not finished.\nThe copy operation may be overlapped with operations in other non-default streams if \\p stream is\nnot the default stream and \\p dst is HostMem allocated with HostMem::PAGE_LOCKED option.\n\nPython prototype (for reference only):\n```python3\nupload(arr, stream) -> None\n```\n#### Variant 2:\nPerforms data upload to GpuMat (Non-Blocking call)\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.GpuMat.t()`\n- **arr**: `Evision.CUDA.GpuMat.t()`\n- **stream**: `Evision.CUDA.Stream.t()`\n\nThis function copies data from host memory to device memory. As being a non-blocking call, this\nfunction may return even if the copy operation is not finished.\nThe copy operation may be overlapped with operations in other non-default streams if \\p stream is\nnot the default stream and \\p dst is HostMem allocated with HostMem::PAGE_LOCKED option.\n\nPython prototype (for reference only):\n```python3\nupload(arr, stream) -> None\n```","ref":"Evision.CUDA.GpuMat.html#upload/3"},{"type":"type","title":"Evision.CUDA.GpuMat.t/0","doc":"Type that represents an `Evision.CUDA.GpuMat` struct.\n\n- **channels**: `int`.\n\n  The number of matrix channels.\n\n- **type**: `Evision.Mat.mat_type()`.\n\n  Type of the matrix elements, following `:nx`'s convention.\n\n- **raw_type**: `int`.\n\n  The raw value returned from `int cv::Mat::type()`.\n\n- **shape**: `tuple`.\n\n  The shape of the matrix.\n\n- **elemSize**: `integer()`.\n\n  Element size in bytes.\n  \n- **step**: `integer()`.\n\n  Number of bytes between two consecutive rows.\n  \n  When there are no gaps between successive rows, the value of `step` \n  is equal to the number of columns times the element size.\n  \n- **device_id**: `integer() | nil`.\n\n  `nil` if currently there's no GPU memory allocated for the GpuMat resource.\n\n- **ref**: `reference`.\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.GpuMat.html#t:t/0"},{"type":"module","title":"Evision.CUDA.GpuMat.Allocator","doc":"","ref":"Evision.CUDA.GpuMat.Allocator.html"},{"type":"type","title":"Evision.CUDA.GpuMat.Allocator.t/0","doc":"Type that represents an `CUDA.GpuMat.Allocator` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.GpuMat.Allocator.html#t:t/0"},{"type":"module","title":"Evision.CUDA.GpuMatND","doc":"","ref":"Evision.CUDA.GpuMatND.html"},{"type":"type","title":"Evision.CUDA.GpuMatND.t/0","doc":"Type that represents an `CUDA.GpuMatND` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.GpuMatND.html#t:t/0"},{"type":"module","title":"Evision.CUDA.HOG","doc":"","ref":"Evision.CUDA.HOG.html"},{"type":"function","title":"Evision.CUDA.HOG.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.CUDA.HOG.html#clear/1"},{"type":"function","title":"Evision.CUDA.HOG.compute/1","doc":"","ref":"Evision.CUDA.HOG.html#compute/1"},{"type":"function","title":"Evision.CUDA.HOG.compute/2","doc":"#### Variant 1:\nReturns block descriptors computed for the whole image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **img**: `Evision.Mat`.\n\n  Source image. See cuda::HOGDescriptor::detect for type limitations.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **descriptors**: `Evision.Mat.t()`.\n\n  2D array of descriptors.\n\nPython prototype (for reference only):\n```python3\ncompute(img[, descriptors[, stream]]) -> descriptors\n```\n#### Variant 2:\nReturns block descriptors computed for the whole image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **img**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. See cuda::HOGDescriptor::detect for type limitations.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **descriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  2D array of descriptors.\n\nPython prototype (for reference only):\n```python3\ncompute(img[, descriptors[, stream]]) -> descriptors\n```","ref":"Evision.CUDA.HOG.html#compute/2"},{"type":"function","title":"Evision.CUDA.HOG.compute/3","doc":"#### Variant 1:\nReturns block descriptors computed for the whole image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **img**: `Evision.Mat`.\n\n  Source image. See cuda::HOGDescriptor::detect for type limitations.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **descriptors**: `Evision.Mat.t()`.\n\n  2D array of descriptors.\n\nPython prototype (for reference only):\n```python3\ncompute(img[, descriptors[, stream]]) -> descriptors\n```\n#### Variant 2:\nReturns block descriptors computed for the whole image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **img**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. See cuda::HOGDescriptor::detect for type limitations.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **descriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  2D array of descriptors.\n\nPython prototype (for reference only):\n```python3\ncompute(img[, descriptors[, stream]]) -> descriptors\n```","ref":"Evision.CUDA.HOG.html#compute/3"},{"type":"function","title":"Evision.CUDA.HOG.create/0","doc":"Creates the HOG descriptor and detector.\n##### Keyword Arguments\n- **win_size**: `Size`.\n\n  Detection window size. Align to block size and block stride.\n\n- **block_size**: `Size`.\n\n  Block size in pixels. Align to cell size. Only (16,16) is supported for now.\n\n- **block_stride**: `Size`.\n\n  Block stride. It must be a multiple of cell size.\n\n- **cell_size**: `Size`.\n\n  Cell size. Only (8, 8) is supported for now.\n\n- **nbins**: `integer()`.\n\n  Number of bins. Only 9 bins per cell are supported for now.\n\n##### Return\n- **retval**: `HOG`\n\nPython prototype (for reference only):\n```python3\ncreate([, win_size[, block_size[, block_stride[, cell_size[, nbins]]]]]) -> retval\n```","ref":"Evision.CUDA.HOG.html#create/0"},{"type":"function","title":"Evision.CUDA.HOG.create/1","doc":"Creates the HOG descriptor and detector.\n##### Keyword Arguments\n- **win_size**: `Size`.\n\n  Detection window size. Align to block size and block stride.\n\n- **block_size**: `Size`.\n\n  Block size in pixels. Align to cell size. Only (16,16) is supported for now.\n\n- **block_stride**: `Size`.\n\n  Block stride. It must be a multiple of cell size.\n\n- **cell_size**: `Size`.\n\n  Cell size. Only (8, 8) is supported for now.\n\n- **nbins**: `integer()`.\n\n  Number of bins. Only 9 bins per cell are supported for now.\n\n##### Return\n- **retval**: `HOG`\n\nPython prototype (for reference only):\n```python3\ncreate([, win_size[, block_size[, block_stride[, cell_size[, nbins]]]]]) -> retval\n```","ref":"Evision.CUDA.HOG.html#create/1"},{"type":"function","title":"Evision.CUDA.HOG.detect/1","doc":"","ref":"Evision.CUDA.HOG.html#detect/1"},{"type":"function","title":"Evision.CUDA.HOG.detect/2","doc":"#### Variant 1:\nPerforms object detection without a multi-scale window.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **img**: `Evision.Mat`.\n\n  Source image. CV_8UC1 and CV_8UC4 types are supported for now.\n\n##### Return\n- **found_locations**: `[Point]`.\n\n  Left-top corner points of detected objects boundaries.\n\n- **confidences**: `[double]`.\n\n  Optional output array for confidences.\n\nPython prototype (for reference only):\n```python3\ndetect(img) -> found_locations, confidences\n```\n#### Variant 2:\nPerforms object detection without a multi-scale window.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **img**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. CV_8UC1 and CV_8UC4 types are supported for now.\n\n##### Return\n- **found_locations**: `[Point]`.\n\n  Left-top corner points of detected objects boundaries.\n\n- **confidences**: `[double]`.\n\n  Optional output array for confidences.\n\nPython prototype (for reference only):\n```python3\ndetect(img) -> found_locations, confidences\n```","ref":"Evision.CUDA.HOG.html#detect/2"},{"type":"function","title":"Evision.CUDA.HOG.detectMultiScale/1","doc":"","ref":"Evision.CUDA.HOG.html#detectMultiScale/1"},{"type":"function","title":"Evision.CUDA.HOG.detectMultiScale/2","doc":"#### Variant 1:\nPerforms object detection with a multi-scale window.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **img**: `Evision.Mat`.\n\n  Source image. See cuda::HOGDescriptor::detect for type limitations.\n\n##### Return\n- **found_locations**: `[Rect]`.\n\n  Detected objects boundaries.\n\n- **confidences**: `[double]`.\n\n  Optional output array for confidences.\n\nPython prototype (for reference only):\n```python3\ndetectMultiScale(img) -> found_locations, confidences\n```\n#### Variant 2:\nPerforms object detection with a multi-scale window.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **img**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. See cuda::HOGDescriptor::detect for type limitations.\n\n##### Return\n- **found_locations**: `[Rect]`.\n\n  Detected objects boundaries.\n\n- **confidences**: `[double]`.\n\n  Optional output array for confidences.\n\nPython prototype (for reference only):\n```python3\ndetectMultiScale(img) -> found_locations, confidences\n```","ref":"Evision.CUDA.HOG.html#detectMultiScale/2"},{"type":"function","title":"Evision.CUDA.HOG.detectMultiScaleWithoutConf/1","doc":"","ref":"Evision.CUDA.HOG.html#detectMultiScaleWithoutConf/1"},{"type":"function","title":"Evision.CUDA.HOG.detectMultiScaleWithoutConf/2","doc":"#### Variant 1:\nPerforms object detection with a multi-scale window.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **img**: `Evision.Mat`.\n\n  Source image. See cuda::HOGDescriptor::detect for type limitations.\n\n##### Return\n- **found_locations**: `[Rect]`.\n\n  Detected objects boundaries.\n\nPython prototype (for reference only):\n```python3\ndetectMultiScaleWithoutConf(img) -> found_locations\n```\n#### Variant 2:\nPerforms object detection with a multi-scale window.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **img**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. See cuda::HOGDescriptor::detect for type limitations.\n\n##### Return\n- **found_locations**: `[Rect]`.\n\n  Detected objects boundaries.\n\nPython prototype (for reference only):\n```python3\ndetectMultiScaleWithoutConf(img) -> found_locations\n```","ref":"Evision.CUDA.HOG.html#detectMultiScaleWithoutConf/2"},{"type":"function","title":"Evision.CUDA.HOG.detectWithoutConf/1","doc":"","ref":"Evision.CUDA.HOG.html#detectWithoutConf/1"},{"type":"function","title":"Evision.CUDA.HOG.detectWithoutConf/2","doc":"#### Variant 1:\nPerforms object detection without a multi-scale window.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **img**: `Evision.Mat`.\n\n  Source image. CV_8UC1 and CV_8UC4 types are supported for now.\n\n##### Return\n- **found_locations**: `[Point]`.\n\n  Left-top corner points of detected objects boundaries.\n\nPython prototype (for reference only):\n```python3\ndetectWithoutConf(img) -> found_locations\n```\n#### Variant 2:\nPerforms object detection without a multi-scale window.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **img**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image. CV_8UC1 and CV_8UC4 types are supported for now.\n\n##### Return\n- **found_locations**: `[Point]`.\n\n  Left-top corner points of detected objects boundaries.\n\nPython prototype (for reference only):\n```python3\ndetectWithoutConf(img) -> found_locations\n```","ref":"Evision.CUDA.HOG.html#detectWithoutConf/2"},{"type":"function","title":"Evision.CUDA.HOG.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CUDA.HOG.html#empty/1"},{"type":"function","title":"Evision.CUDA.HOG.getBlockHistogramSize/1","doc":"Returns the block histogram size.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\ngetBlockHistogramSize() -> retval\n```","ref":"Evision.CUDA.HOG.html#getBlockHistogramSize/1"},{"type":"function","title":"Evision.CUDA.HOG.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CUDA.HOG.html#getDefaultName/1"},{"type":"function","title":"Evision.CUDA.HOG.getDefaultPeopleDetector/1","doc":"Returns coefficients of the classifier trained for people detection.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetDefaultPeopleDetector() -> retval\n```","ref":"Evision.CUDA.HOG.html#getDefaultPeopleDetector/1"},{"type":"function","title":"Evision.CUDA.HOG.getDescriptorFormat/1","doc":"getDescriptorFormat\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n\n##### Return\n- **retval**: `HOGDescriptor::DescriptorStorageFormat`\n\nPython prototype (for reference only):\n```python3\ngetDescriptorFormat() -> retval\n```","ref":"Evision.CUDA.HOG.html#getDescriptorFormat/1"},{"type":"function","title":"Evision.CUDA.HOG.getDescriptorSize/1","doc":"Returns the number of coefficients required for the classification.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\ngetDescriptorSize() -> retval\n```","ref":"Evision.CUDA.HOG.html#getDescriptorSize/1"},{"type":"function","title":"Evision.CUDA.HOG.getGammaCorrection/1","doc":"getGammaCorrection\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetGammaCorrection() -> retval\n```","ref":"Evision.CUDA.HOG.html#getGammaCorrection/1"},{"type":"function","title":"Evision.CUDA.HOG.getGroupThreshold/1","doc":"getGroupThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetGroupThreshold() -> retval\n```","ref":"Evision.CUDA.HOG.html#getGroupThreshold/1"},{"type":"function","title":"Evision.CUDA.HOG.getHitThreshold/1","doc":"getHitThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetHitThreshold() -> retval\n```","ref":"Evision.CUDA.HOG.html#getHitThreshold/1"},{"type":"function","title":"Evision.CUDA.HOG.getL2HysThreshold/1","doc":"getL2HysThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetL2HysThreshold() -> retval\n```","ref":"Evision.CUDA.HOG.html#getL2HysThreshold/1"},{"type":"function","title":"Evision.CUDA.HOG.getNumLevels/1","doc":"getNumLevels\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNumLevels() -> retval\n```","ref":"Evision.CUDA.HOG.html#getNumLevels/1"},{"type":"function","title":"Evision.CUDA.HOG.getScaleFactor/1","doc":"getScaleFactor\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetScaleFactor() -> retval\n```","ref":"Evision.CUDA.HOG.html#getScaleFactor/1"},{"type":"function","title":"Evision.CUDA.HOG.getWinSigma/1","doc":"getWinSigma\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetWinSigma() -> retval\n```","ref":"Evision.CUDA.HOG.html#getWinSigma/1"},{"type":"function","title":"Evision.CUDA.HOG.getWinStride/1","doc":"getWinStride\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n\n##### Return\n- **retval**: `Size`\n\nPython prototype (for reference only):\n```python3\ngetWinStride() -> retval\n```","ref":"Evision.CUDA.HOG.html#getWinStride/1"},{"type":"function","title":"Evision.CUDA.HOG.read/1","doc":"","ref":"Evision.CUDA.HOG.html#read/1"},{"type":"function","title":"Evision.CUDA.HOG.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.CUDA.HOG.html#read/2"},{"type":"function","title":"Evision.CUDA.HOG.save/1","doc":"","ref":"Evision.CUDA.HOG.html#save/1"},{"type":"function","title":"Evision.CUDA.HOG.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.CUDA.HOG.html#save/2"},{"type":"function","title":"Evision.CUDA.HOG.setDescriptorFormat/1","doc":"","ref":"Evision.CUDA.HOG.html#setDescriptorFormat/1"},{"type":"function","title":"Evision.CUDA.HOG.setDescriptorFormat/2","doc":"setDescriptorFormat\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **descr_format**: `HOGDescriptor_DescriptorStorageFormat`\n\nPython prototype (for reference only):\n```python3\nsetDescriptorFormat(descr_format) -> None\n```","ref":"Evision.CUDA.HOG.html#setDescriptorFormat/2"},{"type":"function","title":"Evision.CUDA.HOG.setGammaCorrection/1","doc":"","ref":"Evision.CUDA.HOG.html#setGammaCorrection/1"},{"type":"function","title":"Evision.CUDA.HOG.setGammaCorrection/2","doc":"setGammaCorrection\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **gamma_correction**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetGammaCorrection(gamma_correction) -> None\n```","ref":"Evision.CUDA.HOG.html#setGammaCorrection/2"},{"type":"function","title":"Evision.CUDA.HOG.setGroupThreshold/1","doc":"","ref":"Evision.CUDA.HOG.html#setGroupThreshold/1"},{"type":"function","title":"Evision.CUDA.HOG.setGroupThreshold/2","doc":"setGroupThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **group_threshold**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetGroupThreshold(group_threshold) -> None\n```","ref":"Evision.CUDA.HOG.html#setGroupThreshold/2"},{"type":"function","title":"Evision.CUDA.HOG.setHitThreshold/1","doc":"","ref":"Evision.CUDA.HOG.html#setHitThreshold/1"},{"type":"function","title":"Evision.CUDA.HOG.setHitThreshold/2","doc":"setHitThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **hit_threshold**: `double`\n\nPython prototype (for reference only):\n```python3\nsetHitThreshold(hit_threshold) -> None\n```","ref":"Evision.CUDA.HOG.html#setHitThreshold/2"},{"type":"function","title":"Evision.CUDA.HOG.setL2HysThreshold/1","doc":"","ref":"Evision.CUDA.HOG.html#setL2HysThreshold/1"},{"type":"function","title":"Evision.CUDA.HOG.setL2HysThreshold/2","doc":"setL2HysThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **threshold_L2hys**: `double`\n\nPython prototype (for reference only):\n```python3\nsetL2HysThreshold(threshold_L2hys) -> None\n```","ref":"Evision.CUDA.HOG.html#setL2HysThreshold/2"},{"type":"function","title":"Evision.CUDA.HOG.setNumLevels/1","doc":"","ref":"Evision.CUDA.HOG.html#setNumLevels/1"},{"type":"function","title":"Evision.CUDA.HOG.setNumLevels/2","doc":"setNumLevels\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **nlevels**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNumLevels(nlevels) -> None\n```","ref":"Evision.CUDA.HOG.html#setNumLevels/2"},{"type":"function","title":"Evision.CUDA.HOG.setScaleFactor/1","doc":"","ref":"Evision.CUDA.HOG.html#setScaleFactor/1"},{"type":"function","title":"Evision.CUDA.HOG.setScaleFactor/2","doc":"setScaleFactor\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **scale0**: `double`\n\nPython prototype (for reference only):\n```python3\nsetScaleFactor(scale0) -> None\n```","ref":"Evision.CUDA.HOG.html#setScaleFactor/2"},{"type":"function","title":"Evision.CUDA.HOG.setSVMDetector/1","doc":"","ref":"Evision.CUDA.HOG.html#setSVMDetector/1"},{"type":"function","title":"Evision.CUDA.HOG.setSVMDetector/2","doc":"#### Variant 1:\nSets coefficients for the linear SVM classifier.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **detector**: `Evision.Mat`\n\nPython prototype (for reference only):\n```python3\nsetSVMDetector(detector) -> None\n```\n#### Variant 2:\nSets coefficients for the linear SVM classifier.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **detector**: `Evision.CUDA.GpuMat.t()`\n\nPython prototype (for reference only):\n```python3\nsetSVMDetector(detector) -> None\n```","ref":"Evision.CUDA.HOG.html#setSVMDetector/2"},{"type":"function","title":"Evision.CUDA.HOG.setWinSigma/1","doc":"","ref":"Evision.CUDA.HOG.html#setWinSigma/1"},{"type":"function","title":"Evision.CUDA.HOG.setWinSigma/2","doc":"setWinSigma\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **win_sigma**: `double`\n\nPython prototype (for reference only):\n```python3\nsetWinSigma(win_sigma) -> None\n```","ref":"Evision.CUDA.HOG.html#setWinSigma/2"},{"type":"function","title":"Evision.CUDA.HOG.setWinStride/1","doc":"","ref":"Evision.CUDA.HOG.html#setWinStride/1"},{"type":"function","title":"Evision.CUDA.HOG.setWinStride/2","doc":"setWinStride\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **win_stride**: `Size`\n\nPython prototype (for reference only):\n```python3\nsetWinStride(win_stride) -> None\n```","ref":"Evision.CUDA.HOG.html#setWinStride/2"},{"type":"function","title":"Evision.CUDA.HOG.write/1","doc":"","ref":"Evision.CUDA.HOG.html#write/1"},{"type":"function","title":"Evision.CUDA.HOG.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.CUDA.HOG.html#write/2"},{"type":"function","title":"Evision.CUDA.HOG.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HOG.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CUDA.HOG.html#write/3"},{"type":"type","title":"Evision.CUDA.HOG.t/0","doc":"Type that represents an `CUDA.HOG` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.HOG.html#t:t/0"},{"type":"module","title":"Evision.CUDA.HostMem","doc":"","ref":"Evision.CUDA.HostMem.html"},{"type":"function","title":"Evision.CUDA.HostMem.channels/1","doc":"channels\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HostMem.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nchannels() -> retval\n```","ref":"Evision.CUDA.HostMem.html#channels/1"},{"type":"function","title":"Evision.CUDA.HostMem.clone/1","doc":"clone\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HostMem.t()`\n\n##### Return\n- **retval**: `Evision.CUDA.HostMem.t()`\n\nPython prototype (for reference only):\n```python3\nclone() -> retval\n```","ref":"Evision.CUDA.HostMem.html#clone/1"},{"type":"function","title":"Evision.CUDA.HostMem.create/1","doc":"","ref":"Evision.CUDA.HostMem.html#create/1"},{"type":"function","title":"Evision.CUDA.HostMem.create/4","doc":"create\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HostMem.t()`\n- **rows**: `integer()`\n- **cols**: `integer()`\n- **type**: `integer()`\n\nPython prototype (for reference only):\n```python3\ncreate(rows, cols, type) -> None\n```","ref":"Evision.CUDA.HostMem.html#create/4"},{"type":"function","title":"Evision.CUDA.HostMem.createMatHeader/1","doc":"createMatHeader\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HostMem.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ncreateMatHeader() -> retval\n```","ref":"Evision.CUDA.HostMem.html#createMatHeader/1"},{"type":"function","title":"Evision.CUDA.HostMem.depth/1","doc":"depth\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HostMem.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndepth() -> retval\n```","ref":"Evision.CUDA.HostMem.html#depth/1"},{"type":"function","title":"Evision.CUDA.HostMem.elemSize1/1","doc":"elemSize1\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HostMem.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nelemSize1() -> retval\n```","ref":"Evision.CUDA.HostMem.html#elemSize1/1"},{"type":"function","title":"Evision.CUDA.HostMem.elemSize/1","doc":"elemSize\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HostMem.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nelemSize() -> retval\n```","ref":"Evision.CUDA.HostMem.html#elemSize/1"},{"type":"function","title":"Evision.CUDA.HostMem.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HostMem.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CUDA.HostMem.html#empty/1"},{"type":"function","title":"Evision.CUDA.HostMem.get_step/1","doc":"","ref":"Evision.CUDA.HostMem.html#get_step/1"},{"type":"function","title":"Evision.CUDA.HostMem.hostMem/0","doc":"HostMem\n##### Keyword Arguments\n- **alloc_type**: `HostMem_AllocType`.\n\n##### Return\n- **self**: `Evision.CUDA.HostMem.t()`\n\nPython prototype (for reference only):\n```python3\nHostMem([, alloc_type]) ->  \n```","ref":"Evision.CUDA.HostMem.html#hostMem/0"},{"type":"function","title":"Evision.CUDA.HostMem.hostMem/1","doc":"#### Variant 1:\nHostMem\n\n##### Positional Arguments\n- **arr**: `Evision.Mat`\n\n##### Keyword Arguments\n- **alloc_type**: `HostMem_AllocType`.\n\n##### Return\n- **self**: `Evision.CUDA.HostMem.t()`\n\nPython prototype (for reference only):\n```python3\nHostMem(arr[, alloc_type]) ->  \n```\n#### Variant 2:\nHostMem\n\n##### Positional Arguments\n- **arr**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **alloc_type**: `HostMem_AllocType`.\n\n##### Return\n- **self**: `Evision.CUDA.HostMem.t()`\n\nPython prototype (for reference only):\n```python3\nHostMem(arr[, alloc_type]) ->  \n```\n#### Variant 3:\nHostMem\n##### Keyword Arguments\n- **alloc_type**: `HostMem_AllocType`.\n\n##### Return\n- **self**: `Evision.CUDA.HostMem.t()`\n\nPython prototype (for reference only):\n```python3\nHostMem([, alloc_type]) ->  \n```","ref":"Evision.CUDA.HostMem.html#hostMem/1"},{"type":"function","title":"Evision.CUDA.HostMem.hostMem/2","doc":"#### Variant 1:\nHostMem\n\n##### Positional Arguments\n- **size**: `Size`\n- **type**: `integer()`\n\n##### Keyword Arguments\n- **alloc_type**: `HostMem_AllocType`.\n\n##### Return\n- **self**: `Evision.CUDA.HostMem.t()`\n\nPython prototype (for reference only):\n```python3\nHostMem(size, type[, alloc_type]) ->  \n```\n#### Variant 2:\nHostMem\n\n##### Positional Arguments\n- **arr**: `Evision.Mat`\n\n##### Keyword Arguments\n- **alloc_type**: `HostMem_AllocType`.\n\n##### Return\n- **self**: `Evision.CUDA.HostMem.t()`\n\nPython prototype (for reference only):\n```python3\nHostMem(arr[, alloc_type]) ->  \n```\n#### Variant 3:\nHostMem\n\n##### Positional Arguments\n- **arr**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **alloc_type**: `HostMem_AllocType`.\n\n##### Return\n- **self**: `Evision.CUDA.HostMem.t()`\n\nPython prototype (for reference only):\n```python3\nHostMem(arr[, alloc_type]) ->  \n```","ref":"Evision.CUDA.HostMem.html#hostMem/2"},{"type":"function","title":"Evision.CUDA.HostMem.hostMem/3","doc":"#### Variant 1:\nHostMem\n\n##### Positional Arguments\n- **rows**: `integer()`\n- **cols**: `integer()`\n- **type**: `integer()`\n\n##### Keyword Arguments\n- **alloc_type**: `HostMem_AllocType`.\n\n##### Return\n- **self**: `Evision.CUDA.HostMem.t()`\n\nPython prototype (for reference only):\n```python3\nHostMem(rows, cols, type[, alloc_type]) ->  \n```\n#### Variant 2:\nHostMem\n\n##### Positional Arguments\n- **size**: `Size`\n- **type**: `integer()`\n\n##### Keyword Arguments\n- **alloc_type**: `HostMem_AllocType`.\n\n##### Return\n- **self**: `Evision.CUDA.HostMem.t()`\n\nPython prototype (for reference only):\n```python3\nHostMem(size, type[, alloc_type]) ->  \n```","ref":"Evision.CUDA.HostMem.html#hostMem/3"},{"type":"function","title":"Evision.CUDA.HostMem.hostMem/4","doc":"HostMem\n\n##### Positional Arguments\n- **rows**: `integer()`\n- **cols**: `integer()`\n- **type**: `integer()`\n\n##### Keyword Arguments\n- **alloc_type**: `HostMem_AllocType`.\n\n##### Return\n- **self**: `Evision.CUDA.HostMem.t()`\n\nPython prototype (for reference only):\n```python3\nHostMem(rows, cols, type[, alloc_type]) ->  \n```","ref":"Evision.CUDA.HostMem.html#hostMem/4"},{"type":"function","title":"Evision.CUDA.HostMem.isContinuous/1","doc":"Maps CPU memory to GPU address space and creates the cuda::GpuMat header without reference counting\nfor it.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HostMem.t()`\n\n##### Return\n- **retval**: `bool`\n\nThis can be done only if memory was allocated with the SHARED flag and if it is supported by the\nhardware. Laptops often share video and CPU memory, so address spaces can be mapped, which\neliminates an extra copy.\n\nPython prototype (for reference only):\n```python3\nisContinuous() -> retval\n```","ref":"Evision.CUDA.HostMem.html#isContinuous/1"},{"type":"function","title":"Evision.CUDA.HostMem.reshape/1","doc":"","ref":"Evision.CUDA.HostMem.html#reshape/1"},{"type":"function","title":"Evision.CUDA.HostMem.reshape/2","doc":"reshape\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HostMem.t()`\n- **cn**: `integer()`\n\n##### Keyword Arguments\n- **rows**: `integer()`.\n\n##### Return\n- **retval**: `Evision.CUDA.HostMem.t()`\n\nPython prototype (for reference only):\n```python3\nreshape(cn[, rows]) -> retval\n```","ref":"Evision.CUDA.HostMem.html#reshape/2"},{"type":"function","title":"Evision.CUDA.HostMem.reshape/3","doc":"reshape\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HostMem.t()`\n- **cn**: `integer()`\n\n##### Keyword Arguments\n- **rows**: `integer()`.\n\n##### Return\n- **retval**: `Evision.CUDA.HostMem.t()`\n\nPython prototype (for reference only):\n```python3\nreshape(cn[, rows]) -> retval\n```","ref":"Evision.CUDA.HostMem.html#reshape/3"},{"type":"function","title":"Evision.CUDA.HostMem.size/1","doc":"size\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HostMem.t()`\n\n##### Return\n- **retval**: `Size`\n\nPython prototype (for reference only):\n```python3\nsize() -> retval\n```","ref":"Evision.CUDA.HostMem.html#size/1"},{"type":"function","title":"Evision.CUDA.HostMem.step1/1","doc":"step1\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HostMem.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nstep1() -> retval\n```","ref":"Evision.CUDA.HostMem.html#step1/1"},{"type":"function","title":"Evision.CUDA.HostMem.swap/1","doc":"","ref":"Evision.CUDA.HostMem.html#swap/1"},{"type":"function","title":"Evision.CUDA.HostMem.swap/2","doc":"swap\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HostMem.t()`\n- **b**: `Evision.CUDA.HostMem.t()`\n\nPython prototype (for reference only):\n```python3\nswap(b) -> None\n```","ref":"Evision.CUDA.HostMem.html#swap/2"},{"type":"function","title":"Evision.CUDA.HostMem.type/1","doc":"type\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HostMem.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ntype() -> retval\n```","ref":"Evision.CUDA.HostMem.html#type/1"},{"type":"type","title":"Evision.CUDA.HostMem.t/0","doc":"Type that represents an `CUDA.HostMem` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.HostMem.html#t:t/0"},{"type":"module","title":"Evision.CUDA.HostMem.AllocType","doc":"","ref":"Evision.CUDA.HostMem.AllocType.html"},{"type":"function","title":"Evision.CUDA.HostMem.AllocType.cv_PAGE_LOCKED/0","doc":"","ref":"Evision.CUDA.HostMem.AllocType.html#cv_PAGE_LOCKED/0"},{"type":"function","title":"Evision.CUDA.HostMem.AllocType.cv_SHARED/0","doc":"","ref":"Evision.CUDA.HostMem.AllocType.html#cv_SHARED/0"},{"type":"function","title":"Evision.CUDA.HostMem.AllocType.cv_WRITE_COMBINED/0","doc":"","ref":"Evision.CUDA.HostMem.AllocType.html#cv_WRITE_COMBINED/0"},{"type":"type","title":"Evision.CUDA.HostMem.AllocType.enum/0","doc":"","ref":"Evision.CUDA.HostMem.AllocType.html#t:enum/0"},{"type":"module","title":"Evision.CUDA.HoughCirclesDetector","doc":"","ref":"Evision.CUDA.HoughCirclesDetector.html"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.CUDA.HoughCirclesDetector.html#clear/1"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.detect/1","doc":"","ref":"Evision.CUDA.HoughCirclesDetector.html#detect/1"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.detect/2","doc":"#### Variant 1:\nFinds circles in a grayscale image using the Hough transform.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n- **src**: `Evision.Mat`.\n\n  8-bit, single-channel grayscale input image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **circles**: `Evision.Mat.t()`.\n\n  Output vector of found circles. Each vector is encoded as a 3-element\n  floating-point vector \\f$(x, y, radius)\\f$ .\n\n@sa HoughCircles\n\nPython prototype (for reference only):\n```python3\ndetect(src[, circles[, stream]]) -> circles\n```\n#### Variant 2:\nFinds circles in a grayscale image using the Hough transform.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  8-bit, single-channel grayscale input image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **circles**: `Evision.CUDA.GpuMat.t()`.\n\n  Output vector of found circles. Each vector is encoded as a 3-element\n  floating-point vector \\f$(x, y, radius)\\f$ .\n\n@sa HoughCircles\n\nPython prototype (for reference only):\n```python3\ndetect(src[, circles[, stream]]) -> circles\n```","ref":"Evision.CUDA.HoughCirclesDetector.html#detect/2"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.detect/3","doc":"#### Variant 1:\nFinds circles in a grayscale image using the Hough transform.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n- **src**: `Evision.Mat`.\n\n  8-bit, single-channel grayscale input image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **circles**: `Evision.Mat.t()`.\n\n  Output vector of found circles. Each vector is encoded as a 3-element\n  floating-point vector \\f$(x, y, radius)\\f$ .\n\n@sa HoughCircles\n\nPython prototype (for reference only):\n```python3\ndetect(src[, circles[, stream]]) -> circles\n```\n#### Variant 2:\nFinds circles in a grayscale image using the Hough transform.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  8-bit, single-channel grayscale input image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **circles**: `Evision.CUDA.GpuMat.t()`.\n\n  Output vector of found circles. Each vector is encoded as a 3-element\n  floating-point vector \\f$(x, y, radius)\\f$ .\n\n@sa HoughCircles\n\nPython prototype (for reference only):\n```python3\ndetect(src[, circles[, stream]]) -> circles\n```","ref":"Evision.CUDA.HoughCirclesDetector.html#detect/3"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CUDA.HoughCirclesDetector.html#empty/1"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.getCannyThreshold/1","doc":"getCannyThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetCannyThreshold() -> retval\n```","ref":"Evision.CUDA.HoughCirclesDetector.html#getCannyThreshold/1"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CUDA.HoughCirclesDetector.html#getDefaultName/1"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.getDp/1","doc":"getDp\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetDp() -> retval\n```","ref":"Evision.CUDA.HoughCirclesDetector.html#getDp/1"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.getMaxCircles/1","doc":"getMaxCircles\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxCircles() -> retval\n```","ref":"Evision.CUDA.HoughCirclesDetector.html#getMaxCircles/1"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.getMaxRadius/1","doc":"getMaxRadius\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxRadius() -> retval\n```","ref":"Evision.CUDA.HoughCirclesDetector.html#getMaxRadius/1"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.getMinDist/1","doc":"getMinDist\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetMinDist() -> retval\n```","ref":"Evision.CUDA.HoughCirclesDetector.html#getMinDist/1"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.getMinRadius/1","doc":"getMinRadius\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMinRadius() -> retval\n```","ref":"Evision.CUDA.HoughCirclesDetector.html#getMinRadius/1"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.getVotesThreshold/1","doc":"getVotesThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetVotesThreshold() -> retval\n```","ref":"Evision.CUDA.HoughCirclesDetector.html#getVotesThreshold/1"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.read/1","doc":"","ref":"Evision.CUDA.HoughCirclesDetector.html#read/1"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.CUDA.HoughCirclesDetector.html#read/2"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.save/1","doc":"","ref":"Evision.CUDA.HoughCirclesDetector.html#save/1"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.CUDA.HoughCirclesDetector.html#save/2"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.setCannyThreshold/1","doc":"","ref":"Evision.CUDA.HoughCirclesDetector.html#setCannyThreshold/1"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.setCannyThreshold/2","doc":"setCannyThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n- **cannyThreshold**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetCannyThreshold(cannyThreshold) -> None\n```","ref":"Evision.CUDA.HoughCirclesDetector.html#setCannyThreshold/2"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.setDp/1","doc":"","ref":"Evision.CUDA.HoughCirclesDetector.html#setDp/1"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.setDp/2","doc":"setDp\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n- **dp**: `float`\n\nPython prototype (for reference only):\n```python3\nsetDp(dp) -> None\n```","ref":"Evision.CUDA.HoughCirclesDetector.html#setDp/2"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.setMaxCircles/1","doc":"","ref":"Evision.CUDA.HoughCirclesDetector.html#setMaxCircles/1"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.setMaxCircles/2","doc":"setMaxCircles\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n- **maxCircles**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxCircles(maxCircles) -> None\n```","ref":"Evision.CUDA.HoughCirclesDetector.html#setMaxCircles/2"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.setMaxRadius/1","doc":"","ref":"Evision.CUDA.HoughCirclesDetector.html#setMaxRadius/1"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.setMaxRadius/2","doc":"setMaxRadius\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n- **maxRadius**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxRadius(maxRadius) -> None\n```","ref":"Evision.CUDA.HoughCirclesDetector.html#setMaxRadius/2"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.setMinDist/1","doc":"","ref":"Evision.CUDA.HoughCirclesDetector.html#setMinDist/1"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.setMinDist/2","doc":"setMinDist\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n- **minDist**: `float`\n\nPython prototype (for reference only):\n```python3\nsetMinDist(minDist) -> None\n```","ref":"Evision.CUDA.HoughCirclesDetector.html#setMinDist/2"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.setMinRadius/1","doc":"","ref":"Evision.CUDA.HoughCirclesDetector.html#setMinRadius/1"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.setMinRadius/2","doc":"setMinRadius\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n- **minRadius**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMinRadius(minRadius) -> None\n```","ref":"Evision.CUDA.HoughCirclesDetector.html#setMinRadius/2"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.setVotesThreshold/1","doc":"","ref":"Evision.CUDA.HoughCirclesDetector.html#setVotesThreshold/1"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.setVotesThreshold/2","doc":"setVotesThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n- **votesThreshold**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetVotesThreshold(votesThreshold) -> None\n```","ref":"Evision.CUDA.HoughCirclesDetector.html#setVotesThreshold/2"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.write/1","doc":"","ref":"Evision.CUDA.HoughCirclesDetector.html#write/1"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.CUDA.HoughCirclesDetector.html#write/2"},{"type":"function","title":"Evision.CUDA.HoughCirclesDetector.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughCirclesDetector.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CUDA.HoughCirclesDetector.html#write/3"},{"type":"type","title":"Evision.CUDA.HoughCirclesDetector.t/0","doc":"Type that represents an `CUDA.HoughCirclesDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.HoughCirclesDetector.html#t:t/0"},{"type":"module","title":"Evision.CUDA.HoughLinesDetector","doc":"","ref":"Evision.CUDA.HoughLinesDetector.html"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.CUDA.HoughLinesDetector.html#clear/1"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.detect/1","doc":"","ref":"Evision.CUDA.HoughLinesDetector.html#detect/1"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.detect/2","doc":"#### Variant 1:\nFinds lines in a binary image using the classical Hough transform.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n- **src**: `Evision.Mat`.\n\n  8-bit, single-channel binary source image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **lines**: `Evision.Mat.t()`.\n\n  Output vector of lines. Each line is represented by a two-element vector\n  \\f$(\\rho, \\theta)\\f$ . \\f$\\rho\\f$ is the distance from the coordinate origin \\f$(0,0)\\f$ (top-left corner of\n  the image). \\f$\\theta\\f$ is the line rotation angle in radians (\n  \\f$0 \\sim \\textrm{vertical line}, \\pi/2 \\sim \\textrm{horizontal line}\\f$ ).\n\n@sa HoughLines\n\nPython prototype (for reference only):\n```python3\ndetect(src[, lines[, stream]]) -> lines\n```\n#### Variant 2:\nFinds lines in a binary image using the classical Hough transform.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  8-bit, single-channel binary source image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **lines**: `Evision.CUDA.GpuMat.t()`.\n\n  Output vector of lines. Each line is represented by a two-element vector\n  \\f$(\\rho, \\theta)\\f$ . \\f$\\rho\\f$ is the distance from the coordinate origin \\f$(0,0)\\f$ (top-left corner of\n  the image). \\f$\\theta\\f$ is the line rotation angle in radians (\n  \\f$0 \\sim \\textrm{vertical line}, \\pi/2 \\sim \\textrm{horizontal line}\\f$ ).\n\n@sa HoughLines\n\nPython prototype (for reference only):\n```python3\ndetect(src[, lines[, stream]]) -> lines\n```","ref":"Evision.CUDA.HoughLinesDetector.html#detect/2"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.detect/3","doc":"#### Variant 1:\nFinds lines in a binary image using the classical Hough transform.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n- **src**: `Evision.Mat`.\n\n  8-bit, single-channel binary source image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **lines**: `Evision.Mat.t()`.\n\n  Output vector of lines. Each line is represented by a two-element vector\n  \\f$(\\rho, \\theta)\\f$ . \\f$\\rho\\f$ is the distance from the coordinate origin \\f$(0,0)\\f$ (top-left corner of\n  the image). \\f$\\theta\\f$ is the line rotation angle in radians (\n  \\f$0 \\sim \\textrm{vertical line}, \\pi/2 \\sim \\textrm{horizontal line}\\f$ ).\n\n@sa HoughLines\n\nPython prototype (for reference only):\n```python3\ndetect(src[, lines[, stream]]) -> lines\n```\n#### Variant 2:\nFinds lines in a binary image using the classical Hough transform.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  8-bit, single-channel binary source image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **lines**: `Evision.CUDA.GpuMat.t()`.\n\n  Output vector of lines. Each line is represented by a two-element vector\n  \\f$(\\rho, \\theta)\\f$ . \\f$\\rho\\f$ is the distance from the coordinate origin \\f$(0,0)\\f$ (top-left corner of\n  the image). \\f$\\theta\\f$ is the line rotation angle in radians (\n  \\f$0 \\sim \\textrm{vertical line}, \\pi/2 \\sim \\textrm{horizontal line}\\f$ ).\n\n@sa HoughLines\n\nPython prototype (for reference only):\n```python3\ndetect(src[, lines[, stream]]) -> lines\n```","ref":"Evision.CUDA.HoughLinesDetector.html#detect/3"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.downloadResults/1","doc":"","ref":"Evision.CUDA.HoughLinesDetector.html#downloadResults/1"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.downloadResults/2","doc":"#### Variant 1:\nDownloads results from cuda::HoughLinesDetector::detect to host memory.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n- **d_lines**: `Evision.Mat`.\n\n  Result of cuda::HoughLinesDetector::detect .\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **h_lines**: `Evision.Mat.t()`.\n\n  Output host array.\n\n- **h_votes**: `Evision.Mat.t()`.\n\n  Optional output array for line's votes.\n\nPython prototype (for reference only):\n```python3\ndownloadResults(d_lines[, h_lines[, h_votes[, stream]]]) -> h_lines, h_votes\n```\n#### Variant 2:\nDownloads results from cuda::HoughLinesDetector::detect to host memory.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n- **d_lines**: `Evision.CUDA.GpuMat.t()`.\n\n  Result of cuda::HoughLinesDetector::detect .\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **h_lines**: `Evision.CUDA.GpuMat.t()`.\n\n  Output host array.\n\n- **h_votes**: `Evision.CUDA.GpuMat.t()`.\n\n  Optional output array for line's votes.\n\nPython prototype (for reference only):\n```python3\ndownloadResults(d_lines[, h_lines[, h_votes[, stream]]]) -> h_lines, h_votes\n```","ref":"Evision.CUDA.HoughLinesDetector.html#downloadResults/2"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.downloadResults/3","doc":"#### Variant 1:\nDownloads results from cuda::HoughLinesDetector::detect to host memory.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n- **d_lines**: `Evision.Mat`.\n\n  Result of cuda::HoughLinesDetector::detect .\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **h_lines**: `Evision.Mat.t()`.\n\n  Output host array.\n\n- **h_votes**: `Evision.Mat.t()`.\n\n  Optional output array for line's votes.\n\nPython prototype (for reference only):\n```python3\ndownloadResults(d_lines[, h_lines[, h_votes[, stream]]]) -> h_lines, h_votes\n```\n#### Variant 2:\nDownloads results from cuda::HoughLinesDetector::detect to host memory.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n- **d_lines**: `Evision.CUDA.GpuMat.t()`.\n\n  Result of cuda::HoughLinesDetector::detect .\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **h_lines**: `Evision.CUDA.GpuMat.t()`.\n\n  Output host array.\n\n- **h_votes**: `Evision.CUDA.GpuMat.t()`.\n\n  Optional output array for line's votes.\n\nPython prototype (for reference only):\n```python3\ndownloadResults(d_lines[, h_lines[, h_votes[, stream]]]) -> h_lines, h_votes\n```","ref":"Evision.CUDA.HoughLinesDetector.html#downloadResults/3"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CUDA.HoughLinesDetector.html#empty/1"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CUDA.HoughLinesDetector.html#getDefaultName/1"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.getDoSort/1","doc":"getDoSort\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetDoSort() -> retval\n```","ref":"Evision.CUDA.HoughLinesDetector.html#getDoSort/1"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.getMaxLines/1","doc":"getMaxLines\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxLines() -> retval\n```","ref":"Evision.CUDA.HoughLinesDetector.html#getMaxLines/1"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.getRho/1","doc":"getRho\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetRho() -> retval\n```","ref":"Evision.CUDA.HoughLinesDetector.html#getRho/1"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.getTheta/1","doc":"getTheta\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetTheta() -> retval\n```","ref":"Evision.CUDA.HoughLinesDetector.html#getTheta/1"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.getThreshold/1","doc":"getThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetThreshold() -> retval\n```","ref":"Evision.CUDA.HoughLinesDetector.html#getThreshold/1"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.read/1","doc":"","ref":"Evision.CUDA.HoughLinesDetector.html#read/1"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.CUDA.HoughLinesDetector.html#read/2"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.save/1","doc":"","ref":"Evision.CUDA.HoughLinesDetector.html#save/1"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.CUDA.HoughLinesDetector.html#save/2"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.setDoSort/1","doc":"","ref":"Evision.CUDA.HoughLinesDetector.html#setDoSort/1"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.setDoSort/2","doc":"setDoSort\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n- **doSort**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetDoSort(doSort) -> None\n```","ref":"Evision.CUDA.HoughLinesDetector.html#setDoSort/2"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.setMaxLines/1","doc":"","ref":"Evision.CUDA.HoughLinesDetector.html#setMaxLines/1"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.setMaxLines/2","doc":"setMaxLines\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n- **maxLines**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxLines(maxLines) -> None\n```","ref":"Evision.CUDA.HoughLinesDetector.html#setMaxLines/2"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.setRho/1","doc":"","ref":"Evision.CUDA.HoughLinesDetector.html#setRho/1"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.setRho/2","doc":"setRho\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n- **rho**: `float`\n\nPython prototype (for reference only):\n```python3\nsetRho(rho) -> None\n```","ref":"Evision.CUDA.HoughLinesDetector.html#setRho/2"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.setTheta/1","doc":"","ref":"Evision.CUDA.HoughLinesDetector.html#setTheta/1"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.setTheta/2","doc":"setTheta\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n- **theta**: `float`\n\nPython prototype (for reference only):\n```python3\nsetTheta(theta) -> None\n```","ref":"Evision.CUDA.HoughLinesDetector.html#setTheta/2"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.setThreshold/1","doc":"","ref":"Evision.CUDA.HoughLinesDetector.html#setThreshold/1"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.setThreshold/2","doc":"setThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n- **threshold**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetThreshold(threshold) -> None\n```","ref":"Evision.CUDA.HoughLinesDetector.html#setThreshold/2"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.write/1","doc":"","ref":"Evision.CUDA.HoughLinesDetector.html#write/1"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.CUDA.HoughLinesDetector.html#write/2"},{"type":"function","title":"Evision.CUDA.HoughLinesDetector.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughLinesDetector.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CUDA.HoughLinesDetector.html#write/3"},{"type":"type","title":"Evision.CUDA.HoughLinesDetector.t/0","doc":"Type that represents an `CUDA.HoughLinesDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.HoughLinesDetector.html#t:t/0"},{"type":"module","title":"Evision.CUDA.HoughSegmentDetector","doc":"","ref":"Evision.CUDA.HoughSegmentDetector.html"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughSegmentDetector.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.CUDA.HoughSegmentDetector.html#clear/1"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.detect/1","doc":"","ref":"Evision.CUDA.HoughSegmentDetector.html#detect/1"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.detect/2","doc":"#### Variant 1:\nFinds line segments in a binary image using the probabilistic Hough transform.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughSegmentDetector.t()`\n- **src**: `Evision.Mat`.\n\n  8-bit, single-channel binary source image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **lines**: `Evision.Mat.t()`.\n\n  Output vector of lines. Each line is represented by a 4-element vector\n  \\f$(x_1, y_1, x_2, y_2)\\f$ , where \\f$(x_1,y_1)\\f$ and \\f$(x_2, y_2)\\f$ are the ending points of each detected\n  line segment.\n\n@sa HoughLinesP\n\nPython prototype (for reference only):\n```python3\ndetect(src[, lines[, stream]]) -> lines\n```\n#### Variant 2:\nFinds line segments in a binary image using the probabilistic Hough transform.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughSegmentDetector.t()`\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  8-bit, single-channel binary source image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **lines**: `Evision.CUDA.GpuMat.t()`.\n\n  Output vector of lines. Each line is represented by a 4-element vector\n  \\f$(x_1, y_1, x_2, y_2)\\f$ , where \\f$(x_1,y_1)\\f$ and \\f$(x_2, y_2)\\f$ are the ending points of each detected\n  line segment.\n\n@sa HoughLinesP\n\nPython prototype (for reference only):\n```python3\ndetect(src[, lines[, stream]]) -> lines\n```","ref":"Evision.CUDA.HoughSegmentDetector.html#detect/2"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.detect/3","doc":"#### Variant 1:\nFinds line segments in a binary image using the probabilistic Hough transform.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughSegmentDetector.t()`\n- **src**: `Evision.Mat`.\n\n  8-bit, single-channel binary source image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **lines**: `Evision.Mat.t()`.\n\n  Output vector of lines. Each line is represented by a 4-element vector\n  \\f$(x_1, y_1, x_2, y_2)\\f$ , where \\f$(x_1,y_1)\\f$ and \\f$(x_2, y_2)\\f$ are the ending points of each detected\n  line segment.\n\n@sa HoughLinesP\n\nPython prototype (for reference only):\n```python3\ndetect(src[, lines[, stream]]) -> lines\n```\n#### Variant 2:\nFinds line segments in a binary image using the probabilistic Hough transform.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughSegmentDetector.t()`\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  8-bit, single-channel binary source image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **lines**: `Evision.CUDA.GpuMat.t()`.\n\n  Output vector of lines. Each line is represented by a 4-element vector\n  \\f$(x_1, y_1, x_2, y_2)\\f$ , where \\f$(x_1,y_1)\\f$ and \\f$(x_2, y_2)\\f$ are the ending points of each detected\n  line segment.\n\n@sa HoughLinesP\n\nPython prototype (for reference only):\n```python3\ndetect(src[, lines[, stream]]) -> lines\n```","ref":"Evision.CUDA.HoughSegmentDetector.html#detect/3"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughSegmentDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CUDA.HoughSegmentDetector.html#empty/1"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughSegmentDetector.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CUDA.HoughSegmentDetector.html#getDefaultName/1"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.getMaxLineGap/1","doc":"getMaxLineGap\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughSegmentDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxLineGap() -> retval\n```","ref":"Evision.CUDA.HoughSegmentDetector.html#getMaxLineGap/1"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.getMaxLines/1","doc":"getMaxLines\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughSegmentDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxLines() -> retval\n```","ref":"Evision.CUDA.HoughSegmentDetector.html#getMaxLines/1"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.getMinLineLength/1","doc":"getMinLineLength\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughSegmentDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMinLineLength() -> retval\n```","ref":"Evision.CUDA.HoughSegmentDetector.html#getMinLineLength/1"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.getRho/1","doc":"getRho\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughSegmentDetector.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetRho() -> retval\n```","ref":"Evision.CUDA.HoughSegmentDetector.html#getRho/1"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.getTheta/1","doc":"getTheta\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughSegmentDetector.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetTheta() -> retval\n```","ref":"Evision.CUDA.HoughSegmentDetector.html#getTheta/1"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.getThreshold/1","doc":"getThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughSegmentDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetThreshold() -> retval\n```","ref":"Evision.CUDA.HoughSegmentDetector.html#getThreshold/1"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.read/1","doc":"","ref":"Evision.CUDA.HoughSegmentDetector.html#read/1"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughSegmentDetector.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.CUDA.HoughSegmentDetector.html#read/2"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.save/1","doc":"","ref":"Evision.CUDA.HoughSegmentDetector.html#save/1"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughSegmentDetector.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.CUDA.HoughSegmentDetector.html#save/2"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.setMaxLineGap/1","doc":"","ref":"Evision.CUDA.HoughSegmentDetector.html#setMaxLineGap/1"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.setMaxLineGap/2","doc":"setMaxLineGap\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughSegmentDetector.t()`\n- **maxLineGap**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxLineGap(maxLineGap) -> None\n```","ref":"Evision.CUDA.HoughSegmentDetector.html#setMaxLineGap/2"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.setMaxLines/1","doc":"","ref":"Evision.CUDA.HoughSegmentDetector.html#setMaxLines/1"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.setMaxLines/2","doc":"setMaxLines\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughSegmentDetector.t()`\n- **maxLines**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxLines(maxLines) -> None\n```","ref":"Evision.CUDA.HoughSegmentDetector.html#setMaxLines/2"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.setMinLineLength/1","doc":"","ref":"Evision.CUDA.HoughSegmentDetector.html#setMinLineLength/1"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.setMinLineLength/2","doc":"setMinLineLength\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughSegmentDetector.t()`\n- **minLineLength**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMinLineLength(minLineLength) -> None\n```","ref":"Evision.CUDA.HoughSegmentDetector.html#setMinLineLength/2"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.setRho/1","doc":"","ref":"Evision.CUDA.HoughSegmentDetector.html#setRho/1"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.setRho/2","doc":"setRho\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughSegmentDetector.t()`\n- **rho**: `float`\n\nPython prototype (for reference only):\n```python3\nsetRho(rho) -> None\n```","ref":"Evision.CUDA.HoughSegmentDetector.html#setRho/2"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.setTheta/1","doc":"","ref":"Evision.CUDA.HoughSegmentDetector.html#setTheta/1"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.setTheta/2","doc":"setTheta\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughSegmentDetector.t()`\n- **theta**: `float`\n\nPython prototype (for reference only):\n```python3\nsetTheta(theta) -> None\n```","ref":"Evision.CUDA.HoughSegmentDetector.html#setTheta/2"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.setThreshold/1","doc":"","ref":"Evision.CUDA.HoughSegmentDetector.html#setThreshold/1"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.setThreshold/2","doc":"setThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughSegmentDetector.t()`\n- **threshold**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetThreshold(threshold) -> None\n```","ref":"Evision.CUDA.HoughSegmentDetector.html#setThreshold/2"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.write/1","doc":"","ref":"Evision.CUDA.HoughSegmentDetector.html#write/1"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughSegmentDetector.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.CUDA.HoughSegmentDetector.html#write/2"},{"type":"function","title":"Evision.CUDA.HoughSegmentDetector.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.HoughSegmentDetector.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CUDA.HoughSegmentDetector.html#write/3"},{"type":"type","title":"Evision.CUDA.HoughSegmentDetector.t/0","doc":"Type that represents an `CUDA.HoughSegmentDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.HoughSegmentDetector.html#t:t/0"},{"type":"module","title":"Evision.CUDA.LookUpTable","doc":"","ref":"Evision.CUDA.LookUpTable.html"},{"type":"function","title":"Evision.CUDA.LookUpTable.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.LookUpTable.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.CUDA.LookUpTable.html#clear/1"},{"type":"function","title":"Evision.CUDA.LookUpTable.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.LookUpTable.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CUDA.LookUpTable.html#empty/1"},{"type":"function","title":"Evision.CUDA.LookUpTable.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.LookUpTable.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CUDA.LookUpTable.html#getDefaultName/1"},{"type":"function","title":"Evision.CUDA.LookUpTable.read/1","doc":"","ref":"Evision.CUDA.LookUpTable.html#read/1"},{"type":"function","title":"Evision.CUDA.LookUpTable.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.LookUpTable.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.CUDA.LookUpTable.html#read/2"},{"type":"function","title":"Evision.CUDA.LookUpTable.save/1","doc":"","ref":"Evision.CUDA.LookUpTable.html#save/1"},{"type":"function","title":"Evision.CUDA.LookUpTable.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.LookUpTable.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.CUDA.LookUpTable.html#save/2"},{"type":"function","title":"Evision.CUDA.LookUpTable.transform/1","doc":"","ref":"Evision.CUDA.LookUpTable.html#transform/1"},{"type":"function","title":"Evision.CUDA.LookUpTable.transform/2","doc":"#### Variant 1:\nTransforms the source matrix into the destination matrix using the given look-up table:\ndst(I) = lut(src(I)) .\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.LookUpTable.t()`\n- **src**: `Evision.Mat`.\n\n  Source matrix. CV_8UC1 and CV_8UC3 matrices are supported for now.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix.\n\nPython prototype (for reference only):\n```python3\ntransform(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nTransforms the source matrix into the destination matrix using the given look-up table:\ndst(I) = lut(src(I)) .\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.LookUpTable.t()`\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix. CV_8UC1 and CV_8UC3 matrices are supported for now.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix.\n\nPython prototype (for reference only):\n```python3\ntransform(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.LookUpTable.html#transform/2"},{"type":"function","title":"Evision.CUDA.LookUpTable.transform/3","doc":"#### Variant 1:\nTransforms the source matrix into the destination matrix using the given look-up table:\ndst(I) = lut(src(I)) .\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.LookUpTable.t()`\n- **src**: `Evision.Mat`.\n\n  Source matrix. CV_8UC1 and CV_8UC3 matrices are supported for now.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination matrix.\n\nPython prototype (for reference only):\n```python3\ntransform(src[, dst[, stream]]) -> dst\n```\n#### Variant 2:\nTransforms the source matrix into the destination matrix using the given look-up table:\ndst(I) = lut(src(I)) .\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.LookUpTable.t()`\n- **src**: `Evision.CUDA.GpuMat.t()`.\n\n  Source matrix. CV_8UC1 and CV_8UC3 matrices are supported for now.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **dst**: `Evision.CUDA.GpuMat.t()`.\n\n  Destination matrix.\n\nPython prototype (for reference only):\n```python3\ntransform(src[, dst[, stream]]) -> dst\n```","ref":"Evision.CUDA.LookUpTable.html#transform/3"},{"type":"function","title":"Evision.CUDA.LookUpTable.write/1","doc":"","ref":"Evision.CUDA.LookUpTable.html#write/1"},{"type":"function","title":"Evision.CUDA.LookUpTable.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.LookUpTable.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.CUDA.LookUpTable.html#write/2"},{"type":"function","title":"Evision.CUDA.LookUpTable.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.LookUpTable.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CUDA.LookUpTable.html#write/3"},{"type":"type","title":"Evision.CUDA.LookUpTable.t/0","doc":"Type that represents an `CUDA.LookUpTable` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.LookUpTable.html#t:t/0"},{"type":"module","title":"Evision.CUDA.MomentsOrder","doc":"","ref":"Evision.CUDA.MomentsOrder.html"},{"type":"function","title":"Evision.CUDA.MomentsOrder.cv_FIRST_ORDER_MOMENTS/0","doc":"","ref":"Evision.CUDA.MomentsOrder.html#cv_FIRST_ORDER_MOMENTS/0"},{"type":"function","title":"Evision.CUDA.MomentsOrder.cv_SECOND_ORDER_MOMENTS/0","doc":"","ref":"Evision.CUDA.MomentsOrder.html#cv_SECOND_ORDER_MOMENTS/0"},{"type":"function","title":"Evision.CUDA.MomentsOrder.cv_THIRD_ORDER_MOMENTS/0","doc":"","ref":"Evision.CUDA.MomentsOrder.html#cv_THIRD_ORDER_MOMENTS/0"},{"type":"type","title":"Evision.CUDA.MomentsOrder.enum/0","doc":"","ref":"Evision.CUDA.MomentsOrder.html#t:enum/0"},{"type":"module","title":"Evision.CUDA.ORB","doc":"","ref":"Evision.CUDA.ORB.html"},{"type":"function","title":"Evision.CUDA.ORB.compute/1","doc":"","ref":"Evision.CUDA.ORB.html#compute/1"},{"type":"function","title":"Evision.CUDA.ORB.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.ORB.html#compute/3"},{"type":"function","title":"Evision.CUDA.ORB.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.ORB.html#compute/4"},{"type":"function","title":"Evision.CUDA.ORB.computeAsync/1","doc":"","ref":"Evision.CUDA.ORB.html#computeAsync/1"},{"type":"function","title":"Evision.CUDA.ORB.computeAsync/2","doc":"#### Variant 1:\nComputes the descriptors for a set of keypoints detected in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.Mat.t()`.\n\n  Input collection of keypoints.\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. Row j is the descriptor for j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncomputeAsync(image[, keypoints[, descriptors[, stream]]]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.CUDA.GpuMat.t()`.\n\n  Input collection of keypoints.\n\n- **descriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Computed descriptors. Row j is the descriptor for j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncomputeAsync(image[, keypoints[, descriptors[, stream]]]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.ORB.html#computeAsync/2"},{"type":"function","title":"Evision.CUDA.ORB.computeAsync/3","doc":"#### Variant 1:\nComputes the descriptors for a set of keypoints detected in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.Mat.t()`.\n\n  Input collection of keypoints.\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. Row j is the descriptor for j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncomputeAsync(image[, keypoints[, descriptors[, stream]]]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Image.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.CUDA.GpuMat.t()`.\n\n  Input collection of keypoints.\n\n- **descriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Computed descriptors. Row j is the descriptor for j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncomputeAsync(image[, keypoints[, descriptors[, stream]]]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.ORB.html#computeAsync/3"},{"type":"function","title":"Evision.CUDA.ORB.convert/1","doc":"","ref":"Evision.CUDA.ORB.html#convert/1"},{"type":"function","title":"Evision.CUDA.ORB.convert/2","doc":"#### Variant 1:\nconvert\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **gpu_keypoints**: `Evision.Mat`\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n\nConverts keypoints array from internal representation to standard vector.\n\nPython prototype (for reference only):\n```python3\nconvert(gpu_keypoints) -> keypoints\n```\n#### Variant 2:\nconvert\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **gpu_keypoints**: `Evision.CUDA.GpuMat.t()`\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n\nConverts keypoints array from internal representation to standard vector.\n\nPython prototype (for reference only):\n```python3\nconvert(gpu_keypoints) -> keypoints\n```","ref":"Evision.CUDA.ORB.html#convert/2"},{"type":"function","title":"Evision.CUDA.ORB.create/0","doc":"create\n##### Keyword Arguments\n- **nfeatures**: `integer()`.\n- **scaleFactor**: `float`.\n- **nlevels**: `integer()`.\n- **edgeThreshold**: `integer()`.\n- **firstLevel**: `integer()`.\n- **wTA_K**: `integer()`.\n- **scoreType**: `integer()`.\n- **patchSize**: `integer()`.\n- **fastThreshold**: `integer()`.\n- **blurForDescriptor**: `bool`.\n\n##### Return\n- **retval**: `Evision.CUDA.ORB.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, nfeatures[, scaleFactor[, nlevels[, edgeThreshold[, firstLevel[, WTA_K[, scoreType[, patchSize[, fastThreshold[, blurForDescriptor]]]]]]]]]]) -> retval\n```","ref":"Evision.CUDA.ORB.html#create/0"},{"type":"function","title":"Evision.CUDA.ORB.create/1","doc":"create\n##### Keyword Arguments\n- **nfeatures**: `integer()`.\n- **scaleFactor**: `float`.\n- **nlevels**: `integer()`.\n- **edgeThreshold**: `integer()`.\n- **firstLevel**: `integer()`.\n- **wTA_K**: `integer()`.\n- **scoreType**: `integer()`.\n- **patchSize**: `integer()`.\n- **fastThreshold**: `integer()`.\n- **blurForDescriptor**: `bool`.\n\n##### Return\n- **retval**: `Evision.CUDA.ORB.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, nfeatures[, scaleFactor[, nlevels[, edgeThreshold[, firstLevel[, WTA_K[, scoreType[, patchSize[, fastThreshold[, blurForDescriptor]]]]]]]]]]) -> retval\n```","ref":"Evision.CUDA.ORB.html#create/1"},{"type":"function","title":"Evision.CUDA.ORB.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.CUDA.ORB.html#defaultNorm/1"},{"type":"function","title":"Evision.CUDA.ORB.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.CUDA.ORB.html#descriptorSize/1"},{"type":"function","title":"Evision.CUDA.ORB.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.CUDA.ORB.html#descriptorType/1"},{"type":"function","title":"Evision.CUDA.ORB.detect/1","doc":"","ref":"Evision.CUDA.ORB.html#detect/1"},{"type":"function","title":"Evision.CUDA.ORB.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.CUDA.ORB.html#detect/2"},{"type":"function","title":"Evision.CUDA.ORB.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.CUDA.ORB.html#detect/3"},{"type":"function","title":"Evision.CUDA.ORB.detectAndCompute/1","doc":"","ref":"Evision.CUDA.ORB.html#detectAndCompute/1"},{"type":"function","title":"Evision.CUDA.ORB.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.ORB.html#detectAndCompute/3"},{"type":"function","title":"Evision.CUDA.ORB.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.ORB.html#detectAndCompute/4"},{"type":"function","title":"Evision.CUDA.ORB.detectAndComputeAsync/1","doc":"","ref":"Evision.CUDA.ORB.html#detectAndComputeAsync/1"},{"type":"function","title":"Evision.CUDA.ORB.detectAndComputeAsync/3","doc":"#### Variant 1:\ndetectAndComputeAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **keypoints**: `Evision.Mat.t()`.\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors.\n\nPython prototype (for reference only):\n```python3\ndetectAndComputeAsync(image, mask[, keypoints[, descriptors[, useProvidedKeypoints[, stream]]]]) -> keypoints, descriptors\n```\n#### Variant 2:\ndetectAndComputeAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`\n- **mask**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **keypoints**: `Evision.CUDA.GpuMat.t()`.\n- **descriptors**: `Evision.CUDA.GpuMat.t()`.\n\nDetects keypoints and computes the descriptors.\n\nPython prototype (for reference only):\n```python3\ndetectAndComputeAsync(image, mask[, keypoints[, descriptors[, useProvidedKeypoints[, stream]]]]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.ORB.html#detectAndComputeAsync/3"},{"type":"function","title":"Evision.CUDA.ORB.detectAndComputeAsync/4","doc":"#### Variant 1:\ndetectAndComputeAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **keypoints**: `Evision.Mat.t()`.\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors.\n\nPython prototype (for reference only):\n```python3\ndetectAndComputeAsync(image, mask[, keypoints[, descriptors[, useProvidedKeypoints[, stream]]]]) -> keypoints, descriptors\n```\n#### Variant 2:\ndetectAndComputeAsync\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`\n- **mask**: `Evision.CUDA.GpuMat.t()`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n##### Return\n- **keypoints**: `Evision.CUDA.GpuMat.t()`.\n- **descriptors**: `Evision.CUDA.GpuMat.t()`.\n\nDetects keypoints and computes the descriptors.\n\nPython prototype (for reference only):\n```python3\ndetectAndComputeAsync(image, mask[, keypoints[, descriptors[, useProvidedKeypoints[, stream]]]]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.ORB.html#detectAndComputeAsync/4"},{"type":"function","title":"Evision.CUDA.ORB.detectAsync/1","doc":"","ref":"Evision.CUDA.ORB.html#detectAsync/1"},{"type":"function","title":"Evision.CUDA.ORB.detectAsync/2","doc":"#### Variant 1:\nDetects keypoints in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.Mat.t()`.\n\n  The detected keypoints.\n\nPython prototype (for reference only):\n```python3\ndetectAsync(image[, keypoints[, mask[, stream]]]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.CUDA.GpuMat.t()`.\n\n  The detected keypoints.\n\nPython prototype (for reference only):\n```python3\ndetectAsync(image[, keypoints[, mask[, stream]]]) -> keypoints\n```","ref":"Evision.CUDA.ORB.html#detectAsync/2"},{"type":"function","title":"Evision.CUDA.ORB.detectAsync/3","doc":"#### Variant 1:\nDetects keypoints in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.Mat.t()`.\n\n  The detected keypoints.\n\nPython prototype (for reference only):\n```python3\ndetectAsync(image[, keypoints[, mask[, stream]]]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  CUDA stream.\n\n##### Return\n- **keypoints**: `Evision.CUDA.GpuMat.t()`.\n\n  The detected keypoints.\n\nPython prototype (for reference only):\n```python3\ndetectAsync(image[, keypoints[, mask[, stream]]]) -> keypoints\n```","ref":"Evision.CUDA.ORB.html#detectAsync/3"},{"type":"function","title":"Evision.CUDA.ORB.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CUDA.ORB.html#empty/1"},{"type":"function","title":"Evision.CUDA.ORB.getBlurForDescriptor/1","doc":"getBlurForDescriptor\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetBlurForDescriptor() -> retval\n```","ref":"Evision.CUDA.ORB.html#getBlurForDescriptor/1"},{"type":"function","title":"Evision.CUDA.ORB.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CUDA.ORB.html#getDefaultName/1"},{"type":"function","title":"Evision.CUDA.ORB.getEdgeThreshold/1","doc":"getEdgeThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetEdgeThreshold() -> retval\n```","ref":"Evision.CUDA.ORB.html#getEdgeThreshold/1"},{"type":"function","title":"Evision.CUDA.ORB.getFastThreshold/1","doc":"getFastThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetFastThreshold() -> retval\n```","ref":"Evision.CUDA.ORB.html#getFastThreshold/1"},{"type":"function","title":"Evision.CUDA.ORB.getFirstLevel/1","doc":"getFirstLevel\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetFirstLevel() -> retval\n```","ref":"Evision.CUDA.ORB.html#getFirstLevel/1"},{"type":"function","title":"Evision.CUDA.ORB.getMaxFeatures/1","doc":"getMaxFeatures\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxFeatures() -> retval\n```","ref":"Evision.CUDA.ORB.html#getMaxFeatures/1"},{"type":"function","title":"Evision.CUDA.ORB.getNLevels/1","doc":"getNLevels\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNLevels() -> retval\n```","ref":"Evision.CUDA.ORB.html#getNLevels/1"},{"type":"function","title":"Evision.CUDA.ORB.getPatchSize/1","doc":"getPatchSize\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetPatchSize() -> retval\n```","ref":"Evision.CUDA.ORB.html#getPatchSize/1"},{"type":"function","title":"Evision.CUDA.ORB.getScaleFactor/1","doc":"getScaleFactor\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetScaleFactor() -> retval\n```","ref":"Evision.CUDA.ORB.html#getScaleFactor/1"},{"type":"function","title":"Evision.CUDA.ORB.getScoreType/1","doc":"getScoreType\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetScoreType() -> retval\n```","ref":"Evision.CUDA.ORB.html#getScoreType/1"},{"type":"function","title":"Evision.CUDA.ORB.getWTA_K/1","doc":"getWTA_K\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetWTA_K() -> retval\n```","ref":"Evision.CUDA.ORB.html#getWTA_K/1"},{"type":"function","title":"Evision.CUDA.ORB.read/1","doc":"","ref":"Evision.CUDA.ORB.html#read/1"},{"type":"function","title":"Evision.CUDA.ORB.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.CUDA.ORB.html#read/2"},{"type":"function","title":"Evision.CUDA.ORB.setBlurForDescriptor/1","doc":"","ref":"Evision.CUDA.ORB.html#setBlurForDescriptor/1"},{"type":"function","title":"Evision.CUDA.ORB.setBlurForDescriptor/2","doc":"setBlurForDescriptor\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **blurForDescriptor**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetBlurForDescriptor(blurForDescriptor) -> None\n```","ref":"Evision.CUDA.ORB.html#setBlurForDescriptor/2"},{"type":"function","title":"Evision.CUDA.ORB.setEdgeThreshold/1","doc":"","ref":"Evision.CUDA.ORB.html#setEdgeThreshold/1"},{"type":"function","title":"Evision.CUDA.ORB.setEdgeThreshold/2","doc":"setEdgeThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **edgeThreshold**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetEdgeThreshold(edgeThreshold) -> None\n```","ref":"Evision.CUDA.ORB.html#setEdgeThreshold/2"},{"type":"function","title":"Evision.CUDA.ORB.setFastThreshold/1","doc":"","ref":"Evision.CUDA.ORB.html#setFastThreshold/1"},{"type":"function","title":"Evision.CUDA.ORB.setFastThreshold/2","doc":"setFastThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **fastThreshold**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetFastThreshold(fastThreshold) -> None\n```","ref":"Evision.CUDA.ORB.html#setFastThreshold/2"},{"type":"function","title":"Evision.CUDA.ORB.setFirstLevel/1","doc":"","ref":"Evision.CUDA.ORB.html#setFirstLevel/1"},{"type":"function","title":"Evision.CUDA.ORB.setFirstLevel/2","doc":"setFirstLevel\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **firstLevel**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetFirstLevel(firstLevel) -> None\n```","ref":"Evision.CUDA.ORB.html#setFirstLevel/2"},{"type":"function","title":"Evision.CUDA.ORB.setMaxFeatures/1","doc":"","ref":"Evision.CUDA.ORB.html#setMaxFeatures/1"},{"type":"function","title":"Evision.CUDA.ORB.setMaxFeatures/2","doc":"setMaxFeatures\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **maxFeatures**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxFeatures(maxFeatures) -> None\n```","ref":"Evision.CUDA.ORB.html#setMaxFeatures/2"},{"type":"function","title":"Evision.CUDA.ORB.setNLevels/1","doc":"","ref":"Evision.CUDA.ORB.html#setNLevels/1"},{"type":"function","title":"Evision.CUDA.ORB.setNLevels/2","doc":"setNLevels\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **nlevels**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNLevels(nlevels) -> None\n```","ref":"Evision.CUDA.ORB.html#setNLevels/2"},{"type":"function","title":"Evision.CUDA.ORB.setPatchSize/1","doc":"","ref":"Evision.CUDA.ORB.html#setPatchSize/1"},{"type":"function","title":"Evision.CUDA.ORB.setPatchSize/2","doc":"setPatchSize\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **patchSize**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetPatchSize(patchSize) -> None\n```","ref":"Evision.CUDA.ORB.html#setPatchSize/2"},{"type":"function","title":"Evision.CUDA.ORB.setScaleFactor/1","doc":"","ref":"Evision.CUDA.ORB.html#setScaleFactor/1"},{"type":"function","title":"Evision.CUDA.ORB.setScaleFactor/2","doc":"setScaleFactor\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **scaleFactor**: `double`\n\nPython prototype (for reference only):\n```python3\nsetScaleFactor(scaleFactor) -> None\n```","ref":"Evision.CUDA.ORB.html#setScaleFactor/2"},{"type":"function","title":"Evision.CUDA.ORB.setScoreType/1","doc":"","ref":"Evision.CUDA.ORB.html#setScoreType/1"},{"type":"function","title":"Evision.CUDA.ORB.setScoreType/2","doc":"setScoreType\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **scoreType**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetScoreType(scoreType) -> None\n```","ref":"Evision.CUDA.ORB.html#setScoreType/2"},{"type":"function","title":"Evision.CUDA.ORB.setWTA_K/1","doc":"","ref":"Evision.CUDA.ORB.html#setWTA_K/1"},{"type":"function","title":"Evision.CUDA.ORB.setWTA_K/2","doc":"setWTA_K\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **wta_k**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetWTA_K(wta_k) -> None\n```","ref":"Evision.CUDA.ORB.html#setWTA_K/2"},{"type":"function","title":"Evision.CUDA.ORB.write/1","doc":"","ref":"Evision.CUDA.ORB.html#write/1"},{"type":"function","title":"Evision.CUDA.ORB.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.CUDA.ORB.html#write/2"},{"type":"function","title":"Evision.CUDA.ORB.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.ORB.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CUDA.ORB.html#write/3"},{"type":"type","title":"Evision.CUDA.ORB.t/0","doc":"Type that represents an `CUDA.ORB` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.ORB.html#t:t/0"},{"type":"module","title":"Evision.CUDA.SURFCUDA","doc":"","ref":"Evision.CUDA.SURFCUDA.html"},{"type":"function","title":"Evision.CUDA.SURFCUDA.create/1","doc":"create\n\n##### Positional Arguments\n- **hessianThreshold**: `double`.\n\n  Threshold for hessian keypoint detector used in SURF.\n\n##### Keyword Arguments\n- **nOctaves**: `integer()`.\n\n  Number of pyramid octaves the keypoint detector will use.\n\n- **nOctaveLayers**: `integer()`.\n\n  Number of octave layers within each octave.\n\n- **extended**: `bool`.\n\n  Extended descriptor flag (true - use extended 128-element descriptors; false - use\n  64-element descriptors).\n\n- **keypointsRatio**: `float`.\n\n  Limits a maximum number of features\n\n- **upright**: `bool`.\n\n  Up-right or rotated features flag (true - do not compute orientation of features;\n  false - compute orientation).\n\n##### Return\n- **retval**: `SURF_CUDA`\n\nPython prototype (for reference only):\n```python3\ncreate(_hessianThreshold[, _nOctaves[, _nOctaveLayers[, _extended[, _keypointsRatio[, _upright]]]]]) -> retval\n```","ref":"Evision.CUDA.SURFCUDA.html#create/1"},{"type":"function","title":"Evision.CUDA.SURFCUDA.create/2","doc":"create\n\n##### Positional Arguments\n- **hessianThreshold**: `double`.\n\n  Threshold for hessian keypoint detector used in SURF.\n\n##### Keyword Arguments\n- **nOctaves**: `integer()`.\n\n  Number of pyramid octaves the keypoint detector will use.\n\n- **nOctaveLayers**: `integer()`.\n\n  Number of octave layers within each octave.\n\n- **extended**: `bool`.\n\n  Extended descriptor flag (true - use extended 128-element descriptors; false - use\n  64-element descriptors).\n\n- **keypointsRatio**: `float`.\n\n  Limits a maximum number of features\n\n- **upright**: `bool`.\n\n  Up-right or rotated features flag (true - do not compute orientation of features;\n  false - compute orientation).\n\n##### Return\n- **retval**: `SURF_CUDA`\n\nPython prototype (for reference only):\n```python3\ncreate(_hessianThreshold[, _nOctaves[, _nOctaveLayers[, _extended[, _keypointsRatio[, _upright]]]]]) -> retval\n```","ref":"Evision.CUDA.SURFCUDA.html#create/2"},{"type":"function","title":"Evision.CUDA.SURFCUDA.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.SURFCUDA.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.CUDA.SURFCUDA.html#defaultNorm/1"},{"type":"function","title":"Evision.CUDA.SURFCUDA.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.SURFCUDA.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.CUDA.SURFCUDA.html#descriptorSize/1"},{"type":"function","title":"Evision.CUDA.SURFCUDA.detect/1","doc":"","ref":"Evision.CUDA.SURFCUDA.html#detect/1"},{"type":"function","title":"Evision.CUDA.SURFCUDA.detect/3","doc":"Finds the keypoints using fast hessian detector used in SURF\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.SURFCUDA.t()`\n- **img**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image, currently supports only CV_8UC1 images.\n\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  A mask image same size as src and of type CV_8UC1.\n\n##### Return\n- **keypoints**: `Evision.CUDA.GpuMat.t()`.\n\n  Detected keypoints.\n\nPython prototype (for reference only):\n```python3\ndetect(img, mask[, keypoints]) -> keypoints\n```","ref":"Evision.CUDA.SURFCUDA.html#detect/3"},{"type":"function","title":"Evision.CUDA.SURFCUDA.detect/4","doc":"Finds the keypoints using fast hessian detector used in SURF\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.SURFCUDA.t()`\n- **img**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image, currently supports only CV_8UC1 images.\n\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  A mask image same size as src and of type CV_8UC1.\n\n##### Return\n- **keypoints**: `Evision.CUDA.GpuMat.t()`.\n\n  Detected keypoints.\n\nPython prototype (for reference only):\n```python3\ndetect(img, mask[, keypoints]) -> keypoints\n```","ref":"Evision.CUDA.SURFCUDA.html#detect/4"},{"type":"function","title":"Evision.CUDA.SURFCUDA.detectWithDescriptors/1","doc":"","ref":"Evision.CUDA.SURFCUDA.html#detectWithDescriptors/1"},{"type":"function","title":"Evision.CUDA.SURFCUDA.detectWithDescriptors/3","doc":"Finds the keypoints and computes their descriptors using fast hessian detector used in SURF\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.SURFCUDA.t()`\n- **img**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image, currently supports only CV_8UC1 images.\n\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  A mask image same size as src and of type CV_8UC1.\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n  Compute descriptors for the user-provided keypoints and recompute keypoints direction.\n\n##### Return\n- **keypoints**: `Evision.CUDA.GpuMat.t()`.\n\n  Detected keypoints.\n\n- **descriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Keypoint descriptors.\n\nPython prototype (for reference only):\n```python3\ndetectWithDescriptors(img, mask[, keypoints[, descriptors[, useProvidedKeypoints]]]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.SURFCUDA.html#detectWithDescriptors/3"},{"type":"function","title":"Evision.CUDA.SURFCUDA.detectWithDescriptors/4","doc":"Finds the keypoints and computes their descriptors using fast hessian detector used in SURF\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.SURFCUDA.t()`\n- **img**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image, currently supports only CV_8UC1 images.\n\n- **mask**: `Evision.CUDA.GpuMat.t()`.\n\n  A mask image same size as src and of type CV_8UC1.\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n  Compute descriptors for the user-provided keypoints and recompute keypoints direction.\n\n##### Return\n- **keypoints**: `Evision.CUDA.GpuMat.t()`.\n\n  Detected keypoints.\n\n- **descriptors**: `Evision.CUDA.GpuMat.t()`.\n\n  Keypoint descriptors.\n\nPython prototype (for reference only):\n```python3\ndetectWithDescriptors(img, mask[, keypoints[, descriptors[, useProvidedKeypoints]]]) -> keypoints, descriptors\n```","ref":"Evision.CUDA.SURFCUDA.html#detectWithDescriptors/4"},{"type":"function","title":"Evision.CUDA.SURFCUDA.downloadKeypoints/1","doc":"","ref":"Evision.CUDA.SURFCUDA.html#downloadKeypoints/1"},{"type":"function","title":"Evision.CUDA.SURFCUDA.downloadKeypoints/2","doc":"downloadKeypoints\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.SURFCUDA.t()`\n- **keypointsGPU**: `Evision.CUDA.GpuMat.t()`\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n\nPython prototype (for reference only):\n```python3\ndownloadKeypoints(keypointsGPU) -> keypoints\n```","ref":"Evision.CUDA.SURFCUDA.html#downloadKeypoints/2"},{"type":"function","title":"Evision.CUDA.SURFCUDA.get_extended/1","doc":"","ref":"Evision.CUDA.SURFCUDA.html#get_extended/1"},{"type":"function","title":"Evision.CUDA.SURFCUDA.get_hessianThreshold/1","doc":"","ref":"Evision.CUDA.SURFCUDA.html#get_hessianThreshold/1"},{"type":"function","title":"Evision.CUDA.SURFCUDA.get_keypointsRatio/1","doc":"","ref":"Evision.CUDA.SURFCUDA.html#get_keypointsRatio/1"},{"type":"function","title":"Evision.CUDA.SURFCUDA.get_nOctaveLayers/1","doc":"","ref":"Evision.CUDA.SURFCUDA.html#get_nOctaveLayers/1"},{"type":"function","title":"Evision.CUDA.SURFCUDA.get_nOctaves/1","doc":"","ref":"Evision.CUDA.SURFCUDA.html#get_nOctaves/1"},{"type":"function","title":"Evision.CUDA.SURFCUDA.get_upright/1","doc":"","ref":"Evision.CUDA.SURFCUDA.html#get_upright/1"},{"type":"type","title":"Evision.CUDA.SURFCUDA.t/0","doc":"Type that represents an `CUDA.SURFCUDA` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.SURFCUDA.html#t:t/0"},{"type":"module","title":"Evision.CUDA.SURF_CUDA.KeypointLayout","doc":"","ref":"Evision.CUDA.SURF_CUDA.KeypointLayout.html"},{"type":"function","title":"Evision.CUDA.SURF_CUDA.KeypointLayout.cv_ANGLE_ROW/0","doc":"","ref":"Evision.CUDA.SURF_CUDA.KeypointLayout.html#cv_ANGLE_ROW/0"},{"type":"function","title":"Evision.CUDA.SURF_CUDA.KeypointLayout.cv_HESSIAN_ROW/0","doc":"","ref":"Evision.CUDA.SURF_CUDA.KeypointLayout.html#cv_HESSIAN_ROW/0"},{"type":"function","title":"Evision.CUDA.SURF_CUDA.KeypointLayout.cv_LAPLACIAN_ROW/0","doc":"","ref":"Evision.CUDA.SURF_CUDA.KeypointLayout.html#cv_LAPLACIAN_ROW/0"},{"type":"function","title":"Evision.CUDA.SURF_CUDA.KeypointLayout.cv_OCTAVE_ROW/0","doc":"","ref":"Evision.CUDA.SURF_CUDA.KeypointLayout.html#cv_OCTAVE_ROW/0"},{"type":"function","title":"Evision.CUDA.SURF_CUDA.KeypointLayout.cv_ROWS_COUNT/0","doc":"","ref":"Evision.CUDA.SURF_CUDA.KeypointLayout.html#cv_ROWS_COUNT/0"},{"type":"function","title":"Evision.CUDA.SURF_CUDA.KeypointLayout.cv_SIZE_ROW/0","doc":"","ref":"Evision.CUDA.SURF_CUDA.KeypointLayout.html#cv_SIZE_ROW/0"},{"type":"function","title":"Evision.CUDA.SURF_CUDA.KeypointLayout.cv_X_ROW/0","doc":"","ref":"Evision.CUDA.SURF_CUDA.KeypointLayout.html#cv_X_ROW/0"},{"type":"function","title":"Evision.CUDA.SURF_CUDA.KeypointLayout.cv_Y_ROW/0","doc":"","ref":"Evision.CUDA.SURF_CUDA.KeypointLayout.html#cv_Y_ROW/0"},{"type":"type","title":"Evision.CUDA.SURF_CUDA.KeypointLayout.enum/0","doc":"","ref":"Evision.CUDA.SURF_CUDA.KeypointLayout.html#t:enum/0"},{"type":"module","title":"Evision.CUDA.StereoBM","doc":"","ref":"Evision.CUDA.StereoBM.html"},{"type":"function","title":"Evision.CUDA.StereoBM.compute/1","doc":"","ref":"Evision.CUDA.StereoBM.html#compute/1"},{"type":"function","title":"Evision.CUDA.StereoBM.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBM.t()`\n- **left**: `Evision.Mat`\n- **right**: `Evision.Mat`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **disparity**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ncompute(left, right, stream[, disparity]) -> disparity\n```\n#### Variant 2:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBM.t()`\n- **left**: `Evision.CUDA.GpuMat.t()`\n- **right**: `Evision.CUDA.GpuMat.t()`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **disparity**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\ncompute(left, right, stream[, disparity]) -> disparity\n```","ref":"Evision.CUDA.StereoBM.html#compute/4"},{"type":"function","title":"Evision.CUDA.StereoBM.compute/5","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBM.t()`\n- **left**: `Evision.Mat`\n- **right**: `Evision.Mat`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **disparity**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ncompute(left, right, stream[, disparity]) -> disparity\n```\n#### Variant 2:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBM.t()`\n- **left**: `Evision.CUDA.GpuMat.t()`\n- **right**: `Evision.CUDA.GpuMat.t()`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **disparity**: `Evision.CUDA.GpuMat.t()`.\n\nPython prototype (for reference only):\n```python3\ncompute(left, right, stream[, disparity]) -> disparity\n```","ref":"Evision.CUDA.StereoBM.html#compute/5"},{"type":"type","title":"Evision.CUDA.StereoBM.t/0","doc":"Type that represents an `CUDA.StereoBM` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.StereoBM.html#t:t/0"},{"type":"module","title":"Evision.CUDA.StereoBeliefPropagation","doc":"","ref":"Evision.CUDA.StereoBeliefPropagation.html"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#clear/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.compute/1","doc":"","ref":"Evision.CUDA.StereoBeliefPropagation.html#compute/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.compute/2","doc":"#### Variant 1:\nEnables the stereo correspondence operator that finds the disparity for the specified data cost.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **data**: `Evision.Mat`.\n\n  User-specified data cost, a matrix of msg_type type and\n  Size(\\ \\*ndisp, \\ ) size.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **disparity**: `Evision.Mat.t()`.\n\n  Output disparity map. If disparity is empty, the output type is CV_16SC1 .\n  Otherwise, the type is retained. In 16-bit signed format, the disparity values do not have\n  fractional bits.\n\nPython prototype (for reference only):\n```python3\ncompute(data[, disparity[, stream]]) -> disparity\n```\n#### Variant 2:\nEnables the stereo correspondence operator that finds the disparity for the specified data cost.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **data**: `Evision.CUDA.GpuMat.t()`.\n\n  User-specified data cost, a matrix of msg_type type and\n  Size(\\ \\*ndisp, \\ ) size.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **disparity**: `Evision.CUDA.GpuMat.t()`.\n\n  Output disparity map. If disparity is empty, the output type is CV_16SC1 .\n  Otherwise, the type is retained. In 16-bit signed format, the disparity values do not have\n  fractional bits.\n\nPython prototype (for reference only):\n```python3\ncompute(data[, disparity[, stream]]) -> disparity\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#compute/2"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.compute/3","doc":"#### Variant 1:\nEnables the stereo correspondence operator that finds the disparity for the specified data cost.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **data**: `Evision.Mat`.\n\n  User-specified data cost, a matrix of msg_type type and\n  Size(\\ \\*ndisp, \\ ) size.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **disparity**: `Evision.Mat.t()`.\n\n  Output disparity map. If disparity is empty, the output type is CV_16SC1 .\n  Otherwise, the type is retained. In 16-bit signed format, the disparity values do not have\n  fractional bits.\n\nPython prototype (for reference only):\n```python3\ncompute(data[, disparity[, stream]]) -> disparity\n```\n#### Variant 2:\nEnables the stereo correspondence operator that finds the disparity for the specified data cost.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **data**: `Evision.CUDA.GpuMat.t()`.\n\n  User-specified data cost, a matrix of msg_type type and\n  Size(\\ \\*ndisp, \\ ) size.\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **disparity**: `Evision.CUDA.GpuMat.t()`.\n\n  Output disparity map. If disparity is empty, the output type is CV_16SC1 .\n  Otherwise, the type is retained. In 16-bit signed format, the disparity values do not have\n  fractional bits.\n\nPython prototype (for reference only):\n```python3\ncompute(data[, disparity[, stream]]) -> disparity\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#compute/3"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **left**: `Evision.Mat`\n- **right**: `Evision.Mat`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **disparity**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(left, right, stream[, disparity]) -> disparity\n```\n#### Variant 2:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **left**: `Evision.CUDA.GpuMat.t()`\n- **right**: `Evision.CUDA.GpuMat.t()`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **disparity**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(left, right, stream[, disparity]) -> disparity\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#compute/4"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.compute/5","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **left**: `Evision.Mat`\n- **right**: `Evision.Mat`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **disparity**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(left, right, stream[, disparity]) -> disparity\n```\n#### Variant 2:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **left**: `Evision.CUDA.GpuMat.t()`\n- **right**: `Evision.CUDA.GpuMat.t()`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **disparity**: `Evision.CUDA.GpuMat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(left, right, stream[, disparity]) -> disparity\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#compute/5"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#empty/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.estimateRecommendedParams/1","doc":"","ref":"Evision.CUDA.StereoBeliefPropagation.html#estimateRecommendedParams/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.estimateRecommendedParams/5","doc":"Uses a heuristic method to compute the recommended parameters ( ndisp, iters and levels ) for the\nspecified image size ( width and height ).\n\n##### Positional Arguments\n- **width**: `integer()`\n- **height**: `integer()`\n- **ndisp**: `integer()`\n- **iters**: `integer()`\n- **levels**: `integer()`\n\nPython prototype (for reference only):\n```python3\nestimateRecommendedParams(width, height, ndisp, iters, levels) -> None\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#estimateRecommendedParams/5"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.getBlockSize/1","doc":"getBlockSize\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetBlockSize() -> retval\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#getBlockSize/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.getDataWeight/1","doc":"getDataWeight\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetDataWeight() -> retval\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#getDataWeight/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#getDefaultName/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.getDiscSingleJump/1","doc":"getDiscSingleJump\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetDiscSingleJump() -> retval\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#getDiscSingleJump/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.getDisp12MaxDiff/1","doc":"getDisp12MaxDiff\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetDisp12MaxDiff() -> retval\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#getDisp12MaxDiff/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.getMaxDataTerm/1","doc":"getMaxDataTerm\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxDataTerm() -> retval\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#getMaxDataTerm/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.getMaxDiscTerm/1","doc":"getMaxDiscTerm\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxDiscTerm() -> retval\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#getMaxDiscTerm/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.getMinDisparity/1","doc":"getMinDisparity\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMinDisparity() -> retval\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#getMinDisparity/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.getMsgType/1","doc":"getMsgType\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMsgType() -> retval\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#getMsgType/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.getNumDisparities/1","doc":"getNumDisparities\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNumDisparities() -> retval\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#getNumDisparities/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.getNumIters/1","doc":"getNumIters\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNumIters() -> retval\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#getNumIters/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.getNumLevels/1","doc":"getNumLevels\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNumLevels() -> retval\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#getNumLevels/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.getSpeckleRange/1","doc":"getSpeckleRange\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetSpeckleRange() -> retval\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#getSpeckleRange/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.getSpeckleWindowSize/1","doc":"getSpeckleWindowSize\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetSpeckleWindowSize() -> retval\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#getSpeckleWindowSize/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.read/1","doc":"","ref":"Evision.CUDA.StereoBeliefPropagation.html#read/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#read/2"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.save/1","doc":"","ref":"Evision.CUDA.StereoBeliefPropagation.html#save/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#save/2"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setBlockSize/1","doc":"","ref":"Evision.CUDA.StereoBeliefPropagation.html#setBlockSize/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setBlockSize/2","doc":"setBlockSize\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **blockSize**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetBlockSize(blockSize) -> None\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#setBlockSize/2"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setDataWeight/1","doc":"","ref":"Evision.CUDA.StereoBeliefPropagation.html#setDataWeight/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setDataWeight/2","doc":"setDataWeight\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **data_weight**: `double`\n\nPython prototype (for reference only):\n```python3\nsetDataWeight(data_weight) -> None\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#setDataWeight/2"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setDiscSingleJump/1","doc":"","ref":"Evision.CUDA.StereoBeliefPropagation.html#setDiscSingleJump/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setDiscSingleJump/2","doc":"setDiscSingleJump\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **disc_single_jump**: `double`\n\nPython prototype (for reference only):\n```python3\nsetDiscSingleJump(disc_single_jump) -> None\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#setDiscSingleJump/2"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setDisp12MaxDiff/1","doc":"","ref":"Evision.CUDA.StereoBeliefPropagation.html#setDisp12MaxDiff/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setDisp12MaxDiff/2","doc":"setDisp12MaxDiff\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **disp12MaxDiff**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetDisp12MaxDiff(disp12MaxDiff) -> None\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#setDisp12MaxDiff/2"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setMaxDataTerm/1","doc":"","ref":"Evision.CUDA.StereoBeliefPropagation.html#setMaxDataTerm/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setMaxDataTerm/2","doc":"setMaxDataTerm\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **max_data_term**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxDataTerm(max_data_term) -> None\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#setMaxDataTerm/2"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setMaxDiscTerm/1","doc":"","ref":"Evision.CUDA.StereoBeliefPropagation.html#setMaxDiscTerm/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setMaxDiscTerm/2","doc":"setMaxDiscTerm\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **max_disc_term**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxDiscTerm(max_disc_term) -> None\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#setMaxDiscTerm/2"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setMinDisparity/1","doc":"","ref":"Evision.CUDA.StereoBeliefPropagation.html#setMinDisparity/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setMinDisparity/2","doc":"setMinDisparity\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **minDisparity**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMinDisparity(minDisparity) -> None\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#setMinDisparity/2"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setMsgType/1","doc":"","ref":"Evision.CUDA.StereoBeliefPropagation.html#setMsgType/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setMsgType/2","doc":"setMsgType\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **msg_type**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMsgType(msg_type) -> None\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#setMsgType/2"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setNumDisparities/1","doc":"","ref":"Evision.CUDA.StereoBeliefPropagation.html#setNumDisparities/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setNumDisparities/2","doc":"setNumDisparities\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **numDisparities**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNumDisparities(numDisparities) -> None\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#setNumDisparities/2"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setNumIters/1","doc":"","ref":"Evision.CUDA.StereoBeliefPropagation.html#setNumIters/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setNumIters/2","doc":"setNumIters\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **iters**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNumIters(iters) -> None\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#setNumIters/2"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setNumLevels/1","doc":"","ref":"Evision.CUDA.StereoBeliefPropagation.html#setNumLevels/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setNumLevels/2","doc":"setNumLevels\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **levels**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNumLevels(levels) -> None\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#setNumLevels/2"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setSpeckleRange/1","doc":"","ref":"Evision.CUDA.StereoBeliefPropagation.html#setSpeckleRange/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setSpeckleRange/2","doc":"setSpeckleRange\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **speckleRange**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetSpeckleRange(speckleRange) -> None\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#setSpeckleRange/2"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setSpeckleWindowSize/1","doc":"","ref":"Evision.CUDA.StereoBeliefPropagation.html#setSpeckleWindowSize/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.setSpeckleWindowSize/2","doc":"setSpeckleWindowSize\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **speckleWindowSize**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetSpeckleWindowSize(speckleWindowSize) -> None\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#setSpeckleWindowSize/2"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.write/1","doc":"","ref":"Evision.CUDA.StereoBeliefPropagation.html#write/1"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#write/2"},{"type":"function","title":"Evision.CUDA.StereoBeliefPropagation.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoBeliefPropagation.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CUDA.StereoBeliefPropagation.html#write/3"},{"type":"type","title":"Evision.CUDA.StereoBeliefPropagation.t/0","doc":"Type that represents an `CUDA.StereoBeliefPropagation` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.StereoBeliefPropagation.html#t:t/0"},{"type":"module","title":"Evision.CUDA.StereoConstantSpaceBP","doc":"","ref":"Evision.CUDA.StereoConstantSpaceBP.html"},{"type":"function","title":"Evision.CUDA.StereoConstantSpaceBP.estimateRecommendedParams/1","doc":"","ref":"Evision.CUDA.StereoConstantSpaceBP.html#estimateRecommendedParams/1"},{"type":"function","title":"Evision.CUDA.StereoConstantSpaceBP.estimateRecommendedParams/6","doc":"Uses a heuristic method to compute parameters (ndisp, iters, levelsand nrplane) for the specified\nimage size (widthand height).\n\n##### Positional Arguments\n- **width**: `integer()`\n- **height**: `integer()`\n- **ndisp**: `integer()`\n- **iters**: `integer()`\n- **levels**: `integer()`\n- **nr_plane**: `integer()`\n\nPython prototype (for reference only):\n```python3\nestimateRecommendedParams(width, height, ndisp, iters, levels, nr_plane) -> None\n```","ref":"Evision.CUDA.StereoConstantSpaceBP.html#estimateRecommendedParams/6"},{"type":"function","title":"Evision.CUDA.StereoConstantSpaceBP.getNrPlane/1","doc":"getNrPlane\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoConstantSpaceBP.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNrPlane() -> retval\n```","ref":"Evision.CUDA.StereoConstantSpaceBP.html#getNrPlane/1"},{"type":"function","title":"Evision.CUDA.StereoConstantSpaceBP.getUseLocalInitDataCost/1","doc":"getUseLocalInitDataCost\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoConstantSpaceBP.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetUseLocalInitDataCost() -> retval\n```","ref":"Evision.CUDA.StereoConstantSpaceBP.html#getUseLocalInitDataCost/1"},{"type":"function","title":"Evision.CUDA.StereoConstantSpaceBP.setNrPlane/1","doc":"","ref":"Evision.CUDA.StereoConstantSpaceBP.html#setNrPlane/1"},{"type":"function","title":"Evision.CUDA.StereoConstantSpaceBP.setNrPlane/2","doc":"setNrPlane\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoConstantSpaceBP.t()`\n- **nr_plane**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNrPlane(nr_plane) -> None\n```","ref":"Evision.CUDA.StereoConstantSpaceBP.html#setNrPlane/2"},{"type":"function","title":"Evision.CUDA.StereoConstantSpaceBP.setUseLocalInitDataCost/1","doc":"","ref":"Evision.CUDA.StereoConstantSpaceBP.html#setUseLocalInitDataCost/1"},{"type":"function","title":"Evision.CUDA.StereoConstantSpaceBP.setUseLocalInitDataCost/2","doc":"setUseLocalInitDataCost\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoConstantSpaceBP.t()`\n- **use_local_init_data_cost**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetUseLocalInitDataCost(use_local_init_data_cost) -> None\n```","ref":"Evision.CUDA.StereoConstantSpaceBP.html#setUseLocalInitDataCost/2"},{"type":"type","title":"Evision.CUDA.StereoConstantSpaceBP.t/0","doc":"Type that represents an `CUDA.StereoConstantSpaceBP` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.StereoConstantSpaceBP.html#t:t/0"},{"type":"module","title":"Evision.CUDA.StereoSGM","doc":"","ref":"Evision.CUDA.StereoSGM.html"},{"type":"function","title":"Evision.CUDA.StereoSGM.compute/1","doc":"","ref":"Evision.CUDA.StereoSGM.html#compute/1"},{"type":"function","title":"Evision.CUDA.StereoSGM.compute/3","doc":"#### Variant 1:\nComputes disparity map for the specified stereo pair\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoSGM.t()`\n- **left**: `Evision.Mat`.\n\n  Left 8-bit or 16-bit unsigned single-channel image.\n\n- **right**: `Evision.Mat`.\n\n  Right image of the same size and the same type as the left one.\n\n##### Return\n- **disparity**: `Evision.Mat.t()`.\n\n  Output disparity map. It has the same size as the input images.\n  StereoSGM computes 16-bit fixed-point disparity map (where each disparity value has 4 fractional bits).\n\nPython prototype (for reference only):\n```python3\ncompute(left, right[, disparity]) -> disparity\n```\n#### Variant 2:\nComputes disparity map for the specified stereo pair\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoSGM.t()`\n- **left**: `Evision.CUDA.GpuMat.t()`.\n\n  Left 8-bit or 16-bit unsigned single-channel image.\n\n- **right**: `Evision.CUDA.GpuMat.t()`.\n\n  Right image of the same size and the same type as the left one.\n\n##### Return\n- **disparity**: `Evision.CUDA.GpuMat.t()`.\n\n  Output disparity map. It has the same size as the input images.\n  StereoSGM computes 16-bit fixed-point disparity map (where each disparity value has 4 fractional bits).\n\nPython prototype (for reference only):\n```python3\ncompute(left, right[, disparity]) -> disparity\n```","ref":"Evision.CUDA.StereoSGM.html#compute/3"},{"type":"function","title":"Evision.CUDA.StereoSGM.compute/4","doc":"#### Variant 1:\nComputes disparity map for the specified stereo pair\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoSGM.t()`\n- **left**: `Evision.Mat`.\n\n  Left 8-bit or 16-bit unsigned single-channel image.\n\n- **right**: `Evision.Mat`.\n\n  Right image of the same size and the same type as the left one.\n\n##### Return\n- **disparity**: `Evision.Mat.t()`.\n\n  Output disparity map. It has the same size as the input images.\n  StereoSGM computes 16-bit fixed-point disparity map (where each disparity value has 4 fractional bits).\n\nPython prototype (for reference only):\n```python3\ncompute(left, right[, disparity]) -> disparity\n```\n#### Variant 2:\nComputes disparity map for the specified stereo pair\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoSGM.t()`\n- **left**: `Evision.CUDA.GpuMat.t()`.\n\n  Left 8-bit or 16-bit unsigned single-channel image.\n\n- **right**: `Evision.CUDA.GpuMat.t()`.\n\n  Right image of the same size and the same type as the left one.\n\n##### Return\n- **disparity**: `Evision.CUDA.GpuMat.t()`.\n\n  Output disparity map. It has the same size as the input images.\n  StereoSGM computes 16-bit fixed-point disparity map (where each disparity value has 4 fractional bits).\n\nPython prototype (for reference only):\n```python3\ncompute(left, right[, disparity]) -> disparity\n```","ref":"Evision.CUDA.StereoSGM.html#compute/4"},{"type":"function","title":"Evision.CUDA.StereoSGM.compute_with_stream/1","doc":"","ref":"Evision.CUDA.StereoSGM.html#compute_with_stream/1"},{"type":"function","title":"Evision.CUDA.StereoSGM.compute_with_stream/4","doc":"#### Variant 1:\nComputes disparity map with specified CUDA Stream\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoSGM.t()`\n- **left**: `Evision.Mat`\n- **right**: `Evision.Mat`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **disparity**: `Evision.Mat.t()`.\n\n@sa compute\n\nPython prototype (for reference only):\n```python3\ncompute_with_stream(left, right, stream[, disparity]) -> disparity\n```\n#### Variant 2:\nComputes disparity map with specified CUDA Stream\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoSGM.t()`\n- **left**: `Evision.CUDA.GpuMat.t()`\n- **right**: `Evision.CUDA.GpuMat.t()`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **disparity**: `Evision.CUDA.GpuMat.t()`.\n\n@sa compute\n\nPython prototype (for reference only):\n```python3\ncompute_with_stream(left, right, stream[, disparity]) -> disparity\n```","ref":"Evision.CUDA.StereoSGM.html#compute_with_stream/4"},{"type":"function","title":"Evision.CUDA.StereoSGM.compute_with_stream/5","doc":"#### Variant 1:\nComputes disparity map with specified CUDA Stream\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoSGM.t()`\n- **left**: `Evision.Mat`\n- **right**: `Evision.Mat`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **disparity**: `Evision.Mat.t()`.\n\n@sa compute\n\nPython prototype (for reference only):\n```python3\ncompute_with_stream(left, right, stream[, disparity]) -> disparity\n```\n#### Variant 2:\nComputes disparity map with specified CUDA Stream\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.StereoSGM.t()`\n- **left**: `Evision.CUDA.GpuMat.t()`\n- **right**: `Evision.CUDA.GpuMat.t()`\n- **stream**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **disparity**: `Evision.CUDA.GpuMat.t()`.\n\n@sa compute\n\nPython prototype (for reference only):\n```python3\ncompute_with_stream(left, right, stream[, disparity]) -> disparity\n```","ref":"Evision.CUDA.StereoSGM.html#compute_with_stream/5"},{"type":"type","title":"Evision.CUDA.StereoSGM.t/0","doc":"Type that represents an `CUDA.StereoSGM` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.StereoSGM.html#t:t/0"},{"type":"module","title":"Evision.CUDA.Stream","doc":"","ref":"Evision.CUDA.Stream.html"},{"type":"function","title":"Evision.CUDA.Stream.cudaPtr/1","doc":"cudaPtr\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **retval**: `void*`\n\nPython prototype (for reference only):\n```python3\ncudaPtr() -> retval\n```","ref":"Evision.CUDA.Stream.html#cudaPtr/1"},{"type":"function","title":"Evision.CUDA.Stream.null/0","doc":"Adds a callback to be called on the host after all currently enqueued items in the stream have\ncompleted.\n\n##### Return\n- **retval**: `Evision.CUDA.Stream.t()`\n\n**Note**: Callbacks must not make any CUDA API calls. Callbacks must not perform any synchronization\nthat may depend on outstanding device work or other callbacks that are not mandated to run earlier.\nCallbacks without a mandated order (in independent streams) execute in undefined order and may be\nserialized.\n\nPython prototype (for reference only):\n```python3\nNull() -> retval\n```","ref":"Evision.CUDA.Stream.html#null/0"},{"type":"function","title":"Evision.CUDA.Stream.null/1","doc":"","ref":"Evision.CUDA.Stream.html#null/1"},{"type":"function","title":"Evision.CUDA.Stream.queryIfComplete/1","doc":"Returns true if the current stream queue is finished. Otherwise, it returns false.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Stream.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nqueryIfComplete() -> retval\n```","ref":"Evision.CUDA.Stream.html#queryIfComplete/1"},{"type":"function","title":"Evision.CUDA.Stream.stream/0","doc":"Stream\n##### Return\n- **self**: `Evision.CUDA.Stream.t()`\n\nPython prototype (for reference only):\n```python3\nStream() ->  \n```","ref":"Evision.CUDA.Stream.html#stream/0"},{"type":"function","title":"Evision.CUDA.Stream.stream/1","doc":"#### Variant 1:\ncreates a new Stream using the cudaFlags argument to determine the behaviors of the stream\n\n##### Positional Arguments\n- **cudaFlags**: `size_t`\n\n##### Return\n- **self**: `Evision.CUDA.Stream.t()`\n\n**Note**: The cudaFlags parameter is passed to the underlying api cudaStreamCreateWithFlags() and\nsupports the same parameter values.\n```\n// creates an OpenCV cuda::Stream that manages an asynchronous, non-blocking,\n// non-default CUDA stream\ncv::cuda::Stream cvStream(cudaStreamNonBlocking);\n```\n\nPython prototype (for reference only):\n```python3\nStream(cudaFlags) ->  \n```\n#### Variant 2:\nStream\n\n##### Positional Arguments\n- **allocator**: `GpuMat::Allocator`\n\n##### Return\n- **self**: `Evision.CUDA.Stream.t()`\n\nPython prototype (for reference only):\n```python3\nStream(allocator) ->  \n```","ref":"Evision.CUDA.Stream.html#stream/1"},{"type":"function","title":"Evision.CUDA.Stream.waitEvent/1","doc":"","ref":"Evision.CUDA.Stream.html#waitEvent/1"},{"type":"function","title":"Evision.CUDA.Stream.waitEvent/2","doc":"Makes a compute stream wait on an event.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Stream.t()`\n- **event**: `Evision.CUDA.Event.t()`\n\nPython prototype (for reference only):\n```python3\nwaitEvent(event) -> None\n```","ref":"Evision.CUDA.Stream.html#waitEvent/2"},{"type":"function","title":"Evision.CUDA.Stream.waitForCompletion/1","doc":"Blocks the current CPU thread until all operations in the stream are complete.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.Stream.t()`\n\nPython prototype (for reference only):\n```python3\nwaitForCompletion() -> None\n```","ref":"Evision.CUDA.Stream.html#waitForCompletion/1"},{"type":"type","title":"Evision.CUDA.Stream.t/0","doc":"Type that represents an `CUDA.Stream` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.Stream.html#t:t/0"},{"type":"module","title":"Evision.CUDA.TargetArchs","doc":"","ref":"Evision.CUDA.TargetArchs.html"},{"type":"function","title":"Evision.CUDA.TargetArchs.has/1","doc":"","ref":"Evision.CUDA.TargetArchs.html#has/1"},{"type":"function","title":"Evision.CUDA.TargetArchs.has/2","doc":"There is a set of methods to check whether the module contains intermediate (PTX) or binary CUDA\ncode for the given architecture(s):\n\n##### Positional Arguments\n- **major**: `integer()`.\n\n  Major compute capability version.\n\n- **minor**: `integer()`.\n\n  Minor compute capability version.\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nhas(major, minor) -> retval\n```","ref":"Evision.CUDA.TargetArchs.html#has/2"},{"type":"function","title":"Evision.CUDA.TargetArchs.hasBin/1","doc":"","ref":"Evision.CUDA.TargetArchs.html#hasBin/1"},{"type":"function","title":"Evision.CUDA.TargetArchs.hasBin/2","doc":"hasBin\n\n##### Positional Arguments\n- **major**: `integer()`\n- **minor**: `integer()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nhasBin(major, minor) -> retval\n```","ref":"Evision.CUDA.TargetArchs.html#hasBin/2"},{"type":"function","title":"Evision.CUDA.TargetArchs.hasEqualOrGreater/1","doc":"","ref":"Evision.CUDA.TargetArchs.html#hasEqualOrGreater/1"},{"type":"function","title":"Evision.CUDA.TargetArchs.hasEqualOrGreater/2","doc":"hasEqualOrGreater\n\n##### Positional Arguments\n- **major**: `integer()`\n- **minor**: `integer()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nhasEqualOrGreater(major, minor) -> retval\n```","ref":"Evision.CUDA.TargetArchs.html#hasEqualOrGreater/2"},{"type":"function","title":"Evision.CUDA.TargetArchs.hasEqualOrGreaterBin/1","doc":"","ref":"Evision.CUDA.TargetArchs.html#hasEqualOrGreaterBin/1"},{"type":"function","title":"Evision.CUDA.TargetArchs.hasEqualOrGreaterBin/2","doc":"hasEqualOrGreaterBin\n\n##### Positional Arguments\n- **major**: `integer()`\n- **minor**: `integer()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nhasEqualOrGreaterBin(major, minor) -> retval\n```","ref":"Evision.CUDA.TargetArchs.html#hasEqualOrGreaterBin/2"},{"type":"function","title":"Evision.CUDA.TargetArchs.hasEqualOrGreaterPtx/1","doc":"","ref":"Evision.CUDA.TargetArchs.html#hasEqualOrGreaterPtx/1"},{"type":"function","title":"Evision.CUDA.TargetArchs.hasEqualOrGreaterPtx/2","doc":"hasEqualOrGreaterPtx\n\n##### Positional Arguments\n- **major**: `integer()`\n- **minor**: `integer()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nhasEqualOrGreaterPtx(major, minor) -> retval\n```","ref":"Evision.CUDA.TargetArchs.html#hasEqualOrGreaterPtx/2"},{"type":"function","title":"Evision.CUDA.TargetArchs.hasEqualOrLessPtx/1","doc":"","ref":"Evision.CUDA.TargetArchs.html#hasEqualOrLessPtx/1"},{"type":"function","title":"Evision.CUDA.TargetArchs.hasEqualOrLessPtx/2","doc":"hasEqualOrLessPtx\n\n##### Positional Arguments\n- **major**: `integer()`\n- **minor**: `integer()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nhasEqualOrLessPtx(major, minor) -> retval\n```","ref":"Evision.CUDA.TargetArchs.html#hasEqualOrLessPtx/2"},{"type":"function","title":"Evision.CUDA.TargetArchs.hasPtx/1","doc":"","ref":"Evision.CUDA.TargetArchs.html#hasPtx/1"},{"type":"function","title":"Evision.CUDA.TargetArchs.hasPtx/2","doc":"hasPtx\n\n##### Positional Arguments\n- **major**: `integer()`\n- **minor**: `integer()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nhasPtx(major, minor) -> retval\n```","ref":"Evision.CUDA.TargetArchs.html#hasPtx/2"},{"type":"type","title":"Evision.CUDA.TargetArchs.t/0","doc":"Type that represents an `CUDA.TargetArchs` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.TargetArchs.html#t:t/0"},{"type":"module","title":"Evision.CUDA.TemplateMatching","doc":"","ref":"Evision.CUDA.TemplateMatching.html"},{"type":"function","title":"Evision.CUDA.TemplateMatching.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.TemplateMatching.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.CUDA.TemplateMatching.html#clear/1"},{"type":"function","title":"Evision.CUDA.TemplateMatching.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.TemplateMatching.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CUDA.TemplateMatching.html#empty/1"},{"type":"function","title":"Evision.CUDA.TemplateMatching.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.TemplateMatching.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CUDA.TemplateMatching.html#getDefaultName/1"},{"type":"function","title":"Evision.CUDA.TemplateMatching.match/1","doc":"","ref":"Evision.CUDA.TemplateMatching.html#match/1"},{"type":"function","title":"Evision.CUDA.TemplateMatching.match/3","doc":"#### Variant 1:\nComputes a proximity map for a raster template and an image where the template is searched for.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.TemplateMatching.t()`\n- **image**: `Evision.Mat`.\n\n  Source image.\n\n- **templ**: `Evision.Mat`.\n\n  Template image with the size and type the same as image .\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **result**: `Evision.Mat.t()`.\n\n  Map containing comparison results ( CV_32FC1 ). If image is *W x H* and templ is *w\n  x h*, then result must be *W-w+1 x H-h+1*.\n\nPython prototype (for reference only):\n```python3\nmatch(image, templ[, result[, stream]]) -> result\n```\n#### Variant 2:\nComputes a proximity map for a raster template and an image where the template is searched for.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.TemplateMatching.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image.\n\n- **templ**: `Evision.CUDA.GpuMat.t()`.\n\n  Template image with the size and type the same as image .\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **result**: `Evision.CUDA.GpuMat.t()`.\n\n  Map containing comparison results ( CV_32FC1 ). If image is *W x H* and templ is *w\n  x h*, then result must be *W-w+1 x H-h+1*.\n\nPython prototype (for reference only):\n```python3\nmatch(image, templ[, result[, stream]]) -> result\n```","ref":"Evision.CUDA.TemplateMatching.html#match/3"},{"type":"function","title":"Evision.CUDA.TemplateMatching.match/4","doc":"#### Variant 1:\nComputes a proximity map for a raster template and an image where the template is searched for.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.TemplateMatching.t()`\n- **image**: `Evision.Mat`.\n\n  Source image.\n\n- **templ**: `Evision.Mat`.\n\n  Template image with the size and type the same as image .\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **result**: `Evision.Mat.t()`.\n\n  Map containing comparison results ( CV_32FC1 ). If image is *W x H* and templ is *w\n  x h*, then result must be *W-w+1 x H-h+1*.\n\nPython prototype (for reference only):\n```python3\nmatch(image, templ[, result[, stream]]) -> result\n```\n#### Variant 2:\nComputes a proximity map for a raster template and an image where the template is searched for.\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.TemplateMatching.t()`\n- **image**: `Evision.CUDA.GpuMat.t()`.\n\n  Source image.\n\n- **templ**: `Evision.CUDA.GpuMat.t()`.\n\n  Template image with the size and type the same as image .\n\n##### Keyword Arguments\n- **stream**: `Evision.CUDA.Stream.t()`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **result**: `Evision.CUDA.GpuMat.t()`.\n\n  Map containing comparison results ( CV_32FC1 ). If image is *W x H* and templ is *w\n  x h*, then result must be *W-w+1 x H-h+1*.\n\nPython prototype (for reference only):\n```python3\nmatch(image, templ[, result[, stream]]) -> result\n```","ref":"Evision.CUDA.TemplateMatching.html#match/4"},{"type":"function","title":"Evision.CUDA.TemplateMatching.read/1","doc":"","ref":"Evision.CUDA.TemplateMatching.html#read/1"},{"type":"function","title":"Evision.CUDA.TemplateMatching.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.TemplateMatching.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.CUDA.TemplateMatching.html#read/2"},{"type":"function","title":"Evision.CUDA.TemplateMatching.save/1","doc":"","ref":"Evision.CUDA.TemplateMatching.html#save/1"},{"type":"function","title":"Evision.CUDA.TemplateMatching.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.TemplateMatching.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.CUDA.TemplateMatching.html#save/2"},{"type":"function","title":"Evision.CUDA.TemplateMatching.write/1","doc":"","ref":"Evision.CUDA.TemplateMatching.html#write/1"},{"type":"function","title":"Evision.CUDA.TemplateMatching.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.TemplateMatching.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.CUDA.TemplateMatching.html#write/2"},{"type":"function","title":"Evision.CUDA.TemplateMatching.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CUDA.TemplateMatching.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CUDA.TemplateMatching.html#write/3"},{"type":"type","title":"Evision.CUDA.TemplateMatching.t/0","doc":"Type that represents an `CUDA.TemplateMatching` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDA.TemplateMatching.html#t:t/0"},{"type":"module","title":"Evision.CUDACodec","doc":"","ref":"Evision.CUDACodec.html"},{"type":"function","title":"Evision.CUDACodec.createVideoReader/1","doc":"#### Variant 1:\ncreateVideoReader\n\n##### Positional Arguments\n- **source**: `RawVideoSource`.\n\n  RAW video source implemented by user.\n\n##### Keyword Arguments\n- **params**: `VideoReaderInitParams`.\n\n  Initializaton parameters. See cv::cudacodec::VideoReaderInitParams.\n\n##### Return\n- **retval**: `VideoReader`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncreateVideoReader(source[, params]) -> retval\n```\n#### Variant 2:\nCreates video reader.\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  Name of the input video file.\n\n##### Keyword Arguments\n- **sourceParams**: `[integer()]`.\n\n  Pass through parameters for VideoCapure.  VideoCapture with the FFMpeg back end (CAP_FFMPEG) is used to parse the video input.\n  The `sourceParams` parameter allows to specify extra parameters encoded as pairs `(paramId_1, paramValue_1, paramId_2, paramValue_2, ...)`.\n  See cv::VideoCaptureProperties\n  e.g. when streaming from an RTSP source CAP_PROP_OPEN_TIMEOUT_MSEC may need to be set.\n\n- **params**: `VideoReaderInitParams`.\n\n  Initializaton parameters. See cv::cudacodec::VideoReaderInitParams.\n\n##### Return\n- **retval**: `VideoReader`\n\nFFMPEG is used to read videos. User can implement own demultiplexing with cudacodec::RawVideoSource\n\nPython prototype (for reference only):\n```python3\ncreateVideoReader(filename[, sourceParams[, params]]) -> retval\n```","ref":"Evision.CUDACodec.html#createVideoReader/1"},{"type":"function","title":"Evision.CUDACodec.createVideoReader/2","doc":"#### Variant 1:\ncreateVideoReader\n\n##### Positional Arguments\n- **source**: `RawVideoSource`.\n\n  RAW video source implemented by user.\n\n##### Keyword Arguments\n- **params**: `VideoReaderInitParams`.\n\n  Initializaton parameters. See cv::cudacodec::VideoReaderInitParams.\n\n##### Return\n- **retval**: `VideoReader`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncreateVideoReader(source[, params]) -> retval\n```\n#### Variant 2:\nCreates video reader.\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  Name of the input video file.\n\n##### Keyword Arguments\n- **sourceParams**: `[integer()]`.\n\n  Pass through parameters for VideoCapure.  VideoCapture with the FFMpeg back end (CAP_FFMPEG) is used to parse the video input.\n  The `sourceParams` parameter allows to specify extra parameters encoded as pairs `(paramId_1, paramValue_1, paramId_2, paramValue_2, ...)`.\n  See cv::VideoCaptureProperties\n  e.g. when streaming from an RTSP source CAP_PROP_OPEN_TIMEOUT_MSEC may need to be set.\n\n- **params**: `VideoReaderInitParams`.\n\n  Initializaton parameters. See cv::cudacodec::VideoReaderInitParams.\n\n##### Return\n- **retval**: `VideoReader`\n\nFFMPEG is used to read videos. User can implement own demultiplexing with cudacodec::RawVideoSource\n\nPython prototype (for reference only):\n```python3\ncreateVideoReader(filename[, sourceParams[, params]]) -> retval\n```","ref":"Evision.CUDACodec.html#createVideoReader/2"},{"type":"function","title":"Evision.CUDACodec.createVideoWriter/1","doc":"","ref":"Evision.CUDACodec.html#createVideoWriter/1"},{"type":"function","title":"Evision.CUDACodec.createVideoWriter/2","doc":"Creates video writer.\n\n##### Positional Arguments\n- **fileName**: `String`.\n\n  Name of the output video file.\n\n- **frameSize**: `Size`.\n\n  Size of the input video frames.\n\n##### Keyword Arguments\n- **codec**: `Codec`.\n\n  Supports Codec::H264 and Codec::HEVC.\n\n- **fps**: `double`.\n\n  Framerate of the created video stream.\n\n- **colorFormat**: `ColorFormat`.\n\n  OpenCv color format of the frames to be encoded.\n\n- **encoderCallback**: `EncoderCallback`.\n\n  Callbacks for video encoder. See cudacodec::EncoderCallback. Required for working with the encoded video stream.\n\n- **stream**: `cuda_Stream`.\n\n  Stream for frame pre-processing.\n\n##### Return\n- **retval**: `Evision.CUDACodec.VideoWriter.t()`\n\nPython prototype (for reference only):\n```python3\ncreateVideoWriter(fileName, frameSize[, codec[, fps[, colorFormat[, encoderCallback[, stream]]]]]) -> retval\n```","ref":"Evision.CUDACodec.html#createVideoWriter/2"},{"type":"function","title":"Evision.CUDACodec.createVideoWriter/3","doc":"Creates video writer.\n\n##### Positional Arguments\n- **fileName**: `String`.\n\n  Name of the output video file.\n\n- **frameSize**: `Size`.\n\n  Size of the input video frames.\n\n##### Keyword Arguments\n- **codec**: `Codec`.\n\n  Supports Codec::H264 and Codec::HEVC.\n\n- **fps**: `double`.\n\n  Framerate of the created video stream.\n\n- **colorFormat**: `ColorFormat`.\n\n  OpenCv color format of the frames to be encoded.\n\n- **encoderCallback**: `EncoderCallback`.\n\n  Callbacks for video encoder. See cudacodec::EncoderCallback. Required for working with the encoded video stream.\n\n- **stream**: `cuda_Stream`.\n\n  Stream for frame pre-processing.\n\n##### Return\n- **retval**: `Evision.CUDACodec.VideoWriter.t()`\n\nPython prototype (for reference only):\n```python3\ncreateVideoWriter(fileName, frameSize[, codec[, fps[, colorFormat[, encoderCallback[, stream]]]]]) -> retval\n```","ref":"Evision.CUDACodec.html#createVideoWriter/3"},{"type":"function","title":"Evision.CUDACodec.createVideoWriter/6","doc":"Creates video writer.\n\n##### Positional Arguments\n- **fileName**: `String`.\n\n  Name of the output video file.\n\n- **frameSize**: `Size`.\n\n  Size of the input video frames.\n\n- **codec**: `Codec`.\n\n  Supports Codec::H264 and Codec::HEVC.\n\n- **fps**: `double`.\n\n  Framerate of the created video stream.\n\n- **colorFormat**: `ColorFormat`.\n\n  OpenCv color format of the frames to be encoded.\n\n- **params**: `EncoderParams`.\n\n  Additional encoding parameters.\n\n##### Keyword Arguments\n- **encoderCallback**: `EncoderCallback`.\n\n  Callbacks for video encoder. See cudacodec::EncoderCallback. Required for working with the encoded video stream.\n\n- **stream**: `cuda_Stream`.\n\n  Stream for frame pre-processing.\n\n##### Return\n- **retval**: `Evision.CUDACodec.VideoWriter.t()`\n\nPython prototype (for reference only):\n```python3\ncreateVideoWriter(fileName, frameSize, codec, fps, colorFormat, params[, encoderCallback[, stream]]) -> retval\n```","ref":"Evision.CUDACodec.html#createVideoWriter/6"},{"type":"function","title":"Evision.CUDACodec.createVideoWriter/7","doc":"Creates video writer.\n\n##### Positional Arguments\n- **fileName**: `String`.\n\n  Name of the output video file.\n\n- **frameSize**: `Size`.\n\n  Size of the input video frames.\n\n- **codec**: `Codec`.\n\n  Supports Codec::H264 and Codec::HEVC.\n\n- **fps**: `double`.\n\n  Framerate of the created video stream.\n\n- **colorFormat**: `ColorFormat`.\n\n  OpenCv color format of the frames to be encoded.\n\n- **params**: `EncoderParams`.\n\n  Additional encoding parameters.\n\n##### Keyword Arguments\n- **encoderCallback**: `EncoderCallback`.\n\n  Callbacks for video encoder. See cudacodec::EncoderCallback. Required for working with the encoded video stream.\n\n- **stream**: `cuda_Stream`.\n\n  Stream for frame pre-processing.\n\n##### Return\n- **retval**: `Evision.CUDACodec.VideoWriter.t()`\n\nPython prototype (for reference only):\n```python3\ncreateVideoWriter(fileName, frameSize, codec, fps, colorFormat, params[, encoderCallback[, stream]]) -> retval\n```","ref":"Evision.CUDACodec.html#createVideoWriter/7"},{"type":"function","title":"Evision.CUDACodec.mapHist/1","doc":"Utility function demonstrating how to map the luma histogram when FormatInfo::videoFullRangeFlag == false\n\n##### Positional Arguments\n- **hist**: `Evision.CUDA.GpuMat.t()`.\n\n  Luma histogram \\a hist returned from VideoReader::nextFrame(GpuMat& frame, GpuMat& hist, Stream& stream).\n\n##### Return\n- **histFull**: `Evision.Mat.t()`.\n\n  Host histogram equivelent to downloading \\a hist after calling cuda::calcHist(InputArray frame, OutputArray hist, Stream& stream).\n\n**Note**: \n- This function demonstrates how to map the luma histogram back so that it is equivalent to the result obtained from cuda::calcHist()\n  if the returned frame was colorFormat::GRAY.\n\nPython prototype (for reference only):\n```python3\nMapHist(hist[, histFull]) -> histFull\n```","ref":"Evision.CUDACodec.html#mapHist/1"},{"type":"function","title":"Evision.CUDACodec.mapHist/2","doc":"Utility function demonstrating how to map the luma histogram when FormatInfo::videoFullRangeFlag == false\n\n##### Positional Arguments\n- **hist**: `Evision.CUDA.GpuMat.t()`.\n\n  Luma histogram \\a hist returned from VideoReader::nextFrame(GpuMat& frame, GpuMat& hist, Stream& stream).\n\n##### Return\n- **histFull**: `Evision.Mat.t()`.\n\n  Host histogram equivelent to downloading \\a hist after calling cuda::calcHist(InputArray frame, OutputArray hist, Stream& stream).\n\n**Note**: \n- This function demonstrates how to map the luma histogram back so that it is equivalent to the result obtained from cuda::calcHist()\n  if the returned frame was colorFormat::GRAY.\n\nPython prototype (for reference only):\n```python3\nMapHist(hist[, histFull]) -> histFull\n```","ref":"Evision.CUDACodec.html#mapHist/2"},{"type":"type","title":"Evision.CUDACodec.t/0","doc":"Type that represents an `CUDACodec` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDACodec.html#t:t/0"},{"type":"module","title":"Evision.CUDACodec.ChromaFormat","doc":"","ref":"Evision.CUDACodec.ChromaFormat.html"},{"type":"function","title":"Evision.CUDACodec.ChromaFormat.cv_Monochrome/0","doc":"","ref":"Evision.CUDACodec.ChromaFormat.html#cv_Monochrome/0"},{"type":"function","title":"Evision.CUDACodec.ChromaFormat.cv_NumFormats/0","doc":"","ref":"Evision.CUDACodec.ChromaFormat.html#cv_NumFormats/0"},{"type":"function","title":"Evision.CUDACodec.ChromaFormat.cv_YUV420/0","doc":"","ref":"Evision.CUDACodec.ChromaFormat.html#cv_YUV420/0"},{"type":"function","title":"Evision.CUDACodec.ChromaFormat.cv_YUV422/0","doc":"","ref":"Evision.CUDACodec.ChromaFormat.html#cv_YUV422/0"},{"type":"function","title":"Evision.CUDACodec.ChromaFormat.cv_YUV444/0","doc":"","ref":"Evision.CUDACodec.ChromaFormat.html#cv_YUV444/0"},{"type":"type","title":"Evision.CUDACodec.ChromaFormat.enum/0","doc":"","ref":"Evision.CUDACodec.ChromaFormat.html#t:enum/0"},{"type":"module","title":"Evision.CUDACodec.Codec","doc":"","ref":"Evision.CUDACodec.Codec.html"},{"type":"function","title":"Evision.CUDACodec.Codec.cv_AV1/0","doc":"","ref":"Evision.CUDACodec.Codec.html#cv_AV1/0"},{"type":"function","title":"Evision.CUDACodec.Codec.cv_H264/0","doc":"","ref":"Evision.CUDACodec.Codec.html#cv_H264/0"},{"type":"function","title":"Evision.CUDACodec.Codec.cv_H264_MVC/0","doc":"","ref":"Evision.CUDACodec.Codec.html#cv_H264_MVC/0"},{"type":"function","title":"Evision.CUDACodec.Codec.cv_H264_SVC/0","doc":"","ref":"Evision.CUDACodec.Codec.html#cv_H264_SVC/0"},{"type":"function","title":"Evision.CUDACodec.Codec.cv_HEVC/0","doc":"","ref":"Evision.CUDACodec.Codec.html#cv_HEVC/0"},{"type":"function","title":"Evision.CUDACodec.Codec.cv_JPEG/0","doc":"","ref":"Evision.CUDACodec.Codec.html#cv_JPEG/0"},{"type":"function","title":"Evision.CUDACodec.Codec.cv_MPEG1/0","doc":"","ref":"Evision.CUDACodec.Codec.html#cv_MPEG1/0"},{"type":"function","title":"Evision.CUDACodec.Codec.cv_MPEG2/0","doc":"","ref":"Evision.CUDACodec.Codec.html#cv_MPEG2/0"},{"type":"function","title":"Evision.CUDACodec.Codec.cv_MPEG4/0","doc":"","ref":"Evision.CUDACodec.Codec.html#cv_MPEG4/0"},{"type":"function","title":"Evision.CUDACodec.Codec.cv_NumCodecs/0","doc":"","ref":"Evision.CUDACodec.Codec.html#cv_NumCodecs/0"},{"type":"function","title":"Evision.CUDACodec.Codec.cv_Uncompressed_NV12/0","doc":"","ref":"Evision.CUDACodec.Codec.html#cv_Uncompressed_NV12/0"},{"type":"function","title":"Evision.CUDACodec.Codec.cv_Uncompressed_UYVY/0","doc":"","ref":"Evision.CUDACodec.Codec.html#cv_Uncompressed_UYVY/0"},{"type":"function","title":"Evision.CUDACodec.Codec.cv_Uncompressed_YUV420/0","doc":"","ref":"Evision.CUDACodec.Codec.html#cv_Uncompressed_YUV420/0"},{"type":"function","title":"Evision.CUDACodec.Codec.cv_Uncompressed_YUYV/0","doc":"","ref":"Evision.CUDACodec.Codec.html#cv_Uncompressed_YUYV/0"},{"type":"function","title":"Evision.CUDACodec.Codec.cv_Uncompressed_YV12/0","doc":"","ref":"Evision.CUDACodec.Codec.html#cv_Uncompressed_YV12/0"},{"type":"function","title":"Evision.CUDACodec.Codec.cv_VC1/0","doc":"","ref":"Evision.CUDACodec.Codec.html#cv_VC1/0"},{"type":"function","title":"Evision.CUDACodec.Codec.cv_VP8/0","doc":"","ref":"Evision.CUDACodec.Codec.html#cv_VP8/0"},{"type":"function","title":"Evision.CUDACodec.Codec.cv_VP9/0","doc":"","ref":"Evision.CUDACodec.Codec.html#cv_VP9/0"},{"type":"type","title":"Evision.CUDACodec.Codec.enum/0","doc":"","ref":"Evision.CUDACodec.Codec.html#t:enum/0"},{"type":"module","title":"Evision.CUDACodec.ColorFormat","doc":"","ref":"Evision.CUDACodec.ColorFormat.html"},{"type":"function","title":"Evision.CUDACodec.ColorFormat.cv_BGR/0","doc":"","ref":"Evision.CUDACodec.ColorFormat.html#cv_BGR/0"},{"type":"function","title":"Evision.CUDACodec.ColorFormat.cv_BGRA/0","doc":"","ref":"Evision.CUDACodec.ColorFormat.html#cv_BGRA/0"},{"type":"function","title":"Evision.CUDACodec.ColorFormat.cv_GRAY/0","doc":"","ref":"Evision.CUDACodec.ColorFormat.html#cv_GRAY/0"},{"type":"function","title":"Evision.CUDACodec.ColorFormat.cv_NV_AYUV/0","doc":"","ref":"Evision.CUDACodec.ColorFormat.html#cv_NV_AYUV/0"},{"type":"function","title":"Evision.CUDACodec.ColorFormat.cv_NV_IYUV/0","doc":"","ref":"Evision.CUDACodec.ColorFormat.html#cv_NV_IYUV/0"},{"type":"function","title":"Evision.CUDACodec.ColorFormat.cv_NV_NV12/0","doc":"","ref":"Evision.CUDACodec.ColorFormat.html#cv_NV_NV12/0"},{"type":"function","title":"Evision.CUDACodec.ColorFormat.cv_NV_YUV444/0","doc":"","ref":"Evision.CUDACodec.ColorFormat.html#cv_NV_YUV444/0"},{"type":"function","title":"Evision.CUDACodec.ColorFormat.cv_NV_YV12/0","doc":"","ref":"Evision.CUDACodec.ColorFormat.html#cv_NV_YV12/0"},{"type":"function","title":"Evision.CUDACodec.ColorFormat.cv_PROP_NOT_SUPPORTED/0","doc":"","ref":"Evision.CUDACodec.ColorFormat.html#cv_PROP_NOT_SUPPORTED/0"},{"type":"function","title":"Evision.CUDACodec.ColorFormat.cv_RGB/0","doc":"","ref":"Evision.CUDACodec.ColorFormat.html#cv_RGB/0"},{"type":"function","title":"Evision.CUDACodec.ColorFormat.cv_RGBA/0","doc":"","ref":"Evision.CUDACodec.ColorFormat.html#cv_RGBA/0"},{"type":"function","title":"Evision.CUDACodec.ColorFormat.cv_UNDEFINED/0","doc":"","ref":"Evision.CUDACodec.ColorFormat.html#cv_UNDEFINED/0"},{"type":"type","title":"Evision.CUDACodec.ColorFormat.enum/0","doc":"","ref":"Evision.CUDACodec.ColorFormat.html#t:enum/0"},{"type":"module","title":"Evision.CUDACodec.DeinterlaceMode","doc":"","ref":"Evision.CUDACodec.DeinterlaceMode.html"},{"type":"function","title":"Evision.CUDACodec.DeinterlaceMode.cv_Adaptive/0","doc":"","ref":"Evision.CUDACodec.DeinterlaceMode.html#cv_Adaptive/0"},{"type":"function","title":"Evision.CUDACodec.DeinterlaceMode.cv_Bob/0","doc":"","ref":"Evision.CUDACodec.DeinterlaceMode.html#cv_Bob/0"},{"type":"function","title":"Evision.CUDACodec.DeinterlaceMode.cv_Weave/0","doc":"","ref":"Evision.CUDACodec.DeinterlaceMode.html#cv_Weave/0"},{"type":"type","title":"Evision.CUDACodec.DeinterlaceMode.enum/0","doc":"","ref":"Evision.CUDACodec.DeinterlaceMode.html#t:enum/0"},{"type":"module","title":"Evision.CUDACodec.EncodeMultiPass","doc":"","ref":"Evision.CUDACodec.EncodeMultiPass.html"},{"type":"function","title":"Evision.CUDACodec.EncodeMultiPass.cv_ENC_MULTI_PASS_DISABLED/0","doc":"","ref":"Evision.CUDACodec.EncodeMultiPass.html#cv_ENC_MULTI_PASS_DISABLED/0"},{"type":"function","title":"Evision.CUDACodec.EncodeMultiPass.cv_ENC_TWO_PASS_FULL_RESOLUTION/0","doc":"","ref":"Evision.CUDACodec.EncodeMultiPass.html#cv_ENC_TWO_PASS_FULL_RESOLUTION/0"},{"type":"function","title":"Evision.CUDACodec.EncodeMultiPass.cv_ENC_TWO_PASS_QUARTER_RESOLUTION/0","doc":"","ref":"Evision.CUDACodec.EncodeMultiPass.html#cv_ENC_TWO_PASS_QUARTER_RESOLUTION/0"},{"type":"type","title":"Evision.CUDACodec.EncodeMultiPass.enum/0","doc":"","ref":"Evision.CUDACodec.EncodeMultiPass.html#t:enum/0"},{"type":"module","title":"Evision.CUDACodec.EncodeParamsRcMode","doc":"","ref":"Evision.CUDACodec.EncodeParamsRcMode.html"},{"type":"function","title":"Evision.CUDACodec.EncodeParamsRcMode.cv_ENC_PARAMS_RC_CBR/0","doc":"","ref":"Evision.CUDACodec.EncodeParamsRcMode.html#cv_ENC_PARAMS_RC_CBR/0"},{"type":"function","title":"Evision.CUDACodec.EncodeParamsRcMode.cv_ENC_PARAMS_RC_CONSTQP/0","doc":"","ref":"Evision.CUDACodec.EncodeParamsRcMode.html#cv_ENC_PARAMS_RC_CONSTQP/0"},{"type":"function","title":"Evision.CUDACodec.EncodeParamsRcMode.cv_ENC_PARAMS_RC_VBR/0","doc":"","ref":"Evision.CUDACodec.EncodeParamsRcMode.html#cv_ENC_PARAMS_RC_VBR/0"},{"type":"type","title":"Evision.CUDACodec.EncodeParamsRcMode.enum/0","doc":"","ref":"Evision.CUDACodec.EncodeParamsRcMode.html#t:enum/0"},{"type":"module","title":"Evision.CUDACodec.EncodePreset","doc":"","ref":"Evision.CUDACodec.EncodePreset.html"},{"type":"function","title":"Evision.CUDACodec.EncodePreset.cv_ENC_PRESET_P1/0","doc":"","ref":"Evision.CUDACodec.EncodePreset.html#cv_ENC_PRESET_P1/0"},{"type":"function","title":"Evision.CUDACodec.EncodePreset.cv_ENC_PRESET_P2/0","doc":"","ref":"Evision.CUDACodec.EncodePreset.html#cv_ENC_PRESET_P2/0"},{"type":"function","title":"Evision.CUDACodec.EncodePreset.cv_ENC_PRESET_P3/0","doc":"","ref":"Evision.CUDACodec.EncodePreset.html#cv_ENC_PRESET_P3/0"},{"type":"function","title":"Evision.CUDACodec.EncodePreset.cv_ENC_PRESET_P4/0","doc":"","ref":"Evision.CUDACodec.EncodePreset.html#cv_ENC_PRESET_P4/0"},{"type":"function","title":"Evision.CUDACodec.EncodePreset.cv_ENC_PRESET_P5/0","doc":"","ref":"Evision.CUDACodec.EncodePreset.html#cv_ENC_PRESET_P5/0"},{"type":"function","title":"Evision.CUDACodec.EncodePreset.cv_ENC_PRESET_P6/0","doc":"","ref":"Evision.CUDACodec.EncodePreset.html#cv_ENC_PRESET_P6/0"},{"type":"function","title":"Evision.CUDACodec.EncodePreset.cv_ENC_PRESET_P7/0","doc":"","ref":"Evision.CUDACodec.EncodePreset.html#cv_ENC_PRESET_P7/0"},{"type":"type","title":"Evision.CUDACodec.EncodePreset.enum/0","doc":"","ref":"Evision.CUDACodec.EncodePreset.html#t:enum/0"},{"type":"module","title":"Evision.CUDACodec.EncodeProfile","doc":"","ref":"Evision.CUDACodec.EncodeProfile.html"},{"type":"function","title":"Evision.CUDACodec.EncodeProfile.cv_ENC_CODEC_PROFILE_AUTOSELECT/0","doc":"","ref":"Evision.CUDACodec.EncodeProfile.html#cv_ENC_CODEC_PROFILE_AUTOSELECT/0"},{"type":"function","title":"Evision.CUDACodec.EncodeProfile.cv_ENC_H264_PROFILE_BASELINE/0","doc":"","ref":"Evision.CUDACodec.EncodeProfile.html#cv_ENC_H264_PROFILE_BASELINE/0"},{"type":"function","title":"Evision.CUDACodec.EncodeProfile.cv_ENC_H264_PROFILE_CONSTRAINED_HIGH/0","doc":"","ref":"Evision.CUDACodec.EncodeProfile.html#cv_ENC_H264_PROFILE_CONSTRAINED_HIGH/0"},{"type":"function","title":"Evision.CUDACodec.EncodeProfile.cv_ENC_H264_PROFILE_HIGH/0","doc":"","ref":"Evision.CUDACodec.EncodeProfile.html#cv_ENC_H264_PROFILE_HIGH/0"},{"type":"function","title":"Evision.CUDACodec.EncodeProfile.cv_ENC_H264_PROFILE_HIGH_444/0","doc":"","ref":"Evision.CUDACodec.EncodeProfile.html#cv_ENC_H264_PROFILE_HIGH_444/0"},{"type":"function","title":"Evision.CUDACodec.EncodeProfile.cv_ENC_H264_PROFILE_MAIN/0","doc":"","ref":"Evision.CUDACodec.EncodeProfile.html#cv_ENC_H264_PROFILE_MAIN/0"},{"type":"function","title":"Evision.CUDACodec.EncodeProfile.cv_ENC_H264_PROFILE_PROGRESSIVE_HIGH/0","doc":"","ref":"Evision.CUDACodec.EncodeProfile.html#cv_ENC_H264_PROFILE_PROGRESSIVE_HIGH/0"},{"type":"function","title":"Evision.CUDACodec.EncodeProfile.cv_ENC_H264_PROFILE_STEREO/0","doc":"","ref":"Evision.CUDACodec.EncodeProfile.html#cv_ENC_H264_PROFILE_STEREO/0"},{"type":"function","title":"Evision.CUDACodec.EncodeProfile.cv_ENC_HEVC_PROFILE_FREXT/0","doc":"","ref":"Evision.CUDACodec.EncodeProfile.html#cv_ENC_HEVC_PROFILE_FREXT/0"},{"type":"function","title":"Evision.CUDACodec.EncodeProfile.cv_ENC_HEVC_PROFILE_MAIN10/0","doc":"","ref":"Evision.CUDACodec.EncodeProfile.html#cv_ENC_HEVC_PROFILE_MAIN10/0"},{"type":"function","title":"Evision.CUDACodec.EncodeProfile.cv_ENC_HEVC_PROFILE_MAIN/0","doc":"","ref":"Evision.CUDACodec.EncodeProfile.html#cv_ENC_HEVC_PROFILE_MAIN/0"},{"type":"type","title":"Evision.CUDACodec.EncodeProfile.enum/0","doc":"","ref":"Evision.CUDACodec.EncodeProfile.html#t:enum/0"},{"type":"module","title":"Evision.CUDACodec.EncodeQp","doc":"","ref":"Evision.CUDACodec.EncodeQp.html"},{"type":"function","title":"Evision.CUDACodec.EncodeQp.get_qpInterB/1","doc":"","ref":"Evision.CUDACodec.EncodeQp.html#get_qpInterB/1"},{"type":"function","title":"Evision.CUDACodec.EncodeQp.get_qpInterP/1","doc":"","ref":"Evision.CUDACodec.EncodeQp.html#get_qpInterP/1"},{"type":"function","title":"Evision.CUDACodec.EncodeQp.get_qpIntra/1","doc":"","ref":"Evision.CUDACodec.EncodeQp.html#get_qpIntra/1"},{"type":"function","title":"Evision.CUDACodec.EncodeQp.set_qpInterB/2","doc":"","ref":"Evision.CUDACodec.EncodeQp.html#set_qpInterB/2"},{"type":"function","title":"Evision.CUDACodec.EncodeQp.set_qpInterP/2","doc":"","ref":"Evision.CUDACodec.EncodeQp.html#set_qpInterP/2"},{"type":"function","title":"Evision.CUDACodec.EncodeQp.set_qpIntra/2","doc":"","ref":"Evision.CUDACodec.EncodeQp.html#set_qpIntra/2"},{"type":"type","title":"Evision.CUDACodec.EncodeQp.t/0","doc":"Type that represents an `CUDACodec.EncodeQp` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDACodec.EncodeQp.html#t:t/0"},{"type":"module","title":"Evision.CUDACodec.EncodeTuningInfo","doc":"","ref":"Evision.CUDACodec.EncodeTuningInfo.html"},{"type":"function","title":"Evision.CUDACodec.EncodeTuningInfo.cv_ENC_TUNING_INFO_COUNT/0","doc":"","ref":"Evision.CUDACodec.EncodeTuningInfo.html#cv_ENC_TUNING_INFO_COUNT/0"},{"type":"function","title":"Evision.CUDACodec.EncodeTuningInfo.cv_ENC_TUNING_INFO_HIGH_QUALITY/0","doc":"","ref":"Evision.CUDACodec.EncodeTuningInfo.html#cv_ENC_TUNING_INFO_HIGH_QUALITY/0"},{"type":"function","title":"Evision.CUDACodec.EncodeTuningInfo.cv_ENC_TUNING_INFO_LOSSLESS/0","doc":"","ref":"Evision.CUDACodec.EncodeTuningInfo.html#cv_ENC_TUNING_INFO_LOSSLESS/0"},{"type":"function","title":"Evision.CUDACodec.EncodeTuningInfo.cv_ENC_TUNING_INFO_LOW_LATENCY/0","doc":"","ref":"Evision.CUDACodec.EncodeTuningInfo.html#cv_ENC_TUNING_INFO_LOW_LATENCY/0"},{"type":"function","title":"Evision.CUDACodec.EncodeTuningInfo.cv_ENC_TUNING_INFO_ULTRA_LOW_LATENCY/0","doc":"","ref":"Evision.CUDACodec.EncodeTuningInfo.html#cv_ENC_TUNING_INFO_ULTRA_LOW_LATENCY/0"},{"type":"function","title":"Evision.CUDACodec.EncodeTuningInfo.cv_ENC_TUNING_INFO_UNDEFINED/0","doc":"","ref":"Evision.CUDACodec.EncodeTuningInfo.html#cv_ENC_TUNING_INFO_UNDEFINED/0"},{"type":"type","title":"Evision.CUDACodec.EncodeTuningInfo.enum/0","doc":"","ref":"Evision.CUDACodec.EncodeTuningInfo.html#t:enum/0"},{"type":"module","title":"Evision.CUDACodec.EncoderCallback","doc":"","ref":"Evision.CUDACodec.EncoderCallback.html"},{"type":"type","title":"Evision.CUDACodec.EncoderCallback.t/0","doc":"Type that represents an `CUDACodec.EncoderCallback` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDACodec.EncoderCallback.html#t:t/0"},{"type":"module","title":"Evision.CUDACodec.EncoderParams","doc":"","ref":"Evision.CUDACodec.EncoderParams.html"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.encoderParams/0","doc":"EncoderParams\n##### Return\n- **self**: `EncoderParams`\n\nPython prototype (for reference only):\n```python3\nEncoderParams() ->  \n```","ref":"Evision.CUDACodec.EncoderParams.html#encoderParams/0"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.encoderParams/1","doc":"","ref":"Evision.CUDACodec.EncoderParams.html#encoderParams/1"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.get_averageBitRate/1","doc":"","ref":"Evision.CUDACodec.EncoderParams.html#get_averageBitRate/1"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.get_constQp/1","doc":"","ref":"Evision.CUDACodec.EncoderParams.html#get_constQp/1"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.get_encodingProfile/1","doc":"","ref":"Evision.CUDACodec.EncoderParams.html#get_encodingProfile/1"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.get_gopLength/1","doc":"","ref":"Evision.CUDACodec.EncoderParams.html#get_gopLength/1"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.get_idrPeriod/1","doc":"","ref":"Evision.CUDACodec.EncoderParams.html#get_idrPeriod/1"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.get_maxBitRate/1","doc":"","ref":"Evision.CUDACodec.EncoderParams.html#get_maxBitRate/1"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.get_multiPassEncoding/1","doc":"","ref":"Evision.CUDACodec.EncoderParams.html#get_multiPassEncoding/1"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.get_nvPreset/1","doc":"","ref":"Evision.CUDACodec.EncoderParams.html#get_nvPreset/1"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.get_rateControlMode/1","doc":"","ref":"Evision.CUDACodec.EncoderParams.html#get_rateControlMode/1"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.get_targetQuality/1","doc":"","ref":"Evision.CUDACodec.EncoderParams.html#get_targetQuality/1"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.get_tuningInfo/1","doc":"","ref":"Evision.CUDACodec.EncoderParams.html#get_tuningInfo/1"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.set_averageBitRate/2","doc":"","ref":"Evision.CUDACodec.EncoderParams.html#set_averageBitRate/2"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.set_constQp/2","doc":"","ref":"Evision.CUDACodec.EncoderParams.html#set_constQp/2"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.set_encodingProfile/2","doc":"","ref":"Evision.CUDACodec.EncoderParams.html#set_encodingProfile/2"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.set_gopLength/2","doc":"","ref":"Evision.CUDACodec.EncoderParams.html#set_gopLength/2"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.set_idrPeriod/2","doc":"","ref":"Evision.CUDACodec.EncoderParams.html#set_idrPeriod/2"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.set_maxBitRate/2","doc":"","ref":"Evision.CUDACodec.EncoderParams.html#set_maxBitRate/2"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.set_multiPassEncoding/2","doc":"","ref":"Evision.CUDACodec.EncoderParams.html#set_multiPassEncoding/2"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.set_nvPreset/2","doc":"","ref":"Evision.CUDACodec.EncoderParams.html#set_nvPreset/2"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.set_rateControlMode/2","doc":"","ref":"Evision.CUDACodec.EncoderParams.html#set_rateControlMode/2"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.set_targetQuality/2","doc":"","ref":"Evision.CUDACodec.EncoderParams.html#set_targetQuality/2"},{"type":"function","title":"Evision.CUDACodec.EncoderParams.set_tuningInfo/2","doc":"","ref":"Evision.CUDACodec.EncoderParams.html#set_tuningInfo/2"},{"type":"type","title":"Evision.CUDACodec.EncoderParams.t/0","doc":"Type that represents an `CUDACodec.EncoderParams` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDACodec.EncoderParams.html#t:t/0"},{"type":"module","title":"Evision.CUDACodec.FormatInfo","doc":"","ref":"Evision.CUDACodec.FormatInfo.html"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.formatInfo/0","doc":"FormatInfo\n##### Return\n- **self**: `FormatInfo`\n\nPython prototype (for reference only):\n```python3\nFormatInfo() ->  \n```","ref":"Evision.CUDACodec.FormatInfo.html#formatInfo/0"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.formatInfo/1","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#formatInfo/1"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.get_chromaFormat/1","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#get_chromaFormat/1"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.get_codec/1","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#get_codec/1"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.get_deinterlaceMode/1","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#get_deinterlaceMode/1"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.get_displayArea/1","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#get_displayArea/1"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.get_enableHistogram/1","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#get_enableHistogram/1"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.get_fps/1","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#get_fps/1"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.get_height/1","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#get_height/1"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.get_nBitDepthChromaMinus8/1","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#get_nBitDepthChromaMinus8/1"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.get_nBitDepthMinus8/1","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#get_nBitDepthMinus8/1"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.get_nCounterBitDepth/1","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#get_nCounterBitDepth/1"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.get_nMaxHistogramBins/1","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#get_nMaxHistogramBins/1"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.get_srcRoi/1","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#get_srcRoi/1"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.get_targetRoi/1","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#get_targetRoi/1"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.get_targetSz/1","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#get_targetSz/1"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.get_ulHeight/1","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#get_ulHeight/1"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.get_ulNumDecodeSurfaces/1","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#get_ulNumDecodeSurfaces/1"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.get_ulWidth/1","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#get_ulWidth/1"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.get_valid/1","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#get_valid/1"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.get_videoFullRangeFlag/1","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#get_videoFullRangeFlag/1"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.get_width/1","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#get_width/1"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.set_chromaFormat/2","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#set_chromaFormat/2"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.set_codec/2","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#set_codec/2"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.set_deinterlaceMode/2","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#set_deinterlaceMode/2"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.set_displayArea/2","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#set_displayArea/2"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.set_enableHistogram/2","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#set_enableHistogram/2"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.set_fps/2","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#set_fps/2"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.set_height/2","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#set_height/2"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.set_nBitDepthChromaMinus8/2","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#set_nBitDepthChromaMinus8/2"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.set_nBitDepthMinus8/2","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#set_nBitDepthMinus8/2"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.set_nCounterBitDepth/2","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#set_nCounterBitDepth/2"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.set_nMaxHistogramBins/2","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#set_nMaxHistogramBins/2"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.set_srcRoi/2","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#set_srcRoi/2"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.set_targetRoi/2","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#set_targetRoi/2"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.set_targetSz/2","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#set_targetSz/2"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.set_ulHeight/2","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#set_ulHeight/2"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.set_ulNumDecodeSurfaces/2","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#set_ulNumDecodeSurfaces/2"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.set_ulWidth/2","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#set_ulWidth/2"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.set_valid/2","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#set_valid/2"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.set_videoFullRangeFlag/2","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#set_videoFullRangeFlag/2"},{"type":"function","title":"Evision.CUDACodec.FormatInfo.set_width/2","doc":"","ref":"Evision.CUDACodec.FormatInfo.html#set_width/2"},{"type":"type","title":"Evision.CUDACodec.FormatInfo.t/0","doc":"Type that represents an `CUDACodec.FormatInfo` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDACodec.FormatInfo.html#t:t/0"},{"type":"module","title":"Evision.CUDACodec.RawVideoSource","doc":"","ref":"Evision.CUDACodec.RawVideoSource.html"},{"type":"type","title":"Evision.CUDACodec.RawVideoSource.t/0","doc":"Type that represents an `CUDACodec.RawVideoSource` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDACodec.RawVideoSource.html#t:t/0"},{"type":"module","title":"Evision.CUDACodec.VideoReader","doc":"","ref":"Evision.CUDACodec.VideoReader.html"},{"type":"function","title":"Evision.CUDACodec.VideoReader.format/1","doc":"Returns information about video file format.\n\n##### Positional Arguments\n- **self**: `Evision.CUDACodec.VideoReader.t()`\n\n##### Return\n- **retval**: `FormatInfo`\n\nPython prototype (for reference only):\n```python3\nformat() -> retval\n```","ref":"Evision.CUDACodec.VideoReader.html#format/1"},{"type":"function","title":"Evision.CUDACodec.VideoReader.get/1","doc":"","ref":"Evision.CUDACodec.VideoReader.html#get/1"},{"type":"function","title":"Evision.CUDACodec.VideoReader.get/2","doc":"Retrieves the specified property used by the VideoSource.\n\n##### Positional Arguments\n- **self**: `Evision.CUDACodec.VideoReader.t()`\n- **propertyId**: `integer()`.\n\n  Property identifier from cv::VideoCaptureProperties (eg. cv::CAP_PROP_POS_MSEC, cv::CAP_PROP_POS_FRAMES, ...)\n  or one from @ref videoio_flags_others.\n\n##### Return\n- **retval**: `bool`\n- **propertyVal**: `double`.\n\n  Value for the specified property.\n\n@return `true` unless the property is unset set or not supported.\n\nPython prototype (for reference only):\n```python3\nget(propertyId) -> retval, propertyVal\n```","ref":"Evision.CUDACodec.VideoReader.html#get/2"},{"type":"function","title":"Evision.CUDACodec.VideoReader.getVideoReaderProps/1","doc":"","ref":"Evision.CUDACodec.VideoReader.html#getVideoReaderProps/1"},{"type":"function","title":"Evision.CUDACodec.VideoReader.getVideoReaderProps/2","doc":"Returns the specified VideoReader property\n\n##### Positional Arguments\n- **self**: `Evision.CUDACodec.VideoReader.t()`\n- **propertyId**: `VideoReaderProps`.\n\n  Property identifier from cv::cudacodec::VideoReaderProps (eg. cv::cudacodec::VideoReaderProps::PROP_DECODED_FRAME_IDX,\n  cv::cudacodec::VideoReaderProps::PROP_EXTRA_DATA_INDEX, ...).\n\n##### Keyword Arguments\n- **propertyValIn**: `double`.\n\n##### Return\n- **retval**: `bool`\n- **propertyValOut**: `double`\n\n@return `true` unless the property is not supported.\n\nPython prototype (for reference only):\n```python3\ngetVideoReaderProps(propertyId[, propertyValIn]) -> retval, propertyValOut\n```","ref":"Evision.CUDACodec.VideoReader.html#getVideoReaderProps/2"},{"type":"function","title":"Evision.CUDACodec.VideoReader.getVideoReaderProps/3","doc":"Returns the specified VideoReader property\n\n##### Positional Arguments\n- **self**: `Evision.CUDACodec.VideoReader.t()`\n- **propertyId**: `VideoReaderProps`.\n\n  Property identifier from cv::cudacodec::VideoReaderProps (eg. cv::cudacodec::VideoReaderProps::PROP_DECODED_FRAME_IDX,\n  cv::cudacodec::VideoReaderProps::PROP_EXTRA_DATA_INDEX, ...).\n\n##### Keyword Arguments\n- **propertyValIn**: `double`.\n\n##### Return\n- **retval**: `bool`\n- **propertyValOut**: `double`\n\n@return `true` unless the property is not supported.\n\nPython prototype (for reference only):\n```python3\ngetVideoReaderProps(propertyId[, propertyValIn]) -> retval, propertyValOut\n```","ref":"Evision.CUDACodec.VideoReader.html#getVideoReaderProps/3"},{"type":"function","title":"Evision.CUDACodec.VideoReader.grab/1","doc":"Grabs the next frame from the video source.\n\n##### Positional Arguments\n- **self**: `Evision.CUDACodec.VideoReader.t()`\n\n##### Keyword Arguments\n- **stream**: `cuda_Stream`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **retval**: `bool`\n\n@return `true` (non-zero) in the case of success.\nThe method/function grabs the next frame from video file or camera and returns true (non-zero) in\nthe case of success.\nThe primary use of the function is for reading both the encoded and decoded video data when rawMode is enabled.  With rawMode enabled\nretrieve() can be called following grab() to retrieve all the data associated with the current video source since the last call to grab() or the creation of the VideoReader.\n\nPython prototype (for reference only):\n```python3\ngrab([, stream]) -> retval\n```","ref":"Evision.CUDACodec.VideoReader.html#grab/1"},{"type":"function","title":"Evision.CUDACodec.VideoReader.grab/2","doc":"Grabs the next frame from the video source.\n\n##### Positional Arguments\n- **self**: `Evision.CUDACodec.VideoReader.t()`\n\n##### Keyword Arguments\n- **stream**: `cuda_Stream`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **retval**: `bool`\n\n@return `true` (non-zero) in the case of success.\nThe method/function grabs the next frame from video file or camera and returns true (non-zero) in\nthe case of success.\nThe primary use of the function is for reading both the encoded and decoded video data when rawMode is enabled.  With rawMode enabled\nretrieve() can be called following grab() to retrieve all the data associated with the current video source since the last call to grab() or the creation of the VideoReader.\n\nPython prototype (for reference only):\n```python3\ngrab([, stream]) -> retval\n```","ref":"Evision.CUDACodec.VideoReader.html#grab/2"},{"type":"function","title":"Evision.CUDACodec.VideoReader.nextFrame/1","doc":"Grabs, decodes and returns the next video frame.\n\n##### Positional Arguments\n- **self**: `Evision.CUDACodec.VideoReader.t()`\n\n##### Keyword Arguments\n- **stream**: `cuda_Stream`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **retval**: `bool`\n- **frame**: `Evision.CUDA.GpuMat.t()`.\n\n@return `false` if no frames have been grabbed.\nIf no frames have been grabbed (there are no more frames in video file), the methods return false.\nThe method throws an Exception if error occurs.\n\nPython prototype (for reference only):\n```python3\nnextFrame([, frame[, stream]]) -> retval, frame\n```","ref":"Evision.CUDACodec.VideoReader.html#nextFrame/1"},{"type":"function","title":"Evision.CUDACodec.VideoReader.nextFrame/2","doc":"Grabs, decodes and returns the next video frame.\n\n##### Positional Arguments\n- **self**: `Evision.CUDACodec.VideoReader.t()`\n\n##### Keyword Arguments\n- **stream**: `cuda_Stream`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **retval**: `bool`\n- **frame**: `Evision.CUDA.GpuMat.t()`.\n\n@return `false` if no frames have been grabbed.\nIf no frames have been grabbed (there are no more frames in video file), the methods return false.\nThe method throws an Exception if error occurs.\n\nPython prototype (for reference only):\n```python3\nnextFrame([, frame[, stream]]) -> retval, frame\n```","ref":"Evision.CUDACodec.VideoReader.html#nextFrame/2"},{"type":"function","title":"Evision.CUDACodec.VideoReader.nextFrameWithHist/1","doc":"Grabs, decodes and returns the next video frame and frame luma histogram.\n\n##### Positional Arguments\n- **self**: `Evision.CUDACodec.VideoReader.t()`\n\n##### Keyword Arguments\n- **stream**: `cuda_Stream`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **retval**: `bool`\n- **frame**: `Evision.CUDA.GpuMat.t()`.\n- **histogram**: `Evision.CUDA.GpuMat.t()`.\n\n@return `false` if no frames have been grabbed.\nIf no frames have been grabbed (there are no more frames in video file), the methods return false.\nThe method throws an Exception if error occurs.\n**Note**: Histogram data is collected by NVDEC during the decoding process resulting in zero performance penalty. NVDEC computes the histogram data for only the luma component of decoded output, not on post-processed frame(i.e. when scaling, cropping, etc. applied).  If the source is encoded using a limited range of luma values (FormatInfo::videoFullRangeFlag == false) then the histogram bin values will correspond to to this limited range of values and will need to be mapped to contain the same output as cuda::calcHist().  The MapHist() utility function can be used to perform this mapping on the host if required.\n\nPython prototype (for reference only):\n```python3\nnextFrameWithHist([, frame[, histogram[, stream]]]) -> retval, frame, histogram\n```","ref":"Evision.CUDACodec.VideoReader.html#nextFrameWithHist/1"},{"type":"function","title":"Evision.CUDACodec.VideoReader.nextFrameWithHist/2","doc":"Grabs, decodes and returns the next video frame and frame luma histogram.\n\n##### Positional Arguments\n- **self**: `Evision.CUDACodec.VideoReader.t()`\n\n##### Keyword Arguments\n- **stream**: `cuda_Stream`.\n\n  Stream for the asynchronous version.\n\n##### Return\n- **retval**: `bool`\n- **frame**: `Evision.CUDA.GpuMat.t()`.\n- **histogram**: `Evision.CUDA.GpuMat.t()`.\n\n@return `false` if no frames have been grabbed.\nIf no frames have been grabbed (there are no more frames in video file), the methods return false.\nThe method throws an Exception if error occurs.\n**Note**: Histogram data is collected by NVDEC during the decoding process resulting in zero performance penalty. NVDEC computes the histogram data for only the luma component of decoded output, not on post-processed frame(i.e. when scaling, cropping, etc. applied).  If the source is encoded using a limited range of luma values (FormatInfo::videoFullRangeFlag == false) then the histogram bin values will correspond to to this limited range of values and will need to be mapped to contain the same output as cuda::calcHist().  The MapHist() utility function can be used to perform this mapping on the host if required.\n\nPython prototype (for reference only):\n```python3\nnextFrameWithHist([, frame[, histogram[, stream]]]) -> retval, frame, histogram\n```","ref":"Evision.CUDACodec.VideoReader.html#nextFrameWithHist/2"},{"type":"function","title":"Evision.CUDACodec.VideoReader.retrieve/1","doc":"Returns the next video frame.\n\n##### Positional Arguments\n- **self**: `Evision.CUDACodec.VideoReader.t()`\n\n##### Return\n- **retval**: `bool`\n- **frame**: `Evision.CUDA.GpuMat.t()`.\n\n@return `false` if no frames have been grabbed\nThe method returns data associated with the current video source since the last call to grab(). If no data is present\nthe method returns false and the function returns an empty image.\n\nPython prototype (for reference only):\n```python3\nretrieve([, frame]) -> retval, frame\n```","ref":"Evision.CUDACodec.VideoReader.html#retrieve/1"},{"type":"function","title":"Evision.CUDACodec.VideoReader.retrieve/2","doc":"#### Variant 1:\nReturns previously grabbed encoded video data.\n\n##### Positional Arguments\n- **self**: `Evision.CUDACodec.VideoReader.t()`\n- **idx**: `size_t`.\n\n  Determines the returned data inside image. The returned data can be the:\n  - Extra data if available, idx = get(PROP_EXTRA_DATA_INDEX).\n  - Raw encoded data package.  To retrieve package i,  idx = get(PROP_RAW_PACKAGES_BASE_INDEX) + i with i   retval, frame\n```\n#### Variant 2:\nReturns the next video frame.\n\n##### Positional Arguments\n- **self**: `Evision.CUDACodec.VideoReader.t()`\n\n##### Return\n- **retval**: `bool`\n- **frame**: `Evision.CUDA.GpuMat.t()`.\n\n@return `false` if no frames have been grabbed\nThe method returns data associated with the current video source since the last call to grab(). If no data is present\nthe method returns false and the function returns an empty image.\n\nPython prototype (for reference only):\n```python3\nretrieve([, frame]) -> retval, frame\n```","ref":"Evision.CUDACodec.VideoReader.html#retrieve/2"},{"type":"function","title":"Evision.CUDACodec.VideoReader.retrieve/3","doc":"Returns previously grabbed encoded video data.\n\n##### Positional Arguments\n- **self**: `Evision.CUDACodec.VideoReader.t()`\n- **idx**: `size_t`.\n\n  Determines the returned data inside image. The returned data can be the:\n  - Extra data if available, idx = get(PROP_EXTRA_DATA_INDEX).\n  - Raw encoded data package.  To retrieve package i,  idx = get(PROP_RAW_PACKAGES_BASE_INDEX) + i with i   retval, frame\n```","ref":"Evision.CUDACodec.VideoReader.html#retrieve/3"},{"type":"function","title":"Evision.CUDACodec.VideoReader.set/1","doc":"","ref":"Evision.CUDACodec.VideoReader.html#set/1"},{"type":"function","title":"Evision.CUDACodec.VideoReader.set/2","doc":"Set the desired ColorFormat for the frame returned by nextFrame()/retrieve().\n\n##### Positional Arguments\n- **self**: `Evision.CUDACodec.VideoReader.t()`\n- **colorFormat**: `ColorFormat`.\n\n  Value of the ColorFormat.\n\n##### Return\n- **retval**: `bool`\n\n@return `true` unless the colorFormat is not supported.\n\nPython prototype (for reference only):\n```python3\nset(colorFormat) -> retval\n```","ref":"Evision.CUDACodec.VideoReader.html#set/2"},{"type":"function","title":"Evision.CUDACodec.VideoReader.setVideoReaderProps/1","doc":"","ref":"Evision.CUDACodec.VideoReader.html#setVideoReaderProps/1"},{"type":"function","title":"Evision.CUDACodec.VideoReader.setVideoReaderProps/3","doc":"Sets a property in the VideoReader.\n\n##### Positional Arguments\n- **self**: `Evision.CUDACodec.VideoReader.t()`\n- **propertyId**: `VideoReaderProps`.\n\n  Property identifier from cv::cudacodec::VideoReaderProps (eg. cv::cudacodec::VideoReaderProps::PROP_DECODED_FRAME_IDX,\n  cv::cudacodec::VideoReaderProps::PROP_EXTRA_DATA_INDEX, ...).\n\n- **propertyVal**: `double`.\n\n  Value of the property.\n\n##### Return\n- **retval**: `bool`\n\n@return `true` if the property has been set.\n\nPython prototype (for reference only):\n```python3\nsetVideoReaderProps(propertyId, propertyVal) -> retval\n```","ref":"Evision.CUDACodec.VideoReader.html#setVideoReaderProps/3"},{"type":"type","title":"Evision.CUDACodec.VideoReader.t/0","doc":"Type that represents an `CUDACodec.VideoReader` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDACodec.VideoReader.html#t:t/0"},{"type":"module","title":"Evision.CUDACodec.VideoReaderInitParams","doc":"","ref":"Evision.CUDACodec.VideoReaderInitParams.html"},{"type":"function","title":"Evision.CUDACodec.VideoReaderInitParams.get_allowFrameDrop/1","doc":"","ref":"Evision.CUDACodec.VideoReaderInitParams.html#get_allowFrameDrop/1"},{"type":"function","title":"Evision.CUDACodec.VideoReaderInitParams.get_enableHistogram/1","doc":"","ref":"Evision.CUDACodec.VideoReaderInitParams.html#get_enableHistogram/1"},{"type":"function","title":"Evision.CUDACodec.VideoReaderInitParams.get_firstFrameIdx/1","doc":"","ref":"Evision.CUDACodec.VideoReaderInitParams.html#get_firstFrameIdx/1"},{"type":"function","title":"Evision.CUDACodec.VideoReaderInitParams.get_minNumDecodeSurfaces/1","doc":"","ref":"Evision.CUDACodec.VideoReaderInitParams.html#get_minNumDecodeSurfaces/1"},{"type":"function","title":"Evision.CUDACodec.VideoReaderInitParams.get_rawMode/1","doc":"","ref":"Evision.CUDACodec.VideoReaderInitParams.html#get_rawMode/1"},{"type":"function","title":"Evision.CUDACodec.VideoReaderInitParams.get_srcRoi/1","doc":"","ref":"Evision.CUDACodec.VideoReaderInitParams.html#get_srcRoi/1"},{"type":"function","title":"Evision.CUDACodec.VideoReaderInitParams.get_targetRoi/1","doc":"","ref":"Evision.CUDACodec.VideoReaderInitParams.html#get_targetRoi/1"},{"type":"function","title":"Evision.CUDACodec.VideoReaderInitParams.get_targetSz/1","doc":"","ref":"Evision.CUDACodec.VideoReaderInitParams.html#get_targetSz/1"},{"type":"function","title":"Evision.CUDACodec.VideoReaderInitParams.get_udpSource/1","doc":"","ref":"Evision.CUDACodec.VideoReaderInitParams.html#get_udpSource/1"},{"type":"function","title":"Evision.CUDACodec.VideoReaderInitParams.set_allowFrameDrop/2","doc":"","ref":"Evision.CUDACodec.VideoReaderInitParams.html#set_allowFrameDrop/2"},{"type":"function","title":"Evision.CUDACodec.VideoReaderInitParams.set_enableHistogram/2","doc":"","ref":"Evision.CUDACodec.VideoReaderInitParams.html#set_enableHistogram/2"},{"type":"function","title":"Evision.CUDACodec.VideoReaderInitParams.set_firstFrameIdx/2","doc":"","ref":"Evision.CUDACodec.VideoReaderInitParams.html#set_firstFrameIdx/2"},{"type":"function","title":"Evision.CUDACodec.VideoReaderInitParams.set_minNumDecodeSurfaces/2","doc":"","ref":"Evision.CUDACodec.VideoReaderInitParams.html#set_minNumDecodeSurfaces/2"},{"type":"function","title":"Evision.CUDACodec.VideoReaderInitParams.set_rawMode/2","doc":"","ref":"Evision.CUDACodec.VideoReaderInitParams.html#set_rawMode/2"},{"type":"function","title":"Evision.CUDACodec.VideoReaderInitParams.set_srcRoi/2","doc":"","ref":"Evision.CUDACodec.VideoReaderInitParams.html#set_srcRoi/2"},{"type":"function","title":"Evision.CUDACodec.VideoReaderInitParams.set_targetRoi/2","doc":"","ref":"Evision.CUDACodec.VideoReaderInitParams.html#set_targetRoi/2"},{"type":"function","title":"Evision.CUDACodec.VideoReaderInitParams.set_targetSz/2","doc":"","ref":"Evision.CUDACodec.VideoReaderInitParams.html#set_targetSz/2"},{"type":"function","title":"Evision.CUDACodec.VideoReaderInitParams.set_udpSource/2","doc":"","ref":"Evision.CUDACodec.VideoReaderInitParams.html#set_udpSource/2"},{"type":"function","title":"Evision.CUDACodec.VideoReaderInitParams.videoReaderInitParams/0","doc":"VideoReaderInitParams\n##### Return\n- **self**: `VideoReaderInitParams`\n\nPython prototype (for reference only):\n```python3\nVideoReaderInitParams() ->  \n```","ref":"Evision.CUDACodec.VideoReaderInitParams.html#videoReaderInitParams/0"},{"type":"function","title":"Evision.CUDACodec.VideoReaderInitParams.videoReaderInitParams/1","doc":"","ref":"Evision.CUDACodec.VideoReaderInitParams.html#videoReaderInitParams/1"},{"type":"type","title":"Evision.CUDACodec.VideoReaderInitParams.t/0","doc":"Type that represents an `CUDACodec.VideoReaderInitParams` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDACodec.VideoReaderInitParams.html#t:t/0"},{"type":"module","title":"Evision.CUDACodec.VideoReaderProps","doc":"","ref":"Evision.CUDACodec.VideoReaderProps.html"},{"type":"function","title":"Evision.CUDACodec.VideoReaderProps.cv_PROP_ALLOW_FRAME_DROP/0","doc":"","ref":"Evision.CUDACodec.VideoReaderProps.html#cv_PROP_ALLOW_FRAME_DROP/0"},{"type":"function","title":"Evision.CUDACodec.VideoReaderProps.cv_PROP_COLOR_FORMAT/0","doc":"","ref":"Evision.CUDACodec.VideoReaderProps.html#cv_PROP_COLOR_FORMAT/0"},{"type":"function","title":"Evision.CUDACodec.VideoReaderProps.cv_PROP_DECODED_FRAME_IDX/0","doc":"","ref":"Evision.CUDACodec.VideoReaderProps.html#cv_PROP_DECODED_FRAME_IDX/0"},{"type":"function","title":"Evision.CUDACodec.VideoReaderProps.cv_PROP_EXTRA_DATA_INDEX/0","doc":"","ref":"Evision.CUDACodec.VideoReaderProps.html#cv_PROP_EXTRA_DATA_INDEX/0"},{"type":"function","title":"Evision.CUDACodec.VideoReaderProps.cv_PROP_LRF_HAS_KEY_FRAME/0","doc":"","ref":"Evision.CUDACodec.VideoReaderProps.html#cv_PROP_LRF_HAS_KEY_FRAME/0"},{"type":"function","title":"Evision.CUDACodec.VideoReaderProps.cv_PROP_NOT_SUPPORTED/0","doc":"","ref":"Evision.CUDACodec.VideoReaderProps.html#cv_PROP_NOT_SUPPORTED/0"},{"type":"function","title":"Evision.CUDACodec.VideoReaderProps.cv_PROP_NUMBER_OF_RAW_PACKAGES_SINCE_LAST_GRAB/0","doc":"","ref":"Evision.CUDACodec.VideoReaderProps.html#cv_PROP_NUMBER_OF_RAW_PACKAGES_SINCE_LAST_GRAB/0"},{"type":"function","title":"Evision.CUDACodec.VideoReaderProps.cv_PROP_RAW_MODE/0","doc":"","ref":"Evision.CUDACodec.VideoReaderProps.html#cv_PROP_RAW_MODE/0"},{"type":"function","title":"Evision.CUDACodec.VideoReaderProps.cv_PROP_RAW_PACKAGES_BASE_INDEX/0","doc":"","ref":"Evision.CUDACodec.VideoReaderProps.html#cv_PROP_RAW_PACKAGES_BASE_INDEX/0"},{"type":"function","title":"Evision.CUDACodec.VideoReaderProps.cv_PROP_UDP_SOURCE/0","doc":"","ref":"Evision.CUDACodec.VideoReaderProps.html#cv_PROP_UDP_SOURCE/0"},{"type":"type","title":"Evision.CUDACodec.VideoReaderProps.enum/0","doc":"","ref":"Evision.CUDACodec.VideoReaderProps.html#t:enum/0"},{"type":"module","title":"Evision.CUDACodec.VideoWriter","doc":"","ref":"Evision.CUDACodec.VideoWriter.html"},{"type":"function","title":"Evision.CUDACodec.VideoWriter.getEncoderParams/1","doc":"Retrieve the encoding parameters.\n\n##### Positional Arguments\n- **self**: `Evision.CUDACodec.VideoWriter.t()`\n\n##### Return\n- **retval**: `EncoderParams`\n\nPython prototype (for reference only):\n```python3\ngetEncoderParams() -> retval\n```","ref":"Evision.CUDACodec.VideoWriter.html#getEncoderParams/1"},{"type":"function","title":"Evision.CUDACodec.VideoWriter.release/1","doc":"Waits until the encoding process has finished before calling EncoderCallback::onEncodingFinished().\n\n##### Positional Arguments\n- **self**: `Evision.CUDACodec.VideoWriter.t()`\n\nPython prototype (for reference only):\n```python3\nrelease() -> None\n```","ref":"Evision.CUDACodec.VideoWriter.html#release/1"},{"type":"function","title":"Evision.CUDACodec.VideoWriter.write/1","doc":"","ref":"Evision.CUDACodec.VideoWriter.html#write/1"},{"type":"function","title":"Evision.CUDACodec.VideoWriter.write/2","doc":"#### Variant 1:\nWrites the next video frame.\n\n##### Positional Arguments\n- **self**: `Evision.CUDACodec.VideoWriter.t()`\n- **frame**: `Evision.Mat`.\n\n  The framet to be written.\n\nThe method encodes the specified image to a video stream. The image must have the same size and the same\nsurface format as has been specified when opening the video writer.\n\nPython prototype (for reference only):\n```python3\nwrite(frame) -> None\n```\n#### Variant 2:\nWrites the next video frame.\n\n##### Positional Arguments\n- **self**: `Evision.CUDACodec.VideoWriter.t()`\n- **frame**: `Evision.CUDA.GpuMat.t()`.\n\n  The framet to be written.\n\nThe method encodes the specified image to a video stream. The image must have the same size and the same\nsurface format as has been specified when opening the video writer.\n\nPython prototype (for reference only):\n```python3\nwrite(frame) -> None\n```","ref":"Evision.CUDACodec.VideoWriter.html#write/2"},{"type":"type","title":"Evision.CUDACodec.VideoWriter.t/0","doc":"Type that represents an `CUDACodec.VideoWriter` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CUDACodec.VideoWriter.html#t:t/0"},{"type":"module","title":"Evision.CalibrateCRF","doc":"","ref":"Evision.CalibrateCRF.html"},{"type":"function","title":"Evision.CalibrateCRF.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateCRF.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.CalibrateCRF.html#clear/1"},{"type":"function","title":"Evision.CalibrateCRF.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateCRF.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CalibrateCRF.html#empty/1"},{"type":"function","title":"Evision.CalibrateCRF.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateCRF.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CalibrateCRF.html#getDefaultName/1"},{"type":"function","title":"Evision.CalibrateCRF.process/1","doc":"","ref":"Evision.CalibrateCRF.html#process/1"},{"type":"function","title":"Evision.CalibrateCRF.process/3","doc":"Recovers inverse camera response.\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateCRF.t()`\n- **src**: `[Evision.Mat]`.\n\n  vector of input images\n\n- **times**: `Evision.Mat`.\n\n  vector of exposure time values for each image\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  256x1 matrix with inverse camera response function\n\nPython prototype (for reference only):\n```python3\nprocess(src, times[, dst]) -> dst\n```","ref":"Evision.CalibrateCRF.html#process/3"},{"type":"function","title":"Evision.CalibrateCRF.process/4","doc":"Recovers inverse camera response.\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateCRF.t()`\n- **src**: `[Evision.Mat]`.\n\n  vector of input images\n\n- **times**: `Evision.Mat`.\n\n  vector of exposure time values for each image\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  256x1 matrix with inverse camera response function\n\nPython prototype (for reference only):\n```python3\nprocess(src, times[, dst]) -> dst\n```","ref":"Evision.CalibrateCRF.html#process/4"},{"type":"function","title":"Evision.CalibrateCRF.read/1","doc":"","ref":"Evision.CalibrateCRF.html#read/1"},{"type":"function","title":"Evision.CalibrateCRF.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateCRF.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.CalibrateCRF.html#read/2"},{"type":"function","title":"Evision.CalibrateCRF.save/1","doc":"","ref":"Evision.CalibrateCRF.html#save/1"},{"type":"function","title":"Evision.CalibrateCRF.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateCRF.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.CalibrateCRF.html#save/2"},{"type":"function","title":"Evision.CalibrateCRF.write/1","doc":"","ref":"Evision.CalibrateCRF.html#write/1"},{"type":"function","title":"Evision.CalibrateCRF.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateCRF.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.CalibrateCRF.html#write/2"},{"type":"function","title":"Evision.CalibrateCRF.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateCRF.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CalibrateCRF.html#write/3"},{"type":"type","title":"Evision.CalibrateCRF.t/0","doc":"Type that represents an `CalibrateCRF` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CalibrateCRF.html#t:t/0"},{"type":"module","title":"Evision.CalibrateDebevec","doc":"","ref":"Evision.CalibrateDebevec.html"},{"type":"function","title":"Evision.CalibrateDebevec.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateDebevec.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.CalibrateDebevec.html#clear/1"},{"type":"function","title":"Evision.CalibrateDebevec.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateDebevec.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CalibrateDebevec.html#empty/1"},{"type":"function","title":"Evision.CalibrateDebevec.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateDebevec.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CalibrateDebevec.html#getDefaultName/1"},{"type":"function","title":"Evision.CalibrateDebevec.getLambda/1","doc":"getLambda\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateDebevec.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetLambda() -> retval\n```","ref":"Evision.CalibrateDebevec.html#getLambda/1"},{"type":"function","title":"Evision.CalibrateDebevec.getRandom/1","doc":"getRandom\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateDebevec.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetRandom() -> retval\n```","ref":"Evision.CalibrateDebevec.html#getRandom/1"},{"type":"function","title":"Evision.CalibrateDebevec.getSamples/1","doc":"getSamples\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateDebevec.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetSamples() -> retval\n```","ref":"Evision.CalibrateDebevec.html#getSamples/1"},{"type":"function","title":"Evision.CalibrateDebevec.process/1","doc":"","ref":"Evision.CalibrateDebevec.html#process/1"},{"type":"function","title":"Evision.CalibrateDebevec.process/3","doc":"Recovers inverse camera response.\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateDebevec.t()`\n- **src**: `[Evision.Mat]`.\n\n  vector of input images\n\n- **times**: `Evision.Mat`.\n\n  vector of exposure time values for each image\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  256x1 matrix with inverse camera response function\n\nPython prototype (for reference only):\n```python3\nprocess(src, times[, dst]) -> dst\n```","ref":"Evision.CalibrateDebevec.html#process/3"},{"type":"function","title":"Evision.CalibrateDebevec.process/4","doc":"Recovers inverse camera response.\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateDebevec.t()`\n- **src**: `[Evision.Mat]`.\n\n  vector of input images\n\n- **times**: `Evision.Mat`.\n\n  vector of exposure time values for each image\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  256x1 matrix with inverse camera response function\n\nPython prototype (for reference only):\n```python3\nprocess(src, times[, dst]) -> dst\n```","ref":"Evision.CalibrateDebevec.html#process/4"},{"type":"function","title":"Evision.CalibrateDebevec.read/1","doc":"","ref":"Evision.CalibrateDebevec.html#read/1"},{"type":"function","title":"Evision.CalibrateDebevec.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateDebevec.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.CalibrateDebevec.html#read/2"},{"type":"function","title":"Evision.CalibrateDebevec.save/1","doc":"","ref":"Evision.CalibrateDebevec.html#save/1"},{"type":"function","title":"Evision.CalibrateDebevec.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateDebevec.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.CalibrateDebevec.html#save/2"},{"type":"function","title":"Evision.CalibrateDebevec.setLambda/1","doc":"","ref":"Evision.CalibrateDebevec.html#setLambda/1"},{"type":"function","title":"Evision.CalibrateDebevec.setLambda/2","doc":"setLambda\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateDebevec.t()`\n- **lambda**: `float`\n\nPython prototype (for reference only):\n```python3\nsetLambda(lambda) -> None\n```","ref":"Evision.CalibrateDebevec.html#setLambda/2"},{"type":"function","title":"Evision.CalibrateDebevec.setRandom/1","doc":"","ref":"Evision.CalibrateDebevec.html#setRandom/1"},{"type":"function","title":"Evision.CalibrateDebevec.setRandom/2","doc":"setRandom\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateDebevec.t()`\n- **random**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetRandom(random) -> None\n```","ref":"Evision.CalibrateDebevec.html#setRandom/2"},{"type":"function","title":"Evision.CalibrateDebevec.setSamples/1","doc":"","ref":"Evision.CalibrateDebevec.html#setSamples/1"},{"type":"function","title":"Evision.CalibrateDebevec.setSamples/2","doc":"setSamples\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateDebevec.t()`\n- **samples**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetSamples(samples) -> None\n```","ref":"Evision.CalibrateDebevec.html#setSamples/2"},{"type":"function","title":"Evision.CalibrateDebevec.write/1","doc":"","ref":"Evision.CalibrateDebevec.html#write/1"},{"type":"function","title":"Evision.CalibrateDebevec.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateDebevec.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.CalibrateDebevec.html#write/2"},{"type":"function","title":"Evision.CalibrateDebevec.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateDebevec.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CalibrateDebevec.html#write/3"},{"type":"type","title":"Evision.CalibrateDebevec.t/0","doc":"Type that represents an `CalibrateDebevec` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CalibrateDebevec.html#t:t/0"},{"type":"module","title":"Evision.CalibrateRobertson","doc":"","ref":"Evision.CalibrateRobertson.html"},{"type":"function","title":"Evision.CalibrateRobertson.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateRobertson.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.CalibrateRobertson.html#clear/1"},{"type":"function","title":"Evision.CalibrateRobertson.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateRobertson.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CalibrateRobertson.html#empty/1"},{"type":"function","title":"Evision.CalibrateRobertson.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateRobertson.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.CalibrateRobertson.html#getDefaultName/1"},{"type":"function","title":"Evision.CalibrateRobertson.getMaxIter/1","doc":"getMaxIter\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateRobertson.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxIter() -> retval\n```","ref":"Evision.CalibrateRobertson.html#getMaxIter/1"},{"type":"function","title":"Evision.CalibrateRobertson.getRadiance/1","doc":"getRadiance\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateRobertson.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetRadiance() -> retval\n```","ref":"Evision.CalibrateRobertson.html#getRadiance/1"},{"type":"function","title":"Evision.CalibrateRobertson.getThreshold/1","doc":"getThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateRobertson.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetThreshold() -> retval\n```","ref":"Evision.CalibrateRobertson.html#getThreshold/1"},{"type":"function","title":"Evision.CalibrateRobertson.process/1","doc":"","ref":"Evision.CalibrateRobertson.html#process/1"},{"type":"function","title":"Evision.CalibrateRobertson.process/3","doc":"Recovers inverse camera response.\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateRobertson.t()`\n- **src**: `[Evision.Mat]`.\n\n  vector of input images\n\n- **times**: `Evision.Mat`.\n\n  vector of exposure time values for each image\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  256x1 matrix with inverse camera response function\n\nPython prototype (for reference only):\n```python3\nprocess(src, times[, dst]) -> dst\n```","ref":"Evision.CalibrateRobertson.html#process/3"},{"type":"function","title":"Evision.CalibrateRobertson.process/4","doc":"Recovers inverse camera response.\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateRobertson.t()`\n- **src**: `[Evision.Mat]`.\n\n  vector of input images\n\n- **times**: `Evision.Mat`.\n\n  vector of exposure time values for each image\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  256x1 matrix with inverse camera response function\n\nPython prototype (for reference only):\n```python3\nprocess(src, times[, dst]) -> dst\n```","ref":"Evision.CalibrateRobertson.html#process/4"},{"type":"function","title":"Evision.CalibrateRobertson.read/1","doc":"","ref":"Evision.CalibrateRobertson.html#read/1"},{"type":"function","title":"Evision.CalibrateRobertson.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateRobertson.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.CalibrateRobertson.html#read/2"},{"type":"function","title":"Evision.CalibrateRobertson.save/1","doc":"","ref":"Evision.CalibrateRobertson.html#save/1"},{"type":"function","title":"Evision.CalibrateRobertson.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateRobertson.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.CalibrateRobertson.html#save/2"},{"type":"function","title":"Evision.CalibrateRobertson.setMaxIter/1","doc":"","ref":"Evision.CalibrateRobertson.html#setMaxIter/1"},{"type":"function","title":"Evision.CalibrateRobertson.setMaxIter/2","doc":"setMaxIter\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateRobertson.t()`\n- **max_iter**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxIter(max_iter) -> None\n```","ref":"Evision.CalibrateRobertson.html#setMaxIter/2"},{"type":"function","title":"Evision.CalibrateRobertson.setThreshold/1","doc":"","ref":"Evision.CalibrateRobertson.html#setThreshold/1"},{"type":"function","title":"Evision.CalibrateRobertson.setThreshold/2","doc":"setThreshold\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateRobertson.t()`\n- **threshold**: `float`\n\nPython prototype (for reference only):\n```python3\nsetThreshold(threshold) -> None\n```","ref":"Evision.CalibrateRobertson.html#setThreshold/2"},{"type":"function","title":"Evision.CalibrateRobertson.write/1","doc":"","ref":"Evision.CalibrateRobertson.html#write/1"},{"type":"function","title":"Evision.CalibrateRobertson.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateRobertson.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.CalibrateRobertson.html#write/2"},{"type":"function","title":"Evision.CalibrateRobertson.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.CalibrateRobertson.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.CalibrateRobertson.html#write/3"},{"type":"type","title":"Evision.CalibrateRobertson.t/0","doc":"Type that represents an `CalibrateRobertson` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CalibrateRobertson.html#t:t/0"},{"type":"module","title":"Evision.CascadeClassifier","doc":"","ref":"Evision.CascadeClassifier.html"},{"type":"function","title":"Evision.CascadeClassifier.cascadeClassifier/0","doc":"CascadeClassifier\n##### Return\n- **self**: `Evision.CascadeClassifier.t()`\n\nPython prototype (for reference only):\n```python3\nCascadeClassifier() ->  \n```","ref":"Evision.CascadeClassifier.html#cascadeClassifier/0"},{"type":"function","title":"Evision.CascadeClassifier.cascadeClassifier/1","doc":"Loads a classifier from a file.\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  Name of the file from which the classifier is loaded.\n\n##### Return\n- **self**: `Evision.CascadeClassifier.t()`\n\nPython prototype (for reference only):\n```python3\nCascadeClassifier(filename) ->  \n```","ref":"Evision.CascadeClassifier.html#cascadeClassifier/1"},{"type":"function","title":"Evision.CascadeClassifier.convert/1","doc":"","ref":"Evision.CascadeClassifier.html#convert/1"},{"type":"function","title":"Evision.CascadeClassifier.convert/2","doc":"convert\n\n##### Positional Arguments\n- **oldcascade**: `String`\n- **newcascade**: `String`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nconvert(oldcascade, newcascade) -> retval\n```","ref":"Evision.CascadeClassifier.html#convert/2"},{"type":"function","title":"Evision.CascadeClassifier.detectMultiScale2/1","doc":"","ref":"Evision.CascadeClassifier.html#detectMultiScale2/1"},{"type":"function","title":"Evision.CascadeClassifier.detectMultiScale2/2","doc":"detectMultiScale2\n\n##### Positional Arguments\n- **self**: `Evision.CascadeClassifier.t()`\n- **image**: `Evision.Mat`.\n\n  Matrix of the type CV_8U containing an image where objects are detected.\n\n##### Keyword Arguments\n- **scaleFactor**: `double`.\n\n  Parameter specifying how much the image size is reduced at each image scale.\n\n- **minNeighbors**: `integer()`.\n\n  Parameter specifying how many neighbors each candidate rectangle should have\n  to retain it.\n\n- **flags**: `integer()`.\n\n  Parameter with the same meaning for an old cascade as in the function\n  cvHaarDetectObjects. It is not used for a new cascade.\n\n- **minSize**: `Size`.\n\n  Minimum possible object size. Objects smaller than that are ignored.\n\n- **maxSize**: `Size`.\n\n  Maximum possible object size. Objects larger than that are ignored. If `maxSize == minSize` model is evaluated on single scale.\n\n##### Return\n- **objects**: `[Rect]`.\n\n  Vector of rectangles where each rectangle contains the detected object, the\n  rectangles may be partially outside the original image.\n\n- **numDetections**: `[integer()]`.\n\n  Vector of detection numbers for the corresponding objects. An object's number\n  of detections is the number of neighboring positively classified rectangles that were joined\n  together to form the object.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetectMultiScale2(image[, scaleFactor[, minNeighbors[, flags[, minSize[, maxSize]]]]]) -> objects, numDetections\n```","ref":"Evision.CascadeClassifier.html#detectMultiScale2/2"},{"type":"function","title":"Evision.CascadeClassifier.detectMultiScale2/3","doc":"detectMultiScale2\n\n##### Positional Arguments\n- **self**: `Evision.CascadeClassifier.t()`\n- **image**: `Evision.Mat`.\n\n  Matrix of the type CV_8U containing an image where objects are detected.\n\n##### Keyword Arguments\n- **scaleFactor**: `double`.\n\n  Parameter specifying how much the image size is reduced at each image scale.\n\n- **minNeighbors**: `integer()`.\n\n  Parameter specifying how many neighbors each candidate rectangle should have\n  to retain it.\n\n- **flags**: `integer()`.\n\n  Parameter with the same meaning for an old cascade as in the function\n  cvHaarDetectObjects. It is not used for a new cascade.\n\n- **minSize**: `Size`.\n\n  Minimum possible object size. Objects smaller than that are ignored.\n\n- **maxSize**: `Size`.\n\n  Maximum possible object size. Objects larger than that are ignored. If `maxSize == minSize` model is evaluated on single scale.\n\n##### Return\n- **objects**: `[Rect]`.\n\n  Vector of rectangles where each rectangle contains the detected object, the\n  rectangles may be partially outside the original image.\n\n- **numDetections**: `[integer()]`.\n\n  Vector of detection numbers for the corresponding objects. An object's number\n  of detections is the number of neighboring positively classified rectangles that were joined\n  together to form the object.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetectMultiScale2(image[, scaleFactor[, minNeighbors[, flags[, minSize[, maxSize]]]]]) -> objects, numDetections\n```","ref":"Evision.CascadeClassifier.html#detectMultiScale2/3"},{"type":"function","title":"Evision.CascadeClassifier.detectMultiScale3/1","doc":"","ref":"Evision.CascadeClassifier.html#detectMultiScale3/1"},{"type":"function","title":"Evision.CascadeClassifier.detectMultiScale3/2","doc":"detectMultiScale3\n\n##### Positional Arguments\n- **self**: `Evision.CascadeClassifier.t()`\n- **image**: `Evision.Mat`\n\n##### Keyword Arguments\n- **scaleFactor**: `double`.\n- **minNeighbors**: `integer()`.\n- **flags**: `integer()`.\n- **minSize**: `Size`.\n- **maxSize**: `Size`.\n- **outputRejectLevels**: `bool`.\n\n##### Return\n- **objects**: `[Rect]`\n- **rejectLevels**: `[integer()]`\n- **levelWeights**: `[double]`\n\nHas overloading in C++\n\nThis function allows you to retrieve the final stage decision certainty of classification.\nFor this, one needs to set `outputRejectLevels` on true and provide the `rejectLevels` and `levelWeights` parameter.\nFor each resulting detection, `levelWeights` will then contain the certainty of classification at the final stage.\nThis value can then be used to separate strong from weaker classifications.\nA code sample on how to use it efficiently can be found below:\n```\nMat img;\nvector  weights;\nvector  levels;\nvector  detections;\nCascadeClassifier model(\"/path/to/your/model.xml\");\nmodel.detectMultiScale(img, detections, levels, weights, 1.1, 3, 0, Size(), Size(), true);\ncerr << \"Detection \" <  objects, rejectLevels, levelWeights\n```","ref":"Evision.CascadeClassifier.html#detectMultiScale3/2"},{"type":"function","title":"Evision.CascadeClassifier.detectMultiScale3/3","doc":"detectMultiScale3\n\n##### Positional Arguments\n- **self**: `Evision.CascadeClassifier.t()`\n- **image**: `Evision.Mat`\n\n##### Keyword Arguments\n- **scaleFactor**: `double`.\n- **minNeighbors**: `integer()`.\n- **flags**: `integer()`.\n- **minSize**: `Size`.\n- **maxSize**: `Size`.\n- **outputRejectLevels**: `bool`.\n\n##### Return\n- **objects**: `[Rect]`\n- **rejectLevels**: `[integer()]`\n- **levelWeights**: `[double]`\n\nHas overloading in C++\n\nThis function allows you to retrieve the final stage decision certainty of classification.\nFor this, one needs to set `outputRejectLevels` on true and provide the `rejectLevels` and `levelWeights` parameter.\nFor each resulting detection, `levelWeights` will then contain the certainty of classification at the final stage.\nThis value can then be used to separate strong from weaker classifications.\nA code sample on how to use it efficiently can be found below:\n```\nMat img;\nvector  weights;\nvector  levels;\nvector  detections;\nCascadeClassifier model(\"/path/to/your/model.xml\");\nmodel.detectMultiScale(img, detections, levels, weights, 1.1, 3, 0, Size(), Size(), true);\ncerr << \"Detection \" <  objects, rejectLevels, levelWeights\n```","ref":"Evision.CascadeClassifier.html#detectMultiScale3/3"},{"type":"function","title":"Evision.CascadeClassifier.detectMultiScale/1","doc":"","ref":"Evision.CascadeClassifier.html#detectMultiScale/1"},{"type":"function","title":"Evision.CascadeClassifier.detectMultiScale/2","doc":"Detects objects of different sizes in the input image. The detected objects are returned as a list\nof rectangles.\n\n##### Positional Arguments\n- **self**: `Evision.CascadeClassifier.t()`\n- **image**: `Evision.Mat`.\n\n  Matrix of the type CV_8U containing an image where objects are detected.\n\n##### Keyword Arguments\n- **scaleFactor**: `double`.\n\n  Parameter specifying how much the image size is reduced at each image scale.\n\n- **minNeighbors**: `integer()`.\n\n  Parameter specifying how many neighbors each candidate rectangle should have\n  to retain it.\n\n- **flags**: `integer()`.\n\n  Parameter with the same meaning for an old cascade as in the function\n  cvHaarDetectObjects. It is not used for a new cascade.\n\n- **minSize**: `Size`.\n\n  Minimum possible object size. Objects smaller than that are ignored.\n\n- **maxSize**: `Size`.\n\n  Maximum possible object size. Objects larger than that are ignored. If `maxSize == minSize` model is evaluated on single scale.\n\n##### Return\n- **objects**: `[Rect]`.\n\n  Vector of rectangles where each rectangle contains the detected object, the\n  rectangles may be partially outside the original image.\n\nPython prototype (for reference only):\n```python3\ndetectMultiScale(image[, scaleFactor[, minNeighbors[, flags[, minSize[, maxSize]]]]]) -> objects\n```","ref":"Evision.CascadeClassifier.html#detectMultiScale/2"},{"type":"function","title":"Evision.CascadeClassifier.detectMultiScale/3","doc":"Detects objects of different sizes in the input image. The detected objects are returned as a list\nof rectangles.\n\n##### Positional Arguments\n- **self**: `Evision.CascadeClassifier.t()`\n- **image**: `Evision.Mat`.\n\n  Matrix of the type CV_8U containing an image where objects are detected.\n\n##### Keyword Arguments\n- **scaleFactor**: `double`.\n\n  Parameter specifying how much the image size is reduced at each image scale.\n\n- **minNeighbors**: `integer()`.\n\n  Parameter specifying how many neighbors each candidate rectangle should have\n  to retain it.\n\n- **flags**: `integer()`.\n\n  Parameter with the same meaning for an old cascade as in the function\n  cvHaarDetectObjects. It is not used for a new cascade.\n\n- **minSize**: `Size`.\n\n  Minimum possible object size. Objects smaller than that are ignored.\n\n- **maxSize**: `Size`.\n\n  Maximum possible object size. Objects larger than that are ignored. If `maxSize == minSize` model is evaluated on single scale.\n\n##### Return\n- **objects**: `[Rect]`.\n\n  Vector of rectangles where each rectangle contains the detected object, the\n  rectangles may be partially outside the original image.\n\nPython prototype (for reference only):\n```python3\ndetectMultiScale(image[, scaleFactor[, minNeighbors[, flags[, minSize[, maxSize]]]]]) -> objects\n```","ref":"Evision.CascadeClassifier.html#detectMultiScale/3"},{"type":"function","title":"Evision.CascadeClassifier.empty/1","doc":"Checks whether the classifier has been loaded.\n\n##### Positional Arguments\n- **self**: `Evision.CascadeClassifier.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.CascadeClassifier.html#empty/1"},{"type":"function","title":"Evision.CascadeClassifier.getFeatureType/1","doc":"getFeatureType\n\n##### Positional Arguments\n- **self**: `Evision.CascadeClassifier.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetFeatureType() -> retval\n```","ref":"Evision.CascadeClassifier.html#getFeatureType/1"},{"type":"function","title":"Evision.CascadeClassifier.getOriginalWindowSize/1","doc":"getOriginalWindowSize\n\n##### Positional Arguments\n- **self**: `Evision.CascadeClassifier.t()`\n\n##### Return\n- **retval**: `Size`\n\nPython prototype (for reference only):\n```python3\ngetOriginalWindowSize() -> retval\n```","ref":"Evision.CascadeClassifier.html#getOriginalWindowSize/1"},{"type":"function","title":"Evision.CascadeClassifier.isOldFormatCascade/1","doc":"isOldFormatCascade\n\n##### Positional Arguments\n- **self**: `Evision.CascadeClassifier.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisOldFormatCascade() -> retval\n```","ref":"Evision.CascadeClassifier.html#isOldFormatCascade/1"},{"type":"function","title":"Evision.CascadeClassifier.load/1","doc":"","ref":"Evision.CascadeClassifier.html#load/1"},{"type":"function","title":"Evision.CascadeClassifier.load/2","doc":"Loads a classifier from a file.\n\n##### Positional Arguments\n- **self**: `Evision.CascadeClassifier.t()`\n- **filename**: `String`.\n\n  Name of the file from which the classifier is loaded. The file may contain an old\n  HAAR classifier trained by the haartraining application or a new cascade classifier trained by the\n  traincascade application.\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nload(filename) -> retval\n```","ref":"Evision.CascadeClassifier.html#load/2"},{"type":"function","title":"Evision.CascadeClassifier.read/1","doc":"","ref":"Evision.CascadeClassifier.html#read/1"},{"type":"function","title":"Evision.CascadeClassifier.read/2","doc":"Reads a classifier from a FileStorage node.\n\n##### Positional Arguments\n- **self**: `Evision.CascadeClassifier.t()`\n- **node**: `Evision.FileNode`\n\n##### Return\n- **retval**: `bool`\n\n**Note**: The file may contain a new cascade classifier (trained by the traincascade application) only.\n\nPython prototype (for reference only):\n```python3\nread(node) -> retval\n```","ref":"Evision.CascadeClassifier.html#read/2"},{"type":"type","title":"Evision.CascadeClassifier.t/0","doc":"Type that represents an `CascadeClassifier` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CascadeClassifier.html#t:t/0"},{"type":"module","title":"Evision.ChiHistogramCostExtractor","doc":"","ref":"Evision.ChiHistogramCostExtractor.html"},{"type":"type","title":"Evision.ChiHistogramCostExtractor.t/0","doc":"Type that represents an `ChiHistogramCostExtractor` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ChiHistogramCostExtractor.html#t:t/0"},{"type":"module","title":"Evision.CirclesGridFinderParameters","doc":"","ref":"Evision.CirclesGridFinderParameters.html"},{"type":"function","title":"Evision.CirclesGridFinderParameters.circlesGridFinderParameters/0","doc":"CirclesGridFinderParameters\n##### Return\n- **self**: `Evision.CirclesGridFinderParameters.t()`\n\nPython prototype (for reference only):\n```python3\nCirclesGridFinderParameters() ->  \n```","ref":"Evision.CirclesGridFinderParameters.html#circlesGridFinderParameters/0"},{"type":"function","title":"Evision.CirclesGridFinderParameters.circlesGridFinderParameters/1","doc":"","ref":"Evision.CirclesGridFinderParameters.html#circlesGridFinderParameters/1"},{"type":"function","title":"Evision.CirclesGridFinderParameters.get_convexHullFactor/1","doc":"","ref":"Evision.CirclesGridFinderParameters.html#get_convexHullFactor/1"},{"type":"function","title":"Evision.CirclesGridFinderParameters.get_densityNeighborhoodSize/1","doc":"","ref":"Evision.CirclesGridFinderParameters.html#get_densityNeighborhoodSize/1"},{"type":"function","title":"Evision.CirclesGridFinderParameters.get_edgeGain/1","doc":"","ref":"Evision.CirclesGridFinderParameters.html#get_edgeGain/1"},{"type":"function","title":"Evision.CirclesGridFinderParameters.get_edgePenalty/1","doc":"","ref":"Evision.CirclesGridFinderParameters.html#get_edgePenalty/1"},{"type":"function","title":"Evision.CirclesGridFinderParameters.get_existingVertexGain/1","doc":"","ref":"Evision.CirclesGridFinderParameters.html#get_existingVertexGain/1"},{"type":"function","title":"Evision.CirclesGridFinderParameters.get_keypointScale/1","doc":"","ref":"Evision.CirclesGridFinderParameters.html#get_keypointScale/1"},{"type":"function","title":"Evision.CirclesGridFinderParameters.get_kmeansAttempts/1","doc":"","ref":"Evision.CirclesGridFinderParameters.html#get_kmeansAttempts/1"},{"type":"function","title":"Evision.CirclesGridFinderParameters.get_maxRectifiedDistance/1","doc":"","ref":"Evision.CirclesGridFinderParameters.html#get_maxRectifiedDistance/1"},{"type":"function","title":"Evision.CirclesGridFinderParameters.get_minDensity/1","doc":"","ref":"Evision.CirclesGridFinderParameters.html#get_minDensity/1"},{"type":"function","title":"Evision.CirclesGridFinderParameters.get_minDistanceToAddKeypoint/1","doc":"","ref":"Evision.CirclesGridFinderParameters.html#get_minDistanceToAddKeypoint/1"},{"type":"function","title":"Evision.CirclesGridFinderParameters.get_minGraphConfidence/1","doc":"","ref":"Evision.CirclesGridFinderParameters.html#get_minGraphConfidence/1"},{"type":"function","title":"Evision.CirclesGridFinderParameters.get_minRNGEdgeSwitchDist/1","doc":"","ref":"Evision.CirclesGridFinderParameters.html#get_minRNGEdgeSwitchDist/1"},{"type":"function","title":"Evision.CirclesGridFinderParameters.get_squareSize/1","doc":"","ref":"Evision.CirclesGridFinderParameters.html#get_squareSize/1"},{"type":"function","title":"Evision.CirclesGridFinderParameters.get_vertexGain/1","doc":"","ref":"Evision.CirclesGridFinderParameters.html#get_vertexGain/1"},{"type":"function","title":"Evision.CirclesGridFinderParameters.get_vertexPenalty/1","doc":"","ref":"Evision.CirclesGridFinderParameters.html#get_vertexPenalty/1"},{"type":"function","title":"Evision.CirclesGridFinderParameters.set_convexHullFactor/2","doc":"","ref":"Evision.CirclesGridFinderParameters.html#set_convexHullFactor/2"},{"type":"function","title":"Evision.CirclesGridFinderParameters.set_densityNeighborhoodSize/2","doc":"","ref":"Evision.CirclesGridFinderParameters.html#set_densityNeighborhoodSize/2"},{"type":"function","title":"Evision.CirclesGridFinderParameters.set_edgeGain/2","doc":"","ref":"Evision.CirclesGridFinderParameters.html#set_edgeGain/2"},{"type":"function","title":"Evision.CirclesGridFinderParameters.set_edgePenalty/2","doc":"","ref":"Evision.CirclesGridFinderParameters.html#set_edgePenalty/2"},{"type":"function","title":"Evision.CirclesGridFinderParameters.set_existingVertexGain/2","doc":"","ref":"Evision.CirclesGridFinderParameters.html#set_existingVertexGain/2"},{"type":"function","title":"Evision.CirclesGridFinderParameters.set_keypointScale/2","doc":"","ref":"Evision.CirclesGridFinderParameters.html#set_keypointScale/2"},{"type":"function","title":"Evision.CirclesGridFinderParameters.set_kmeansAttempts/2","doc":"","ref":"Evision.CirclesGridFinderParameters.html#set_kmeansAttempts/2"},{"type":"function","title":"Evision.CirclesGridFinderParameters.set_maxRectifiedDistance/2","doc":"","ref":"Evision.CirclesGridFinderParameters.html#set_maxRectifiedDistance/2"},{"type":"function","title":"Evision.CirclesGridFinderParameters.set_minDensity/2","doc":"","ref":"Evision.CirclesGridFinderParameters.html#set_minDensity/2"},{"type":"function","title":"Evision.CirclesGridFinderParameters.set_minDistanceToAddKeypoint/2","doc":"","ref":"Evision.CirclesGridFinderParameters.html#set_minDistanceToAddKeypoint/2"},{"type":"function","title":"Evision.CirclesGridFinderParameters.set_minGraphConfidence/2","doc":"","ref":"Evision.CirclesGridFinderParameters.html#set_minGraphConfidence/2"},{"type":"function","title":"Evision.CirclesGridFinderParameters.set_minRNGEdgeSwitchDist/2","doc":"","ref":"Evision.CirclesGridFinderParameters.html#set_minRNGEdgeSwitchDist/2"},{"type":"function","title":"Evision.CirclesGridFinderParameters.set_squareSize/2","doc":"","ref":"Evision.CirclesGridFinderParameters.html#set_squareSize/2"},{"type":"function","title":"Evision.CirclesGridFinderParameters.set_vertexGain/2","doc":"","ref":"Evision.CirclesGridFinderParameters.html#set_vertexGain/2"},{"type":"function","title":"Evision.CirclesGridFinderParameters.set_vertexPenalty/2","doc":"","ref":"Evision.CirclesGridFinderParameters.html#set_vertexPenalty/2"},{"type":"type","title":"Evision.CirclesGridFinderParameters.t/0","doc":"Type that represents an `CirclesGridFinderParameters` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.CirclesGridFinderParameters.html#t:t/0"},{"type":"module","title":"Evision.CirclesGridFinderParameters.GridType","doc":"","ref":"Evision.CirclesGridFinderParameters.GridType.html"},{"type":"function","title":"Evision.CirclesGridFinderParameters.GridType.cv_ASYMMETRIC_GRID/0","doc":"","ref":"Evision.CirclesGridFinderParameters.GridType.html#cv_ASYMMETRIC_GRID/0"},{"type":"function","title":"Evision.CirclesGridFinderParameters.GridType.cv_SYMMETRIC_GRID/0","doc":"","ref":"Evision.CirclesGridFinderParameters.GridType.html#cv_SYMMETRIC_GRID/0"},{"type":"type","title":"Evision.CirclesGridFinderParameters.GridType.enum/0","doc":"","ref":"Evision.CirclesGridFinderParameters.GridType.html#t:enum/0"},{"type":"module","title":"Evision.CmpTypes","doc":"","ref":"Evision.CmpTypes.html"},{"type":"function","title":"Evision.CmpTypes.cv_CMP_EQ/0","doc":"","ref":"Evision.CmpTypes.html#cv_CMP_EQ/0"},{"type":"function","title":"Evision.CmpTypes.cv_CMP_GE/0","doc":"","ref":"Evision.CmpTypes.html#cv_CMP_GE/0"},{"type":"function","title":"Evision.CmpTypes.cv_CMP_GT/0","doc":"","ref":"Evision.CmpTypes.html#cv_CMP_GT/0"},{"type":"function","title":"Evision.CmpTypes.cv_CMP_LE/0","doc":"","ref":"Evision.CmpTypes.html#cv_CMP_LE/0"},{"type":"function","title":"Evision.CmpTypes.cv_CMP_LT/0","doc":"","ref":"Evision.CmpTypes.html#cv_CMP_LT/0"},{"type":"function","title":"Evision.CmpTypes.cv_CMP_NE/0","doc":"","ref":"Evision.CmpTypes.html#cv_CMP_NE/0"},{"type":"type","title":"Evision.CmpTypes.enum/0","doc":"","ref":"Evision.CmpTypes.html#t:enum/0"},{"type":"module","title":"Evision.ColorConversionCodes","doc":"","ref":"Evision.ColorConversionCodes.html"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerBG2BGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerBG2BGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerBG2BGR_EA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerBG2BGR_EA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerBG2BGR_VNG/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerBG2BGR_VNG/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerBG2BGRA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerBG2BGRA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerBG2GRAY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerBG2GRAY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerBG2RGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerBG2RGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerBG2RGB_EA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerBG2RGB_EA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerBG2RGB_VNG/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerBG2RGB_VNG/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerBG2RGBA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerBG2RGBA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerBGGR2BGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerBGGR2BGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerBGGR2BGR_EA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerBGGR2BGR_EA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerBGGR2BGR_VNG/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerBGGR2BGR_VNG/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerBGGR2BGRA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerBGGR2BGRA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerBGGR2GRAY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerBGGR2GRAY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerBGGR2RGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerBGGR2RGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerBGGR2RGB_EA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerBGGR2RGB_EA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerBGGR2RGB_VNG/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerBGGR2RGB_VNG/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerBGGR2RGBA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerBGGR2RGBA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGB2BGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGB2BGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGB2BGR_EA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGB2BGR_EA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGB2BGR_VNG/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGB2BGR_VNG/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGB2BGRA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGB2BGRA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGB2GRAY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGB2GRAY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGB2RGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGB2RGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGB2RGB_EA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGB2RGB_EA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGB2RGB_VNG/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGB2RGB_VNG/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGB2RGBA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGB2RGBA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGBRG2BGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGBRG2BGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGBRG2BGR_EA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGBRG2BGR_EA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGBRG2BGR_VNG/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGBRG2BGR_VNG/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGBRG2BGRA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGBRG2BGRA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGBRG2GRAY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGBRG2GRAY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGBRG2RGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGBRG2RGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGBRG2RGB_EA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGBRG2RGB_EA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGBRG2RGB_VNG/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGBRG2RGB_VNG/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGBRG2RGBA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGBRG2RGBA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGR2BGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGR2BGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGR2BGR_EA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGR2BGR_EA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGR2BGR_VNG/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGR2BGR_VNG/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGR2BGRA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGR2BGRA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGR2GRAY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGR2GRAY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGR2RGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGR2RGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGR2RGB_EA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGR2RGB_EA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGR2RGB_VNG/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGR2RGB_VNG/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGR2RGBA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGR2RGBA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGRBG2BGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGRBG2BGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGRBG2BGR_EA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGRBG2BGR_EA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGRBG2BGR_VNG/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGRBG2BGR_VNG/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGRBG2BGRA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGRBG2BGRA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGRBG2GRAY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGRBG2GRAY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGRBG2RGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGRBG2RGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGRBG2RGB_EA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGRBG2RGB_EA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGRBG2RGB_VNG/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGRBG2RGB_VNG/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerGRBG2RGBA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerGRBG2RGBA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerRG2BGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerRG2BGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerRG2BGR_EA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerRG2BGR_EA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerRG2BGR_VNG/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerRG2BGR_VNG/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerRG2BGRA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerRG2BGRA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerRG2GRAY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerRG2GRAY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerRG2RGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerRG2RGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerRG2RGB_EA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerRG2RGB_EA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerRG2RGB_VNG/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerRG2RGB_VNG/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerRG2RGBA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerRG2RGBA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerRGGB2BGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerRGGB2BGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerRGGB2BGR_EA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerRGGB2BGR_EA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerRGGB2BGR_VNG/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerRGGB2BGR_VNG/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerRGGB2BGRA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerRGGB2BGRA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerRGGB2GRAY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerRGGB2GRAY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerRGGB2RGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerRGGB2RGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerRGGB2RGB_EA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerRGGB2RGB_EA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerRGGB2RGB_VNG/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerRGGB2RGB_VNG/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BayerRGGB2RGBA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BayerRGGB2RGBA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2BGR555/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2BGR555/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2BGR565/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2BGR565/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2BGRA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2BGRA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2GRAY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2GRAY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2HLS/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2HLS/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2HLS_FULL/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2HLS_FULL/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2HSV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2HSV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2HSV_FULL/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2HSV_FULL/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2Lab/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2Lab/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2Luv/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2Luv/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2RGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2RGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2RGBA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2RGBA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2XYZ/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2XYZ/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2YCrCb/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2YCrCb/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2YUV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2YUV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2YUV_I420/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2YUV_I420/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2YUV_IYUV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2YUV_IYUV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2YUV_UYNV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2YUV_UYNV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2YUV_UYVY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2YUV_UYVY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2YUV_Y422/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2YUV_Y422/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2YUV_YUNV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2YUV_YUNV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2YUV_YUY2/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2YUV_YUY2/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2YUV_YUYV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2YUV_YUYV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2YUV_YV12/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2YUV_YV12/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR2YUV_YVYU/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR2YUV_YVYU/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR5552BGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR5552BGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR5552BGRA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR5552BGRA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR5552GRAY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR5552GRAY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR5552RGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR5552RGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR5552RGBA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR5552RGBA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR5652BGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR5652BGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR5652BGRA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR5652BGRA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR5652GRAY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR5652GRAY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR5652RGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR5652RGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGR5652RGBA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGR5652RGBA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGRA2BGR555/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGRA2BGR555/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGRA2BGR565/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGRA2BGR565/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGRA2BGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGRA2BGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGRA2GRAY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGRA2GRAY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGRA2RGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGRA2RGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGRA2RGBA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGRA2RGBA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGRA2YUV_I420/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGRA2YUV_I420/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGRA2YUV_IYUV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGRA2YUV_IYUV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGRA2YUV_UYNV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGRA2YUV_UYNV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGRA2YUV_UYVY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGRA2YUV_UYVY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGRA2YUV_Y422/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGRA2YUV_Y422/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGRA2YUV_YUNV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGRA2YUV_YUNV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGRA2YUV_YUY2/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGRA2YUV_YUY2/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGRA2YUV_YUYV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGRA2YUV_YUYV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGRA2YUV_YV12/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGRA2YUV_YV12/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_BGRA2YUV_YVYU/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_BGRA2YUV_YVYU/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_COLORCVT_MAX/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_COLORCVT_MAX/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_GRAY2BGR555/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_GRAY2BGR555/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_GRAY2BGR565/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_GRAY2BGR565/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_GRAY2BGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_GRAY2BGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_GRAY2BGRA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_GRAY2BGRA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_GRAY2RGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_GRAY2RGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_GRAY2RGBA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_GRAY2RGBA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_HLS2BGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_HLS2BGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_HLS2BGR_FULL/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_HLS2BGR_FULL/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_HLS2RGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_HLS2RGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_HLS2RGB_FULL/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_HLS2RGB_FULL/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_HSV2BGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_HSV2BGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_HSV2BGR_FULL/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_HSV2BGR_FULL/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_HSV2RGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_HSV2RGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_HSV2RGB_FULL/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_HSV2RGB_FULL/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_Lab2BGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_Lab2BGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_Lab2LBGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_Lab2LBGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_Lab2LRGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_Lab2LRGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_Lab2RGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_Lab2RGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_LBGR2Lab/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_LBGR2Lab/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_LBGR2Luv/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_LBGR2Luv/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_LRGB2Lab/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_LRGB2Lab/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_LRGB2Luv/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_LRGB2Luv/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_Luv2BGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_Luv2BGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_Luv2LBGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_Luv2LBGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_Luv2LRGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_Luv2LRGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_Luv2RGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_Luv2RGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_mRGBA2RGBA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_mRGBA2RGBA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2BGR555/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2BGR555/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2BGR565/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2BGR565/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2BGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2BGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2BGRA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2BGRA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2GRAY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2GRAY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2HLS/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2HLS/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2HLS_FULL/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2HLS_FULL/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2HSV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2HSV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2HSV_FULL/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2HSV_FULL/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2Lab/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2Lab/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2Luv/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2Luv/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2RGBA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2RGBA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2XYZ/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2XYZ/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2YCrCb/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2YCrCb/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2YUV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2YUV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2YUV_I420/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2YUV_I420/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2YUV_IYUV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2YUV_IYUV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2YUV_UYNV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2YUV_UYNV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2YUV_UYVY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2YUV_UYVY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2YUV_Y422/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2YUV_Y422/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2YUV_YUNV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2YUV_YUNV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2YUV_YUY2/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2YUV_YUY2/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2YUV_YUYV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2YUV_YUYV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2YUV_YV12/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2YUV_YV12/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGB2YUV_YVYU/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGB2YUV_YVYU/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGBA2BGR555/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGBA2BGR555/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGBA2BGR565/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGBA2BGR565/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGBA2BGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGBA2BGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGBA2BGRA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGBA2BGRA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGBA2GRAY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGBA2GRAY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGBA2mRGBA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGBA2mRGBA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGBA2RGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGBA2RGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGBA2YUV_I420/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGBA2YUV_I420/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGBA2YUV_IYUV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGBA2YUV_IYUV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGBA2YUV_UYNV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGBA2YUV_UYNV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGBA2YUV_UYVY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGBA2YUV_UYVY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGBA2YUV_Y422/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGBA2YUV_Y422/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGBA2YUV_YUNV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGBA2YUV_YUNV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGBA2YUV_YUY2/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGBA2YUV_YUY2/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGBA2YUV_YUYV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGBA2YUV_YUYV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGBA2YUV_YV12/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGBA2YUV_YV12/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_RGBA2YUV_YVYU/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_RGBA2YUV_YVYU/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_XYZ2BGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_XYZ2BGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_XYZ2RGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_XYZ2RGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YCrCb2BGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YCrCb2BGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YCrCb2RGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YCrCb2RGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGR_I420/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGR_I420/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGR_IYUV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGR_IYUV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGR_NV12/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGR_NV12/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGR_NV21/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGR_NV21/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGR_UYNV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGR_UYNV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGR_UYVY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGR_UYVY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGR_Y422/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGR_Y422/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGR_YUNV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGR_YUNV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGR_YUY2/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGR_YUY2/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGR_YUYV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGR_YUYV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGR_YV12/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGR_YV12/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGR_YVYU/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGR_YVYU/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGRA_I420/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGRA_I420/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGRA_IYUV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGRA_IYUV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGRA_NV12/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGRA_NV12/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGRA_NV21/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGRA_NV21/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGRA_UYNV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGRA_UYNV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGRA_UYVY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGRA_UYVY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGRA_Y422/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGRA_Y422/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGRA_YUNV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGRA_YUNV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGRA_YUY2/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGRA_YUY2/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGRA_YUYV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGRA_YUYV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGRA_YV12/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGRA_YV12/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2BGRA_YVYU/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2BGRA_YVYU/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2GRAY_420/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2GRAY_420/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2GRAY_I420/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2GRAY_I420/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2GRAY_IYUV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2GRAY_IYUV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2GRAY_NV12/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2GRAY_NV12/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2GRAY_NV21/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2GRAY_NV21/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2GRAY_UYNV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2GRAY_UYNV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2GRAY_UYVY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2GRAY_UYVY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2GRAY_Y422/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2GRAY_Y422/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2GRAY_YUNV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2GRAY_YUNV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2GRAY_YUY2/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2GRAY_YUY2/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2GRAY_YUYV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2GRAY_YUYV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2GRAY_YV12/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2GRAY_YV12/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2GRAY_YVYU/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2GRAY_YVYU/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGB_I420/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGB_I420/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGB_IYUV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGB_IYUV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGB_NV12/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGB_NV12/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGB_NV21/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGB_NV21/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGB_UYNV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGB_UYNV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGB_UYVY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGB_UYVY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGB_Y422/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGB_Y422/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGB_YUNV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGB_YUNV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGB_YUY2/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGB_YUY2/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGB_YUYV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGB_YUYV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGB_YV12/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGB_YV12/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGB_YVYU/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGB_YVYU/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGBA_I420/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGBA_I420/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGBA_IYUV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGBA_IYUV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGBA_NV12/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGBA_NV12/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGBA_NV21/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGBA_NV21/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGBA_UYNV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGBA_UYNV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGBA_UYVY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGBA_UYVY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGBA_Y422/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGBA_Y422/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGBA_YUNV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGBA_YUNV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGBA_YUY2/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGBA_YUY2/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGBA_YUYV/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGBA_YUYV/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGBA_YV12/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGBA_YV12/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV2RGBA_YVYU/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV2RGBA_YVYU/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV420p2BGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV420p2BGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV420p2BGRA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV420p2BGRA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV420p2GRAY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV420p2GRAY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV420p2RGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV420p2RGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV420p2RGBA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV420p2RGBA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV420sp2BGR/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV420sp2BGR/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV420sp2BGRA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV420sp2BGRA/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV420sp2GRAY/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV420sp2GRAY/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV420sp2RGB/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV420sp2RGB/0"},{"type":"function","title":"Evision.ColorConversionCodes.cv_COLOR_YUV420sp2RGBA/0","doc":"","ref":"Evision.ColorConversionCodes.html#cv_COLOR_YUV420sp2RGBA/0"},{"type":"type","title":"Evision.ColorConversionCodes.enum/0","doc":"","ref":"Evision.ColorConversionCodes.html#t:enum/0"},{"type":"module","title":"Evision.ColoredKinFu","doc":"","ref":"Evision.ColoredKinFu.html"},{"type":"type","title":"Evision.ColoredKinFu.t/0","doc":"Type that represents an `ColoredKinFu` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ColoredKinFu.html#t:t/0"},{"type":"module","title":"Evision.ColoredKinFu.ColoredKinFu","doc":"","ref":"Evision.ColoredKinFu.ColoredKinFu.html"},{"type":"function","title":"Evision.ColoredKinFu.ColoredKinFu.create/1","doc":"create\n\n##### Positional Arguments\n- **params**: `Params`\n\n##### Return\n- **retval**: `Evision.ColoredKinFu.t()`\n\nPython prototype (for reference only):\n```python3\ncreate(_params) -> retval\n```","ref":"Evision.ColoredKinFu.ColoredKinFu.html#create/1"},{"type":"function","title":"Evision.ColoredKinFu.ColoredKinFu.getCloud/1","doc":"Gets points, normals and colors of current 3d mesh\n\n##### Positional Arguments\n- **self**: `Evision.ColoredKinFu.ColoredKinFu.t()`\n\n##### Return\n- **points**: `Evision.Mat.t()`.\n\n  vector of points which are 4-float vectors\n\n- **normals**: `Evision.Mat.t()`.\n\n  vector of normals which are 4-float vectors\n\n- **colors**: `Evision.Mat.t()`.\n\n  vector of colors which are 4-float vectors\n\nThe order of normals corresponds to order of points.\nThe order of points is undefined.\n\nPython prototype (for reference only):\n```python3\ngetCloud([, points[, normals[, colors]]]) -> points, normals, colors\n```","ref":"Evision.ColoredKinFu.ColoredKinFu.html#getCloud/1"},{"type":"function","title":"Evision.ColoredKinFu.ColoredKinFu.getCloud/2","doc":"Gets points, normals and colors of current 3d mesh\n\n##### Positional Arguments\n- **self**: `Evision.ColoredKinFu.ColoredKinFu.t()`\n\n##### Return\n- **points**: `Evision.Mat.t()`.\n\n  vector of points which are 4-float vectors\n\n- **normals**: `Evision.Mat.t()`.\n\n  vector of normals which are 4-float vectors\n\n- **colors**: `Evision.Mat.t()`.\n\n  vector of colors which are 4-float vectors\n\nThe order of normals corresponds to order of points.\nThe order of points is undefined.\n\nPython prototype (for reference only):\n```python3\ngetCloud([, points[, normals[, colors]]]) -> points, normals, colors\n```","ref":"Evision.ColoredKinFu.ColoredKinFu.html#getCloud/2"},{"type":"function","title":"Evision.ColoredKinFu.ColoredKinFu.getNormals/1","doc":"","ref":"Evision.ColoredKinFu.ColoredKinFu.html#getNormals/1"},{"type":"function","title":"Evision.ColoredKinFu.ColoredKinFu.getNormals/2","doc":"Calculates normals for given points\n\n##### Positional Arguments\n- **self**: `Evision.ColoredKinFu.ColoredKinFu.t()`\n- **points**: `Evision.Mat`.\n\n  input vector of points which are 4-float vectors\n\n##### Return\n- **normals**: `Evision.Mat.t()`.\n\n  output vector of corresponding normals which are 4-float vectors\n\nPython prototype (for reference only):\n```python3\ngetNormals(points[, normals]) -> normals\n```","ref":"Evision.ColoredKinFu.ColoredKinFu.html#getNormals/2"},{"type":"function","title":"Evision.ColoredKinFu.ColoredKinFu.getNormals/3","doc":"Calculates normals for given points\n\n##### Positional Arguments\n- **self**: `Evision.ColoredKinFu.ColoredKinFu.t()`\n- **points**: `Evision.Mat`.\n\n  input vector of points which are 4-float vectors\n\n##### Return\n- **normals**: `Evision.Mat.t()`.\n\n  output vector of corresponding normals which are 4-float vectors\n\nPython prototype (for reference only):\n```python3\ngetNormals(points[, normals]) -> normals\n```","ref":"Evision.ColoredKinFu.ColoredKinFu.html#getNormals/3"},{"type":"function","title":"Evision.ColoredKinFu.ColoredKinFu.getPoints/1","doc":"Gets points of current 3d mesh\n\n##### Positional Arguments\n- **self**: `Evision.ColoredKinFu.ColoredKinFu.t()`\n\n##### Return\n- **points**: `Evision.Mat.t()`.\n\n  vector of points which are 4-float vectors\n\nThe order of points is undefined.\n\nPython prototype (for reference only):\n```python3\ngetPoints([, points]) -> points\n```","ref":"Evision.ColoredKinFu.ColoredKinFu.html#getPoints/1"},{"type":"function","title":"Evision.ColoredKinFu.ColoredKinFu.getPoints/2","doc":"Gets points of current 3d mesh\n\n##### Positional Arguments\n- **self**: `Evision.ColoredKinFu.ColoredKinFu.t()`\n\n##### Return\n- **points**: `Evision.Mat.t()`.\n\n  vector of points which are 4-float vectors\n\nThe order of points is undefined.\n\nPython prototype (for reference only):\n```python3\ngetPoints([, points]) -> points\n```","ref":"Evision.ColoredKinFu.ColoredKinFu.html#getPoints/2"},{"type":"function","title":"Evision.ColoredKinFu.ColoredKinFu.render/1","doc":"Renders a volume into an image\n\n##### Positional Arguments\n- **self**: `Evision.ColoredKinFu.ColoredKinFu.t()`\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  resulting image\n\nRenders a 0-surface of TSDF using Phong shading into a CV_8UC4 Mat.\nLight pose is fixed in KinFu params.\n\nPython prototype (for reference only):\n```python3\nrender([, image]) -> image\n```","ref":"Evision.ColoredKinFu.ColoredKinFu.html#render/1"},{"type":"function","title":"Evision.ColoredKinFu.ColoredKinFu.render/2","doc":"#### Variant 1:\nRenders a volume into an image\n\n##### Positional Arguments\n- **self**: `Evision.ColoredKinFu.ColoredKinFu.t()`\n- **cameraPose**: `Evision.Mat`.\n\n  pose of camera to render from. If empty then render from current pose\n  which is a last frame camera pose.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  resulting image\n\nRenders a 0-surface of TSDF using Phong shading into a CV_8UC4 Mat.\nLight pose is fixed in KinFu params.\n\nPython prototype (for reference only):\n```python3\nrender(cameraPose[, image]) -> image\n```\n#### Variant 2:\nRenders a volume into an image\n\n##### Positional Arguments\n- **self**: `Evision.ColoredKinFu.ColoredKinFu.t()`\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  resulting image\n\nRenders a 0-surface of TSDF using Phong shading into a CV_8UC4 Mat.\nLight pose is fixed in KinFu params.\n\nPython prototype (for reference only):\n```python3\nrender([, image]) -> image\n```","ref":"Evision.ColoredKinFu.ColoredKinFu.html#render/2"},{"type":"function","title":"Evision.ColoredKinFu.ColoredKinFu.render/3","doc":"Renders a volume into an image\n\n##### Positional Arguments\n- **self**: `Evision.ColoredKinFu.ColoredKinFu.t()`\n- **cameraPose**: `Evision.Mat`.\n\n  pose of camera to render from. If empty then render from current pose\n  which is a last frame camera pose.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  resulting image\n\nRenders a 0-surface of TSDF using Phong shading into a CV_8UC4 Mat.\nLight pose is fixed in KinFu params.\n\nPython prototype (for reference only):\n```python3\nrender(cameraPose[, image]) -> image\n```","ref":"Evision.ColoredKinFu.ColoredKinFu.html#render/3"},{"type":"function","title":"Evision.ColoredKinFu.ColoredKinFu.reset/1","doc":"Resets the algorithm\n\n##### Positional Arguments\n- **self**: `Evision.ColoredKinFu.ColoredKinFu.t()`\n\nClears current model and resets a pose.\n\nPython prototype (for reference only):\n```python3\nreset() -> None\n```","ref":"Evision.ColoredKinFu.ColoredKinFu.html#reset/1"},{"type":"function","title":"Evision.ColoredKinFu.ColoredKinFu.update/1","doc":"","ref":"Evision.ColoredKinFu.ColoredKinFu.html#update/1"},{"type":"function","title":"Evision.ColoredKinFu.ColoredKinFu.update/3","doc":"Process next depth frame\n\n##### Positional Arguments\n- **self**: `Evision.ColoredKinFu.ColoredKinFu.t()`\n- **depth**: `Evision.Mat`.\n\n  input Mat of depth frame\n\n- **rgb**: `Evision.Mat`.\n\n  input Mat of rgb (colored) frame\n\n##### Return\n- **retval**: `bool`\n\n@return true if succeeded to align new frame with current scene, false if opposite\n\nPython prototype (for reference only):\n```python3\nupdate(depth, rgb) -> retval\n```","ref":"Evision.ColoredKinFu.ColoredKinFu.html#update/3"},{"type":"type","title":"Evision.ColoredKinFu.ColoredKinFu.t/0","doc":"Type that represents an `ColoredKinFu.ColoredKinFu` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ColoredKinFu.ColoredKinFu.html#t:t/0"},{"type":"module","title":"Evision.ColoredKinFu.Params","doc":"","ref":"Evision.ColoredKinFu.Params.html"},{"type":"function","title":"Evision.ColoredKinFu.Params.coarseParams/0","doc":"Coarse parameters\nA set of parameters which provides better speed, can fail to match frames\nin case of rapid sensor motion.\n\n##### Return\n- **retval**: `Params`\n\nPython prototype (for reference only):\n```python3\ncoarseParams() -> retval\n```","ref":"Evision.ColoredKinFu.Params.html#coarseParams/0"},{"type":"function","title":"Evision.ColoredKinFu.Params.coarseParams/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#coarseParams/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.coloredTSDFParams/1","doc":"ColoredTSDF parameters\nA set of parameters suitable for use with HashTSDFVolume\n\n##### Positional Arguments\n- **isCoarse**: `bool`\n\n##### Return\n- **retval**: `Params`\n\nPython prototype (for reference only):\n```python3\ncoloredTSDFParams(isCoarse) -> retval\n```","ref":"Evision.ColoredKinFu.Params.html#coloredTSDFParams/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.defaultParams/0","doc":"Default parameters\nA set of parameters which provides better model quality, can be very slow.\n\n##### Return\n- **retval**: `Params`\n\nPython prototype (for reference only):\n```python3\ndefaultParams() -> retval\n```","ref":"Evision.ColoredKinFu.Params.html#defaultParams/0"},{"type":"function","title":"Evision.ColoredKinFu.Params.defaultParams/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#defaultParams/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.get_bilateral_kernel_size/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#get_bilateral_kernel_size/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.get_bilateral_sigma_depth/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#get_bilateral_sigma_depth/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.get_bilateral_sigma_spatial/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#get_bilateral_sigma_spatial/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.get_depthFactor/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#get_depthFactor/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.get_frameSize/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#get_frameSize/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.get_icpAngleThresh/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#get_icpAngleThresh/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.get_icpDistThresh/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#get_icpDistThresh/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.get_icpIterations/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#get_icpIterations/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.get_intr/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#get_intr/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.get_lightPose/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#get_lightPose/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.get_pyramidLevels/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#get_pyramidLevels/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.get_raycast_step_factor/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#get_raycast_step_factor/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.get_rgb_frameSize/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#get_rgb_frameSize/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.get_rgb_intr/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#get_rgb_intr/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.get_truncateThreshold/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#get_truncateThreshold/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.get_tsdf_max_weight/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#get_tsdf_max_weight/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.get_tsdf_min_camera_movement/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#get_tsdf_min_camera_movement/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.get_tsdf_trunc_dist/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#get_tsdf_trunc_dist/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.get_volumeDims/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#get_volumeDims/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.get_volumeType/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#get_volumeType/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.get_voxelSize/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#get_voxelSize/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.hashTSDFParams/1","doc":"HashTSDF parameters\nA set of parameters suitable for use with HashTSDFVolume\n\n##### Positional Arguments\n- **isCoarse**: `bool`\n\n##### Return\n- **retval**: `Params`\n\nPython prototype (for reference only):\n```python3\nhashTSDFParams(isCoarse) -> retval\n```","ref":"Evision.ColoredKinFu.Params.html#hashTSDFParams/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.params/0","doc":"Params\n##### Return\n- **self**: `Params`\n\nPython prototype (for reference only):\n```python3\nParams() ->  \n```","ref":"Evision.ColoredKinFu.Params.html#params/0"},{"type":"function","title":"Evision.ColoredKinFu.Params.params/1","doc":"Constructor for Params\nSets the initial pose of the TSDF volume.\n\n##### Positional Arguments\n- **volumeInitialPose**: `Evision.Mat`.\n\n  4 by 4 Homogeneous Transform matrix to set the intial pose of TSDF volume\n\n##### Return\n- **self**: `Params`\n\nPython prototype (for reference only):\n```python3\nParams(volumeInitialPose) ->  \n```","ref":"Evision.ColoredKinFu.Params.html#params/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.params/2","doc":"Constructor for Params\nSets the initial pose of the TSDF volume.\n\n##### Positional Arguments\n- **volumeInitialPoseRot**: `Evision.Mat`.\n\n  rotation matrix\n\n- **volumeInitialPoseTransl**: `Vec3f`.\n\n  translation vector\n\n##### Return\n- **self**: `Params`\n\nPython prototype (for reference only):\n```python3\nParams(volumeInitialPoseRot, volumeInitialPoseTransl) ->  \n```","ref":"Evision.ColoredKinFu.Params.html#params/2"},{"type":"function","title":"Evision.ColoredKinFu.Params.set_bilateral_kernel_size/2","doc":"","ref":"Evision.ColoredKinFu.Params.html#set_bilateral_kernel_size/2"},{"type":"function","title":"Evision.ColoredKinFu.Params.set_bilateral_sigma_depth/2","doc":"","ref":"Evision.ColoredKinFu.Params.html#set_bilateral_sigma_depth/2"},{"type":"function","title":"Evision.ColoredKinFu.Params.set_bilateral_sigma_spatial/2","doc":"","ref":"Evision.ColoredKinFu.Params.html#set_bilateral_sigma_spatial/2"},{"type":"function","title":"Evision.ColoredKinFu.Params.set_depthFactor/2","doc":"","ref":"Evision.ColoredKinFu.Params.html#set_depthFactor/2"},{"type":"function","title":"Evision.ColoredKinFu.Params.set_frameSize/2","doc":"","ref":"Evision.ColoredKinFu.Params.html#set_frameSize/2"},{"type":"function","title":"Evision.ColoredKinFu.Params.set_icpAngleThresh/2","doc":"","ref":"Evision.ColoredKinFu.Params.html#set_icpAngleThresh/2"},{"type":"function","title":"Evision.ColoredKinFu.Params.set_icpDistThresh/2","doc":"","ref":"Evision.ColoredKinFu.Params.html#set_icpDistThresh/2"},{"type":"function","title":"Evision.ColoredKinFu.Params.set_icpIterations/2","doc":"","ref":"Evision.ColoredKinFu.Params.html#set_icpIterations/2"},{"type":"function","title":"Evision.ColoredKinFu.Params.set_intr/2","doc":"","ref":"Evision.ColoredKinFu.Params.html#set_intr/2"},{"type":"function","title":"Evision.ColoredKinFu.Params.set_lightPose/2","doc":"","ref":"Evision.ColoredKinFu.Params.html#set_lightPose/2"},{"type":"function","title":"Evision.ColoredKinFu.Params.set_pyramidLevels/2","doc":"","ref":"Evision.ColoredKinFu.Params.html#set_pyramidLevels/2"},{"type":"function","title":"Evision.ColoredKinFu.Params.set_raycast_step_factor/2","doc":"","ref":"Evision.ColoredKinFu.Params.html#set_raycast_step_factor/2"},{"type":"function","title":"Evision.ColoredKinFu.Params.set_rgb_frameSize/2","doc":"","ref":"Evision.ColoredKinFu.Params.html#set_rgb_frameSize/2"},{"type":"function","title":"Evision.ColoredKinFu.Params.set_rgb_intr/2","doc":"","ref":"Evision.ColoredKinFu.Params.html#set_rgb_intr/2"},{"type":"function","title":"Evision.ColoredKinFu.Params.set_truncateThreshold/2","doc":"","ref":"Evision.ColoredKinFu.Params.html#set_truncateThreshold/2"},{"type":"function","title":"Evision.ColoredKinFu.Params.set_tsdf_max_weight/2","doc":"","ref":"Evision.ColoredKinFu.Params.html#set_tsdf_max_weight/2"},{"type":"function","title":"Evision.ColoredKinFu.Params.set_tsdf_min_camera_movement/2","doc":"","ref":"Evision.ColoredKinFu.Params.html#set_tsdf_min_camera_movement/2"},{"type":"function","title":"Evision.ColoredKinFu.Params.set_tsdf_trunc_dist/2","doc":"","ref":"Evision.ColoredKinFu.Params.html#set_tsdf_trunc_dist/2"},{"type":"function","title":"Evision.ColoredKinFu.Params.set_volumeDims/2","doc":"","ref":"Evision.ColoredKinFu.Params.html#set_volumeDims/2"},{"type":"function","title":"Evision.ColoredKinFu.Params.set_volumeType/2","doc":"","ref":"Evision.ColoredKinFu.Params.html#set_volumeType/2"},{"type":"function","title":"Evision.ColoredKinFu.Params.set_voxelSize/2","doc":"","ref":"Evision.ColoredKinFu.Params.html#set_voxelSize/2"},{"type":"function","title":"Evision.ColoredKinFu.Params.setInitialVolumePose/1","doc":"","ref":"Evision.ColoredKinFu.Params.html#setInitialVolumePose/1"},{"type":"function","title":"Evision.ColoredKinFu.Params.setInitialVolumePose/2","doc":"Set Initial Volume Pose\nSets the initial pose of the TSDF volume.\n\n##### Positional Arguments\n- **self**: `Evision.ColoredKinFu.Params.t()`\n- **homogen_tf**: `Evision.Mat`.\n\n  4 by 4 Homogeneous Transform matrix to set the intial pose of TSDF volume\n\nPython prototype (for reference only):\n```python3\nsetInitialVolumePose(homogen_tf) -> None\n```","ref":"Evision.ColoredKinFu.Params.html#setInitialVolumePose/2"},{"type":"function","title":"Evision.ColoredKinFu.Params.setInitialVolumePose/3","doc":"Set Initial Volume Pose\nSets the initial pose of the TSDF volume.\n\n##### Positional Arguments\n- **self**: `Evision.ColoredKinFu.Params.t()`\n- **r**: `Evision.Mat`.\n\n  rotation matrix\n\n- **t**: `Vec3f`.\n\n  translation vector\n\nPython prototype (for reference only):\n```python3\nsetInitialVolumePose(R, t) -> None\n```","ref":"Evision.ColoredKinFu.Params.html#setInitialVolumePose/3"},{"type":"type","title":"Evision.ColoredKinFu.Params.t/0","doc":"Type that represents an `ColoredKinFu.Params` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ColoredKinFu.Params.html#t:t/0"},{"type":"module","title":"Evision.ColormapTypes","doc":"","ref":"Evision.ColormapTypes.html"},{"type":"function","title":"Evision.ColormapTypes.cv_COLORMAP_AUTUMN/0","doc":"","ref":"Evision.ColormapTypes.html#cv_COLORMAP_AUTUMN/0"},{"type":"function","title":"Evision.ColormapTypes.cv_COLORMAP_BONE/0","doc":"","ref":"Evision.ColormapTypes.html#cv_COLORMAP_BONE/0"},{"type":"function","title":"Evision.ColormapTypes.cv_COLORMAP_CIVIDIS/0","doc":"","ref":"Evision.ColormapTypes.html#cv_COLORMAP_CIVIDIS/0"},{"type":"function","title":"Evision.ColormapTypes.cv_COLORMAP_COOL/0","doc":"","ref":"Evision.ColormapTypes.html#cv_COLORMAP_COOL/0"},{"type":"function","title":"Evision.ColormapTypes.cv_COLORMAP_DEEPGREEN/0","doc":"","ref":"Evision.ColormapTypes.html#cv_COLORMAP_DEEPGREEN/0"},{"type":"function","title":"Evision.ColormapTypes.cv_COLORMAP_HOT/0","doc":"","ref":"Evision.ColormapTypes.html#cv_COLORMAP_HOT/0"},{"type":"function","title":"Evision.ColormapTypes.cv_COLORMAP_HSV/0","doc":"","ref":"Evision.ColormapTypes.html#cv_COLORMAP_HSV/0"},{"type":"function","title":"Evision.ColormapTypes.cv_COLORMAP_INFERNO/0","doc":"","ref":"Evision.ColormapTypes.html#cv_COLORMAP_INFERNO/0"},{"type":"function","title":"Evision.ColormapTypes.cv_COLORMAP_JET/0","doc":"","ref":"Evision.ColormapTypes.html#cv_COLORMAP_JET/0"},{"type":"function","title":"Evision.ColormapTypes.cv_COLORMAP_MAGMA/0","doc":"","ref":"Evision.ColormapTypes.html#cv_COLORMAP_MAGMA/0"},{"type":"function","title":"Evision.ColormapTypes.cv_COLORMAP_OCEAN/0","doc":"","ref":"Evision.ColormapTypes.html#cv_COLORMAP_OCEAN/0"},{"type":"function","title":"Evision.ColormapTypes.cv_COLORMAP_PARULA/0","doc":"","ref":"Evision.ColormapTypes.html#cv_COLORMAP_PARULA/0"},{"type":"function","title":"Evision.ColormapTypes.cv_COLORMAP_PINK/0","doc":"","ref":"Evision.ColormapTypes.html#cv_COLORMAP_PINK/0"},{"type":"function","title":"Evision.ColormapTypes.cv_COLORMAP_PLASMA/0","doc":"","ref":"Evision.ColormapTypes.html#cv_COLORMAP_PLASMA/0"},{"type":"function","title":"Evision.ColormapTypes.cv_COLORMAP_RAINBOW/0","doc":"","ref":"Evision.ColormapTypes.html#cv_COLORMAP_RAINBOW/0"},{"type":"function","title":"Evision.ColormapTypes.cv_COLORMAP_SPRING/0","doc":"","ref":"Evision.ColormapTypes.html#cv_COLORMAP_SPRING/0"},{"type":"function","title":"Evision.ColormapTypes.cv_COLORMAP_SUMMER/0","doc":"","ref":"Evision.ColormapTypes.html#cv_COLORMAP_SUMMER/0"},{"type":"function","title":"Evision.ColormapTypes.cv_COLORMAP_TURBO/0","doc":"","ref":"Evision.ColormapTypes.html#cv_COLORMAP_TURBO/0"},{"type":"function","title":"Evision.ColormapTypes.cv_COLORMAP_TWILIGHT/0","doc":"","ref":"Evision.ColormapTypes.html#cv_COLORMAP_TWILIGHT/0"},{"type":"function","title":"Evision.ColormapTypes.cv_COLORMAP_TWILIGHT_SHIFTED/0","doc":"","ref":"Evision.ColormapTypes.html#cv_COLORMAP_TWILIGHT_SHIFTED/0"},{"type":"function","title":"Evision.ColormapTypes.cv_COLORMAP_VIRIDIS/0","doc":"","ref":"Evision.ColormapTypes.html#cv_COLORMAP_VIRIDIS/0"},{"type":"function","title":"Evision.ColormapTypes.cv_COLORMAP_WINTER/0","doc":"","ref":"Evision.ColormapTypes.html#cv_COLORMAP_WINTER/0"},{"type":"type","title":"Evision.ColormapTypes.enum/0","doc":"","ref":"Evision.ColormapTypes.html#t:enum/0"},{"type":"module","title":"Evision.ConnectedComponentsAlgorithmsTypes","doc":"","ref":"Evision.ConnectedComponentsAlgorithmsTypes.html"},{"type":"function","title":"Evision.ConnectedComponentsAlgorithmsTypes.cv_CCL_BBDT/0","doc":"","ref":"Evision.ConnectedComponentsAlgorithmsTypes.html#cv_CCL_BBDT/0"},{"type":"function","title":"Evision.ConnectedComponentsAlgorithmsTypes.cv_CCL_BOLELLI/0","doc":"","ref":"Evision.ConnectedComponentsAlgorithmsTypes.html#cv_CCL_BOLELLI/0"},{"type":"function","title":"Evision.ConnectedComponentsAlgorithmsTypes.cv_CCL_DEFAULT/0","doc":"","ref":"Evision.ConnectedComponentsAlgorithmsTypes.html#cv_CCL_DEFAULT/0"},{"type":"function","title":"Evision.ConnectedComponentsAlgorithmsTypes.cv_CCL_GRANA/0","doc":"","ref":"Evision.ConnectedComponentsAlgorithmsTypes.html#cv_CCL_GRANA/0"},{"type":"function","title":"Evision.ConnectedComponentsAlgorithmsTypes.cv_CCL_SAUF/0","doc":"","ref":"Evision.ConnectedComponentsAlgorithmsTypes.html#cv_CCL_SAUF/0"},{"type":"function","title":"Evision.ConnectedComponentsAlgorithmsTypes.cv_CCL_SPAGHETTI/0","doc":"","ref":"Evision.ConnectedComponentsAlgorithmsTypes.html#cv_CCL_SPAGHETTI/0"},{"type":"function","title":"Evision.ConnectedComponentsAlgorithmsTypes.cv_CCL_WU/0","doc":"","ref":"Evision.ConnectedComponentsAlgorithmsTypes.html#cv_CCL_WU/0"},{"type":"type","title":"Evision.ConnectedComponentsAlgorithmsTypes.enum/0","doc":"","ref":"Evision.ConnectedComponentsAlgorithmsTypes.html#t:enum/0"},{"type":"module","title":"Evision.ConnectedComponentsTypes","doc":"","ref":"Evision.ConnectedComponentsTypes.html"},{"type":"function","title":"Evision.ConnectedComponentsTypes.cv_CC_STAT_AREA/0","doc":"","ref":"Evision.ConnectedComponentsTypes.html#cv_CC_STAT_AREA/0"},{"type":"function","title":"Evision.ConnectedComponentsTypes.cv_CC_STAT_HEIGHT/0","doc":"","ref":"Evision.ConnectedComponentsTypes.html#cv_CC_STAT_HEIGHT/0"},{"type":"function","title":"Evision.ConnectedComponentsTypes.cv_CC_STAT_LEFT/0","doc":"","ref":"Evision.ConnectedComponentsTypes.html#cv_CC_STAT_LEFT/0"},{"type":"function","title":"Evision.ConnectedComponentsTypes.cv_CC_STAT_MAX/0","doc":"","ref":"Evision.ConnectedComponentsTypes.html#cv_CC_STAT_MAX/0"},{"type":"function","title":"Evision.ConnectedComponentsTypes.cv_CC_STAT_TOP/0","doc":"","ref":"Evision.ConnectedComponentsTypes.html#cv_CC_STAT_TOP/0"},{"type":"function","title":"Evision.ConnectedComponentsTypes.cv_CC_STAT_WIDTH/0","doc":"","ref":"Evision.ConnectedComponentsTypes.html#cv_CC_STAT_WIDTH/0"},{"type":"type","title":"Evision.ConnectedComponentsTypes.enum/0","doc":"","ref":"Evision.ConnectedComponentsTypes.html#t:enum/0"},{"type":"module","title":"Evision.Constant","doc":"","ref":"Evision.Constant.html"},{"type":"function","title":"Evision.Constant.cv_8S/0","doc":"","ref":"Evision.Constant.html#cv_8S/0"},{"type":"function","title":"Evision.Constant.cv_8SC1/0","doc":"","ref":"Evision.Constant.html#cv_8SC1/0"},{"type":"function","title":"Evision.Constant.cv_8SC2/0","doc":"","ref":"Evision.Constant.html#cv_8SC2/0"},{"type":"function","title":"Evision.Constant.cv_8SC3/0","doc":"","ref":"Evision.Constant.html#cv_8SC3/0"},{"type":"function","title":"Evision.Constant.cv_8SC4/0","doc":"","ref":"Evision.Constant.html#cv_8SC4/0"},{"type":"function","title":"Evision.Constant.cv_8SC/1","doc":"","ref":"Evision.Constant.html#cv_8SC/1"},{"type":"function","title":"Evision.Constant.cv_8U/0","doc":"","ref":"Evision.Constant.html#cv_8U/0"},{"type":"function","title":"Evision.Constant.cv_8UC1/0","doc":"","ref":"Evision.Constant.html#cv_8UC1/0"},{"type":"function","title":"Evision.Constant.cv_8UC2/0","doc":"","ref":"Evision.Constant.html#cv_8UC2/0"},{"type":"function","title":"Evision.Constant.cv_8UC3/0","doc":"","ref":"Evision.Constant.html#cv_8UC3/0"},{"type":"function","title":"Evision.Constant.cv_8UC4/0","doc":"","ref":"Evision.Constant.html#cv_8UC4/0"},{"type":"function","title":"Evision.Constant.cv_8UC/1","doc":"","ref":"Evision.Constant.html#cv_8UC/1"},{"type":"function","title":"Evision.Constant.cv_16F/0","doc":"","ref":"Evision.Constant.html#cv_16F/0"},{"type":"function","title":"Evision.Constant.cv_16FC1/0","doc":"","ref":"Evision.Constant.html#cv_16FC1/0"},{"type":"function","title":"Evision.Constant.cv_16FC2/0","doc":"","ref":"Evision.Constant.html#cv_16FC2/0"},{"type":"function","title":"Evision.Constant.cv_16FC3/0","doc":"","ref":"Evision.Constant.html#cv_16FC3/0"},{"type":"function","title":"Evision.Constant.cv_16FC4/0","doc":"","ref":"Evision.Constant.html#cv_16FC4/0"},{"type":"function","title":"Evision.Constant.cv_16FC/1","doc":"","ref":"Evision.Constant.html#cv_16FC/1"},{"type":"function","title":"Evision.Constant.cv_16S/0","doc":"","ref":"Evision.Constant.html#cv_16S/0"},{"type":"function","title":"Evision.Constant.cv_16SC1/0","doc":"","ref":"Evision.Constant.html#cv_16SC1/0"},{"type":"function","title":"Evision.Constant.cv_16SC2/0","doc":"","ref":"Evision.Constant.html#cv_16SC2/0"},{"type":"function","title":"Evision.Constant.cv_16SC3/0","doc":"","ref":"Evision.Constant.html#cv_16SC3/0"},{"type":"function","title":"Evision.Constant.cv_16SC4/0","doc":"","ref":"Evision.Constant.html#cv_16SC4/0"},{"type":"function","title":"Evision.Constant.cv_16SC/1","doc":"","ref":"Evision.Constant.html#cv_16SC/1"},{"type":"function","title":"Evision.Constant.cv_16U/0","doc":"","ref":"Evision.Constant.html#cv_16U/0"},{"type":"function","title":"Evision.Constant.cv_16UC1/0","doc":"","ref":"Evision.Constant.html#cv_16UC1/0"},{"type":"function","title":"Evision.Constant.cv_16UC2/0","doc":"","ref":"Evision.Constant.html#cv_16UC2/0"},{"type":"function","title":"Evision.Constant.cv_16UC3/0","doc":"","ref":"Evision.Constant.html#cv_16UC3/0"},{"type":"function","title":"Evision.Constant.cv_16UC4/0","doc":"","ref":"Evision.Constant.html#cv_16UC4/0"},{"type":"function","title":"Evision.Constant.cv_16UC/1","doc":"","ref":"Evision.Constant.html#cv_16UC/1"},{"type":"function","title":"Evision.Constant.cv_32F/0","doc":"","ref":"Evision.Constant.html#cv_32F/0"},{"type":"function","title":"Evision.Constant.cv_32FC1/0","doc":"","ref":"Evision.Constant.html#cv_32FC1/0"},{"type":"function","title":"Evision.Constant.cv_32FC2/0","doc":"","ref":"Evision.Constant.html#cv_32FC2/0"},{"type":"function","title":"Evision.Constant.cv_32FC3/0","doc":"","ref":"Evision.Constant.html#cv_32FC3/0"},{"type":"function","title":"Evision.Constant.cv_32FC4/0","doc":"","ref":"Evision.Constant.html#cv_32FC4/0"},{"type":"function","title":"Evision.Constant.cv_32FC/1","doc":"","ref":"Evision.Constant.html#cv_32FC/1"},{"type":"function","title":"Evision.Constant.cv_32S/0","doc":"","ref":"Evision.Constant.html#cv_32S/0"},{"type":"function","title":"Evision.Constant.cv_32SC1/0","doc":"","ref":"Evision.Constant.html#cv_32SC1/0"},{"type":"function","title":"Evision.Constant.cv_32SC2/0","doc":"","ref":"Evision.Constant.html#cv_32SC2/0"},{"type":"function","title":"Evision.Constant.cv_32SC3/0","doc":"","ref":"Evision.Constant.html#cv_32SC3/0"},{"type":"function","title":"Evision.Constant.cv_32SC4/0","doc":"","ref":"Evision.Constant.html#cv_32SC4/0"},{"type":"function","title":"Evision.Constant.cv_32SC/1","doc":"","ref":"Evision.Constant.html#cv_32SC/1"},{"type":"function","title":"Evision.Constant.cv_64F/0","doc":"","ref":"Evision.Constant.html#cv_64F/0"},{"type":"function","title":"Evision.Constant.cv_64FC1/0","doc":"","ref":"Evision.Constant.html#cv_64FC1/0"},{"type":"function","title":"Evision.Constant.cv_64FC2/0","doc":"","ref":"Evision.Constant.html#cv_64FC2/0"},{"type":"function","title":"Evision.Constant.cv_64FC3/0","doc":"","ref":"Evision.Constant.html#cv_64FC3/0"},{"type":"function","title":"Evision.Constant.cv_64FC4/0","doc":"","ref":"Evision.Constant.html#cv_64FC4/0"},{"type":"function","title":"Evision.Constant.cv_64FC/1","doc":"","ref":"Evision.Constant.html#cv_64FC/1"},{"type":"function","title":"Evision.Constant.cv_ACCESS_FAST/0","doc":"","ref":"Evision.Constant.html#cv_ACCESS_FAST/0"},{"type":"function","title":"Evision.Constant.cv_ACCESS_MASK/0","doc":"","ref":"Evision.Constant.html#cv_ACCESS_MASK/0"},{"type":"function","title":"Evision.Constant.cv_ACCESS_READ/0","doc":"","ref":"Evision.Constant.html#cv_ACCESS_READ/0"},{"type":"function","title":"Evision.Constant.cv_ACCESS_RW/0","doc":"","ref":"Evision.Constant.html#cv_ACCESS_RW/0"},{"type":"function","title":"Evision.Constant.cv_ACCESS_WRITE/0","doc":"","ref":"Evision.Constant.html#cv_ACCESS_WRITE/0"},{"type":"function","title":"Evision.Constant.cv_ADAPTIVE_THRESH_GAUSSIAN_C/0","doc":"","ref":"Evision.Constant.html#cv_ADAPTIVE_THRESH_GAUSSIAN_C/0"},{"type":"function","title":"Evision.Constant.cv_ADAPTIVE_THRESH_MEAN_C/0","doc":"","ref":"Evision.Constant.html#cv_ADAPTIVE_THRESH_MEAN_C/0"},{"type":"function","title":"Evision.Constant.cv_Adaptive/0","doc":"","ref":"Evision.Constant.html#cv_Adaptive/0"},{"type":"function","title":"Evision.Constant.cv_AGAST_5_8/0","doc":"","ref":"Evision.Constant.html#cv_AGAST_5_8/0"},{"type":"function","title":"Evision.Constant.cv_AGAST_7_12d/0","doc":"","ref":"Evision.Constant.html#cv_AGAST_7_12d/0"},{"type":"function","title":"Evision.Constant.cv_AGAST_7_12s/0","doc":"","ref":"Evision.Constant.html#cv_AGAST_7_12s/0"},{"type":"function","title":"Evision.Constant.cv_ALGORITHM/0","doc":"","ref":"Evision.Constant.html#cv_ALGORITHM/0"},{"type":"function","title":"Evision.Constant.cv_ALPHA_ATOP/0","doc":"","ref":"Evision.Constant.html#cv_ALPHA_ATOP/0"},{"type":"function","title":"Evision.Constant.cv_ALPHA_ATOP_PREMUL/0","doc":"","ref":"Evision.Constant.html#cv_ALPHA_ATOP_PREMUL/0"},{"type":"function","title":"Evision.Constant.cv_ALPHA_IN/0","doc":"","ref":"Evision.Constant.html#cv_ALPHA_IN/0"},{"type":"function","title":"Evision.Constant.cv_ALPHA_IN_PREMUL/0","doc":"","ref":"Evision.Constant.html#cv_ALPHA_IN_PREMUL/0"},{"type":"function","title":"Evision.Constant.cv_ALPHA_OUT/0","doc":"","ref":"Evision.Constant.html#cv_ALPHA_OUT/0"},{"type":"function","title":"Evision.Constant.cv_ALPHA_OUT_PREMUL/0","doc":"","ref":"Evision.Constant.html#cv_ALPHA_OUT_PREMUL/0"},{"type":"function","title":"Evision.Constant.cv_ALPHA_OVER/0","doc":"","ref":"Evision.Constant.html#cv_ALPHA_OVER/0"},{"type":"function","title":"Evision.Constant.cv_ALPHA_OVER_PREMUL/0","doc":"","ref":"Evision.Constant.html#cv_ALPHA_OVER_PREMUL/0"},{"type":"function","title":"Evision.Constant.cv_ALPHA_PLUS/0","doc":"","ref":"Evision.Constant.html#cv_ALPHA_PLUS/0"},{"type":"function","title":"Evision.Constant.cv_ALPHA_PLUS_PREMUL/0","doc":"","ref":"Evision.Constant.html#cv_ALPHA_PLUS_PREMUL/0"},{"type":"function","title":"Evision.Constant.cv_ALPHA_PREMUL/0","doc":"","ref":"Evision.Constant.html#cv_ALPHA_PREMUL/0"},{"type":"function","title":"Evision.Constant.cv_ALPHA_XOR/0","doc":"","ref":"Evision.Constant.html#cv_ALPHA_XOR/0"},{"type":"function","title":"Evision.Constant.cv_ALPHA_XOR_PREMUL/0","doc":"","ref":"Evision.Constant.html#cv_ALPHA_XOR_PREMUL/0"},{"type":"function","title":"Evision.Constant.cv_AM_FILTER/0","doc":"","ref":"Evision.Constant.html#cv_AM_FILTER/0"},{"type":"function","title":"Evision.Constant.cv_ANGLE_ROW/0","doc":"","ref":"Evision.Constant.html#cv_ANGLE_ROW/0"},{"type":"function","title":"Evision.Constant.cv_ANNEAL/0","doc":"","ref":"Evision.Constant.html#cv_ANNEAL/0"},{"type":"function","title":"Evision.Constant.cv_APPEND/0","doc":"","ref":"Evision.Constant.html#cv_APPEND/0"},{"type":"function","title":"Evision.Constant.cv_ARO_0_45/0","doc":"","ref":"Evision.Constant.html#cv_ARO_0_45/0"},{"type":"function","title":"Evision.Constant.cv_ARO_45_90/0","doc":"","ref":"Evision.Constant.html#cv_ARO_45_90/0"},{"type":"function","title":"Evision.Constant.cv_ARO_45_135/0","doc":"","ref":"Evision.Constant.html#cv_ARO_45_135/0"},{"type":"function","title":"Evision.Constant.cv_ARO_90_135/0","doc":"","ref":"Evision.Constant.html#cv_ARO_90_135/0"},{"type":"function","title":"Evision.Constant.cv_ARO_315_0/0","doc":"","ref":"Evision.Constant.html#cv_ARO_315_0/0"},{"type":"function","title":"Evision.Constant.cv_ARO_315_45/0","doc":"","ref":"Evision.Constant.html#cv_ARO_315_45/0"},{"type":"function","title":"Evision.Constant.cv_ARO_315_135/0","doc":"","ref":"Evision.Constant.html#cv_ARO_315_135/0"},{"type":"function","title":"Evision.Constant.cv_ARO_CTR_HOR/0","doc":"","ref":"Evision.Constant.html#cv_ARO_CTR_HOR/0"},{"type":"function","title":"Evision.Constant.cv_ARO_CTR_VER/0","doc":"","ref":"Evision.Constant.html#cv_ARO_CTR_VER/0"},{"type":"function","title":"Evision.Constant.cv_ARRAY_BUFFER/0","doc":"","ref":"Evision.Constant.html#cv_ARRAY_BUFFER/0"},{"type":"function","title":"Evision.Constant.cv_ARUCO_CCW_CENTER/0","doc":"","ref":"Evision.Constant.html#cv_ARUCO_CCW_CENTER/0"},{"type":"function","title":"Evision.Constant.cv_ARUCO_CW_TOP_LEFT_CORNER/0","doc":"","ref":"Evision.Constant.html#cv_ARUCO_CW_TOP_LEFT_CORNER/0"},{"type":"function","title":"Evision.Constant.cv_AS_IS/0","doc":"","ref":"Evision.Constant.html#cv_AS_IS/0"},{"type":"function","title":"Evision.Constant.cv_ASGD/0","doc":"","ref":"Evision.Constant.html#cv_ASGD/0"},{"type":"function","title":"Evision.Constant.cv_ASYMMETRIC_GRID/0","doc":"","ref":"Evision.Constant.html#cv_ASYMMETRIC_GRID/0"},{"type":"function","title":"Evision.Constant.cv_ASYNC_CLEANUP/0","doc":"","ref":"Evision.Constant.html#cv_ASYNC_CLEANUP/0"},{"type":"function","title":"Evision.Constant.cv_AUTO_STEP/0","doc":"","ref":"Evision.Constant.html#cv_AUTO_STEP/0"},{"type":"function","title":"Evision.Constant.cv_AV1/0","doc":"","ref":"Evision.Constant.html#cv_AV1/0"},{"type":"function","title":"Evision.Constant.cv_BACKPROP/0","doc":"","ref":"Evision.Constant.html#cv_BACKPROP/0"},{"type":"function","title":"Evision.Constant.cv_BASE64/0","doc":"","ref":"Evision.Constant.html#cv_BASE64/0"},{"type":"function","title":"Evision.Constant.cv_BATCH/0","doc":"","ref":"Evision.Constant.html#cv_BATCH/0"},{"type":"function","title":"Evision.Constant.cv_BadAlign/0","doc":"","ref":"Evision.Constant.html#cv_BadAlign/0"},{"type":"function","title":"Evision.Constant.cv_BadAlphaChannel/0","doc":"","ref":"Evision.Constant.html#cv_BadAlphaChannel/0"},{"type":"function","title":"Evision.Constant.cv_BadCallBack/0","doc":"","ref":"Evision.Constant.html#cv_BadCallBack/0"},{"type":"function","title":"Evision.Constant.cv_BadCOI/0","doc":"","ref":"Evision.Constant.html#cv_BadCOI/0"},{"type":"function","title":"Evision.Constant.cv_BadDataPtr/0","doc":"","ref":"Evision.Constant.html#cv_BadDataPtr/0"},{"type":"function","title":"Evision.Constant.cv_BadDepth/0","doc":"","ref":"Evision.Constant.html#cv_BadDepth/0"},{"type":"function","title":"Evision.Constant.cv_BadImageSize/0","doc":"","ref":"Evision.Constant.html#cv_BadImageSize/0"},{"type":"function","title":"Evision.Constant.cv_BadModelOrChSeq/0","doc":"","ref":"Evision.Constant.html#cv_BadModelOrChSeq/0"},{"type":"function","title":"Evision.Constant.cv_BadNumChannel1U/0","doc":"","ref":"Evision.Constant.html#cv_BadNumChannel1U/0"},{"type":"function","title":"Evision.Constant.cv_BadNumChannels/0","doc":"","ref":"Evision.Constant.html#cv_BadNumChannels/0"},{"type":"function","title":"Evision.Constant.cv_BadOffset/0","doc":"","ref":"Evision.Constant.html#cv_BadOffset/0"},{"type":"function","title":"Evision.Constant.cv_BadOrder/0","doc":"","ref":"Evision.Constant.html#cv_BadOrder/0"},{"type":"function","title":"Evision.Constant.cv_BadOrigin/0","doc":"","ref":"Evision.Constant.html#cv_BadOrigin/0"},{"type":"function","title":"Evision.Constant.cv_BadROISize/0","doc":"","ref":"Evision.Constant.html#cv_BadROISize/0"},{"type":"function","title":"Evision.Constant.cv_BadStep/0","doc":"","ref":"Evision.Constant.html#cv_BadStep/0"},{"type":"function","title":"Evision.Constant.cv_BadTileSize/0","doc":"","ref":"Evision.Constant.html#cv_BadTileSize/0"},{"type":"function","title":"Evision.Constant.cv_BGR/0","doc":"","ref":"Evision.Constant.html#cv_BGR/0"},{"type":"function","title":"Evision.Constant.cv_BGRA/0","doc":"","ref":"Evision.Constant.html#cv_BGRA/0"},{"type":"function","title":"Evision.Constant.cv_BINARIZATION_NIBLACK/0","doc":"","ref":"Evision.Constant.html#cv_BINARIZATION_NIBLACK/0"},{"type":"function","title":"Evision.Constant.cv_BINARIZATION_NICK/0","doc":"","ref":"Evision.Constant.html#cv_BINARIZATION_NICK/0"},{"type":"function","title":"Evision.Constant.cv_BINARIZATION_SAUVOLA/0","doc":"","ref":"Evision.Constant.html#cv_BINARIZATION_SAUVOLA/0"},{"type":"function","title":"Evision.Constant.cv_BINARIZATION_WOLF/0","doc":"","ref":"Evision.Constant.html#cv_BINARIZATION_WOLF/0"},{"type":"function","title":"Evision.Constant.cv_BLOCK_MEAN_HASH_MODE_0/0","doc":"","ref":"Evision.Constant.html#cv_BLOCK_MEAN_HASH_MODE_0/0"},{"type":"function","title":"Evision.Constant.cv_BLOCK_MEAN_HASH_MODE_1/0","doc":"","ref":"Evision.Constant.html#cv_BLOCK_MEAN_HASH_MODE_1/0"},{"type":"function","title":"Evision.Constant.cv_BLOCKING_SYNC/0","doc":"","ref":"Evision.Constant.html#cv_BLOCKING_SYNC/0"},{"type":"function","title":"Evision.Constant.cv_BM3D_STEP1/0","doc":"","ref":"Evision.Constant.html#cv_BM3D_STEP1/0"},{"type":"function","title":"Evision.Constant.cv_BM3D_STEP2/0","doc":"","ref":"Evision.Constant.html#cv_BM3D_STEP2/0"},{"type":"function","title":"Evision.Constant.cv_BM3D_STEPALL/0","doc":"","ref":"Evision.Constant.html#cv_BM3D_STEPALL/0"},{"type":"function","title":"Evision.Constant.cv_BOOLEAN/0","doc":"","ref":"Evision.Constant.html#cv_BOOLEAN/0"},{"type":"function","title":"Evision.Constant.cv_BORDER_CONSTANT/0","doc":"","ref":"Evision.Constant.html#cv_BORDER_CONSTANT/0"},{"type":"function","title":"Evision.Constant.cv_BORDER_DEFAULT/0","doc":"","ref":"Evision.Constant.html#cv_BORDER_DEFAULT/0"},{"type":"function","title":"Evision.Constant.cv_BORDER_ISOLATED/0","doc":"","ref":"Evision.Constant.html#cv_BORDER_ISOLATED/0"},{"type":"function","title":"Evision.Constant.cv_BORDER_REFLECT101/0","doc":"","ref":"Evision.Constant.html#cv_BORDER_REFLECT101/0"},{"type":"function","title":"Evision.Constant.cv_BORDER_REFLECT/0","doc":"","ref":"Evision.Constant.html#cv_BORDER_REFLECT/0"},{"type":"function","title":"Evision.Constant.cv_BORDER_REFLECT_101/0","doc":"","ref":"Evision.Constant.html#cv_BORDER_REFLECT_101/0"},{"type":"function","title":"Evision.Constant.cv_BORDER_REPLICATE/0","doc":"","ref":"Evision.Constant.html#cv_BORDER_REPLICATE/0"},{"type":"function","title":"Evision.Constant.cv_BORDER_TRANSPARENT/0","doc":"","ref":"Evision.Constant.html#cv_BORDER_TRANSPARENT/0"},{"type":"function","title":"Evision.Constant.cv_BORDER_WRAP/0","doc":"","ref":"Evision.Constant.html#cv_BORDER_WRAP/0"},{"type":"function","title":"Evision.Constant.cv_Bob/0","doc":"","ref":"Evision.Constant.html#cv_Bob/0"},{"type":"function","title":"Evision.Constant.cv_Boost_REAL/0","doc":"","ref":"Evision.Constant.html#cv_Boost_REAL/0"},{"type":"function","title":"Evision.Constant.cv_BRUTE_FORCE/0","doc":"","ref":"Evision.Constant.html#cv_BRUTE_FORCE/0"},{"type":"function","title":"Evision.Constant.cv_BRUTEFORCE/0","doc":"","ref":"Evision.Constant.html#cv_BRUTEFORCE/0"},{"type":"function","title":"Evision.Constant.cv_BRUTEFORCE_HAMMING/0","doc":"","ref":"Evision.Constant.html#cv_BRUTEFORCE_HAMMING/0"},{"type":"function","title":"Evision.Constant.cv_BRUTEFORCE_HAMMINGLUT/0","doc":"","ref":"Evision.Constant.html#cv_BRUTEFORCE_HAMMINGLUT/0"},{"type":"function","title":"Evision.Constant.cv_BRUTEFORCE_L1/0","doc":"","ref":"Evision.Constant.html#cv_BRUTEFORCE_L1/0"},{"type":"function","title":"Evision.Constant.cv_BRUTEFORCE_SL2/0","doc":"","ref":"Evision.Constant.html#cv_BRUTEFORCE_SL2/0"},{"type":"function","title":"Evision.Constant.cv_Buffer_READ_ONLY/0","doc":"","ref":"Evision.Constant.html#cv_Buffer_READ_ONLY/0"},{"type":"function","title":"Evision.Constant.cv_Buffer_READ_WRITE/0","doc":"","ref":"Evision.Constant.html#cv_Buffer_READ_WRITE/0"},{"type":"function","title":"Evision.Constant.cv_Buffer_WRITE_ONLY/0","doc":"","ref":"Evision.Constant.html#cv_Buffer_WRITE_ONLY/0"},{"type":"function","title":"Evision.Constant.cv_C/0","doc":"","ref":"Evision.Constant.html#cv_C/0"},{"type":"function","title":"Evision.Constant.cv_C_SVC/0","doc":"","ref":"Evision.Constant.html#cv_C_SVC/0"},{"type":"function","title":"Evision.Constant.cv_CACHE_ALL/0","doc":"","ref":"Evision.Constant.html#cv_CACHE_ALL/0"},{"type":"function","title":"Evision.Constant.cv_CACHE_DST/0","doc":"","ref":"Evision.Constant.html#cv_CACHE_DST/0"},{"type":"function","title":"Evision.Constant.cv_CACHE_SRC/0","doc":"","ref":"Evision.Constant.html#cv_CACHE_SRC/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_CB_ACCURACY/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_CB_ACCURACY/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_CB_ADAPTIVE_THRESH/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_CB_ADAPTIVE_THRESH/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_CB_ASYMMETRIC_GRID/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_CB_ASYMMETRIC_GRID/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_CB_CLUSTERING/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_CB_CLUSTERING/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_CB_EXHAUSTIVE/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_CB_EXHAUSTIVE/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_CB_FAST_CHECK/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_CB_FAST_CHECK/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_CB_FILTER_QUADS/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_CB_FILTER_QUADS/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_CB_LARGER/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_CB_LARGER/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_CB_MARKER/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_CB_MARKER/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_CB_NORMALIZE_IMAGE/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_CB_NORMALIZE_IMAGE/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_CB_PLAIN/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_CB_PLAIN/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_CB_SYMMETRIC_GRID/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_CB_SYMMETRIC_GRID/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_CHECK_COND/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_CHECK_COND/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_FIX_ASPECT_RATIO/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_FIX_ASPECT_RATIO/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_FIX_CENTER/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_FIX_CENTER/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_FIX_FOCAL_LENGTH/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_FIX_FOCAL_LENGTH/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_FIX_GAMMA/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_FIX_GAMMA/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_FIX_INTRINSIC/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_FIX_INTRINSIC/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_FIX_K1/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_FIX_K1/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_FIX_K2/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_FIX_K2/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_FIX_K3/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_FIX_K3/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_FIX_K4/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_FIX_K4/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_FIX_K5/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_FIX_K5/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_FIX_K6/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_FIX_K6/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_FIX_P1/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_FIX_P1/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_FIX_P2/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_FIX_P2/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_FIX_PRINCIPAL_POINT/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_FIX_PRINCIPAL_POINT/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_FIX_S1_S2_S3_S4/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_FIX_S1_S2_S3_S4/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_FIX_SKEW/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_FIX_SKEW/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_FIX_TANGENT_DIST/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_FIX_TANGENT_DIST/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_FIX_TAUX_TAUY/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_FIX_TAUX_TAUY/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_FIX_XI/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_FIX_XI/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_HAND_EYE_ANDREFF/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_HAND_EYE_ANDREFF/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_HAND_EYE_DANIILIDIS/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_HAND_EYE_DANIILIDIS/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_HAND_EYE_HORAUD/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_HAND_EYE_HORAUD/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_HAND_EYE_PARK/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_HAND_EYE_PARK/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_HAND_EYE_TSAI/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_HAND_EYE_TSAI/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_NINTRINSIC/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_NINTRINSIC/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_RATIONAL_MODEL/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_RATIONAL_MODEL/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_RECOMPUTE_EXTRINSIC/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_RECOMPUTE_EXTRINSIC/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_ROBOT_WORLD_HAND_EYE_LI/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_ROBOT_WORLD_HAND_EYE_LI/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_ROBOT_WORLD_HAND_EYE_SHAH/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_ROBOT_WORLD_HAND_EYE_SHAH/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_SAME_FOCAL_LENGTH/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_SAME_FOCAL_LENGTH/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_THIN_PRISM_MODEL/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_THIN_PRISM_MODEL/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_TILTED_MODEL/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_TILTED_MODEL/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_USE_EXTRINSIC_GUESS/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_USE_EXTRINSIC_GUESS/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_USE_GUESS/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_USE_GUESS/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_USE_INTRINSIC_GUESS/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_USE_INTRINSIC_GUESS/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_USE_LU/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_USE_LU/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_USE_QR/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_USE_QR/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_ZERO_DISPARITY/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_ZERO_DISPARITY/0"},{"type":"function","title":"Evision.Constant.cv_CALIB_ZERO_TANGENT_DIST/0","doc":"","ref":"Evision.Constant.html#cv_CALIB_ZERO_TANGENT_DIST/0"},{"type":"function","title":"Evision.Constant.cv_CAP_ANDROID/0","doc":"","ref":"Evision.Constant.html#cv_CAP_ANDROID/0"},{"type":"function","title":"Evision.Constant.cv_CAP_ANY/0","doc":"","ref":"Evision.Constant.html#cv_CAP_ANY/0"},{"type":"function","title":"Evision.Constant.cv_CAP_ARAVIS/0","doc":"","ref":"Evision.Constant.html#cv_CAP_ARAVIS/0"},{"type":"function","title":"Evision.Constant.cv_CAP_AVFOUNDATION/0","doc":"","ref":"Evision.Constant.html#cv_CAP_AVFOUNDATION/0"},{"type":"function","title":"Evision.Constant.cv_CAP_CMU1394/0","doc":"","ref":"Evision.Constant.html#cv_CAP_CMU1394/0"},{"type":"function","title":"Evision.Constant.cv_CAP_DC1394/0","doc":"","ref":"Evision.Constant.html#cv_CAP_DC1394/0"},{"type":"function","title":"Evision.Constant.cv_CAP_DSHOW/0","doc":"","ref":"Evision.Constant.html#cv_CAP_DSHOW/0"},{"type":"function","title":"Evision.Constant.cv_CAP_FFMPEG/0","doc":"","ref":"Evision.Constant.html#cv_CAP_FFMPEG/0"},{"type":"function","title":"Evision.Constant.cv_CAP_FIREWARE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_FIREWARE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_FIREWIRE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_FIREWIRE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_GIGANETIX/0","doc":"","ref":"Evision.Constant.html#cv_CAP_GIGANETIX/0"},{"type":"function","title":"Evision.Constant.cv_CAP_GPHOTO2/0","doc":"","ref":"Evision.Constant.html#cv_CAP_GPHOTO2/0"},{"type":"function","title":"Evision.Constant.cv_CAP_GSTREAMER/0","doc":"","ref":"Evision.Constant.html#cv_CAP_GSTREAMER/0"},{"type":"function","title":"Evision.Constant.cv_CAP_IEEE1394/0","doc":"","ref":"Evision.Constant.html#cv_CAP_IEEE1394/0"},{"type":"function","title":"Evision.Constant.cv_CAP_IMAGES/0","doc":"","ref":"Evision.Constant.html#cv_CAP_IMAGES/0"},{"type":"function","title":"Evision.Constant.cv_CAP_INTEL_MFX/0","doc":"","ref":"Evision.Constant.html#cv_CAP_INTEL_MFX/0"},{"type":"function","title":"Evision.Constant.cv_CAP_INTELPERC/0","doc":"","ref":"Evision.Constant.html#cv_CAP_INTELPERC/0"},{"type":"function","title":"Evision.Constant.cv_CAP_INTELPERC_DEPTH_GENERATOR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_INTELPERC_DEPTH_GENERATOR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_INTELPERC_DEPTH_MAP/0","doc":"","ref":"Evision.Constant.html#cv_CAP_INTELPERC_DEPTH_MAP/0"},{"type":"function","title":"Evision.Constant.cv_CAP_INTELPERC_GENERATORS_MASK/0","doc":"","ref":"Evision.Constant.html#cv_CAP_INTELPERC_GENERATORS_MASK/0"},{"type":"function","title":"Evision.Constant.cv_CAP_INTELPERC_IMAGE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_INTELPERC_IMAGE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_INTELPERC_IMAGE_GENERATOR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_INTELPERC_IMAGE_GENERATOR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_INTELPERC_IR_GENERATOR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_INTELPERC_IR_GENERATOR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_INTELPERC_IR_MAP/0","doc":"","ref":"Evision.Constant.html#cv_CAP_INTELPERC_IR_MAP/0"},{"type":"function","title":"Evision.Constant.cv_CAP_INTELPERC_UVDEPTH_MAP/0","doc":"","ref":"Evision.Constant.html#cv_CAP_INTELPERC_UVDEPTH_MAP/0"},{"type":"function","title":"Evision.Constant.cv_CAP_MSMF/0","doc":"","ref":"Evision.Constant.html#cv_CAP_MSMF/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OBSENSOR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OBSENSOR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OBSENSOR_BGR_IMAGE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OBSENSOR_BGR_IMAGE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OBSENSOR_DEPTH_GENERATOR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OBSENSOR_DEPTH_GENERATOR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OBSENSOR_DEPTH_MAP/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OBSENSOR_DEPTH_MAP/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OBSENSOR_GENERATORS_MASK/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OBSENSOR_GENERATORS_MASK/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OBSENSOR_IMAGE_GENERATOR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OBSENSOR_IMAGE_GENERATOR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OBSENSOR_IR_GENERATOR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OBSENSOR_IR_GENERATOR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OBSENSOR_IR_IMAGE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OBSENSOR_IR_IMAGE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENCV_MJPEG/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENCV_MJPEG/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI2/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI2/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI2_ASTRA/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI2_ASTRA/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI2_ASUS/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI2_ASUS/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_ASUS/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_ASUS/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_BGR_IMAGE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_BGR_IMAGE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_DEPTH_GENERATOR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_DEPTH_GENERATOR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_DEPTH_GENERATOR_BASELINE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_DEPTH_GENERATOR_BASELINE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_DEPTH_GENERATOR_FOCAL_LENGTH/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_DEPTH_GENERATOR_FOCAL_LENGTH/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_DEPTH_GENERATOR_PRESENT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_DEPTH_GENERATOR_PRESENT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_DEPTH_GENERATOR_REGISTRATION/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_DEPTH_GENERATOR_REGISTRATION/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_DEPTH_GENERATOR_REGISTRATION_ON/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_DEPTH_GENERATOR_REGISTRATION_ON/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_DEPTH_MAP/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_DEPTH_MAP/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_DISPARITY_MAP/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_DISPARITY_MAP/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_DISPARITY_MAP_32F/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_DISPARITY_MAP_32F/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_GENERATORS_MASK/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_GENERATORS_MASK/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_GRAY_IMAGE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_GRAY_IMAGE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_IMAGE_GENERATOR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_IMAGE_GENERATOR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_IMAGE_GENERATOR_OUTPUT_MODE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_IMAGE_GENERATOR_OUTPUT_MODE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_IMAGE_GENERATOR_PRESENT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_IMAGE_GENERATOR_PRESENT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_IR_GENERATOR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_IR_GENERATOR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_IR_GENERATOR_PRESENT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_IR_GENERATOR_PRESENT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_IR_IMAGE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_IR_IMAGE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_POINT_CLOUD_MAP/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_POINT_CLOUD_MAP/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_QVGA_30HZ/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_QVGA_30HZ/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_QVGA_60HZ/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_QVGA_60HZ/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_SXGA_15HZ/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_SXGA_15HZ/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_SXGA_30HZ/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_SXGA_30HZ/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_VALID_DEPTH_MASK/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_VALID_DEPTH_MASK/0"},{"type":"function","title":"Evision.Constant.cv_CAP_OPENNI_VGA_30HZ/0","doc":"","ref":"Evision.Constant.html#cv_CAP_OPENNI_VGA_30HZ/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_APERTURE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_APERTURE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_ARAVIS_AUTOTRIGGER/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_ARAVIS_AUTOTRIGGER/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_AUDIO_BASE_INDEX/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_AUDIO_BASE_INDEX/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_AUDIO_DATA_DEPTH/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_AUDIO_DATA_DEPTH/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_AUDIO_POS/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_AUDIO_POS/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_AUDIO_SAMPLES_PER_SECOND/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_AUDIO_SAMPLES_PER_SECOND/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_AUDIO_SHIFT_NSEC/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_AUDIO_SHIFT_NSEC/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_AUDIO_STREAM/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_AUDIO_STREAM/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_AUDIO_SYNCHRONIZE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_AUDIO_SYNCHRONIZE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_AUDIO_TOTAL_CHANNELS/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_AUDIO_TOTAL_CHANNELS/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_AUDIO_TOTAL_STREAMS/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_AUDIO_TOTAL_STREAMS/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_AUTO_EXPOSURE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_AUTO_EXPOSURE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_AUTO_WB/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_AUTO_WB/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_AUTOFOCUS/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_AUTOFOCUS/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_BACKEND/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_BACKEND/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_BACKLIGHT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_BACKLIGHT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_BITRATE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_BITRATE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_BRIGHTNESS/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_BRIGHTNESS/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_BUFFERSIZE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_BUFFERSIZE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_CHANNEL/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_CHANNEL/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_CODEC_EXTRADATA_INDEX/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_CODEC_EXTRADATA_INDEX/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_CODEC_PIXEL_FORMAT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_CODEC_PIXEL_FORMAT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_CONTRAST/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_CONTRAST/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_CONVERT_RGB/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_CONVERT_RGB/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_DC1394_MAX/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_DC1394_MAX/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_DC1394_MODE_AUTO/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_DC1394_MODE_AUTO/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_DC1394_MODE_MANUAL/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_DC1394_MODE_MANUAL/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_DC1394_MODE_ONE_PUSH_AUTO/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_DC1394_MODE_ONE_PUSH_AUTO/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_DC1394_OFF/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_DC1394_OFF/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_EXPOSURE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_EXPOSURE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_EXPOSUREPROGRAM/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_EXPOSUREPROGRAM/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_FOCUS/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_FOCUS/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_FORMAT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_FORMAT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_FOURCC/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_FOURCC/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_FPS/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_FPS/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_FRAME_COUNT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_FRAME_COUNT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_FRAME_HEIGHT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_FRAME_HEIGHT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_FRAME_TYPE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_FRAME_TYPE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_FRAME_WIDTH/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_FRAME_WIDTH/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_GAIN/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_GAIN/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_GAMMA/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_GAMMA/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_GIGA_FRAME_HEIGH_MAX/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_GIGA_FRAME_HEIGH_MAX/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_GIGA_FRAME_OFFSET_X/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_GIGA_FRAME_OFFSET_X/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_GIGA_FRAME_OFFSET_Y/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_GIGA_FRAME_OFFSET_Y/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_GIGA_FRAME_SENS_HEIGH/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_GIGA_FRAME_SENS_HEIGH/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_GIGA_FRAME_SENS_WIDTH/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_GIGA_FRAME_SENS_WIDTH/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_GIGA_FRAME_WIDTH_MAX/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_GIGA_FRAME_WIDTH_MAX/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_GPHOTO2_COLLECT_MSGS/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_GPHOTO2_COLLECT_MSGS/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_GPHOTO2_FLUSH_MSGS/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_GPHOTO2_FLUSH_MSGS/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_GPHOTO2_PREVIEW/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_GPHOTO2_PREVIEW/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_GPHOTO2_RELOAD_CONFIG/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_GPHOTO2_RELOAD_CONFIG/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_GPHOTO2_RELOAD_ON_CHANGE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_GPHOTO2_RELOAD_ON_CHANGE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_GPHOTO2_WIDGET_ENUMERATE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_GPHOTO2_WIDGET_ENUMERATE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_GSTREAMER_QUEUE_LENGTH/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_GSTREAMER_QUEUE_LENGTH/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_GUID/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_GUID/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_HUE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_HUE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_HW_ACCELERATION/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_HW_ACCELERATION/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_HW_ACCELERATION_USE_OPENCL/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_HW_ACCELERATION_USE_OPENCL/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_HW_DEVICE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_HW_DEVICE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_IMAGES_BASE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_IMAGES_BASE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_IMAGES_LAST/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_IMAGES_LAST/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_INTELPERC_DEPTH_CONFIDENCE_THRESHOLD/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_INTELPERC_DEPTH_CONFIDENCE_THRESHOLD/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_INTELPERC_DEPTH_FOCAL_LENGTH_HORZ/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_INTELPERC_DEPTH_FOCAL_LENGTH_HORZ/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_INTELPERC_DEPTH_FOCAL_LENGTH_VERT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_INTELPERC_DEPTH_FOCAL_LENGTH_VERT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_INTELPERC_DEPTH_LOW_CONFIDENCE_VALUE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_INTELPERC_DEPTH_LOW_CONFIDENCE_VALUE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_INTELPERC_DEPTH_SATURATION_VALUE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_INTELPERC_DEPTH_SATURATION_VALUE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_INTELPERC_PROFILE_COUNT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_INTELPERC_PROFILE_COUNT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_INTELPERC_PROFILE_IDX/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_INTELPERC_PROFILE_IDX/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_IOS_DEVICE_EXPOSURE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_IOS_DEVICE_EXPOSURE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_IOS_DEVICE_FLASH/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_IOS_DEVICE_FLASH/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_IOS_DEVICE_FOCUS/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_IOS_DEVICE_FOCUS/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_IOS_DEVICE_TORCH/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_IOS_DEVICE_TORCH/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_IOS_DEVICE_WHITEBALANCE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_IOS_DEVICE_WHITEBALANCE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_IRIS/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_IRIS/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_ISO_SPEED/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_ISO_SPEED/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_LRF_HAS_KEY_FRAME/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_LRF_HAS_KEY_FRAME/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_MODE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_MODE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_MONOCHROME/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_MONOCHROME/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_N_THREADS/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_N_THREADS/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_OBSENSOR_INTRINSIC_CX/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_OBSENSOR_INTRINSIC_CX/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_OBSENSOR_INTRINSIC_CY/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_OBSENSOR_INTRINSIC_CY/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_OBSENSOR_INTRINSIC_FX/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_OBSENSOR_INTRINSIC_FX/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_OBSENSOR_INTRINSIC_FY/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_OBSENSOR_INTRINSIC_FY/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_OPEN_TIMEOUT_MSEC/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_OPEN_TIMEOUT_MSEC/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_OPENNI2_MIRROR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_OPENNI2_MIRROR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_OPENNI2_SYNC/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_OPENNI2_SYNC/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_OPENNI_APPROX_FRAME_SYNC/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_OPENNI_APPROX_FRAME_SYNC/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_OPENNI_BASELINE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_OPENNI_BASELINE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_OPENNI_CIRCLE_BUFFER/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_OPENNI_CIRCLE_BUFFER/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_OPENNI_FOCAL_LENGTH/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_OPENNI_FOCAL_LENGTH/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_OPENNI_FRAME_MAX_DEPTH/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_OPENNI_FRAME_MAX_DEPTH/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_OPENNI_GENERATOR_PRESENT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_OPENNI_GENERATOR_PRESENT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_OPENNI_MAX_BUFFER_SIZE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_OPENNI_MAX_BUFFER_SIZE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_OPENNI_MAX_TIME_DURATION/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_OPENNI_MAX_TIME_DURATION/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_OPENNI_OUTPUT_MODE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_OPENNI_OUTPUT_MODE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_OPENNI_REGISTRATION/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_OPENNI_REGISTRATION/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_OPENNI_REGISTRATION_ON/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_OPENNI_REGISTRATION_ON/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_ORIENTATION_AUTO/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_ORIENTATION_AUTO/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_ORIENTATION_META/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_ORIENTATION_META/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_PAN/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_PAN/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_POS_AVI_RATIO/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_POS_AVI_RATIO/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_POS_FRAMES/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_POS_FRAMES/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_POS_MSEC/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_POS_MSEC/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_PVAPI_BINNINGX/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_PVAPI_BINNINGX/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_PVAPI_BINNINGY/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_PVAPI_BINNINGY/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_PVAPI_DECIMATIONHORIZONTAL/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_PVAPI_DECIMATIONHORIZONTAL/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_PVAPI_DECIMATIONVERTICAL/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_PVAPI_DECIMATIONVERTICAL/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_PVAPI_FRAMESTARTTRIGGERMODE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_PVAPI_FRAMESTARTTRIGGERMODE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_PVAPI_MULTICASTIP/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_PVAPI_MULTICASTIP/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_PVAPI_PIXELFORMAT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_PVAPI_PIXELFORMAT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_READ_TIMEOUT_MSEC/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_READ_TIMEOUT_MSEC/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_RECTIFICATION/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_RECTIFICATION/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_ROLL/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_ROLL/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_SAR_DEN/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_SAR_DEN/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_SAR_NUM/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_SAR_NUM/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_SATURATION/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_SATURATION/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_SETTINGS/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_SETTINGS/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_SHARPNESS/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_SHARPNESS/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_SPEED/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_SPEED/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_STREAM_OPEN_TIME_USEC/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_STREAM_OPEN_TIME_USEC/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_TEMPERATURE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_TEMPERATURE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_TILT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_TILT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_TRIGGER/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_TRIGGER/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_TRIGGER_DELAY/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_TRIGGER_DELAY/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_VIDEO_STREAM/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_VIDEO_STREAM/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_VIDEO_TOTAL_CHANNELS/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_VIDEO_TOTAL_CHANNELS/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_VIEWFINDER/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_VIEWFINDER/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_WB_TEMPERATURE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_WB_TEMPERATURE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_WHITE_BALANCE_BLUE_U/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_WHITE_BALANCE_BLUE_U/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_WHITE_BALANCE_RED_V/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_WHITE_BALANCE_RED_V/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_ACQ_BUFFER_SIZE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_ACQ_BUFFER_SIZE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_ACQ_BUFFER_SIZE_UNIT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_ACQ_BUFFER_SIZE_UNIT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_ACQ_FRAME_BURST_COUNT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_ACQ_FRAME_BURST_COUNT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_ACQ_TIMING_MODE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_ACQ_TIMING_MODE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_ACQ_TRANSPORT_BUFFER_COMMIT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_ACQ_TRANSPORT_BUFFER_COMMIT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_ACQ_TRANSPORT_BUFFER_SIZE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_ACQ_TRANSPORT_BUFFER_SIZE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_AE_MAX_LIMIT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_AE_MAX_LIMIT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_AEAG/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_AEAG/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_AEAG_LEVEL/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_AEAG_LEVEL/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_AEAG_ROI_HEIGHT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_AEAG_ROI_HEIGHT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_AEAG_ROI_OFFSET_X/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_AEAG_ROI_OFFSET_X/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_AEAG_ROI_OFFSET_Y/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_AEAG_ROI_OFFSET_Y/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_AEAG_ROI_WIDTH/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_AEAG_ROI_WIDTH/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_AG_MAX_LIMIT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_AG_MAX_LIMIT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_APPLY_CMS/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_APPLY_CMS/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_AUTO_BANDWIDTH_CALCULATION/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_AUTO_BANDWIDTH_CALCULATION/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_AUTO_WB/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_AUTO_WB/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_AVAILABLE_BANDWIDTH/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_AVAILABLE_BANDWIDTH/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_BINNING_HORIZONTAL/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_BINNING_HORIZONTAL/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_BINNING_PATTERN/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_BINNING_PATTERN/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_BINNING_SELECTOR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_BINNING_SELECTOR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_BINNING_VERTICAL/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_BINNING_VERTICAL/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_BPC/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_BPC/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_BUFFER_POLICY/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_BUFFER_POLICY/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_BUFFERS_QUEUE_SIZE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_BUFFERS_QUEUE_SIZE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_CC_MATRIX_00/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_CC_MATRIX_00/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_CC_MATRIX_01/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_CC_MATRIX_01/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_CC_MATRIX_02/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_CC_MATRIX_02/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_CC_MATRIX_03/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_CC_MATRIX_03/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_CC_MATRIX_10/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_CC_MATRIX_10/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_CC_MATRIX_11/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_CC_MATRIX_11/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_CC_MATRIX_12/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_CC_MATRIX_12/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_CC_MATRIX_13/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_CC_MATRIX_13/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_CC_MATRIX_20/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_CC_MATRIX_20/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_CC_MATRIX_21/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_CC_MATRIX_21/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_CC_MATRIX_22/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_CC_MATRIX_22/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_CC_MATRIX_23/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_CC_MATRIX_23/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_CC_MATRIX_30/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_CC_MATRIX_30/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_CC_MATRIX_31/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_CC_MATRIX_31/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_CC_MATRIX_32/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_CC_MATRIX_32/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_CC_MATRIX_33/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_CC_MATRIX_33/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_CHIP_TEMP/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_CHIP_TEMP/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_CMS/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_CMS/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_COLOR_FILTER_ARRAY/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_COLOR_FILTER_ARRAY/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_COLUMN_FPN_CORRECTION/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_COLUMN_FPN_CORRECTION/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_COOLING/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_COOLING/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_COUNTER_SELECTOR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_COUNTER_SELECTOR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_COUNTER_VALUE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_COUNTER_VALUE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_DATA_FORMAT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_DATA_FORMAT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_DEBOUNCE_EN/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_DEBOUNCE_EN/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_DEBOUNCE_POL/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_DEBOUNCE_POL/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_DEBOUNCE_T0/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_DEBOUNCE_T0/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_DEBOUNCE_T1/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_DEBOUNCE_T1/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_DEBUG_LEVEL/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_DEBUG_LEVEL/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_DECIMATION_HORIZONTAL/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_DECIMATION_HORIZONTAL/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_DECIMATION_PATTERN/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_DECIMATION_PATTERN/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_DECIMATION_SELECTOR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_DECIMATION_SELECTOR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_DECIMATION_VERTICAL/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_DECIMATION_VERTICAL/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_DEFAULT_CC_MATRIX/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_DEFAULT_CC_MATRIX/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_DEVICE_MODEL_ID/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_DEVICE_MODEL_ID/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_DEVICE_RESET/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_DEVICE_RESET/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_DEVICE_SN/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_DEVICE_SN/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_DOWNSAMPLING/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_DOWNSAMPLING/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_DOWNSAMPLING_TYPE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_DOWNSAMPLING_TYPE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_EXP_PRIORITY/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_EXP_PRIORITY/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_EXPOSURE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_EXPOSURE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_EXPOSURE_BURST_COUNT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_EXPOSURE_BURST_COUNT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_FFS_ACCESS_KEY/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_FFS_ACCESS_KEY/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_FFS_FILE_ID/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_FFS_FILE_ID/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_FFS_FILE_SIZE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_FFS_FILE_SIZE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_FRAMERATE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_FRAMERATE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_FREE_FFS_SIZE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_FREE_FFS_SIZE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_GAIN/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_GAIN/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_GAIN_SELECTOR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_GAIN_SELECTOR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_GAMMAC/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_GAMMAC/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_GAMMAY/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_GAMMAY/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_GPI_LEVEL/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_GPI_LEVEL/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_GPI_MODE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_GPI_MODE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_GPI_SELECTOR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_GPI_SELECTOR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_GPO_MODE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_GPO_MODE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_GPO_SELECTOR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_GPO_SELECTOR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_HDR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_HDR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_HDR_KNEEPOINT_COUNT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_HDR_KNEEPOINT_COUNT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_HDR_T1/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_HDR_T1/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_HDR_T2/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_HDR_T2/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_HEIGHT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_HEIGHT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_HOUS_BACK_SIDE_TEMP/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_HOUS_BACK_SIDE_TEMP/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_HOUS_TEMP/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_HOUS_TEMP/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_HW_REVISION/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_HW_REVISION/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_IMAGE_BLACK_LEVEL/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_IMAGE_BLACK_LEVEL/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_IMAGE_DATA_BIT_DEPTH/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_IMAGE_DATA_BIT_DEPTH/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_IMAGE_DATA_FORMAT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_IMAGE_DATA_FORMAT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_IMAGE_DATA_FORMAT_RGB32_ALPHA/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_IMAGE_DATA_FORMAT_RGB32_ALPHA/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_IMAGE_IS_COLOR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_IMAGE_IS_COLOR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_IMAGE_PAYLOAD_SIZE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_IMAGE_PAYLOAD_SIZE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_IS_COOLED/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_IS_COOLED/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_IS_DEVICE_EXIST/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_IS_DEVICE_EXIST/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_KNEEPOINT1/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_KNEEPOINT1/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_KNEEPOINT2/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_KNEEPOINT2/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_LED_MODE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_LED_MODE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_LED_SELECTOR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_LED_SELECTOR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_LENS_APERTURE_VALUE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_LENS_APERTURE_VALUE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_LENS_FEATURE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_LENS_FEATURE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_LENS_FEATURE_SELECTOR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_LENS_FEATURE_SELECTOR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_LENS_FOCAL_LENGTH/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_LENS_FOCAL_LENGTH/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_LENS_FOCUS_DISTANCE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_LENS_FOCUS_DISTANCE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_LENS_FOCUS_MOVE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_LENS_FOCUS_MOVE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_LENS_FOCUS_MOVEMENT_VALUE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_LENS_FOCUS_MOVEMENT_VALUE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_LENS_MODE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_LENS_MODE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_LIMIT_BANDWIDTH/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_LIMIT_BANDWIDTH/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_LUT_EN/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_LUT_EN/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_LUT_INDEX/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_LUT_INDEX/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_LUT_VALUE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_LUT_VALUE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_MANUAL_WB/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_MANUAL_WB/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_OFFSET_X/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_OFFSET_X/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_OFFSET_Y/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_OFFSET_Y/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_OUTPUT_DATA_BIT_DEPTH/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_OUTPUT_DATA_BIT_DEPTH/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_OUTPUT_DATA_PACKING/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_OUTPUT_DATA_PACKING/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_OUTPUT_DATA_PACKING_TYPE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_OUTPUT_DATA_PACKING_TYPE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_RECENT_FRAME/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_RECENT_FRAME/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_REGION_MODE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_REGION_MODE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_REGION_SELECTOR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_REGION_SELECTOR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_ROW_FPN_CORRECTION/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_ROW_FPN_CORRECTION/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_SENSOR_BOARD_TEMP/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_SENSOR_BOARD_TEMP/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_SENSOR_CLOCK_FREQ_HZ/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_SENSOR_CLOCK_FREQ_HZ/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_SENSOR_CLOCK_FREQ_INDEX/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_SENSOR_CLOCK_FREQ_INDEX/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_SENSOR_DATA_BIT_DEPTH/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_SENSOR_DATA_BIT_DEPTH/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_SENSOR_FEATURE_SELECTOR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_SENSOR_FEATURE_SELECTOR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_SENSOR_FEATURE_VALUE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_SENSOR_FEATURE_VALUE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_SENSOR_MODE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_SENSOR_MODE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_SENSOR_OUTPUT_CHANNEL_COUNT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_SENSOR_OUTPUT_CHANNEL_COUNT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_SENSOR_TAPS/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_SENSOR_TAPS/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_SHARPNESS/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_SHARPNESS/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_SHUTTER_TYPE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_SHUTTER_TYPE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_TARGET_TEMP/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_TARGET_TEMP/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_TEST_PATTERN/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_TEST_PATTERN/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_TEST_PATTERN_GENERATOR_SELECTOR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_TEST_PATTERN_GENERATOR_SELECTOR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_TIMEOUT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_TIMEOUT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_TRANSPORT_PIXEL_FORMAT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_TRANSPORT_PIXEL_FORMAT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_TRG_DELAY/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_TRG_DELAY/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_TRG_SELECTOR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_TRG_SELECTOR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_TRG_SOFTWARE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_TRG_SOFTWARE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_TRG_SOURCE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_TRG_SOURCE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_TS_RST_MODE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_TS_RST_MODE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_TS_RST_SOURCE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_TS_RST_SOURCE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_USED_FFS_SIZE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_USED_FFS_SIZE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_WB_KB/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_WB_KB/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_WB_KG/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_WB_KG/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_WB_KR/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_WB_KR/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_XI_WIDTH/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_XI_WIDTH/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PROP_ZOOM/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PROP_ZOOM/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PVAPI/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PVAPI/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PVAPI_DECIMATION_2OUTOF4/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PVAPI_DECIMATION_2OUTOF4/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PVAPI_DECIMATION_2OUTOF8/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PVAPI_DECIMATION_2OUTOF8/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PVAPI_DECIMATION_2OUTOF16/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PVAPI_DECIMATION_2OUTOF16/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PVAPI_DECIMATION_OFF/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PVAPI_DECIMATION_OFF/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PVAPI_FSTRIGMODE_FIXEDRATE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PVAPI_FSTRIGMODE_FIXEDRATE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PVAPI_FSTRIGMODE_FREERUN/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PVAPI_FSTRIGMODE_FREERUN/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PVAPI_FSTRIGMODE_SOFTWARE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PVAPI_FSTRIGMODE_SOFTWARE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PVAPI_FSTRIGMODE_SYNCIN1/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PVAPI_FSTRIGMODE_SYNCIN1/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PVAPI_FSTRIGMODE_SYNCIN2/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PVAPI_FSTRIGMODE_SYNCIN2/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PVAPI_PIXELFORMAT_BAYER8/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PVAPI_PIXELFORMAT_BAYER8/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PVAPI_PIXELFORMAT_BAYER16/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PVAPI_PIXELFORMAT_BAYER16/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PVAPI_PIXELFORMAT_BGR24/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PVAPI_PIXELFORMAT_BGR24/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PVAPI_PIXELFORMAT_BGRA32/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PVAPI_PIXELFORMAT_BGRA32/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PVAPI_PIXELFORMAT_MONO8/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PVAPI_PIXELFORMAT_MONO8/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PVAPI_PIXELFORMAT_MONO16/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PVAPI_PIXELFORMAT_MONO16/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PVAPI_PIXELFORMAT_RGB24/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PVAPI_PIXELFORMAT_RGB24/0"},{"type":"function","title":"Evision.Constant.cv_CAP_PVAPI_PIXELFORMAT_RGBA32/0","doc":"","ref":"Evision.Constant.html#cv_CAP_PVAPI_PIXELFORMAT_RGBA32/0"},{"type":"function","title":"Evision.Constant.cv_CAP_QT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_QT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_REALSENSE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_REALSENSE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_UEYE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_UEYE/0"},{"type":"function","title":"Evision.Constant.cv_CAP_UNICAP/0","doc":"","ref":"Evision.Constant.html#cv_CAP_UNICAP/0"},{"type":"function","title":"Evision.Constant.cv_CAP_V4L2/0","doc":"","ref":"Evision.Constant.html#cv_CAP_V4L2/0"},{"type":"function","title":"Evision.Constant.cv_CAP_V4L/0","doc":"","ref":"Evision.Constant.html#cv_CAP_V4L/0"},{"type":"function","title":"Evision.Constant.cv_CAP_VFW/0","doc":"","ref":"Evision.Constant.html#cv_CAP_VFW/0"},{"type":"function","title":"Evision.Constant.cv_CAP_WINRT/0","doc":"","ref":"Evision.Constant.html#cv_CAP_WINRT/0"},{"type":"function","title":"Evision.Constant.cv_CAP_XIAPI/0","doc":"","ref":"Evision.Constant.html#cv_CAP_XIAPI/0"},{"type":"function","title":"Evision.Constant.cv_CAP_XINE/0","doc":"","ref":"Evision.Constant.html#cv_CAP_XINE/0"},{"type":"function","title":"Evision.Constant.cv_CASCADE_DO_CANNY_PRUNING/0","doc":"","ref":"Evision.Constant.html#cv_CASCADE_DO_CANNY_PRUNING/0"},{"type":"function","title":"Evision.Constant.cv_CASCADE_DO_ROUGH_SEARCH/0","doc":"","ref":"Evision.Constant.html#cv_CASCADE_DO_ROUGH_SEARCH/0"},{"type":"function","title":"Evision.Constant.cv_CASCADE_FIND_BIGGEST_OBJECT/0","doc":"","ref":"Evision.Constant.html#cv_CASCADE_FIND_BIGGEST_OBJECT/0"},{"type":"function","title":"Evision.Constant.cv_CASCADE_SCALE_IMAGE/0","doc":"","ref":"Evision.Constant.html#cv_CASCADE_SCALE_IMAGE/0"},{"type":"function","title":"Evision.Constant.cv_CC_STAT_AREA/0","doc":"","ref":"Evision.Constant.html#cv_CC_STAT_AREA/0"},{"type":"function","title":"Evision.Constant.cv_CC_STAT_HEIGHT/0","doc":"","ref":"Evision.Constant.html#cv_CC_STAT_HEIGHT/0"},{"type":"function","title":"Evision.Constant.cv_CC_STAT_LEFT/0","doc":"","ref":"Evision.Constant.html#cv_CC_STAT_LEFT/0"},{"type":"function","title":"Evision.Constant.cv_CC_STAT_MAX/0","doc":"","ref":"Evision.Constant.html#cv_CC_STAT_MAX/0"},{"type":"function","title":"Evision.Constant.cv_CC_STAT_TOP/0","doc":"","ref":"Evision.Constant.html#cv_CC_STAT_TOP/0"},{"type":"function","title":"Evision.Constant.cv_CC_STAT_WIDTH/0","doc":"","ref":"Evision.Constant.html#cv_CC_STAT_WIDTH/0"},{"type":"function","title":"Evision.Constant.cv_CCL_BBDT/0","doc":"","ref":"Evision.Constant.html#cv_CCL_BBDT/0"},{"type":"function","title":"Evision.Constant.cv_CCL_BKE/0","doc":"","ref":"Evision.Constant.html#cv_CCL_BKE/0"},{"type":"function","title":"Evision.Constant.cv_CCL_BOLELLI/0","doc":"","ref":"Evision.Constant.html#cv_CCL_BOLELLI/0"},{"type":"function","title":"Evision.Constant.cv_CCL_DEFAULT/0","doc":"","ref":"Evision.Constant.html#cv_CCL_DEFAULT/0"},{"type":"function","title":"Evision.Constant.cv_CCL_GRANA/0","doc":"","ref":"Evision.Constant.html#cv_CCL_GRANA/0"},{"type":"function","title":"Evision.Constant.cv_CCL_SAUF/0","doc":"","ref":"Evision.Constant.html#cv_CCL_SAUF/0"},{"type":"function","title":"Evision.Constant.cv_CCL_SPAGHETTI/0","doc":"","ref":"Evision.Constant.html#cv_CCL_SPAGHETTI/0"},{"type":"function","title":"Evision.Constant.cv_CCL_WU/0","doc":"","ref":"Evision.Constant.html#cv_CCL_WU/0"},{"type":"function","title":"Evision.Constant.cv_CCM_3x3/0","doc":"","ref":"Evision.Constant.html#cv_CCM_3x3/0"},{"type":"function","title":"Evision.Constant.cv_CCM_4x3/0","doc":"","ref":"Evision.Constant.html#cv_CCM_4x3/0"},{"type":"function","title":"Evision.Constant.cv_CHAIN_APPROX_NONE/0","doc":"","ref":"Evision.Constant.html#cv_CHAIN_APPROX_NONE/0"},{"type":"function","title":"Evision.Constant.cv_CHAIN_APPROX_SIMPLE/0","doc":"","ref":"Evision.Constant.html#cv_CHAIN_APPROX_SIMPLE/0"},{"type":"function","title":"Evision.Constant.cv_CHAIN_APPROX_TC89_KCOS/0","doc":"","ref":"Evision.Constant.html#cv_CHAIN_APPROX_TC89_KCOS/0"},{"type":"function","title":"Evision.Constant.cv_CHAIN_APPROX_TC89_L1/0","doc":"","ref":"Evision.Constant.html#cv_CHAIN_APPROX_TC89_L1/0"},{"type":"function","title":"Evision.Constant.cv_CHANNELS/0","doc":"","ref":"Evision.Constant.html#cv_CHANNELS/0"},{"type":"function","title":"Evision.Constant.cv_CHANNELS_BLOCKS/0","doc":"","ref":"Evision.Constant.html#cv_CHANNELS_BLOCKS/0"},{"type":"function","title":"Evision.Constant.cv_CHI2/0","doc":"","ref":"Evision.Constant.html#cv_CHI2/0"},{"type":"function","title":"Evision.Constant.cv_CMP_EQ/0","doc":"","ref":"Evision.Constant.html#cv_CMP_EQ/0"},{"type":"function","title":"Evision.Constant.cv_CMP_GE/0","doc":"","ref":"Evision.Constant.html#cv_CMP_GE/0"},{"type":"function","title":"Evision.Constant.cv_CMP_GT/0","doc":"","ref":"Evision.Constant.html#cv_CMP_GT/0"},{"type":"function","title":"Evision.Constant.cv_CMP_LE/0","doc":"","ref":"Evision.Constant.html#cv_CMP_LE/0"},{"type":"function","title":"Evision.Constant.cv_CMP_LT/0","doc":"","ref":"Evision.Constant.html#cv_CMP_LT/0"},{"type":"function","title":"Evision.Constant.cv_CMP_NE/0","doc":"","ref":"Evision.Constant.html#cv_CMP_NE/0"},{"type":"function","title":"Evision.Constant.cv_CN/0","doc":"","ref":"Evision.Constant.html#cv_CN/0"},{"type":"function","title":"Evision.Constant.cv_COEF/0","doc":"","ref":"Evision.Constant.html#cv_COEF/0"},{"type":"function","title":"Evision.Constant.cv_COL_SAMPLE/0","doc":"","ref":"Evision.Constant.html#cv_COL_SAMPLE/0"},{"type":"function","title":"Evision.Constant.cv_COLOR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerBG2BGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerBG2BGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerBG2BGR_EA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerBG2BGR_EA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerBG2BGR_MHT/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerBG2BGR_MHT/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerBG2BGR_VNG/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerBG2BGR_VNG/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerBG2BGRA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerBG2BGRA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerBG2GRAY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerBG2GRAY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerBG2GRAY_MHT/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerBG2GRAY_MHT/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerBG2RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerBG2RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerBG2RGB_EA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerBG2RGB_EA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerBG2RGB_MHT/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerBG2RGB_MHT/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerBG2RGB_VNG/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerBG2RGB_VNG/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerBG2RGBA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerBG2RGBA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerBGGR2BGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerBGGR2BGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerBGGR2BGR_EA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerBGGR2BGR_EA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerBGGR2BGR_VNG/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerBGGR2BGR_VNG/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerBGGR2BGRA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerBGGR2BGRA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerBGGR2GRAY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerBGGR2GRAY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerBGGR2RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerBGGR2RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerBGGR2RGB_EA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerBGGR2RGB_EA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerBGGR2RGB_VNG/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerBGGR2RGB_VNG/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerBGGR2RGBA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerBGGR2RGBA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGB2BGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGB2BGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGB2BGR_EA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGB2BGR_EA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGB2BGR_MHT/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGB2BGR_MHT/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGB2BGR_VNG/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGB2BGR_VNG/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGB2BGRA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGB2BGRA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGB2GRAY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGB2GRAY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGB2GRAY_MHT/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGB2GRAY_MHT/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGB2RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGB2RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGB2RGB_EA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGB2RGB_EA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGB2RGB_MHT/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGB2RGB_MHT/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGB2RGB_VNG/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGB2RGB_VNG/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGB2RGBA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGB2RGBA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGBRG2BGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGBRG2BGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGBRG2BGR_EA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGBRG2BGR_EA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGBRG2BGR_VNG/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGBRG2BGR_VNG/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGBRG2BGRA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGBRG2BGRA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGBRG2GRAY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGBRG2GRAY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGBRG2RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGBRG2RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGBRG2RGB_EA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGBRG2RGB_EA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGBRG2RGB_VNG/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGBRG2RGB_VNG/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGBRG2RGBA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGBRG2RGBA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGR2BGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGR2BGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGR2BGR_EA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGR2BGR_EA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGR2BGR_MHT/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGR2BGR_MHT/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGR2BGR_VNG/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGR2BGR_VNG/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGR2BGRA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGR2BGRA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGR2GRAY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGR2GRAY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGR2GRAY_MHT/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGR2GRAY_MHT/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGR2RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGR2RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGR2RGB_EA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGR2RGB_EA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGR2RGB_MHT/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGR2RGB_MHT/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGR2RGB_VNG/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGR2RGB_VNG/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGR2RGBA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGR2RGBA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGRBG2BGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGRBG2BGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGRBG2BGR_EA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGRBG2BGR_EA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGRBG2BGR_VNG/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGRBG2BGR_VNG/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGRBG2BGRA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGRBG2BGRA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGRBG2GRAY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGRBG2GRAY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGRBG2RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGRBG2RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGRBG2RGB_EA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGRBG2RGB_EA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGRBG2RGB_VNG/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGRBG2RGB_VNG/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerGRBG2RGBA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerGRBG2RGBA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerRG2BGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerRG2BGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerRG2BGR_EA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerRG2BGR_EA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerRG2BGR_MHT/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerRG2BGR_MHT/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerRG2BGR_VNG/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerRG2BGR_VNG/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerRG2BGRA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerRG2BGRA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerRG2GRAY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerRG2GRAY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerRG2GRAY_MHT/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerRG2GRAY_MHT/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerRG2RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerRG2RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerRG2RGB_EA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerRG2RGB_EA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerRG2RGB_MHT/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerRG2RGB_MHT/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerRG2RGB_VNG/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerRG2RGB_VNG/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerRG2RGBA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerRG2RGBA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerRGGB2BGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerRGGB2BGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerRGGB2BGR_EA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerRGGB2BGR_EA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerRGGB2BGR_VNG/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerRGGB2BGR_VNG/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerRGGB2BGRA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerRGGB2BGRA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerRGGB2GRAY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerRGGB2GRAY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerRGGB2RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerRGGB2RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerRGGB2RGB_EA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerRGGB2RGB_EA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerRGGB2RGB_VNG/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerRGGB2RGB_VNG/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BayerRGGB2RGBA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BayerRGGB2RGBA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2BGR555/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2BGR555/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2BGR565/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2BGR565/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2BGRA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2BGRA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2GRAY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2GRAY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2HLS/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2HLS/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2HLS_FULL/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2HLS_FULL/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2HSV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2HSV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2HSV_FULL/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2HSV_FULL/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2Lab/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2Lab/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2Luv/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2Luv/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2RGBA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2RGBA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2XYZ/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2XYZ/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2YCrCb/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2YCrCb/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2YUV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2YUV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2YUV_I420/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2YUV_I420/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2YUV_IYUV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2YUV_IYUV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2YUV_UYNV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2YUV_UYNV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2YUV_UYVY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2YUV_UYVY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2YUV_Y422/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2YUV_Y422/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2YUV_YUNV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2YUV_YUNV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2YUV_YUY2/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2YUV_YUY2/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2YUV_YUYV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2YUV_YUYV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2YUV_YV12/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2YUV_YV12/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR2YUV_YVYU/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR2YUV_YVYU/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR5552BGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR5552BGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR5552BGRA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR5552BGRA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR5552GRAY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR5552GRAY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR5552RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR5552RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR5552RGBA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR5552RGBA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR5652BGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR5652BGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR5652BGRA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR5652BGRA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR5652GRAY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR5652GRAY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR5652RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR5652RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGR5652RGBA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGR5652RGBA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGRA2BGR555/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGRA2BGR555/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGRA2BGR565/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGRA2BGR565/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGRA2BGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGRA2BGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGRA2GRAY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGRA2GRAY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGRA2RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGRA2RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGRA2RGBA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGRA2RGBA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGRA2YUV_I420/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGRA2YUV_I420/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGRA2YUV_IYUV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGRA2YUV_IYUV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGRA2YUV_UYNV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGRA2YUV_UYNV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGRA2YUV_UYVY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGRA2YUV_UYVY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGRA2YUV_Y422/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGRA2YUV_Y422/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGRA2YUV_YUNV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGRA2YUV_YUNV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGRA2YUV_YUY2/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGRA2YUV_YUY2/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGRA2YUV_YUYV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGRA2YUV_YUYV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGRA2YUV_YV12/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGRA2YUV_YV12/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_BGRA2YUV_YVYU/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_BGRA2YUV_YVYU/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_COLORCVT_MAX/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_COLORCVT_MAX/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_GRAD/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_GRAD/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_GRAY2BGR555/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_GRAY2BGR555/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_GRAY2BGR565/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_GRAY2BGR565/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_GRAY2BGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_GRAY2BGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_GRAY2BGRA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_GRAY2BGRA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_GRAY2RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_GRAY2RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_GRAY2RGBA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_GRAY2RGBA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_HLS2BGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_HLS2BGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_HLS2BGR_FULL/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_HLS2BGR_FULL/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_HLS2RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_HLS2RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_HLS2RGB_FULL/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_HLS2RGB_FULL/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_HSV2BGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_HSV2BGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_HSV2BGR_FULL/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_HSV2BGR_FULL/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_HSV2RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_HSV2RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_HSV2RGB_FULL/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_HSV2RGB_FULL/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_Lab2BGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_Lab2BGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_Lab2LBGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_Lab2LBGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_Lab2LRGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_Lab2LRGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_Lab2RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_Lab2RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_LBGR2Lab/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_LBGR2Lab/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_LBGR2Luv/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_LBGR2Luv/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_LRGB2Lab/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_LRGB2Lab/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_LRGB2Luv/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_LRGB2Luv/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_Luv2BGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_Luv2BGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_Luv2LBGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_Luv2LBGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_Luv2LRGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_Luv2LRGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_Luv2RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_Luv2RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_mRGBA2RGBA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_mRGBA2RGBA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2BGR555/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2BGR555/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2BGR565/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2BGR565/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2BGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2BGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2BGRA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2BGRA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2GRAY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2GRAY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2HLS/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2HLS/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2HLS_FULL/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2HLS_FULL/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2HSV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2HSV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2HSV_FULL/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2HSV_FULL/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2Lab/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2Lab/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2Luv/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2Luv/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2RGBA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2RGBA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2XYZ/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2XYZ/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2YCrCb/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2YCrCb/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2YUV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2YUV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2YUV_I420/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2YUV_I420/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2YUV_IYUV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2YUV_IYUV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2YUV_UYNV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2YUV_UYNV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2YUV_UYVY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2YUV_UYVY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2YUV_Y422/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2YUV_Y422/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2YUV_YUNV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2YUV_YUNV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2YUV_YUY2/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2YUV_YUY2/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2YUV_YUYV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2YUV_YUYV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2YUV_YV12/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2YUV_YV12/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGB2YUV_YVYU/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGB2YUV_YVYU/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGBA2BGR555/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGBA2BGR555/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGBA2BGR565/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGBA2BGR565/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGBA2BGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGBA2BGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGBA2BGRA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGBA2BGRA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGBA2GRAY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGBA2GRAY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGBA2mRGBA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGBA2mRGBA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGBA2RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGBA2RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGBA2YUV_I420/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGBA2YUV_I420/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGBA2YUV_IYUV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGBA2YUV_IYUV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGBA2YUV_UYNV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGBA2YUV_UYNV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGBA2YUV_UYVY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGBA2YUV_UYVY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGBA2YUV_Y422/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGBA2YUV_Y422/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGBA2YUV_YUNV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGBA2YUV_YUNV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGBA2YUV_YUY2/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGBA2YUV_YUY2/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGBA2YUV_YUYV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGBA2YUV_YUYV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGBA2YUV_YV12/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGBA2YUV_YV12/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_RGBA2YUV_YVYU/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_RGBA2YUV_YVYU/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_AdobeRGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_AdobeRGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_AdobeRGBL/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_AdobeRGBL/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_AppleRGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_AppleRGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_AppleRGBL/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_AppleRGBL/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_DCI_P3_RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_DCI_P3_RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_DCI_P3_RGBL/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_DCI_P3_RGBL/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_Lab_A_2/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_Lab_A_2/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_Lab_A_10/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_Lab_A_10/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_Lab_D50_2/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_Lab_D50_2/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_Lab_D50_10/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_Lab_D50_10/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_Lab_D55_2/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_Lab_D55_2/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_Lab_D55_10/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_Lab_D55_10/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_Lab_D65_2/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_Lab_D65_2/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_Lab_D65_10/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_Lab_D65_10/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_Lab_D75_2/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_Lab_D75_2/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_Lab_D75_10/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_Lab_D75_10/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_Lab_E_2/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_Lab_E_2/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_Lab_E_10/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_Lab_E_10/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_ProPhotoRGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_ProPhotoRGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_ProPhotoRGBL/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_ProPhotoRGBL/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_REC_709_RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_REC_709_RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_REC_709_RGBL/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_REC_709_RGBL/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_REC_2020_RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_REC_2020_RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_REC_2020_RGBL/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_REC_2020_RGBL/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_sRGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_sRGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_sRGBL/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_sRGBL/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_WideGamutRGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_WideGamutRGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_WideGamutRGBL/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_WideGamutRGBL/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_XYZ_A_2/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_XYZ_A_2/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_XYZ_A_10/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_XYZ_A_10/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_XYZ_D50_2/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_XYZ_D50_2/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_XYZ_D50_10/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_XYZ_D50_10/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_XYZ_D55_2/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_XYZ_D55_2/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_XYZ_D55_10/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_XYZ_D55_10/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_XYZ_D65_2/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_XYZ_D65_2/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_XYZ_D65_10/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_XYZ_D65_10/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_XYZ_D75_2/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_XYZ_D75_2/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_XYZ_D75_10/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_XYZ_D75_10/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_XYZ_E_2/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_XYZ_E_2/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_SPACE_XYZ_E_10/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_SPACE_XYZ_E_10/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_XYZ2BGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_XYZ2BGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_XYZ2RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_XYZ2RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YCrCb2BGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YCrCb2BGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YCrCb2RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YCrCb2RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGR_I420/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGR_I420/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGR_IYUV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGR_IYUV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGR_NV12/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGR_NV12/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGR_NV21/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGR_NV21/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGR_UYNV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGR_UYNV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGR_UYVY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGR_UYVY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGR_Y422/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGR_Y422/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGR_YUNV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGR_YUNV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGR_YUY2/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGR_YUY2/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGR_YUYV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGR_YUYV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGR_YV12/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGR_YV12/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGR_YVYU/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGR_YVYU/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGRA_I420/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGRA_I420/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGRA_IYUV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGRA_IYUV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGRA_NV12/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGRA_NV12/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGRA_NV21/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGRA_NV21/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGRA_UYNV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGRA_UYNV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGRA_UYVY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGRA_UYVY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGRA_Y422/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGRA_Y422/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGRA_YUNV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGRA_YUNV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGRA_YUY2/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGRA_YUY2/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGRA_YUYV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGRA_YUYV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGRA_YV12/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGRA_YV12/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2BGRA_YVYU/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2BGRA_YVYU/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2GRAY_420/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2GRAY_420/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2GRAY_I420/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2GRAY_I420/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2GRAY_IYUV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2GRAY_IYUV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2GRAY_NV12/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2GRAY_NV12/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2GRAY_NV21/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2GRAY_NV21/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2GRAY_UYNV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2GRAY_UYNV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2GRAY_UYVY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2GRAY_UYVY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2GRAY_Y422/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2GRAY_Y422/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2GRAY_YUNV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2GRAY_YUNV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2GRAY_YUY2/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2GRAY_YUY2/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2GRAY_YUYV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2GRAY_YUYV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2GRAY_YV12/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2GRAY_YV12/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2GRAY_YVYU/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2GRAY_YVYU/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGB_I420/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGB_I420/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGB_IYUV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGB_IYUV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGB_NV12/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGB_NV12/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGB_NV21/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGB_NV21/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGB_UYNV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGB_UYNV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGB_UYVY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGB_UYVY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGB_Y422/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGB_Y422/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGB_YUNV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGB_YUNV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGB_YUY2/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGB_YUY2/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGB_YUYV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGB_YUYV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGB_YV12/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGB_YV12/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGB_YVYU/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGB_YVYU/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGBA_I420/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGBA_I420/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGBA_IYUV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGBA_IYUV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGBA_NV12/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGBA_NV12/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGBA_NV21/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGBA_NV21/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGBA_UYNV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGBA_UYNV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGBA_UYVY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGBA_UYVY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGBA_Y422/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGBA_Y422/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGBA_YUNV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGBA_YUNV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGBA_YUY2/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGBA_YUY2/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGBA_YUYV/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGBA_YUYV/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGBA_YV12/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGBA_YV12/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV2RGBA_YVYU/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV2RGBA_YVYU/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV420p2BGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV420p2BGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV420p2BGRA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV420p2BGRA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV420p2GRAY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV420p2GRAY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV420p2RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV420p2RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV420p2RGBA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV420p2RGBA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV420sp2BGR/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV420sp2BGR/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV420sp2BGRA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV420sp2BGRA/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV420sp2GRAY/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV420sp2GRAY/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV420sp2RGB/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV420sp2RGB/0"},{"type":"function","title":"Evision.Constant.cv_COLOR_YUV420sp2RGBA/0","doc":"","ref":"Evision.Constant.html#cv_COLOR_YUV420sp2RGBA/0"},{"type":"function","title":"Evision.Constant.cv_COLORCHECKER_DigitalSG/0","doc":"","ref":"Evision.Constant.html#cv_COLORCHECKER_DigitalSG/0"},{"type":"function","title":"Evision.Constant.cv_COLORCHECKER_Macbeth/0","doc":"","ref":"Evision.Constant.html#cv_COLORCHECKER_Macbeth/0"},{"type":"function","title":"Evision.Constant.cv_COLORCHECKER_Vinyl/0","doc":"","ref":"Evision.Constant.html#cv_COLORCHECKER_Vinyl/0"},{"type":"function","title":"Evision.Constant.cv_COLOREDTSDF/0","doc":"","ref":"Evision.Constant.html#cv_COLOREDTSDF/0"},{"type":"function","title":"Evision.Constant.cv_COLORMAP_AUTUMN/0","doc":"","ref":"Evision.Constant.html#cv_COLORMAP_AUTUMN/0"},{"type":"function","title":"Evision.Constant.cv_COLORMAP_BONE/0","doc":"","ref":"Evision.Constant.html#cv_COLORMAP_BONE/0"},{"type":"function","title":"Evision.Constant.cv_COLORMAP_CIVIDIS/0","doc":"","ref":"Evision.Constant.html#cv_COLORMAP_CIVIDIS/0"},{"type":"function","title":"Evision.Constant.cv_COLORMAP_COOL/0","doc":"","ref":"Evision.Constant.html#cv_COLORMAP_COOL/0"},{"type":"function","title":"Evision.Constant.cv_COLORMAP_DEEPGREEN/0","doc":"","ref":"Evision.Constant.html#cv_COLORMAP_DEEPGREEN/0"},{"type":"function","title":"Evision.Constant.cv_COLORMAP_HOT/0","doc":"","ref":"Evision.Constant.html#cv_COLORMAP_HOT/0"},{"type":"function","title":"Evision.Constant.cv_COLORMAP_HSV/0","doc":"","ref":"Evision.Constant.html#cv_COLORMAP_HSV/0"},{"type":"function","title":"Evision.Constant.cv_COLORMAP_INFERNO/0","doc":"","ref":"Evision.Constant.html#cv_COLORMAP_INFERNO/0"},{"type":"function","title":"Evision.Constant.cv_COLORMAP_JET/0","doc":"","ref":"Evision.Constant.html#cv_COLORMAP_JET/0"},{"type":"function","title":"Evision.Constant.cv_COLORMAP_MAGMA/0","doc":"","ref":"Evision.Constant.html#cv_COLORMAP_MAGMA/0"},{"type":"function","title":"Evision.Constant.cv_COLORMAP_OCEAN/0","doc":"","ref":"Evision.Constant.html#cv_COLORMAP_OCEAN/0"},{"type":"function","title":"Evision.Constant.cv_COLORMAP_PARULA/0","doc":"","ref":"Evision.Constant.html#cv_COLORMAP_PARULA/0"},{"type":"function","title":"Evision.Constant.cv_COLORMAP_PINK/0","doc":"","ref":"Evision.Constant.html#cv_COLORMAP_PINK/0"},{"type":"function","title":"Evision.Constant.cv_COLORMAP_PLASMA/0","doc":"","ref":"Evision.Constant.html#cv_COLORMAP_PLASMA/0"},{"type":"function","title":"Evision.Constant.cv_COLORMAP_RAINBOW/0","doc":"","ref":"Evision.Constant.html#cv_COLORMAP_RAINBOW/0"},{"type":"function","title":"Evision.Constant.cv_COLORMAP_SPRING/0","doc":"","ref":"Evision.Constant.html#cv_COLORMAP_SPRING/0"},{"type":"function","title":"Evision.Constant.cv_COLORMAP_SUMMER/0","doc":"","ref":"Evision.Constant.html#cv_COLORMAP_SUMMER/0"},{"type":"function","title":"Evision.Constant.cv_COLORMAP_TURBO/0","doc":"","ref":"Evision.Constant.html#cv_COLORMAP_TURBO/0"},{"type":"function","title":"Evision.Constant.cv_COLORMAP_TWILIGHT/0","doc":"","ref":"Evision.Constant.html#cv_COLORMAP_TWILIGHT/0"},{"type":"function","title":"Evision.Constant.cv_COLORMAP_TWILIGHT_SHIFTED/0","doc":"","ref":"Evision.Constant.html#cv_COLORMAP_TWILIGHT_SHIFTED/0"},{"type":"function","title":"Evision.Constant.cv_COLORMAP_VIRIDIS/0","doc":"","ref":"Evision.Constant.html#cv_COLORMAP_VIRIDIS/0"},{"type":"function","title":"Evision.Constant.cv_COLORMAP_WINTER/0","doc":"","ref":"Evision.Constant.html#cv_COLORMAP_WINTER/0"},{"type":"function","title":"Evision.Constant.cv_COMPRESSED_INPUT/0","doc":"","ref":"Evision.Constant.html#cv_COMPRESSED_INPUT/0"},{"type":"function","title":"Evision.Constant.cv_CONSTANT/0","doc":"","ref":"Evision.Constant.html#cv_CONSTANT/0"},{"type":"function","title":"Evision.Constant.cv_CONTOURS_MATCH_I1/0","doc":"","ref":"Evision.Constant.html#cv_CONTOURS_MATCH_I1/0"},{"type":"function","title":"Evision.Constant.cv_CONTOURS_MATCH_I2/0","doc":"","ref":"Evision.Constant.html#cv_CONTOURS_MATCH_I2/0"},{"type":"function","title":"Evision.Constant.cv_CONTOURS_MATCH_I3/0","doc":"","ref":"Evision.Constant.html#cv_CONTOURS_MATCH_I3/0"},{"type":"function","title":"Evision.Constant.cv_COPY_ON_MAP/0","doc":"","ref":"Evision.Constant.html#cv_COPY_ON_MAP/0"},{"type":"function","title":"Evision.Constant.cv_CORNER_REFINE_APRILTAG/0","doc":"","ref":"Evision.Constant.html#cv_CORNER_REFINE_APRILTAG/0"},{"type":"function","title":"Evision.Constant.cv_CORNER_REFINE_CONTOUR/0","doc":"","ref":"Evision.Constant.html#cv_CORNER_REFINE_CONTOUR/0"},{"type":"function","title":"Evision.Constant.cv_CORNER_REFINE_NONE/0","doc":"","ref":"Evision.Constant.html#cv_CORNER_REFINE_NONE/0"},{"type":"function","title":"Evision.Constant.cv_CORNER_REFINE_SUBPIX/0","doc":"","ref":"Evision.Constant.html#cv_CORNER_REFINE_SUBPIX/0"},{"type":"function","title":"Evision.Constant.cv_CORRECT_LEVEL_H/0","doc":"","ref":"Evision.Constant.html#cv_CORRECT_LEVEL_H/0"},{"type":"function","title":"Evision.Constant.cv_CORRECT_LEVEL_L/0","doc":"","ref":"Evision.Constant.html#cv_CORRECT_LEVEL_L/0"},{"type":"function","title":"Evision.Constant.cv_CORRECT_LEVEL_M/0","doc":"","ref":"Evision.Constant.html#cv_CORRECT_LEVEL_M/0"},{"type":"function","title":"Evision.Constant.cv_CORRECT_LEVEL_Q/0","doc":"","ref":"Evision.Constant.html#cv_CORRECT_LEVEL_Q/0"},{"type":"function","title":"Evision.Constant.cv_COST_COLOR/0","doc":"","ref":"Evision.Constant.html#cv_COST_COLOR/0"},{"type":"function","title":"Evision.Constant.cv_COST_COLOR_GRAD/0","doc":"","ref":"Evision.Constant.html#cv_COST_COLOR_GRAD/0"},{"type":"function","title":"Evision.Constant.cv_COUNT/0","doc":"","ref":"Evision.Constant.html#cv_COUNT/0"},{"type":"function","title":"Evision.Constant.cv_COV_MAT_DEFAULT/0","doc":"","ref":"Evision.Constant.html#cv_COV_MAT_DEFAULT/0"},{"type":"function","title":"Evision.Constant.cv_COV_MAT_DIAGONAL/0","doc":"","ref":"Evision.Constant.html#cv_COV_MAT_DIAGONAL/0"},{"type":"function","title":"Evision.Constant.cv_COV_MAT_GENERIC/0","doc":"","ref":"Evision.Constant.html#cv_COV_MAT_GENERIC/0"},{"type":"function","title":"Evision.Constant.cv_COV_MAT_SPHERICAL/0","doc":"","ref":"Evision.Constant.html#cv_COV_MAT_SPHERICAL/0"},{"type":"function","title":"Evision.Constant.cv_COV_POLISHER/0","doc":"","ref":"Evision.Constant.html#cv_COV_POLISHER/0"},{"type":"function","title":"Evision.Constant.cv_COVAR_COLS/0","doc":"","ref":"Evision.Constant.html#cv_COVAR_COLS/0"},{"type":"function","title":"Evision.Constant.cv_COVAR_NORMAL/0","doc":"","ref":"Evision.Constant.html#cv_COVAR_NORMAL/0"},{"type":"function","title":"Evision.Constant.cv_COVAR_ROWS/0","doc":"","ref":"Evision.Constant.html#cv_COVAR_ROWS/0"},{"type":"function","title":"Evision.Constant.cv_COVAR_SCALE/0","doc":"","ref":"Evision.Constant.html#cv_COVAR_SCALE/0"},{"type":"function","title":"Evision.Constant.cv_COVAR_SCRAMBLED/0","doc":"","ref":"Evision.Constant.html#cv_COVAR_SCRAMBLED/0"},{"type":"function","title":"Evision.Constant.cv_COVAR_USE_AVG/0","doc":"","ref":"Evision.Constant.html#cv_COVAR_USE_AVG/0"},{"type":"function","title":"Evision.Constant.cv_ColorFormat_RGB/0","doc":"","ref":"Evision.Constant.html#cv_ColorFormat_RGB/0"},{"type":"function","title":"Evision.Constant.cv_ColorFormat_RGBA/0","doc":"","ref":"Evision.Constant.html#cv_ColorFormat_RGBA/0"},{"type":"function","title":"Evision.Constant.cv_ComputeModeDefault/0","doc":"","ref":"Evision.Constant.html#cv_ComputeModeDefault/0"},{"type":"function","title":"Evision.Constant.cv_ComputeModeExclusive/0","doc":"","ref":"Evision.Constant.html#cv_ComputeModeExclusive/0"},{"type":"function","title":"Evision.Constant.cv_ComputeModeExclusiveProcess/0","doc":"","ref":"Evision.Constant.html#cv_ComputeModeExclusiveProcess/0"},{"type":"function","title":"Evision.Constant.cv_ComputeModeProhibited/0","doc":"","ref":"Evision.Constant.html#cv_ComputeModeProhibited/0"},{"type":"function","title":"Evision.Constant.cv_CROP/0","doc":"","ref":"Evision.Constant.html#cv_CROP/0"},{"type":"function","title":"Evision.Constant.cv_CUDA_GPU_MAT/0","doc":"","ref":"Evision.Constant.html#cv_CUDA_GPU_MAT/0"},{"type":"function","title":"Evision.Constant.cv_CUDA_HOST_MEM/0","doc":"","ref":"Evision.Constant.html#cv_CUDA_HOST_MEM/0"},{"type":"function","title":"Evision.Constant.cv_CUSTOM/0","doc":"","ref":"Evision.Constant.html#cv_CUSTOM/0"},{"type":"function","title":"Evision.Constant.cv_CV_CS_CENSUS/0","doc":"","ref":"Evision.Constant.html#cv_CV_CS_CENSUS/0"},{"type":"function","title":"Evision.Constant.cv_CV_DENSE_CENSUS/0","doc":"","ref":"Evision.Constant.html#cv_CV_DENSE_CENSUS/0"},{"type":"function","title":"Evision.Constant.cv_CV_MEAN_VARIATION/0","doc":"","ref":"Evision.Constant.html#cv_CV_MEAN_VARIATION/0"},{"type":"function","title":"Evision.Constant.cv_CV_MODIFIED_CENSUS_TRANSFORM/0","doc":"","ref":"Evision.Constant.html#cv_CV_MODIFIED_CENSUS_TRANSFORM/0"},{"type":"function","title":"Evision.Constant.cv_CV_MODIFIED_CS_CENSUS/0","doc":"","ref":"Evision.Constant.html#cv_CV_MODIFIED_CS_CENSUS/0"},{"type":"function","title":"Evision.Constant.cv_CV_QUADRATIC_INTERPOLATION/0","doc":"","ref":"Evision.Constant.html#cv_CV_QUADRATIC_INTERPOLATION/0"},{"type":"function","title":"Evision.Constant.cv_CV_SIMETRICV_INTERPOLATION/0","doc":"","ref":"Evision.Constant.html#cv_CV_SIMETRICV_INTERPOLATION/0"},{"type":"function","title":"Evision.Constant.cv_CV_SPARSE_CENSUS/0","doc":"","ref":"Evision.Constant.html#cv_CV_SPARSE_CENSUS/0"},{"type":"function","title":"Evision.Constant.cv_CV_SPECKLE_REMOVAL_ALGORITHM/0","doc":"","ref":"Evision.Constant.html#cv_CV_SPECKLE_REMOVAL_ALGORITHM/0"},{"type":"function","title":"Evision.Constant.cv_CV_SPECKLE_REMOVAL_AVG_ALGORITHM/0","doc":"","ref":"Evision.Constant.html#cv_CV_SPECKLE_REMOVAL_AVG_ALGORITHM/0"},{"type":"function","title":"Evision.Constant.cv_CV_STAR_KERNEL/0","doc":"","ref":"Evision.Constant.html#cv_CV_STAR_KERNEL/0"},{"type":"function","title":"Evision.Constant.cv_cn_shift/0","doc":"","ref":"Evision.Constant.html#cv_cn_shift/0"},{"type":"function","title":"Evision.Constant.cv_DATA_AS_COL/0","doc":"","ref":"Evision.Constant.html#cv_DATA_AS_COL/0"},{"type":"function","title":"Evision.Constant.cv_DATA_AS_ROW/0","doc":"","ref":"Evision.Constant.html#cv_DATA_AS_ROW/0"},{"type":"function","title":"Evision.Constant.cv_DCT_INVERSE/0","doc":"","ref":"Evision.Constant.html#cv_DCT_INVERSE/0"},{"type":"function","title":"Evision.Constant.cv_DCT_ROWS/0","doc":"","ref":"Evision.Constant.html#cv_DCT_ROWS/0"},{"type":"function","title":"Evision.Constant.cv_DECODE_3D_UNDERWORLD/0","doc":"","ref":"Evision.Constant.html#cv_DECODE_3D_UNDERWORLD/0"},{"type":"function","title":"Evision.Constant.cv_DECOMP_CHOLESKY/0","doc":"","ref":"Evision.Constant.html#cv_DECOMP_CHOLESKY/0"},{"type":"function","title":"Evision.Constant.cv_DECOMP_EIG/0","doc":"","ref":"Evision.Constant.html#cv_DECOMP_EIG/0"},{"type":"function","title":"Evision.Constant.cv_DECOMP_LU/0","doc":"","ref":"Evision.Constant.html#cv_DECOMP_LU/0"},{"type":"function","title":"Evision.Constant.cv_DECOMP_NORMAL/0","doc":"","ref":"Evision.Constant.html#cv_DECOMP_NORMAL/0"},{"type":"function","title":"Evision.Constant.cv_DECOMP_QR/0","doc":"","ref":"Evision.Constant.html#cv_DECOMP_QR/0"},{"type":"function","title":"Evision.Constant.cv_DECOMP_SVD/0","doc":"","ref":"Evision.Constant.html#cv_DECOMP_SVD/0"},{"type":"function","title":"Evision.Constant.cv_DEFAULT/0","doc":"","ref":"Evision.Constant.html#cv_DEFAULT/0"},{"type":"function","title":"Evision.Constant.cv_DEFAULT_MAX_ITERS/0","doc":"","ref":"Evision.Constant.html#cv_DEFAULT_MAX_ITERS/0"},{"type":"function","title":"Evision.Constant.cv_DEFAULT_NCLUSTERS/0","doc":"","ref":"Evision.Constant.html#cv_DEFAULT_NCLUSTERS/0"},{"type":"function","title":"Evision.Constant.cv_DEFAULT_NLEVELS/0","doc":"","ref":"Evision.Constant.html#cv_DEFAULT_NLEVELS/0"},{"type":"function","title":"Evision.Constant.cv_DEGREE/0","doc":"","ref":"Evision.Constant.html#cv_DEGREE/0"},{"type":"function","title":"Evision.Constant.cv_DEPTH_CLEANER_NIL/0","doc":"","ref":"Evision.Constant.html#cv_DEPTH_CLEANER_NIL/0"},{"type":"function","title":"Evision.Constant.cv_DEPTH_COMPONENT/0","doc":"","ref":"Evision.Constant.html#cv_DEPTH_COMPONENT/0"},{"type":"function","title":"Evision.Constant.cv_DEPTH_MASK/0","doc":"","ref":"Evision.Constant.html#cv_DEPTH_MASK/0"},{"type":"function","title":"Evision.Constant.cv_DEPTH_MASK_8S/0","doc":"","ref":"Evision.Constant.html#cv_DEPTH_MASK_8S/0"},{"type":"function","title":"Evision.Constant.cv_DEPTH_MASK_8U/0","doc":"","ref":"Evision.Constant.html#cv_DEPTH_MASK_8U/0"},{"type":"function","title":"Evision.Constant.cv_DEPTH_MASK_16F/0","doc":"","ref":"Evision.Constant.html#cv_DEPTH_MASK_16F/0"},{"type":"function","title":"Evision.Constant.cv_DEPTH_MASK_16S/0","doc":"","ref":"Evision.Constant.html#cv_DEPTH_MASK_16S/0"},{"type":"function","title":"Evision.Constant.cv_DEPTH_MASK_16U/0","doc":"","ref":"Evision.Constant.html#cv_DEPTH_MASK_16U/0"},{"type":"function","title":"Evision.Constant.cv_DEPTH_MASK_32F/0","doc":"","ref":"Evision.Constant.html#cv_DEPTH_MASK_32F/0"},{"type":"function","title":"Evision.Constant.cv_DEPTH_MASK_32S/0","doc":"","ref":"Evision.Constant.html#cv_DEPTH_MASK_32S/0"},{"type":"function","title":"Evision.Constant.cv_DEPTH_MASK_64F/0","doc":"","ref":"Evision.Constant.html#cv_DEPTH_MASK_64F/0"},{"type":"function","title":"Evision.Constant.cv_DEPTH_MASK_ALL/0","doc":"","ref":"Evision.Constant.html#cv_DEPTH_MASK_ALL/0"},{"type":"function","title":"Evision.Constant.cv_DEPTH_MASK_ALL_16F/0","doc":"","ref":"Evision.Constant.html#cv_DEPTH_MASK_ALL_16F/0"},{"type":"function","title":"Evision.Constant.cv_DEPTH_MASK_ALL_BUT_8S/0","doc":"","ref":"Evision.Constant.html#cv_DEPTH_MASK_ALL_BUT_8S/0"},{"type":"function","title":"Evision.Constant.cv_DEPTH_MASK_FLT/0","doc":"","ref":"Evision.Constant.html#cv_DEPTH_MASK_FLT/0"},{"type":"function","title":"Evision.Constant.cv_DESCR_FORMAT_COL_BY_COL/0","doc":"","ref":"Evision.Constant.html#cv_DESCR_FORMAT_COL_BY_COL/0"},{"type":"function","title":"Evision.Constant.cv_DESCR_FORMAT_ROW_BY_ROW/0","doc":"","ref":"Evision.Constant.html#cv_DESCR_FORMAT_ROW_BY_ROW/0"},{"type":"function","title":"Evision.Constant.cv_DESCRIPTOR_KAZE/0","doc":"","ref":"Evision.Constant.html#cv_DESCRIPTOR_KAZE/0"},{"type":"function","title":"Evision.Constant.cv_DESCRIPTOR_KAZE_UPRIGHT/0","doc":"","ref":"Evision.Constant.html#cv_DESCRIPTOR_KAZE_UPRIGHT/0"},{"type":"function","title":"Evision.Constant.cv_DESCRIPTOR_MLDB/0","doc":"","ref":"Evision.Constant.html#cv_DESCRIPTOR_MLDB/0"},{"type":"function","title":"Evision.Constant.cv_DESCRIPTOR_MLDB_UPRIGHT/0","doc":"","ref":"Evision.Constant.html#cv_DESCRIPTOR_MLDB_UPRIGHT/0"},{"type":"function","title":"Evision.Constant.cv_DEVICE_COPY_OBSOLETE/0","doc":"","ref":"Evision.Constant.html#cv_DEVICE_COPY_OBSOLETE/0"},{"type":"function","title":"Evision.Constant.cv_DEVICE_MEM_MAPPED/0","doc":"","ref":"Evision.Constant.html#cv_DEVICE_MEM_MAPPED/0"},{"type":"function","title":"Evision.Constant.cv_DFT_COMPLEX_INPUT/0","doc":"","ref":"Evision.Constant.html#cv_DFT_COMPLEX_INPUT/0"},{"type":"function","title":"Evision.Constant.cv_DFT_COMPLEX_OUTPUT/0","doc":"","ref":"Evision.Constant.html#cv_DFT_COMPLEX_OUTPUT/0"},{"type":"function","title":"Evision.Constant.cv_DFT_INVERSE/0","doc":"","ref":"Evision.Constant.html#cv_DFT_INVERSE/0"},{"type":"function","title":"Evision.Constant.cv_DFT_REAL_OUTPUT/0","doc":"","ref":"Evision.Constant.html#cv_DFT_REAL_OUTPUT/0"},{"type":"function","title":"Evision.Constant.cv_DFT_ROWS/0","doc":"","ref":"Evision.Constant.html#cv_DFT_ROWS/0"},{"type":"function","title":"Evision.Constant.cv_DFT_SCALE/0","doc":"","ref":"Evision.Constant.html#cv_DFT_SCALE/0"},{"type":"function","title":"Evision.Constant.cv_DICT_4X4_50/0","doc":"","ref":"Evision.Constant.html#cv_DICT_4X4_50/0"},{"type":"function","title":"Evision.Constant.cv_DICT_4X4_100/0","doc":"","ref":"Evision.Constant.html#cv_DICT_4X4_100/0"},{"type":"function","title":"Evision.Constant.cv_DICT_4X4_250/0","doc":"","ref":"Evision.Constant.html#cv_DICT_4X4_250/0"},{"type":"function","title":"Evision.Constant.cv_DICT_4X4_1000/0","doc":"","ref":"Evision.Constant.html#cv_DICT_4X4_1000/0"},{"type":"function","title":"Evision.Constant.cv_DICT_5X5_50/0","doc":"","ref":"Evision.Constant.html#cv_DICT_5X5_50/0"},{"type":"function","title":"Evision.Constant.cv_DICT_5X5_100/0","doc":"","ref":"Evision.Constant.html#cv_DICT_5X5_100/0"},{"type":"function","title":"Evision.Constant.cv_DICT_5X5_250/0","doc":"","ref":"Evision.Constant.html#cv_DICT_5X5_250/0"},{"type":"function","title":"Evision.Constant.cv_DICT_5X5_1000/0","doc":"","ref":"Evision.Constant.html#cv_DICT_5X5_1000/0"},{"type":"function","title":"Evision.Constant.cv_DICT_6X6_50/0","doc":"","ref":"Evision.Constant.html#cv_DICT_6X6_50/0"},{"type":"function","title":"Evision.Constant.cv_DICT_6X6_100/0","doc":"","ref":"Evision.Constant.html#cv_DICT_6X6_100/0"},{"type":"function","title":"Evision.Constant.cv_DICT_6X6_250/0","doc":"","ref":"Evision.Constant.html#cv_DICT_6X6_250/0"},{"type":"function","title":"Evision.Constant.cv_DICT_6X6_1000/0","doc":"","ref":"Evision.Constant.html#cv_DICT_6X6_1000/0"},{"type":"function","title":"Evision.Constant.cv_DICT_7X7_50/0","doc":"","ref":"Evision.Constant.html#cv_DICT_7X7_50/0"},{"type":"function","title":"Evision.Constant.cv_DICT_7X7_100/0","doc":"","ref":"Evision.Constant.html#cv_DICT_7X7_100/0"},{"type":"function","title":"Evision.Constant.cv_DICT_7X7_250/0","doc":"","ref":"Evision.Constant.html#cv_DICT_7X7_250/0"},{"type":"function","title":"Evision.Constant.cv_DICT_7X7_1000/0","doc":"","ref":"Evision.Constant.html#cv_DICT_7X7_1000/0"},{"type":"function","title":"Evision.Constant.cv_DICT_APRILTAG_16h5/0","doc":"","ref":"Evision.Constant.html#cv_DICT_APRILTAG_16h5/0"},{"type":"function","title":"Evision.Constant.cv_DICT_APRILTAG_25h9/0","doc":"","ref":"Evision.Constant.html#cv_DICT_APRILTAG_25h9/0"},{"type":"function","title":"Evision.Constant.cv_DICT_APRILTAG_36h10/0","doc":"","ref":"Evision.Constant.html#cv_DICT_APRILTAG_36h10/0"},{"type":"function","title":"Evision.Constant.cv_DICT_APRILTAG_36h11/0","doc":"","ref":"Evision.Constant.html#cv_DICT_APRILTAG_36h11/0"},{"type":"function","title":"Evision.Constant.cv_DICT_ARUCO_MIP_36h12/0","doc":"","ref":"Evision.Constant.html#cv_DICT_ARUCO_MIP_36h12/0"},{"type":"function","title":"Evision.Constant.cv_DICT_ARUCO_ORIGINAL/0","doc":"","ref":"Evision.Constant.html#cv_DICT_ARUCO_ORIGINAL/0"},{"type":"function","title":"Evision.Constant.cv_DIFF_CHARBONNIER/0","doc":"","ref":"Evision.Constant.html#cv_DIFF_CHARBONNIER/0"},{"type":"function","title":"Evision.Constant.cv_DIFF_PM_G1/0","doc":"","ref":"Evision.Constant.html#cv_DIFF_PM_G1/0"},{"type":"function","title":"Evision.Constant.cv_DIFF_PM_G2/0","doc":"","ref":"Evision.Constant.html#cv_DIFF_PM_G2/0"},{"type":"function","title":"Evision.Constant.cv_DIFF_WEICKERT/0","doc":"","ref":"Evision.Constant.html#cv_DIFF_WEICKERT/0"},{"type":"function","title":"Evision.Constant.cv_DISABLE_TIMING/0","doc":"","ref":"Evision.Constant.html#cv_DISABLE_TIMING/0"},{"type":"function","title":"Evision.Constant.cv_DISCRETE/0","doc":"","ref":"Evision.Constant.html#cv_DISCRETE/0"},{"type":"function","title":"Evision.Constant.cv_DISP_SCALE/0","doc":"","ref":"Evision.Constant.html#cv_DISP_SCALE/0"},{"type":"function","title":"Evision.Constant.cv_DISP_SHIFT/0","doc":"","ref":"Evision.Constant.html#cv_DISP_SHIFT/0"},{"type":"function","title":"Evision.Constant.cv_DIST_C/0","doc":"","ref":"Evision.Constant.html#cv_DIST_C/0"},{"type":"function","title":"Evision.Constant.cv_DIST_FAIR/0","doc":"","ref":"Evision.Constant.html#cv_DIST_FAIR/0"},{"type":"function","title":"Evision.Constant.cv_DIST_HUBER/0","doc":"","ref":"Evision.Constant.html#cv_DIST_HUBER/0"},{"type":"function","title":"Evision.Constant.cv_DIST_L1/0","doc":"","ref":"Evision.Constant.html#cv_DIST_L1/0"},{"type":"function","title":"Evision.Constant.cv_DIST_L2/0","doc":"","ref":"Evision.Constant.html#cv_DIST_L2/0"},{"type":"function","title":"Evision.Constant.cv_DIST_L12/0","doc":"","ref":"Evision.Constant.html#cv_DIST_L12/0"},{"type":"function","title":"Evision.Constant.cv_DIST_LABEL_CCOMP/0","doc":"","ref":"Evision.Constant.html#cv_DIST_LABEL_CCOMP/0"},{"type":"function","title":"Evision.Constant.cv_DIST_LABEL_PIXEL/0","doc":"","ref":"Evision.Constant.html#cv_DIST_LABEL_PIXEL/0"},{"type":"function","title":"Evision.Constant.cv_DIST_MASK_3/0","doc":"","ref":"Evision.Constant.html#cv_DIST_MASK_3/0"},{"type":"function","title":"Evision.Constant.cv_DIST_MASK_5/0","doc":"","ref":"Evision.Constant.html#cv_DIST_MASK_5/0"},{"type":"function","title":"Evision.Constant.cv_DIST_MASK_PRECISE/0","doc":"","ref":"Evision.Constant.html#cv_DIST_MASK_PRECISE/0"},{"type":"function","title":"Evision.Constant.cv_DIST_USER/0","doc":"","ref":"Evision.Constant.html#cv_DIST_USER/0"},{"type":"function","title":"Evision.Constant.cv_DIST_WELSCH/0","doc":"","ref":"Evision.Constant.html#cv_DIST_WELSCH/0"},{"type":"function","title":"Evision.Constant.cv_DISTANCE_CIE76/0","doc":"","ref":"Evision.Constant.html#cv_DISTANCE_CIE76/0"},{"type":"function","title":"Evision.Constant.cv_DISTANCE_CIE94_GRAPHIC_ARTS/0","doc":"","ref":"Evision.Constant.html#cv_DISTANCE_CIE94_GRAPHIC_ARTS/0"},{"type":"function","title":"Evision.Constant.cv_DISTANCE_CIE94_TEXTILES/0","doc":"","ref":"Evision.Constant.html#cv_DISTANCE_CIE94_TEXTILES/0"},{"type":"function","title":"Evision.Constant.cv_DISTANCE_CIE2000/0","doc":"","ref":"Evision.Constant.html#cv_DISTANCE_CIE2000/0"},{"type":"function","title":"Evision.Constant.cv_DISTANCE_CMC_1TO1/0","doc":"","ref":"Evision.Constant.html#cv_DISTANCE_CMC_1TO1/0"},{"type":"function","title":"Evision.Constant.cv_DISTANCE_CMC_2TO1/0","doc":"","ref":"Evision.Constant.html#cv_DISTANCE_CMC_2TO1/0"},{"type":"function","title":"Evision.Constant.cv_DISTANCE_RGB/0","doc":"","ref":"Evision.Constant.html#cv_DISTANCE_RGB/0"},{"type":"function","title":"Evision.Constant.cv_DISTANCE_RGBL/0","doc":"","ref":"Evision.Constant.html#cv_DISTANCE_RGBL/0"},{"type":"function","title":"Evision.Constant.cv_DNN_BACKEND_CANN/0","doc":"","ref":"Evision.Constant.html#cv_DNN_BACKEND_CANN/0"},{"type":"function","title":"Evision.Constant.cv_DNN_BACKEND_CUDA/0","doc":"","ref":"Evision.Constant.html#cv_DNN_BACKEND_CUDA/0"},{"type":"function","title":"Evision.Constant.cv_DNN_BACKEND_DEFAULT/0","doc":"","ref":"Evision.Constant.html#cv_DNN_BACKEND_DEFAULT/0"},{"type":"function","title":"Evision.Constant.cv_DNN_BACKEND_HALIDE/0","doc":"","ref":"Evision.Constant.html#cv_DNN_BACKEND_HALIDE/0"},{"type":"function","title":"Evision.Constant.cv_DNN_BACKEND_INFERENCE_ENGINE/0","doc":"","ref":"Evision.Constant.html#cv_DNN_BACKEND_INFERENCE_ENGINE/0"},{"type":"function","title":"Evision.Constant.cv_DNN_BACKEND_OPENCV/0","doc":"","ref":"Evision.Constant.html#cv_DNN_BACKEND_OPENCV/0"},{"type":"function","title":"Evision.Constant.cv_DNN_BACKEND_TIMVX/0","doc":"","ref":"Evision.Constant.html#cv_DNN_BACKEND_TIMVX/0"},{"type":"function","title":"Evision.Constant.cv_DNN_BACKEND_VKCOM/0","doc":"","ref":"Evision.Constant.html#cv_DNN_BACKEND_VKCOM/0"},{"type":"function","title":"Evision.Constant.cv_DNN_BACKEND_WEBNN/0","doc":"","ref":"Evision.Constant.html#cv_DNN_BACKEND_WEBNN/0"},{"type":"function","title":"Evision.Constant.cv_DNN_LAYOUT_NCDHW/0","doc":"","ref":"Evision.Constant.html#cv_DNN_LAYOUT_NCDHW/0"},{"type":"function","title":"Evision.Constant.cv_DNN_LAYOUT_NCHW/0","doc":"","ref":"Evision.Constant.html#cv_DNN_LAYOUT_NCHW/0"},{"type":"function","title":"Evision.Constant.cv_DNN_LAYOUT_ND/0","doc":"","ref":"Evision.Constant.html#cv_DNN_LAYOUT_ND/0"},{"type":"function","title":"Evision.Constant.cv_DNN_LAYOUT_NDHWC/0","doc":"","ref":"Evision.Constant.html#cv_DNN_LAYOUT_NDHWC/0"},{"type":"function","title":"Evision.Constant.cv_DNN_LAYOUT_NHWC/0","doc":"","ref":"Evision.Constant.html#cv_DNN_LAYOUT_NHWC/0"},{"type":"function","title":"Evision.Constant.cv_DNN_LAYOUT_PLANAR/0","doc":"","ref":"Evision.Constant.html#cv_DNN_LAYOUT_PLANAR/0"},{"type":"function","title":"Evision.Constant.cv_DNN_LAYOUT_UNKNOWN/0","doc":"","ref":"Evision.Constant.html#cv_DNN_LAYOUT_UNKNOWN/0"},{"type":"function","title":"Evision.Constant.cv_DNN_PMODE_CROP_CENTER/0","doc":"","ref":"Evision.Constant.html#cv_DNN_PMODE_CROP_CENTER/0"},{"type":"function","title":"Evision.Constant.cv_DNN_PMODE_LETTERBOX/0","doc":"","ref":"Evision.Constant.html#cv_DNN_PMODE_LETTERBOX/0"},{"type":"function","title":"Evision.Constant.cv_DNN_PMODE_NULL/0","doc":"","ref":"Evision.Constant.html#cv_DNN_PMODE_NULL/0"},{"type":"function","title":"Evision.Constant.cv_DNN_TARGET_CPU/0","doc":"","ref":"Evision.Constant.html#cv_DNN_TARGET_CPU/0"},{"type":"function","title":"Evision.Constant.cv_DNN_TARGET_CPU_FP16/0","doc":"","ref":"Evision.Constant.html#cv_DNN_TARGET_CPU_FP16/0"},{"type":"function","title":"Evision.Constant.cv_DNN_TARGET_CUDA/0","doc":"","ref":"Evision.Constant.html#cv_DNN_TARGET_CUDA/0"},{"type":"function","title":"Evision.Constant.cv_DNN_TARGET_CUDA_FP16/0","doc":"","ref":"Evision.Constant.html#cv_DNN_TARGET_CUDA_FP16/0"},{"type":"function","title":"Evision.Constant.cv_DNN_TARGET_FPGA/0","doc":"","ref":"Evision.Constant.html#cv_DNN_TARGET_FPGA/0"},{"type":"function","title":"Evision.Constant.cv_DNN_TARGET_HDDL/0","doc":"","ref":"Evision.Constant.html#cv_DNN_TARGET_HDDL/0"},{"type":"function","title":"Evision.Constant.cv_DNN_TARGET_MYRIAD/0","doc":"","ref":"Evision.Constant.html#cv_DNN_TARGET_MYRIAD/0"},{"type":"function","title":"Evision.Constant.cv_DNN_TARGET_NPU/0","doc":"","ref":"Evision.Constant.html#cv_DNN_TARGET_NPU/0"},{"type":"function","title":"Evision.Constant.cv_DNN_TARGET_OPENCL/0","doc":"","ref":"Evision.Constant.html#cv_DNN_TARGET_OPENCL/0"},{"type":"function","title":"Evision.Constant.cv_DNN_TARGET_OPENCL_FP16/0","doc":"","ref":"Evision.Constant.html#cv_DNN_TARGET_OPENCL_FP16/0"},{"type":"function","title":"Evision.Constant.cv_DNN_TARGET_VULKAN/0","doc":"","ref":"Evision.Constant.html#cv_DNN_TARGET_VULKAN/0"},{"type":"function","title":"Evision.Constant.cv_DP_SEAM/0","doc":"","ref":"Evision.Constant.html#cv_DP_SEAM/0"},{"type":"function","title":"Evision.Constant.cv_DRAW_OVER_OUTIMG/0","doc":"","ref":"Evision.Constant.html#cv_DRAW_OVER_OUTIMG/0"},{"type":"function","title":"Evision.Constant.cv_DRAW_RICH_KEYPOINTS/0","doc":"","ref":"Evision.Constant.html#cv_DRAW_RICH_KEYPOINTS/0"},{"type":"function","title":"Evision.Constant.cv_DTF_IC/0","doc":"","ref":"Evision.Constant.html#cv_DTF_IC/0"},{"type":"function","title":"Evision.Constant.cv_DTF_NC/0","doc":"","ref":"Evision.Constant.html#cv_DTF_NC/0"},{"type":"function","title":"Evision.Constant.cv_DTF_RF/0","doc":"","ref":"Evision.Constant.html#cv_DTF_RF/0"},{"type":"function","title":"Evision.Constant.cv_DYNAMIC_PARALLELISM/0","doc":"","ref":"Evision.Constant.html#cv_DYNAMIC_PARALLELISM/0"},{"type":"function","title":"Evision.Constant.cv_depth_max/0","doc":"","ref":"Evision.Constant.html#cv_depth_max/0"},{"type":"function","title":"Evision.Constant.cv_ECI_UTF8/0","doc":"","ref":"Evision.Constant.html#cv_ECI_UTF8/0"},{"type":"function","title":"Evision.Constant.cv_ELEMENT_ARRAY_BUFFER/0","doc":"","ref":"Evision.Constant.html#cv_ELEMENT_ARRAY_BUFFER/0"},{"type":"function","title":"Evision.Constant.cv_EMPTY/0","doc":"","ref":"Evision.Constant.html#cv_EMPTY/0"},{"type":"function","title":"Evision.Constant.cv_ENC_CODEC_PROFILE_AUTOSELECT/0","doc":"","ref":"Evision.Constant.html#cv_ENC_CODEC_PROFILE_AUTOSELECT/0"},{"type":"function","title":"Evision.Constant.cv_ENC_H264_PROFILE_BASELINE/0","doc":"","ref":"Evision.Constant.html#cv_ENC_H264_PROFILE_BASELINE/0"},{"type":"function","title":"Evision.Constant.cv_ENC_H264_PROFILE_CONSTRAINED_HIGH/0","doc":"","ref":"Evision.Constant.html#cv_ENC_H264_PROFILE_CONSTRAINED_HIGH/0"},{"type":"function","title":"Evision.Constant.cv_ENC_H264_PROFILE_HIGH/0","doc":"","ref":"Evision.Constant.html#cv_ENC_H264_PROFILE_HIGH/0"},{"type":"function","title":"Evision.Constant.cv_ENC_H264_PROFILE_HIGH_444/0","doc":"","ref":"Evision.Constant.html#cv_ENC_H264_PROFILE_HIGH_444/0"},{"type":"function","title":"Evision.Constant.cv_ENC_H264_PROFILE_MAIN/0","doc":"","ref":"Evision.Constant.html#cv_ENC_H264_PROFILE_MAIN/0"},{"type":"function","title":"Evision.Constant.cv_ENC_H264_PROFILE_PROGRESSIVE_HIGH/0","doc":"","ref":"Evision.Constant.html#cv_ENC_H264_PROFILE_PROGRESSIVE_HIGH/0"},{"type":"function","title":"Evision.Constant.cv_ENC_H264_PROFILE_STEREO/0","doc":"","ref":"Evision.Constant.html#cv_ENC_H264_PROFILE_STEREO/0"},{"type":"function","title":"Evision.Constant.cv_ENC_HEVC_PROFILE_FREXT/0","doc":"","ref":"Evision.Constant.html#cv_ENC_HEVC_PROFILE_FREXT/0"},{"type":"function","title":"Evision.Constant.cv_ENC_HEVC_PROFILE_MAIN10/0","doc":"","ref":"Evision.Constant.html#cv_ENC_HEVC_PROFILE_MAIN10/0"},{"type":"function","title":"Evision.Constant.cv_ENC_HEVC_PROFILE_MAIN/0","doc":"","ref":"Evision.Constant.html#cv_ENC_HEVC_PROFILE_MAIN/0"},{"type":"function","title":"Evision.Constant.cv_ENC_MULTI_PASS_DISABLED/0","doc":"","ref":"Evision.Constant.html#cv_ENC_MULTI_PASS_DISABLED/0"},{"type":"function","title":"Evision.Constant.cv_ENC_PARAMS_RC_CBR/0","doc":"","ref":"Evision.Constant.html#cv_ENC_PARAMS_RC_CBR/0"},{"type":"function","title":"Evision.Constant.cv_ENC_PARAMS_RC_CONSTQP/0","doc":"","ref":"Evision.Constant.html#cv_ENC_PARAMS_RC_CONSTQP/0"},{"type":"function","title":"Evision.Constant.cv_ENC_PARAMS_RC_VBR/0","doc":"","ref":"Evision.Constant.html#cv_ENC_PARAMS_RC_VBR/0"},{"type":"function","title":"Evision.Constant.cv_ENC_PRESET_P1/0","doc":"","ref":"Evision.Constant.html#cv_ENC_PRESET_P1/0"},{"type":"function","title":"Evision.Constant.cv_ENC_PRESET_P2/0","doc":"","ref":"Evision.Constant.html#cv_ENC_PRESET_P2/0"},{"type":"function","title":"Evision.Constant.cv_ENC_PRESET_P3/0","doc":"","ref":"Evision.Constant.html#cv_ENC_PRESET_P3/0"},{"type":"function","title":"Evision.Constant.cv_ENC_PRESET_P4/0","doc":"","ref":"Evision.Constant.html#cv_ENC_PRESET_P4/0"},{"type":"function","title":"Evision.Constant.cv_ENC_PRESET_P5/0","doc":"","ref":"Evision.Constant.html#cv_ENC_PRESET_P5/0"},{"type":"function","title":"Evision.Constant.cv_ENC_PRESET_P6/0","doc":"","ref":"Evision.Constant.html#cv_ENC_PRESET_P6/0"},{"type":"function","title":"Evision.Constant.cv_ENC_PRESET_P7/0","doc":"","ref":"Evision.Constant.html#cv_ENC_PRESET_P7/0"},{"type":"function","title":"Evision.Constant.cv_ENC_TUNING_INFO_COUNT/0","doc":"","ref":"Evision.Constant.html#cv_ENC_TUNING_INFO_COUNT/0"},{"type":"function","title":"Evision.Constant.cv_ENC_TUNING_INFO_HIGH_QUALITY/0","doc":"","ref":"Evision.Constant.html#cv_ENC_TUNING_INFO_HIGH_QUALITY/0"},{"type":"function","title":"Evision.Constant.cv_ENC_TUNING_INFO_LOSSLESS/0","doc":"","ref":"Evision.Constant.html#cv_ENC_TUNING_INFO_LOSSLESS/0"},{"type":"function","title":"Evision.Constant.cv_ENC_TUNING_INFO_LOW_LATENCY/0","doc":"","ref":"Evision.Constant.html#cv_ENC_TUNING_INFO_LOW_LATENCY/0"},{"type":"function","title":"Evision.Constant.cv_ENC_TUNING_INFO_ULTRA_LOW_LATENCY/0","doc":"","ref":"Evision.Constant.html#cv_ENC_TUNING_INFO_ULTRA_LOW_LATENCY/0"},{"type":"function","title":"Evision.Constant.cv_ENC_TUNING_INFO_UNDEFINED/0","doc":"","ref":"Evision.Constant.html#cv_ENC_TUNING_INFO_UNDEFINED/0"},{"type":"function","title":"Evision.Constant.cv_ENC_TWO_PASS_FULL_RESOLUTION/0","doc":"","ref":"Evision.Constant.html#cv_ENC_TWO_PASS_FULL_RESOLUTION/0"},{"type":"function","title":"Evision.Constant.cv_ENC_TWO_PASS_QUARTER_RESOLUTION/0","doc":"","ref":"Evision.Constant.html#cv_ENC_TWO_PASS_QUARTER_RESOLUTION/0"},{"type":"function","title":"Evision.Constant.cv_EPS/0","doc":"","ref":"Evision.Constant.html#cv_EPS/0"},{"type":"function","title":"Evision.Constant.cv_EPS_SVR/0","doc":"","ref":"Evision.Constant.html#cv_EPS_SVR/0"},{"type":"function","title":"Evision.Constant.cv_ERFILTER_NM_IHSGrad/0","doc":"","ref":"Evision.Constant.html#cv_ERFILTER_NM_IHSGrad/0"},{"type":"function","title":"Evision.Constant.cv_ERFILTER_NM_RGBLGrad/0","doc":"","ref":"Evision.Constant.html#cv_ERFILTER_NM_RGBLGrad/0"},{"type":"function","title":"Evision.Constant.cv_ERGROUPING_ORIENTATION_ANY/0","doc":"","ref":"Evision.Constant.html#cv_ERGROUPING_ORIENTATION_ANY/0"},{"type":"function","title":"Evision.Constant.cv_ERGROUPING_ORIENTATION_HORIZ/0","doc":"","ref":"Evision.Constant.html#cv_ERGROUPING_ORIENTATION_HORIZ/0"},{"type":"function","title":"Evision.Constant.cv_ERR_CAMERA_PARAMS_ADJUST_FAIL/0","doc":"","ref":"Evision.Constant.html#cv_ERR_CAMERA_PARAMS_ADJUST_FAIL/0"},{"type":"function","title":"Evision.Constant.cv_ERR_HOMOGRAPHY_EST_FAIL/0","doc":"","ref":"Evision.Constant.html#cv_ERR_HOMOGRAPHY_EST_FAIL/0"},{"type":"function","title":"Evision.Constant.cv_ERR_NEED_MORE_IMGS/0","doc":"","ref":"Evision.Constant.html#cv_ERR_NEED_MORE_IMGS/0"},{"type":"function","title":"Evision.Constant.cv_EULER_ANGLES_MAX_VALUE/0","doc":"","ref":"Evision.Constant.html#cv_EULER_ANGLES_MAX_VALUE/0"},{"type":"function","title":"Evision.Constant.cv_EVENT_FLAG_ALTKEY/0","doc":"","ref":"Evision.Constant.html#cv_EVENT_FLAG_ALTKEY/0"},{"type":"function","title":"Evision.Constant.cv_EVENT_FLAG_CTRLKEY/0","doc":"","ref":"Evision.Constant.html#cv_EVENT_FLAG_CTRLKEY/0"},{"type":"function","title":"Evision.Constant.cv_EVENT_FLAG_LBUTTON/0","doc":"","ref":"Evision.Constant.html#cv_EVENT_FLAG_LBUTTON/0"},{"type":"function","title":"Evision.Constant.cv_EVENT_FLAG_MBUTTON/0","doc":"","ref":"Evision.Constant.html#cv_EVENT_FLAG_MBUTTON/0"},{"type":"function","title":"Evision.Constant.cv_EVENT_FLAG_RBUTTON/0","doc":"","ref":"Evision.Constant.html#cv_EVENT_FLAG_RBUTTON/0"},{"type":"function","title":"Evision.Constant.cv_EVENT_FLAG_SHIFTKEY/0","doc":"","ref":"Evision.Constant.html#cv_EVENT_FLAG_SHIFTKEY/0"},{"type":"function","title":"Evision.Constant.cv_EVENT_LBUTTONDBLCLK/0","doc":"","ref":"Evision.Constant.html#cv_EVENT_LBUTTONDBLCLK/0"},{"type":"function","title":"Evision.Constant.cv_EVENT_LBUTTONDOWN/0","doc":"","ref":"Evision.Constant.html#cv_EVENT_LBUTTONDOWN/0"},{"type":"function","title":"Evision.Constant.cv_EVENT_LBUTTONUP/0","doc":"","ref":"Evision.Constant.html#cv_EVENT_LBUTTONUP/0"},{"type":"function","title":"Evision.Constant.cv_EVENT_MBUTTONDBLCLK/0","doc":"","ref":"Evision.Constant.html#cv_EVENT_MBUTTONDBLCLK/0"},{"type":"function","title":"Evision.Constant.cv_EVENT_MBUTTONDOWN/0","doc":"","ref":"Evision.Constant.html#cv_EVENT_MBUTTONDOWN/0"},{"type":"function","title":"Evision.Constant.cv_EVENT_MBUTTONUP/0","doc":"","ref":"Evision.Constant.html#cv_EVENT_MBUTTONUP/0"},{"type":"function","title":"Evision.Constant.cv_EVENT_MOUSEHWHEEL/0","doc":"","ref":"Evision.Constant.html#cv_EVENT_MOUSEHWHEEL/0"},{"type":"function","title":"Evision.Constant.cv_EVENT_MOUSEMOVE/0","doc":"","ref":"Evision.Constant.html#cv_EVENT_MOUSEMOVE/0"},{"type":"function","title":"Evision.Constant.cv_EVENT_MOUSEWHEEL/0","doc":"","ref":"Evision.Constant.html#cv_EVENT_MOUSEWHEEL/0"},{"type":"function","title":"Evision.Constant.cv_EVENT_RBUTTONDBLCLK/0","doc":"","ref":"Evision.Constant.html#cv_EVENT_RBUTTONDBLCLK/0"},{"type":"function","title":"Evision.Constant.cv_EVENT_RBUTTONDOWN/0","doc":"","ref":"Evision.Constant.html#cv_EVENT_RBUTTONDOWN/0"},{"type":"function","title":"Evision.Constant.cv_EVENT_RBUTTONUP/0","doc":"","ref":"Evision.Constant.html#cv_EVENT_RBUTTONUP/0"},{"type":"function","title":"Evision.Constant.cv_EXEC_KERNEL/0","doc":"","ref":"Evision.Constant.html#cv_EXEC_KERNEL/0"},{"type":"function","title":"Evision.Constant.cv_EXEC_NATIVE_KERNEL/0","doc":"","ref":"Evision.Constant.html#cv_EXEC_NATIVE_KERNEL/0"},{"type":"function","title":"Evision.Constant.cv_EXPR/0","doc":"","ref":"Evision.Constant.html#cv_EXPR/0"},{"type":"function","title":"Evision.Constant.cv_EXT_XYX/0","doc":"","ref":"Evision.Constant.html#cv_EXT_XYX/0"},{"type":"function","title":"Evision.Constant.cv_EXT_XYZ/0","doc":"","ref":"Evision.Constant.html#cv_EXT_XYZ/0"},{"type":"function","title":"Evision.Constant.cv_EXT_XZX/0","doc":"","ref":"Evision.Constant.html#cv_EXT_XZX/0"},{"type":"function","title":"Evision.Constant.cv_EXT_XZY/0","doc":"","ref":"Evision.Constant.html#cv_EXT_XZY/0"},{"type":"function","title":"Evision.Constant.cv_EXT_YXY/0","doc":"","ref":"Evision.Constant.html#cv_EXT_YXY/0"},{"type":"function","title":"Evision.Constant.cv_EXT_YXZ/0","doc":"","ref":"Evision.Constant.html#cv_EXT_YXZ/0"},{"type":"function","title":"Evision.Constant.cv_EXT_YZX/0","doc":"","ref":"Evision.Constant.html#cv_EXT_YZX/0"},{"type":"function","title":"Evision.Constant.cv_EXT_YZY/0","doc":"","ref":"Evision.Constant.html#cv_EXT_YZY/0"},{"type":"function","title":"Evision.Constant.cv_EXT_ZXY/0","doc":"","ref":"Evision.Constant.html#cv_EXT_ZXY/0"},{"type":"function","title":"Evision.Constant.cv_EXT_ZXZ/0","doc":"","ref":"Evision.Constant.html#cv_EXT_ZXZ/0"},{"type":"function","title":"Evision.Constant.cv_EXT_ZYX/0","doc":"","ref":"Evision.Constant.html#cv_EXT_ZYX/0"},{"type":"function","title":"Evision.Constant.cv_EXT_ZYZ/0","doc":"","ref":"Evision.Constant.html#cv_EXT_ZYZ/0"},{"type":"function","title":"Evision.Constant.cv_FAPS/0","doc":"","ref":"Evision.Constant.html#cv_FAPS/0"},{"type":"function","title":"Evision.Constant.cv_FAST_N/0","doc":"","ref":"Evision.Constant.html#cv_FAST_N/0"},{"type":"function","title":"Evision.Constant.cv_FAST_SCORE/0","doc":"","ref":"Evision.Constant.html#cv_FAST_SCORE/0"},{"type":"function","title":"Evision.Constant.cv_FEATHER/0","doc":"","ref":"Evision.Constant.html#cv_FEATHER/0"},{"type":"function","title":"Evision.Constant.cv_FEATURE_SET_COMPUTE_10/0","doc":"","ref":"Evision.Constant.html#cv_FEATURE_SET_COMPUTE_10/0"},{"type":"function","title":"Evision.Constant.cv_FEATURE_SET_COMPUTE_11/0","doc":"","ref":"Evision.Constant.html#cv_FEATURE_SET_COMPUTE_11/0"},{"type":"function","title":"Evision.Constant.cv_FEATURE_SET_COMPUTE_12/0","doc":"","ref":"Evision.Constant.html#cv_FEATURE_SET_COMPUTE_12/0"},{"type":"function","title":"Evision.Constant.cv_FEATURE_SET_COMPUTE_13/0","doc":"","ref":"Evision.Constant.html#cv_FEATURE_SET_COMPUTE_13/0"},{"type":"function","title":"Evision.Constant.cv_FEATURE_SET_COMPUTE_20/0","doc":"","ref":"Evision.Constant.html#cv_FEATURE_SET_COMPUTE_20/0"},{"type":"function","title":"Evision.Constant.cv_FEATURE_SET_COMPUTE_21/0","doc":"","ref":"Evision.Constant.html#cv_FEATURE_SET_COMPUTE_21/0"},{"type":"function","title":"Evision.Constant.cv_FEATURE_SET_COMPUTE_30/0","doc":"","ref":"Evision.Constant.html#cv_FEATURE_SET_COMPUTE_30/0"},{"type":"function","title":"Evision.Constant.cv_FEATURE_SET_COMPUTE_32/0","doc":"","ref":"Evision.Constant.html#cv_FEATURE_SET_COMPUTE_32/0"},{"type":"function","title":"Evision.Constant.cv_FEATURE_SET_COMPUTE_35/0","doc":"","ref":"Evision.Constant.html#cv_FEATURE_SET_COMPUTE_35/0"},{"type":"function","title":"Evision.Constant.cv_FEATURE_SET_COMPUTE_50/0","doc":"","ref":"Evision.Constant.html#cv_FEATURE_SET_COMPUTE_50/0"},{"type":"function","title":"Evision.Constant.cv_FHT_ADD/0","doc":"","ref":"Evision.Constant.html#cv_FHT_ADD/0"},{"type":"function","title":"Evision.Constant.cv_FHT_AVE/0","doc":"","ref":"Evision.Constant.html#cv_FHT_AVE/0"},{"type":"function","title":"Evision.Constant.cv_FHT_MAX/0","doc":"","ref":"Evision.Constant.html#cv_FHT_MAX/0"},{"type":"function","title":"Evision.Constant.cv_FHT_MIN/0","doc":"","ref":"Evision.Constant.html#cv_FHT_MIN/0"},{"type":"function","title":"Evision.Constant.cv_FILLED/0","doc":"","ref":"Evision.Constant.html#cv_FILLED/0"},{"type":"function","title":"Evision.Constant.cv_FILTER_SCHARR/0","doc":"","ref":"Evision.Constant.html#cv_FILTER_SCHARR/0"},{"type":"function","title":"Evision.Constant.cv_FIRST_ORDER_MOMENTS/0","doc":"","ref":"Evision.Constant.html#cv_FIRST_ORDER_MOMENTS/0"},{"type":"function","title":"Evision.Constant.cv_FIXED_SIZE/0","doc":"","ref":"Evision.Constant.html#cv_FIXED_SIZE/0"},{"type":"function","title":"Evision.Constant.cv_FIXED_TYPE/0","doc":"","ref":"Evision.Constant.html#cv_FIXED_TYPE/0"},{"type":"function","title":"Evision.Constant.cv_FileNode_FLOAT/0","doc":"","ref":"Evision.Constant.html#cv_FileNode_FLOAT/0"},{"type":"function","title":"Evision.Constant.cv_FileNode_INT/0","doc":"","ref":"Evision.Constant.html#cv_FileNode_INT/0"},{"type":"function","title":"Evision.Constant.cv_FileNode_NONE/0","doc":"","ref":"Evision.Constant.html#cv_FileNode_NONE/0"},{"type":"function","title":"Evision.Constant.cv_FileNode_STRING/0","doc":"","ref":"Evision.Constant.html#cv_FileNode_STRING/0"},{"type":"function","title":"Evision.Constant.cv_FileNode_TYPE_MASK/0","doc":"","ref":"Evision.Constant.html#cv_FileNode_TYPE_MASK/0"},{"type":"function","title":"Evision.Constant.cv_FileNode_UNIFORM/0","doc":"","ref":"Evision.Constant.html#cv_FileNode_UNIFORM/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_CENTERS_GONZALES/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_CENTERS_GONZALES/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_CENTERS_GROUPWISE/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_CENTERS_GROUPWISE/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_CENTERS_KMEANSPP/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_CENTERS_KMEANSPP/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_CENTERS_RANDOM/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_CENTERS_RANDOM/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_CHECKS_AUTOTUNED/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_CHECKS_AUTOTUNED/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_CHECKS_UNLIMITED/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_CHECKS_UNLIMITED/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_DIST_CHI_SQUARE/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_DIST_CHI_SQUARE/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_DIST_CS/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_DIST_CS/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_DIST_DNAMMING/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_DIST_DNAMMING/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_DIST_EUCLIDEAN/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_DIST_EUCLIDEAN/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_DIST_HAMMING/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_DIST_HAMMING/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_DIST_HELLINGER/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_DIST_HELLINGER/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_DIST_HIST_INTERSECT/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_DIST_HIST_INTERSECT/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_DIST_KL/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_DIST_KL/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_DIST_KULLBACK_LEIBLER/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_DIST_KULLBACK_LEIBLER/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_DIST_L1/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_DIST_L1/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_DIST_L2/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_DIST_L2/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_DIST_MANHATTAN/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_DIST_MANHATTAN/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_DIST_MAX/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_DIST_MAX/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_DIST_MINKOWSKI/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_DIST_MINKOWSKI/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_FLOAT32/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_FLOAT32/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_FLOAT64/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_FLOAT64/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_INDEX_AUTOTUNED/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_INDEX_AUTOTUNED/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_INDEX_COMPOSITE/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_INDEX_COMPOSITE/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_INDEX_HIERARCHICAL/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_INDEX_HIERARCHICAL/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_INDEX_KDTREE/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_INDEX_KDTREE/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_INDEX_KDTREE_SINGLE/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_INDEX_KDTREE_SINGLE/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_INDEX_KMEANS/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_INDEX_KMEANS/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_INDEX_LINEAR/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_INDEX_LINEAR/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_INDEX_LSH/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_INDEX_LSH/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_INDEX_SAVED/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_INDEX_SAVED/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_INDEX_TYPE_8S/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_INDEX_TYPE_8S/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_INDEX_TYPE_8U/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_INDEX_TYPE_8U/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_INDEX_TYPE_16S/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_INDEX_TYPE_16S/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_INDEX_TYPE_16U/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_INDEX_TYPE_16U/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_INDEX_TYPE_32F/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_INDEX_TYPE_32F/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_INDEX_TYPE_32S/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_INDEX_TYPE_32S/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_INDEX_TYPE_64F/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_INDEX_TYPE_64F/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_INDEX_TYPE_ALGORITHM/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_INDEX_TYPE_ALGORITHM/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_INDEX_TYPE_BOOL/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_INDEX_TYPE_BOOL/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_INDEX_TYPE_STRING/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_INDEX_TYPE_STRING/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_INT8/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_INT8/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_INT16/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_INT16/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_INT32/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_INT32/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_INT64/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_INT64/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_LOG_ERROR/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_LOG_ERROR/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_LOG_FATAL/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_LOG_FATAL/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_LOG_INFO/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_LOG_INFO/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_LOG_NONE/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_LOG_NONE/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_LOG_WARN/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_LOG_WARN/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_UINT8/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_UINT8/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_UINT16/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_UINT16/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_UINT32/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_UINT32/0"},{"type":"function","title":"Evision.Constant.cv_FLANN_UINT64/0","doc":"","ref":"Evision.Constant.html#cv_FLANN_UINT64/0"},{"type":"function","title":"Evision.Constant.cv_FLANNBASED/0","doc":"","ref":"Evision.Constant.html#cv_FLANNBASED/0"},{"type":"function","title":"Evision.Constant.cv_FLOAT/0","doc":"","ref":"Evision.Constant.html#cv_FLOAT/0"},{"type":"function","title":"Evision.Constant.cv_FLOODFILL_FIXED_RANGE/0","doc":"","ref":"Evision.Constant.html#cv_FLOODFILL_FIXED_RANGE/0"},{"type":"function","title":"Evision.Constant.cv_FLOODFILL_MASK_ONLY/0","doc":"","ref":"Evision.Constant.html#cv_FLOODFILL_MASK_ONLY/0"},{"type":"function","title":"Evision.Constant.cv_FLOW/0","doc":"","ref":"Evision.Constant.html#cv_FLOW/0"},{"type":"function","title":"Evision.Constant.cv_FM_7POINT/0","doc":"","ref":"Evision.Constant.html#cv_FM_7POINT/0"},{"type":"function","title":"Evision.Constant.cv_FM_8POINT/0","doc":"","ref":"Evision.Constant.html#cv_FM_8POINT/0"},{"type":"function","title":"Evision.Constant.cv_FM_LMEDS/0","doc":"","ref":"Evision.Constant.html#cv_FM_LMEDS/0"},{"type":"function","title":"Evision.Constant.cv_FM_RANSAC/0","doc":"","ref":"Evision.Constant.html#cv_FM_RANSAC/0"},{"type":"function","title":"Evision.Constant.cv_FMT_C/0","doc":"","ref":"Evision.Constant.html#cv_FMT_C/0"},{"type":"function","title":"Evision.Constant.cv_FMT_CSV/0","doc":"","ref":"Evision.Constant.html#cv_FMT_CSV/0"},{"type":"function","title":"Evision.Constant.cv_FMT_DEFAULT/0","doc":"","ref":"Evision.Constant.html#cv_FMT_DEFAULT/0"},{"type":"function","title":"Evision.Constant.cv_FMT_MATLAB/0","doc":"","ref":"Evision.Constant.html#cv_FMT_MATLAB/0"},{"type":"function","title":"Evision.Constant.cv_FMT_NUMPY/0","doc":"","ref":"Evision.Constant.html#cv_FMT_NUMPY/0"},{"type":"function","title":"Evision.Constant.cv_FMT_PYTHON/0","doc":"","ref":"Evision.Constant.html#cv_FMT_PYTHON/0"},{"type":"function","title":"Evision.Constant.cv_FONT_HERSHEY_COMPLEX/0","doc":"","ref":"Evision.Constant.html#cv_FONT_HERSHEY_COMPLEX/0"},{"type":"function","title":"Evision.Constant.cv_FONT_HERSHEY_COMPLEX_SMALL/0","doc":"","ref":"Evision.Constant.html#cv_FONT_HERSHEY_COMPLEX_SMALL/0"},{"type":"function","title":"Evision.Constant.cv_FONT_HERSHEY_DUPLEX/0","doc":"","ref":"Evision.Constant.html#cv_FONT_HERSHEY_DUPLEX/0"},{"type":"function","title":"Evision.Constant.cv_FONT_HERSHEY_PLAIN/0","doc":"","ref":"Evision.Constant.html#cv_FONT_HERSHEY_PLAIN/0"},{"type":"function","title":"Evision.Constant.cv_FONT_HERSHEY_SCRIPT_COMPLEX/0","doc":"","ref":"Evision.Constant.html#cv_FONT_HERSHEY_SCRIPT_COMPLEX/0"},{"type":"function","title":"Evision.Constant.cv_FONT_HERSHEY_SCRIPT_SIMPLEX/0","doc":"","ref":"Evision.Constant.html#cv_FONT_HERSHEY_SCRIPT_SIMPLEX/0"},{"type":"function","title":"Evision.Constant.cv_FONT_HERSHEY_SIMPLEX/0","doc":"","ref":"Evision.Constant.html#cv_FONT_HERSHEY_SIMPLEX/0"},{"type":"function","title":"Evision.Constant.cv_FONT_HERSHEY_TRIPLEX/0","doc":"","ref":"Evision.Constant.html#cv_FONT_HERSHEY_TRIPLEX/0"},{"type":"function","title":"Evision.Constant.cv_FONT_ITALIC/0","doc":"","ref":"Evision.Constant.html#cv_FONT_ITALIC/0"},{"type":"function","title":"Evision.Constant.cv_FORMAT_AUTO/0","doc":"","ref":"Evision.Constant.html#cv_FORMAT_AUTO/0"},{"type":"function","title":"Evision.Constant.cv_FORMAT_JSON/0","doc":"","ref":"Evision.Constant.html#cv_FORMAT_JSON/0"},{"type":"function","title":"Evision.Constant.cv_FORMAT_MASK/0","doc":"","ref":"Evision.Constant.html#cv_FORMAT_MASK/0"},{"type":"function","title":"Evision.Constant.cv_FORMAT_XML/0","doc":"","ref":"Evision.Constant.html#cv_FORMAT_XML/0"},{"type":"function","title":"Evision.Constant.cv_FORMAT_YAML/0","doc":"","ref":"Evision.Constant.html#cv_FORMAT_YAML/0"},{"type":"function","title":"Evision.Constant.cv_FP_CORRECTLY_ROUNDED_DIVIDE_SQRT/0","doc":"","ref":"Evision.Constant.html#cv_FP_CORRECTLY_ROUNDED_DIVIDE_SQRT/0"},{"type":"function","title":"Evision.Constant.cv_FP_DENORM/0","doc":"","ref":"Evision.Constant.html#cv_FP_DENORM/0"},{"type":"function","title":"Evision.Constant.cv_FP_FMA/0","doc":"","ref":"Evision.Constant.html#cv_FP_FMA/0"},{"type":"function","title":"Evision.Constant.cv_FP_INF_NAN/0","doc":"","ref":"Evision.Constant.html#cv_FP_INF_NAN/0"},{"type":"function","title":"Evision.Constant.cv_FP_ROUND_TO_INF/0","doc":"","ref":"Evision.Constant.html#cv_FP_ROUND_TO_INF/0"},{"type":"function","title":"Evision.Constant.cv_FP_ROUND_TO_NEAREST/0","doc":"","ref":"Evision.Constant.html#cv_FP_ROUND_TO_NEAREST/0"},{"type":"function","title":"Evision.Constant.cv_FP_ROUND_TO_ZERO/0","doc":"","ref":"Evision.Constant.html#cv_FP_ROUND_TO_ZERO/0"},{"type":"function","title":"Evision.Constant.cv_FP_SOFT_FLOAT/0","doc":"","ref":"Evision.Constant.html#cv_FP_SOFT_FLOAT/0"},{"type":"function","title":"Evision.Constant.cv_FR_COSINE/0","doc":"","ref":"Evision.Constant.html#cv_FR_COSINE/0"},{"type":"function","title":"Evision.Constant.cv_FR_NORM_L2/0","doc":"","ref":"Evision.Constant.html#cv_FR_NORM_L2/0"},{"type":"function","title":"Evision.Constant.cv_FTP/0","doc":"","ref":"Evision.Constant.html#cv_FTP/0"},{"type":"function","title":"Evision.Constant.cv_FULL_UV/0","doc":"","ref":"Evision.Constant.html#cv_FULL_UV/0"},{"type":"function","title":"Evision.Constant.cv_fisheye_CALIB_FIX_FOCAL_LENGTH/0","doc":"","ref":"Evision.Constant.html#cv_fisheye_CALIB_FIX_FOCAL_LENGTH/0"},{"type":"function","title":"Evision.Constant.cv_fisheye_CALIB_FIX_INTRINSIC/0","doc":"","ref":"Evision.Constant.html#cv_fisheye_CALIB_FIX_INTRINSIC/0"},{"type":"function","title":"Evision.Constant.cv_fisheye_CALIB_FIX_K1/0","doc":"","ref":"Evision.Constant.html#cv_fisheye_CALIB_FIX_K1/0"},{"type":"function","title":"Evision.Constant.cv_fisheye_CALIB_FIX_K2/0","doc":"","ref":"Evision.Constant.html#cv_fisheye_CALIB_FIX_K2/0"},{"type":"function","title":"Evision.Constant.cv_fisheye_CALIB_FIX_K3/0","doc":"","ref":"Evision.Constant.html#cv_fisheye_CALIB_FIX_K3/0"},{"type":"function","title":"Evision.Constant.cv_fisheye_CALIB_FIX_K4/0","doc":"","ref":"Evision.Constant.html#cv_fisheye_CALIB_FIX_K4/0"},{"type":"function","title":"Evision.Constant.cv_fisheye_CALIB_FIX_PRINCIPAL_POINT/0","doc":"","ref":"Evision.Constant.html#cv_fisheye_CALIB_FIX_PRINCIPAL_POINT/0"},{"type":"function","title":"Evision.Constant.cv_fisheye_CALIB_USE_INTRINSIC_GUESS/0","doc":"","ref":"Evision.Constant.html#cv_fisheye_CALIB_USE_INTRINSIC_GUESS/0"},{"type":"function","title":"Evision.Constant.cv_fisheye_CALIB_ZERO_DISPARITY/0","doc":"","ref":"Evision.Constant.html#cv_fisheye_CALIB_ZERO_DISPARITY/0"},{"type":"function","title":"Evision.Constant.cv_ft_LINEAR/0","doc":"","ref":"Evision.Constant.html#cv_ft_LINEAR/0"},{"type":"function","title":"Evision.Constant.cv_GAIN/0","doc":"","ref":"Evision.Constant.html#cv_GAIN/0"},{"type":"function","title":"Evision.Constant.cv_GAIN_BLOCKS/0","doc":"","ref":"Evision.Constant.html#cv_GAIN_BLOCKS/0"},{"type":"function","title":"Evision.Constant.cv_GAMMA/0","doc":"","ref":"Evision.Constant.html#cv_GAMMA/0"},{"type":"function","title":"Evision.Constant.cv_GAUSSIAN/0","doc":"","ref":"Evision.Constant.html#cv_GAUSSIAN/0"},{"type":"function","title":"Evision.Constant.cv_GC_BGD/0","doc":"","ref":"Evision.Constant.html#cv_GC_BGD/0"},{"type":"function","title":"Evision.Constant.cv_GC_EVAL/0","doc":"","ref":"Evision.Constant.html#cv_GC_EVAL/0"},{"type":"function","title":"Evision.Constant.cv_GC_EVAL_FREEZE_MODEL/0","doc":"","ref":"Evision.Constant.html#cv_GC_EVAL_FREEZE_MODEL/0"},{"type":"function","title":"Evision.Constant.cv_GC_FGD/0","doc":"","ref":"Evision.Constant.html#cv_GC_FGD/0"},{"type":"function","title":"Evision.Constant.cv_GC_INIT_WITH_MASK/0","doc":"","ref":"Evision.Constant.html#cv_GC_INIT_WITH_MASK/0"},{"type":"function","title":"Evision.Constant.cv_GC_INIT_WITH_RECT/0","doc":"","ref":"Evision.Constant.html#cv_GC_INIT_WITH_RECT/0"},{"type":"function","title":"Evision.Constant.cv_GC_PR_BGD/0","doc":"","ref":"Evision.Constant.html#cv_GC_PR_BGD/0"},{"type":"function","title":"Evision.Constant.cv_GC_PR_FGD/0","doc":"","ref":"Evision.Constant.html#cv_GC_PR_FGD/0"},{"type":"function","title":"Evision.Constant.cv_GEMM_1_T/0","doc":"","ref":"Evision.Constant.html#cv_GEMM_1_T/0"},{"type":"function","title":"Evision.Constant.cv_GEMM_2_T/0","doc":"","ref":"Evision.Constant.html#cv_GEMM_2_T/0"},{"type":"function","title":"Evision.Constant.cv_GEMM_3_T/0","doc":"","ref":"Evision.Constant.html#cv_GEMM_3_T/0"},{"type":"function","title":"Evision.Constant.cv_GENTLE/0","doc":"","ref":"Evision.Constant.html#cv_GENTLE/0"},{"type":"function","title":"Evision.Constant.cv_GLOBAL_ATOMICS/0","doc":"","ref":"Evision.Constant.html#cv_GLOBAL_ATOMICS/0"},{"type":"function","title":"Evision.Constant.cv_GpuApiCallError/0","doc":"","ref":"Evision.Constant.html#cv_GpuApiCallError/0"},{"type":"function","title":"Evision.Constant.cv_GpuNotSupported/0","doc":"","ref":"Evision.Constant.html#cv_GpuNotSupported/0"},{"type":"function","title":"Evision.Constant.cv_GRAY/0","doc":"","ref":"Evision.Constant.html#cv_GRAY/0"},{"type":"function","title":"Evision.Constant.cv_GUIDED_FILTER/0","doc":"","ref":"Evision.Constant.html#cv_GUIDED_FILTER/0"},{"type":"function","title":"Evision.Constant.cv_H264/0","doc":"","ref":"Evision.Constant.html#cv_H264/0"},{"type":"function","title":"Evision.Constant.cv_H264_MVC/0","doc":"","ref":"Evision.Constant.html#cv_H264_MVC/0"},{"type":"function","title":"Evision.Constant.cv_H264_SVC/0","doc":"","ref":"Evision.Constant.html#cv_H264_SVC/0"},{"type":"function","title":"Evision.Constant.cv_HAAR/0","doc":"","ref":"Evision.Constant.html#cv_HAAR/0"},{"type":"function","title":"Evision.Constant.cv_HARD_MARGIN/0","doc":"","ref":"Evision.Constant.html#cv_HARD_MARGIN/0"},{"type":"function","title":"Evision.Constant.cv_HARRIS_SCORE/0","doc":"","ref":"Evision.Constant.html#cv_HARRIS_SCORE/0"},{"type":"function","title":"Evision.Constant.cv_HASH_BIT/0","doc":"","ref":"Evision.Constant.html#cv_HASH_BIT/0"},{"type":"function","title":"Evision.Constant.cv_HASH_SCALE/0","doc":"","ref":"Evision.Constant.html#cv_HASH_SCALE/0"},{"type":"function","title":"Evision.Constant.cv_HASHTSDF/0","doc":"","ref":"Evision.Constant.html#cv_HASHTSDF/0"},{"type":"function","title":"Evision.Constant.cv_HDO_DESKEW/0","doc":"","ref":"Evision.Constant.html#cv_HDO_DESKEW/0"},{"type":"function","title":"Evision.Constant.cv_HDO_RAW/0","doc":"","ref":"Evision.Constant.html#cv_HDO_RAW/0"},{"type":"function","title":"Evision.Constant.cv_HESSIAN_ROW/0","doc":"","ref":"Evision.Constant.html#cv_HESSIAN_ROW/0"},{"type":"function","title":"Evision.Constant.cv_HEURISTIC/0","doc":"","ref":"Evision.Constant.html#cv_HEURISTIC/0"},{"type":"function","title":"Evision.Constant.cv_HEVC/0","doc":"","ref":"Evision.Constant.html#cv_HEVC/0"},{"type":"function","title":"Evision.Constant.cv_HeaderIsNull/0","doc":"","ref":"Evision.Constant.html#cv_HeaderIsNull/0"},{"type":"function","title":"Evision.Constant.cv_HISTCMP_BHATTACHARYYA/0","doc":"","ref":"Evision.Constant.html#cv_HISTCMP_BHATTACHARYYA/0"},{"type":"function","title":"Evision.Constant.cv_HISTCMP_CHISQR/0","doc":"","ref":"Evision.Constant.html#cv_HISTCMP_CHISQR/0"},{"type":"function","title":"Evision.Constant.cv_HISTCMP_CHISQR_ALT/0","doc":"","ref":"Evision.Constant.html#cv_HISTCMP_CHISQR_ALT/0"},{"type":"function","title":"Evision.Constant.cv_HISTCMP_CORREL/0","doc":"","ref":"Evision.Constant.html#cv_HISTCMP_CORREL/0"},{"type":"function","title":"Evision.Constant.cv_HISTCMP_HELLINGER/0","doc":"","ref":"Evision.Constant.html#cv_HISTCMP_HELLINGER/0"},{"type":"function","title":"Evision.Constant.cv_HISTCMP_INTERSECT/0","doc":"","ref":"Evision.Constant.html#cv_HISTCMP_INTERSECT/0"},{"type":"function","title":"Evision.Constant.cv_HISTCMP_KL_DIV/0","doc":"","ref":"Evision.Constant.html#cv_HISTCMP_KL_DIV/0"},{"type":"function","title":"Evision.Constant.cv_HOG/0","doc":"","ref":"Evision.Constant.html#cv_HOG/0"},{"type":"function","title":"Evision.Constant.cv_HOST_COPY_OBSOLETE/0","doc":"","ref":"Evision.Constant.html#cv_HOST_COPY_OBSOLETE/0"},{"type":"function","title":"Evision.Constant.cv_HOUGH_GRADIENT/0","doc":"","ref":"Evision.Constant.html#cv_HOUGH_GRADIENT/0"},{"type":"function","title":"Evision.Constant.cv_HOUGH_GRADIENT_ALT/0","doc":"","ref":"Evision.Constant.html#cv_HOUGH_GRADIENT_ALT/0"},{"type":"function","title":"Evision.Constant.cv_HOUGH_MULTI_SCALE/0","doc":"","ref":"Evision.Constant.html#cv_HOUGH_MULTI_SCALE/0"},{"type":"function","title":"Evision.Constant.cv_HOUGH_PROBABILISTIC/0","doc":"","ref":"Evision.Constant.html#cv_HOUGH_PROBABILISTIC/0"},{"type":"function","title":"Evision.Constant.cv_HOUGH_STANDARD/0","doc":"","ref":"Evision.Constant.html#cv_HOUGH_STANDARD/0"},{"type":"function","title":"Evision.Constant.cv_IDENTITY/0","doc":"","ref":"Evision.Constant.html#cv_IDENTITY/0"},{"type":"function","title":"Evision.Constant.cv_IMREAD_ANYCOLOR/0","doc":"","ref":"Evision.Constant.html#cv_IMREAD_ANYCOLOR/0"},{"type":"function","title":"Evision.Constant.cv_IMREAD_ANYDEPTH/0","doc":"","ref":"Evision.Constant.html#cv_IMREAD_ANYDEPTH/0"},{"type":"function","title":"Evision.Constant.cv_IMREAD_COLOR/0","doc":"","ref":"Evision.Constant.html#cv_IMREAD_COLOR/0"},{"type":"function","title":"Evision.Constant.cv_IMREAD_GRAYSCALE/0","doc":"","ref":"Evision.Constant.html#cv_IMREAD_GRAYSCALE/0"},{"type":"function","title":"Evision.Constant.cv_IMREAD_IGNORE_ORIENTATION/0","doc":"","ref":"Evision.Constant.html#cv_IMREAD_IGNORE_ORIENTATION/0"},{"type":"function","title":"Evision.Constant.cv_IMREAD_LOAD_GDAL/0","doc":"","ref":"Evision.Constant.html#cv_IMREAD_LOAD_GDAL/0"},{"type":"function","title":"Evision.Constant.cv_IMREAD_REDUCED_COLOR_2/0","doc":"","ref":"Evision.Constant.html#cv_IMREAD_REDUCED_COLOR_2/0"},{"type":"function","title":"Evision.Constant.cv_IMREAD_REDUCED_COLOR_4/0","doc":"","ref":"Evision.Constant.html#cv_IMREAD_REDUCED_COLOR_4/0"},{"type":"function","title":"Evision.Constant.cv_IMREAD_REDUCED_COLOR_8/0","doc":"","ref":"Evision.Constant.html#cv_IMREAD_REDUCED_COLOR_8/0"},{"type":"function","title":"Evision.Constant.cv_IMREAD_REDUCED_GRAYSCALE_2/0","doc":"","ref":"Evision.Constant.html#cv_IMREAD_REDUCED_GRAYSCALE_2/0"},{"type":"function","title":"Evision.Constant.cv_IMREAD_REDUCED_GRAYSCALE_4/0","doc":"","ref":"Evision.Constant.html#cv_IMREAD_REDUCED_GRAYSCALE_4/0"},{"type":"function","title":"Evision.Constant.cv_IMREAD_REDUCED_GRAYSCALE_8/0","doc":"","ref":"Evision.Constant.html#cv_IMREAD_REDUCED_GRAYSCALE_8/0"},{"type":"function","title":"Evision.Constant.cv_IMREAD_UNCHANGED/0","doc":"","ref":"Evision.Constant.html#cv_IMREAD_UNCHANGED/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_AVIF_DEPTH/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_AVIF_DEPTH/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_AVIF_QUALITY/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_AVIF_QUALITY/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_AVIF_SPEED/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_AVIF_SPEED/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_EXR_COMPRESSION/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_EXR_COMPRESSION/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_EXR_COMPRESSION_B44/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_EXR_COMPRESSION_B44/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_EXR_COMPRESSION_B44A/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_EXR_COMPRESSION_B44A/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_EXR_COMPRESSION_DWAA/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_EXR_COMPRESSION_DWAA/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_EXR_COMPRESSION_DWAB/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_EXR_COMPRESSION_DWAB/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_EXR_COMPRESSION_NO/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_EXR_COMPRESSION_NO/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_EXR_COMPRESSION_PIZ/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_EXR_COMPRESSION_PIZ/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_EXR_COMPRESSION_PXR24/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_EXR_COMPRESSION_PXR24/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_EXR_COMPRESSION_RLE/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_EXR_COMPRESSION_RLE/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_EXR_COMPRESSION_ZIP/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_EXR_COMPRESSION_ZIP/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_EXR_COMPRESSION_ZIPS/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_EXR_COMPRESSION_ZIPS/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_EXR_DWA_COMPRESSION_LEVEL/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_EXR_DWA_COMPRESSION_LEVEL/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_EXR_TYPE/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_EXR_TYPE/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_EXR_TYPE_FLOAT/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_EXR_TYPE_FLOAT/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_EXR_TYPE_HALF/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_EXR_TYPE_HALF/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_HDR_COMPRESSION/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_HDR_COMPRESSION/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_HDR_COMPRESSION_NONE/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_HDR_COMPRESSION_NONE/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_HDR_COMPRESSION_RLE/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_HDR_COMPRESSION_RLE/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_JPEG2000_COMPRESSION_X1000/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_JPEG2000_COMPRESSION_X1000/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_JPEG_CHROMA_QUALITY/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_JPEG_CHROMA_QUALITY/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_JPEG_LUMA_QUALITY/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_JPEG_LUMA_QUALITY/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_JPEG_OPTIMIZE/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_JPEG_OPTIMIZE/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_JPEG_PROGRESSIVE/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_JPEG_PROGRESSIVE/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_JPEG_QUALITY/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_JPEG_QUALITY/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_JPEG_RST_INTERVAL/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_JPEG_RST_INTERVAL/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_JPEG_SAMPLING_FACTOR/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_JPEG_SAMPLING_FACTOR/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_JPEG_SAMPLING_FACTOR_411/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_JPEG_SAMPLING_FACTOR_411/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_JPEG_SAMPLING_FACTOR_420/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_JPEG_SAMPLING_FACTOR_420/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_JPEG_SAMPLING_FACTOR_422/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_JPEG_SAMPLING_FACTOR_422/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_JPEG_SAMPLING_FACTOR_440/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_JPEG_SAMPLING_FACTOR_440/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_JPEG_SAMPLING_FACTOR_444/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_JPEG_SAMPLING_FACTOR_444/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_PAM_FORMAT_BLACKANDWHITE/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_PAM_FORMAT_BLACKANDWHITE/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_PAM_FORMAT_GRAYSCALE/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_PAM_FORMAT_GRAYSCALE/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_PAM_FORMAT_GRAYSCALE_ALPHA/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_PAM_FORMAT_GRAYSCALE_ALPHA/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_PAM_FORMAT_NULL/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_PAM_FORMAT_NULL/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_PAM_FORMAT_RGB/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_PAM_FORMAT_RGB/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_PAM_FORMAT_RGB_ALPHA/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_PAM_FORMAT_RGB_ALPHA/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_PAM_TUPLETYPE/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_PAM_TUPLETYPE/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_PNG_BILEVEL/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_PNG_BILEVEL/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_PNG_COMPRESSION/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_PNG_COMPRESSION/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_PNG_STRATEGY/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_PNG_STRATEGY/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_PNG_STRATEGY_DEFAULT/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_PNG_STRATEGY_DEFAULT/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_PNG_STRATEGY_FILTERED/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_PNG_STRATEGY_FILTERED/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_PNG_STRATEGY_FIXED/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_PNG_STRATEGY_FIXED/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_PNG_STRATEGY_HUFFMAN_ONLY/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_PNG_STRATEGY_HUFFMAN_ONLY/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_PNG_STRATEGY_RLE/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_PNG_STRATEGY_RLE/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_PXM_BINARY/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_PXM_BINARY/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_ADOBE_DEFLATE/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_ADOBE_DEFLATE/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_CCITT_T4/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_CCITT_T4/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_CCITT_T6/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_CCITT_T6/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_CCITTFAX3/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_CCITTFAX3/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_CCITTFAX4/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_CCITTFAX4/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_CCITTRLE/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_CCITTRLE/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_CCITTRLEW/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_CCITTRLEW/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_DCS/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_DCS/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_DEFLATE/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_DEFLATE/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_IT8BL/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_IT8BL/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_IT8CTPAD/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_IT8CTPAD/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_IT8LW/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_IT8LW/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_IT8MP/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_IT8MP/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_JBIG/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_JBIG/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_JP2000/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_JP2000/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_JPEG/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_JPEG/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_JXL/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_JXL/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_LERC/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_LERC/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_LZMA/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_LZMA/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_LZW/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_LZW/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_NEXT/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_NEXT/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_NONE/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_NONE/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_OJPEG/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_OJPEG/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_PACKBITS/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_PACKBITS/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_PIXARFILM/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_PIXARFILM/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_PIXARLOG/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_PIXARLOG/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_SGILOG24/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_SGILOG24/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_SGILOG/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_SGILOG/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_T43/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_T43/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_T85/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_T85/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_THUNDERSCAN/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_THUNDERSCAN/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_WEBP/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_WEBP/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_COMPRESSION_ZSTD/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_COMPRESSION_ZSTD/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_PREDICTOR/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_PREDICTOR/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_PREDICTOR_FLOATINGPOINT/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_PREDICTOR_FLOATINGPOINT/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_PREDICTOR_HORIZONTAL/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_PREDICTOR_HORIZONTAL/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_PREDICTOR_NONE/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_PREDICTOR_NONE/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_RESUNIT/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_RESUNIT/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_ROWSPERSTRIP/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_ROWSPERSTRIP/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_XDPI/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_XDPI/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_TIFF_YDPI/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_TIFF_YDPI/0"},{"type":"function","title":"Evision.Constant.cv_IMWRITE_WEBP_QUALITY/0","doc":"","ref":"Evision.Constant.html#cv_IMWRITE_WEBP_QUALITY/0"},{"type":"function","title":"Evision.Constant.cv_INITIAL_METHOD_LEAST_SQUARE/0","doc":"","ref":"Evision.Constant.html#cv_INITIAL_METHOD_LEAST_SQUARE/0"},{"type":"function","title":"Evision.Constant.cv_INITIAL_METHOD_WHITE_BALANCE/0","doc":"","ref":"Evision.Constant.html#cv_INITIAL_METHOD_WHITE_BALANCE/0"},{"type":"function","title":"Evision.Constant.cv_INPAINT_FSR_BEST/0","doc":"","ref":"Evision.Constant.html#cv_INPAINT_FSR_BEST/0"},{"type":"function","title":"Evision.Constant.cv_INPAINT_FSR_FAST/0","doc":"","ref":"Evision.Constant.html#cv_INPAINT_FSR_FAST/0"},{"type":"function","title":"Evision.Constant.cv_INPAINT_NS/0","doc":"","ref":"Evision.Constant.html#cv_INPAINT_NS/0"},{"type":"function","title":"Evision.Constant.cv_INPAINT_SHIFTMAP/0","doc":"","ref":"Evision.Constant.html#cv_INPAINT_SHIFTMAP/0"},{"type":"function","title":"Evision.Constant.cv_INPAINT_TELEA/0","doc":"","ref":"Evision.Constant.html#cv_INPAINT_TELEA/0"},{"type":"function","title":"Evision.Constant.cv_INSIDE_MAP/0","doc":"","ref":"Evision.Constant.html#cv_INSIDE_MAP/0"},{"type":"function","title":"Evision.Constant.cv_INT/0","doc":"","ref":"Evision.Constant.html#cv_INT/0"},{"type":"function","title":"Evision.Constant.cv_INT_XYX/0","doc":"","ref":"Evision.Constant.html#cv_INT_XYX/0"},{"type":"function","title":"Evision.Constant.cv_INT_XYZ/0","doc":"","ref":"Evision.Constant.html#cv_INT_XYZ/0"},{"type":"function","title":"Evision.Constant.cv_INT_XZX/0","doc":"","ref":"Evision.Constant.html#cv_INT_XZX/0"},{"type":"function","title":"Evision.Constant.cv_INT_XZY/0","doc":"","ref":"Evision.Constant.html#cv_INT_XZY/0"},{"type":"function","title":"Evision.Constant.cv_INT_YXY/0","doc":"","ref":"Evision.Constant.html#cv_INT_YXY/0"},{"type":"function","title":"Evision.Constant.cv_INT_YXZ/0","doc":"","ref":"Evision.Constant.html#cv_INT_YXZ/0"},{"type":"function","title":"Evision.Constant.cv_INT_YZX/0","doc":"","ref":"Evision.Constant.html#cv_INT_YZX/0"},{"type":"function","title":"Evision.Constant.cv_INT_YZY/0","doc":"","ref":"Evision.Constant.html#cv_INT_YZY/0"},{"type":"function","title":"Evision.Constant.cv_INT_ZXY/0","doc":"","ref":"Evision.Constant.html#cv_INT_ZXY/0"},{"type":"function","title":"Evision.Constant.cv_INT_ZXZ/0","doc":"","ref":"Evision.Constant.html#cv_INT_ZXZ/0"},{"type":"function","title":"Evision.Constant.cv_INT_ZYX/0","doc":"","ref":"Evision.Constant.html#cv_INT_ZYX/0"},{"type":"function","title":"Evision.Constant.cv_INT_ZYZ/0","doc":"","ref":"Evision.Constant.html#cv_INT_ZYZ/0"},{"type":"function","title":"Evision.Constant.cv_INTER/0","doc":"","ref":"Evision.Constant.html#cv_INTER/0"},{"type":"function","title":"Evision.Constant.cv_INTER_AREA/0","doc":"","ref":"Evision.Constant.html#cv_INTER_AREA/0"},{"type":"function","title":"Evision.Constant.cv_INTER_BITS2/0","doc":"","ref":"Evision.Constant.html#cv_INTER_BITS2/0"},{"type":"function","title":"Evision.Constant.cv_INTER_BITS/0","doc":"","ref":"Evision.Constant.html#cv_INTER_BITS/0"},{"type":"function","title":"Evision.Constant.cv_INTER_CUBIC/0","doc":"","ref":"Evision.Constant.html#cv_INTER_CUBIC/0"},{"type":"function","title":"Evision.Constant.cv_INTER_LANCZOS4/0","doc":"","ref":"Evision.Constant.html#cv_INTER_LANCZOS4/0"},{"type":"function","title":"Evision.Constant.cv_INTER_LINEAR/0","doc":"","ref":"Evision.Constant.html#cv_INTER_LINEAR/0"},{"type":"function","title":"Evision.Constant.cv_INTER_LINEAR_EXACT/0","doc":"","ref":"Evision.Constant.html#cv_INTER_LINEAR_EXACT/0"},{"type":"function","title":"Evision.Constant.cv_INTER_MAX/0","doc":"","ref":"Evision.Constant.html#cv_INTER_MAX/0"},{"type":"function","title":"Evision.Constant.cv_INTER_NEAREST/0","doc":"","ref":"Evision.Constant.html#cv_INTER_NEAREST/0"},{"type":"function","title":"Evision.Constant.cv_INTER_NEAREST_EXACT/0","doc":"","ref":"Evision.Constant.html#cv_INTER_NEAREST_EXACT/0"},{"type":"function","title":"Evision.Constant.cv_INTER_TAB_SIZE2/0","doc":"","ref":"Evision.Constant.html#cv_INTER_TAB_SIZE2/0"},{"type":"function","title":"Evision.Constant.cv_INTER_TAB_SIZE/0","doc":"","ref":"Evision.Constant.html#cv_INTER_TAB_SIZE/0"},{"type":"function","title":"Evision.Constant.cv_INTERPROCESS/0","doc":"","ref":"Evision.Constant.html#cv_INTERPROCESS/0"},{"type":"function","title":"Evision.Constant.cv_INTERSECT_FULL/0","doc":"","ref":"Evision.Constant.html#cv_INTERSECT_FULL/0"},{"type":"function","title":"Evision.Constant.cv_INTERSECT_NONE/0","doc":"","ref":"Evision.Constant.html#cv_INTERSECT_NONE/0"},{"type":"function","title":"Evision.Constant.cv_INTERSECT_PARTIAL/0","doc":"","ref":"Evision.Constant.html#cv_INTERSECT_PARTIAL/0"},{"type":"function","title":"Evision.Constant.cv_InputArray_MAT/0","doc":"","ref":"Evision.Constant.html#cv_InputArray_MAT/0"},{"type":"function","title":"Evision.Constant.cv_ITERATIVE/0","doc":"","ref":"Evision.Constant.html#cv_ITERATIVE/0"},{"type":"function","title":"Evision.Constant.cv_JPEG/0","doc":"","ref":"Evision.Constant.html#cv_JPEG/0"},{"type":"function","title":"Evision.Constant.cv_KDTREE/0","doc":"","ref":"Evision.Constant.html#cv_KDTREE/0"},{"type":"function","title":"Evision.Constant.cv_KIND_MASK/0","doc":"","ref":"Evision.Constant.html#cv_KIND_MASK/0"},{"type":"function","title":"Evision.Constant.cv_KIND_SHIFT/0","doc":"","ref":"Evision.Constant.html#cv_KIND_SHIFT/0"},{"type":"function","title":"Evision.Constant.cv_KMEANS_PP_CENTERS/0","doc":"","ref":"Evision.Constant.html#cv_KMEANS_PP_CENTERS/0"},{"type":"function","title":"Evision.Constant.cv_KMEANS_RANDOM_CENTERS/0","doc":"","ref":"Evision.Constant.html#cv_KMEANS_RANDOM_CENTERS/0"},{"type":"function","title":"Evision.Constant.cv_KMEANS_USE_INITIAL_LABELS/0","doc":"","ref":"Evision.Constant.html#cv_KMEANS_USE_INITIAL_LABELS/0"},{"type":"function","title":"Evision.Constant.cv_L0_5/0","doc":"","ref":"Evision.Constant.html#cv_L0_5/0"},{"type":"function","title":"Evision.Constant.cv_L0_25/0","doc":"","ref":"Evision.Constant.html#cv_L0_25/0"},{"type":"function","title":"Evision.Constant.cv_L1/0","doc":"","ref":"Evision.Constant.html#cv_L1/0"},{"type":"function","title":"Evision.Constant.cv_L2/0","doc":"","ref":"Evision.Constant.html#cv_L2/0"},{"type":"function","title":"Evision.Constant.cv_L2Hys/0","doc":"","ref":"Evision.Constant.html#cv_L2Hys/0"},{"type":"function","title":"Evision.Constant.cv_L2SQUARED/0","doc":"","ref":"Evision.Constant.html#cv_L2SQUARED/0"},{"type":"function","title":"Evision.Constant.cv_L5/0","doc":"","ref":"Evision.Constant.html#cv_L5/0"},{"type":"function","title":"Evision.Constant.cv_L_INFINITY/0","doc":"","ref":"Evision.Constant.html#cv_L_INFINITY/0"},{"type":"function","title":"Evision.Constant.cv_LAPLACIAN_ROW/0","doc":"","ref":"Evision.Constant.html#cv_LAPLACIAN_ROW/0"},{"type":"function","title":"Evision.Constant.cv_LAST_VALUE_FLANN_INDEX_TYPE/0","doc":"","ref":"Evision.Constant.html#cv_LAST_VALUE_FLANN_INDEX_TYPE/0"},{"type":"function","title":"Evision.Constant.cv_LBP/0","doc":"","ref":"Evision.Constant.html#cv_LBP/0"},{"type":"function","title":"Evision.Constant.cv_LDR_SIZE/0","doc":"","ref":"Evision.Constant.html#cv_LDR_SIZE/0"},{"type":"function","title":"Evision.Constant.cv_LEAKYRELU/0","doc":"","ref":"Evision.Constant.html#cv_LEAKYRELU/0"},{"type":"function","title":"Evision.Constant.cv_LINE_4/0","doc":"","ref":"Evision.Constant.html#cv_LINE_4/0"},{"type":"function","title":"Evision.Constant.cv_LINE_8/0","doc":"","ref":"Evision.Constant.html#cv_LINE_8/0"},{"type":"function","title":"Evision.Constant.cv_LINE_AA/0","doc":"","ref":"Evision.Constant.html#cv_LINE_AA/0"},{"type":"function","title":"Evision.Constant.cv_LINE_LOOP/0","doc":"","ref":"Evision.Constant.html#cv_LINE_LOOP/0"},{"type":"function","title":"Evision.Constant.cv_LINE_STRIP/0","doc":"","ref":"Evision.Constant.html#cv_LINE_STRIP/0"},{"type":"function","title":"Evision.Constant.cv_LINEAR/0","doc":"","ref":"Evision.Constant.html#cv_LINEAR/0"},{"type":"function","title":"Evision.Constant.cv_LINEARIZATION_COLORLOGPOLYFIT/0","doc":"","ref":"Evision.Constant.html#cv_LINEARIZATION_COLORLOGPOLYFIT/0"},{"type":"function","title":"Evision.Constant.cv_LINEARIZATION_COLORPOLYFIT/0","doc":"","ref":"Evision.Constant.html#cv_LINEARIZATION_COLORPOLYFIT/0"},{"type":"function","title":"Evision.Constant.cv_LINEARIZATION_GAMMA/0","doc":"","ref":"Evision.Constant.html#cv_LINEARIZATION_GAMMA/0"},{"type":"function","title":"Evision.Constant.cv_LINEARIZATION_GRAYLOGPOLYFIT/0","doc":"","ref":"Evision.Constant.html#cv_LINEARIZATION_GRAYLOGPOLYFIT/0"},{"type":"function","title":"Evision.Constant.cv_LINEARIZATION_GRAYPOLYFIT/0","doc":"","ref":"Evision.Constant.html#cv_LINEARIZATION_GRAYPOLYFIT/0"},{"type":"function","title":"Evision.Constant.cv_LINEARIZATION_IDENTITY/0","doc":"","ref":"Evision.Constant.html#cv_LINEARIZATION_IDENTITY/0"},{"type":"function","title":"Evision.Constant.cv_LINES/0","doc":"","ref":"Evision.Constant.html#cv_LINES/0"},{"type":"function","title":"Evision.Constant.cv_LMEDS/0","doc":"","ref":"Evision.Constant.html#cv_LMEDS/0"},{"type":"function","title":"Evision.Constant.cv_LOCAL/0","doc":"","ref":"Evision.Constant.html#cv_LOCAL/0"},{"type":"function","title":"Evision.Constant.cv_LOCAL_IS_GLOBAL/0","doc":"","ref":"Evision.Constant.html#cv_LOCAL_IS_GLOBAL/0"},{"type":"function","title":"Evision.Constant.cv_LOCAL_IS_LOCAL/0","doc":"","ref":"Evision.Constant.html#cv_LOCAL_IS_LOCAL/0"},{"type":"function","title":"Evision.Constant.cv_LOCAL_OPTIM_GC/0","doc":"","ref":"Evision.Constant.html#cv_LOCAL_OPTIM_GC/0"},{"type":"function","title":"Evision.Constant.cv_LOCAL_OPTIM_INNER_AND_ITER_LO/0","doc":"","ref":"Evision.Constant.html#cv_LOCAL_OPTIM_INNER_AND_ITER_LO/0"},{"type":"function","title":"Evision.Constant.cv_LOCAL_OPTIM_INNER_LO/0","doc":"","ref":"Evision.Constant.html#cv_LOCAL_OPTIM_INNER_LO/0"},{"type":"function","title":"Evision.Constant.cv_LOCAL_OPTIM_NULL/0","doc":"","ref":"Evision.Constant.html#cv_LOCAL_OPTIM_NULL/0"},{"type":"function","title":"Evision.Constant.cv_LOCAL_OPTIM_SIGMA/0","doc":"","ref":"Evision.Constant.html#cv_LOCAL_OPTIM_SIGMA/0"},{"type":"function","title":"Evision.Constant.cv_LOGIT/0","doc":"","ref":"Evision.Constant.html#cv_LOGIT/0"},{"type":"function","title":"Evision.Constant.cv_LSBP_CAMERA_MOTION_COMPENSATION_LK/0","doc":"","ref":"Evision.Constant.html#cv_LSBP_CAMERA_MOTION_COMPENSATION_LK/0"},{"type":"function","title":"Evision.Constant.cv_LSBP_CAMERA_MOTION_COMPENSATION_NONE/0","doc":"","ref":"Evision.Constant.html#cv_LSBP_CAMERA_MOTION_COMPENSATION_NONE/0"},{"type":"function","title":"Evision.Constant.cv_LSD/0","doc":"","ref":"Evision.Constant.html#cv_LSD/0"},{"type":"function","title":"Evision.Constant.cv_LSD_REFINE_ADV/0","doc":"","ref":"Evision.Constant.html#cv_LSD_REFINE_ADV/0"},{"type":"function","title":"Evision.Constant.cv_LSD_REFINE_NONE/0","doc":"","ref":"Evision.Constant.html#cv_LSD_REFINE_NONE/0"},{"type":"function","title":"Evision.Constant.cv_LSD_REFINE_STD/0","doc":"","ref":"Evision.Constant.html#cv_LSD_REFINE_STD/0"},{"type":"function","title":"Evision.Constant.cv_LSQ_POLISHER/0","doc":"","ref":"Evision.Constant.html#cv_LSQ_POLISHER/0"},{"type":"function","title":"Evision.Constant.cv_MAGIC_MASK/0","doc":"","ref":"Evision.Constant.html#cv_MAGIC_MASK/0"},{"type":"function","title":"Evision.Constant.cv_MAGIC_VAL/0","doc":"","ref":"Evision.Constant.html#cv_MAGIC_VAL/0"},{"type":"function","title":"Evision.Constant.cv_MAGSAC/0","doc":"","ref":"Evision.Constant.html#cv_MAGSAC/0"},{"type":"function","title":"Evision.Constant.cv_MAP/0","doc":"","ref":"Evision.Constant.html#cv_MAP/0"},{"type":"function","title":"Evision.Constant.cv_MARKER_CROSS/0","doc":"","ref":"Evision.Constant.html#cv_MARKER_CROSS/0"},{"type":"function","title":"Evision.Constant.cv_MARKER_DIAMOND/0","doc":"","ref":"Evision.Constant.html#cv_MARKER_DIAMOND/0"},{"type":"function","title":"Evision.Constant.cv_MARKER_SQUARE/0","doc":"","ref":"Evision.Constant.html#cv_MARKER_SQUARE/0"},{"type":"function","title":"Evision.Constant.cv_MARKER_STAR/0","doc":"","ref":"Evision.Constant.html#cv_MARKER_STAR/0"},{"type":"function","title":"Evision.Constant.cv_MARKER_TILTED_CROSS/0","doc":"","ref":"Evision.Constant.html#cv_MARKER_TILTED_CROSS/0"},{"type":"function","title":"Evision.Constant.cv_MARKER_TRIANGLE_DOWN/0","doc":"","ref":"Evision.Constant.html#cv_MARKER_TRIANGLE_DOWN/0"},{"type":"function","title":"Evision.Constant.cv_MARKER_TRIANGLE_UP/0","doc":"","ref":"Evision.Constant.html#cv_MARKER_TRIANGLE_UP/0"},{"type":"function","title":"Evision.Constant.cv_MAT/0","doc":"","ref":"Evision.Constant.html#cv_MAT/0"},{"type":"function","title":"Evision.Constant.cv_MAT_VECTOR/0","doc":"","ref":"Evision.Constant.html#cv_MAT_VECTOR/0"},{"type":"function","title":"Evision.Constant.cv_MATX/0","doc":"","ref":"Evision.Constant.html#cv_MATX/0"},{"type":"function","title":"Evision.Constant.cv_MAX_DIM/0","doc":"","ref":"Evision.Constant.html#cv_MAX_DIM/0"},{"type":"function","title":"Evision.Constant.cv_MAX_ITER/0","doc":"","ref":"Evision.Constant.html#cv_MAX_ITER/0"},{"type":"function","title":"Evision.Constant.cv_MaskIsTiled/0","doc":"","ref":"Evision.Constant.html#cv_MaskIsTiled/0"},{"type":"function","title":"Evision.Constant.cv_MCC24/0","doc":"","ref":"Evision.Constant.html#cv_MCC24/0"},{"type":"function","title":"Evision.Constant.cv_MEMORY/0","doc":"","ref":"Evision.Constant.html#cv_MEMORY/0"},{"type":"function","title":"Evision.Constant.cv_MINI_BATCH/0","doc":"","ref":"Evision.Constant.html#cv_MINI_BATCH/0"},{"type":"function","title":"Evision.Constant.cv_MINUS/0","doc":"","ref":"Evision.Constant.html#cv_MINUS/0"},{"type":"function","title":"Evision.Constant.cv_MIXED_CLONE/0","doc":"","ref":"Evision.Constant.html#cv_MIXED_CLONE/0"},{"type":"function","title":"Evision.Constant.cv_MODE_ALPHANUMERIC/0","doc":"","ref":"Evision.Constant.html#cv_MODE_ALPHANUMERIC/0"},{"type":"function","title":"Evision.Constant.cv_MODE_AUTO/0","doc":"","ref":"Evision.Constant.html#cv_MODE_AUTO/0"},{"type":"function","title":"Evision.Constant.cv_MODE_BYTE/0","doc":"","ref":"Evision.Constant.html#cv_MODE_BYTE/0"},{"type":"function","title":"Evision.Constant.cv_MODE_CLASSIFY/0","doc":"","ref":"Evision.Constant.html#cv_MODE_CLASSIFY/0"},{"type":"function","title":"Evision.Constant.cv_MODE_DETECT/0","doc":"","ref":"Evision.Constant.html#cv_MODE_DETECT/0"},{"type":"function","title":"Evision.Constant.cv_MODE_ECI/0","doc":"","ref":"Evision.Constant.html#cv_MODE_ECI/0"},{"type":"function","title":"Evision.Constant.cv_MODE_HH4/0","doc":"","ref":"Evision.Constant.html#cv_MODE_HH4/0"},{"type":"function","title":"Evision.Constant.cv_MODE_HH/0","doc":"","ref":"Evision.Constant.html#cv_MODE_HH/0"},{"type":"function","title":"Evision.Constant.cv_MODE_INIT_NEG/0","doc":"","ref":"Evision.Constant.html#cv_MODE_INIT_NEG/0"},{"type":"function","title":"Evision.Constant.cv_MODE_INIT_POS/0","doc":"","ref":"Evision.Constant.html#cv_MODE_INIT_POS/0"},{"type":"function","title":"Evision.Constant.cv_MODE_KANJI/0","doc":"","ref":"Evision.Constant.html#cv_MODE_KANJI/0"},{"type":"function","title":"Evision.Constant.cv_MODE_NEGATIVE/0","doc":"","ref":"Evision.Constant.html#cv_MODE_NEGATIVE/0"},{"type":"function","title":"Evision.Constant.cv_MODE_NUMERIC/0","doc":"","ref":"Evision.Constant.html#cv_MODE_NUMERIC/0"},{"type":"function","title":"Evision.Constant.cv_MODE_POSITIVE/0","doc":"","ref":"Evision.Constant.html#cv_MODE_POSITIVE/0"},{"type":"function","title":"Evision.Constant.cv_MODE_SGBM/0","doc":"","ref":"Evision.Constant.html#cv_MODE_SGBM/0"},{"type":"function","title":"Evision.Constant.cv_MODE_SGBM_3WAY/0","doc":"","ref":"Evision.Constant.html#cv_MODE_SGBM_3WAY/0"},{"type":"function","title":"Evision.Constant.cv_MODE_STRUCTURED_APPEND/0","doc":"","ref":"Evision.Constant.html#cv_MODE_STRUCTURED_APPEND/0"},{"type":"function","title":"Evision.Constant.cv_MODE_TRACK_NEG/0","doc":"","ref":"Evision.Constant.html#cv_MODE_TRACK_NEG/0"},{"type":"function","title":"Evision.Constant.cv_MODE_TRACK_POS/0","doc":"","ref":"Evision.Constant.html#cv_MODE_TRACK_POS/0"},{"type":"function","title":"Evision.Constant.cv_MODIFY_A/0","doc":"","ref":"Evision.Constant.html#cv_MODIFY_A/0"},{"type":"function","title":"Evision.Constant.cv_MONOCHROME_TRANSFER/0","doc":"","ref":"Evision.Constant.html#cv_MONOCHROME_TRANSFER/0"},{"type":"function","title":"Evision.Constant.cv_MORPH_BLACKHAT/0","doc":"","ref":"Evision.Constant.html#cv_MORPH_BLACKHAT/0"},{"type":"function","title":"Evision.Constant.cv_MORPH_CLOSE/0","doc":"","ref":"Evision.Constant.html#cv_MORPH_CLOSE/0"},{"type":"function","title":"Evision.Constant.cv_MORPH_CROSS/0","doc":"","ref":"Evision.Constant.html#cv_MORPH_CROSS/0"},{"type":"function","title":"Evision.Constant.cv_MORPH_DILATE/0","doc":"","ref":"Evision.Constant.html#cv_MORPH_DILATE/0"},{"type":"function","title":"Evision.Constant.cv_MORPH_ELLIPSE/0","doc":"","ref":"Evision.Constant.html#cv_MORPH_ELLIPSE/0"},{"type":"function","title":"Evision.Constant.cv_MORPH_ERODE/0","doc":"","ref":"Evision.Constant.html#cv_MORPH_ERODE/0"},{"type":"function","title":"Evision.Constant.cv_MORPH_GRADIENT/0","doc":"","ref":"Evision.Constant.html#cv_MORPH_GRADIENT/0"},{"type":"function","title":"Evision.Constant.cv_MORPH_HITMISS/0","doc":"","ref":"Evision.Constant.html#cv_MORPH_HITMISS/0"},{"type":"function","title":"Evision.Constant.cv_MORPH_OPEN/0","doc":"","ref":"Evision.Constant.html#cv_MORPH_OPEN/0"},{"type":"function","title":"Evision.Constant.cv_MORPH_RECT/0","doc":"","ref":"Evision.Constant.html#cv_MORPH_RECT/0"},{"type":"function","title":"Evision.Constant.cv_MORPH_TOPHAT/0","doc":"","ref":"Evision.Constant.html#cv_MORPH_TOPHAT/0"},{"type":"function","title":"Evision.Constant.cv_MOTION_AFFINE/0","doc":"","ref":"Evision.Constant.html#cv_MOTION_AFFINE/0"},{"type":"function","title":"Evision.Constant.cv_MOTION_EUCLIDEAN/0","doc":"","ref":"Evision.Constant.html#cv_MOTION_EUCLIDEAN/0"},{"type":"function","title":"Evision.Constant.cv_MOTION_HOMOGRAPHY/0","doc":"","ref":"Evision.Constant.html#cv_MOTION_HOMOGRAPHY/0"},{"type":"function","title":"Evision.Constant.cv_MOTION_TRANSLATION/0","doc":"","ref":"Evision.Constant.html#cv_MOTION_TRANSLATION/0"},{"type":"function","title":"Evision.Constant.cv_Monochrome/0","doc":"","ref":"Evision.Constant.html#cv_Monochrome/0"},{"type":"function","title":"Evision.Constant.cv_MPEG1/0","doc":"","ref":"Evision.Constant.html#cv_MPEG1/0"},{"type":"function","title":"Evision.Constant.cv_MPEG2/0","doc":"","ref":"Evision.Constant.html#cv_MPEG2/0"},{"type":"function","title":"Evision.Constant.cv_MPEG4/0","doc":"","ref":"Evision.Constant.html#cv_MPEG4/0"},{"type":"function","title":"Evision.Constant.cv_MSLIC/0","doc":"","ref":"Evision.Constant.html#cv_MSLIC/0"},{"type":"function","title":"Evision.Constant.cv_MULTI_BAND/0","doc":"","ref":"Evision.Constant.html#cv_MULTI_BAND/0"},{"type":"function","title":"Evision.Constant.cv_MULTI_STEP/0","doc":"","ref":"Evision.Constant.html#cv_MULTI_STEP/0"},{"type":"function","title":"Evision.Constant.cv_maketype/2","doc":"","ref":"Evision.Constant.html#cv_maketype/2"},{"type":"function","title":"Evision.Constant.cv_mat_depth_mask/0","doc":"","ref":"Evision.Constant.html#cv_mat_depth_mask/0"},{"type":"function","title":"Evision.Constant.cv_NAME_EXPECTED/0","doc":"","ref":"Evision.Constant.html#cv_NAME_EXPECTED/0"},{"type":"function","title":"Evision.Constant.cv_NAMED/0","doc":"","ref":"Evision.Constant.html#cv_NAMED/0"},{"type":"function","title":"Evision.Constant.cv_NATIVE_DOUBLE/0","doc":"","ref":"Evision.Constant.html#cv_NATIVE_DOUBLE/0"},{"type":"function","title":"Evision.Constant.cv_NEIGH_FLANN_KNN/0","doc":"","ref":"Evision.Constant.html#cv_NEIGH_FLANN_KNN/0"},{"type":"function","title":"Evision.Constant.cv_NEIGH_FLANN_RADIUS/0","doc":"","ref":"Evision.Constant.html#cv_NEIGH_FLANN_RADIUS/0"},{"type":"function","title":"Evision.Constant.cv_NEIGH_GRID/0","doc":"","ref":"Evision.Constant.html#cv_NEIGH_GRID/0"},{"type":"function","title":"Evision.Constant.cv_NEXT_AROUND_DST/0","doc":"","ref":"Evision.Constant.html#cv_NEXT_AROUND_DST/0"},{"type":"function","title":"Evision.Constant.cv_NEXT_AROUND_LEFT/0","doc":"","ref":"Evision.Constant.html#cv_NEXT_AROUND_LEFT/0"},{"type":"function","title":"Evision.Constant.cv_NEXT_AROUND_ORG/0","doc":"","ref":"Evision.Constant.html#cv_NEXT_AROUND_ORG/0"},{"type":"function","title":"Evision.Constant.cv_NEXT_AROUND_RIGHT/0","doc":"","ref":"Evision.Constant.html#cv_NEXT_AROUND_RIGHT/0"},{"type":"function","title":"Evision.Constant.cv_NO/0","doc":"","ref":"Evision.Constant.html#cv_NO/0"},{"type":"function","title":"Evision.Constant.cv_NO_CACHE/0","doc":"","ref":"Evision.Constant.html#cv_NO_CACHE/0"},{"type":"function","title":"Evision.Constant.cv_NO_INPUT_SCALE/0","doc":"","ref":"Evision.Constant.html#cv_NO_INPUT_SCALE/0"},{"type":"function","title":"Evision.Constant.cv_NO_LOCAL_MEM/0","doc":"","ref":"Evision.Constant.html#cv_NO_LOCAL_MEM/0"},{"type":"function","title":"Evision.Constant.cv_NO_OUTPUT_SCALE/0","doc":"","ref":"Evision.Constant.html#cv_NO_OUTPUT_SCALE/0"},{"type":"function","title":"Evision.Constant.cv_NO_SIZE/0","doc":"","ref":"Evision.Constant.html#cv_NO_SIZE/0"},{"type":"function","title":"Evision.Constant.cv_NO_UV/0","doc":"","ref":"Evision.Constant.html#cv_NO_UV/0"},{"type":"function","title":"Evision.Constant.cv_NONE/0","doc":"","ref":"Evision.Constant.html#cv_NONE/0"},{"type":"function","title":"Evision.Constant.cv_NONE_POLISHER/0","doc":"","ref":"Evision.Constant.html#cv_NONE_POLISHER/0"},{"type":"function","title":"Evision.Constant.cv_NONMAX_SUPPRESSION/0","doc":"","ref":"Evision.Constant.html#cv_NONMAX_SUPPRESSION/0"},{"type":"function","title":"Evision.Constant.cv_NORM_HAMMING2/0","doc":"","ref":"Evision.Constant.html#cv_NORM_HAMMING2/0"},{"type":"function","title":"Evision.Constant.cv_NORM_HAMMING/0","doc":"","ref":"Evision.Constant.html#cv_NORM_HAMMING/0"},{"type":"function","title":"Evision.Constant.cv_NORM_INF/0","doc":"","ref":"Evision.Constant.html#cv_NORM_INF/0"},{"type":"function","title":"Evision.Constant.cv_NORM_L1/0","doc":"","ref":"Evision.Constant.html#cv_NORM_L1/0"},{"type":"function","title":"Evision.Constant.cv_NORM_L2/0","doc":"","ref":"Evision.Constant.html#cv_NORM_L2/0"},{"type":"function","title":"Evision.Constant.cv_NORM_L2SQR/0","doc":"","ref":"Evision.Constant.html#cv_NORM_L2SQR/0"},{"type":"function","title":"Evision.Constant.cv_NORM_MINMAX/0","doc":"","ref":"Evision.Constant.html#cv_NORM_MINMAX/0"},{"type":"function","title":"Evision.Constant.cv_NORM_RELATIVE/0","doc":"","ref":"Evision.Constant.html#cv_NORM_RELATIVE/0"},{"type":"function","title":"Evision.Constant.cv_NORM_TYPE_MASK/0","doc":"","ref":"Evision.Constant.html#cv_NORM_TYPE_MASK/0"},{"type":"function","title":"Evision.Constant.cv_NORMAL/0","doc":"","ref":"Evision.Constant.html#cv_NORMAL/0"},{"type":"function","title":"Evision.Constant.cv_NORMAL_CLONE/0","doc":"","ref":"Evision.Constant.html#cv_NORMAL_CLONE/0"},{"type":"function","title":"Evision.Constant.cv_NORMCONV_FILTER/0","doc":"","ref":"Evision.Constant.html#cv_NORMCONV_FILTER/0"},{"type":"function","title":"Evision.Constant.cv_NOT_DRAW_SINGLE_POINTS/0","doc":"","ref":"Evision.Constant.html#cv_NOT_DRAW_SINGLE_POINTS/0"},{"type":"function","title":"Evision.Constant.cv_NRM_FULL/0","doc":"","ref":"Evision.Constant.html#cv_NRM_FULL/0"},{"type":"function","title":"Evision.Constant.cv_NRM_NONE/0","doc":"","ref":"Evision.Constant.html#cv_NRM_NONE/0"},{"type":"function","title":"Evision.Constant.cv_NRM_PARTIAL/0","doc":"","ref":"Evision.Constant.html#cv_NRM_PARTIAL/0"},{"type":"function","title":"Evision.Constant.cv_NRM_SIFT/0","doc":"","ref":"Evision.Constant.html#cv_NRM_SIFT/0"},{"type":"function","title":"Evision.Constant.cv_NU/0","doc":"","ref":"Evision.Constant.html#cv_NU/0"},{"type":"function","title":"Evision.Constant.cv_NU_SVC/0","doc":"","ref":"Evision.Constant.html#cv_NU_SVC/0"},{"type":"function","title":"Evision.Constant.cv_NU_SVR/0","doc":"","ref":"Evision.Constant.html#cv_NU_SVR/0"},{"type":"function","title":"Evision.Constant.cv_NumCodecs/0","doc":"","ref":"Evision.Constant.html#cv_NumCodecs/0"},{"type":"function","title":"Evision.Constant.cv_NumFormats/0","doc":"","ref":"Evision.Constant.html#cv_NumFormats/0"},{"type":"function","title":"Evision.Constant.cv_NV_AYUV/0","doc":"","ref":"Evision.Constant.html#cv_NV_AYUV/0"},{"type":"function","title":"Evision.Constant.cv_NV_IYUV/0","doc":"","ref":"Evision.Constant.html#cv_NV_IYUV/0"},{"type":"function","title":"Evision.Constant.cv_NV_NV12/0","doc":"","ref":"Evision.Constant.html#cv_NV_NV12/0"},{"type":"function","title":"Evision.Constant.cv_NV_YUV444/0","doc":"","ref":"Evision.Constant.html#cv_NV_YUV444/0"},{"type":"function","title":"Evision.Constant.cv_NV_YV12/0","doc":"","ref":"Evision.Constant.html#cv_NV_YV12/0"},{"type":"function","title":"Evision.Constant.cv_OAST_9_16/0","doc":"","ref":"Evision.Constant.html#cv_OAST_9_16/0"},{"type":"function","title":"Evision.Constant.cv_OCL_VECTOR_DEFAULT/0","doc":"","ref":"Evision.Constant.html#cv_OCL_VECTOR_DEFAULT/0"},{"type":"function","title":"Evision.Constant.cv_OCL_VECTOR_MAX/0","doc":"","ref":"Evision.Constant.html#cv_OCL_VECTOR_MAX/0"},{"type":"function","title":"Evision.Constant.cv_OCL_VECTOR_OWN/0","doc":"","ref":"Evision.Constant.html#cv_OCL_VECTOR_OWN/0"},{"type":"function","title":"Evision.Constant.cv_OCR_CNN_CLASSIFIER/0","doc":"","ref":"Evision.Constant.html#cv_OCR_CNN_CLASSIFIER/0"},{"type":"function","title":"Evision.Constant.cv_OCR_DECODER_VITERBI/0","doc":"","ref":"Evision.Constant.html#cv_OCR_DECODER_VITERBI/0"},{"type":"function","title":"Evision.Constant.cv_OCR_KNN_CLASSIFIER/0","doc":"","ref":"Evision.Constant.html#cv_OCR_KNN_CLASSIFIER/0"},{"type":"function","title":"Evision.Constant.cv_OCR_LEVEL_TEXTLINE/0","doc":"","ref":"Evision.Constant.html#cv_OCR_LEVEL_TEXTLINE/0"},{"type":"function","title":"Evision.Constant.cv_OCR_LEVEL_WORD/0","doc":"","ref":"Evision.Constant.html#cv_OCR_LEVEL_WORD/0"},{"type":"function","title":"Evision.Constant.cv_OCTAVE_ROW/0","doc":"","ref":"Evision.Constant.html#cv_OCTAVE_ROW/0"},{"type":"function","title":"Evision.Constant.cv_OEM_CUBE_ONLY/0","doc":"","ref":"Evision.Constant.html#cv_OEM_CUBE_ONLY/0"},{"type":"function","title":"Evision.Constant.cv_OEM_DEFAULT/0","doc":"","ref":"Evision.Constant.html#cv_OEM_DEFAULT/0"},{"type":"function","title":"Evision.Constant.cv_OEM_TESSERACT_CUBE_COMBINED/0","doc":"","ref":"Evision.Constant.html#cv_OEM_TESSERACT_CUBE_COMBINED/0"},{"type":"function","title":"Evision.Constant.cv_OEM_TESSERACT_ONLY/0","doc":"","ref":"Evision.Constant.html#cv_OEM_TESSERACT_ONLY/0"},{"type":"function","title":"Evision.Constant.cv_OK/0","doc":"","ref":"Evision.Constant.html#cv_OK/0"},{"type":"function","title":"Evision.Constant.cv_OMNIDIRECTIONAL/0","doc":"","ref":"Evision.Constant.html#cv_OMNIDIRECTIONAL/0"},{"type":"function","title":"Evision.Constant.cv_ONE_CLASS/0","doc":"","ref":"Evision.Constant.html#cv_ONE_CLASS/0"},{"type":"function","title":"Evision.Constant.cv_ONE_STEP/0","doc":"","ref":"Evision.Constant.html#cv_ONE_STEP/0"},{"type":"function","title":"Evision.Constant.cv_OPENGL_BUFFER/0","doc":"","ref":"Evision.Constant.html#cv_OPENGL_BUFFER/0"},{"type":"function","title":"Evision.Constant.cv_OPTFLOW_FARNEBACK_GAUSSIAN/0","doc":"","ref":"Evision.Constant.html#cv_OPTFLOW_FARNEBACK_GAUSSIAN/0"},{"type":"function","title":"Evision.Constant.cv_OPTFLOW_LK_GET_MIN_EIGENVALS/0","doc":"","ref":"Evision.Constant.html#cv_OPTFLOW_LK_GET_MIN_EIGENVALS/0"},{"type":"function","title":"Evision.Constant.cv_OPTFLOW_USE_INITIAL_FLOW/0","doc":"","ref":"Evision.Constant.html#cv_OPTFLOW_USE_INITIAL_FLOW/0"},{"type":"function","title":"Evision.Constant.cv_OpenCLApiCallError/0","doc":"","ref":"Evision.Constant.html#cv_OpenCLApiCallError/0"},{"type":"function","title":"Evision.Constant.cv_OpenCLDoubleNotSupported/0","doc":"","ref":"Evision.Constant.html#cv_OpenCLDoubleNotSupported/0"},{"type":"function","title":"Evision.Constant.cv_OpenCLInitError/0","doc":"","ref":"Evision.Constant.html#cv_OpenCLInitError/0"},{"type":"function","title":"Evision.Constant.cv_OpenCLNoAMDBlasFft/0","doc":"","ref":"Evision.Constant.html#cv_OpenCLNoAMDBlasFft/0"},{"type":"function","title":"Evision.Constant.cv_OpenGlApiCallError/0","doc":"","ref":"Evision.Constant.html#cv_OpenGlApiCallError/0"},{"type":"function","title":"Evision.Constant.cv_OpenGlNotSupported/0","doc":"","ref":"Evision.Constant.html#cv_OpenGlNotSupported/0"},{"type":"function","title":"Evision.Constant.cv_omnidir_CALIB_FIX_K1/0","doc":"","ref":"Evision.Constant.html#cv_omnidir_CALIB_FIX_K1/0"},{"type":"function","title":"Evision.Constant.cv_omnidir_CALIB_FIX_K2/0","doc":"","ref":"Evision.Constant.html#cv_omnidir_CALIB_FIX_K2/0"},{"type":"function","title":"Evision.Constant.cv_omnidir_CALIB_FIX_SKEW/0","doc":"","ref":"Evision.Constant.html#cv_omnidir_CALIB_FIX_SKEW/0"},{"type":"function","title":"Evision.Constant.cv_P/0","doc":"","ref":"Evision.Constant.html#cv_P/0"},{"type":"function","title":"Evision.Constant.cv_PAGE_LOCKED/0","doc":"","ref":"Evision.Constant.html#cv_PAGE_LOCKED/0"},{"type":"function","title":"Evision.Constant.cv_PANORAMA/0","doc":"","ref":"Evision.Constant.html#cv_PANORAMA/0"},{"type":"function","title":"Evision.Constant.cv_PCTSignatures_GAUSSIAN/0","doc":"","ref":"Evision.Constant.html#cv_PCTSignatures_GAUSSIAN/0"},{"type":"function","title":"Evision.Constant.cv_PCTSignatures_NORMAL/0","doc":"","ref":"Evision.Constant.html#cv_PCTSignatures_NORMAL/0"},{"type":"function","title":"Evision.Constant.cv_PINHOLE/0","doc":"","ref":"Evision.Constant.html#cv_PINHOLE/0"},{"type":"function","title":"Evision.Constant.cv_PIXEL_PACK_BUFFER/0","doc":"","ref":"Evision.Constant.html#cv_PIXEL_PACK_BUFFER/0"},{"type":"function","title":"Evision.Constant.cv_PIXEL_UNPACK_BUFFER/0","doc":"","ref":"Evision.Constant.html#cv_PIXEL_UNPACK_BUFFER/0"},{"type":"function","title":"Evision.Constant.cv_POINTS/0","doc":"","ref":"Evision.Constant.html#cv_POINTS/0"},{"type":"function","title":"Evision.Constant.cv_POLY/0","doc":"","ref":"Evision.Constant.html#cv_POLY/0"},{"type":"function","title":"Evision.Constant.cv_POLYGON/0","doc":"","ref":"Evision.Constant.html#cv_POLYGON/0"},{"type":"function","title":"Evision.Constant.cv_PREDICT_AUTO/0","doc":"","ref":"Evision.Constant.html#cv_PREDICT_AUTO/0"},{"type":"function","title":"Evision.Constant.cv_PREDICT_MASK/0","doc":"","ref":"Evision.Constant.html#cv_PREDICT_MASK/0"},{"type":"function","title":"Evision.Constant.cv_PREDICT_MAX_VOTE/0","doc":"","ref":"Evision.Constant.html#cv_PREDICT_MAX_VOTE/0"},{"type":"function","title":"Evision.Constant.cv_PREDICT_SUM/0","doc":"","ref":"Evision.Constant.html#cv_PREDICT_SUM/0"},{"type":"function","title":"Evision.Constant.cv_PREFILTER_NORMALIZED_RESPONSE/0","doc":"","ref":"Evision.Constant.html#cv_PREFILTER_NORMALIZED_RESPONSE/0"},{"type":"function","title":"Evision.Constant.cv_PREFILTER_XSOBEL/0","doc":"","ref":"Evision.Constant.html#cv_PREFILTER_XSOBEL/0"},{"type":"function","title":"Evision.Constant.cv_PREPROCESSED_INPUT/0","doc":"","ref":"Evision.Constant.html#cv_PREPROCESSED_INPUT/0"},{"type":"function","title":"Evision.Constant.cv_PRESET_FAST/0","doc":"","ref":"Evision.Constant.html#cv_PRESET_FAST/0"},{"type":"function","title":"Evision.Constant.cv_PRESET_MEDIUM/0","doc":"","ref":"Evision.Constant.html#cv_PRESET_MEDIUM/0"},{"type":"function","title":"Evision.Constant.cv_PRESET_ULTRAFAST/0","doc":"","ref":"Evision.Constant.html#cv_PRESET_ULTRAFAST/0"},{"type":"function","title":"Evision.Constant.cv_PREV_AROUND_DST/0","doc":"","ref":"Evision.Constant.html#cv_PREV_AROUND_DST/0"},{"type":"function","title":"Evision.Constant.cv_PREV_AROUND_LEFT/0","doc":"","ref":"Evision.Constant.html#cv_PREV_AROUND_LEFT/0"},{"type":"function","title":"Evision.Constant.cv_PREV_AROUND_ORG/0","doc":"","ref":"Evision.Constant.html#cv_PREV_AROUND_ORG/0"},{"type":"function","title":"Evision.Constant.cv_PREV_AROUND_RIGHT/0","doc":"","ref":"Evision.Constant.html#cv_PREV_AROUND_RIGHT/0"},{"type":"function","title":"Evision.Constant.cv_PREWITT/0","doc":"","ref":"Evision.Constant.html#cv_PREWITT/0"},{"type":"function","title":"Evision.Constant.cv_PROJ_SPHERICAL_EQRECT/0","doc":"","ref":"Evision.Constant.html#cv_PROJ_SPHERICAL_EQRECT/0"},{"type":"function","title":"Evision.Constant.cv_PROJ_SPHERICAL_ORTHO/0","doc":"","ref":"Evision.Constant.html#cv_PROJ_SPHERICAL_ORTHO/0"},{"type":"function","title":"Evision.Constant.cv_PROP_ALLOW_FRAME_DROP/0","doc":"","ref":"Evision.Constant.html#cv_PROP_ALLOW_FRAME_DROP/0"},{"type":"function","title":"Evision.Constant.cv_PROP_COLOR_FORMAT/0","doc":"","ref":"Evision.Constant.html#cv_PROP_COLOR_FORMAT/0"},{"type":"function","title":"Evision.Constant.cv_PROP_DECODED_FRAME_IDX/0","doc":"","ref":"Evision.Constant.html#cv_PROP_DECODED_FRAME_IDX/0"},{"type":"function","title":"Evision.Constant.cv_PROP_EXTRA_DATA_INDEX/0","doc":"","ref":"Evision.Constant.html#cv_PROP_EXTRA_DATA_INDEX/0"},{"type":"function","title":"Evision.Constant.cv_PROP_LRF_HAS_KEY_FRAME/0","doc":"","ref":"Evision.Constant.html#cv_PROP_LRF_HAS_KEY_FRAME/0"},{"type":"function","title":"Evision.Constant.cv_PROP_NOT_SUPPORTED/0","doc":"","ref":"Evision.Constant.html#cv_PROP_NOT_SUPPORTED/0"},{"type":"function","title":"Evision.Constant.cv_PROP_NUMBER_OF_RAW_PACKAGES_SINCE_LAST_GRAB/0","doc":"","ref":"Evision.Constant.html#cv_PROP_NUMBER_OF_RAW_PACKAGES_SINCE_LAST_GRAB/0"},{"type":"function","title":"Evision.Constant.cv_PROP_RAW_MODE/0","doc":"","ref":"Evision.Constant.html#cv_PROP_RAW_MODE/0"},{"type":"function","title":"Evision.Constant.cv_PROP_RAW_PACKAGES_BASE_INDEX/0","doc":"","ref":"Evision.Constant.html#cv_PROP_RAW_PACKAGES_BASE_INDEX/0"},{"type":"function","title":"Evision.Constant.cv_PROP_UDP_SOURCE/0","doc":"","ref":"Evision.Constant.html#cv_PROP_UDP_SOURCE/0"},{"type":"function","title":"Evision.Constant.cv_PSM_AUTO/0","doc":"","ref":"Evision.Constant.html#cv_PSM_AUTO/0"},{"type":"function","title":"Evision.Constant.cv_PSM_AUTO_ONLY/0","doc":"","ref":"Evision.Constant.html#cv_PSM_AUTO_ONLY/0"},{"type":"function","title":"Evision.Constant.cv_PSM_AUTO_OSD/0","doc":"","ref":"Evision.Constant.html#cv_PSM_AUTO_OSD/0"},{"type":"function","title":"Evision.Constant.cv_PSM_CIRCLE_WORD/0","doc":"","ref":"Evision.Constant.html#cv_PSM_CIRCLE_WORD/0"},{"type":"function","title":"Evision.Constant.cv_PSM_OSD_ONLY/0","doc":"","ref":"Evision.Constant.html#cv_PSM_OSD_ONLY/0"},{"type":"function","title":"Evision.Constant.cv_PSM_SINGLE_BLOCK/0","doc":"","ref":"Evision.Constant.html#cv_PSM_SINGLE_BLOCK/0"},{"type":"function","title":"Evision.Constant.cv_PSM_SINGLE_BLOCK_VERT_TEXT/0","doc":"","ref":"Evision.Constant.html#cv_PSM_SINGLE_BLOCK_VERT_TEXT/0"},{"type":"function","title":"Evision.Constant.cv_PSM_SINGLE_CHAR/0","doc":"","ref":"Evision.Constant.html#cv_PSM_SINGLE_CHAR/0"},{"type":"function","title":"Evision.Constant.cv_PSM_SINGLE_COLUMN/0","doc":"","ref":"Evision.Constant.html#cv_PSM_SINGLE_COLUMN/0"},{"type":"function","title":"Evision.Constant.cv_PSM_SINGLE_LINE/0","doc":"","ref":"Evision.Constant.html#cv_PSM_SINGLE_LINE/0"},{"type":"function","title":"Evision.Constant.cv_PSM_SINGLE_WORD/0","doc":"","ref":"Evision.Constant.html#cv_PSM_SINGLE_WORD/0"},{"type":"function","title":"Evision.Constant.cv_PSP/0","doc":"","ref":"Evision.Constant.html#cv_PSP/0"},{"type":"function","title":"Evision.Constant.cv_PTLOC_ERROR/0","doc":"","ref":"Evision.Constant.html#cv_PTLOC_ERROR/0"},{"type":"function","title":"Evision.Constant.cv_PTLOC_INSIDE/0","doc":"","ref":"Evision.Constant.html#cv_PTLOC_INSIDE/0"},{"type":"function","title":"Evision.Constant.cv_PTLOC_ON_EDGE/0","doc":"","ref":"Evision.Constant.html#cv_PTLOC_ON_EDGE/0"},{"type":"function","title":"Evision.Constant.cv_PTLOC_OUTSIDE_RECT/0","doc":"","ref":"Evision.Constant.html#cv_PTLOC_OUTSIDE_RECT/0"},{"type":"function","title":"Evision.Constant.cv_PTLOC_VERTEX/0","doc":"","ref":"Evision.Constant.html#cv_PTLOC_VERTEX/0"},{"type":"function","title":"Evision.Constant.cv_PTR_ONLY/0","doc":"","ref":"Evision.Constant.html#cv_PTR_ONLY/0"},{"type":"function","title":"Evision.Constant.cv_QT_CHECKBOX/0","doc":"","ref":"Evision.Constant.html#cv_QT_CHECKBOX/0"},{"type":"function","title":"Evision.Constant.cv_QT_FONT_BLACK/0","doc":"","ref":"Evision.Constant.html#cv_QT_FONT_BLACK/0"},{"type":"function","title":"Evision.Constant.cv_QT_FONT_BOLD/0","doc":"","ref":"Evision.Constant.html#cv_QT_FONT_BOLD/0"},{"type":"function","title":"Evision.Constant.cv_QT_FONT_DEMIBOLD/0","doc":"","ref":"Evision.Constant.html#cv_QT_FONT_DEMIBOLD/0"},{"type":"function","title":"Evision.Constant.cv_QT_FONT_LIGHT/0","doc":"","ref":"Evision.Constant.html#cv_QT_FONT_LIGHT/0"},{"type":"function","title":"Evision.Constant.cv_QT_FONT_NORMAL/0","doc":"","ref":"Evision.Constant.html#cv_QT_FONT_NORMAL/0"},{"type":"function","title":"Evision.Constant.cv_QT_NEW_BUTTONBAR/0","doc":"","ref":"Evision.Constant.html#cv_QT_NEW_BUTTONBAR/0"},{"type":"function","title":"Evision.Constant.cv_QT_PUSH_BUTTON/0","doc":"","ref":"Evision.Constant.html#cv_QT_PUSH_BUTTON/0"},{"type":"function","title":"Evision.Constant.cv_QT_RADIOBOX/0","doc":"","ref":"Evision.Constant.html#cv_QT_RADIOBOX/0"},{"type":"function","title":"Evision.Constant.cv_QT_STYLE_ITALIC/0","doc":"","ref":"Evision.Constant.html#cv_QT_STYLE_ITALIC/0"},{"type":"function","title":"Evision.Constant.cv_QT_STYLE_NORMAL/0","doc":"","ref":"Evision.Constant.html#cv_QT_STYLE_NORMAL/0"},{"type":"function","title":"Evision.Constant.cv_QT_STYLE_OBLIQUE/0","doc":"","ref":"Evision.Constant.html#cv_QT_STYLE_OBLIQUE/0"},{"type":"function","title":"Evision.Constant.cv_QUAD_STRIP/0","doc":"","ref":"Evision.Constant.html#cv_QUAD_STRIP/0"},{"type":"function","title":"Evision.Constant.cv_QUADS/0","doc":"","ref":"Evision.Constant.html#cv_QUADS/0"},{"type":"function","title":"Evision.Constant.cv_QUAT_ASSUME_NOT_UNIT/0","doc":"","ref":"Evision.Constant.html#cv_QUAT_ASSUME_NOT_UNIT/0"},{"type":"function","title":"Evision.Constant.cv_QUAT_ASSUME_UNIT/0","doc":"","ref":"Evision.Constant.html#cv_QUAT_ASSUME_UNIT/0"},{"type":"function","title":"Evision.Constant.cv_RANSAC/0","doc":"","ref":"Evision.Constant.html#cv_RANSAC/0"},{"type":"function","title":"Evision.Constant.cv_RAW_OUTPUT/0","doc":"","ref":"Evision.Constant.html#cv_RAW_OUTPUT/0"},{"type":"function","title":"Evision.Constant.cv_RBF/0","doc":"","ref":"Evision.Constant.html#cv_RBF/0"},{"type":"function","title":"Evision.Constant.cv_READ/0","doc":"","ref":"Evision.Constant.html#cv_READ/0"},{"type":"function","title":"Evision.Constant.cv_READ_ONLY/0","doc":"","ref":"Evision.Constant.html#cv_READ_ONLY/0"},{"type":"function","title":"Evision.Constant.cv_READ_ONLY_CACHE/0","doc":"","ref":"Evision.Constant.html#cv_READ_ONLY_CACHE/0"},{"type":"function","title":"Evision.Constant.cv_READ_WRITE/0","doc":"","ref":"Evision.Constant.html#cv_READ_WRITE/0"},{"type":"function","title":"Evision.Constant.cv_READ_WRITE_CACHE/0","doc":"","ref":"Evision.Constant.html#cv_READ_WRITE_CACHE/0"},{"type":"function","title":"Evision.Constant.cv_REAL/0","doc":"","ref":"Evision.Constant.html#cv_REAL/0"},{"type":"function","title":"Evision.Constant.cv_RECTIFY_CYLINDRICAL/0","doc":"","ref":"Evision.Constant.html#cv_RECTIFY_CYLINDRICAL/0"},{"type":"function","title":"Evision.Constant.cv_RECTIFY_LONGLATI/0","doc":"","ref":"Evision.Constant.html#cv_RECTIFY_LONGLATI/0"},{"type":"function","title":"Evision.Constant.cv_RECTIFY_PERSPECTIVE/0","doc":"","ref":"Evision.Constant.html#cv_RECTIFY_PERSPECTIVE/0"},{"type":"function","title":"Evision.Constant.cv_RECTIFY_STEREOGRAPHIC/0","doc":"","ref":"Evision.Constant.html#cv_RECTIFY_STEREOGRAPHIC/0"},{"type":"function","title":"Evision.Constant.cv_RECURS_FILTER/0","doc":"","ref":"Evision.Constant.html#cv_RECURS_FILTER/0"},{"type":"function","title":"Evision.Constant.cv_REDUCE_AVG/0","doc":"","ref":"Evision.Constant.html#cv_REDUCE_AVG/0"},{"type":"function","title":"Evision.Constant.cv_REDUCE_MAX/0","doc":"","ref":"Evision.Constant.html#cv_REDUCE_MAX/0"},{"type":"function","title":"Evision.Constant.cv_REDUCE_MIN/0","doc":"","ref":"Evision.Constant.html#cv_REDUCE_MIN/0"},{"type":"function","title":"Evision.Constant.cv_REDUCE_SUM2/0","doc":"","ref":"Evision.Constant.html#cv_REDUCE_SUM2/0"},{"type":"function","title":"Evision.Constant.cv_REDUCE_SUM/0","doc":"","ref":"Evision.Constant.html#cv_REDUCE_SUM/0"},{"type":"function","title":"Evision.Constant.cv_REG_DISABLE/0","doc":"","ref":"Evision.Constant.html#cv_REG_DISABLE/0"},{"type":"function","title":"Evision.Constant.cv_REG_L1/0","doc":"","ref":"Evision.Constant.html#cv_REG_L1/0"},{"type":"function","title":"Evision.Constant.cv_REG_L2/0","doc":"","ref":"Evision.Constant.html#cv_REG_L2/0"},{"type":"function","title":"Evision.Constant.cv_REGULAR/0","doc":"","ref":"Evision.Constant.html#cv_REGULAR/0"},{"type":"function","title":"Evision.Constant.cv_RELU/0","doc":"","ref":"Evision.Constant.html#cv_RELU/0"},{"type":"function","title":"Evision.Constant.cv_RETINA_COLOR_BAYER/0","doc":"","ref":"Evision.Constant.html#cv_RETINA_COLOR_BAYER/0"},{"type":"function","title":"Evision.Constant.cv_RETINA_COLOR_DIAGONAL/0","doc":"","ref":"Evision.Constant.html#cv_RETINA_COLOR_DIAGONAL/0"},{"type":"function","title":"Evision.Constant.cv_RETINA_COLOR_RANDOM/0","doc":"","ref":"Evision.Constant.html#cv_RETINA_COLOR_RANDOM/0"},{"type":"function","title":"Evision.Constant.cv_RETR_CCOMP/0","doc":"","ref":"Evision.Constant.html#cv_RETR_CCOMP/0"},{"type":"function","title":"Evision.Constant.cv_RETR_EXTERNAL/0","doc":"","ref":"Evision.Constant.html#cv_RETR_EXTERNAL/0"},{"type":"function","title":"Evision.Constant.cv_RETR_FLOODFILL/0","doc":"","ref":"Evision.Constant.html#cv_RETR_FLOODFILL/0"},{"type":"function","title":"Evision.Constant.cv_RETR_LIST/0","doc":"","ref":"Evision.Constant.html#cv_RETR_LIST/0"},{"type":"function","title":"Evision.Constant.cv_RETR_TREE/0","doc":"","ref":"Evision.Constant.html#cv_RETR_TREE/0"},{"type":"function","title":"Evision.Constant.cv_RGB/0","doc":"","ref":"Evision.Constant.html#cv_RGB/0"},{"type":"function","title":"Evision.Constant.cv_RGBA/0","doc":"","ref":"Evision.Constant.html#cv_RGBA/0"},{"type":"function","title":"Evision.Constant.cv_RGBD_NORMALS_METHOD_FALS/0","doc":"","ref":"Evision.Constant.html#cv_RGBD_NORMALS_METHOD_FALS/0"},{"type":"function","title":"Evision.Constant.cv_RGBD_NORMALS_METHOD_LINEMOD/0","doc":"","ref":"Evision.Constant.html#cv_RGBD_NORMALS_METHOD_LINEMOD/0"},{"type":"function","title":"Evision.Constant.cv_RGBD_NORMALS_METHOD_SRI/0","doc":"","ref":"Evision.Constant.html#cv_RGBD_NORMALS_METHOD_SRI/0"},{"type":"function","title":"Evision.Constant.cv_RGBD_PLANE_METHOD_DEFAULT/0","doc":"","ref":"Evision.Constant.html#cv_RGBD_PLANE_METHOD_DEFAULT/0"},{"type":"function","title":"Evision.Constant.cv_RHO/0","doc":"","ref":"Evision.Constant.html#cv_RHO/0"},{"type":"function","title":"Evision.Constant.cv_RIGID_BODY_MOTION/0","doc":"","ref":"Evision.Constant.html#cv_RIGID_BODY_MOTION/0"},{"type":"function","title":"Evision.Constant.cv_ROTATE_90_CLOCKWISE/0","doc":"","ref":"Evision.Constant.html#cv_ROTATE_90_CLOCKWISE/0"},{"type":"function","title":"Evision.Constant.cv_ROTATE_90_COUNTERCLOCKWISE/0","doc":"","ref":"Evision.Constant.html#cv_ROTATE_90_COUNTERCLOCKWISE/0"},{"type":"function","title":"Evision.Constant.cv_ROTATE_180/0","doc":"","ref":"Evision.Constant.html#cv_ROTATE_180/0"},{"type":"function","title":"Evision.Constant.cv_ROTATION/0","doc":"","ref":"Evision.Constant.html#cv_ROTATION/0"},{"type":"function","title":"Evision.Constant.cv_ROW_SAMPLE/0","doc":"","ref":"Evision.Constant.html#cv_ROW_SAMPLE/0"},{"type":"function","title":"Evision.Constant.cv_ROWS_COUNT/0","doc":"","ref":"Evision.Constant.html#cv_ROWS_COUNT/0"},{"type":"function","title":"Evision.Constant.cv_RPROP/0","doc":"","ref":"Evision.Constant.html#cv_RPROP/0"},{"type":"function","title":"Evision.Constant.cv_SAMPLING_NAPSAC/0","doc":"","ref":"Evision.Constant.html#cv_SAMPLING_NAPSAC/0"},{"type":"function","title":"Evision.Constant.cv_SAMPLING_PROGRESSIVE_NAPSAC/0","doc":"","ref":"Evision.Constant.html#cv_SAMPLING_PROGRESSIVE_NAPSAC/0"},{"type":"function","title":"Evision.Constant.cv_SAMPLING_PROSAC/0","doc":"","ref":"Evision.Constant.html#cv_SAMPLING_PROSAC/0"},{"type":"function","title":"Evision.Constant.cv_SAMPLING_UNIFORM/0","doc":"","ref":"Evision.Constant.html#cv_SAMPLING_UNIFORM/0"},{"type":"function","title":"Evision.Constant.cv_SCALAR/0","doc":"","ref":"Evision.Constant.html#cv_SCALAR/0"},{"type":"function","title":"Evision.Constant.cv_SCANS/0","doc":"","ref":"Evision.Constant.html#cv_SCANS/0"},{"type":"function","title":"Evision.Constant.cv_SCHARR/0","doc":"","ref":"Evision.Constant.html#cv_SCHARR/0"},{"type":"function","title":"Evision.Constant.cv_SCORE_METHOD_LMEDS/0","doc":"","ref":"Evision.Constant.html#cv_SCORE_METHOD_LMEDS/0"},{"type":"function","title":"Evision.Constant.cv_SCORE_METHOD_MAGSAC/0","doc":"","ref":"Evision.Constant.html#cv_SCORE_METHOD_MAGSAC/0"},{"type":"function","title":"Evision.Constant.cv_SCORE_METHOD_MSAC/0","doc":"","ref":"Evision.Constant.html#cv_SCORE_METHOD_MSAC/0"},{"type":"function","title":"Evision.Constant.cv_SCORE_METHOD_RANSAC/0","doc":"","ref":"Evision.Constant.html#cv_SCORE_METHOD_RANSAC/0"},{"type":"function","title":"Evision.Constant.cv_SECOND_ORDER_MOMENTS/0","doc":"","ref":"Evision.Constant.html#cv_SECOND_ORDER_MOMENTS/0"},{"type":"function","title":"Evision.Constant.cv_SEQ/0","doc":"","ref":"Evision.Constant.html#cv_SEQ/0"},{"type":"function","title":"Evision.Constant.cv_SG140/0","doc":"","ref":"Evision.Constant.html#cv_SG140/0"},{"type":"function","title":"Evision.Constant.cv_SGD/0","doc":"","ref":"Evision.Constant.html#cv_SGD/0"},{"type":"function","title":"Evision.Constant.cv_SHARED/0","doc":"","ref":"Evision.Constant.html#cv_SHARED/0"},{"type":"function","title":"Evision.Constant.cv_SHARED_ATOMICS/0","doc":"","ref":"Evision.Constant.html#cv_SHARED_ATOMICS/0"},{"type":"function","title":"Evision.Constant.cv_SIGMOID/0","doc":"","ref":"Evision.Constant.html#cv_SIGMOID/0"},{"type":"function","title":"Evision.Constant.cv_SIGMOID_SYM/0","doc":"","ref":"Evision.Constant.html#cv_SIGMOID_SYM/0"},{"type":"function","title":"Evision.Constant.cv_SINUS/0","doc":"","ref":"Evision.Constant.html#cv_SINUS/0"},{"type":"function","title":"Evision.Constant.cv_SIZE_256_BITS/0","doc":"","ref":"Evision.Constant.html#cv_SIZE_256_BITS/0"},{"type":"function","title":"Evision.Constant.cv_SIZE_512_BITS/0","doc":"","ref":"Evision.Constant.html#cv_SIZE_512_BITS/0"},{"type":"function","title":"Evision.Constant.cv_SIZE_ROW/0","doc":"","ref":"Evision.Constant.html#cv_SIZE_ROW/0"},{"type":"function","title":"Evision.Constant.cv_SLIC/0","doc":"","ref":"Evision.Constant.html#cv_SLIC/0"},{"type":"function","title":"Evision.Constant.cv_SLICO/0","doc":"","ref":"Evision.Constant.html#cv_SLICO/0"},{"type":"function","title":"Evision.Constant.cv_SOBEL/0","doc":"","ref":"Evision.Constant.html#cv_SOBEL/0"},{"type":"function","title":"Evision.Constant.cv_SOFT_MARGIN/0","doc":"","ref":"Evision.Constant.html#cv_SOFT_MARGIN/0"},{"type":"function","title":"Evision.Constant.cv_SOFTNMS_GAUSSIAN/0","doc":"","ref":"Evision.Constant.html#cv_SOFTNMS_GAUSSIAN/0"},{"type":"function","title":"Evision.Constant.cv_SOFTNMS_LINEAR/0","doc":"","ref":"Evision.Constant.html#cv_SOFTNMS_LINEAR/0"},{"type":"function","title":"Evision.Constant.cv_SOLVELP_LOST/0","doc":"","ref":"Evision.Constant.html#cv_SOLVELP_LOST/0"},{"type":"function","title":"Evision.Constant.cv_SOLVELP_MULTI/0","doc":"","ref":"Evision.Constant.html#cv_SOLVELP_MULTI/0"},{"type":"function","title":"Evision.Constant.cv_SOLVELP_SINGLE/0","doc":"","ref":"Evision.Constant.html#cv_SOLVELP_SINGLE/0"},{"type":"function","title":"Evision.Constant.cv_SOLVELP_UNBOUNDED/0","doc":"","ref":"Evision.Constant.html#cv_SOLVELP_UNBOUNDED/0"},{"type":"function","title":"Evision.Constant.cv_SOLVELP_UNFEASIBLE/0","doc":"","ref":"Evision.Constant.html#cv_SOLVELP_UNFEASIBLE/0"},{"type":"function","title":"Evision.Constant.cv_SOLVEPNP_AP3P/0","doc":"","ref":"Evision.Constant.html#cv_SOLVEPNP_AP3P/0"},{"type":"function","title":"Evision.Constant.cv_SOLVEPNP_DLS/0","doc":"","ref":"Evision.Constant.html#cv_SOLVEPNP_DLS/0"},{"type":"function","title":"Evision.Constant.cv_SOLVEPNP_EPNP/0","doc":"","ref":"Evision.Constant.html#cv_SOLVEPNP_EPNP/0"},{"type":"function","title":"Evision.Constant.cv_SOLVEPNP_IPPE/0","doc":"","ref":"Evision.Constant.html#cv_SOLVEPNP_IPPE/0"},{"type":"function","title":"Evision.Constant.cv_SOLVEPNP_IPPE_SQUARE/0","doc":"","ref":"Evision.Constant.html#cv_SOLVEPNP_IPPE_SQUARE/0"},{"type":"function","title":"Evision.Constant.cv_SOLVEPNP_ITERATIVE/0","doc":"","ref":"Evision.Constant.html#cv_SOLVEPNP_ITERATIVE/0"},{"type":"function","title":"Evision.Constant.cv_SOLVEPNP_MAX_COUNT/0","doc":"","ref":"Evision.Constant.html#cv_SOLVEPNP_MAX_COUNT/0"},{"type":"function","title":"Evision.Constant.cv_SOLVEPNP_P3P/0","doc":"","ref":"Evision.Constant.html#cv_SOLVEPNP_P3P/0"},{"type":"function","title":"Evision.Constant.cv_SOLVEPNP_SQPNP/0","doc":"","ref":"Evision.Constant.html#cv_SOLVEPNP_SQPNP/0"},{"type":"function","title":"Evision.Constant.cv_SOLVEPNP_UPNP/0","doc":"","ref":"Evision.Constant.html#cv_SOLVEPNP_UPNP/0"},{"type":"function","title":"Evision.Constant.cv_SORT_ASCENDING/0","doc":"","ref":"Evision.Constant.html#cv_SORT_ASCENDING/0"},{"type":"function","title":"Evision.Constant.cv_SORT_DESCENDING/0","doc":"","ref":"Evision.Constant.html#cv_SORT_DESCENDING/0"},{"type":"function","title":"Evision.Constant.cv_SORT_EVERY_COLUMN/0","doc":"","ref":"Evision.Constant.html#cv_SORT_EVERY_COLUMN/0"},{"type":"function","title":"Evision.Constant.cv_SORT_EVERY_ROW/0","doc":"","ref":"Evision.Constant.html#cv_SORT_EVERY_ROW/0"},{"type":"function","title":"Evision.Constant.cv_SparseMat_MAGIC_VAL/0","doc":"","ref":"Evision.Constant.html#cv_SparseMat_MAGIC_VAL/0"},{"type":"function","title":"Evision.Constant.cv_START_AUTO_STEP/0","doc":"","ref":"Evision.Constant.html#cv_START_AUTO_STEP/0"},{"type":"function","title":"Evision.Constant.cv_START_E_STEP/0","doc":"","ref":"Evision.Constant.html#cv_START_E_STEP/0"},{"type":"function","title":"Evision.Constant.cv_START_M_STEP/0","doc":"","ref":"Evision.Constant.html#cv_START_M_STEP/0"},{"type":"function","title":"Evision.Constant.cv_STD_ARRAY/0","doc":"","ref":"Evision.Constant.html#cv_STD_ARRAY/0"},{"type":"function","title":"Evision.Constant.cv_STD_ARRAY_MAT/0","doc":"","ref":"Evision.Constant.html#cv_STD_ARRAY_MAT/0"},{"type":"function","title":"Evision.Constant.cv_STD_BOOL_VECTOR/0","doc":"","ref":"Evision.Constant.html#cv_STD_BOOL_VECTOR/0"},{"type":"function","title":"Evision.Constant.cv_STD_VECTOR/0","doc":"","ref":"Evision.Constant.html#cv_STD_VECTOR/0"},{"type":"function","title":"Evision.Constant.cv_STD_VECTOR_CUDA_GPU_MAT/0","doc":"","ref":"Evision.Constant.html#cv_STD_VECTOR_CUDA_GPU_MAT/0"},{"type":"function","title":"Evision.Constant.cv_STD_VECTOR_MAT/0","doc":"","ref":"Evision.Constant.html#cv_STD_VECTOR_MAT/0"},{"type":"function","title":"Evision.Constant.cv_STD_VECTOR_UMAT/0","doc":"","ref":"Evision.Constant.html#cv_STD_VECTOR_UMAT/0"},{"type":"function","title":"Evision.Constant.cv_STD_VECTOR_VECTOR/0","doc":"","ref":"Evision.Constant.html#cv_STD_VECTOR_VECTOR/0"},{"type":"function","title":"Evision.Constant.cv_STR/0","doc":"","ref":"Evision.Constant.html#cv_STR/0"},{"type":"function","title":"Evision.Constant.cv_STRING/0","doc":"","ref":"Evision.Constant.html#cv_STRING/0"},{"type":"function","title":"Evision.Constant.cv_StsAssert/0","doc":"","ref":"Evision.Constant.html#cv_StsAssert/0"},{"type":"function","title":"Evision.Constant.cv_StsAutoTrace/0","doc":"","ref":"Evision.Constant.html#cv_StsAutoTrace/0"},{"type":"function","title":"Evision.Constant.cv_StsBackTrace/0","doc":"","ref":"Evision.Constant.html#cv_StsBackTrace/0"},{"type":"function","title":"Evision.Constant.cv_StsBadArg/0","doc":"","ref":"Evision.Constant.html#cv_StsBadArg/0"},{"type":"function","title":"Evision.Constant.cv_StsBadFlag/0","doc":"","ref":"Evision.Constant.html#cv_StsBadFlag/0"},{"type":"function","title":"Evision.Constant.cv_StsBadFunc/0","doc":"","ref":"Evision.Constant.html#cv_StsBadFunc/0"},{"type":"function","title":"Evision.Constant.cv_StsBadMask/0","doc":"","ref":"Evision.Constant.html#cv_StsBadMask/0"},{"type":"function","title":"Evision.Constant.cv_StsBadMemBlock/0","doc":"","ref":"Evision.Constant.html#cv_StsBadMemBlock/0"},{"type":"function","title":"Evision.Constant.cv_StsBadPoint/0","doc":"","ref":"Evision.Constant.html#cv_StsBadPoint/0"},{"type":"function","title":"Evision.Constant.cv_StsBadSize/0","doc":"","ref":"Evision.Constant.html#cv_StsBadSize/0"},{"type":"function","title":"Evision.Constant.cv_StsDivByZero/0","doc":"","ref":"Evision.Constant.html#cv_StsDivByZero/0"},{"type":"function","title":"Evision.Constant.cv_StsError/0","doc":"","ref":"Evision.Constant.html#cv_StsError/0"},{"type":"function","title":"Evision.Constant.cv_StsFilterOffsetErr/0","doc":"","ref":"Evision.Constant.html#cv_StsFilterOffsetErr/0"},{"type":"function","title":"Evision.Constant.cv_StsFilterStructContentErr/0","doc":"","ref":"Evision.Constant.html#cv_StsFilterStructContentErr/0"},{"type":"function","title":"Evision.Constant.cv_StsInplaceNotSupported/0","doc":"","ref":"Evision.Constant.html#cv_StsInplaceNotSupported/0"},{"type":"function","title":"Evision.Constant.cv_StsInternal/0","doc":"","ref":"Evision.Constant.html#cv_StsInternal/0"},{"type":"function","title":"Evision.Constant.cv_StsKernelStructContentErr/0","doc":"","ref":"Evision.Constant.html#cv_StsKernelStructContentErr/0"},{"type":"function","title":"Evision.Constant.cv_StsNoConv/0","doc":"","ref":"Evision.Constant.html#cv_StsNoConv/0"},{"type":"function","title":"Evision.Constant.cv_StsNoMem/0","doc":"","ref":"Evision.Constant.html#cv_StsNoMem/0"},{"type":"function","title":"Evision.Constant.cv_StsNotImplemented/0","doc":"","ref":"Evision.Constant.html#cv_StsNotImplemented/0"},{"type":"function","title":"Evision.Constant.cv_StsNullPtr/0","doc":"","ref":"Evision.Constant.html#cv_StsNullPtr/0"},{"type":"function","title":"Evision.Constant.cv_StsObjectNotFound/0","doc":"","ref":"Evision.Constant.html#cv_StsObjectNotFound/0"},{"type":"function","title":"Evision.Constant.cv_StsOk/0","doc":"","ref":"Evision.Constant.html#cv_StsOk/0"},{"type":"function","title":"Evision.Constant.cv_StsOutOfRange/0","doc":"","ref":"Evision.Constant.html#cv_StsOutOfRange/0"},{"type":"function","title":"Evision.Constant.cv_StsParseError/0","doc":"","ref":"Evision.Constant.html#cv_StsParseError/0"},{"type":"function","title":"Evision.Constant.cv_StsUnmatchedFormats/0","doc":"","ref":"Evision.Constant.html#cv_StsUnmatchedFormats/0"},{"type":"function","title":"Evision.Constant.cv_StsUnmatchedSizes/0","doc":"","ref":"Evision.Constant.html#cv_StsUnmatchedSizes/0"},{"type":"function","title":"Evision.Constant.cv_StsUnsupportedFormat/0","doc":"","ref":"Evision.Constant.html#cv_StsUnsupportedFormat/0"},{"type":"function","title":"Evision.Constant.cv_StsVecLengthErr/0","doc":"","ref":"Evision.Constant.html#cv_StsVecLengthErr/0"},{"type":"function","title":"Evision.Constant.cv_SYMMETRIC_GRID/0","doc":"","ref":"Evision.Constant.html#cv_SYMMETRIC_GRID/0"},{"type":"function","title":"Evision.Constant.cv_TEBLID_SIZE_256_BITS/0","doc":"","ref":"Evision.Constant.html#cv_TEBLID_SIZE_256_BITS/0"},{"type":"function","title":"Evision.Constant.cv_TEBLID_SIZE_512_BITS/0","doc":"","ref":"Evision.Constant.html#cv_TEBLID_SIZE_512_BITS/0"},{"type":"function","title":"Evision.Constant.cv_TEMP_COPIED_UMAT/0","doc":"","ref":"Evision.Constant.html#cv_TEMP_COPIED_UMAT/0"},{"type":"function","title":"Evision.Constant.cv_TEMP_UMAT/0","doc":"","ref":"Evision.Constant.html#cv_TEMP_UMAT/0"},{"type":"function","title":"Evision.Constant.cv_TEST_CUSTOM/0","doc":"","ref":"Evision.Constant.html#cv_TEST_CUSTOM/0"},{"type":"function","title":"Evision.Constant.cv_TEST_EQ/0","doc":"","ref":"Evision.Constant.html#cv_TEST_EQ/0"},{"type":"function","title":"Evision.Constant.cv_TEST_ERROR/0","doc":"","ref":"Evision.Constant.html#cv_TEST_ERROR/0"},{"type":"function","title":"Evision.Constant.cv_TEST_GE/0","doc":"","ref":"Evision.Constant.html#cv_TEST_GE/0"},{"type":"function","title":"Evision.Constant.cv_TEST_GT/0","doc":"","ref":"Evision.Constant.html#cv_TEST_GT/0"},{"type":"function","title":"Evision.Constant.cv_TEST_LE/0","doc":"","ref":"Evision.Constant.html#cv_TEST_LE/0"},{"type":"function","title":"Evision.Constant.cv_TEST_LT/0","doc":"","ref":"Evision.Constant.html#cv_TEST_LT/0"},{"type":"function","title":"Evision.Constant.cv_TEST_NE/0","doc":"","ref":"Evision.Constant.html#cv_TEST_NE/0"},{"type":"function","title":"Evision.Constant.cv_Texture2D_NONE/0","doc":"","ref":"Evision.Constant.html#cv_Texture2D_NONE/0"},{"type":"function","title":"Evision.Constant.cv_THINNING_GUOHALL/0","doc":"","ref":"Evision.Constant.html#cv_THINNING_GUOHALL/0"},{"type":"function","title":"Evision.Constant.cv_THINNING_ZHANGSUEN/0","doc":"","ref":"Evision.Constant.html#cv_THINNING_ZHANGSUEN/0"},{"type":"function","title":"Evision.Constant.cv_THIRD_ORDER_MOMENTS/0","doc":"","ref":"Evision.Constant.html#cv_THIRD_ORDER_MOMENTS/0"},{"type":"function","title":"Evision.Constant.cv_THRESH_BINARY/0","doc":"","ref":"Evision.Constant.html#cv_THRESH_BINARY/0"},{"type":"function","title":"Evision.Constant.cv_THRESH_BINARY_INV/0","doc":"","ref":"Evision.Constant.html#cv_THRESH_BINARY_INV/0"},{"type":"function","title":"Evision.Constant.cv_THRESH_MASK/0","doc":"","ref":"Evision.Constant.html#cv_THRESH_MASK/0"},{"type":"function","title":"Evision.Constant.cv_THRESH_OTSU/0","doc":"","ref":"Evision.Constant.html#cv_THRESH_OTSU/0"},{"type":"function","title":"Evision.Constant.cv_THRESH_TOZERO/0","doc":"","ref":"Evision.Constant.html#cv_THRESH_TOZERO/0"},{"type":"function","title":"Evision.Constant.cv_THRESH_TOZERO_INV/0","doc":"","ref":"Evision.Constant.html#cv_THRESH_TOZERO_INV/0"},{"type":"function","title":"Evision.Constant.cv_THRESH_TRIANGLE/0","doc":"","ref":"Evision.Constant.html#cv_THRESH_TRIANGLE/0"},{"type":"function","title":"Evision.Constant.cv_THRESH_TRUNC/0","doc":"","ref":"Evision.Constant.html#cv_THRESH_TRUNC/0"},{"type":"function","title":"Evision.Constant.cv_THRESHOLD/0","doc":"","ref":"Evision.Constant.html#cv_THRESHOLD/0"},{"type":"function","title":"Evision.Constant.cv_TM_CCOEFF/0","doc":"","ref":"Evision.Constant.html#cv_TM_CCOEFF/0"},{"type":"function","title":"Evision.Constant.cv_TM_CCOEFF_NORMED/0","doc":"","ref":"Evision.Constant.html#cv_TM_CCOEFF_NORMED/0"},{"type":"function","title":"Evision.Constant.cv_TM_CCORR/0","doc":"","ref":"Evision.Constant.html#cv_TM_CCORR/0"},{"type":"function","title":"Evision.Constant.cv_TM_CCORR_NORMED/0","doc":"","ref":"Evision.Constant.html#cv_TM_CCORR_NORMED/0"},{"type":"function","title":"Evision.Constant.cv_TM_SQDIFF/0","doc":"","ref":"Evision.Constant.html#cv_TM_SQDIFF/0"},{"type":"function","title":"Evision.Constant.cv_TM_SQDIFF_NORMED/0","doc":"","ref":"Evision.Constant.html#cv_TM_SQDIFF_NORMED/0"},{"type":"function","title":"Evision.Constant.cv_TRAIN_ERROR/0","doc":"","ref":"Evision.Constant.html#cv_TRAIN_ERROR/0"},{"type":"function","title":"Evision.Constant.cv_TRANSLATION/0","doc":"","ref":"Evision.Constant.html#cv_TRANSLATION/0"},{"type":"function","title":"Evision.Constant.cv_TRIANGLE_FAN/0","doc":"","ref":"Evision.Constant.html#cv_TRIANGLE_FAN/0"},{"type":"function","title":"Evision.Constant.cv_TRIANGLE_STRIP/0","doc":"","ref":"Evision.Constant.html#cv_TRIANGLE_STRIP/0"},{"type":"function","title":"Evision.Constant.cv_TRIANGLES/0","doc":"","ref":"Evision.Constant.html#cv_TRIANGLES/0"},{"type":"function","title":"Evision.Constant.cv_TrackerKCF_CUSTOM/0","doc":"","ref":"Evision.Constant.html#cv_TrackerKCF_CUSTOM/0"},{"type":"function","title":"Evision.Constant.cv_TrackerKCF_GRAY/0","doc":"","ref":"Evision.Constant.html#cv_TrackerKCF_GRAY/0"},{"type":"function","title":"Evision.Constant.cv_TSDF/0","doc":"","ref":"Evision.Constant.html#cv_TSDF/0"},{"type":"function","title":"Evision.Constant.cv_TYPE_5_8/0","doc":"","ref":"Evision.Constant.html#cv_TYPE_5_8/0"},{"type":"function","title":"Evision.Constant.cv_TYPE_7_12/0","doc":"","ref":"Evision.Constant.html#cv_TYPE_7_12/0"},{"type":"function","title":"Evision.Constant.cv_TYPE_9_16/0","doc":"","ref":"Evision.Constant.html#cv_TYPE_9_16/0"},{"type":"function","title":"Evision.Constant.cv_TYPE_ACCELERATOR/0","doc":"","ref":"Evision.Constant.html#cv_TYPE_ACCELERATOR/0"},{"type":"function","title":"Evision.Constant.cv_TYPE_ALL/0","doc":"","ref":"Evision.Constant.html#cv_TYPE_ALL/0"},{"type":"function","title":"Evision.Constant.cv_TYPE_CPU/0","doc":"","ref":"Evision.Constant.html#cv_TYPE_CPU/0"},{"type":"function","title":"Evision.Constant.cv_TYPE_DEFAULT/0","doc":"","ref":"Evision.Constant.html#cv_TYPE_DEFAULT/0"},{"type":"function","title":"Evision.Constant.cv_TYPE_DGPU/0","doc":"","ref":"Evision.Constant.html#cv_TYPE_DGPU/0"},{"type":"function","title":"Evision.Constant.cv_TYPE_GPU/0","doc":"","ref":"Evision.Constant.html#cv_TYPE_GPU/0"},{"type":"function","title":"Evision.Constant.cv_TYPE_IGPU/0","doc":"","ref":"Evision.Constant.html#cv_TYPE_IGPU/0"},{"type":"function","title":"Evision.Constant.cv_TYPE_MASK/0","doc":"","ref":"Evision.Constant.html#cv_TYPE_MASK/0"},{"type":"function","title":"Evision.Constant.cv_UCHAR/0","doc":"","ref":"Evision.Constant.html#cv_UCHAR/0"},{"type":"function","title":"Evision.Constant.cv_UINT64/0","doc":"","ref":"Evision.Constant.html#cv_UINT64/0"},{"type":"function","title":"Evision.Constant.cv_UMAT/0","doc":"","ref":"Evision.Constant.html#cv_UMAT/0"},{"type":"function","title":"Evision.Constant.cv_UMAT_USAGE_FLAGS_32BIT/0","doc":"","ref":"Evision.Constant.html#cv_UMAT_USAGE_FLAGS_32BIT/0"},{"type":"function","title":"Evision.Constant.cv_UNDEFINED/0","doc":"","ref":"Evision.Constant.html#cv_UNDEFINED/0"},{"type":"function","title":"Evision.Constant.cv_UNIFORM/0","doc":"","ref":"Evision.Constant.html#cv_UNIFORM/0"},{"type":"function","title":"Evision.Constant.cv_UNKNOWN_VENDOR/0","doc":"","ref":"Evision.Constant.html#cv_UNKNOWN_VENDOR/0"},{"type":"function","title":"Evision.Constant.cv_UNSIGNED_INT/0","doc":"","ref":"Evision.Constant.html#cv_UNSIGNED_INT/0"},{"type":"function","title":"Evision.Constant.cv_Uncompressed_NV12/0","doc":"","ref":"Evision.Constant.html#cv_Uncompressed_NV12/0"},{"type":"function","title":"Evision.Constant.cv_Uncompressed_UYVY/0","doc":"","ref":"Evision.Constant.html#cv_Uncompressed_UYVY/0"},{"type":"function","title":"Evision.Constant.cv_Uncompressed_YUV420/0","doc":"","ref":"Evision.Constant.html#cv_Uncompressed_YUV420/0"},{"type":"function","title":"Evision.Constant.cv_Uncompressed_YUYV/0","doc":"","ref":"Evision.Constant.html#cv_Uncompressed_YUYV/0"},{"type":"function","title":"Evision.Constant.cv_Uncompressed_YV12/0","doc":"","ref":"Evision.Constant.html#cv_Uncompressed_YV12/0"},{"type":"function","title":"Evision.Constant.cv_UPDATE_MODEL/0","doc":"","ref":"Evision.Constant.html#cv_UPDATE_MODEL/0"},{"type":"function","title":"Evision.Constant.cv_UPDATE_WEIGHTS/0","doc":"","ref":"Evision.Constant.html#cv_UPDATE_WEIGHTS/0"},{"type":"function","title":"Evision.Constant.cv_USAC_ACCURATE/0","doc":"","ref":"Evision.Constant.html#cv_USAC_ACCURATE/0"},{"type":"function","title":"Evision.Constant.cv_USAC_DEFAULT/0","doc":"","ref":"Evision.Constant.html#cv_USAC_DEFAULT/0"},{"type":"function","title":"Evision.Constant.cv_USAC_FAST/0","doc":"","ref":"Evision.Constant.html#cv_USAC_FAST/0"},{"type":"function","title":"Evision.Constant.cv_USAC_FM_8PTS/0","doc":"","ref":"Evision.Constant.html#cv_USAC_FM_8PTS/0"},{"type":"function","title":"Evision.Constant.cv_USAC_MAGSAC/0","doc":"","ref":"Evision.Constant.html#cv_USAC_MAGSAC/0"},{"type":"function","title":"Evision.Constant.cv_USAC_PARALLEL/0","doc":"","ref":"Evision.Constant.html#cv_USAC_PARALLEL/0"},{"type":"function","title":"Evision.Constant.cv_USAC_PROSAC/0","doc":"","ref":"Evision.Constant.html#cv_USAC_PROSAC/0"},{"type":"function","title":"Evision.Constant.cv_USAGE_ALLOCATE_DEVICE_MEMORY/0","doc":"","ref":"Evision.Constant.html#cv_USAGE_ALLOCATE_DEVICE_MEMORY/0"},{"type":"function","title":"Evision.Constant.cv_USAGE_ALLOCATE_HOST_MEMORY/0","doc":"","ref":"Evision.Constant.html#cv_USAGE_ALLOCATE_HOST_MEMORY/0"},{"type":"function","title":"Evision.Constant.cv_USAGE_ALLOCATE_SHARED_MEMORY/0","doc":"","ref":"Evision.Constant.html#cv_USAGE_ALLOCATE_SHARED_MEMORY/0"},{"type":"function","title":"Evision.Constant.cv_USAGE_DEFAULT/0","doc":"","ref":"Evision.Constant.html#cv_USAGE_DEFAULT/0"},{"type":"function","title":"Evision.Constant.cv_USE_AVG/0","doc":"","ref":"Evision.Constant.html#cv_USE_AVG/0"},{"type":"function","title":"Evision.Constant.cv_USER_ALLOCATED/0","doc":"","ref":"Evision.Constant.html#cv_USER_ALLOCATED/0"},{"type":"function","title":"Evision.Constant.cv_VALUE_EXPECTED/0","doc":"","ref":"Evision.Constant.html#cv_VALUE_EXPECTED/0"},{"type":"function","title":"Evision.Constant.cv_VAR_CATEGORICAL/0","doc":"","ref":"Evision.Constant.html#cv_VAR_CATEGORICAL/0"},{"type":"function","title":"Evision.Constant.cv_VAR_NUMERICAL/0","doc":"","ref":"Evision.Constant.html#cv_VAR_NUMERICAL/0"},{"type":"function","title":"Evision.Constant.cv_VAR_ORDERED/0","doc":"","ref":"Evision.Constant.html#cv_VAR_ORDERED/0"},{"type":"function","title":"Evision.Constant.cv_VC1/0","doc":"","ref":"Evision.Constant.html#cv_VC1/0"},{"type":"function","title":"Evision.Constant.cv_VENDOR_AMD/0","doc":"","ref":"Evision.Constant.html#cv_VENDOR_AMD/0"},{"type":"function","title":"Evision.Constant.cv_VENDOR_INTEL/0","doc":"","ref":"Evision.Constant.html#cv_VENDOR_INTEL/0"},{"type":"function","title":"Evision.Constant.cv_VENDOR_NVIDIA/0","doc":"","ref":"Evision.Constant.html#cv_VENDOR_NVIDIA/0"},{"type":"function","title":"Evision.Constant.cv_VIDEO_ACCELERATION_ANY/0","doc":"","ref":"Evision.Constant.html#cv_VIDEO_ACCELERATION_ANY/0"},{"type":"function","title":"Evision.Constant.cv_VIDEO_ACCELERATION_D3D11/0","doc":"","ref":"Evision.Constant.html#cv_VIDEO_ACCELERATION_D3D11/0"},{"type":"function","title":"Evision.Constant.cv_VIDEO_ACCELERATION_MFX/0","doc":"","ref":"Evision.Constant.html#cv_VIDEO_ACCELERATION_MFX/0"},{"type":"function","title":"Evision.Constant.cv_VIDEO_ACCELERATION_NONE/0","doc":"","ref":"Evision.Constant.html#cv_VIDEO_ACCELERATION_NONE/0"},{"type":"function","title":"Evision.Constant.cv_VIDEO_ACCELERATION_VAAPI/0","doc":"","ref":"Evision.Constant.html#cv_VIDEO_ACCELERATION_VAAPI/0"},{"type":"function","title":"Evision.Constant.cv_VIDEOWRITER_PROP_DEPTH/0","doc":"","ref":"Evision.Constant.html#cv_VIDEOWRITER_PROP_DEPTH/0"},{"type":"function","title":"Evision.Constant.cv_VIDEOWRITER_PROP_FRAMEBYTES/0","doc":"","ref":"Evision.Constant.html#cv_VIDEOWRITER_PROP_FRAMEBYTES/0"},{"type":"function","title":"Evision.Constant.cv_VIDEOWRITER_PROP_HW_ACCELERATION/0","doc":"","ref":"Evision.Constant.html#cv_VIDEOWRITER_PROP_HW_ACCELERATION/0"},{"type":"function","title":"Evision.Constant.cv_VIDEOWRITER_PROP_HW_ACCELERATION_USE_OPENCL/0","doc":"","ref":"Evision.Constant.html#cv_VIDEOWRITER_PROP_HW_ACCELERATION_USE_OPENCL/0"},{"type":"function","title":"Evision.Constant.cv_VIDEOWRITER_PROP_HW_DEVICE/0","doc":"","ref":"Evision.Constant.html#cv_VIDEOWRITER_PROP_HW_DEVICE/0"},{"type":"function","title":"Evision.Constant.cv_VIDEOWRITER_PROP_IS_COLOR/0","doc":"","ref":"Evision.Constant.html#cv_VIDEOWRITER_PROP_IS_COLOR/0"},{"type":"function","title":"Evision.Constant.cv_VIDEOWRITER_PROP_KEY_FLAG/0","doc":"","ref":"Evision.Constant.html#cv_VIDEOWRITER_PROP_KEY_FLAG/0"},{"type":"function","title":"Evision.Constant.cv_VIDEOWRITER_PROP_KEY_INTERVAL/0","doc":"","ref":"Evision.Constant.html#cv_VIDEOWRITER_PROP_KEY_INTERVAL/0"},{"type":"function","title":"Evision.Constant.cv_VIDEOWRITER_PROP_NSTRIPES/0","doc":"","ref":"Evision.Constant.html#cv_VIDEOWRITER_PROP_NSTRIPES/0"},{"type":"function","title":"Evision.Constant.cv_VIDEOWRITER_PROP_QUALITY/0","doc":"","ref":"Evision.Constant.html#cv_VIDEOWRITER_PROP_QUALITY/0"},{"type":"function","title":"Evision.Constant.cv_VIDEOWRITER_PROP_RAW_VIDEO/0","doc":"","ref":"Evision.Constant.html#cv_VIDEOWRITER_PROP_RAW_VIDEO/0"},{"type":"function","title":"Evision.Constant.cv_VINYL18/0","doc":"","ref":"Evision.Constant.html#cv_VINYL18/0"},{"type":"function","title":"Evision.Constant.cv_VideoReaderProps_PROP_NOT_SUPPORTED/0","doc":"","ref":"Evision.Constant.html#cv_VideoReaderProps_PROP_NOT_SUPPORTED/0"},{"type":"function","title":"Evision.Constant.cv_VORONOI_SEAM/0","doc":"","ref":"Evision.Constant.html#cv_VORONOI_SEAM/0"},{"type":"function","title":"Evision.Constant.cv_VP8/0","doc":"","ref":"Evision.Constant.html#cv_VP8/0"},{"type":"function","title":"Evision.Constant.cv_VP9/0","doc":"","ref":"Evision.Constant.html#cv_VP9/0"},{"type":"function","title":"Evision.Constant.cv_WARP_FILL_OUTLIERS/0","doc":"","ref":"Evision.Constant.html#cv_WARP_FILL_OUTLIERS/0"},{"type":"function","title":"Evision.Constant.cv_WARP_INVERSE_MAP/0","doc":"","ref":"Evision.Constant.html#cv_WARP_INVERSE_MAP/0"},{"type":"function","title":"Evision.Constant.cv_WARP_POLAR_LINEAR/0","doc":"","ref":"Evision.Constant.html#cv_WARP_POLAR_LINEAR/0"},{"type":"function","title":"Evision.Constant.cv_WARP_POLAR_LOG/0","doc":"","ref":"Evision.Constant.html#cv_WARP_POLAR_LOG/0"},{"type":"function","title":"Evision.Constant.cv_WARP_RELATIVE_MAP/0","doc":"","ref":"Evision.Constant.html#cv_WARP_RELATIVE_MAP/0"},{"type":"function","title":"Evision.Constant.cv_WARP_SHUFFLE_FUNCTIONS/0","doc":"","ref":"Evision.Constant.html#cv_WARP_SHUFFLE_FUNCTIONS/0"},{"type":"function","title":"Evision.Constant.cv_WAVE_CORRECT_AUTO/0","doc":"","ref":"Evision.Constant.html#cv_WAVE_CORRECT_AUTO/0"},{"type":"function","title":"Evision.Constant.cv_WAVE_CORRECT_HORIZ/0","doc":"","ref":"Evision.Constant.html#cv_WAVE_CORRECT_HORIZ/0"},{"type":"function","title":"Evision.Constant.cv_WAVE_CORRECT_VERT/0","doc":"","ref":"Evision.Constant.html#cv_WAVE_CORRECT_VERT/0"},{"type":"function","title":"Evision.Constant.cv_Weave/0","doc":"","ref":"Evision.Constant.html#cv_Weave/0"},{"type":"function","title":"Evision.Constant.cv_WINDOW_AUTOSIZE/0","doc":"","ref":"Evision.Constant.html#cv_WINDOW_AUTOSIZE/0"},{"type":"function","title":"Evision.Constant.cv_WINDOW_FREERATIO/0","doc":"","ref":"Evision.Constant.html#cv_WINDOW_FREERATIO/0"},{"type":"function","title":"Evision.Constant.cv_WINDOW_FULLSCREEN/0","doc":"","ref":"Evision.Constant.html#cv_WINDOW_FULLSCREEN/0"},{"type":"function","title":"Evision.Constant.cv_WINDOW_GUI_EXPANDED/0","doc":"","ref":"Evision.Constant.html#cv_WINDOW_GUI_EXPANDED/0"},{"type":"function","title":"Evision.Constant.cv_WINDOW_GUI_NORMAL/0","doc":"","ref":"Evision.Constant.html#cv_WINDOW_GUI_NORMAL/0"},{"type":"function","title":"Evision.Constant.cv_WINDOW_KEEPRATIO/0","doc":"","ref":"Evision.Constant.html#cv_WINDOW_KEEPRATIO/0"},{"type":"function","title":"Evision.Constant.cv_WINDOW_NORMAL/0","doc":"","ref":"Evision.Constant.html#cv_WINDOW_NORMAL/0"},{"type":"function","title":"Evision.Constant.cv_WINDOW_OPENGL/0","doc":"","ref":"Evision.Constant.html#cv_WINDOW_OPENGL/0"},{"type":"function","title":"Evision.Constant.cv_WMF_COS/0","doc":"","ref":"Evision.Constant.html#cv_WMF_COS/0"},{"type":"function","title":"Evision.Constant.cv_WMF_EXP/0","doc":"","ref":"Evision.Constant.html#cv_WMF_EXP/0"},{"type":"function","title":"Evision.Constant.cv_WMF_IV1/0","doc":"","ref":"Evision.Constant.html#cv_WMF_IV1/0"},{"type":"function","title":"Evision.Constant.cv_WMF_IV2/0","doc":"","ref":"Evision.Constant.html#cv_WMF_IV2/0"},{"type":"function","title":"Evision.Constant.cv_WMF_JAC/0","doc":"","ref":"Evision.Constant.html#cv_WMF_JAC/0"},{"type":"function","title":"Evision.Constant.cv_WMF_OFF/0","doc":"","ref":"Evision.Constant.html#cv_WMF_OFF/0"},{"type":"function","title":"Evision.Constant.cv_WND_PROP_ASPECT_RATIO/0","doc":"","ref":"Evision.Constant.html#cv_WND_PROP_ASPECT_RATIO/0"},{"type":"function","title":"Evision.Constant.cv_WND_PROP_AUTOSIZE/0","doc":"","ref":"Evision.Constant.html#cv_WND_PROP_AUTOSIZE/0"},{"type":"function","title":"Evision.Constant.cv_WND_PROP_FULLSCREEN/0","doc":"","ref":"Evision.Constant.html#cv_WND_PROP_FULLSCREEN/0"},{"type":"function","title":"Evision.Constant.cv_WND_PROP_OPENGL/0","doc":"","ref":"Evision.Constant.html#cv_WND_PROP_OPENGL/0"},{"type":"function","title":"Evision.Constant.cv_WND_PROP_TOPMOST/0","doc":"","ref":"Evision.Constant.html#cv_WND_PROP_TOPMOST/0"},{"type":"function","title":"Evision.Constant.cv_WND_PROP_VISIBLE/0","doc":"","ref":"Evision.Constant.html#cv_WND_PROP_VISIBLE/0"},{"type":"function","title":"Evision.Constant.cv_WND_PROP_VSYNC/0","doc":"","ref":"Evision.Constant.html#cv_WND_PROP_VSYNC/0"},{"type":"function","title":"Evision.Constant.cv_WRITE/0","doc":"","ref":"Evision.Constant.html#cv_WRITE/0"},{"type":"function","title":"Evision.Constant.cv_WRITE_BASE64/0","doc":"","ref":"Evision.Constant.html#cv_WRITE_BASE64/0"},{"type":"function","title":"Evision.Constant.cv_WRITE_COMBINED/0","doc":"","ref":"Evision.Constant.html#cv_WRITE_COMBINED/0"},{"type":"function","title":"Evision.Constant.cv_WRITE_ONLY/0","doc":"","ref":"Evision.Constant.html#cv_WRITE_ONLY/0"},{"type":"function","title":"Evision.Constant.cv_X_ROW/0","doc":"","ref":"Evision.Constant.html#cv_X_ROW/0"},{"type":"function","title":"Evision.Constant.cv_XYZ/0","doc":"","ref":"Evision.Constant.html#cv_XYZ/0"},{"type":"function","title":"Evision.Constant.cv_XYZRGB/0","doc":"","ref":"Evision.Constant.html#cv_XYZRGB/0"},{"type":"function","title":"Evision.Constant.cv_Y_ROW/0","doc":"","ref":"Evision.Constant.html#cv_Y_ROW/0"},{"type":"function","title":"Evision.Constant.cv_YUV420/0","doc":"","ref":"Evision.Constant.html#cv_YUV420/0"},{"type":"function","title":"Evision.Constant.cv_YUV422/0","doc":"","ref":"Evision.Constant.html#cv_YUV422/0"},{"type":"function","title":"Evision.Constant.cv_YUV444/0","doc":"","ref":"Evision.Constant.html#cv_YUV444/0"},{"type":"module","title":"Evision.ContourApproximationModes","doc":"","ref":"Evision.ContourApproximationModes.html"},{"type":"function","title":"Evision.ContourApproximationModes.cv_CHAIN_APPROX_NONE/0","doc":"","ref":"Evision.ContourApproximationModes.html#cv_CHAIN_APPROX_NONE/0"},{"type":"function","title":"Evision.ContourApproximationModes.cv_CHAIN_APPROX_SIMPLE/0","doc":"","ref":"Evision.ContourApproximationModes.html#cv_CHAIN_APPROX_SIMPLE/0"},{"type":"function","title":"Evision.ContourApproximationModes.cv_CHAIN_APPROX_TC89_KCOS/0","doc":"","ref":"Evision.ContourApproximationModes.html#cv_CHAIN_APPROX_TC89_KCOS/0"},{"type":"function","title":"Evision.ContourApproximationModes.cv_CHAIN_APPROX_TC89_L1/0","doc":"","ref":"Evision.ContourApproximationModes.html#cv_CHAIN_APPROX_TC89_L1/0"},{"type":"type","title":"Evision.ContourApproximationModes.enum/0","doc":"","ref":"Evision.ContourApproximationModes.html#t:enum/0"},{"type":"module","title":"Evision.CovarFlags","doc":"","ref":"Evision.CovarFlags.html"},{"type":"function","title":"Evision.CovarFlags.cv_COVAR_COLS/0","doc":"","ref":"Evision.CovarFlags.html#cv_COVAR_COLS/0"},{"type":"function","title":"Evision.CovarFlags.cv_COVAR_NORMAL/0","doc":"","ref":"Evision.CovarFlags.html#cv_COVAR_NORMAL/0"},{"type":"function","title":"Evision.CovarFlags.cv_COVAR_ROWS/0","doc":"","ref":"Evision.CovarFlags.html#cv_COVAR_ROWS/0"},{"type":"function","title":"Evision.CovarFlags.cv_COVAR_SCALE/0","doc":"","ref":"Evision.CovarFlags.html#cv_COVAR_SCALE/0"},{"type":"function","title":"Evision.CovarFlags.cv_COVAR_SCRAMBLED/0","doc":"","ref":"Evision.CovarFlags.html#cv_COVAR_SCRAMBLED/0"},{"type":"function","title":"Evision.CovarFlags.cv_COVAR_USE_AVG/0","doc":"","ref":"Evision.CovarFlags.html#cv_COVAR_USE_AVG/0"},{"type":"type","title":"Evision.CovarFlags.enum/0","doc":"","ref":"Evision.CovarFlags.html#t:enum/0"},{"type":"module","title":"Evision.DISOpticalFlow","doc":"","ref":"Evision.DISOpticalFlow.html"},{"type":"function","title":"Evision.DISOpticalFlow.create/0","doc":"Creates an instance of DISOpticalFlow\n##### Keyword Arguments\n- **preset**: `integer()`.\n\n  one of PRESET_ULTRAFAST, PRESET_FAST and PRESET_MEDIUM\n\n##### Return\n- **retval**: `Evision.DISOpticalFlow.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, preset]) -> retval\n```","ref":"Evision.DISOpticalFlow.html#create/0"},{"type":"function","title":"Evision.DISOpticalFlow.create/1","doc":"Creates an instance of DISOpticalFlow\n##### Keyword Arguments\n- **preset**: `integer()`.\n\n  one of PRESET_ULTRAFAST, PRESET_FAST and PRESET_MEDIUM\n\n##### Return\n- **retval**: `Evision.DISOpticalFlow.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, preset]) -> retval\n```","ref":"Evision.DISOpticalFlow.html#create/1"},{"type":"function","title":"Evision.DISOpticalFlow.cv_PRESET_FAST/0","doc":"","ref":"Evision.DISOpticalFlow.html#cv_PRESET_FAST/0"},{"type":"function","title":"Evision.DISOpticalFlow.cv_PRESET_MEDIUM/0","doc":"","ref":"Evision.DISOpticalFlow.html#cv_PRESET_MEDIUM/0"},{"type":"function","title":"Evision.DISOpticalFlow.cv_PRESET_ULTRAFAST/0","doc":"","ref":"Evision.DISOpticalFlow.html#cv_PRESET_ULTRAFAST/0"},{"type":"function","title":"Evision.DISOpticalFlow.getFinestScale/1","doc":"Finest level of the Gaussian pyramid on which the flow is computed (zero level\ncorresponds to the original image resolution). The final flow is obtained by bilinear upscaling.\n\n##### Positional Arguments\n- **self**: `Evision.DISOpticalFlow.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setFinestScale/2`\n\nPython prototype (for reference only):\n```python3\ngetFinestScale() -> retval\n```","ref":"Evision.DISOpticalFlow.html#getFinestScale/1"},{"type":"function","title":"Evision.DISOpticalFlow.getGradientDescentIterations/1","doc":"Maximum number of gradient descent iterations in the patch inverse search stage. Higher values\nmay improve quality in some cases.\n\n##### Positional Arguments\n- **self**: `Evision.DISOpticalFlow.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setGradientDescentIterations/2`\n\nPython prototype (for reference only):\n```python3\ngetGradientDescentIterations() -> retval\n```","ref":"Evision.DISOpticalFlow.html#getGradientDescentIterations/1"},{"type":"function","title":"Evision.DISOpticalFlow.getPatchSize/1","doc":"Size of an image patch for matching (in pixels). Normally, default 8x8 patches work well\nenough in most cases.\n\n##### Positional Arguments\n- **self**: `Evision.DISOpticalFlow.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setPatchSize/2`\n\nPython prototype (for reference only):\n```python3\ngetPatchSize() -> retval\n```","ref":"Evision.DISOpticalFlow.html#getPatchSize/1"},{"type":"function","title":"Evision.DISOpticalFlow.getPatchStride/1","doc":"Stride between neighbor patches. Must be less than patch size. Lower values correspond\nto higher flow quality.\n\n##### Positional Arguments\n- **self**: `Evision.DISOpticalFlow.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setPatchStride/2`\n\nPython prototype (for reference only):\n```python3\ngetPatchStride() -> retval\n```","ref":"Evision.DISOpticalFlow.html#getPatchStride/1"},{"type":"function","title":"Evision.DISOpticalFlow.getUseMeanNormalization/1","doc":"Whether to use mean-normalization of patches when computing patch distance. It is turned on\nby default as it typically provides a noticeable quality boost because of increased robustness to\nillumination variations. Turn it off if you are certain that your sequence doesn't contain any changes\nin illumination.\n\n##### Positional Arguments\n- **self**: `Evision.DISOpticalFlow.t()`\n\n##### Return\n- **retval**: `bool`\n\n@see `setUseMeanNormalization/2`\n\nPython prototype (for reference only):\n```python3\ngetUseMeanNormalization() -> retval\n```","ref":"Evision.DISOpticalFlow.html#getUseMeanNormalization/1"},{"type":"function","title":"Evision.DISOpticalFlow.getUseSpatialPropagation/1","doc":"Whether to use spatial propagation of good optical flow vectors. This option is turned on by\ndefault, as it tends to work better on average and can sometimes help recover from major errors\nintroduced by the coarse-to-fine scheme employed by the DIS optical flow algorithm. Turning this\noption off can make the output flow field a bit smoother, however.\n\n##### Positional Arguments\n- **self**: `Evision.DISOpticalFlow.t()`\n\n##### Return\n- **retval**: `bool`\n\n@see `setUseSpatialPropagation/2`\n\nPython prototype (for reference only):\n```python3\ngetUseSpatialPropagation() -> retval\n```","ref":"Evision.DISOpticalFlow.html#getUseSpatialPropagation/1"},{"type":"function","title":"Evision.DISOpticalFlow.getVariationalRefinementAlpha/1","doc":"Weight of the smoothness term\n\n##### Positional Arguments\n- **self**: `Evision.DISOpticalFlow.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setVariationalRefinementAlpha/2`\n\nPython prototype (for reference only):\n```python3\ngetVariationalRefinementAlpha() -> retval\n```","ref":"Evision.DISOpticalFlow.html#getVariationalRefinementAlpha/1"},{"type":"function","title":"Evision.DISOpticalFlow.getVariationalRefinementDelta/1","doc":"Weight of the color constancy term\n\n##### Positional Arguments\n- **self**: `Evision.DISOpticalFlow.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setVariationalRefinementDelta/2`\n\nPython prototype (for reference only):\n```python3\ngetVariationalRefinementDelta() -> retval\n```","ref":"Evision.DISOpticalFlow.html#getVariationalRefinementDelta/1"},{"type":"function","title":"Evision.DISOpticalFlow.getVariationalRefinementEpsilon/1","doc":"Norm value shift for robust penalizer\n\n##### Positional Arguments\n- **self**: `Evision.DISOpticalFlow.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setVariationalRefinementEpsilon/2`\n\nPython prototype (for reference only):\n```python3\ngetVariationalRefinementEpsilon() -> retval\n```","ref":"Evision.DISOpticalFlow.html#getVariationalRefinementEpsilon/1"},{"type":"function","title":"Evision.DISOpticalFlow.getVariationalRefinementGamma/1","doc":"Weight of the gradient constancy term\n\n##### Positional Arguments\n- **self**: `Evision.DISOpticalFlow.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setVariationalRefinementGamma/2`\n\nPython prototype (for reference only):\n```python3\ngetVariationalRefinementGamma() -> retval\n```","ref":"Evision.DISOpticalFlow.html#getVariationalRefinementGamma/1"},{"type":"function","title":"Evision.DISOpticalFlow.getVariationalRefinementIterations/1","doc":"Number of fixed point iterations of variational refinement per scale. Set to zero to\ndisable variational refinement completely. Higher values will typically result in more smooth and\nhigh-quality flow.\n\n##### Positional Arguments\n- **self**: `Evision.DISOpticalFlow.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setGradientDescentIterations/2`\n\nPython prototype (for reference only):\n```python3\ngetVariationalRefinementIterations() -> retval\n```","ref":"Evision.DISOpticalFlow.html#getVariationalRefinementIterations/1"},{"type":"function","title":"Evision.DISOpticalFlow.setFinestScale/1","doc":"","ref":"Evision.DISOpticalFlow.html#setFinestScale/1"},{"type":"function","title":"Evision.DISOpticalFlow.setFinestScale/2","doc":"setFinestScale\n\n##### Positional Arguments\n- **self**: `Evision.DISOpticalFlow.t()`\n- **val**: `integer()`\n\n@see `getFinestScale/1`\n\nPython prototype (for reference only):\n```python3\nsetFinestScale(val) -> None\n```","ref":"Evision.DISOpticalFlow.html#setFinestScale/2"},{"type":"function","title":"Evision.DISOpticalFlow.setGradientDescentIterations/1","doc":"","ref":"Evision.DISOpticalFlow.html#setGradientDescentIterations/1"},{"type":"function","title":"Evision.DISOpticalFlow.setGradientDescentIterations/2","doc":"setGradientDescentIterations\n\n##### Positional Arguments\n- **self**: `Evision.DISOpticalFlow.t()`\n- **val**: `integer()`\n\n@see `getGradientDescentIterations/1`\n\nPython prototype (for reference only):\n```python3\nsetGradientDescentIterations(val) -> None\n```","ref":"Evision.DISOpticalFlow.html#setGradientDescentIterations/2"},{"type":"function","title":"Evision.DISOpticalFlow.setPatchSize/1","doc":"","ref":"Evision.DISOpticalFlow.html#setPatchSize/1"},{"type":"function","title":"Evision.DISOpticalFlow.setPatchSize/2","doc":"setPatchSize\n\n##### Positional Arguments\n- **self**: `Evision.DISOpticalFlow.t()`\n- **val**: `integer()`\n\n@see `getPatchSize/1`\n\nPython prototype (for reference only):\n```python3\nsetPatchSize(val) -> None\n```","ref":"Evision.DISOpticalFlow.html#setPatchSize/2"},{"type":"function","title":"Evision.DISOpticalFlow.setPatchStride/1","doc":"","ref":"Evision.DISOpticalFlow.html#setPatchStride/1"},{"type":"function","title":"Evision.DISOpticalFlow.setPatchStride/2","doc":"setPatchStride\n\n##### Positional Arguments\n- **self**: `Evision.DISOpticalFlow.t()`\n- **val**: `integer()`\n\n@see `getPatchStride/1`\n\nPython prototype (for reference only):\n```python3\nsetPatchStride(val) -> None\n```","ref":"Evision.DISOpticalFlow.html#setPatchStride/2"},{"type":"function","title":"Evision.DISOpticalFlow.setUseMeanNormalization/1","doc":"","ref":"Evision.DISOpticalFlow.html#setUseMeanNormalization/1"},{"type":"function","title":"Evision.DISOpticalFlow.setUseMeanNormalization/2","doc":"setUseMeanNormalization\n\n##### Positional Arguments\n- **self**: `Evision.DISOpticalFlow.t()`\n- **val**: `bool`\n\n@see `getUseMeanNormalization/1`\n\nPython prototype (for reference only):\n```python3\nsetUseMeanNormalization(val) -> None\n```","ref":"Evision.DISOpticalFlow.html#setUseMeanNormalization/2"},{"type":"function","title":"Evision.DISOpticalFlow.setUseSpatialPropagation/1","doc":"","ref":"Evision.DISOpticalFlow.html#setUseSpatialPropagation/1"},{"type":"function","title":"Evision.DISOpticalFlow.setUseSpatialPropagation/2","doc":"setUseSpatialPropagation\n\n##### Positional Arguments\n- **self**: `Evision.DISOpticalFlow.t()`\n- **val**: `bool`\n\n@see `getUseSpatialPropagation/1`\n\nPython prototype (for reference only):\n```python3\nsetUseSpatialPropagation(val) -> None\n```","ref":"Evision.DISOpticalFlow.html#setUseSpatialPropagation/2"},{"type":"function","title":"Evision.DISOpticalFlow.setVariationalRefinementAlpha/1","doc":"","ref":"Evision.DISOpticalFlow.html#setVariationalRefinementAlpha/1"},{"type":"function","title":"Evision.DISOpticalFlow.setVariationalRefinementAlpha/2","doc":"setVariationalRefinementAlpha\n\n##### Positional Arguments\n- **self**: `Evision.DISOpticalFlow.t()`\n- **val**: `float`\n\n@see `getVariationalRefinementAlpha/1`\n\nPython prototype (for reference only):\n```python3\nsetVariationalRefinementAlpha(val) -> None\n```","ref":"Evision.DISOpticalFlow.html#setVariationalRefinementAlpha/2"},{"type":"function","title":"Evision.DISOpticalFlow.setVariationalRefinementDelta/1","doc":"","ref":"Evision.DISOpticalFlow.html#setVariationalRefinementDelta/1"},{"type":"function","title":"Evision.DISOpticalFlow.setVariationalRefinementDelta/2","doc":"setVariationalRefinementDelta\n\n##### Positional Arguments\n- **self**: `Evision.DISOpticalFlow.t()`\n- **val**: `float`\n\n@see `getVariationalRefinementDelta/1`\n\nPython prototype (for reference only):\n```python3\nsetVariationalRefinementDelta(val) -> None\n```","ref":"Evision.DISOpticalFlow.html#setVariationalRefinementDelta/2"},{"type":"function","title":"Evision.DISOpticalFlow.setVariationalRefinementEpsilon/1","doc":"","ref":"Evision.DISOpticalFlow.html#setVariationalRefinementEpsilon/1"},{"type":"function","title":"Evision.DISOpticalFlow.setVariationalRefinementEpsilon/2","doc":"setVariationalRefinementEpsilon\n\n##### Positional Arguments\n- **self**: `Evision.DISOpticalFlow.t()`\n- **val**: `float`\n\n@see `getVariationalRefinementEpsilon/1`\n\nPython prototype (for reference only):\n```python3\nsetVariationalRefinementEpsilon(val) -> None\n```","ref":"Evision.DISOpticalFlow.html#setVariationalRefinementEpsilon/2"},{"type":"function","title":"Evision.DISOpticalFlow.setVariationalRefinementGamma/1","doc":"","ref":"Evision.DISOpticalFlow.html#setVariationalRefinementGamma/1"},{"type":"function","title":"Evision.DISOpticalFlow.setVariationalRefinementGamma/2","doc":"setVariationalRefinementGamma\n\n##### Positional Arguments\n- **self**: `Evision.DISOpticalFlow.t()`\n- **val**: `float`\n\n@see `getVariationalRefinementGamma/1`\n\nPython prototype (for reference only):\n```python3\nsetVariationalRefinementGamma(val) -> None\n```","ref":"Evision.DISOpticalFlow.html#setVariationalRefinementGamma/2"},{"type":"function","title":"Evision.DISOpticalFlow.setVariationalRefinementIterations/1","doc":"","ref":"Evision.DISOpticalFlow.html#setVariationalRefinementIterations/1"},{"type":"function","title":"Evision.DISOpticalFlow.setVariationalRefinementIterations/2","doc":"setVariationalRefinementIterations\n\n##### Positional Arguments\n- **self**: `Evision.DISOpticalFlow.t()`\n- **val**: `integer()`\n\n@see `getGradientDescentIterations/1`\n\nPython prototype (for reference only):\n```python3\nsetVariationalRefinementIterations(val) -> None\n```","ref":"Evision.DISOpticalFlow.html#setVariationalRefinementIterations/2"},{"type":"type","title":"Evision.DISOpticalFlow.enum/0","doc":"","ref":"Evision.DISOpticalFlow.html#t:enum/0"},{"type":"type","title":"Evision.DISOpticalFlow.t/0","doc":"Type that represents an `DISOpticalFlow` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.DISOpticalFlow.html#t:t/0"},{"type":"module","title":"Evision.DMatch","doc":"","ref":"Evision.DMatch.html"},{"type":"function","title":"Evision.DMatch.dMatcher/0","doc":"DMatch\n##### Return\n- **self**: `Evision.DMatch.t()`\n\nPython prototype (for reference only):\n```python3\nDMatch() ->  \n```","ref":"Evision.DMatch.html#dMatcher/0"},{"type":"function","title":"Evision.DMatch.dMatcher/1","doc":"","ref":"Evision.DMatch.html#dMatcher/1"},{"type":"function","title":"Evision.DMatch.dMatcher/3","doc":"DMatch\n\n##### Positional Arguments\n- **queryIdx**: `integer()`\n- **trainIdx**: `integer()`\n- **distance**: `float`\n\n##### Return\n- **self**: `Evision.DMatch.t()`\n\nPython prototype (for reference only):\n```python3\nDMatch(_queryIdx, _trainIdx, _distance) ->  \n```","ref":"Evision.DMatch.html#dMatcher/3"},{"type":"function","title":"Evision.DMatch.dMatcher/4","doc":"DMatch\n\n##### Positional Arguments\n- **queryIdx**: `integer()`\n- **trainIdx**: `integer()`\n- **imgIdx**: `integer()`\n- **distance**: `float`\n\n##### Return\n- **self**: `Evision.DMatch.t()`\n\nPython prototype (for reference only):\n```python3\nDMatch(_queryIdx, _trainIdx, _imgIdx, _distance) ->  \n```","ref":"Evision.DMatch.html#dMatcher/4"},{"type":"function","title":"Evision.DMatch.get_distance/1","doc":"","ref":"Evision.DMatch.html#get_distance/1"},{"type":"function","title":"Evision.DMatch.get_imgIdx/1","doc":"","ref":"Evision.DMatch.html#get_imgIdx/1"},{"type":"function","title":"Evision.DMatch.get_queryIdx/1","doc":"","ref":"Evision.DMatch.html#get_queryIdx/1"},{"type":"function","title":"Evision.DMatch.get_trainIdx/1","doc":"","ref":"Evision.DMatch.html#get_trainIdx/1"},{"type":"function","title":"Evision.DMatch.set_distance/2","doc":"","ref":"Evision.DMatch.html#set_distance/2"},{"type":"function","title":"Evision.DMatch.set_imgIdx/2","doc":"","ref":"Evision.DMatch.html#set_imgIdx/2"},{"type":"function","title":"Evision.DMatch.set_queryIdx/2","doc":"","ref":"Evision.DMatch.html#set_queryIdx/2"},{"type":"function","title":"Evision.DMatch.set_trainIdx/2","doc":"","ref":"Evision.DMatch.html#set_trainIdx/2"},{"type":"type","title":"Evision.DMatch.t/0","doc":"Type that represents an `DMatch` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.DMatch.html#t:t/0"},{"type":"module","title":"Evision.DNN","doc":"","ref":"Evision.DNN.html"},{"type":"function","title":"Evision.DNN.blobFromImage/1","doc":"Creates 4-dimensional blob from image. Optionally resizes and crops @p image from center,\nsubtract @p mean values, scales values by @p scalefactor, swap Blue and Red channels.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  input image (with 1-, 3- or 4-channels).\n\n##### Keyword Arguments\n- **scalefactor**: `double`.\n\n  multiplier for @p images values.\n\n- **size**: `Size`.\n\n  spatial size for output image\n\n- **mean**: `Evision.scalar()`.\n\n  scalar with mean values which are subtracted from channels. Values are intended\n  to be in (mean-R, mean-G, mean-B) order if @p image has BGR ordering and @p swapRB is true.\n\n- **swapRB**: `bool`.\n\n  flag which indicates that swap first and last channels\n  in 3-channel image is necessary.\n\n- **crop**: `bool`.\n\n  flag which indicates whether image will be cropped after resize or not\n\n- **ddepth**: `integer()`.\n\n  Depth of output blob. Choose CV_32F or CV_8U.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n@details if @p crop is true, input image is resized so one side after resize is equal to corresponding\n  dimension in @p size and another one is equal or larger. Then, crop from the center is performed.\n  If @p crop is false, direct resize without cropping and preserving aspect ratio is performed.\n@returns 4-dimensional Mat with NCHW dimensions order.\n**Note**: \n The order and usage of `scalefactor` and `mean` are (input - mean) * scalefactor.\n\nPython prototype (for reference only):\n```python3\nblobFromImage(image[, scalefactor[, size[, mean[, swapRB[, crop[, ddepth]]]]]]) -> retval\n```","ref":"Evision.DNN.html#blobFromImage/1"},{"type":"function","title":"Evision.DNN.blobFromImage/2","doc":"Creates 4-dimensional blob from image. Optionally resizes and crops @p image from center,\nsubtract @p mean values, scales values by @p scalefactor, swap Blue and Red channels.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  input image (with 1-, 3- or 4-channels).\n\n##### Keyword Arguments\n- **scalefactor**: `double`.\n\n  multiplier for @p images values.\n\n- **size**: `Size`.\n\n  spatial size for output image\n\n- **mean**: `Evision.scalar()`.\n\n  scalar with mean values which are subtracted from channels. Values are intended\n  to be in (mean-R, mean-G, mean-B) order if @p image has BGR ordering and @p swapRB is true.\n\n- **swapRB**: `bool`.\n\n  flag which indicates that swap first and last channels\n  in 3-channel image is necessary.\n\n- **crop**: `bool`.\n\n  flag which indicates whether image will be cropped after resize or not\n\n- **ddepth**: `integer()`.\n\n  Depth of output blob. Choose CV_32F or CV_8U.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n@details if @p crop is true, input image is resized so one side after resize is equal to corresponding\n  dimension in @p size and another one is equal or larger. Then, crop from the center is performed.\n  If @p crop is false, direct resize without cropping and preserving aspect ratio is performed.\n@returns 4-dimensional Mat with NCHW dimensions order.\n**Note**: \n The order and usage of `scalefactor` and `mean` are (input - mean) * scalefactor.\n\nPython prototype (for reference only):\n```python3\nblobFromImage(image[, scalefactor[, size[, mean[, swapRB[, crop[, ddepth]]]]]]) -> retval\n```","ref":"Evision.DNN.html#blobFromImage/2"},{"type":"function","title":"Evision.DNN.blobFromImages/1","doc":"Creates 4-dimensional blob from series of images. Optionally resizes and\ncrops @p images from center, subtract @p mean values, scales values by @p scalefactor,\nswap Blue and Red channels.\n\n##### Positional Arguments\n- **images**: `[Evision.Mat]`.\n\n  input images (all with 1-, 3- or 4-channels).\n\n##### Keyword Arguments\n- **scalefactor**: `double`.\n\n  multiplier for @p images values.\n\n- **size**: `Size`.\n\n  spatial size for output image\n\n- **mean**: `Evision.scalar()`.\n\n  scalar with mean values which are subtracted from channels. Values are intended\n  to be in (mean-R, mean-G, mean-B) order if @p image has BGR ordering and @p swapRB is true.\n\n- **swapRB**: `bool`.\n\n  flag which indicates that swap first and last channels\n  in 3-channel image is necessary.\n\n- **crop**: `bool`.\n\n  flag which indicates whether image will be cropped after resize or not\n\n- **ddepth**: `integer()`.\n\n  Depth of output blob. Choose CV_32F or CV_8U.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n@details if @p crop is true, input image is resized so one side after resize is equal to corresponding\n  dimension in @p size and another one is equal or larger. Then, crop from the center is performed.\n  If @p crop is false, direct resize without cropping and preserving aspect ratio is performed.\n@returns 4-dimensional Mat with NCHW dimensions order.\n**Note**: \n The order and usage of `scalefactor` and `mean` are (input - mean) * scalefactor.\n\nPython prototype (for reference only):\n```python3\nblobFromImages(images[, scalefactor[, size[, mean[, swapRB[, crop[, ddepth]]]]]]) -> retval\n```","ref":"Evision.DNN.html#blobFromImages/1"},{"type":"function","title":"Evision.DNN.blobFromImages/2","doc":"Creates 4-dimensional blob from series of images. Optionally resizes and\ncrops @p images from center, subtract @p mean values, scales values by @p scalefactor,\nswap Blue and Red channels.\n\n##### Positional Arguments\n- **images**: `[Evision.Mat]`.\n\n  input images (all with 1-, 3- or 4-channels).\n\n##### Keyword Arguments\n- **scalefactor**: `double`.\n\n  multiplier for @p images values.\n\n- **size**: `Size`.\n\n  spatial size for output image\n\n- **mean**: `Evision.scalar()`.\n\n  scalar with mean values which are subtracted from channels. Values are intended\n  to be in (mean-R, mean-G, mean-B) order if @p image has BGR ordering and @p swapRB is true.\n\n- **swapRB**: `bool`.\n\n  flag which indicates that swap first and last channels\n  in 3-channel image is necessary.\n\n- **crop**: `bool`.\n\n  flag which indicates whether image will be cropped after resize or not\n\n- **ddepth**: `integer()`.\n\n  Depth of output blob. Choose CV_32F or CV_8U.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n@details if @p crop is true, input image is resized so one side after resize is equal to corresponding\n  dimension in @p size and another one is equal or larger. Then, crop from the center is performed.\n  If @p crop is false, direct resize without cropping and preserving aspect ratio is performed.\n@returns 4-dimensional Mat with NCHW dimensions order.\n**Note**: \n The order and usage of `scalefactor` and `mean` are (input - mean) * scalefactor.\n\nPython prototype (for reference only):\n```python3\nblobFromImages(images[, scalefactor[, size[, mean[, swapRB[, crop[, ddepth]]]]]]) -> retval\n```","ref":"Evision.DNN.html#blobFromImages/2"},{"type":"function","title":"Evision.DNN.blobFromImagesWithParams/1","doc":"blobFromImagesWithParams\n\n##### Positional Arguments\n- **images**: `[Evision.Mat]`\n\n##### Keyword Arguments\n- **param**: `Image2BlobParams`.\n\n##### Return\n- **blob**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nblobFromImagesWithParams(images[, blob[, param]]) -> blob\n```","ref":"Evision.DNN.html#blobFromImagesWithParams/1"},{"type":"function","title":"Evision.DNN.blobFromImagesWithParams/2","doc":"blobFromImagesWithParams\n\n##### Positional Arguments\n- **images**: `[Evision.Mat]`\n\n##### Keyword Arguments\n- **param**: `Image2BlobParams`.\n\n##### Return\n- **blob**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nblobFromImagesWithParams(images[, blob[, param]]) -> blob\n```","ref":"Evision.DNN.html#blobFromImagesWithParams/2"},{"type":"function","title":"Evision.DNN.blobFromImageWithParams/1","doc":"blobFromImageWithParams\n\n##### Positional Arguments\n- **image**: `Evision.Mat`\n\n##### Keyword Arguments\n- **param**: `Image2BlobParams`.\n\n##### Return\n- **blob**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nblobFromImageWithParams(image[, blob[, param]]) -> blob\n```","ref":"Evision.DNN.html#blobFromImageWithParams/1"},{"type":"function","title":"Evision.DNN.blobFromImageWithParams/2","doc":"blobFromImageWithParams\n\n##### Positional Arguments\n- **image**: `Evision.Mat`\n\n##### Keyword Arguments\n- **param**: `Image2BlobParams`.\n\n##### Return\n- **blob**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nblobFromImageWithParams(image[, blob[, param]]) -> blob\n```","ref":"Evision.DNN.html#blobFromImageWithParams/2"},{"type":"function","title":"Evision.DNN.getAvailableTargets/1","doc":"getAvailableTargets\n\n##### Positional Arguments\n- **be**: `dnn_Backend`\n\n##### Return\n- **retval**: `[Target]`\n\nPython prototype (for reference only):\n```python3\ngetAvailableTargets(be) -> retval\n```","ref":"Evision.DNN.html#getAvailableTargets/1"},{"type":"function","title":"Evision.DNN.imagesFromBlob/1","doc":"Parse a 4D blob and output the images it contains as 2D arrays through a simpler data structure\n(std::vector ).\n\n##### Positional Arguments\n- **blob_**: `Evision.Mat`.\n\n  4 dimensional array (images, channels, height, width) in floating point precision (CV_32F) from\n  which you would like to extract the images.\n\n##### Return\n- **images_**: `[Evision.Mat]`.\n\n  array of 2D Mat containing the images extracted from the blob in floating point precision\n  (CV_32F). They are non normalized neither mean added. The number of returned images equals the first dimension\n  of the blob (batch size). Every image has a number of channels equals to the second dimension of the blob (depth).\n\nPython prototype (for reference only):\n```python3\nimagesFromBlob(blob_[, images_]) -> images_\n```","ref":"Evision.DNN.html#imagesFromBlob/1"},{"type":"function","title":"Evision.DNN.imagesFromBlob/2","doc":"Parse a 4D blob and output the images it contains as 2D arrays through a simpler data structure\n(std::vector ).\n\n##### Positional Arguments\n- **blob_**: `Evision.Mat`.\n\n  4 dimensional array (images, channels, height, width) in floating point precision (CV_32F) from\n  which you would like to extract the images.\n\n##### Return\n- **images_**: `[Evision.Mat]`.\n\n  array of 2D Mat containing the images extracted from the blob in floating point precision\n  (CV_32F). They are non normalized neither mean added. The number of returned images equals the first dimension\n  of the blob (batch size). Every image has a number of channels equals to the second dimension of the blob (depth).\n\nPython prototype (for reference only):\n```python3\nimagesFromBlob(blob_[, images_]) -> images_\n```","ref":"Evision.DNN.html#imagesFromBlob/2"},{"type":"function","title":"Evision.DNN.nmsBoxes/4","doc":"Performs non maximum suppression given boxes and corresponding scores.\n\n##### Positional Arguments\n- **bboxes**: `[Rect2d]`, `Nx.Tensor.t()`, `Evision.Mat.t()`..\n\n    a set of bounding boxes to apply NMS.\n\n- **scores**: `[float]`.\n\n    a set of corresponding confidences.\n\n- **score_threshold**: `float`.\n\n    a threshold used to filter boxes by score.\n\n- **nms_threshold**: `float`.\n\n    a threshold used in non maximum suppression.\n\n##### Keyword Arguments\n- **eta**: `float`.\n\n    a coefficient in adaptive threshold formula: \f$nms_threshold_{i+1}=etacdot nms_threshold_i\f$.\n\n- **top_k**: `int`.\n\n    if `>0`, keep at most @p top_k picked indices.\n\n##### Return\n- **indices**: `[int]`.\n\n    the kept indices of bboxes after NMS.\n\nPython prototype (for reference only):\n```python3\nNMSBoxes(bboxes, scores, score_threshold, nms_threshold[, eta[, top_k]]) -> indices\n```","ref":"Evision.DNN.html#nmsBoxes/4"},{"type":"function","title":"Evision.DNN.nmsBoxes/5","doc":"Performs non maximum suppression given boxes and corresponding scores.\n\n##### Positional Arguments\n- **bboxes**: `[Rect2d]`, `Nx.Tensor.t()`, `Evision.Mat.t()`.\n\n    a set of bounding boxes to apply NMS.\n\n- **scores**: `[float]`.\n\n    a set of corresponding confidences.\n\n- **score_threshold**: `float`.\n\n    a threshold used to filter boxes by score.\n\n- **nms_threshold**: `float`.\n\n    a threshold used in non maximum suppression.\n\n##### Keyword Arguments\n- **eta**: `float`.\n\n    a coefficient in adaptive threshold formula: \f$nms_threshold_{i+1}=etacdot nms_threshold_i\f$.\n\n- **top_k**: `int`.\n\n    if `>0`, keep at most @p top_k picked indices.\n\n##### Return\n- **indices**: `[int]`.\n\n    the kept indices of bboxes after NMS.\n\nPython prototype (for reference only):\n```python3\nNMSBoxes(bboxes, scores, score_threshold, nms_threshold[, eta[, top_k]]) -> indices\n```","ref":"Evision.DNN.html#nmsBoxes/5"},{"type":"function","title":"Evision.DNN.nmsBoxesBatched/5","doc":"Performs batched non maximum suppression on given boxes and corresponding scores across different classes.\n\n##### Positional Arguments\n- **bboxes**: `[Rect2d]`, `Nx.Tensor.t()`, `Evision.Mat.t()`.\n\n  a set of bounding boxes to apply NMS.\n\n- **scores**: `[float]`.\n\n  a set of corresponding confidences.\n\n- **class_ids**: `[int]`.\n\n  a set of corresponding class ids. Ids are integer and usually start from 0.\n\n- **score_threshold**: `float`.\n\n  a threshold used to filter boxes by score.\n\n- **nms_threshold**: `float`.\n\n  a threshold used in non maximum suppression.\n\n##### Keyword Arguments\n- **eta**: `float`.\n\n  a coefficient in adaptive threshold formula: \f$nms_threshold_{i+1}=etacdot nms_threshold_i\f$.\n\n- **top_k**: `int`.\n\n  if `>0`, keep at most @p top_k picked indices.\n\n##### Return\n- **indices**: `[int]`.\n\n  the kept indices of bboxes after NMS.\n\nPython prototype (for reference only):\n```python3\nNMSBoxesBatched(bboxes, scores, class_ids, score_threshold, nms_threshold[, eta[, top_k]]) -> indices\n```","ref":"Evision.DNN.html#nmsBoxesBatched/5"},{"type":"function","title":"Evision.DNN.nmsBoxesBatched/6","doc":"Performs batched non maximum suppression on given boxes and corresponding scores across different classes.\n\n##### Positional Arguments\n- **bboxes**: `[Rect2d]`, `Nx.Tensor.t()`, `Evision.Mat.t()`.\n\n  a set of bounding boxes to apply NMS.\n\n- **scores**: `[float]`.\n\n  a set of corresponding confidences.\n\n- **class_ids**: `[int]`.\n\n  a set of corresponding class ids. Ids are integer and usually start from 0.\n\n- **score_threshold**: `float`.\n\n  a threshold used to filter boxes by score.\n\n- **nms_threshold**: `float`.\n\n  a threshold used in non maximum suppression.\n\n##### Keyword Arguments\n- **eta**: `float`.\n\n  a coefficient in adaptive threshold formula: \f$nms_threshold_{i+1}=etacdot nms_threshold_i\f$.\n\n- **top_k**: `int`.\n\n  if `>0`, keep at most @p top_k picked indices.\n\n##### Return\n- **indices**: `[int]`.\n\n  the kept indices of bboxes after NMS.\n\nPython prototype (for reference only):\n```python3\nNMSBoxesBatched(bboxes, scores, class_ids, score_threshold, nms_threshold[, eta[, top_k]]) -> indices\n```","ref":"Evision.DNN.html#nmsBoxesBatched/6"},{"type":"function","title":"Evision.DNN.nmsBoxesRotated/1","doc":"","ref":"Evision.DNN.html#nmsBoxesRotated/1"},{"type":"function","title":"Evision.DNN.nmsBoxesRotated/4","doc":"NMSBoxesRotated\n\n##### Positional Arguments\n- **bboxes**: `[{centre={x, y}, size={s1, s2}, angle}]`\n- **scores**: `[float]`\n- **score_threshold**: `float`\n- **nms_threshold**: `float`\n\n##### Keyword Arguments\n- **eta**: `float`.\n- **top_k**: `integer()`.\n\n##### Return\n- **indices**: `[integer()]`\n\nPython prototype (for reference only):\n```python3\nNMSBoxesRotated(bboxes, scores, score_threshold, nms_threshold[, eta[, top_k]]) -> indices\n```","ref":"Evision.DNN.html#nmsBoxesRotated/4"},{"type":"function","title":"Evision.DNN.nmsBoxesRotated/5","doc":"NMSBoxesRotated\n\n##### Positional Arguments\n- **bboxes**: `[{centre={x, y}, size={s1, s2}, angle}]`\n- **scores**: `[float]`\n- **score_threshold**: `float`\n- **nms_threshold**: `float`\n\n##### Keyword Arguments\n- **eta**: `float`.\n- **top_k**: `integer()`.\n\n##### Return\n- **indices**: `[integer()]`\n\nPython prototype (for reference only):\n```python3\nNMSBoxesRotated(bboxes, scores, score_threshold, nms_threshold[, eta[, top_k]]) -> indices\n```","ref":"Evision.DNN.html#nmsBoxesRotated/5"},{"type":"function","title":"Evision.DNN.readNet/1","doc":"Read deep learning network represented in one of the supported formats.\n\n##### Positional Arguments\n- **model**: `String`.\n\n  Binary file contains trained weights. The following file\n  extensions are expected for models from different frameworks:\n  * `*.caffemodel` (Caffe, http://caffe.berkeleyvision.org/)\n    * `*.pb` (TensorFlow, https://www.tensorflow.org/)\n      * `*.t7` | `*.net` (Torch, http://torch.ch/)\n        * `*.weights` (Darknet, https://pjreddie.com/darknet/)\n          * `*.bin` | `*.onnx` (OpenVINO, https://software.intel.com/openvino-toolkit)\n            * `*.onnx` (ONNX, https://onnx.ai/)\n\n##### Keyword Arguments\n- **config**: `String`.\n\n  Text file contains network configuration. It could be a\n  file with the following extensions:\n  * `*.prototxt` (Caffe, http://caffe.berkeleyvision.org/)\n    * `*.pbtxt` (TensorFlow, https://www.tensorflow.org/)\n      * `*.cfg` (Darknet, https://pjreddie.com/darknet/)\n        * `*.xml` (OpenVINO, https://software.intel.com/openvino-toolkit)\n\n- **framework**: `String`.\n\n  Explicit framework name tag to determine a format.\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Net object.\n This function automatically detects an origin framework of trained model\n and calls an appropriate function such @ref readNetFromCaffe, @ref readNetFromTensorflow,\n@ref readNetFromTorch or @ref readNetFromDarknet. An order of @p model and @p config\n arguments does not matter.\n\nPython prototype (for reference only):\n```python3\nreadNet(model[, config[, framework]]) -> retval\n```","ref":"Evision.DNN.html#readNet/1"},{"type":"function","title":"Evision.DNN.readNet/2","doc":"#### Variant 1:\nRead deep learning network represented in one of the supported formats.\n\n##### Positional Arguments\n- **framework**: `String`.\n\n  Name of origin framework.\n\n- **bufferModel**: `[uchar]`.\n\n  A buffer with a content of binary file with weights\n\n##### Keyword Arguments\n- **bufferConfig**: `[uchar]`.\n\n  A buffer with a content of text file contains network configuration.\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@details This is an overloaded member function, provided for convenience.\n          It differs from the above function only in what argument(s) it accepts.\n@returns Net object.\n\nPython prototype (for reference only):\n```python3\nreadNet(framework, bufferModel[, bufferConfig]) -> retval\n```\n#### Variant 2:\nRead deep learning network represented in one of the supported formats.\n\n##### Positional Arguments\n- **model**: `String`.\n\n  Binary file contains trained weights. The following file\n  extensions are expected for models from different frameworks:\n  * `*.caffemodel` (Caffe, http://caffe.berkeleyvision.org/)\n    * `*.pb` (TensorFlow, https://www.tensorflow.org/)\n      * `*.t7` | `*.net` (Torch, http://torch.ch/)\n        * `*.weights` (Darknet, https://pjreddie.com/darknet/)\n          * `*.bin` | `*.onnx` (OpenVINO, https://software.intel.com/openvino-toolkit)\n            * `*.onnx` (ONNX, https://onnx.ai/)\n\n##### Keyword Arguments\n- **config**: `String`.\n\n  Text file contains network configuration. It could be a\n  file with the following extensions:\n  * `*.prototxt` (Caffe, http://caffe.berkeleyvision.org/)\n    * `*.pbtxt` (TensorFlow, https://www.tensorflow.org/)\n      * `*.cfg` (Darknet, https://pjreddie.com/darknet/)\n        * `*.xml` (OpenVINO, https://software.intel.com/openvino-toolkit)\n\n- **framework**: `String`.\n\n  Explicit framework name tag to determine a format.\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Net object.\n This function automatically detects an origin framework of trained model\n and calls an appropriate function such @ref readNetFromCaffe, @ref readNetFromTensorflow,\n@ref readNetFromTorch or @ref readNetFromDarknet. An order of @p model and @p config\n arguments does not matter.\n\nPython prototype (for reference only):\n```python3\nreadNet(model[, config[, framework]]) -> retval\n```","ref":"Evision.DNN.html#readNet/2"},{"type":"function","title":"Evision.DNN.readNet/3","doc":"Read deep learning network represented in one of the supported formats.\n\n##### Positional Arguments\n- **framework**: `String`.\n\n  Name of origin framework.\n\n- **bufferModel**: `[uchar]`.\n\n  A buffer with a content of binary file with weights\n\n##### Keyword Arguments\n- **bufferConfig**: `[uchar]`.\n\n  A buffer with a content of text file contains network configuration.\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@details This is an overloaded member function, provided for convenience.\n          It differs from the above function only in what argument(s) it accepts.\n@returns Net object.\n\nPython prototype (for reference only):\n```python3\nreadNet(framework, bufferModel[, bufferConfig]) -> retval\n```","ref":"Evision.DNN.html#readNet/3"},{"type":"function","title":"Evision.DNN.readNetFromCaffe/1","doc":"Reads a network model stored in  Caffe  framework's format.\n\n##### Positional Arguments\n- **prototxt**: `String`.\n\n  path to the .prototxt file with text description of the network architecture.\n\n##### Keyword Arguments\n- **caffeModel**: `String`.\n\n  path to the .caffemodel file with learned network.\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Net object.\n\nPython prototype (for reference only):\n```python3\nreadNetFromCaffe(prototxt[, caffeModel]) -> retval\n```","ref":"Evision.DNN.html#readNetFromCaffe/1"},{"type":"function","title":"Evision.DNN.readNetFromCaffe/2","doc":"Reads a network model stored in  Caffe  framework's format.\n\n##### Positional Arguments\n- **prototxt**: `String`.\n\n  path to the .prototxt file with text description of the network architecture.\n\n##### Keyword Arguments\n- **caffeModel**: `String`.\n\n  path to the .caffemodel file with learned network.\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Net object.\n\nPython prototype (for reference only):\n```python3\nreadNetFromCaffe(prototxt[, caffeModel]) -> retval\n```","ref":"Evision.DNN.html#readNetFromCaffe/2"},{"type":"function","title":"Evision.DNN.readNetFromCaffeBuffer/1","doc":"Reads a network model stored in Caffe model in memory.\n\n##### Positional Arguments\n- **bufferProto**: `[uchar]`.\n\n  buffer containing the content of the .prototxt file\n\n##### Keyword Arguments\n- **bufferModel**: `[uchar]`.\n\n  buffer containing the content of the .caffemodel file\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Net object.\n\nPython prototype (for reference only):\n```python3\nreadNetFromCaffe(bufferProto[, bufferModel]) -> retval\n```","ref":"Evision.DNN.html#readNetFromCaffeBuffer/1"},{"type":"function","title":"Evision.DNN.readNetFromCaffeBuffer/2","doc":"Reads a network model stored in Caffe model in memory.\n\n##### Positional Arguments\n- **bufferProto**: `[uchar]`.\n\n  buffer containing the content of the .prototxt file\n\n##### Keyword Arguments\n- **bufferModel**: `[uchar]`.\n\n  buffer containing the content of the .caffemodel file\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Net object.\n\nPython prototype (for reference only):\n```python3\nreadNetFromCaffe(bufferProto[, bufferModel]) -> retval\n```","ref":"Evision.DNN.html#readNetFromCaffeBuffer/2"},{"type":"function","title":"Evision.DNN.readNetFromDarknet/1","doc":"Reads a network model stored in  Darknet  model files.\n\n##### Positional Arguments\n- **cfgFile**: `String`.\n\n  path to the .cfg file with text description of the network architecture.\n\n##### Keyword Arguments\n- **darknetModel**: `String`.\n\n  path to the .weights file with learned network.\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Network object that ready to do forward, throw an exception in failure cases.\n\nPython prototype (for reference only):\n```python3\nreadNetFromDarknet(cfgFile[, darknetModel]) -> retval\n```","ref":"Evision.DNN.html#readNetFromDarknet/1"},{"type":"function","title":"Evision.DNN.readNetFromDarknet/2","doc":"Reads a network model stored in  Darknet  model files.\n\n##### Positional Arguments\n- **cfgFile**: `String`.\n\n  path to the .cfg file with text description of the network architecture.\n\n##### Keyword Arguments\n- **darknetModel**: `String`.\n\n  path to the .weights file with learned network.\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Network object that ready to do forward, throw an exception in failure cases.\n\nPython prototype (for reference only):\n```python3\nreadNetFromDarknet(cfgFile[, darknetModel]) -> retval\n```","ref":"Evision.DNN.html#readNetFromDarknet/2"},{"type":"function","title":"Evision.DNN.readNetFromDarknetBuffer/1","doc":"Reads a network model stored in  Darknet  model files.\n\n##### Positional Arguments\n- **bufferCfg**: `[uchar]`.\n\n  A buffer contains a content of .cfg file with text description of the network architecture.\n\n##### Keyword Arguments\n- **bufferModel**: `[uchar]`.\n\n  A buffer contains a content of .weights file with learned network.\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Net object.\n\nPython prototype (for reference only):\n```python3\nreadNetFromDarknet(bufferCfg[, bufferModel]) -> retval\n```","ref":"Evision.DNN.html#readNetFromDarknetBuffer/1"},{"type":"function","title":"Evision.DNN.readNetFromDarknetBuffer/2","doc":"Reads a network model stored in  Darknet  model files.\n\n##### Positional Arguments\n- **bufferCfg**: `[uchar]`.\n\n  A buffer contains a content of .cfg file with text description of the network architecture.\n\n##### Keyword Arguments\n- **bufferModel**: `[uchar]`.\n\n  A buffer contains a content of .weights file with learned network.\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Net object.\n\nPython prototype (for reference only):\n```python3\nreadNetFromDarknet(bufferCfg[, bufferModel]) -> retval\n```","ref":"Evision.DNN.html#readNetFromDarknetBuffer/2"},{"type":"function","title":"Evision.DNN.readNetFromModelOptimizer/1","doc":"Load a network from Intel's Model Optimizer intermediate representation.\n\n##### Positional Arguments\n- **xml**: `String`.\n\n  XML configuration file with network's topology.\n\n##### Keyword Arguments\n- **bin**: `String`.\n\n  Binary file with trained weights.\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Net object.\n  Networks imported from Intel's Model Optimizer are launched in Intel's Inference Engine\n  backend.\n\nPython prototype (for reference only):\n```python3\nreadNetFromModelOptimizer(xml[, bin]) -> retval\n```","ref":"Evision.DNN.html#readNetFromModelOptimizer/1"},{"type":"function","title":"Evision.DNN.readNetFromModelOptimizer/2","doc":"Load a network from Intel's Model Optimizer intermediate representation.\n\n##### Positional Arguments\n- **xml**: `String`.\n\n  XML configuration file with network's topology.\n\n##### Keyword Arguments\n- **bin**: `String`.\n\n  Binary file with trained weights.\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Net object.\n  Networks imported from Intel's Model Optimizer are launched in Intel's Inference Engine\n  backend.\n\nPython prototype (for reference only):\n```python3\nreadNetFromModelOptimizer(xml[, bin]) -> retval\n```","ref":"Evision.DNN.html#readNetFromModelOptimizer/2"},{"type":"function","title":"Evision.DNN.readNetFromModelOptimizerBuffer/1","doc":"","ref":"Evision.DNN.html#readNetFromModelOptimizerBuffer/1"},{"type":"function","title":"Evision.DNN.readNetFromModelOptimizerBuffer/2","doc":"Load a network from Intel's Model Optimizer intermediate representation.\n\n##### Positional Arguments\n- **bufferModelConfig**: `[uchar]`.\n\n  Buffer contains XML configuration with network's topology.\n\n- **bufferWeights**: `[uchar]`.\n\n  Buffer contains binary data with trained weights.\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Net object.\n  Networks imported from Intel's Model Optimizer are launched in Intel's Inference Engine\n  backend.\n\nPython prototype (for reference only):\n```python3\nreadNetFromModelOptimizer(bufferModelConfig, bufferWeights) -> retval\n```","ref":"Evision.DNN.html#readNetFromModelOptimizerBuffer/2"},{"type":"function","title":"Evision.DNN.readNetFromONNX/1","doc":"Reads a network model  ONNX .\n\n##### Positional Arguments\n- **onnxFile**: `String`.\n\n  path to the .onnx file with text description of the network architecture.\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Network object that ready to do forward, throw an exception in failure cases.\n\nPython prototype (for reference only):\n```python3\nreadNetFromONNX(onnxFile) -> retval\n```","ref":"Evision.DNN.html#readNetFromONNX/1"},{"type":"function","title":"Evision.DNN.readNetFromONNXBuffer/1","doc":"Reads a network model from  ONNX \nin-memory buffer.\n\n##### Positional Arguments\n- **buffer**: `[uchar]`.\n\n  in-memory buffer that stores the ONNX model bytes.\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Network object that ready to do forward, throw an exception\n        in failure cases.\n\nPython prototype (for reference only):\n```python3\nreadNetFromONNX(buffer) -> retval\n```","ref":"Evision.DNN.html#readNetFromONNXBuffer/1"},{"type":"function","title":"Evision.DNN.readNetFromTensorflow/1","doc":"Reads a network model stored in  TensorFlow  framework's format.\n\n##### Positional Arguments\n- **model**: `String`.\n\n  path to the .pb file with binary protobuf description of the network architecture\n\n##### Keyword Arguments\n- **config**: `String`.\n\n  path to the .pbtxt file that contains text graph definition in protobuf format.\n  Resulting Net object is built by text graph using weights from a binary one that\n  let us make it more flexible.\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Net object.\n\nPython prototype (for reference only):\n```python3\nreadNetFromTensorflow(model[, config]) -> retval\n```","ref":"Evision.DNN.html#readNetFromTensorflow/1"},{"type":"function","title":"Evision.DNN.readNetFromTensorflow/2","doc":"Reads a network model stored in  TensorFlow  framework's format.\n\n##### Positional Arguments\n- **model**: `String`.\n\n  path to the .pb file with binary protobuf description of the network architecture\n\n##### Keyword Arguments\n- **config**: `String`.\n\n  path to the .pbtxt file that contains text graph definition in protobuf format.\n  Resulting Net object is built by text graph using weights from a binary one that\n  let us make it more flexible.\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Net object.\n\nPython prototype (for reference only):\n```python3\nreadNetFromTensorflow(model[, config]) -> retval\n```","ref":"Evision.DNN.html#readNetFromTensorflow/2"},{"type":"function","title":"Evision.DNN.readNetFromTensorflowBuffer/1","doc":"Reads a network model stored in  TensorFlow  framework's format.\n\n##### Positional Arguments\n- **bufferModel**: `[uchar]`.\n\n  buffer containing the content of the pb file\n\n##### Keyword Arguments\n- **bufferConfig**: `[uchar]`.\n\n  buffer containing the content of the pbtxt file\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Net object.\n\nPython prototype (for reference only):\n```python3\nreadNetFromTensorflow(bufferModel[, bufferConfig]) -> retval\n```","ref":"Evision.DNN.html#readNetFromTensorflowBuffer/1"},{"type":"function","title":"Evision.DNN.readNetFromTensorflowBuffer/2","doc":"Reads a network model stored in  TensorFlow  framework's format.\n\n##### Positional Arguments\n- **bufferModel**: `[uchar]`.\n\n  buffer containing the content of the pb file\n\n##### Keyword Arguments\n- **bufferConfig**: `[uchar]`.\n\n  buffer containing the content of the pbtxt file\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Net object.\n\nPython prototype (for reference only):\n```python3\nreadNetFromTensorflow(bufferModel[, bufferConfig]) -> retval\n```","ref":"Evision.DNN.html#readNetFromTensorflowBuffer/2"},{"type":"function","title":"Evision.DNN.readNetFromTFLite/1","doc":"Reads a network model stored in  TFLite  framework's format.\n\n##### Positional Arguments\n- **model**: `String`.\n\n  path to the .tflite file with binary flatbuffers description of the network architecture\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Net object.\n\nPython prototype (for reference only):\n```python3\nreadNetFromTFLite(model) -> retval\n```","ref":"Evision.DNN.html#readNetFromTFLite/1"},{"type":"function","title":"Evision.DNN.readNetFromTFLiteBuffer/1","doc":"Reads a network model stored in  TFLite  framework's format.\n\n##### Positional Arguments\n- **bufferModel**: `[uchar]`.\n\n  buffer containing the content of the tflite file\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Net object.\n\nPython prototype (for reference only):\n```python3\nreadNetFromTFLite(bufferModel) -> retval\n```","ref":"Evision.DNN.html#readNetFromTFLiteBuffer/1"},{"type":"function","title":"Evision.DNN.readNetFromTorch/1","doc":"Reads a network model stored in  Torch7  framework's format.\n\n##### Positional Arguments\n- **model**: `String`.\n\n  path to the file, dumped from Torch by using torch.save() function.\n\n##### Keyword Arguments\n- **isBinary**: `bool`.\n\n  specifies whether the network was serialized in ascii mode or binary.\n\n- **evaluate**: `bool`.\n\n  specifies testing phase of network. If true, it's similar to evaluate() method in Torch.\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Net object.\n**Note**: Ascii mode of Torch serializer is more preferable, because binary mode extensively use `long` type of C language,\n  which has various bit-length on different systems.\n The loading file must contain serialized  nn.Module  object\n with importing network. Try to eliminate a custom objects from serialazing data to avoid importing errors.\n List of supported layers (i.e. object instances derived from Torch nn.Module class):\n- nn.Sequential\n- nn.Parallel\n- nn.Concat\n- nn.Linear\n- nn.SpatialConvolution\n- nn.SpatialMaxPooling, nn.SpatialAveragePooling\n- nn.ReLU, nn.TanH, nn.Sigmoid\n- nn.Reshape\n- nn.SoftMax, nn.LogSoftMax\n\n Also some equivalents of these classes from cunn, cudnn, and fbcunn may be successfully imported.\n\nPython prototype (for reference only):\n```python3\nreadNetFromTorch(model[, isBinary[, evaluate]]) -> retval\n```","ref":"Evision.DNN.html#readNetFromTorch/1"},{"type":"function","title":"Evision.DNN.readNetFromTorch/2","doc":"Reads a network model stored in  Torch7  framework's format.\n\n##### Positional Arguments\n- **model**: `String`.\n\n  path to the file, dumped from Torch by using torch.save() function.\n\n##### Keyword Arguments\n- **isBinary**: `bool`.\n\n  specifies whether the network was serialized in ascii mode or binary.\n\n- **evaluate**: `bool`.\n\n  specifies testing phase of network. If true, it's similar to evaluate() method in Torch.\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Net object.\n**Note**: Ascii mode of Torch serializer is more preferable, because binary mode extensively use `long` type of C language,\n  which has various bit-length on different systems.\n The loading file must contain serialized  nn.Module  object\n with importing network. Try to eliminate a custom objects from serialazing data to avoid importing errors.\n List of supported layers (i.e. object instances derived from Torch nn.Module class):\n- nn.Sequential\n- nn.Parallel\n- nn.Concat\n- nn.Linear\n- nn.SpatialConvolution\n- nn.SpatialMaxPooling, nn.SpatialAveragePooling\n- nn.ReLU, nn.TanH, nn.Sigmoid\n- nn.Reshape\n- nn.SoftMax, nn.LogSoftMax\n\n Also some equivalents of these classes from cunn, cudnn, and fbcunn may be successfully imported.\n\nPython prototype (for reference only):\n```python3\nreadNetFromTorch(model[, isBinary[, evaluate]]) -> retval\n```","ref":"Evision.DNN.html#readNetFromTorch/2"},{"type":"function","title":"Evision.DNN.readTensorFromONNX/1","doc":"Creates blob from .pb file.\n\n##### Positional Arguments\n- **path**: `String`.\n\n  to the .pb file with input tensor.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n@returns Mat.\n\nPython prototype (for reference only):\n```python3\nreadTensorFromONNX(path) -> retval\n```","ref":"Evision.DNN.html#readTensorFromONNX/1"},{"type":"function","title":"Evision.DNN.readTorchBlob/1","doc":"Loads blob which was serialized as torch.Tensor object of Torch7 framework.\n\n##### Positional Arguments\n- **filename**: `String`\n\n##### Keyword Arguments\n- **isBinary**: `bool`.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n@warning This function has the same limitations as readNetFromTorch().\n\nPython prototype (for reference only):\n```python3\nreadTorchBlob(filename[, isBinary]) -> retval\n```","ref":"Evision.DNN.html#readTorchBlob/1"},{"type":"function","title":"Evision.DNN.readTorchBlob/2","doc":"Loads blob which was serialized as torch.Tensor object of Torch7 framework.\n\n##### Positional Arguments\n- **filename**: `String`\n\n##### Keyword Arguments\n- **isBinary**: `bool`.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n@warning This function has the same limitations as readNetFromTorch().\n\nPython prototype (for reference only):\n```python3\nreadTorchBlob(filename[, isBinary]) -> retval\n```","ref":"Evision.DNN.html#readTorchBlob/2"},{"type":"function","title":"Evision.DNN.shrinkCaffeModel/1","doc":"","ref":"Evision.DNN.html#shrinkCaffeModel/1"},{"type":"function","title":"Evision.DNN.shrinkCaffeModel/2","doc":"Convert all weights of Caffe network to half precision floating point.\n\n##### Positional Arguments\n- **src**: `String`.\n\n  Path to origin model from Caffe framework contains single\n  precision floating point weights (usually has `.caffemodel` extension).\n\n- **dst**: `String`.\n\n  Path to destination model with updated weights.\n\n##### Keyword Arguments\n- **layersTypes**: `[String]`.\n\n  Set of layers types which parameters will be converted.\n  By default, converts only Convolutional and Fully-Connected layers'\n  weights.\n\n**Note**: Shrinked model has no origin float32 weights so it can't be used\n       in origin Caffe framework anymore. However the structure of data\n       is taken from NVidia's Caffe fork: https://github.com/NVIDIA/caffe.\n       So the resulting model may be used there.\n\nPython prototype (for reference only):\n```python3\nshrinkCaffeModel(src, dst[, layersTypes]) -> None\n```","ref":"Evision.DNN.html#shrinkCaffeModel/2"},{"type":"function","title":"Evision.DNN.shrinkCaffeModel/3","doc":"Convert all weights of Caffe network to half precision floating point.\n\n##### Positional Arguments\n- **src**: `String`.\n\n  Path to origin model from Caffe framework contains single\n  precision floating point weights (usually has `.caffemodel` extension).\n\n- **dst**: `String`.\n\n  Path to destination model with updated weights.\n\n##### Keyword Arguments\n- **layersTypes**: `[String]`.\n\n  Set of layers types which parameters will be converted.\n  By default, converts only Convolutional and Fully-Connected layers'\n  weights.\n\n**Note**: Shrinked model has no origin float32 weights so it can't be used\n       in origin Caffe framework anymore. However the structure of data\n       is taken from NVidia's Caffe fork: https://github.com/NVIDIA/caffe.\n       So the resulting model may be used there.\n\nPython prototype (for reference only):\n```python3\nshrinkCaffeModel(src, dst[, layersTypes]) -> None\n```","ref":"Evision.DNN.html#shrinkCaffeModel/3"},{"type":"function","title":"Evision.DNN.softNMSBoxes/4","doc":"Performs soft non maximum suppression given boxes and corresponding scores.\nReference: https://arxiv.org/abs/1704.04503\n\n##### Positional Arguments\n- **bboxes**: `[Rect]`, `Nx.Tensor.t()`, `Evision.Mat.t()`..\n\n  a set of bounding boxes to apply Soft NMS.\n\n- **scores**: `[float]`.\n\n  a set of corresponding confidences.\n\n- **score_threshold**: `float`.\n\n  a threshold used to filter boxes by score.\n\n- **nms_threshold**: `float`.\n\n  a threshold used in non maximum suppression.\n\n##### Keyword Arguments\n- **top_k**: `size_t`.\n\n  keep at most @p top_k picked indices.\n\n- **sigma**: `float`.\n\n  parameter of Gaussian weighting.\n\n- **method**: `SoftNMSMethod`.\n\n  Gaussian or linear.\n\n##### Return\n- **updated_scores**: `[float]`.\n\n  a set of corresponding updated confidences.\n\n- **indices**: `[int]`.\n\n  the kept indices of bboxes after NMS.\n\n@see SoftNMSMethod\n\nPython prototype (for reference only):\n```python3\nsoftNMSBoxes(bboxes, scores, score_threshold, nms_threshold[, top_k[, sigma[, method]]]) -> updated_scores, indices\n```","ref":"Evision.DNN.html#softNMSBoxes/4"},{"type":"function","title":"Evision.DNN.softNMSBoxes/5","doc":"Performs soft non maximum suppression given boxes and corresponding scores.\nReference: https://arxiv.org/abs/1704.04503\n\n##### Positional Arguments\n- **bboxes**: `[Rect]`, `Nx.Tensor.t()`, `Evision.Mat.t()`..\n\n  a set of bounding boxes to apply Soft NMS.\n\n- **scores**: `[float]`.\n\n  a set of corresponding confidences.\n\n- **score_threshold**: `float`.\n\n  a threshold used to filter boxes by score.\n\n- **nms_threshold**: `float`.\n\n  a threshold used in non maximum suppression.\n\n##### Keyword Arguments\n- **top_k**: `size_t`.\n\n  keep at most @p top_k picked indices.\n\n- **sigma**: `float`.\n\n  parameter of Gaussian weighting.\n\n- **method**: `SoftNMSMethod`.\n\n  Gaussian or linear.\n\n##### Return\n- **updated_scores**: `[float]`.\n\n  a set of corresponding updated confidences.\n\n- **indices**: `[int]`.\n\n  the kept indices of bboxes after NMS.\n\n@see SoftNMSMethod\n\nPython prototype (for reference only):\n```python3\nsoftNMSBoxes(bboxes, scores, score_threshold, nms_threshold[, top_k[, sigma[, method]]]) -> updated_scores, indices\n```","ref":"Evision.DNN.html#softNMSBoxes/5"},{"type":"function","title":"Evision.DNN.writeTextGraph/1","doc":"","ref":"Evision.DNN.html#writeTextGraph/1"},{"type":"function","title":"Evision.DNN.writeTextGraph/2","doc":"Create a text representation for a binary network stored in protocol buffer format.\n\n##### Positional Arguments\n- **model**: `String`.\n\n  A path to binary network.\n\n- **output**: `String`.\n\n  A path to output text file to be created.\n\n**Note**: To reduce output file size, trained weights are not included.\n\nPython prototype (for reference only):\n```python3\nwriteTextGraph(model, output) -> None\n```","ref":"Evision.DNN.html#writeTextGraph/2"},{"type":"type","title":"Evision.DNN.t/0","doc":"Type that represents an `DNN` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.DNN.html#t:t/0"},{"type":"module","title":"Evision.DNN.Backend","doc":"","ref":"Evision.DNN.Backend.html"},{"type":"function","title":"Evision.DNN.Backend.cv_DNN_BACKEND_CANN/0","doc":"","ref":"Evision.DNN.Backend.html#cv_DNN_BACKEND_CANN/0"},{"type":"function","title":"Evision.DNN.Backend.cv_DNN_BACKEND_CUDA/0","doc":"","ref":"Evision.DNN.Backend.html#cv_DNN_BACKEND_CUDA/0"},{"type":"function","title":"Evision.DNN.Backend.cv_DNN_BACKEND_DEFAULT/0","doc":"","ref":"Evision.DNN.Backend.html#cv_DNN_BACKEND_DEFAULT/0"},{"type":"function","title":"Evision.DNN.Backend.cv_DNN_BACKEND_HALIDE/0","doc":"","ref":"Evision.DNN.Backend.html#cv_DNN_BACKEND_HALIDE/0"},{"type":"function","title":"Evision.DNN.Backend.cv_DNN_BACKEND_INFERENCE_ENGINE/0","doc":"","ref":"Evision.DNN.Backend.html#cv_DNN_BACKEND_INFERENCE_ENGINE/0"},{"type":"function","title":"Evision.DNN.Backend.cv_DNN_BACKEND_OPENCV/0","doc":"","ref":"Evision.DNN.Backend.html#cv_DNN_BACKEND_OPENCV/0"},{"type":"function","title":"Evision.DNN.Backend.cv_DNN_BACKEND_TIMVX/0","doc":"","ref":"Evision.DNN.Backend.html#cv_DNN_BACKEND_TIMVX/0"},{"type":"function","title":"Evision.DNN.Backend.cv_DNN_BACKEND_VKCOM/0","doc":"","ref":"Evision.DNN.Backend.html#cv_DNN_BACKEND_VKCOM/0"},{"type":"function","title":"Evision.DNN.Backend.cv_DNN_BACKEND_WEBNN/0","doc":"","ref":"Evision.DNN.Backend.html#cv_DNN_BACKEND_WEBNN/0"},{"type":"type","title":"Evision.DNN.Backend.enum/0","doc":"","ref":"Evision.DNN.Backend.html#t:enum/0"},{"type":"module","title":"Evision.DNN.ClassificationModel","doc":"","ref":"Evision.DNN.ClassificationModel.html"},{"type":"function","title":"Evision.DNN.ClassificationModel.classificationModel/1","doc":"#### Variant 1:\nCreate model from deep learning network.\n\n##### Positional Arguments\n- **network**: `Evision.DNN.Net.t()`.\n\n  Net object.\n\n##### Return\n- **self**: `Evision.DNN.ClassificationModel.t()`\n\nPython prototype (for reference only):\n```python3\nClassificationModel(network) ->  \n```\n#### Variant 2:\nCreate classification model from network represented in one of the supported formats.\nAn order of @p model and @p config arguments does not matter.\n\n##### Positional Arguments\n- **model**: `String`.\n\n  Binary file contains trained weights.\n\n##### Keyword Arguments\n- **config**: `String`.\n\n  Text file contains network configuration.\n\n##### Return\n- **self**: `Evision.DNN.ClassificationModel.t()`\n\nPython prototype (for reference only):\n```python3\nClassificationModel(model[, config]) ->  \n```","ref":"Evision.DNN.ClassificationModel.html#classificationModel/1"},{"type":"function","title":"Evision.DNN.ClassificationModel.classificationModel/2","doc":"Create classification model from network represented in one of the supported formats.\nAn order of @p model and @p config arguments does not matter.\n\n##### Positional Arguments\n- **model**: `String`.\n\n  Binary file contains trained weights.\n\n##### Keyword Arguments\n- **config**: `String`.\n\n  Text file contains network configuration.\n\n##### Return\n- **self**: `Evision.DNN.ClassificationModel.t()`\n\nPython prototype (for reference only):\n```python3\nClassificationModel(model[, config]) ->  \n```","ref":"Evision.DNN.ClassificationModel.html#classificationModel/2"},{"type":"function","title":"Evision.DNN.ClassificationModel.classify/1","doc":"","ref":"Evision.DNN.ClassificationModel.html#classify/1"},{"type":"function","title":"Evision.DNN.ClassificationModel.classify/2","doc":"classify\n\n##### Positional Arguments\n- **self**: `Evision.DNN.ClassificationModel.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **classId**: `integer()`\n- **conf**: `float`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nclassify(frame) -> classId, conf\n```","ref":"Evision.DNN.ClassificationModel.html#classify/2"},{"type":"function","title":"Evision.DNN.ClassificationModel.enableWinograd/1","doc":"","ref":"Evision.DNN.ClassificationModel.html#enableWinograd/1"},{"type":"function","title":"Evision.DNN.ClassificationModel.enableWinograd/2","doc":"enableWinograd\n\n##### Positional Arguments\n- **self**: `Evision.DNN.ClassificationModel.t()`\n- **useWinograd**: `bool`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nenableWinograd(useWinograd) -> retval\n```","ref":"Evision.DNN.ClassificationModel.html#enableWinograd/2"},{"type":"function","title":"Evision.DNN.ClassificationModel.getEnableSoftmaxPostProcessing/1","doc":"Get enable/disable softmax post processing option.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.ClassificationModel.t()`\n\n##### Return\n- **retval**: `bool`\n\n This option defaults to false, softmax post processing is not applied within the classify() function.\n\nPython prototype (for reference only):\n```python3\ngetEnableSoftmaxPostProcessing() -> retval\n```","ref":"Evision.DNN.ClassificationModel.html#getEnableSoftmaxPostProcessing/1"},{"type":"function","title":"Evision.DNN.ClassificationModel.predict/1","doc":"","ref":"Evision.DNN.ClassificationModel.html#predict/1"},{"type":"function","title":"Evision.DNN.ClassificationModel.predict/2","doc":"Given the @p input frame, create input blob, run net and return the output @p blobs.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.ClassificationModel.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **outs**: `[Evision.Mat]`.\n\n  Allocated output blobs, which will store results of the computation.\n\nPython prototype (for reference only):\n```python3\npredict(frame[, outs]) -> outs\n```","ref":"Evision.DNN.ClassificationModel.html#predict/2"},{"type":"function","title":"Evision.DNN.ClassificationModel.predict/3","doc":"Given the @p input frame, create input blob, run net and return the output @p blobs.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.ClassificationModel.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **outs**: `[Evision.Mat]`.\n\n  Allocated output blobs, which will store results of the computation.\n\nPython prototype (for reference only):\n```python3\npredict(frame[, outs]) -> outs\n```","ref":"Evision.DNN.ClassificationModel.html#predict/3"},{"type":"function","title":"Evision.DNN.ClassificationModel.setEnableSoftmaxPostProcessing/1","doc":"","ref":"Evision.DNN.ClassificationModel.html#setEnableSoftmaxPostProcessing/1"},{"type":"function","title":"Evision.DNN.ClassificationModel.setEnableSoftmaxPostProcessing/2","doc":"Set enable/disable softmax post processing option.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.ClassificationModel.t()`\n- **enable**: `bool`.\n\n  Set enable softmax post processing within the classify() function.\n\n##### Return\n- **retval**: `Evision.DNN.ClassificationModel.t()`\n\n If this option is true, softmax is applied after forward inference within the classify() function\n to convert the confidences range to [0.0-1.0].\n This function allows you to toggle this behavior.\n Please turn true when not contain softmax layer in model.\n\nPython prototype (for reference only):\n```python3\nsetEnableSoftmaxPostProcessing(enable) -> retval\n```","ref":"Evision.DNN.ClassificationModel.html#setEnableSoftmaxPostProcessing/2"},{"type":"function","title":"Evision.DNN.ClassificationModel.setInputCrop/1","doc":"","ref":"Evision.DNN.ClassificationModel.html#setInputCrop/1"},{"type":"function","title":"Evision.DNN.ClassificationModel.setInputCrop/2","doc":"Set flag crop for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.ClassificationModel.t()`\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputCrop(crop) -> retval\n```","ref":"Evision.DNN.ClassificationModel.html#setInputCrop/2"},{"type":"function","title":"Evision.DNN.ClassificationModel.setInputMean/1","doc":"","ref":"Evision.DNN.ClassificationModel.html#setInputMean/1"},{"type":"function","title":"Evision.DNN.ClassificationModel.setInputMean/2","doc":"Set mean value for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.ClassificationModel.t()`\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputMean(mean) -> retval\n```","ref":"Evision.DNN.ClassificationModel.html#setInputMean/2"},{"type":"function","title":"Evision.DNN.ClassificationModel.setInputParams/1","doc":"Set preprocessing parameters for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.ClassificationModel.t()`\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Multiplier for frame values.\n\n- **size**: `Size`.\n\n  New input size.\n\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n  blob(n, c, y, x) = scale * resize( frame(y, x, c) ) - mean(c) )\n\nPython prototype (for reference only):\n```python3\nsetInputParams([, scale[, size[, mean[, swapRB[, crop]]]]]) -> None\n```","ref":"Evision.DNN.ClassificationModel.html#setInputParams/1"},{"type":"function","title":"Evision.DNN.ClassificationModel.setInputParams/2","doc":"Set preprocessing parameters for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.ClassificationModel.t()`\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Multiplier for frame values.\n\n- **size**: `Size`.\n\n  New input size.\n\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n  blob(n, c, y, x) = scale * resize( frame(y, x, c) ) - mean(c) )\n\nPython prototype (for reference only):\n```python3\nsetInputParams([, scale[, size[, mean[, swapRB[, crop]]]]]) -> None\n```","ref":"Evision.DNN.ClassificationModel.html#setInputParams/2"},{"type":"function","title":"Evision.DNN.ClassificationModel.setInputScale/1","doc":"","ref":"Evision.DNN.ClassificationModel.html#setInputScale/1"},{"type":"function","title":"Evision.DNN.ClassificationModel.setInputScale/2","doc":"Set scalefactor value for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.ClassificationModel.t()`\n- **scale**: `Evision.scalar()`.\n\n  Multiplier for frame values.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputScale(scale) -> retval\n```","ref":"Evision.DNN.ClassificationModel.html#setInputScale/2"},{"type":"function","title":"Evision.DNN.ClassificationModel.setInputSize/1","doc":"","ref":"Evision.DNN.ClassificationModel.html#setInputSize/1"},{"type":"function","title":"Evision.DNN.ClassificationModel.setInputSize/2","doc":"Set input size for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.ClassificationModel.t()`\n- **size**: `Size`.\n\n  New input size.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\n**Note**: If shape of the new blob less than 0, then frame size not change.\n\nPython prototype (for reference only):\n```python3\nsetInputSize(size) -> retval\n```","ref":"Evision.DNN.ClassificationModel.html#setInputSize/2"},{"type":"function","title":"Evision.DNN.ClassificationModel.setInputSize/3","doc":"setInputSize\n\n##### Positional Arguments\n- **self**: `Evision.DNN.ClassificationModel.t()`\n- **width**: `integer()`.\n\n  New input width.\n\n- **height**: `integer()`.\n\n  New input height.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nsetInputSize(width, height) -> retval\n```","ref":"Evision.DNN.ClassificationModel.html#setInputSize/3"},{"type":"function","title":"Evision.DNN.ClassificationModel.setInputSwapRB/1","doc":"","ref":"Evision.DNN.ClassificationModel.html#setInputSwapRB/1"},{"type":"function","title":"Evision.DNN.ClassificationModel.setInputSwapRB/2","doc":"Set flag swapRB for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.ClassificationModel.t()`\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputSwapRB(swapRB) -> retval\n```","ref":"Evision.DNN.ClassificationModel.html#setInputSwapRB/2"},{"type":"function","title":"Evision.DNN.ClassificationModel.setOutputNames/1","doc":"","ref":"Evision.DNN.ClassificationModel.html#setOutputNames/1"},{"type":"function","title":"Evision.DNN.ClassificationModel.setOutputNames/2","doc":"Set output names for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.ClassificationModel.t()`\n- **outNames**: `[String]`.\n\n  Names for output layers.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetOutputNames(outNames) -> retval\n```","ref":"Evision.DNN.ClassificationModel.html#setOutputNames/2"},{"type":"function","title":"Evision.DNN.ClassificationModel.setPreferableBackend/1","doc":"","ref":"Evision.DNN.ClassificationModel.html#setPreferableBackend/1"},{"type":"function","title":"Evision.DNN.ClassificationModel.setPreferableBackend/2","doc":"setPreferableBackend\n\n##### Positional Arguments\n- **self**: `Evision.DNN.ClassificationModel.t()`\n- **backendId**: `dnn_Backend`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetPreferableBackend(backendId) -> retval\n```","ref":"Evision.DNN.ClassificationModel.html#setPreferableBackend/2"},{"type":"function","title":"Evision.DNN.ClassificationModel.setPreferableTarget/1","doc":"","ref":"Evision.DNN.ClassificationModel.html#setPreferableTarget/1"},{"type":"function","title":"Evision.DNN.ClassificationModel.setPreferableTarget/2","doc":"setPreferableTarget\n\n##### Positional Arguments\n- **self**: `Evision.DNN.ClassificationModel.t()`\n- **targetId**: `dnn_Target`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetPreferableTarget(targetId) -> retval\n```","ref":"Evision.DNN.ClassificationModel.html#setPreferableTarget/2"},{"type":"type","title":"Evision.DNN.ClassificationModel.t/0","doc":"Type that represents an `DNN.ClassificationModel` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.DNN.ClassificationModel.html#t:t/0"},{"type":"module","title":"Evision.DNN.DataLayout","doc":"","ref":"Evision.DNN.DataLayout.html"},{"type":"function","title":"Evision.DNN.DataLayout.cv_DNN_LAYOUT_NCDHW/0","doc":"","ref":"Evision.DNN.DataLayout.html#cv_DNN_LAYOUT_NCDHW/0"},{"type":"function","title":"Evision.DNN.DataLayout.cv_DNN_LAYOUT_NCHW/0","doc":"","ref":"Evision.DNN.DataLayout.html#cv_DNN_LAYOUT_NCHW/0"},{"type":"function","title":"Evision.DNN.DataLayout.cv_DNN_LAYOUT_ND/0","doc":"","ref":"Evision.DNN.DataLayout.html#cv_DNN_LAYOUT_ND/0"},{"type":"function","title":"Evision.DNN.DataLayout.cv_DNN_LAYOUT_NDHWC/0","doc":"","ref":"Evision.DNN.DataLayout.html#cv_DNN_LAYOUT_NDHWC/0"},{"type":"function","title":"Evision.DNN.DataLayout.cv_DNN_LAYOUT_NHWC/0","doc":"","ref":"Evision.DNN.DataLayout.html#cv_DNN_LAYOUT_NHWC/0"},{"type":"function","title":"Evision.DNN.DataLayout.cv_DNN_LAYOUT_PLANAR/0","doc":"","ref":"Evision.DNN.DataLayout.html#cv_DNN_LAYOUT_PLANAR/0"},{"type":"function","title":"Evision.DNN.DataLayout.cv_DNN_LAYOUT_UNKNOWN/0","doc":"","ref":"Evision.DNN.DataLayout.html#cv_DNN_LAYOUT_UNKNOWN/0"},{"type":"type","title":"Evision.DNN.DataLayout.enum/0","doc":"","ref":"Evision.DNN.DataLayout.html#t:enum/0"},{"type":"module","title":"Evision.DNN.DetectionModel","doc":"","ref":"Evision.DNN.DetectionModel.html"},{"type":"function","title":"Evision.DNN.DetectionModel.detect/1","doc":"","ref":"Evision.DNN.DetectionModel.html#detect/1"},{"type":"function","title":"Evision.DNN.DetectionModel.detect/2","doc":"Given the @p input frame, create input blob, run net and return result detections.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DetectionModel.t()`\n- **frame**: `Evision.Mat`\n\n##### Keyword Arguments\n- **confThreshold**: `float`.\n\n  A threshold used to filter boxes by confidences.\n\n- **nmsThreshold**: `float`.\n\n  A threshold used in non maximum suppression.\n\n##### Return\n- **classIds**: `[integer()]`.\n\n  Class indexes in result detection.\n\n- **confidences**: `[float]`.\n\n  A set of corresponding confidences.\n\n- **boxes**: `[Rect]`.\n\n  A set of bounding boxes.\n\nPython prototype (for reference only):\n```python3\ndetect(frame[, confThreshold[, nmsThreshold]]) -> classIds, confidences, boxes\n```","ref":"Evision.DNN.DetectionModel.html#detect/2"},{"type":"function","title":"Evision.DNN.DetectionModel.detect/3","doc":"Given the @p input frame, create input blob, run net and return result detections.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DetectionModel.t()`\n- **frame**: `Evision.Mat`\n\n##### Keyword Arguments\n- **confThreshold**: `float`.\n\n  A threshold used to filter boxes by confidences.\n\n- **nmsThreshold**: `float`.\n\n  A threshold used in non maximum suppression.\n\n##### Return\n- **classIds**: `[integer()]`.\n\n  Class indexes in result detection.\n\n- **confidences**: `[float]`.\n\n  A set of corresponding confidences.\n\n- **boxes**: `[Rect]`.\n\n  A set of bounding boxes.\n\nPython prototype (for reference only):\n```python3\ndetect(frame[, confThreshold[, nmsThreshold]]) -> classIds, confidences, boxes\n```","ref":"Evision.DNN.DetectionModel.html#detect/3"},{"type":"function","title":"Evision.DNN.DetectionModel.detectionModel/1","doc":"#### Variant 1:\nCreate model from deep learning network.\n\n##### Positional Arguments\n- **network**: `Evision.DNN.Net.t()`.\n\n  Net object.\n\n##### Return\n- **self**: `Evision.DNN.DetectionModel.t()`\n\nPython prototype (for reference only):\n```python3\nDetectionModel(network) ->  \n```\n#### Variant 2:\nCreate detection model from network represented in one of the supported formats.\nAn order of @p model and @p config arguments does not matter.\n\n##### Positional Arguments\n- **model**: `String`.\n\n  Binary file contains trained weights.\n\n##### Keyword Arguments\n- **config**: `String`.\n\n  Text file contains network configuration.\n\n##### Return\n- **self**: `Evision.DNN.DetectionModel.t()`\n\nPython prototype (for reference only):\n```python3\nDetectionModel(model[, config]) ->  \n```","ref":"Evision.DNN.DetectionModel.html#detectionModel/1"},{"type":"function","title":"Evision.DNN.DetectionModel.detectionModel/2","doc":"Create detection model from network represented in one of the supported formats.\nAn order of @p model and @p config arguments does not matter.\n\n##### Positional Arguments\n- **model**: `String`.\n\n  Binary file contains trained weights.\n\n##### Keyword Arguments\n- **config**: `String`.\n\n  Text file contains network configuration.\n\n##### Return\n- **self**: `Evision.DNN.DetectionModel.t()`\n\nPython prototype (for reference only):\n```python3\nDetectionModel(model[, config]) ->  \n```","ref":"Evision.DNN.DetectionModel.html#detectionModel/2"},{"type":"function","title":"Evision.DNN.DetectionModel.enableWinograd/1","doc":"","ref":"Evision.DNN.DetectionModel.html#enableWinograd/1"},{"type":"function","title":"Evision.DNN.DetectionModel.enableWinograd/2","doc":"enableWinograd\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DetectionModel.t()`\n- **useWinograd**: `bool`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nenableWinograd(useWinograd) -> retval\n```","ref":"Evision.DNN.DetectionModel.html#enableWinograd/2"},{"type":"function","title":"Evision.DNN.DetectionModel.getNmsAcrossClasses/1","doc":"Getter for nmsAcrossClasses. This variable defaults to false,\nsuch that when non max suppression is used during the detect() function, it will do so only per-class\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DetectionModel.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetNmsAcrossClasses() -> retval\n```","ref":"Evision.DNN.DetectionModel.html#getNmsAcrossClasses/1"},{"type":"function","title":"Evision.DNN.DetectionModel.predict/1","doc":"","ref":"Evision.DNN.DetectionModel.html#predict/1"},{"type":"function","title":"Evision.DNN.DetectionModel.predict/2","doc":"Given the @p input frame, create input blob, run net and return the output @p blobs.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DetectionModel.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **outs**: `[Evision.Mat]`.\n\n  Allocated output blobs, which will store results of the computation.\n\nPython prototype (for reference only):\n```python3\npredict(frame[, outs]) -> outs\n```","ref":"Evision.DNN.DetectionModel.html#predict/2"},{"type":"function","title":"Evision.DNN.DetectionModel.predict/3","doc":"Given the @p input frame, create input blob, run net and return the output @p blobs.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DetectionModel.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **outs**: `[Evision.Mat]`.\n\n  Allocated output blobs, which will store results of the computation.\n\nPython prototype (for reference only):\n```python3\npredict(frame[, outs]) -> outs\n```","ref":"Evision.DNN.DetectionModel.html#predict/3"},{"type":"function","title":"Evision.DNN.DetectionModel.setInputCrop/1","doc":"","ref":"Evision.DNN.DetectionModel.html#setInputCrop/1"},{"type":"function","title":"Evision.DNN.DetectionModel.setInputCrop/2","doc":"Set flag crop for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DetectionModel.t()`\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputCrop(crop) -> retval\n```","ref":"Evision.DNN.DetectionModel.html#setInputCrop/2"},{"type":"function","title":"Evision.DNN.DetectionModel.setInputMean/1","doc":"","ref":"Evision.DNN.DetectionModel.html#setInputMean/1"},{"type":"function","title":"Evision.DNN.DetectionModel.setInputMean/2","doc":"Set mean value for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DetectionModel.t()`\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputMean(mean) -> retval\n```","ref":"Evision.DNN.DetectionModel.html#setInputMean/2"},{"type":"function","title":"Evision.DNN.DetectionModel.setInputParams/1","doc":"Set preprocessing parameters for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DetectionModel.t()`\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Multiplier for frame values.\n\n- **size**: `Size`.\n\n  New input size.\n\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n  blob(n, c, y, x) = scale * resize( frame(y, x, c) ) - mean(c) )\n\nPython prototype (for reference only):\n```python3\nsetInputParams([, scale[, size[, mean[, swapRB[, crop]]]]]) -> None\n```","ref":"Evision.DNN.DetectionModel.html#setInputParams/1"},{"type":"function","title":"Evision.DNN.DetectionModel.setInputParams/2","doc":"Set preprocessing parameters for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DetectionModel.t()`\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Multiplier for frame values.\n\n- **size**: `Size`.\n\n  New input size.\n\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n  blob(n, c, y, x) = scale * resize( frame(y, x, c) ) - mean(c) )\n\nPython prototype (for reference only):\n```python3\nsetInputParams([, scale[, size[, mean[, swapRB[, crop]]]]]) -> None\n```","ref":"Evision.DNN.DetectionModel.html#setInputParams/2"},{"type":"function","title":"Evision.DNN.DetectionModel.setInputScale/1","doc":"","ref":"Evision.DNN.DetectionModel.html#setInputScale/1"},{"type":"function","title":"Evision.DNN.DetectionModel.setInputScale/2","doc":"Set scalefactor value for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DetectionModel.t()`\n- **scale**: `Evision.scalar()`.\n\n  Multiplier for frame values.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputScale(scale) -> retval\n```","ref":"Evision.DNN.DetectionModel.html#setInputScale/2"},{"type":"function","title":"Evision.DNN.DetectionModel.setInputSize/1","doc":"","ref":"Evision.DNN.DetectionModel.html#setInputSize/1"},{"type":"function","title":"Evision.DNN.DetectionModel.setInputSize/2","doc":"Set input size for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DetectionModel.t()`\n- **size**: `Size`.\n\n  New input size.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\n**Note**: If shape of the new blob less than 0, then frame size not change.\n\nPython prototype (for reference only):\n```python3\nsetInputSize(size) -> retval\n```","ref":"Evision.DNN.DetectionModel.html#setInputSize/2"},{"type":"function","title":"Evision.DNN.DetectionModel.setInputSize/3","doc":"setInputSize\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DetectionModel.t()`\n- **width**: `integer()`.\n\n  New input width.\n\n- **height**: `integer()`.\n\n  New input height.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nsetInputSize(width, height) -> retval\n```","ref":"Evision.DNN.DetectionModel.html#setInputSize/3"},{"type":"function","title":"Evision.DNN.DetectionModel.setInputSwapRB/1","doc":"","ref":"Evision.DNN.DetectionModel.html#setInputSwapRB/1"},{"type":"function","title":"Evision.DNN.DetectionModel.setInputSwapRB/2","doc":"Set flag swapRB for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DetectionModel.t()`\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputSwapRB(swapRB) -> retval\n```","ref":"Evision.DNN.DetectionModel.html#setInputSwapRB/2"},{"type":"function","title":"Evision.DNN.DetectionModel.setNmsAcrossClasses/1","doc":"","ref":"Evision.DNN.DetectionModel.html#setNmsAcrossClasses/1"},{"type":"function","title":"Evision.DNN.DetectionModel.setNmsAcrossClasses/2","doc":"nmsAcrossClasses defaults to false,\nsuch that when non max suppression is used during the detect() function, it will do so per-class.\nThis function allows you to toggle this behaviour.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DetectionModel.t()`\n- **value**: `bool`.\n\n  The new value for nmsAcrossClasses\n\n##### Return\n- **retval**: `Evision.DNN.DetectionModel.t()`\n\nPython prototype (for reference only):\n```python3\nsetNmsAcrossClasses(value) -> retval\n```","ref":"Evision.DNN.DetectionModel.html#setNmsAcrossClasses/2"},{"type":"function","title":"Evision.DNN.DetectionModel.setOutputNames/1","doc":"","ref":"Evision.DNN.DetectionModel.html#setOutputNames/1"},{"type":"function","title":"Evision.DNN.DetectionModel.setOutputNames/2","doc":"Set output names for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DetectionModel.t()`\n- **outNames**: `[String]`.\n\n  Names for output layers.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetOutputNames(outNames) -> retval\n```","ref":"Evision.DNN.DetectionModel.html#setOutputNames/2"},{"type":"function","title":"Evision.DNN.DetectionModel.setPreferableBackend/1","doc":"","ref":"Evision.DNN.DetectionModel.html#setPreferableBackend/1"},{"type":"function","title":"Evision.DNN.DetectionModel.setPreferableBackend/2","doc":"setPreferableBackend\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DetectionModel.t()`\n- **backendId**: `dnn_Backend`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetPreferableBackend(backendId) -> retval\n```","ref":"Evision.DNN.DetectionModel.html#setPreferableBackend/2"},{"type":"function","title":"Evision.DNN.DetectionModel.setPreferableTarget/1","doc":"","ref":"Evision.DNN.DetectionModel.html#setPreferableTarget/1"},{"type":"function","title":"Evision.DNN.DetectionModel.setPreferableTarget/2","doc":"setPreferableTarget\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DetectionModel.t()`\n- **targetId**: `dnn_Target`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetPreferableTarget(targetId) -> retval\n```","ref":"Evision.DNN.DetectionModel.html#setPreferableTarget/2"},{"type":"type","title":"Evision.DNN.DetectionModel.t/0","doc":"Type that represents an `DNN.DetectionModel` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.DNN.DetectionModel.html#t:t/0"},{"type":"module","title":"Evision.DNN.DictValue","doc":"","ref":"Evision.DNN.DictValue.html"},{"type":"function","title":"Evision.DNN.DictValue.dictValue/1","doc":"#### Variant 1:\nDictValue\n\n##### Positional Arguments\n- **s**: `String`\n\n##### Return\n- **self**: `Evision.DNN.DictValue.t()`\n\nPython prototype (for reference only):\n```python3\nDictValue(s) ->  \n```\n#### Variant 2:\nDictValue\n\n##### Positional Arguments\n- **p**: `double`\n\n##### Return\n- **self**: `Evision.DNN.DictValue.t()`\n\nPython prototype (for reference only):\n```python3\nDictValue(p) ->  \n```\n#### Variant 3:\nDictValue\n\n##### Positional Arguments\n- **i**: `integer()`\n\n##### Return\n- **self**: `Evision.DNN.DictValue.t()`\n\nPython prototype (for reference only):\n```python3\nDictValue(i) ->  \n```","ref":"Evision.DNN.DictValue.html#dictValue/1"},{"type":"function","title":"Evision.DNN.DictValue.getIntValue/1","doc":"getIntValue\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DictValue.t()`\n\n##### Keyword Arguments\n- **idx**: `integer()`.\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetIntValue([, idx]) -> retval\n```","ref":"Evision.DNN.DictValue.html#getIntValue/1"},{"type":"function","title":"Evision.DNN.DictValue.getIntValue/2","doc":"getIntValue\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DictValue.t()`\n\n##### Keyword Arguments\n- **idx**: `integer()`.\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetIntValue([, idx]) -> retval\n```","ref":"Evision.DNN.DictValue.html#getIntValue/2"},{"type":"function","title":"Evision.DNN.DictValue.getRealValue/1","doc":"getRealValue\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DictValue.t()`\n\n##### Keyword Arguments\n- **idx**: `integer()`.\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetRealValue([, idx]) -> retval\n```","ref":"Evision.DNN.DictValue.html#getRealValue/1"},{"type":"function","title":"Evision.DNN.DictValue.getRealValue/2","doc":"getRealValue\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DictValue.t()`\n\n##### Keyword Arguments\n- **idx**: `integer()`.\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetRealValue([, idx]) -> retval\n```","ref":"Evision.DNN.DictValue.html#getRealValue/2"},{"type":"function","title":"Evision.DNN.DictValue.getStringValue/1","doc":"getStringValue\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DictValue.t()`\n\n##### Keyword Arguments\n- **idx**: `integer()`.\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetStringValue([, idx]) -> retval\n```","ref":"Evision.DNN.DictValue.html#getStringValue/1"},{"type":"function","title":"Evision.DNN.DictValue.getStringValue/2","doc":"getStringValue\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DictValue.t()`\n\n##### Keyword Arguments\n- **idx**: `integer()`.\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetStringValue([, idx]) -> retval\n```","ref":"Evision.DNN.DictValue.html#getStringValue/2"},{"type":"function","title":"Evision.DNN.DictValue.isInt/1","doc":"isInt\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DictValue.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisInt() -> retval\n```","ref":"Evision.DNN.DictValue.html#isInt/1"},{"type":"function","title":"Evision.DNN.DictValue.isReal/1","doc":"isReal\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DictValue.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisReal() -> retval\n```","ref":"Evision.DNN.DictValue.html#isReal/1"},{"type":"function","title":"Evision.DNN.DictValue.isString/1","doc":"isString\n\n##### Positional Arguments\n- **self**: `Evision.DNN.DictValue.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisString() -> retval\n```","ref":"Evision.DNN.DictValue.html#isString/1"},{"type":"type","title":"Evision.DNN.DictValue.t/0","doc":"Type that represents an `DNN.DictValue` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.DNN.DictValue.html#t:t/0"},{"type":"module","title":"Evision.DNN.Image2BlobParams","doc":"","ref":"Evision.DNN.Image2BlobParams.html"},{"type":"function","title":"Evision.DNN.Image2BlobParams.blobRectsToImageRects/1","doc":"","ref":"Evision.DNN.Image2BlobParams.html#blobRectsToImageRects/1"},{"type":"function","title":"Evision.DNN.Image2BlobParams.blobRectsToImageRects/3","doc":"Get rectangle coordinates in original image system from rectangle in blob coordinates.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Image2BlobParams.t()`\n- **rBlob**: `[Rect]`.\n\n  rect in blob coordinates.\n\n- **size**: `Size`.\n\n  original input image size.\n\n##### Return\n- **rImg**: `[Rect]`.\n\n  result rect in image coordinates.\n\nPython prototype (for reference only):\n```python3\nblobRectsToImageRects(rBlob, size) -> rImg\n```","ref":"Evision.DNN.Image2BlobParams.html#blobRectsToImageRects/3"},{"type":"function","title":"Evision.DNN.Image2BlobParams.blobRectToImageRect/1","doc":"","ref":"Evision.DNN.Image2BlobParams.html#blobRectToImageRect/1"},{"type":"function","title":"Evision.DNN.Image2BlobParams.blobRectToImageRect/3","doc":"Get rectangle coordinates in original image system from rectangle in blob coordinates.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Image2BlobParams.t()`\n- **rBlob**: `Rect`.\n\n  rect in blob coordinates.\n\n- **size**: `Size`.\n\n  original input image size.\n\n##### Return\n- **retval**: `Rect`\n\n@returns rectangle in original image coordinates.\n\nPython prototype (for reference only):\n```python3\nblobRectToImageRect(rBlob, size) -> retval\n```","ref":"Evision.DNN.Image2BlobParams.html#blobRectToImageRect/3"},{"type":"function","title":"Evision.DNN.Image2BlobParams.get_borderValue/1","doc":"","ref":"Evision.DNN.Image2BlobParams.html#get_borderValue/1"},{"type":"function","title":"Evision.DNN.Image2BlobParams.get_datalayout/1","doc":"","ref":"Evision.DNN.Image2BlobParams.html#get_datalayout/1"},{"type":"function","title":"Evision.DNN.Image2BlobParams.get_ddepth/1","doc":"","ref":"Evision.DNN.Image2BlobParams.html#get_ddepth/1"},{"type":"function","title":"Evision.DNN.Image2BlobParams.get_mean/1","doc":"","ref":"Evision.DNN.Image2BlobParams.html#get_mean/1"},{"type":"function","title":"Evision.DNN.Image2BlobParams.get_paddingmode/1","doc":"","ref":"Evision.DNN.Image2BlobParams.html#get_paddingmode/1"},{"type":"function","title":"Evision.DNN.Image2BlobParams.get_scalefactor/1","doc":"","ref":"Evision.DNN.Image2BlobParams.html#get_scalefactor/1"},{"type":"function","title":"Evision.DNN.Image2BlobParams.get_size/1","doc":"","ref":"Evision.DNN.Image2BlobParams.html#get_size/1"},{"type":"function","title":"Evision.DNN.Image2BlobParams.get_swapRB/1","doc":"","ref":"Evision.DNN.Image2BlobParams.html#get_swapRB/1"},{"type":"function","title":"Evision.DNN.Image2BlobParams.image2BlobParams/0","doc":"Image2BlobParams\n##### Return\n- **self**: `Image2BlobParams`\n\nPython prototype (for reference only):\n```python3\nImage2BlobParams() ->  \n```","ref":"Evision.DNN.Image2BlobParams.html#image2BlobParams/0"},{"type":"function","title":"Evision.DNN.Image2BlobParams.image2BlobParams/1","doc":"Image2BlobParams\n\n##### Positional Arguments\n- **scalefactor**: `Evision.scalar()`\n\n##### Keyword Arguments\n- **size**: `Size`.\n- **mean**: `Evision.scalar()`.\n- **swapRB**: `bool`.\n- **ddepth**: `integer()`.\n- **datalayout**: `DataLayout`.\n- **mode**: `ImagePaddingMode`.\n- **borderValue**: `Evision.scalar()`.\n\n##### Return\n- **self**: `Image2BlobParams`\n\nPython prototype (for reference only):\n```python3\nImage2BlobParams(scalefactor[, size[, mean[, swapRB[, ddepth[, datalayout[, mode[, borderValue]]]]]]]) ->  \n```","ref":"Evision.DNN.Image2BlobParams.html#image2BlobParams/1"},{"type":"function","title":"Evision.DNN.Image2BlobParams.image2BlobParams/2","doc":"Image2BlobParams\n\n##### Positional Arguments\n- **scalefactor**: `Evision.scalar()`\n\n##### Keyword Arguments\n- **size**: `Size`.\n- **mean**: `Evision.scalar()`.\n- **swapRB**: `bool`.\n- **ddepth**: `integer()`.\n- **datalayout**: `DataLayout`.\n- **mode**: `ImagePaddingMode`.\n- **borderValue**: `Evision.scalar()`.\n\n##### Return\n- **self**: `Image2BlobParams`\n\nPython prototype (for reference only):\n```python3\nImage2BlobParams(scalefactor[, size[, mean[, swapRB[, ddepth[, datalayout[, mode[, borderValue]]]]]]]) ->  \n```","ref":"Evision.DNN.Image2BlobParams.html#image2BlobParams/2"},{"type":"function","title":"Evision.DNN.Image2BlobParams.set_borderValue/2","doc":"","ref":"Evision.DNN.Image2BlobParams.html#set_borderValue/2"},{"type":"function","title":"Evision.DNN.Image2BlobParams.set_datalayout/2","doc":"","ref":"Evision.DNN.Image2BlobParams.html#set_datalayout/2"},{"type":"function","title":"Evision.DNN.Image2BlobParams.set_ddepth/2","doc":"","ref":"Evision.DNN.Image2BlobParams.html#set_ddepth/2"},{"type":"function","title":"Evision.DNN.Image2BlobParams.set_mean/2","doc":"","ref":"Evision.DNN.Image2BlobParams.html#set_mean/2"},{"type":"function","title":"Evision.DNN.Image2BlobParams.set_paddingmode/2","doc":"","ref":"Evision.DNN.Image2BlobParams.html#set_paddingmode/2"},{"type":"function","title":"Evision.DNN.Image2BlobParams.set_scalefactor/2","doc":"","ref":"Evision.DNN.Image2BlobParams.html#set_scalefactor/2"},{"type":"function","title":"Evision.DNN.Image2BlobParams.set_size/2","doc":"","ref":"Evision.DNN.Image2BlobParams.html#set_size/2"},{"type":"function","title":"Evision.DNN.Image2BlobParams.set_swapRB/2","doc":"","ref":"Evision.DNN.Image2BlobParams.html#set_swapRB/2"},{"type":"type","title":"Evision.DNN.Image2BlobParams.t/0","doc":"Type that represents an `DNN.Image2BlobParams` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.DNN.Image2BlobParams.html#t:t/0"},{"type":"module","title":"Evision.DNN.ImagePaddingMode","doc":"","ref":"Evision.DNN.ImagePaddingMode.html"},{"type":"function","title":"Evision.DNN.ImagePaddingMode.cv_DNN_PMODE_CROP_CENTER/0","doc":"","ref":"Evision.DNN.ImagePaddingMode.html#cv_DNN_PMODE_CROP_CENTER/0"},{"type":"function","title":"Evision.DNN.ImagePaddingMode.cv_DNN_PMODE_LETTERBOX/0","doc":"","ref":"Evision.DNN.ImagePaddingMode.html#cv_DNN_PMODE_LETTERBOX/0"},{"type":"function","title":"Evision.DNN.ImagePaddingMode.cv_DNN_PMODE_NULL/0","doc":"","ref":"Evision.DNN.ImagePaddingMode.html#cv_DNN_PMODE_NULL/0"},{"type":"type","title":"Evision.DNN.ImagePaddingMode.enum/0","doc":"","ref":"Evision.DNN.ImagePaddingMode.html#t:enum/0"},{"type":"module","title":"Evision.DNN.KeypointsModel","doc":"","ref":"Evision.DNN.KeypointsModel.html"},{"type":"function","title":"Evision.DNN.KeypointsModel.enableWinograd/1","doc":"","ref":"Evision.DNN.KeypointsModel.html#enableWinograd/1"},{"type":"function","title":"Evision.DNN.KeypointsModel.enableWinograd/2","doc":"enableWinograd\n\n##### Positional Arguments\n- **self**: `Evision.DNN.KeypointsModel.t()`\n- **useWinograd**: `bool`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nenableWinograd(useWinograd) -> retval\n```","ref":"Evision.DNN.KeypointsModel.html#enableWinograd/2"},{"type":"function","title":"Evision.DNN.KeypointsModel.estimate/1","doc":"","ref":"Evision.DNN.KeypointsModel.html#estimate/1"},{"type":"function","title":"Evision.DNN.KeypointsModel.estimate/2","doc":"Given the @p input frame, create input blob, run net\n\n##### Positional Arguments\n- **self**: `Evision.DNN.KeypointsModel.t()`\n- **frame**: `Evision.Mat`\n\n##### Keyword Arguments\n- **thresh**: `float`.\n\n  minimum confidence threshold to select a keypoint\n\n##### Return\n- **retval**: `[Point2f]`\n\n@returns a vector holding the x and y coordinates of each detected keypoint\n\nPython prototype (for reference only):\n```python3\nestimate(frame[, thresh]) -> retval\n```","ref":"Evision.DNN.KeypointsModel.html#estimate/2"},{"type":"function","title":"Evision.DNN.KeypointsModel.estimate/3","doc":"Given the @p input frame, create input blob, run net\n\n##### Positional Arguments\n- **self**: `Evision.DNN.KeypointsModel.t()`\n- **frame**: `Evision.Mat`\n\n##### Keyword Arguments\n- **thresh**: `float`.\n\n  minimum confidence threshold to select a keypoint\n\n##### Return\n- **retval**: `[Point2f]`\n\n@returns a vector holding the x and y coordinates of each detected keypoint\n\nPython prototype (for reference only):\n```python3\nestimate(frame[, thresh]) -> retval\n```","ref":"Evision.DNN.KeypointsModel.html#estimate/3"},{"type":"function","title":"Evision.DNN.KeypointsModel.keypointsModel/1","doc":"#### Variant 1:\nCreate model from deep learning network.\n\n##### Positional Arguments\n- **network**: `Evision.DNN.Net.t()`.\n\n  Net object.\n\n##### Return\n- **self**: `Evision.DNN.KeypointsModel.t()`\n\nPython prototype (for reference only):\n```python3\nKeypointsModel(network) ->  \n```\n#### Variant 2:\nCreate keypoints model from network represented in one of the supported formats.\nAn order of @p model and @p config arguments does not matter.\n\n##### Positional Arguments\n- **model**: `String`.\n\n  Binary file contains trained weights.\n\n##### Keyword Arguments\n- **config**: `String`.\n\n  Text file contains network configuration.\n\n##### Return\n- **self**: `Evision.DNN.KeypointsModel.t()`\n\nPython prototype (for reference only):\n```python3\nKeypointsModel(model[, config]) ->  \n```","ref":"Evision.DNN.KeypointsModel.html#keypointsModel/1"},{"type":"function","title":"Evision.DNN.KeypointsModel.keypointsModel/2","doc":"Create keypoints model from network represented in one of the supported formats.\nAn order of @p model and @p config arguments does not matter.\n\n##### Positional Arguments\n- **model**: `String`.\n\n  Binary file contains trained weights.\n\n##### Keyword Arguments\n- **config**: `String`.\n\n  Text file contains network configuration.\n\n##### Return\n- **self**: `Evision.DNN.KeypointsModel.t()`\n\nPython prototype (for reference only):\n```python3\nKeypointsModel(model[, config]) ->  \n```","ref":"Evision.DNN.KeypointsModel.html#keypointsModel/2"},{"type":"function","title":"Evision.DNN.KeypointsModel.predict/1","doc":"","ref":"Evision.DNN.KeypointsModel.html#predict/1"},{"type":"function","title":"Evision.DNN.KeypointsModel.predict/2","doc":"Given the @p input frame, create input blob, run net and return the output @p blobs.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.KeypointsModel.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **outs**: `[Evision.Mat]`.\n\n  Allocated output blobs, which will store results of the computation.\n\nPython prototype (for reference only):\n```python3\npredict(frame[, outs]) -> outs\n```","ref":"Evision.DNN.KeypointsModel.html#predict/2"},{"type":"function","title":"Evision.DNN.KeypointsModel.predict/3","doc":"Given the @p input frame, create input blob, run net and return the output @p blobs.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.KeypointsModel.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **outs**: `[Evision.Mat]`.\n\n  Allocated output blobs, which will store results of the computation.\n\nPython prototype (for reference only):\n```python3\npredict(frame[, outs]) -> outs\n```","ref":"Evision.DNN.KeypointsModel.html#predict/3"},{"type":"function","title":"Evision.DNN.KeypointsModel.setInputCrop/1","doc":"","ref":"Evision.DNN.KeypointsModel.html#setInputCrop/1"},{"type":"function","title":"Evision.DNN.KeypointsModel.setInputCrop/2","doc":"Set flag crop for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.KeypointsModel.t()`\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputCrop(crop) -> retval\n```","ref":"Evision.DNN.KeypointsModel.html#setInputCrop/2"},{"type":"function","title":"Evision.DNN.KeypointsModel.setInputMean/1","doc":"","ref":"Evision.DNN.KeypointsModel.html#setInputMean/1"},{"type":"function","title":"Evision.DNN.KeypointsModel.setInputMean/2","doc":"Set mean value for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.KeypointsModel.t()`\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputMean(mean) -> retval\n```","ref":"Evision.DNN.KeypointsModel.html#setInputMean/2"},{"type":"function","title":"Evision.DNN.KeypointsModel.setInputParams/1","doc":"Set preprocessing parameters for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.KeypointsModel.t()`\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Multiplier for frame values.\n\n- **size**: `Size`.\n\n  New input size.\n\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n  blob(n, c, y, x) = scale * resize( frame(y, x, c) ) - mean(c) )\n\nPython prototype (for reference only):\n```python3\nsetInputParams([, scale[, size[, mean[, swapRB[, crop]]]]]) -> None\n```","ref":"Evision.DNN.KeypointsModel.html#setInputParams/1"},{"type":"function","title":"Evision.DNN.KeypointsModel.setInputParams/2","doc":"Set preprocessing parameters for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.KeypointsModel.t()`\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Multiplier for frame values.\n\n- **size**: `Size`.\n\n  New input size.\n\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n  blob(n, c, y, x) = scale * resize( frame(y, x, c) ) - mean(c) )\n\nPython prototype (for reference only):\n```python3\nsetInputParams([, scale[, size[, mean[, swapRB[, crop]]]]]) -> None\n```","ref":"Evision.DNN.KeypointsModel.html#setInputParams/2"},{"type":"function","title":"Evision.DNN.KeypointsModel.setInputScale/1","doc":"","ref":"Evision.DNN.KeypointsModel.html#setInputScale/1"},{"type":"function","title":"Evision.DNN.KeypointsModel.setInputScale/2","doc":"Set scalefactor value for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.KeypointsModel.t()`\n- **scale**: `Evision.scalar()`.\n\n  Multiplier for frame values.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputScale(scale) -> retval\n```","ref":"Evision.DNN.KeypointsModel.html#setInputScale/2"},{"type":"function","title":"Evision.DNN.KeypointsModel.setInputSize/1","doc":"","ref":"Evision.DNN.KeypointsModel.html#setInputSize/1"},{"type":"function","title":"Evision.DNN.KeypointsModel.setInputSize/2","doc":"Set input size for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.KeypointsModel.t()`\n- **size**: `Size`.\n\n  New input size.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\n**Note**: If shape of the new blob less than 0, then frame size not change.\n\nPython prototype (for reference only):\n```python3\nsetInputSize(size) -> retval\n```","ref":"Evision.DNN.KeypointsModel.html#setInputSize/2"},{"type":"function","title":"Evision.DNN.KeypointsModel.setInputSize/3","doc":"setInputSize\n\n##### Positional Arguments\n- **self**: `Evision.DNN.KeypointsModel.t()`\n- **width**: `integer()`.\n\n  New input width.\n\n- **height**: `integer()`.\n\n  New input height.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nsetInputSize(width, height) -> retval\n```","ref":"Evision.DNN.KeypointsModel.html#setInputSize/3"},{"type":"function","title":"Evision.DNN.KeypointsModel.setInputSwapRB/1","doc":"","ref":"Evision.DNN.KeypointsModel.html#setInputSwapRB/1"},{"type":"function","title":"Evision.DNN.KeypointsModel.setInputSwapRB/2","doc":"Set flag swapRB for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.KeypointsModel.t()`\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputSwapRB(swapRB) -> retval\n```","ref":"Evision.DNN.KeypointsModel.html#setInputSwapRB/2"},{"type":"function","title":"Evision.DNN.KeypointsModel.setOutputNames/1","doc":"","ref":"Evision.DNN.KeypointsModel.html#setOutputNames/1"},{"type":"function","title":"Evision.DNN.KeypointsModel.setOutputNames/2","doc":"Set output names for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.KeypointsModel.t()`\n- **outNames**: `[String]`.\n\n  Names for output layers.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetOutputNames(outNames) -> retval\n```","ref":"Evision.DNN.KeypointsModel.html#setOutputNames/2"},{"type":"function","title":"Evision.DNN.KeypointsModel.setPreferableBackend/1","doc":"","ref":"Evision.DNN.KeypointsModel.html#setPreferableBackend/1"},{"type":"function","title":"Evision.DNN.KeypointsModel.setPreferableBackend/2","doc":"setPreferableBackend\n\n##### Positional Arguments\n- **self**: `Evision.DNN.KeypointsModel.t()`\n- **backendId**: `dnn_Backend`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetPreferableBackend(backendId) -> retval\n```","ref":"Evision.DNN.KeypointsModel.html#setPreferableBackend/2"},{"type":"function","title":"Evision.DNN.KeypointsModel.setPreferableTarget/1","doc":"","ref":"Evision.DNN.KeypointsModel.html#setPreferableTarget/1"},{"type":"function","title":"Evision.DNN.KeypointsModel.setPreferableTarget/2","doc":"setPreferableTarget\n\n##### Positional Arguments\n- **self**: `Evision.DNN.KeypointsModel.t()`\n- **targetId**: `dnn_Target`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetPreferableTarget(targetId) -> retval\n```","ref":"Evision.DNN.KeypointsModel.html#setPreferableTarget/2"},{"type":"type","title":"Evision.DNN.KeypointsModel.t/0","doc":"Type that represents an `DNN.KeypointsModel` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.DNN.KeypointsModel.html#t:t/0"},{"type":"module","title":"Evision.DNN.Layer","doc":"","ref":"Evision.DNN.Layer.html"},{"type":"function","title":"Evision.DNN.Layer.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Layer.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.DNN.Layer.html#clear/1"},{"type":"function","title":"Evision.DNN.Layer.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Layer.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.DNN.Layer.html#empty/1"},{"type":"function","title":"Evision.DNN.Layer.finalize/1","doc":"","ref":"Evision.DNN.Layer.html#finalize/1"},{"type":"function","title":"Evision.DNN.Layer.finalize/2","doc":"Computes and sets internal parameters according to inputs, outputs and blobs.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Layer.t()`\n- **inputs**: `[Evision.Mat]`\n\n##### Return\n- **outputs**: `[Evision.Mat]`.\n\n  vector of already allocated output blobs\n\n This method is called after network has allocated all memory for input and output blobs\n and before inferencing.\n\nPython prototype (for reference only):\n```python3\nfinalize(inputs[, outputs]) -> outputs\n```","ref":"Evision.DNN.Layer.html#finalize/2"},{"type":"function","title":"Evision.DNN.Layer.finalize/3","doc":"Computes and sets internal parameters according to inputs, outputs and blobs.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Layer.t()`\n- **inputs**: `[Evision.Mat]`\n\n##### Return\n- **outputs**: `[Evision.Mat]`.\n\n  vector of already allocated output blobs\n\n This method is called after network has allocated all memory for input and output blobs\n and before inferencing.\n\nPython prototype (for reference only):\n```python3\nfinalize(inputs[, outputs]) -> outputs\n```","ref":"Evision.DNN.Layer.html#finalize/3"},{"type":"function","title":"Evision.DNN.Layer.get_blobs/1","doc":"","ref":"Evision.DNN.Layer.html#get_blobs/1"},{"type":"function","title":"Evision.DNN.Layer.get_name/1","doc":"","ref":"Evision.DNN.Layer.html#get_name/1"},{"type":"function","title":"Evision.DNN.Layer.get_preferableTarget/1","doc":"","ref":"Evision.DNN.Layer.html#get_preferableTarget/1"},{"type":"function","title":"Evision.DNN.Layer.get_type/1","doc":"","ref":"Evision.DNN.Layer.html#get_type/1"},{"type":"function","title":"Evision.DNN.Layer.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Layer.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.DNN.Layer.html#getDefaultName/1"},{"type":"function","title":"Evision.DNN.Layer.outputNameToIndex/1","doc":"","ref":"Evision.DNN.Layer.html#outputNameToIndex/1"},{"type":"function","title":"Evision.DNN.Layer.outputNameToIndex/2","doc":"Returns index of output blob in output array.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Layer.t()`\n- **outputName**: `String`\n\n##### Return\n- **retval**: `integer()`\n\n@see inputNameToIndex()\n\nPython prototype (for reference only):\n```python3\noutputNameToIndex(outputName) -> retval\n```","ref":"Evision.DNN.Layer.html#outputNameToIndex/2"},{"type":"function","title":"Evision.DNN.Layer.read/1","doc":"","ref":"Evision.DNN.Layer.html#read/1"},{"type":"function","title":"Evision.DNN.Layer.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Layer.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.DNN.Layer.html#read/2"},{"type":"function","title":"Evision.DNN.Layer.run/1","doc":"","ref":"Evision.DNN.Layer.html#run/1"},{"type":"function","title":"Evision.DNN.Layer.run/3","doc":"Allocates layer and computes output.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Layer.t()`\n- **inputs**: `[Evision.Mat]`\n\n##### Return\n- **outputs**: `[Evision.Mat]`.\n- **internals**: `[Evision.Mat]`\n\n@deprecated This method will be removed in the future release.\n\nPython prototype (for reference only):\n```python3\nrun(inputs, internals[, outputs]) -> outputs, internals\n```","ref":"Evision.DNN.Layer.html#run/3"},{"type":"function","title":"Evision.DNN.Layer.run/4","doc":"Allocates layer and computes output.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Layer.t()`\n- **inputs**: `[Evision.Mat]`\n\n##### Return\n- **outputs**: `[Evision.Mat]`.\n- **internals**: `[Evision.Mat]`\n\n@deprecated This method will be removed in the future release.\n\nPython prototype (for reference only):\n```python3\nrun(inputs, internals[, outputs]) -> outputs, internals\n```","ref":"Evision.DNN.Layer.html#run/4"},{"type":"function","title":"Evision.DNN.Layer.save/1","doc":"","ref":"Evision.DNN.Layer.html#save/1"},{"type":"function","title":"Evision.DNN.Layer.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Layer.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.DNN.Layer.html#save/2"},{"type":"function","title":"Evision.DNN.Layer.set_blobs/2","doc":"","ref":"Evision.DNN.Layer.html#set_blobs/2"},{"type":"function","title":"Evision.DNN.Layer.write/1","doc":"","ref":"Evision.DNN.Layer.html#write/1"},{"type":"function","title":"Evision.DNN.Layer.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Layer.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.DNN.Layer.html#write/2"},{"type":"function","title":"Evision.DNN.Layer.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Layer.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.DNN.Layer.html#write/3"},{"type":"type","title":"Evision.DNN.Layer.t/0","doc":"Type that represents an `DNN.Layer` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.DNN.Layer.html#t:t/0"},{"type":"module","title":"Evision.DNN.Model","doc":"","ref":"Evision.DNN.Model.html"},{"type":"function","title":"Evision.DNN.Model.enableWinograd/1","doc":"","ref":"Evision.DNN.Model.html#enableWinograd/1"},{"type":"function","title":"Evision.DNN.Model.enableWinograd/2","doc":"enableWinograd\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Model.t()`\n- **useWinograd**: `bool`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nenableWinograd(useWinograd) -> retval\n```","ref":"Evision.DNN.Model.html#enableWinograd/2"},{"type":"function","title":"Evision.DNN.Model.model/1","doc":"#### Variant 1:\nCreate model from deep learning network.\n\n##### Positional Arguments\n- **network**: `Evision.DNN.Net.t()`.\n\n  Net object.\n\n##### Return\n- **self**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nModel(network) ->  \n```\n#### Variant 2:\nCreate model from deep learning network represented in one of the supported formats.\nAn order of @p model and @p config arguments does not matter.\n\n##### Positional Arguments\n- **model**: `String`.\n\n  Binary file contains trained weights.\n\n##### Keyword Arguments\n- **config**: `String`.\n\n  Text file contains network configuration.\n\n##### Return\n- **self**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nModel(model[, config]) ->  \n```","ref":"Evision.DNN.Model.html#model/1"},{"type":"function","title":"Evision.DNN.Model.model/2","doc":"Create model from deep learning network represented in one of the supported formats.\nAn order of @p model and @p config arguments does not matter.\n\n##### Positional Arguments\n- **model**: `String`.\n\n  Binary file contains trained weights.\n\n##### Keyword Arguments\n- **config**: `String`.\n\n  Text file contains network configuration.\n\n##### Return\n- **self**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nModel(model[, config]) ->  \n```","ref":"Evision.DNN.Model.html#model/2"},{"type":"function","title":"Evision.DNN.Model.predict/1","doc":"","ref":"Evision.DNN.Model.html#predict/1"},{"type":"function","title":"Evision.DNN.Model.predict/2","doc":"Given the @p input frame, create input blob, run net and return the output @p blobs.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Model.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **outs**: `[Evision.Mat]`.\n\n  Allocated output blobs, which will store results of the computation.\n\nPython prototype (for reference only):\n```python3\npredict(frame[, outs]) -> outs\n```","ref":"Evision.DNN.Model.html#predict/2"},{"type":"function","title":"Evision.DNN.Model.predict/3","doc":"Given the @p input frame, create input blob, run net and return the output @p blobs.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Model.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **outs**: `[Evision.Mat]`.\n\n  Allocated output blobs, which will store results of the computation.\n\nPython prototype (for reference only):\n```python3\npredict(frame[, outs]) -> outs\n```","ref":"Evision.DNN.Model.html#predict/3"},{"type":"function","title":"Evision.DNN.Model.setInputCrop/1","doc":"","ref":"Evision.DNN.Model.html#setInputCrop/1"},{"type":"function","title":"Evision.DNN.Model.setInputCrop/2","doc":"Set flag crop for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Model.t()`\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputCrop(crop) -> retval\n```","ref":"Evision.DNN.Model.html#setInputCrop/2"},{"type":"function","title":"Evision.DNN.Model.setInputMean/1","doc":"","ref":"Evision.DNN.Model.html#setInputMean/1"},{"type":"function","title":"Evision.DNN.Model.setInputMean/2","doc":"Set mean value for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Model.t()`\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputMean(mean) -> retval\n```","ref":"Evision.DNN.Model.html#setInputMean/2"},{"type":"function","title":"Evision.DNN.Model.setInputParams/1","doc":"Set preprocessing parameters for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Model.t()`\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Multiplier for frame values.\n\n- **size**: `Size`.\n\n  New input size.\n\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n  blob(n, c, y, x) = scale * resize( frame(y, x, c) ) - mean(c) )\n\nPython prototype (for reference only):\n```python3\nsetInputParams([, scale[, size[, mean[, swapRB[, crop]]]]]) -> None\n```","ref":"Evision.DNN.Model.html#setInputParams/1"},{"type":"function","title":"Evision.DNN.Model.setInputParams/2","doc":"Set preprocessing parameters for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Model.t()`\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Multiplier for frame values.\n\n- **size**: `Size`.\n\n  New input size.\n\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n  blob(n, c, y, x) = scale * resize( frame(y, x, c) ) - mean(c) )\n\nPython prototype (for reference only):\n```python3\nsetInputParams([, scale[, size[, mean[, swapRB[, crop]]]]]) -> None\n```","ref":"Evision.DNN.Model.html#setInputParams/2"},{"type":"function","title":"Evision.DNN.Model.setInputScale/1","doc":"","ref":"Evision.DNN.Model.html#setInputScale/1"},{"type":"function","title":"Evision.DNN.Model.setInputScale/2","doc":"Set scalefactor value for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Model.t()`\n- **scale**: `Evision.scalar()`.\n\n  Multiplier for frame values.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputScale(scale) -> retval\n```","ref":"Evision.DNN.Model.html#setInputScale/2"},{"type":"function","title":"Evision.DNN.Model.setInputSize/1","doc":"","ref":"Evision.DNN.Model.html#setInputSize/1"},{"type":"function","title":"Evision.DNN.Model.setInputSize/2","doc":"Set input size for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Model.t()`\n- **size**: `Size`.\n\n  New input size.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\n**Note**: If shape of the new blob less than 0, then frame size not change.\n\nPython prototype (for reference only):\n```python3\nsetInputSize(size) -> retval\n```","ref":"Evision.DNN.Model.html#setInputSize/2"},{"type":"function","title":"Evision.DNN.Model.setInputSize/3","doc":"setInputSize\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Model.t()`\n- **width**: `integer()`.\n\n  New input width.\n\n- **height**: `integer()`.\n\n  New input height.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nsetInputSize(width, height) -> retval\n```","ref":"Evision.DNN.Model.html#setInputSize/3"},{"type":"function","title":"Evision.DNN.Model.setInputSwapRB/1","doc":"","ref":"Evision.DNN.Model.html#setInputSwapRB/1"},{"type":"function","title":"Evision.DNN.Model.setInputSwapRB/2","doc":"Set flag swapRB for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Model.t()`\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputSwapRB(swapRB) -> retval\n```","ref":"Evision.DNN.Model.html#setInputSwapRB/2"},{"type":"function","title":"Evision.DNN.Model.setOutputNames/1","doc":"","ref":"Evision.DNN.Model.html#setOutputNames/1"},{"type":"function","title":"Evision.DNN.Model.setOutputNames/2","doc":"Set output names for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Model.t()`\n- **outNames**: `[String]`.\n\n  Names for output layers.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetOutputNames(outNames) -> retval\n```","ref":"Evision.DNN.Model.html#setOutputNames/2"},{"type":"function","title":"Evision.DNN.Model.setPreferableBackend/1","doc":"","ref":"Evision.DNN.Model.html#setPreferableBackend/1"},{"type":"function","title":"Evision.DNN.Model.setPreferableBackend/2","doc":"setPreferableBackend\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Model.t()`\n- **backendId**: `dnn_Backend`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetPreferableBackend(backendId) -> retval\n```","ref":"Evision.DNN.Model.html#setPreferableBackend/2"},{"type":"function","title":"Evision.DNN.Model.setPreferableTarget/1","doc":"","ref":"Evision.DNN.Model.html#setPreferableTarget/1"},{"type":"function","title":"Evision.DNN.Model.setPreferableTarget/2","doc":"setPreferableTarget\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Model.t()`\n- **targetId**: `dnn_Target`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetPreferableTarget(targetId) -> retval\n```","ref":"Evision.DNN.Model.html#setPreferableTarget/2"},{"type":"type","title":"Evision.DNN.Model.t/0","doc":"Type that represents an `DNN.Model` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.DNN.Model.html#t:t/0"},{"type":"module","title":"Evision.DNN.Net","doc":"","ref":"Evision.DNN.Net.html"},{"type":"function","title":"Evision.DNN.Net.connect/1","doc":"","ref":"Evision.DNN.Net.html#connect/1"},{"type":"function","title":"Evision.DNN.Net.connect/3","doc":"Connects output of the first layer to input of the second layer.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **outPin**: `String`.\n\n  descriptor of the first layer output.\n\n- **inpPin**: `String`.\n\n  descriptor of the second layer input.\n\n Descriptors have the following template  &lt;layer_name&gt;[.input_number] :\n- the first part of the template  layer_name  is string name of the added layer.\n  If this part is empty then the network input pseudo layer will be used;\n\n- the second optional part of the template  input_number \n  is either number of the layer input, either label one.\n  If this part is omitted then the first layer input will be used.\n\n@see setNetInputs(), Layer::inputNameToIndex(), Layer::outputNameToIndex()\n\nPython prototype (for reference only):\n```python3\nconnect(outPin, inpPin) -> None\n```","ref":"Evision.DNN.Net.html#connect/3"},{"type":"function","title":"Evision.DNN.Net.dump/1","doc":"Dump net to String\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n\n##### Return\n- **retval**: `String`\n\n@returns String with structure, hyperparameters, backend, target and fusion\n  Call method after setInput(). To see correct backend, target and fusion run after forward().\n\nPython prototype (for reference only):\n```python3\ndump() -> retval\n```","ref":"Evision.DNN.Net.html#dump/1"},{"type":"function","title":"Evision.DNN.Net.dumpToFile/1","doc":"","ref":"Evision.DNN.Net.html#dumpToFile/1"},{"type":"function","title":"Evision.DNN.Net.dumpToFile/2","doc":"Dump net structure, hyperparameters, backend, target and fusion to dot file\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **path**: `String`.\n\n  path to output file with .dot extension\n\n@see dump()\n\nPython prototype (for reference only):\n```python3\ndumpToFile(path) -> None\n```","ref":"Evision.DNN.Net.html#dumpToFile/2"},{"type":"function","title":"Evision.DNN.Net.dumpToPbtxt/1","doc":"","ref":"Evision.DNN.Net.html#dumpToPbtxt/1"},{"type":"function","title":"Evision.DNN.Net.dumpToPbtxt/2","doc":"Dump net structure, hyperparameters, backend, target and fusion to pbtxt file\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **path**: `String`.\n\n  path to output file with .pbtxt extension\n\n  Use Netron (https://netron.app) to open the target file to visualize the model.\n  Call method after setInput(). To see correct backend, target and fusion run after forward().\n\nPython prototype (for reference only):\n```python3\ndumpToPbtxt(path) -> None\n```","ref":"Evision.DNN.Net.html#dumpToPbtxt/2"},{"type":"function","title":"Evision.DNN.Net.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n\n##### Return\n- **retval**: `bool`\n\nReturns true if there are no layers in the network.\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.DNN.Net.html#empty/1"},{"type":"function","title":"Evision.DNN.Net.enableFusion/1","doc":"","ref":"Evision.DNN.Net.html#enableFusion/1"},{"type":"function","title":"Evision.DNN.Net.enableFusion/2","doc":"Enables or disables layer fusion in the network.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **fusion**: `bool`.\n\n  true to enable the fusion, false to disable. The fusion is enabled by default.\n\nPython prototype (for reference only):\n```python3\nenableFusion(fusion) -> None\n```","ref":"Evision.DNN.Net.html#enableFusion/2"},{"type":"function","title":"Evision.DNN.Net.enableWinograd/1","doc":"","ref":"Evision.DNN.Net.html#enableWinograd/1"},{"type":"function","title":"Evision.DNN.Net.enableWinograd/2","doc":"Enables or disables the Winograd compute branch. The Winograd compute branch can speed up\n3x3 Convolution at a small loss of accuracy.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **useWinograd**: `bool`.\n\n  true to enable the Winograd compute branch. The default is true.\n\nPython prototype (for reference only):\n```python3\nenableWinograd(useWinograd) -> None\n```","ref":"Evision.DNN.Net.html#enableWinograd/2"},{"type":"function","title":"Evision.DNN.Net.forward/2","doc":"Runs forward pass to compute outputs of layers listed in @p outBlobNames.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **outBlobNames**: `[String]`.\n\n  names for layers which outputs are needed to get\n\n##### Return\n- **outputBlobs**: `[Evision.Mat]`.\n\n  contains blobs for first outputs of specified layers.\n\nPython prototype (for reference only):\n```python3\nforward(outBlobNames[, outputBlobs]) -> outputBlobs\n```","ref":"Evision.DNN.Net.html#forward/2"},{"type":"function","title":"Evision.DNN.Net.forwardAndRetrieve/1","doc":"","ref":"Evision.DNN.Net.html#forwardAndRetrieve/1"},{"type":"function","title":"Evision.DNN.Net.forwardAndRetrieve/2","doc":"Runs forward pass to compute outputs of layers listed in @p outBlobNames.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **outBlobNames**: `[String]`.\n\n  names for layers which outputs are needed to get\n\n##### Return\n- **outputBlobs**: `[[Evision.Mat]]`.\n\n  contains all output blobs for each layer specified in @p outBlobNames.\n\nPython prototype (for reference only):\n```python3\nforwardAndRetrieve(outBlobNames) -> outputBlobs\n```","ref":"Evision.DNN.Net.html#forwardAndRetrieve/2"},{"type":"function","title":"Evision.DNN.Net.forwardAsync/1","doc":"Runs forward pass to compute output of layer with name @p outputName.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n\n##### Keyword Arguments\n- **outputName**: `String`.\n\n  name for layer which output is needed to get\n\n##### Return\n- **retval**: `Evision.AsyncArray.t()`\n\n@details By default runs forward pass for the whole network.\n  This is an asynchronous version of forward(const String&).\n  dnn::DNN_BACKEND_INFERENCE_ENGINE backend is required.\n\nPython prototype (for reference only):\n```python3\nforwardAsync([, outputName]) -> retval\n```","ref":"Evision.DNN.Net.html#forwardAsync/1"},{"type":"function","title":"Evision.DNN.Net.forwardAsync/2","doc":"Runs forward pass to compute output of layer with name @p outputName.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n\n##### Keyword Arguments\n- **outputName**: `String`.\n\n  name for layer which output is needed to get\n\n##### Return\n- **retval**: `Evision.AsyncArray.t()`\n\n@details By default runs forward pass for the whole network.\n  This is an asynchronous version of forward(const String&).\n  dnn::DNN_BACKEND_INFERENCE_ENGINE backend is required.\n\nPython prototype (for reference only):\n```python3\nforwardAsync([, outputName]) -> retval\n```","ref":"Evision.DNN.Net.html#forwardAsync/2"},{"type":"function","title":"Evision.DNN.Net.getFLOPS/1","doc":"","ref":"Evision.DNN.Net.html#getFLOPS/1"},{"type":"function","title":"Evision.DNN.Net.getFLOPS/2","doc":"getFLOPS\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **netInputShape**: `MatShape`\n\n##### Return\n- **retval**: `int64`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ngetFLOPS(netInputShape) -> retval\n```","ref":"Evision.DNN.Net.html#getFLOPS/2"},{"type":"function","title":"Evision.DNN.Net.getFLOPS/3","doc":"getFLOPS\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **layerId**: `integer()`\n- **netInputShape**: `MatShape`\n\n##### Return\n- **retval**: `int64`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ngetFLOPS(layerId, netInputShape) -> retval\n```","ref":"Evision.DNN.Net.html#getFLOPS/3"},{"type":"function","title":"Evision.DNN.Net.getInputDetails/1","doc":"Returns input scale and zeropoint for a quantized Net.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n\n##### Return\n- **scales**: `[float]`.\n\n  output parameter for returning input scales.\n\n- **zeropoints**: `[integer()]`.\n\n  output parameter for returning input zeropoints.\n\nPython prototype (for reference only):\n```python3\ngetInputDetails() -> scales, zeropoints\n```","ref":"Evision.DNN.Net.html#getInputDetails/1"},{"type":"function","title":"Evision.DNN.Net.getLayer/1","doc":"","ref":"Evision.DNN.Net.html#getLayer/1"},{"type":"function","title":"Evision.DNN.Net.getLayer/2","doc":"#### Variant 1:\ngetLayer\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **layerId**: `LayerId`\n\n##### Return\n- **retval**: `Evision.DNN.Layer.t()`\n\nHas overloading in C++\n\n@deprecated to be removed\n\nPython prototype (for reference only):\n```python3\ngetLayer(layerId) -> retval\n```\n#### Variant 2:\ngetLayer\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **layerName**: `String`\n\n##### Return\n- **retval**: `Evision.DNN.Layer.t()`\n\nHas overloading in C++\n\n@deprecated Use int getLayerId(const String &layer)\n\nPython prototype (for reference only):\n```python3\ngetLayer(layerName) -> retval\n```\n#### Variant 3:\nReturns pointer to layer with specified id or name which the network use.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **layerId**: `integer()`\n\n##### Return\n- **retval**: `Evision.DNN.Layer.t()`\n\nPython prototype (for reference only):\n```python3\ngetLayer(layerId) -> retval\n```","ref":"Evision.DNN.Net.html#getLayer/2"},{"type":"function","title":"Evision.DNN.Net.getLayerId/1","doc":"","ref":"Evision.DNN.Net.html#getLayerId/1"},{"type":"function","title":"Evision.DNN.Net.getLayerId/2","doc":"Converts string name of the layer to the integer identifier.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **layer**: `String`\n\n##### Return\n- **retval**: `integer()`\n\n@returns id of the layer, or -1 if the layer wasn't found.\n\nPython prototype (for reference only):\n```python3\ngetLayerId(layer) -> retval\n```","ref":"Evision.DNN.Net.html#getLayerId/2"},{"type":"function","title":"Evision.DNN.Net.getLayerNames/1","doc":"getLayerNames\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n\n##### Return\n- **retval**: `[String]`\n\nPython prototype (for reference only):\n```python3\ngetLayerNames() -> retval\n```","ref":"Evision.DNN.Net.html#getLayerNames/1"},{"type":"function","title":"Evision.DNN.Net.getLayerShapes/2","doc":"getLayerShapes\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **netInputShapes**: `[MatShape]`\n- **layerId**: `integer()`\n\n##### Return\n- **inLayerShapes**: `[MatShape]`\n- **outLayerShapes**: `[MatShape]`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ngetLayerShapes(netInputShapes, layerId) -> inLayerShapes, outLayerShapes\n```","ref":"Evision.DNN.Net.html#getLayerShapes/2"},{"type":"function","title":"Evision.DNN.Net.getLayersCount/1","doc":"","ref":"Evision.DNN.Net.html#getLayersCount/1"},{"type":"function","title":"Evision.DNN.Net.getLayersCount/2","doc":"Returns count of layers of specified type.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **layerType**: `String`.\n\n  type.\n\n##### Return\n- **retval**: `integer()`\n\n@returns count of layers\n\nPython prototype (for reference only):\n```python3\ngetLayersCount(layerType) -> retval\n```","ref":"Evision.DNN.Net.html#getLayersCount/2"},{"type":"function","title":"Evision.DNN.Net.getLayersShapes/2","doc":"getLayersShapes\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **netInputShape**: `MatShape`\n\n##### Return\n- **layersIds**: `[integer()]`\n- **inLayersShapes**: `[[MatShape]]`\n- **outLayersShapes**: `[[MatShape]]`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ngetLayersShapes(netInputShape) -> layersIds, inLayersShapes, outLayersShapes\n```","ref":"Evision.DNN.Net.html#getLayersShapes/2"},{"type":"function","title":"Evision.DNN.Net.getLayerTypes/1","doc":"Returns list of types for layer used in model.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n\n##### Return\n- **layersTypes**: `[String]`.\n\n  output parameter for returning types.\n\nPython prototype (for reference only):\n```python3\ngetLayerTypes() -> layersTypes\n```","ref":"Evision.DNN.Net.html#getLayerTypes/1"},{"type":"function","title":"Evision.DNN.Net.getMemoryConsumption/1","doc":"","ref":"Evision.DNN.Net.html#getMemoryConsumption/1"},{"type":"function","title":"Evision.DNN.Net.getMemoryConsumption/2","doc":"getMemoryConsumption\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **netInputShape**: `MatShape`\n\n##### Return\n- **weights**: `size_t`\n- **blobs**: `size_t`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ngetMemoryConsumption(netInputShape) -> weights, blobs\n```","ref":"Evision.DNN.Net.html#getMemoryConsumption/2"},{"type":"function","title":"Evision.DNN.Net.getMemoryConsumption/3","doc":"getMemoryConsumption\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **layerId**: `integer()`\n- **netInputShape**: `MatShape`\n\n##### Return\n- **weights**: `size_t`\n- **blobs**: `size_t`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ngetMemoryConsumption(layerId, netInputShape) -> weights, blobs\n```","ref":"Evision.DNN.Net.html#getMemoryConsumption/3"},{"type":"function","title":"Evision.DNN.Net.getOutputDetails/1","doc":"Returns output scale and zeropoint for a quantized Net.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n\n##### Return\n- **scales**: `[float]`.\n\n  output parameter for returning output scales.\n\n- **zeropoints**: `[integer()]`.\n\n  output parameter for returning output zeropoints.\n\nPython prototype (for reference only):\n```python3\ngetOutputDetails() -> scales, zeropoints\n```","ref":"Evision.DNN.Net.html#getOutputDetails/1"},{"type":"function","title":"Evision.DNN.Net.getParam/1","doc":"","ref":"Evision.DNN.Net.html#getParam/1"},{"type":"function","title":"Evision.DNN.Net.getParam/2","doc":"#### Variant 1:\ngetParam\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **layerName**: `String`\n\n##### Keyword Arguments\n- **numParam**: `integer()`.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetParam(layerName[, numParam]) -> retval\n```\n#### Variant 2:\nReturns parameter blob of the layer.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **layer**: `integer()`.\n\n  name or id of the layer.\n\n##### Keyword Arguments\n- **numParam**: `integer()`.\n\n  index of the layer parameter in the Layer::blobs array.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n@see Layer::blobs\n\nPython prototype (for reference only):\n```python3\ngetParam(layer[, numParam]) -> retval\n```","ref":"Evision.DNN.Net.html#getParam/2"},{"type":"function","title":"Evision.DNN.Net.getParam/3","doc":"#### Variant 1:\ngetParam\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **layerName**: `String`\n\n##### Keyword Arguments\n- **numParam**: `integer()`.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetParam(layerName[, numParam]) -> retval\n```\n#### Variant 2:\nReturns parameter blob of the layer.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **layer**: `integer()`.\n\n  name or id of the layer.\n\n##### Keyword Arguments\n- **numParam**: `integer()`.\n\n  index of the layer parameter in the Layer::blobs array.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n@see Layer::blobs\n\nPython prototype (for reference only):\n```python3\ngetParam(layer[, numParam]) -> retval\n```","ref":"Evision.DNN.Net.html#getParam/3"},{"type":"function","title":"Evision.DNN.Net.getPerfProfile/1","doc":"Returns overall time for inference and timings (in ticks) for layers.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n\n##### Return\n- **retval**: `int64`\n- **timings**: `[double]`.\n\n  vector for tick timings for all layers.\n\n Indexes in returned vector correspond to layers ids. Some layers can be fused with others,\n in this case zero ticks count will be return for that skipped layers. Supported by DNN_BACKEND_OPENCV on DNN_TARGET_CPU only.\n@return overall ticks for model inference.\n\nPython prototype (for reference only):\n```python3\ngetPerfProfile() -> retval, timings\n```","ref":"Evision.DNN.Net.html#getPerfProfile/1"},{"type":"function","title":"Evision.DNN.Net.getUnconnectedOutLayers/1","doc":"Returns indexes of layers with unconnected outputs.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n\n##### Return\n- **retval**: `[integer()]`\n\n FIXIT: Rework API to registerOutput() approach, deprecate this call\n\nPython prototype (for reference only):\n```python3\ngetUnconnectedOutLayers() -> retval\n```","ref":"Evision.DNN.Net.html#getUnconnectedOutLayers/1"},{"type":"function","title":"Evision.DNN.Net.getUnconnectedOutLayersNames/1","doc":"Returns names of layers with unconnected outputs.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n\n##### Return\n- **retval**: `[String]`\n\n FIXIT: Rework API to registerOutput() approach, deprecate this call\n\nPython prototype (for reference only):\n```python3\ngetUnconnectedOutLayersNames() -> retval\n```","ref":"Evision.DNN.Net.html#getUnconnectedOutLayersNames/1"},{"type":"function","title":"Evision.DNN.Net.net/0","doc":"Net\n##### Return\n- **self**: `Evision.DNN.Net.t()`\n\nPython prototype (for reference only):\n```python3\nNet() ->  \n```","ref":"Evision.DNN.Net.html#net/0"},{"type":"function","title":"Evision.DNN.Net.net/1","doc":"","ref":"Evision.DNN.Net.html#net/1"},{"type":"function","title":"Evision.DNN.Net.quantize/1","doc":"","ref":"Evision.DNN.Net.html#quantize/1"},{"type":"function","title":"Evision.DNN.Net.quantize/4","doc":"Returns a quantized Net from a floating-point Net.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **calibData**: `[Evision.Mat]`.\n\n  Calibration data to compute the quantization parameters.\n\n- **inputsDtype**: `integer()`.\n\n  Datatype of quantized net's inputs. Can be CV_32F or CV_8S.\n\n- **outputsDtype**: `integer()`.\n\n  Datatype of quantized net's outputs. Can be CV_32F or CV_8S.\n\n##### Keyword Arguments\n- **perChannel**: `bool`.\n\n  Quantization granularity of quantized Net. The default is true, that means quantize model\n  in per-channel way (channel-wise). Set it false to quantize model in per-tensor way (or tensor-wise).\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\nPython prototype (for reference only):\n```python3\nquantize(calibData, inputsDtype, outputsDtype[, perChannel]) -> retval\n```","ref":"Evision.DNN.Net.html#quantize/4"},{"type":"function","title":"Evision.DNN.Net.quantize/5","doc":"Returns a quantized Net from a floating-point Net.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **calibData**: `[Evision.Mat]`.\n\n  Calibration data to compute the quantization parameters.\n\n- **inputsDtype**: `integer()`.\n\n  Datatype of quantized net's inputs. Can be CV_32F or CV_8S.\n\n- **outputsDtype**: `integer()`.\n\n  Datatype of quantized net's outputs. Can be CV_32F or CV_8S.\n\n##### Keyword Arguments\n- **perChannel**: `bool`.\n\n  Quantization granularity of quantized Net. The default is true, that means quantize model\n  in per-channel way (channel-wise). Set it false to quantize model in per-tensor way (or tensor-wise).\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\nPython prototype (for reference only):\n```python3\nquantize(calibData, inputsDtype, outputsDtype[, perChannel]) -> retval\n```","ref":"Evision.DNN.Net.html#quantize/5"},{"type":"function","title":"Evision.DNN.Net.readFromModelOptimizer/1","doc":"","ref":"Evision.DNN.Net.html#readFromModelOptimizer/1"},{"type":"function","title":"Evision.DNN.Net.readFromModelOptimizer/2","doc":"Create a network from Intel's Model Optimizer in-memory buffers with intermediate representation (IR).\n\n##### Positional Arguments\n- **bufferModelConfig**: `[uchar]`.\n\n  buffer with model's configuration.\n\n- **bufferWeights**: `[uchar]`.\n\n  buffer with model's trained weights.\n\n##### Return\n- **retval**: `Evision.DNN.Net.t()`\n\n@returns Net object.\n\nPython prototype (for reference only):\n```python3\nreadFromModelOptimizer(bufferModelConfig, bufferWeights) -> retval\n```","ref":"Evision.DNN.Net.html#readFromModelOptimizer/2"},{"type":"function","title":"Evision.DNN.Net.setHalideScheduler/1","doc":"","ref":"Evision.DNN.Net.html#setHalideScheduler/1"},{"type":"function","title":"Evision.DNN.Net.setHalideScheduler/2","doc":"Compile Halide layers.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **scheduler**: `String`.\n\n  Path to YAML file with scheduling directives.\n\n@see `setPreferableBackend/2`\n Schedule layers that support Halide backend. Then compile them for\n specific target. For layers that not represented in scheduling file\n or if no manual scheduling used at all, automatic scheduling will be applied.\n\nPython prototype (for reference only):\n```python3\nsetHalideScheduler(scheduler) -> None\n```","ref":"Evision.DNN.Net.html#setHalideScheduler/2"},{"type":"function","title":"Evision.DNN.Net.setInput/1","doc":"","ref":"Evision.DNN.Net.html#setInput/1"},{"type":"function","title":"Evision.DNN.Net.setInput/2","doc":"Sets the new input value for the network\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **blob**: `Evision.Mat`.\n\n  A new blob. Should have CV_32F or CV_8U depth.\n\n##### Keyword Arguments\n- **name**: `String`.\n\n  A name of input layer.\n\n- **scalefactor**: `double`.\n\n  An optional normalization scale.\n\n- **mean**: `Evision.scalar()`.\n\n  An optional mean subtraction values.\n\n@see connect(String, String) to know format of the descriptor.\n  If scale or mean values are specified, a final input blob is computed\n  as:\n \\f[input(n,c,h,w) = scalefactor \\times (blob(n,c,h,w) - mean\\_c)\\f]\n\nPython prototype (for reference only):\n```python3\nsetInput(blob[, name[, scalefactor[, mean]]]) -> None\n```","ref":"Evision.DNN.Net.html#setInput/2"},{"type":"function","title":"Evision.DNN.Net.setInput/3","doc":"Sets the new input value for the network\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **blob**: `Evision.Mat`.\n\n  A new blob. Should have CV_32F or CV_8U depth.\n\n##### Keyword Arguments\n- **name**: `String`.\n\n  A name of input layer.\n\n- **scalefactor**: `double`.\n\n  An optional normalization scale.\n\n- **mean**: `Evision.scalar()`.\n\n  An optional mean subtraction values.\n\n@see connect(String, String) to know format of the descriptor.\n  If scale or mean values are specified, a final input blob is computed\n  as:\n \\f[input(n,c,h,w) = scalefactor \\times (blob(n,c,h,w) - mean\\_c)\\f]\n\nPython prototype (for reference only):\n```python3\nsetInput(blob[, name[, scalefactor[, mean]]]) -> None\n```","ref":"Evision.DNN.Net.html#setInput/3"},{"type":"function","title":"Evision.DNN.Net.setInputShape/1","doc":"","ref":"Evision.DNN.Net.html#setInputShape/1"},{"type":"function","title":"Evision.DNN.Net.setInputShape/3","doc":"Specify shape of network input.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **inputName**: `String`\n- **shape**: `MatShape`\n\nPython prototype (for reference only):\n```python3\nsetInputShape(inputName, shape) -> None\n```","ref":"Evision.DNN.Net.html#setInputShape/3"},{"type":"function","title":"Evision.DNN.Net.setInputsNames/1","doc":"","ref":"Evision.DNN.Net.html#setInputsNames/1"},{"type":"function","title":"Evision.DNN.Net.setInputsNames/2","doc":"Sets outputs names of the network input pseudo layer.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **inputBlobNames**: `[String]`\n\n Each net always has special own the network input pseudo layer with id=0.\n This layer stores the user blobs only and don't make any computations.\n In fact, this layer provides the only way to pass user data into the network.\n As any other layer, this layer can label its outputs and this function provides an easy way to do this.\n\nPython prototype (for reference only):\n```python3\nsetInputsNames(inputBlobNames) -> None\n```","ref":"Evision.DNN.Net.html#setInputsNames/2"},{"type":"function","title":"Evision.DNN.Net.setParam/1","doc":"","ref":"Evision.DNN.Net.html#setParam/1"},{"type":"function","title":"Evision.DNN.Net.setParam/4","doc":"#### Variant 1:\nsetParam\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **layerName**: `String`\n- **numParam**: `integer()`\n- **blob**: `Evision.Mat`\n\nPython prototype (for reference only):\n```python3\nsetParam(layerName, numParam, blob) -> None\n```\n#### Variant 2:\nSets the new value for the learned param of the layer.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **layer**: `integer()`.\n\n  name or id of the layer.\n\n- **numParam**: `integer()`.\n\n  index of the layer parameter in the Layer::blobs array.\n\n- **blob**: `Evision.Mat`.\n\n  the new value.\n\n@see Layer::blobs\n**Note**: If shape of the new blob differs from the previous shape,\n  then the following forward pass may fail.\n\nPython prototype (for reference only):\n```python3\nsetParam(layer, numParam, blob) -> None\n```","ref":"Evision.DNN.Net.html#setParam/4"},{"type":"function","title":"Evision.DNN.Net.setPreferableBackend/1","doc":"","ref":"Evision.DNN.Net.html#setPreferableBackend/1"},{"type":"function","title":"Evision.DNN.Net.setPreferableBackend/2","doc":"Ask network to use specific computation backend where it supported.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **backendId**: `integer()`.\n\n  backend identifier.\n\n@see Backend\n\nPython prototype (for reference only):\n```python3\nsetPreferableBackend(backendId) -> None\n```","ref":"Evision.DNN.Net.html#setPreferableBackend/2"},{"type":"function","title":"Evision.DNN.Net.setPreferableTarget/1","doc":"","ref":"Evision.DNN.Net.html#setPreferableTarget/1"},{"type":"function","title":"Evision.DNN.Net.setPreferableTarget/2","doc":"Ask network to make computations on specific target device.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.Net.t()`\n- **targetId**: `integer()`.\n\n  target identifier.\n\n@see Target\n List of supported combinations backend / target:\n |                        | DNN_BACKEND_OPENCV | DNN_BACKEND_INFERENCE_ENGINE | DNN_BACKEND_HALIDE |  DNN_BACKEND_CUDA |\n |------------------------|--------------------|------------------------------|--------------------|-------------------|\n | DNN_TARGET_CPU         |                  + |                            + |                  + |                   |\n | DNN_TARGET_OPENCL      |                  + |                            + |                  + |                   |\n | DNN_TARGET_OPENCL_FP16 |                  + |                            + |                    |                   |\n | DNN_TARGET_MYRIAD      |                    |                            + |                    |                   |\n | DNN_TARGET_FPGA        |                    |                            + |                    |                   |\n | DNN_TARGET_CUDA        |                    |                              |                    |                 + |\n | DNN_TARGET_CUDA_FP16   |                    |                              |                    |                 + |\n | DNN_TARGET_HDDL        |                    |                            + |                    |                   |\n\nPython prototype (for reference only):\n```python3\nsetPreferableTarget(targetId) -> None\n```","ref":"Evision.DNN.Net.html#setPreferableTarget/2"},{"type":"type","title":"Evision.DNN.Net.t/0","doc":"Type that represents an `DNN.Net` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.DNN.Net.html#t:t/0"},{"type":"module","title":"Evision.DNN.SegmentationModel","doc":"","ref":"Evision.DNN.SegmentationModel.html"},{"type":"function","title":"Evision.DNN.SegmentationModel.enableWinograd/1","doc":"","ref":"Evision.DNN.SegmentationModel.html#enableWinograd/1"},{"type":"function","title":"Evision.DNN.SegmentationModel.enableWinograd/2","doc":"enableWinograd\n\n##### Positional Arguments\n- **self**: `Evision.DNN.SegmentationModel.t()`\n- **useWinograd**: `bool`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nenableWinograd(useWinograd) -> retval\n```","ref":"Evision.DNN.SegmentationModel.html#enableWinograd/2"},{"type":"function","title":"Evision.DNN.SegmentationModel.predict/1","doc":"","ref":"Evision.DNN.SegmentationModel.html#predict/1"},{"type":"function","title":"Evision.DNN.SegmentationModel.predict/2","doc":"Given the @p input frame, create input blob, run net and return the output @p blobs.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.SegmentationModel.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **outs**: `[Evision.Mat]`.\n\n  Allocated output blobs, which will store results of the computation.\n\nPython prototype (for reference only):\n```python3\npredict(frame[, outs]) -> outs\n```","ref":"Evision.DNN.SegmentationModel.html#predict/2"},{"type":"function","title":"Evision.DNN.SegmentationModel.predict/3","doc":"Given the @p input frame, create input blob, run net and return the output @p blobs.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.SegmentationModel.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **outs**: `[Evision.Mat]`.\n\n  Allocated output blobs, which will store results of the computation.\n\nPython prototype (for reference only):\n```python3\npredict(frame[, outs]) -> outs\n```","ref":"Evision.DNN.SegmentationModel.html#predict/3"},{"type":"function","title":"Evision.DNN.SegmentationModel.segment/1","doc":"","ref":"Evision.DNN.SegmentationModel.html#segment/1"},{"type":"function","title":"Evision.DNN.SegmentationModel.segment/2","doc":"Given the @p input frame, create input blob, run net\n\n##### Positional Arguments\n- **self**: `Evision.DNN.SegmentationModel.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **mask**: `Evision.Mat.t()`.\n\n  Allocated class prediction for each pixel\n\nPython prototype (for reference only):\n```python3\nsegment(frame[, mask]) -> mask\n```","ref":"Evision.DNN.SegmentationModel.html#segment/2"},{"type":"function","title":"Evision.DNN.SegmentationModel.segment/3","doc":"Given the @p input frame, create input blob, run net\n\n##### Positional Arguments\n- **self**: `Evision.DNN.SegmentationModel.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **mask**: `Evision.Mat.t()`.\n\n  Allocated class prediction for each pixel\n\nPython prototype (for reference only):\n```python3\nsegment(frame[, mask]) -> mask\n```","ref":"Evision.DNN.SegmentationModel.html#segment/3"},{"type":"function","title":"Evision.DNN.SegmentationModel.segmentationModel/1","doc":"#### Variant 1:\nCreate model from deep learning network.\n\n##### Positional Arguments\n- **network**: `Evision.DNN.Net.t()`.\n\n  Net object.\n\n##### Return\n- **self**: `Evision.DNN.SegmentationModel.t()`\n\nPython prototype (for reference only):\n```python3\nSegmentationModel(network) ->  \n```\n#### Variant 2:\nCreate segmentation model from network represented in one of the supported formats.\nAn order of @p model and @p config arguments does not matter.\n\n##### Positional Arguments\n- **model**: `String`.\n\n  Binary file contains trained weights.\n\n##### Keyword Arguments\n- **config**: `String`.\n\n  Text file contains network configuration.\n\n##### Return\n- **self**: `Evision.DNN.SegmentationModel.t()`\n\nPython prototype (for reference only):\n```python3\nSegmentationModel(model[, config]) ->  \n```","ref":"Evision.DNN.SegmentationModel.html#segmentationModel/1"},{"type":"function","title":"Evision.DNN.SegmentationModel.segmentationModel/2","doc":"Create segmentation model from network represented in one of the supported formats.\nAn order of @p model and @p config arguments does not matter.\n\n##### Positional Arguments\n- **model**: `String`.\n\n  Binary file contains trained weights.\n\n##### Keyword Arguments\n- **config**: `String`.\n\n  Text file contains network configuration.\n\n##### Return\n- **self**: `Evision.DNN.SegmentationModel.t()`\n\nPython prototype (for reference only):\n```python3\nSegmentationModel(model[, config]) ->  \n```","ref":"Evision.DNN.SegmentationModel.html#segmentationModel/2"},{"type":"function","title":"Evision.DNN.SegmentationModel.setInputCrop/1","doc":"","ref":"Evision.DNN.SegmentationModel.html#setInputCrop/1"},{"type":"function","title":"Evision.DNN.SegmentationModel.setInputCrop/2","doc":"Set flag crop for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.SegmentationModel.t()`\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputCrop(crop) -> retval\n```","ref":"Evision.DNN.SegmentationModel.html#setInputCrop/2"},{"type":"function","title":"Evision.DNN.SegmentationModel.setInputMean/1","doc":"","ref":"Evision.DNN.SegmentationModel.html#setInputMean/1"},{"type":"function","title":"Evision.DNN.SegmentationModel.setInputMean/2","doc":"Set mean value for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.SegmentationModel.t()`\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputMean(mean) -> retval\n```","ref":"Evision.DNN.SegmentationModel.html#setInputMean/2"},{"type":"function","title":"Evision.DNN.SegmentationModel.setInputParams/1","doc":"Set preprocessing parameters for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.SegmentationModel.t()`\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Multiplier for frame values.\n\n- **size**: `Size`.\n\n  New input size.\n\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n  blob(n, c, y, x) = scale * resize( frame(y, x, c) ) - mean(c) )\n\nPython prototype (for reference only):\n```python3\nsetInputParams([, scale[, size[, mean[, swapRB[, crop]]]]]) -> None\n```","ref":"Evision.DNN.SegmentationModel.html#setInputParams/1"},{"type":"function","title":"Evision.DNN.SegmentationModel.setInputParams/2","doc":"Set preprocessing parameters for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.SegmentationModel.t()`\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Multiplier for frame values.\n\n- **size**: `Size`.\n\n  New input size.\n\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n  blob(n, c, y, x) = scale * resize( frame(y, x, c) ) - mean(c) )\n\nPython prototype (for reference only):\n```python3\nsetInputParams([, scale[, size[, mean[, swapRB[, crop]]]]]) -> None\n```","ref":"Evision.DNN.SegmentationModel.html#setInputParams/2"},{"type":"function","title":"Evision.DNN.SegmentationModel.setInputScale/1","doc":"","ref":"Evision.DNN.SegmentationModel.html#setInputScale/1"},{"type":"function","title":"Evision.DNN.SegmentationModel.setInputScale/2","doc":"Set scalefactor value for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.SegmentationModel.t()`\n- **scale**: `Evision.scalar()`.\n\n  Multiplier for frame values.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputScale(scale) -> retval\n```","ref":"Evision.DNN.SegmentationModel.html#setInputScale/2"},{"type":"function","title":"Evision.DNN.SegmentationModel.setInputSize/1","doc":"","ref":"Evision.DNN.SegmentationModel.html#setInputSize/1"},{"type":"function","title":"Evision.DNN.SegmentationModel.setInputSize/2","doc":"Set input size for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.SegmentationModel.t()`\n- **size**: `Size`.\n\n  New input size.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\n**Note**: If shape of the new blob less than 0, then frame size not change.\n\nPython prototype (for reference only):\n```python3\nsetInputSize(size) -> retval\n```","ref":"Evision.DNN.SegmentationModel.html#setInputSize/2"},{"type":"function","title":"Evision.DNN.SegmentationModel.setInputSize/3","doc":"setInputSize\n\n##### Positional Arguments\n- **self**: `Evision.DNN.SegmentationModel.t()`\n- **width**: `integer()`.\n\n  New input width.\n\n- **height**: `integer()`.\n\n  New input height.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nsetInputSize(width, height) -> retval\n```","ref":"Evision.DNN.SegmentationModel.html#setInputSize/3"},{"type":"function","title":"Evision.DNN.SegmentationModel.setInputSwapRB/1","doc":"","ref":"Evision.DNN.SegmentationModel.html#setInputSwapRB/1"},{"type":"function","title":"Evision.DNN.SegmentationModel.setInputSwapRB/2","doc":"Set flag swapRB for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.SegmentationModel.t()`\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputSwapRB(swapRB) -> retval\n```","ref":"Evision.DNN.SegmentationModel.html#setInputSwapRB/2"},{"type":"function","title":"Evision.DNN.SegmentationModel.setOutputNames/1","doc":"","ref":"Evision.DNN.SegmentationModel.html#setOutputNames/1"},{"type":"function","title":"Evision.DNN.SegmentationModel.setOutputNames/2","doc":"Set output names for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.SegmentationModel.t()`\n- **outNames**: `[String]`.\n\n  Names for output layers.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetOutputNames(outNames) -> retval\n```","ref":"Evision.DNN.SegmentationModel.html#setOutputNames/2"},{"type":"function","title":"Evision.DNN.SegmentationModel.setPreferableBackend/1","doc":"","ref":"Evision.DNN.SegmentationModel.html#setPreferableBackend/1"},{"type":"function","title":"Evision.DNN.SegmentationModel.setPreferableBackend/2","doc":"setPreferableBackend\n\n##### Positional Arguments\n- **self**: `Evision.DNN.SegmentationModel.t()`\n- **backendId**: `dnn_Backend`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetPreferableBackend(backendId) -> retval\n```","ref":"Evision.DNN.SegmentationModel.html#setPreferableBackend/2"},{"type":"function","title":"Evision.DNN.SegmentationModel.setPreferableTarget/1","doc":"","ref":"Evision.DNN.SegmentationModel.html#setPreferableTarget/1"},{"type":"function","title":"Evision.DNN.SegmentationModel.setPreferableTarget/2","doc":"setPreferableTarget\n\n##### Positional Arguments\n- **self**: `Evision.DNN.SegmentationModel.t()`\n- **targetId**: `dnn_Target`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetPreferableTarget(targetId) -> retval\n```","ref":"Evision.DNN.SegmentationModel.html#setPreferableTarget/2"},{"type":"type","title":"Evision.DNN.SegmentationModel.t/0","doc":"Type that represents an `DNN.SegmentationModel` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.DNN.SegmentationModel.html#t:t/0"},{"type":"module","title":"Evision.DNN.SoftNMSMethod","doc":"","ref":"Evision.DNN.SoftNMSMethod.html"},{"type":"function","title":"Evision.DNN.SoftNMSMethod.cv_SOFTNMS_GAUSSIAN/0","doc":"","ref":"Evision.DNN.SoftNMSMethod.html#cv_SOFTNMS_GAUSSIAN/0"},{"type":"function","title":"Evision.DNN.SoftNMSMethod.cv_SOFTNMS_LINEAR/0","doc":"","ref":"Evision.DNN.SoftNMSMethod.html#cv_SOFTNMS_LINEAR/0"},{"type":"type","title":"Evision.DNN.SoftNMSMethod.enum/0","doc":"","ref":"Evision.DNN.SoftNMSMethod.html#t:enum/0"},{"type":"module","title":"Evision.DNN.Target","doc":"","ref":"Evision.DNN.Target.html"},{"type":"function","title":"Evision.DNN.Target.cv_DNN_TARGET_CPU/0","doc":"","ref":"Evision.DNN.Target.html#cv_DNN_TARGET_CPU/0"},{"type":"function","title":"Evision.DNN.Target.cv_DNN_TARGET_CPU_FP16/0","doc":"","ref":"Evision.DNN.Target.html#cv_DNN_TARGET_CPU_FP16/0"},{"type":"function","title":"Evision.DNN.Target.cv_DNN_TARGET_CUDA/0","doc":"","ref":"Evision.DNN.Target.html#cv_DNN_TARGET_CUDA/0"},{"type":"function","title":"Evision.DNN.Target.cv_DNN_TARGET_CUDA_FP16/0","doc":"","ref":"Evision.DNN.Target.html#cv_DNN_TARGET_CUDA_FP16/0"},{"type":"function","title":"Evision.DNN.Target.cv_DNN_TARGET_FPGA/0","doc":"","ref":"Evision.DNN.Target.html#cv_DNN_TARGET_FPGA/0"},{"type":"function","title":"Evision.DNN.Target.cv_DNN_TARGET_HDDL/0","doc":"","ref":"Evision.DNN.Target.html#cv_DNN_TARGET_HDDL/0"},{"type":"function","title":"Evision.DNN.Target.cv_DNN_TARGET_MYRIAD/0","doc":"","ref":"Evision.DNN.Target.html#cv_DNN_TARGET_MYRIAD/0"},{"type":"function","title":"Evision.DNN.Target.cv_DNN_TARGET_NPU/0","doc":"","ref":"Evision.DNN.Target.html#cv_DNN_TARGET_NPU/0"},{"type":"function","title":"Evision.DNN.Target.cv_DNN_TARGET_OPENCL/0","doc":"","ref":"Evision.DNN.Target.html#cv_DNN_TARGET_OPENCL/0"},{"type":"function","title":"Evision.DNN.Target.cv_DNN_TARGET_OPENCL_FP16/0","doc":"","ref":"Evision.DNN.Target.html#cv_DNN_TARGET_OPENCL_FP16/0"},{"type":"function","title":"Evision.DNN.Target.cv_DNN_TARGET_VULKAN/0","doc":"","ref":"Evision.DNN.Target.html#cv_DNN_TARGET_VULKAN/0"},{"type":"type","title":"Evision.DNN.Target.enum/0","doc":"","ref":"Evision.DNN.Target.html#t:enum/0"},{"type":"module","title":"Evision.DNN.TextDetectionModel","doc":"","ref":"Evision.DNN.TextDetectionModel.html"},{"type":"function","title":"Evision.DNN.TextDetectionModel.detect/1","doc":"","ref":"Evision.DNN.TextDetectionModel.html#detect/1"},{"type":"function","title":"Evision.DNN.TextDetectionModel.detect/2","doc":"detect\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModel.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **detections**: `[[Point]]`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(frame) -> detections\n```","ref":"Evision.DNN.TextDetectionModel.html#detect/2"},{"type":"function","title":"Evision.DNN.TextDetectionModel.detectTextRectangles/1","doc":"","ref":"Evision.DNN.TextDetectionModel.html#detectTextRectangles/1"},{"type":"function","title":"Evision.DNN.TextDetectionModel.detectTextRectangles/2","doc":"Performs detection\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModel.t()`\n- **frame**: `Evision.Mat`.\n\n  the input image\n\n##### Return\n- **detections**: `[{centre={x, y}, size={s1, s2}, angle}]`.\n\n  array with detections' RotationRect results\n\n- **confidences**: `[float]`.\n\n  array with detection confidences\n\n Given the input @p frame, prepare network input, run network inference, post-process network output and return result detections.\n Each result is rotated rectangle.\n**Note**: Result may be inaccurate in case of strong perspective transformations.\n\nPython prototype (for reference only):\n```python3\ndetectTextRectangles(frame) -> detections, confidences\n```","ref":"Evision.DNN.TextDetectionModel.html#detectTextRectangles/2"},{"type":"function","title":"Evision.DNN.TextDetectionModel.enableWinograd/1","doc":"","ref":"Evision.DNN.TextDetectionModel.html#enableWinograd/1"},{"type":"function","title":"Evision.DNN.TextDetectionModel.enableWinograd/2","doc":"enableWinograd\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModel.t()`\n- **useWinograd**: `bool`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nenableWinograd(useWinograd) -> retval\n```","ref":"Evision.DNN.TextDetectionModel.html#enableWinograd/2"},{"type":"function","title":"Evision.DNN.TextDetectionModel.predict/1","doc":"","ref":"Evision.DNN.TextDetectionModel.html#predict/1"},{"type":"function","title":"Evision.DNN.TextDetectionModel.predict/2","doc":"Given the @p input frame, create input blob, run net and return the output @p blobs.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModel.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **outs**: `[Evision.Mat]`.\n\n  Allocated output blobs, which will store results of the computation.\n\nPython prototype (for reference only):\n```python3\npredict(frame[, outs]) -> outs\n```","ref":"Evision.DNN.TextDetectionModel.html#predict/2"},{"type":"function","title":"Evision.DNN.TextDetectionModel.predict/3","doc":"Given the @p input frame, create input blob, run net and return the output @p blobs.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModel.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **outs**: `[Evision.Mat]`.\n\n  Allocated output blobs, which will store results of the computation.\n\nPython prototype (for reference only):\n```python3\npredict(frame[, outs]) -> outs\n```","ref":"Evision.DNN.TextDetectionModel.html#predict/3"},{"type":"function","title":"Evision.DNN.TextDetectionModel.setInputCrop/1","doc":"","ref":"Evision.DNN.TextDetectionModel.html#setInputCrop/1"},{"type":"function","title":"Evision.DNN.TextDetectionModel.setInputCrop/2","doc":"Set flag crop for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModel.t()`\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputCrop(crop) -> retval\n```","ref":"Evision.DNN.TextDetectionModel.html#setInputCrop/2"},{"type":"function","title":"Evision.DNN.TextDetectionModel.setInputMean/1","doc":"","ref":"Evision.DNN.TextDetectionModel.html#setInputMean/1"},{"type":"function","title":"Evision.DNN.TextDetectionModel.setInputMean/2","doc":"Set mean value for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModel.t()`\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputMean(mean) -> retval\n```","ref":"Evision.DNN.TextDetectionModel.html#setInputMean/2"},{"type":"function","title":"Evision.DNN.TextDetectionModel.setInputParams/1","doc":"Set preprocessing parameters for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModel.t()`\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Multiplier for frame values.\n\n- **size**: `Size`.\n\n  New input size.\n\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n  blob(n, c, y, x) = scale * resize( frame(y, x, c) ) - mean(c) )\n\nPython prototype (for reference only):\n```python3\nsetInputParams([, scale[, size[, mean[, swapRB[, crop]]]]]) -> None\n```","ref":"Evision.DNN.TextDetectionModel.html#setInputParams/1"},{"type":"function","title":"Evision.DNN.TextDetectionModel.setInputParams/2","doc":"Set preprocessing parameters for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModel.t()`\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Multiplier for frame values.\n\n- **size**: `Size`.\n\n  New input size.\n\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n  blob(n, c, y, x) = scale * resize( frame(y, x, c) ) - mean(c) )\n\nPython prototype (for reference only):\n```python3\nsetInputParams([, scale[, size[, mean[, swapRB[, crop]]]]]) -> None\n```","ref":"Evision.DNN.TextDetectionModel.html#setInputParams/2"},{"type":"function","title":"Evision.DNN.TextDetectionModel.setInputScale/1","doc":"","ref":"Evision.DNN.TextDetectionModel.html#setInputScale/1"},{"type":"function","title":"Evision.DNN.TextDetectionModel.setInputScale/2","doc":"Set scalefactor value for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModel.t()`\n- **scale**: `Evision.scalar()`.\n\n  Multiplier for frame values.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputScale(scale) -> retval\n```","ref":"Evision.DNN.TextDetectionModel.html#setInputScale/2"},{"type":"function","title":"Evision.DNN.TextDetectionModel.setInputSize/1","doc":"","ref":"Evision.DNN.TextDetectionModel.html#setInputSize/1"},{"type":"function","title":"Evision.DNN.TextDetectionModel.setInputSize/2","doc":"Set input size for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModel.t()`\n- **size**: `Size`.\n\n  New input size.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\n**Note**: If shape of the new blob less than 0, then frame size not change.\n\nPython prototype (for reference only):\n```python3\nsetInputSize(size) -> retval\n```","ref":"Evision.DNN.TextDetectionModel.html#setInputSize/2"},{"type":"function","title":"Evision.DNN.TextDetectionModel.setInputSize/3","doc":"setInputSize\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModel.t()`\n- **width**: `integer()`.\n\n  New input width.\n\n- **height**: `integer()`.\n\n  New input height.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nsetInputSize(width, height) -> retval\n```","ref":"Evision.DNN.TextDetectionModel.html#setInputSize/3"},{"type":"function","title":"Evision.DNN.TextDetectionModel.setInputSwapRB/1","doc":"","ref":"Evision.DNN.TextDetectionModel.html#setInputSwapRB/1"},{"type":"function","title":"Evision.DNN.TextDetectionModel.setInputSwapRB/2","doc":"Set flag swapRB for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModel.t()`\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputSwapRB(swapRB) -> retval\n```","ref":"Evision.DNN.TextDetectionModel.html#setInputSwapRB/2"},{"type":"function","title":"Evision.DNN.TextDetectionModel.setOutputNames/1","doc":"","ref":"Evision.DNN.TextDetectionModel.html#setOutputNames/1"},{"type":"function","title":"Evision.DNN.TextDetectionModel.setOutputNames/2","doc":"Set output names for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModel.t()`\n- **outNames**: `[String]`.\n\n  Names for output layers.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetOutputNames(outNames) -> retval\n```","ref":"Evision.DNN.TextDetectionModel.html#setOutputNames/2"},{"type":"function","title":"Evision.DNN.TextDetectionModel.setPreferableBackend/1","doc":"","ref":"Evision.DNN.TextDetectionModel.html#setPreferableBackend/1"},{"type":"function","title":"Evision.DNN.TextDetectionModel.setPreferableBackend/2","doc":"setPreferableBackend\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModel.t()`\n- **backendId**: `dnn_Backend`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetPreferableBackend(backendId) -> retval\n```","ref":"Evision.DNN.TextDetectionModel.html#setPreferableBackend/2"},{"type":"function","title":"Evision.DNN.TextDetectionModel.setPreferableTarget/1","doc":"","ref":"Evision.DNN.TextDetectionModel.html#setPreferableTarget/1"},{"type":"function","title":"Evision.DNN.TextDetectionModel.setPreferableTarget/2","doc":"setPreferableTarget\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModel.t()`\n- **targetId**: `dnn_Target`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetPreferableTarget(targetId) -> retval\n```","ref":"Evision.DNN.TextDetectionModel.html#setPreferableTarget/2"},{"type":"type","title":"Evision.DNN.TextDetectionModel.t/0","doc":"Type that represents an `DNN.TextDetectionModel` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.DNN.TextDetectionModel.html#t:t/0"},{"type":"module","title":"Evision.DNN.TextDetectionModelDB","doc":"","ref":"Evision.DNN.TextDetectionModelDB.html"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.detect/1","doc":"","ref":"Evision.DNN.TextDetectionModelDB.html#detect/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.detect/2","doc":"detect\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **detections**: `[[Point]]`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(frame) -> detections\n```","ref":"Evision.DNN.TextDetectionModelDB.html#detect/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.detectTextRectangles/1","doc":"","ref":"Evision.DNN.TextDetectionModelDB.html#detectTextRectangles/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.detectTextRectangles/2","doc":"Performs detection\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n- **frame**: `Evision.Mat`.\n\n  the input image\n\n##### Return\n- **detections**: `[{centre={x, y}, size={s1, s2}, angle}]`.\n\n  array with detections' RotationRect results\n\n- **confidences**: `[float]`.\n\n  array with detection confidences\n\n Given the input @p frame, prepare network input, run network inference, post-process network output and return result detections.\n Each result is rotated rectangle.\n**Note**: Result may be inaccurate in case of strong perspective transformations.\n\nPython prototype (for reference only):\n```python3\ndetectTextRectangles(frame) -> detections, confidences\n```","ref":"Evision.DNN.TextDetectionModelDB.html#detectTextRectangles/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.enableWinograd/1","doc":"","ref":"Evision.DNN.TextDetectionModelDB.html#enableWinograd/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.enableWinograd/2","doc":"enableWinograd\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n- **useWinograd**: `bool`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nenableWinograd(useWinograd) -> retval\n```","ref":"Evision.DNN.TextDetectionModelDB.html#enableWinograd/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.getBinaryThreshold/1","doc":"getBinaryThreshold\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetBinaryThreshold() -> retval\n```","ref":"Evision.DNN.TextDetectionModelDB.html#getBinaryThreshold/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.getMaxCandidates/1","doc":"getMaxCandidates\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxCandidates() -> retval\n```","ref":"Evision.DNN.TextDetectionModelDB.html#getMaxCandidates/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.getPolygonThreshold/1","doc":"getPolygonThreshold\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetPolygonThreshold() -> retval\n```","ref":"Evision.DNN.TextDetectionModelDB.html#getPolygonThreshold/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.getUnclipRatio/1","doc":"getUnclipRatio\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetUnclipRatio() -> retval\n```","ref":"Evision.DNN.TextDetectionModelDB.html#getUnclipRatio/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.predict/1","doc":"","ref":"Evision.DNN.TextDetectionModelDB.html#predict/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.predict/2","doc":"Given the @p input frame, create input blob, run net and return the output @p blobs.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **outs**: `[Evision.Mat]`.\n\n  Allocated output blobs, which will store results of the computation.\n\nPython prototype (for reference only):\n```python3\npredict(frame[, outs]) -> outs\n```","ref":"Evision.DNN.TextDetectionModelDB.html#predict/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.predict/3","doc":"Given the @p input frame, create input blob, run net and return the output @p blobs.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **outs**: `[Evision.Mat]`.\n\n  Allocated output blobs, which will store results of the computation.\n\nPython prototype (for reference only):\n```python3\npredict(frame[, outs]) -> outs\n```","ref":"Evision.DNN.TextDetectionModelDB.html#predict/3"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setBinaryThreshold/1","doc":"","ref":"Evision.DNN.TextDetectionModelDB.html#setBinaryThreshold/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setBinaryThreshold/2","doc":"setBinaryThreshold\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n- **binaryThreshold**: `float`\n\n##### Return\n- **retval**: `Evision.DNN.TextDetectionModelDB.t()`\n\nPython prototype (for reference only):\n```python3\nsetBinaryThreshold(binaryThreshold) -> retval\n```","ref":"Evision.DNN.TextDetectionModelDB.html#setBinaryThreshold/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setInputCrop/1","doc":"","ref":"Evision.DNN.TextDetectionModelDB.html#setInputCrop/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setInputCrop/2","doc":"Set flag crop for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputCrop(crop) -> retval\n```","ref":"Evision.DNN.TextDetectionModelDB.html#setInputCrop/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setInputMean/1","doc":"","ref":"Evision.DNN.TextDetectionModelDB.html#setInputMean/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setInputMean/2","doc":"Set mean value for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputMean(mean) -> retval\n```","ref":"Evision.DNN.TextDetectionModelDB.html#setInputMean/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setInputParams/1","doc":"Set preprocessing parameters for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Multiplier for frame values.\n\n- **size**: `Size`.\n\n  New input size.\n\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n  blob(n, c, y, x) = scale * resize( frame(y, x, c) ) - mean(c) )\n\nPython prototype (for reference only):\n```python3\nsetInputParams([, scale[, size[, mean[, swapRB[, crop]]]]]) -> None\n```","ref":"Evision.DNN.TextDetectionModelDB.html#setInputParams/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setInputParams/2","doc":"Set preprocessing parameters for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Multiplier for frame values.\n\n- **size**: `Size`.\n\n  New input size.\n\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n  blob(n, c, y, x) = scale * resize( frame(y, x, c) ) - mean(c) )\n\nPython prototype (for reference only):\n```python3\nsetInputParams([, scale[, size[, mean[, swapRB[, crop]]]]]) -> None\n```","ref":"Evision.DNN.TextDetectionModelDB.html#setInputParams/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setInputScale/1","doc":"","ref":"Evision.DNN.TextDetectionModelDB.html#setInputScale/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setInputScale/2","doc":"Set scalefactor value for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n- **scale**: `Evision.scalar()`.\n\n  Multiplier for frame values.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputScale(scale) -> retval\n```","ref":"Evision.DNN.TextDetectionModelDB.html#setInputScale/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setInputSize/1","doc":"","ref":"Evision.DNN.TextDetectionModelDB.html#setInputSize/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setInputSize/2","doc":"Set input size for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n- **size**: `Size`.\n\n  New input size.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\n**Note**: If shape of the new blob less than 0, then frame size not change.\n\nPython prototype (for reference only):\n```python3\nsetInputSize(size) -> retval\n```","ref":"Evision.DNN.TextDetectionModelDB.html#setInputSize/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setInputSize/3","doc":"setInputSize\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n- **width**: `integer()`.\n\n  New input width.\n\n- **height**: `integer()`.\n\n  New input height.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nsetInputSize(width, height) -> retval\n```","ref":"Evision.DNN.TextDetectionModelDB.html#setInputSize/3"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setInputSwapRB/1","doc":"","ref":"Evision.DNN.TextDetectionModelDB.html#setInputSwapRB/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setInputSwapRB/2","doc":"Set flag swapRB for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputSwapRB(swapRB) -> retval\n```","ref":"Evision.DNN.TextDetectionModelDB.html#setInputSwapRB/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setMaxCandidates/1","doc":"","ref":"Evision.DNN.TextDetectionModelDB.html#setMaxCandidates/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setMaxCandidates/2","doc":"setMaxCandidates\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n- **maxCandidates**: `integer()`\n\n##### Return\n- **retval**: `Evision.DNN.TextDetectionModelDB.t()`\n\nPython prototype (for reference only):\n```python3\nsetMaxCandidates(maxCandidates) -> retval\n```","ref":"Evision.DNN.TextDetectionModelDB.html#setMaxCandidates/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setOutputNames/1","doc":"","ref":"Evision.DNN.TextDetectionModelDB.html#setOutputNames/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setOutputNames/2","doc":"Set output names for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n- **outNames**: `[String]`.\n\n  Names for output layers.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetOutputNames(outNames) -> retval\n```","ref":"Evision.DNN.TextDetectionModelDB.html#setOutputNames/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setPolygonThreshold/1","doc":"","ref":"Evision.DNN.TextDetectionModelDB.html#setPolygonThreshold/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setPolygonThreshold/2","doc":"setPolygonThreshold\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n- **polygonThreshold**: `float`\n\n##### Return\n- **retval**: `Evision.DNN.TextDetectionModelDB.t()`\n\nPython prototype (for reference only):\n```python3\nsetPolygonThreshold(polygonThreshold) -> retval\n```","ref":"Evision.DNN.TextDetectionModelDB.html#setPolygonThreshold/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setPreferableBackend/1","doc":"","ref":"Evision.DNN.TextDetectionModelDB.html#setPreferableBackend/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setPreferableBackend/2","doc":"setPreferableBackend\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n- **backendId**: `dnn_Backend`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetPreferableBackend(backendId) -> retval\n```","ref":"Evision.DNN.TextDetectionModelDB.html#setPreferableBackend/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setPreferableTarget/1","doc":"","ref":"Evision.DNN.TextDetectionModelDB.html#setPreferableTarget/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setPreferableTarget/2","doc":"setPreferableTarget\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n- **targetId**: `dnn_Target`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetPreferableTarget(targetId) -> retval\n```","ref":"Evision.DNN.TextDetectionModelDB.html#setPreferableTarget/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setUnclipRatio/1","doc":"","ref":"Evision.DNN.TextDetectionModelDB.html#setUnclipRatio/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.setUnclipRatio/2","doc":"setUnclipRatio\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n- **unclipRatio**: `double`\n\n##### Return\n- **retval**: `Evision.DNN.TextDetectionModelDB.t()`\n\nPython prototype (for reference only):\n```python3\nsetUnclipRatio(unclipRatio) -> retval\n```","ref":"Evision.DNN.TextDetectionModelDB.html#setUnclipRatio/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.textDetectionModelDB/1","doc":"#### Variant 1:\nCreate text detection model from network represented in one of the supported formats.\nAn order of @p model and @p config arguments does not matter.\n\n##### Positional Arguments\n- **model**: `string`.\n\n  Binary file contains trained weights.\n\n##### Keyword Arguments\n- **config**: `string`.\n\n  Text file contains network configuration.\n\n##### Return\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n\nPython prototype (for reference only):\n```python3\nTextDetectionModel_DB(model[, config]) ->  \n```\n#### Variant 2:\nCreate text detection algorithm from deep learning network.\n\n##### Positional Arguments\n- **network**: `Evision.DNN.Net.t()`.\n\n  Net object.\n\n##### Return\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n\nPython prototype (for reference only):\n```python3\nTextDetectionModel_DB(network) ->  \n```","ref":"Evision.DNN.TextDetectionModelDB.html#textDetectionModelDB/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelDB.textDetectionModelDB/2","doc":"Create text detection model from network represented in one of the supported formats.\nAn order of @p model and @p config arguments does not matter.\n\n##### Positional Arguments\n- **model**: `string`.\n\n  Binary file contains trained weights.\n\n##### Keyword Arguments\n- **config**: `string`.\n\n  Text file contains network configuration.\n\n##### Return\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`\n\nPython prototype (for reference only):\n```python3\nTextDetectionModel_DB(model[, config]) ->  \n```","ref":"Evision.DNN.TextDetectionModelDB.html#textDetectionModelDB/2"},{"type":"type","title":"Evision.DNN.TextDetectionModelDB.t/0","doc":"Type that represents an `DNN.TextDetectionModelDB` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.DNN.TextDetectionModelDB.html#t:t/0"},{"type":"module","title":"Evision.DNN.TextDetectionModelEAST","doc":"","ref":"Evision.DNN.TextDetectionModelEAST.html"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.detect/1","doc":"","ref":"Evision.DNN.TextDetectionModelEAST.html#detect/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.detect/2","doc":"detect\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelEAST.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **detections**: `[[Point]]`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(frame) -> detections\n```","ref":"Evision.DNN.TextDetectionModelEAST.html#detect/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.detectTextRectangles/1","doc":"","ref":"Evision.DNN.TextDetectionModelEAST.html#detectTextRectangles/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.detectTextRectangles/2","doc":"Performs detection\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelEAST.t()`\n- **frame**: `Evision.Mat`.\n\n  the input image\n\n##### Return\n- **detections**: `[{centre={x, y}, size={s1, s2}, angle}]`.\n\n  array with detections' RotationRect results\n\n- **confidences**: `[float]`.\n\n  array with detection confidences\n\n Given the input @p frame, prepare network input, run network inference, post-process network output and return result detections.\n Each result is rotated rectangle.\n**Note**: Result may be inaccurate in case of strong perspective transformations.\n\nPython prototype (for reference only):\n```python3\ndetectTextRectangles(frame) -> detections, confidences\n```","ref":"Evision.DNN.TextDetectionModelEAST.html#detectTextRectangles/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.enableWinograd/1","doc":"","ref":"Evision.DNN.TextDetectionModelEAST.html#enableWinograd/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.enableWinograd/2","doc":"enableWinograd\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelEAST.t()`\n- **useWinograd**: `bool`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nenableWinograd(useWinograd) -> retval\n```","ref":"Evision.DNN.TextDetectionModelEAST.html#enableWinograd/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.getConfidenceThreshold/1","doc":"Get the detection confidence threshold\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelEAST.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetConfidenceThreshold() -> retval\n```","ref":"Evision.DNN.TextDetectionModelEAST.html#getConfidenceThreshold/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.getNMSThreshold/1","doc":"Get the detection confidence threshold\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelEAST.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetNMSThreshold() -> retval\n```","ref":"Evision.DNN.TextDetectionModelEAST.html#getNMSThreshold/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.predict/1","doc":"","ref":"Evision.DNN.TextDetectionModelEAST.html#predict/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.predict/2","doc":"Given the @p input frame, create input blob, run net and return the output @p blobs.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelEAST.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **outs**: `[Evision.Mat]`.\n\n  Allocated output blobs, which will store results of the computation.\n\nPython prototype (for reference only):\n```python3\npredict(frame[, outs]) -> outs\n```","ref":"Evision.DNN.TextDetectionModelEAST.html#predict/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.predict/3","doc":"Given the @p input frame, create input blob, run net and return the output @p blobs.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelEAST.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **outs**: `[Evision.Mat]`.\n\n  Allocated output blobs, which will store results of the computation.\n\nPython prototype (for reference only):\n```python3\npredict(frame[, outs]) -> outs\n```","ref":"Evision.DNN.TextDetectionModelEAST.html#predict/3"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.setConfidenceThreshold/1","doc":"","ref":"Evision.DNN.TextDetectionModelEAST.html#setConfidenceThreshold/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.setConfidenceThreshold/2","doc":"Set the detection confidence threshold\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelEAST.t()`\n- **confThreshold**: `float`.\n\n  A threshold used to filter boxes by confidences\n\n##### Return\n- **retval**: `Evision.DNN.TextDetectionModelEAST.t()`\n\nPython prototype (for reference only):\n```python3\nsetConfidenceThreshold(confThreshold) -> retval\n```","ref":"Evision.DNN.TextDetectionModelEAST.html#setConfidenceThreshold/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.setInputCrop/1","doc":"","ref":"Evision.DNN.TextDetectionModelEAST.html#setInputCrop/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.setInputCrop/2","doc":"Set flag crop for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelEAST.t()`\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputCrop(crop) -> retval\n```","ref":"Evision.DNN.TextDetectionModelEAST.html#setInputCrop/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.setInputMean/1","doc":"","ref":"Evision.DNN.TextDetectionModelEAST.html#setInputMean/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.setInputMean/2","doc":"Set mean value for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelEAST.t()`\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputMean(mean) -> retval\n```","ref":"Evision.DNN.TextDetectionModelEAST.html#setInputMean/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.setInputParams/1","doc":"Set preprocessing parameters for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelEAST.t()`\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Multiplier for frame values.\n\n- **size**: `Size`.\n\n  New input size.\n\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n  blob(n, c, y, x) = scale * resize( frame(y, x, c) ) - mean(c) )\n\nPython prototype (for reference only):\n```python3\nsetInputParams([, scale[, size[, mean[, swapRB[, crop]]]]]) -> None\n```","ref":"Evision.DNN.TextDetectionModelEAST.html#setInputParams/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.setInputParams/2","doc":"Set preprocessing parameters for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelEAST.t()`\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Multiplier for frame values.\n\n- **size**: `Size`.\n\n  New input size.\n\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n  blob(n, c, y, x) = scale * resize( frame(y, x, c) ) - mean(c) )\n\nPython prototype (for reference only):\n```python3\nsetInputParams([, scale[, size[, mean[, swapRB[, crop]]]]]) -> None\n```","ref":"Evision.DNN.TextDetectionModelEAST.html#setInputParams/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.setInputScale/1","doc":"","ref":"Evision.DNN.TextDetectionModelEAST.html#setInputScale/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.setInputScale/2","doc":"Set scalefactor value for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelEAST.t()`\n- **scale**: `Evision.scalar()`.\n\n  Multiplier for frame values.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputScale(scale) -> retval\n```","ref":"Evision.DNN.TextDetectionModelEAST.html#setInputScale/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.setInputSize/1","doc":"","ref":"Evision.DNN.TextDetectionModelEAST.html#setInputSize/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.setInputSize/2","doc":"Set input size for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelEAST.t()`\n- **size**: `Size`.\n\n  New input size.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\n**Note**: If shape of the new blob less than 0, then frame size not change.\n\nPython prototype (for reference only):\n```python3\nsetInputSize(size) -> retval\n```","ref":"Evision.DNN.TextDetectionModelEAST.html#setInputSize/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.setInputSize/3","doc":"setInputSize\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelEAST.t()`\n- **width**: `integer()`.\n\n  New input width.\n\n- **height**: `integer()`.\n\n  New input height.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nsetInputSize(width, height) -> retval\n```","ref":"Evision.DNN.TextDetectionModelEAST.html#setInputSize/3"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.setInputSwapRB/1","doc":"","ref":"Evision.DNN.TextDetectionModelEAST.html#setInputSwapRB/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.setInputSwapRB/2","doc":"Set flag swapRB for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelEAST.t()`\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputSwapRB(swapRB) -> retval\n```","ref":"Evision.DNN.TextDetectionModelEAST.html#setInputSwapRB/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.setNMSThreshold/1","doc":"","ref":"Evision.DNN.TextDetectionModelEAST.html#setNMSThreshold/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.setNMSThreshold/2","doc":"Set the detection NMS filter threshold\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelEAST.t()`\n- **nmsThreshold**: `float`.\n\n  A threshold used in non maximum suppression\n\n##### Return\n- **retval**: `Evision.DNN.TextDetectionModelEAST.t()`\n\nPython prototype (for reference only):\n```python3\nsetNMSThreshold(nmsThreshold) -> retval\n```","ref":"Evision.DNN.TextDetectionModelEAST.html#setNMSThreshold/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.setOutputNames/1","doc":"","ref":"Evision.DNN.TextDetectionModelEAST.html#setOutputNames/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.setOutputNames/2","doc":"Set output names for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelEAST.t()`\n- **outNames**: `[String]`.\n\n  Names for output layers.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetOutputNames(outNames) -> retval\n```","ref":"Evision.DNN.TextDetectionModelEAST.html#setOutputNames/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.setPreferableBackend/1","doc":"","ref":"Evision.DNN.TextDetectionModelEAST.html#setPreferableBackend/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.setPreferableBackend/2","doc":"setPreferableBackend\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelEAST.t()`\n- **backendId**: `dnn_Backend`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetPreferableBackend(backendId) -> retval\n```","ref":"Evision.DNN.TextDetectionModelEAST.html#setPreferableBackend/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.setPreferableTarget/1","doc":"","ref":"Evision.DNN.TextDetectionModelEAST.html#setPreferableTarget/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.setPreferableTarget/2","doc":"setPreferableTarget\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextDetectionModelEAST.t()`\n- **targetId**: `dnn_Target`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetPreferableTarget(targetId) -> retval\n```","ref":"Evision.DNN.TextDetectionModelEAST.html#setPreferableTarget/2"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.textDetectionModelEAST/1","doc":"#### Variant 1:\nCreate text detection model from network represented in one of the supported formats.\nAn order of @p model and @p config arguments does not matter.\n\n##### Positional Arguments\n- **model**: `string`.\n\n  Binary file contains trained weights.\n\n##### Keyword Arguments\n- **config**: `string`.\n\n  Text file contains network configuration.\n\n##### Return\n- **self**: `Evision.DNN.TextDetectionModelEAST.t()`\n\nPython prototype (for reference only):\n```python3\nTextDetectionModel_EAST(model[, config]) ->  \n```\n#### Variant 2:\nCreate text detection algorithm from deep learning network\n\n##### Positional Arguments\n- **network**: `Evision.DNN.Net.t()`.\n\n  Net object\n\n##### Return\n- **self**: `Evision.DNN.TextDetectionModelEAST.t()`\n\nPython prototype (for reference only):\n```python3\nTextDetectionModel_EAST(network) ->  \n```","ref":"Evision.DNN.TextDetectionModelEAST.html#textDetectionModelEAST/1"},{"type":"function","title":"Evision.DNN.TextDetectionModelEAST.textDetectionModelEAST/2","doc":"Create text detection model from network represented in one of the supported formats.\nAn order of @p model and @p config arguments does not matter.\n\n##### Positional Arguments\n- **model**: `string`.\n\n  Binary file contains trained weights.\n\n##### Keyword Arguments\n- **config**: `string`.\n\n  Text file contains network configuration.\n\n##### Return\n- **self**: `Evision.DNN.TextDetectionModelEAST.t()`\n\nPython prototype (for reference only):\n```python3\nTextDetectionModel_EAST(model[, config]) ->  \n```","ref":"Evision.DNN.TextDetectionModelEAST.html#textDetectionModelEAST/2"},{"type":"type","title":"Evision.DNN.TextDetectionModelEAST.t/0","doc":"Type that represents an `DNN.TextDetectionModelEAST` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.DNN.TextDetectionModelEAST.html#t:t/0"},{"type":"module","title":"Evision.DNN.TextRecognitionModel","doc":"","ref":"Evision.DNN.TextRecognitionModel.html"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.enableWinograd/1","doc":"","ref":"Evision.DNN.TextRecognitionModel.html#enableWinograd/1"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.enableWinograd/2","doc":"enableWinograd\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n- **useWinograd**: `bool`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nenableWinograd(useWinograd) -> retval\n```","ref":"Evision.DNN.TextRecognitionModel.html#enableWinograd/2"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.getDecodeType/1","doc":"Get the decoding method\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n\n##### Return\n- **retval**: `string`\n\n@return the decoding method\n\nPython prototype (for reference only):\n```python3\ngetDecodeType() -> retval\n```","ref":"Evision.DNN.TextRecognitionModel.html#getDecodeType/1"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.getVocabulary/1","doc":"Get the vocabulary for recognition.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n\n##### Return\n- **retval**: `[string]`\n\n@return vocabulary the associated vocabulary\n\nPython prototype (for reference only):\n```python3\ngetVocabulary() -> retval\n```","ref":"Evision.DNN.TextRecognitionModel.html#getVocabulary/1"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.predict/1","doc":"","ref":"Evision.DNN.TextRecognitionModel.html#predict/1"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.predict/2","doc":"Given the @p input frame, create input blob, run net and return the output @p blobs.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **outs**: `[Evision.Mat]`.\n\n  Allocated output blobs, which will store results of the computation.\n\nPython prototype (for reference only):\n```python3\npredict(frame[, outs]) -> outs\n```","ref":"Evision.DNN.TextRecognitionModel.html#predict/2"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.predict/3","doc":"Given the @p input frame, create input blob, run net and return the output @p blobs.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n- **frame**: `Evision.Mat`\n\n##### Return\n- **outs**: `[Evision.Mat]`.\n\n  Allocated output blobs, which will store results of the computation.\n\nPython prototype (for reference only):\n```python3\npredict(frame[, outs]) -> outs\n```","ref":"Evision.DNN.TextRecognitionModel.html#predict/3"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.recognize/1","doc":"","ref":"Evision.DNN.TextRecognitionModel.html#recognize/1"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.recognize/2","doc":"Given the @p input frame, create input blob, run net and return recognition result\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n- **frame**: `Evision.Mat`.\n\n  The input image\n\n##### Return\n- **retval**: `string`\n\n@return The text recognition result\n\nPython prototype (for reference only):\n```python3\nrecognize(frame) -> retval\n```","ref":"Evision.DNN.TextRecognitionModel.html#recognize/2"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.recognize/3","doc":"Given the @p input frame, create input blob, run net and return recognition result\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n- **frame**: `Evision.Mat`.\n\n  The input image\n\n- **roiRects**: `[Evision.Mat]`.\n\n  List of text detection regions of interest (cv::Rect, CV_32SC4). ROIs is be cropped as the network inputs\n\n##### Return\n- **results**: `[string]`.\n\n  A set of text recognition results.\n\nPython prototype (for reference only):\n```python3\nrecognize(frame, roiRects) -> results\n```","ref":"Evision.DNN.TextRecognitionModel.html#recognize/3"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setDecodeOptsCTCPrefixBeamSearch/1","doc":"","ref":"Evision.DNN.TextRecognitionModel.html#setDecodeOptsCTCPrefixBeamSearch/1"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setDecodeOptsCTCPrefixBeamSearch/2","doc":"Set the decoding method options for `\"CTC-prefix-beam-search\"` decode usage\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n- **beamSize**: `integer()`.\n\n  Beam size for search\n\n##### Keyword Arguments\n- **vocPruneSize**: `integer()`.\n\n  Parameter to optimize big vocabulary search,\n  only take top @p vocPruneSize tokens in each search step, @p vocPruneSize <= 0 stands for disable this prune.\n\n##### Return\n- **retval**: `Evision.DNN.TextRecognitionModel.t()`\n\nPython prototype (for reference only):\n```python3\nsetDecodeOptsCTCPrefixBeamSearch(beamSize[, vocPruneSize]) -> retval\n```","ref":"Evision.DNN.TextRecognitionModel.html#setDecodeOptsCTCPrefixBeamSearch/2"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setDecodeOptsCTCPrefixBeamSearch/3","doc":"Set the decoding method options for `\"CTC-prefix-beam-search\"` decode usage\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n- **beamSize**: `integer()`.\n\n  Beam size for search\n\n##### Keyword Arguments\n- **vocPruneSize**: `integer()`.\n\n  Parameter to optimize big vocabulary search,\n  only take top @p vocPruneSize tokens in each search step, @p vocPruneSize <= 0 stands for disable this prune.\n\n##### Return\n- **retval**: `Evision.DNN.TextRecognitionModel.t()`\n\nPython prototype (for reference only):\n```python3\nsetDecodeOptsCTCPrefixBeamSearch(beamSize[, vocPruneSize]) -> retval\n```","ref":"Evision.DNN.TextRecognitionModel.html#setDecodeOptsCTCPrefixBeamSearch/3"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setDecodeType/1","doc":"","ref":"Evision.DNN.TextRecognitionModel.html#setDecodeType/1"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setDecodeType/2","doc":"Set the decoding method of translating the network output into string\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n- **decodeType**: `string`.\n\n  The decoding method of translating the network output into string, currently supported type:\n  - `\"CTC-greedy\"` greedy decoding for the output of CTC-based methods\n  - `\"CTC-prefix-beam-search\"` Prefix beam search decoding for the output of CTC-based methods\n\n##### Return\n- **retval**: `Evision.DNN.TextRecognitionModel.t()`\n\nPython prototype (for reference only):\n```python3\nsetDecodeType(decodeType) -> retval\n```","ref":"Evision.DNN.TextRecognitionModel.html#setDecodeType/2"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setInputCrop/1","doc":"","ref":"Evision.DNN.TextRecognitionModel.html#setInputCrop/1"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setInputCrop/2","doc":"Set flag crop for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputCrop(crop) -> retval\n```","ref":"Evision.DNN.TextRecognitionModel.html#setInputCrop/2"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setInputMean/1","doc":"","ref":"Evision.DNN.TextRecognitionModel.html#setInputMean/1"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setInputMean/2","doc":"Set mean value for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputMean(mean) -> retval\n```","ref":"Evision.DNN.TextRecognitionModel.html#setInputMean/2"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setInputParams/1","doc":"Set preprocessing parameters for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Multiplier for frame values.\n\n- **size**: `Size`.\n\n  New input size.\n\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n  blob(n, c, y, x) = scale * resize( frame(y, x, c) ) - mean(c) )\n\nPython prototype (for reference only):\n```python3\nsetInputParams([, scale[, size[, mean[, swapRB[, crop]]]]]) -> None\n```","ref":"Evision.DNN.TextRecognitionModel.html#setInputParams/1"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setInputParams/2","doc":"Set preprocessing parameters for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  Multiplier for frame values.\n\n- **size**: `Size`.\n\n  New input size.\n\n- **mean**: `Evision.scalar()`.\n\n  Scalar with mean values which are subtracted from channels.\n\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n- **crop**: `bool`.\n\n  Flag which indicates whether image will be cropped after resize or not.\n  blob(n, c, y, x) = scale * resize( frame(y, x, c) ) - mean(c) )\n\nPython prototype (for reference only):\n```python3\nsetInputParams([, scale[, size[, mean[, swapRB[, crop]]]]]) -> None\n```","ref":"Evision.DNN.TextRecognitionModel.html#setInputParams/2"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setInputScale/1","doc":"","ref":"Evision.DNN.TextRecognitionModel.html#setInputScale/1"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setInputScale/2","doc":"Set scalefactor value for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n- **scale**: `Evision.scalar()`.\n\n  Multiplier for frame values.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputScale(scale) -> retval\n```","ref":"Evision.DNN.TextRecognitionModel.html#setInputScale/2"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setInputSize/1","doc":"","ref":"Evision.DNN.TextRecognitionModel.html#setInputSize/1"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setInputSize/2","doc":"Set input size for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n- **size**: `Size`.\n\n  New input size.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\n**Note**: If shape of the new blob less than 0, then frame size not change.\n\nPython prototype (for reference only):\n```python3\nsetInputSize(size) -> retval\n```","ref":"Evision.DNN.TextRecognitionModel.html#setInputSize/2"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setInputSize/3","doc":"setInputSize\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n- **width**: `integer()`.\n\n  New input width.\n\n- **height**: `integer()`.\n\n  New input height.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nsetInputSize(width, height) -> retval\n```","ref":"Evision.DNN.TextRecognitionModel.html#setInputSize/3"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setInputSwapRB/1","doc":"","ref":"Evision.DNN.TextRecognitionModel.html#setInputSwapRB/1"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setInputSwapRB/2","doc":"Set flag swapRB for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n- **swapRB**: `bool`.\n\n  Flag which indicates that swap first and last channels.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetInputSwapRB(swapRB) -> retval\n```","ref":"Evision.DNN.TextRecognitionModel.html#setInputSwapRB/2"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setOutputNames/1","doc":"","ref":"Evision.DNN.TextRecognitionModel.html#setOutputNames/1"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setOutputNames/2","doc":"Set output names for frame.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n- **outNames**: `[String]`.\n\n  Names for output layers.\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetOutputNames(outNames) -> retval\n```","ref":"Evision.DNN.TextRecognitionModel.html#setOutputNames/2"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setPreferableBackend/1","doc":"","ref":"Evision.DNN.TextRecognitionModel.html#setPreferableBackend/1"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setPreferableBackend/2","doc":"setPreferableBackend\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n- **backendId**: `dnn_Backend`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetPreferableBackend(backendId) -> retval\n```","ref":"Evision.DNN.TextRecognitionModel.html#setPreferableBackend/2"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setPreferableTarget/1","doc":"","ref":"Evision.DNN.TextRecognitionModel.html#setPreferableTarget/1"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setPreferableTarget/2","doc":"setPreferableTarget\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n- **targetId**: `dnn_Target`\n\n##### Return\n- **retval**: `Evision.DNN.Model.t()`\n\nPython prototype (for reference only):\n```python3\nsetPreferableTarget(targetId) -> retval\n```","ref":"Evision.DNN.TextRecognitionModel.html#setPreferableTarget/2"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setVocabulary/1","doc":"","ref":"Evision.DNN.TextRecognitionModel.html#setVocabulary/1"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.setVocabulary/2","doc":"Set the vocabulary for recognition.\n\n##### Positional Arguments\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n- **vocabulary**: `[string]`.\n\n  the associated vocabulary of the network.\n\n##### Return\n- **retval**: `Evision.DNN.TextRecognitionModel.t()`\n\nPython prototype (for reference only):\n```python3\nsetVocabulary(vocabulary) -> retval\n```","ref":"Evision.DNN.TextRecognitionModel.html#setVocabulary/2"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.textRecognitionModel/1","doc":"#### Variant 1:\nCreate text recognition model from network represented in one of the supported formats\nCall setDecodeType() and setVocabulary() after constructor to initialize the decoding method\n\n##### Positional Arguments\n- **model**: `string`.\n\n  Binary file contains trained weights\n\n##### Keyword Arguments\n- **config**: `string`.\n\n  Text file contains network configuration\n\n##### Return\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n\nPython prototype (for reference only):\n```python3\nTextRecognitionModel(model[, config]) ->  \n```\n#### Variant 2:\nCreate Text Recognition model from deep learning network\nCall setDecodeType() and setVocabulary() after constructor to initialize the decoding method\n\n##### Positional Arguments\n- **network**: `Evision.DNN.Net.t()`.\n\n  Net object\n\n##### Return\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n\nPython prototype (for reference only):\n```python3\nTextRecognitionModel(network) ->  \n```","ref":"Evision.DNN.TextRecognitionModel.html#textRecognitionModel/1"},{"type":"function","title":"Evision.DNN.TextRecognitionModel.textRecognitionModel/2","doc":"Create text recognition model from network represented in one of the supported formats\nCall setDecodeType() and setVocabulary() after constructor to initialize the decoding method\n\n##### Positional Arguments\n- **model**: `string`.\n\n  Binary file contains trained weights\n\n##### Keyword Arguments\n- **config**: `string`.\n\n  Text file contains network configuration\n\n##### Return\n- **self**: `Evision.DNN.TextRecognitionModel.t()`\n\nPython prototype (for reference only):\n```python3\nTextRecognitionModel(model[, config]) ->  \n```","ref":"Evision.DNN.TextRecognitionModel.html#textRecognitionModel/2"},{"type":"type","title":"Evision.DNN.TextRecognitionModel.t/0","doc":"Type that represents an `DNN.TextRecognitionModel` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.DNN.TextRecognitionModel.html#t:t/0"},{"type":"module","title":"Evision.DNNSuperRes","doc":"","ref":"Evision.DNNSuperRes.html"},{"type":"type","title":"Evision.DNNSuperRes.t/0","doc":"Type that represents an `DNNSuperRes` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.DNNSuperRes.html#t:t/0"},{"type":"module","title":"Evision.DNNSuperRes.DNNSuperResImpl","doc":"","ref":"Evision.DNNSuperRes.DNNSuperResImpl.html"},{"type":"function","title":"Evision.DNNSuperRes.DNNSuperResImpl.create/0","doc":"Empty constructor for python\n##### Return\n- **retval**: `Evision.DNNSuperRes.DNNSuperResImpl.t()`\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.DNNSuperRes.DNNSuperResImpl.html#create/0"},{"type":"function","title":"Evision.DNNSuperRes.DNNSuperResImpl.create/1","doc":"","ref":"Evision.DNNSuperRes.DNNSuperResImpl.html#create/1"},{"type":"function","title":"Evision.DNNSuperRes.DNNSuperResImpl.getAlgorithm/1","doc":"Returns the scale factor of the model:\n\n##### Positional Arguments\n- **self**: `Evision.DNNSuperRes.DNNSuperResImpl.t()`\n\n##### Return\n- **retval**: `String`\n\n@return Current algorithm.\n\nPython prototype (for reference only):\n```python3\ngetAlgorithm() -> retval\n```","ref":"Evision.DNNSuperRes.DNNSuperResImpl.html#getAlgorithm/1"},{"type":"function","title":"Evision.DNNSuperRes.DNNSuperResImpl.getScale/1","doc":"Returns the scale factor of the model:\n\n##### Positional Arguments\n- **self**: `Evision.DNNSuperRes.DNNSuperResImpl.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@return Current scale factor.\n\nPython prototype (for reference only):\n```python3\ngetScale() -> retval\n```","ref":"Evision.DNNSuperRes.DNNSuperResImpl.html#getScale/1"},{"type":"function","title":"Evision.DNNSuperRes.DNNSuperResImpl.readModel/1","doc":"","ref":"Evision.DNNSuperRes.DNNSuperResImpl.html#readModel/1"},{"type":"function","title":"Evision.DNNSuperRes.DNNSuperResImpl.readModel/2","doc":"Read the model from the given path\n\n##### Positional Arguments\n- **self**: `Evision.DNNSuperRes.DNNSuperResImpl.t()`\n- **path**: `String`.\n\n  Path to the model file.\n\nPython prototype (for reference only):\n```python3\nreadModel(path) -> None\n```","ref":"Evision.DNNSuperRes.DNNSuperResImpl.html#readModel/2"},{"type":"function","title":"Evision.DNNSuperRes.DNNSuperResImpl.setModel/1","doc":"","ref":"Evision.DNNSuperRes.DNNSuperResImpl.html#setModel/1"},{"type":"function","title":"Evision.DNNSuperRes.DNNSuperResImpl.setModel/3","doc":"Set desired model\n\n##### Positional Arguments\n- **self**: `Evision.DNNSuperRes.DNNSuperResImpl.t()`\n- **algo**: `String`.\n\n  String containing one of the desired models:\n  - __edsr__\n  - __espcn__\n  - __fsrcnn__\n  - __lapsrn__\n\n- **scale**: `integer()`.\n\n  Integer specifying the upscale factor\n\nPython prototype (for reference only):\n```python3\nsetModel(algo, scale) -> None\n```","ref":"Evision.DNNSuperRes.DNNSuperResImpl.html#setModel/3"},{"type":"function","title":"Evision.DNNSuperRes.DNNSuperResImpl.setPreferableBackend/1","doc":"","ref":"Evision.DNNSuperRes.DNNSuperResImpl.html#setPreferableBackend/1"},{"type":"function","title":"Evision.DNNSuperRes.DNNSuperResImpl.setPreferableBackend/2","doc":"Set computation backend\n\n##### Positional Arguments\n- **self**: `Evision.DNNSuperRes.DNNSuperResImpl.t()`\n- **backendId**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetPreferableBackend(backendId) -> None\n```","ref":"Evision.DNNSuperRes.DNNSuperResImpl.html#setPreferableBackend/2"},{"type":"function","title":"Evision.DNNSuperRes.DNNSuperResImpl.setPreferableTarget/1","doc":"","ref":"Evision.DNNSuperRes.DNNSuperResImpl.html#setPreferableTarget/1"},{"type":"function","title":"Evision.DNNSuperRes.DNNSuperResImpl.setPreferableTarget/2","doc":"Set computation target\n\n##### Positional Arguments\n- **self**: `Evision.DNNSuperRes.DNNSuperResImpl.t()`\n- **targetId**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetPreferableTarget(targetId) -> None\n```","ref":"Evision.DNNSuperRes.DNNSuperResImpl.html#setPreferableTarget/2"},{"type":"function","title":"Evision.DNNSuperRes.DNNSuperResImpl.upsample/1","doc":"","ref":"Evision.DNNSuperRes.DNNSuperResImpl.html#upsample/1"},{"type":"function","title":"Evision.DNNSuperRes.DNNSuperResImpl.upsample/2","doc":"Upsample via neural network\n\n##### Positional Arguments\n- **self**: `Evision.DNNSuperRes.DNNSuperResImpl.t()`\n- **img**: `Evision.Mat`.\n\n  Image to upscale\n\n##### Return\n- **result**: `Evision.Mat.t()`.\n\n  Destination upscaled image\n\nPython prototype (for reference only):\n```python3\nupsample(img[, result]) -> result\n```","ref":"Evision.DNNSuperRes.DNNSuperResImpl.html#upsample/2"},{"type":"function","title":"Evision.DNNSuperRes.DNNSuperResImpl.upsample/3","doc":"Upsample via neural network\n\n##### Positional Arguments\n- **self**: `Evision.DNNSuperRes.DNNSuperResImpl.t()`\n- **img**: `Evision.Mat`.\n\n  Image to upscale\n\n##### Return\n- **result**: `Evision.Mat.t()`.\n\n  Destination upscaled image\n\nPython prototype (for reference only):\n```python3\nupsample(img[, result]) -> result\n```","ref":"Evision.DNNSuperRes.DNNSuperResImpl.html#upsample/3"},{"type":"function","title":"Evision.DNNSuperRes.DNNSuperResImpl.upsampleMultioutput/1","doc":"","ref":"Evision.DNNSuperRes.DNNSuperResImpl.html#upsampleMultioutput/1"},{"type":"function","title":"Evision.DNNSuperRes.DNNSuperResImpl.upsampleMultioutput/5","doc":"Upsample via neural network of multiple outputs\n\n##### Positional Arguments\n- **self**: `Evision.DNNSuperRes.DNNSuperResImpl.t()`\n- **img**: `Evision.Mat`.\n\n  Image to upscale\n\n- **imgs_new**: `[Evision.Mat]`.\n\n  Destination upscaled images\n\n- **scale_factors**: `[integer()]`.\n\n  Scaling factors of the output nodes\n\n- **node_names**: `[String]`.\n\n  Names of the output nodes in the neural network\n\nPython prototype (for reference only):\n```python3\nupsampleMultioutput(img, imgs_new, scale_factors, node_names) -> None\n```","ref":"Evision.DNNSuperRes.DNNSuperResImpl.html#upsampleMultioutput/5"},{"type":"type","title":"Evision.DNNSuperRes.DNNSuperResImpl.t/0","doc":"Type that represents an `DNNSuperRes.DNNSuperResImpl` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.DNNSuperRes.DNNSuperResImpl.html#t:t/0"},{"type":"module","title":"Evision.DecompTypes","doc":"","ref":"Evision.DecompTypes.html"},{"type":"function","title":"Evision.DecompTypes.cv_DECOMP_CHOLESKY/0","doc":"","ref":"Evision.DecompTypes.html#cv_DECOMP_CHOLESKY/0"},{"type":"function","title":"Evision.DecompTypes.cv_DECOMP_EIG/0","doc":"","ref":"Evision.DecompTypes.html#cv_DECOMP_EIG/0"},{"type":"function","title":"Evision.DecompTypes.cv_DECOMP_LU/0","doc":"","ref":"Evision.DecompTypes.html#cv_DECOMP_LU/0"},{"type":"function","title":"Evision.DecompTypes.cv_DECOMP_NORMAL/0","doc":"","ref":"Evision.DecompTypes.html#cv_DECOMP_NORMAL/0"},{"type":"function","title":"Evision.DecompTypes.cv_DECOMP_QR/0","doc":"","ref":"Evision.DecompTypes.html#cv_DECOMP_QR/0"},{"type":"function","title":"Evision.DecompTypes.cv_DECOMP_SVD/0","doc":"","ref":"Evision.DecompTypes.html#cv_DECOMP_SVD/0"},{"type":"type","title":"Evision.DecompTypes.enum/0","doc":"","ref":"Evision.DecompTypes.html#t:enum/0"},{"type":"module","title":"Evision.DenseOpticalFlow","doc":"","ref":"Evision.DenseOpticalFlow.html"},{"type":"function","title":"Evision.DenseOpticalFlow.calc/1","doc":"","ref":"Evision.DenseOpticalFlow.html#calc/1"},{"type":"function","title":"Evision.DenseOpticalFlow.calc/4","doc":"Calculates an optical flow.\n\n##### Positional Arguments\n- **self**: `Evision.DenseOpticalFlow.t()`\n- **i0**: `Evision.Mat`.\n\n  first 8-bit single-channel input image.\n\n- **i1**: `Evision.Mat`.\n\n  second input image of the same size and the same type as prev.\n\n##### Return\n- **flow**: `Evision.Mat.t()`.\n\n  computed flow image that has the same size as prev and type CV_32FC2.\n\nPython prototype (for reference only):\n```python3\ncalc(I0, I1, flow) -> flow\n```","ref":"Evision.DenseOpticalFlow.html#calc/4"},{"type":"function","title":"Evision.DenseOpticalFlow.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.DenseOpticalFlow.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.DenseOpticalFlow.html#clear/1"},{"type":"function","title":"Evision.DenseOpticalFlow.collectGarbage/1","doc":"Releases all inner buffers.\n\n##### Positional Arguments\n- **self**: `Evision.DenseOpticalFlow.t()`\n\nPython prototype (for reference only):\n```python3\ncollectGarbage() -> None\n```","ref":"Evision.DenseOpticalFlow.html#collectGarbage/1"},{"type":"function","title":"Evision.DenseOpticalFlow.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.DenseOpticalFlow.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.DenseOpticalFlow.html#empty/1"},{"type":"function","title":"Evision.DenseOpticalFlow.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.DenseOpticalFlow.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.DenseOpticalFlow.html#getDefaultName/1"},{"type":"function","title":"Evision.DenseOpticalFlow.read/1","doc":"","ref":"Evision.DenseOpticalFlow.html#read/1"},{"type":"function","title":"Evision.DenseOpticalFlow.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.DenseOpticalFlow.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.DenseOpticalFlow.html#read/2"},{"type":"function","title":"Evision.DenseOpticalFlow.save/1","doc":"","ref":"Evision.DenseOpticalFlow.html#save/1"},{"type":"function","title":"Evision.DenseOpticalFlow.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.DenseOpticalFlow.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.DenseOpticalFlow.html#save/2"},{"type":"function","title":"Evision.DenseOpticalFlow.write/1","doc":"","ref":"Evision.DenseOpticalFlow.html#write/1"},{"type":"function","title":"Evision.DenseOpticalFlow.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.DenseOpticalFlow.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.DenseOpticalFlow.html#write/2"},{"type":"function","title":"Evision.DenseOpticalFlow.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.DenseOpticalFlow.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.DenseOpticalFlow.html#write/3"},{"type":"type","title":"Evision.DenseOpticalFlow.t/0","doc":"Type that represents an `DenseOpticalFlow` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.DenseOpticalFlow.html#t:t/0"},{"type":"module","title":"Evision.DescriptorMatcher","doc":"","ref":"Evision.DescriptorMatcher.html"},{"type":"function","title":"Evision.DescriptorMatcher.add/1","doc":"","ref":"Evision.DescriptorMatcher.html#add/1"},{"type":"function","title":"Evision.DescriptorMatcher.add/2","doc":"Adds descriptors to train a CPU(trainDescCollectionis) or GPU(utrainDescCollectionis) descriptor\ncollection.\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n- **descriptors**: `[Evision.Mat]`.\n\n  Descriptors to add. Each descriptors[i] is a set of descriptors from the same\n  train image.\n\nIf the collection is not empty, the new descriptors are added to existing train descriptors.\n\nPython prototype (for reference only):\n```python3\nadd(descriptors) -> None\n```","ref":"Evision.DescriptorMatcher.html#add/2"},{"type":"function","title":"Evision.DescriptorMatcher.clear/1","doc":"Clears the train descriptor collections.\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.DescriptorMatcher.html#clear/1"},{"type":"function","title":"Evision.DescriptorMatcher.clone/1","doc":"Clones the matcher.\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n\n##### Keyword Arguments\n- **emptyTrainData**: `bool`.\n\n  If emptyTrainData is false, the method creates a deep copy of the object,\n  that is, copies both parameters and train data. If emptyTrainData is true, the method creates an\n  object copy with the current parameters but with empty train data.\n\n##### Return\n- **retval**: `Evision.DescriptorMatcher.t()`\n\nPython prototype (for reference only):\n```python3\nclone([, emptyTrainData]) -> retval\n```","ref":"Evision.DescriptorMatcher.html#clone/1"},{"type":"function","title":"Evision.DescriptorMatcher.clone/2","doc":"Clones the matcher.\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n\n##### Keyword Arguments\n- **emptyTrainData**: `bool`.\n\n  If emptyTrainData is false, the method creates a deep copy of the object,\n  that is, copies both parameters and train data. If emptyTrainData is true, the method creates an\n  object copy with the current parameters but with empty train data.\n\n##### Return\n- **retval**: `Evision.DescriptorMatcher.t()`\n\nPython prototype (for reference only):\n```python3\nclone([, emptyTrainData]) -> retval\n```","ref":"Evision.DescriptorMatcher.html#clone/2"},{"type":"function","title":"Evision.DescriptorMatcher.create/1","doc":"#### Variant 1:\ncreate\n\n##### Positional Arguments\n- **matcherType**: `DescriptorMatcher_MatcherType`\n\n##### Return\n- **retval**: `Evision.DescriptorMatcher.t()`\n\nPython prototype (for reference only):\n```python3\ncreate(matcherType) -> retval\n```\n#### Variant 2:\nCreates a descriptor matcher of a given type with the default parameters (using default\nconstructor).\n\n##### Positional Arguments\n- **descriptorMatcherType**: `String`.\n\n  Descriptor matcher type. Now the following matcher types are\n  supported:\n  - `BruteForce` (it uses L2 )\n  - `BruteForce-L1`\n  - `BruteForce-Hamming`\n  - `BruteForce-Hamming(2)`\n  - `FlannBased`\n\n##### Return\n- **retval**: `Evision.DescriptorMatcher.t()`\n\nPython prototype (for reference only):\n```python3\ncreate(descriptorMatcherType) -> retval\n```","ref":"Evision.DescriptorMatcher.html#create/1"},{"type":"function","title":"Evision.DescriptorMatcher.empty/1","doc":"Returns true if there are no train descriptors in the both collections.\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.DescriptorMatcher.html#empty/1"},{"type":"function","title":"Evision.DescriptorMatcher.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.DescriptorMatcher.html#getDefaultName/1"},{"type":"function","title":"Evision.DescriptorMatcher.getTrainDescriptors/1","doc":"Returns a constant link to the train descriptor collection trainDescCollection .\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n\n##### Return\n- **retval**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\ngetTrainDescriptors() -> retval\n```","ref":"Evision.DescriptorMatcher.html#getTrainDescriptors/1"},{"type":"function","title":"Evision.DescriptorMatcher.isMaskSupported/1","doc":"Returns true if the descriptor matcher supports masking permissible matches.\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisMaskSupported() -> retval\n```","ref":"Evision.DescriptorMatcher.html#isMaskSupported/1"},{"type":"function","title":"Evision.DescriptorMatcher.knnMatch/1","doc":"","ref":"Evision.DescriptorMatcher.html#knnMatch/1"},{"type":"function","title":"Evision.DescriptorMatcher.knnMatch/3","doc":"knnMatch\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **k**: `integer()`.\n\n  Count of best matches found per each query descriptor or less if a query descriptor has\n  less than k possible matches in total.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Set of masks. Each masks[i] specifies permissible matches between the input query\n  descriptors and stored train descriptors from the i-th image trainDescCollection[i].\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Matches. Each matches[i] is k or less matches for the same query descriptor.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nknnMatch(queryDescriptors, k[, masks[, compactResult]]) -> matches\n```","ref":"Evision.DescriptorMatcher.html#knnMatch/3"},{"type":"function","title":"Evision.DescriptorMatcher.knnMatch/4","doc":"#### Variant 1:\nFinds the k best matches for each descriptor from a query set.\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **k**: `integer()`.\n\n  Count of best matches found per each query descriptor or less if a query descriptor has\n  less than k possible matches in total.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Matches. Each matches[i] is k or less matches for the same query descriptor.\n\nThese extended variants of DescriptorMatcher::match methods find several best matches for each query\ndescriptor. The matches are returned in the distance increasing order. See DescriptorMatcher::match\nfor the details about query and train descriptors.\n\nPython prototype (for reference only):\n```python3\nknnMatch(queryDescriptors, trainDescriptors, k[, mask[, compactResult]]) -> matches\n```\n#### Variant 2:\nknnMatch\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **k**: `integer()`.\n\n  Count of best matches found per each query descriptor or less if a query descriptor has\n  less than k possible matches in total.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Set of masks. Each masks[i] specifies permissible matches between the input query\n  descriptors and stored train descriptors from the i-th image trainDescCollection[i].\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Matches. Each matches[i] is k or less matches for the same query descriptor.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nknnMatch(queryDescriptors, k[, masks[, compactResult]]) -> matches\n```","ref":"Evision.DescriptorMatcher.html#knnMatch/4"},{"type":"function","title":"Evision.DescriptorMatcher.knnMatch/5","doc":"Finds the k best matches for each descriptor from a query set.\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **k**: `integer()`.\n\n  Count of best matches found per each query descriptor or less if a query descriptor has\n  less than k possible matches in total.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Matches. Each matches[i] is k or less matches for the same query descriptor.\n\nThese extended variants of DescriptorMatcher::match methods find several best matches for each query\ndescriptor. The matches are returned in the distance increasing order. See DescriptorMatcher::match\nfor the details about query and train descriptors.\n\nPython prototype (for reference only):\n```python3\nknnMatch(queryDescriptors, trainDescriptors, k[, mask[, compactResult]]) -> matches\n```","ref":"Evision.DescriptorMatcher.html#knnMatch/5"},{"type":"function","title":"Evision.DescriptorMatcher.match/1","doc":"","ref":"Evision.DescriptorMatcher.html#match/1"},{"type":"function","title":"Evision.DescriptorMatcher.match/2","doc":"match\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Set of masks. Each masks[i] specifies permissible matches between the input query\n  descriptors and stored train descriptors from the i-th image trainDescCollection[i].\n\n##### Return\n- **matches**: `[Evision.DMatch]`.\n\n  Matches. If a query descriptor is masked out in mask , no match is added for this\n  descriptor. So, matches size may be smaller than the query descriptors count.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmatch(queryDescriptors[, masks]) -> matches\n```","ref":"Evision.DescriptorMatcher.html#match/2"},{"type":"function","title":"Evision.DescriptorMatcher.match/3","doc":"#### Variant 1:\nFinds the best match for each descriptor from a query set.\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n##### Return\n- **matches**: `[Evision.DMatch]`.\n\n  Matches. If a query descriptor is masked out in mask , no match is added for this\n  descriptor. So, matches size may be smaller than the query descriptors count.\n\nIn the first variant of this method, the train descriptors are passed as an input argument. In the\nsecond variant of the method, train descriptors collection that was set by DescriptorMatcher::add is\nused. Optional mask (or masks) can be passed to specify which query and training descriptors can be\nmatched. Namely, queryDescriptors[i] can be matched with trainDescriptors[j] only if\nmask.at\\ (i,j) is non-zero.\n\nPython prototype (for reference only):\n```python3\nmatch(queryDescriptors, trainDescriptors[, mask]) -> matches\n```\n#### Variant 2:\nmatch\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Set of masks. Each masks[i] specifies permissible matches between the input query\n  descriptors and stored train descriptors from the i-th image trainDescCollection[i].\n\n##### Return\n- **matches**: `[Evision.DMatch]`.\n\n  Matches. If a query descriptor is masked out in mask , no match is added for this\n  descriptor. So, matches size may be smaller than the query descriptors count.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmatch(queryDescriptors[, masks]) -> matches\n```","ref":"Evision.DescriptorMatcher.html#match/3"},{"type":"function","title":"Evision.DescriptorMatcher.match/4","doc":"Finds the best match for each descriptor from a query set.\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n##### Return\n- **matches**: `[Evision.DMatch]`.\n\n  Matches. If a query descriptor is masked out in mask , no match is added for this\n  descriptor. So, matches size may be smaller than the query descriptors count.\n\nIn the first variant of this method, the train descriptors are passed as an input argument. In the\nsecond variant of the method, train descriptors collection that was set by DescriptorMatcher::add is\nused. Optional mask (or masks) can be passed to specify which query and training descriptors can be\nmatched. Namely, queryDescriptors[i] can be matched with trainDescriptors[j] only if\nmask.at\\ (i,j) is non-zero.\n\nPython prototype (for reference only):\n```python3\nmatch(queryDescriptors, trainDescriptors[, mask]) -> matches\n```","ref":"Evision.DescriptorMatcher.html#match/4"},{"type":"function","title":"Evision.DescriptorMatcher.radiusMatch/1","doc":"","ref":"Evision.DescriptorMatcher.html#radiusMatch/1"},{"type":"function","title":"Evision.DescriptorMatcher.radiusMatch/3","doc":"radiusMatch\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **maxDistance**: `float`.\n\n  Threshold for the distance between matched descriptors. Distance means here\n  metric distance (e.g. Hamming distance), not the distance between coordinates (which is measured\n  in Pixels)!\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Set of masks. Each masks[i] specifies permissible matches between the input query\n  descriptors and stored train descriptors from the i-th image trainDescCollection[i].\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Found matches.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nradiusMatch(queryDescriptors, maxDistance[, masks[, compactResult]]) -> matches\n```","ref":"Evision.DescriptorMatcher.html#radiusMatch/3"},{"type":"function","title":"Evision.DescriptorMatcher.radiusMatch/4","doc":"#### Variant 1:\nFor each query descriptor, finds the training descriptors not farther than the specified distance.\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **maxDistance**: `float`.\n\n  Threshold for the distance between matched descriptors. Distance means here\n  metric distance (e.g. Hamming distance), not the distance between coordinates (which is measured\n  in Pixels)!\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Found matches.\n\nFor each query descriptor, the methods find such training descriptors that the distance between the\nquery descriptor and the training descriptor is equal or smaller than maxDistance. Found matches are\nreturned in the distance increasing order.\n\nPython prototype (for reference only):\n```python3\nradiusMatch(queryDescriptors, trainDescriptors, maxDistance[, mask[, compactResult]]) -> matches\n```\n#### Variant 2:\nradiusMatch\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **maxDistance**: `float`.\n\n  Threshold for the distance between matched descriptors. Distance means here\n  metric distance (e.g. Hamming distance), not the distance between coordinates (which is measured\n  in Pixels)!\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Set of masks. Each masks[i] specifies permissible matches between the input query\n  descriptors and stored train descriptors from the i-th image trainDescCollection[i].\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Found matches.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nradiusMatch(queryDescriptors, maxDistance[, masks[, compactResult]]) -> matches\n```","ref":"Evision.DescriptorMatcher.html#radiusMatch/4"},{"type":"function","title":"Evision.DescriptorMatcher.radiusMatch/5","doc":"For each query descriptor, finds the training descriptors not farther than the specified distance.\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **maxDistance**: `float`.\n\n  Threshold for the distance between matched descriptors. Distance means here\n  metric distance (e.g. Hamming distance), not the distance between coordinates (which is measured\n  in Pixels)!\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Found matches.\n\nFor each query descriptor, the methods find such training descriptors that the distance between the\nquery descriptor and the training descriptor is equal or smaller than maxDistance. Found matches are\nreturned in the distance increasing order.\n\nPython prototype (for reference only):\n```python3\nradiusMatch(queryDescriptors, trainDescriptors, maxDistance[, mask[, compactResult]]) -> matches\n```","ref":"Evision.DescriptorMatcher.html#radiusMatch/5"},{"type":"function","title":"Evision.DescriptorMatcher.read/1","doc":"","ref":"Evision.DescriptorMatcher.html#read/1"},{"type":"function","title":"Evision.DescriptorMatcher.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.DescriptorMatcher.html#read/2"},{"type":"function","title":"Evision.DescriptorMatcher.save/1","doc":"","ref":"Evision.DescriptorMatcher.html#save/1"},{"type":"function","title":"Evision.DescriptorMatcher.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.DescriptorMatcher.html#save/2"},{"type":"function","title":"Evision.DescriptorMatcher.train/1","doc":"Trains a descriptor matcher\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n\nTrains a descriptor matcher (for example, the flann index). In all methods to match, the method\ntrain() is run every time before matching. Some descriptor matchers (for example, BruteForceMatcher)\nhave an empty implementation of this method. Other matchers really train their inner structures (for\nexample, FlannBasedMatcher trains flann::Index ).\n\nPython prototype (for reference only):\n```python3\ntrain() -> None\n```","ref":"Evision.DescriptorMatcher.html#train/1"},{"type":"function","title":"Evision.DescriptorMatcher.write/1","doc":"","ref":"Evision.DescriptorMatcher.html#write/1"},{"type":"function","title":"Evision.DescriptorMatcher.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.DescriptorMatcher.html#write/2"},{"type":"function","title":"Evision.DescriptorMatcher.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.DescriptorMatcher.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.DescriptorMatcher.html#write/3"},{"type":"type","title":"Evision.DescriptorMatcher.t/0","doc":"Type that represents an `DescriptorMatcher` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.DescriptorMatcher.html#t:t/0"},{"type":"module","title":"Evision.DescriptorMatcher.MatcherType","doc":"","ref":"Evision.DescriptorMatcher.MatcherType.html"},{"type":"function","title":"Evision.DescriptorMatcher.MatcherType.cv_BRUTEFORCE/0","doc":"","ref":"Evision.DescriptorMatcher.MatcherType.html#cv_BRUTEFORCE/0"},{"type":"function","title":"Evision.DescriptorMatcher.MatcherType.cv_BRUTEFORCE_HAMMING/0","doc":"","ref":"Evision.DescriptorMatcher.MatcherType.html#cv_BRUTEFORCE_HAMMING/0"},{"type":"function","title":"Evision.DescriptorMatcher.MatcherType.cv_BRUTEFORCE_HAMMINGLUT/0","doc":"","ref":"Evision.DescriptorMatcher.MatcherType.html#cv_BRUTEFORCE_HAMMINGLUT/0"},{"type":"function","title":"Evision.DescriptorMatcher.MatcherType.cv_BRUTEFORCE_L1/0","doc":"","ref":"Evision.DescriptorMatcher.MatcherType.html#cv_BRUTEFORCE_L1/0"},{"type":"function","title":"Evision.DescriptorMatcher.MatcherType.cv_BRUTEFORCE_SL2/0","doc":"","ref":"Evision.DescriptorMatcher.MatcherType.html#cv_BRUTEFORCE_SL2/0"},{"type":"function","title":"Evision.DescriptorMatcher.MatcherType.cv_FLANNBASED/0","doc":"","ref":"Evision.DescriptorMatcher.MatcherType.html#cv_FLANNBASED/0"},{"type":"type","title":"Evision.DescriptorMatcher.MatcherType.enum/0","doc":"","ref":"Evision.DescriptorMatcher.MatcherType.html#t:enum/0"},{"type":"module","title":"Evision.Detail","doc":"","ref":"Evision.Detail.html"},{"type":"function","title":"Evision.Detail.calibrateRotatingCamera/1","doc":"Estimates focal lengths for each given camera.\n\n##### Positional Arguments\n- **hs**: `[Evision.Mat]`\n\n##### Return\n- **retval**: `bool`\n- **k**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ncalibrateRotatingCamera(Hs[, K]) -> retval, K\n```","ref":"Evision.Detail.html#calibrateRotatingCamera/1"},{"type":"function","title":"Evision.Detail.calibrateRotatingCamera/2","doc":"Estimates focal lengths for each given camera.\n\n##### Positional Arguments\n- **hs**: `[Evision.Mat]`\n\n##### Return\n- **retval**: `bool`\n- **k**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ncalibrateRotatingCamera(Hs[, K]) -> retval, K\n```","ref":"Evision.Detail.html#calibrateRotatingCamera/2"},{"type":"function","title":"Evision.Detail.computeImageFeatures2/1","doc":"","ref":"Evision.Detail.html#computeImageFeatures2/1"},{"type":"function","title":"Evision.Detail.computeImageFeatures2/2","doc":"##### Positional Arguments\n- **featuresFinder**: `Evision.Feature2D`.\n\n- **image**: `Evision.Mat`.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n##### Return\n- **features**: `Evision.Detail.ImageFeatures.t()`.\n\nPython prototype (for reference only):\n```python3\ncomputeImageFeatures2(featuresFinder, image[, mask]) -> features\n```","ref":"Evision.Detail.html#computeImageFeatures2/2"},{"type":"function","title":"Evision.Detail.computeImageFeatures2/3","doc":"##### Positional Arguments\n- **featuresFinder**: `Evision.Feature2D`.\n\n- **image**: `Evision.Mat`.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n##### Return\n- **features**: `Evision.Detail.ImageFeatures.t()`.\n\nPython prototype (for reference only):\n```python3\ncomputeImageFeatures2(featuresFinder, image[, mask]) -> features\n```","ref":"Evision.Detail.html#computeImageFeatures2/3"},{"type":"function","title":"Evision.Detail.computeImageFeatures/1","doc":"","ref":"Evision.Detail.html#computeImageFeatures/1"},{"type":"function","title":"Evision.Detail.computeImageFeatures/2","doc":"##### Positional Arguments\n- **featuresFinder**: `Evision.Feature2D`.\n\n- **images**: `[Evision.Mat]`.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n##### Return\n- **features**: `[Evision.Detail.ImageFeatures]`.\n\nPython prototype (for reference only):\n```python3\ncomputeImageFeatures(featuresFinder, images[, masks]) -> features\n```","ref":"Evision.Detail.html#computeImageFeatures/2"},{"type":"function","title":"Evision.Detail.computeImageFeatures/3","doc":"##### Positional Arguments\n- **featuresFinder**: `Evision.Feature2D`.\n\n- **images**: `[Evision.Mat]`.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n##### Return\n- **features**: `[Evision.Detail.ImageFeatures]`.\n\nPython prototype (for reference only):\n```python3\ncomputeImageFeatures(featuresFinder, images[, masks]) -> features\n```","ref":"Evision.Detail.html#computeImageFeatures/3"},{"type":"function","title":"Evision.Detail.createLaplacePyr/1","doc":"","ref":"Evision.Detail.html#createLaplacePyr/1"},{"type":"function","title":"Evision.Detail.createLaplacePyr/3","doc":"createLaplacePyr\n\n##### Positional Arguments\n- **img**: `Evision.Mat`\n- **num_levels**: `integer()`\n\n##### Return\n- **pyr**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\ncreateLaplacePyr(img, num_levels, pyr) -> pyr\n```","ref":"Evision.Detail.html#createLaplacePyr/3"},{"type":"function","title":"Evision.Detail.createLaplacePyrGpu/1","doc":"","ref":"Evision.Detail.html#createLaplacePyrGpu/1"},{"type":"function","title":"Evision.Detail.createLaplacePyrGpu/3","doc":"createLaplacePyrGpu\n\n##### Positional Arguments\n- **img**: `Evision.Mat`\n- **num_levels**: `integer()`\n\n##### Return\n- **pyr**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\ncreateLaplacePyrGpu(img, num_levels, pyr) -> pyr\n```","ref":"Evision.Detail.html#createLaplacePyrGpu/3"},{"type":"function","title":"Evision.Detail.createWeightMap/1","doc":"","ref":"Evision.Detail.html#createWeightMap/1"},{"type":"function","title":"Evision.Detail.createWeightMap/3","doc":"createWeightMap\n\n##### Positional Arguments\n- **mask**: `Evision.Mat`\n- **sharpness**: `float`\n\n##### Return\n- **weight**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ncreateWeightMap(mask, sharpness, weight) -> weight\n```","ref":"Evision.Detail.html#createWeightMap/3"},{"type":"function","title":"Evision.Detail.focalsFromHomography/1","doc":"","ref":"Evision.Detail.html#focalsFromHomography/1"},{"type":"function","title":"Evision.Detail.focalsFromHomography/5","doc":"Tries to estimate focal lengths from the given homography under the assumption that the camera\nundergoes rotations around its centre only.\n\n##### Positional Arguments\n- **h**: `Evision.Mat`.\n\n  Homography.\n\n- **f0**: `double`.\n\n  Estimated focal length along X axis.\n\n- **f1**: `double`.\n\n  Estimated focal length along Y axis.\n\n- **f0_ok**: `bool`.\n\n  True, if f0 was estimated successfully, false otherwise.\n\n- **f1_ok**: `bool`.\n\n  True, if f1 was estimated successfully, false otherwise.\n\nSee \"Construction of Panoramic Image Mosaics with Global and Local Alignment\"\nby Heung-Yeung Shum and Richard Szeliski.\n\nPython prototype (for reference only):\n```python3\nfocalsFromHomography(H, f0, f1, f0_ok, f1_ok) -> None\n```","ref":"Evision.Detail.html#focalsFromHomography/5"},{"type":"function","title":"Evision.Detail.leaveBiggestComponent/1","doc":"","ref":"Evision.Detail.html#leaveBiggestComponent/1"},{"type":"function","title":"Evision.Detail.leaveBiggestComponent/3","doc":"leaveBiggestComponent\n\n##### Positional Arguments\n- **features**: `[Evision.Detail.ImageFeatures]`\n- **pairwise_matches**: `[Evision.Detail.MatchesInfo]`\n- **conf_threshold**: `float`\n\n##### Return\n- **retval**: `[integer()]`\n\nPython prototype (for reference only):\n```python3\nleaveBiggestComponent(features, pairwise_matches, conf_threshold) -> retval\n```","ref":"Evision.Detail.html#leaveBiggestComponent/3"},{"type":"function","title":"Evision.Detail.matchesGraphAsString/1","doc":"","ref":"Evision.Detail.html#matchesGraphAsString/1"},{"type":"function","title":"Evision.Detail.matchesGraphAsString/3","doc":"matchesGraphAsString\n\n##### Positional Arguments\n- **paths**: `[String]`\n- **pairwise_matches**: `[Evision.Detail.MatchesInfo]`\n- **conf_threshold**: `float`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\nmatchesGraphAsString(paths, pairwise_matches, conf_threshold) -> retval\n```","ref":"Evision.Detail.html#matchesGraphAsString/3"},{"type":"function","title":"Evision.Detail.normalizeUsingWeightMap/1","doc":"","ref":"Evision.Detail.html#normalizeUsingWeightMap/1"},{"type":"function","title":"Evision.Detail.normalizeUsingWeightMap/2","doc":"normalizeUsingWeightMap\n\n##### Positional Arguments\n- **weight**: `Evision.Mat`\n\n##### Return\n- **src**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nnormalizeUsingWeightMap(weight, src) -> src\n```","ref":"Evision.Detail.html#normalizeUsingWeightMap/2"},{"type":"function","title":"Evision.Detail.overlapRoi/1","doc":"","ref":"Evision.Detail.html#overlapRoi/1"},{"type":"function","title":"Evision.Detail.overlapRoi/5","doc":"overlapRoi\n\n##### Positional Arguments\n- **tl1**: `Point`\n- **tl2**: `Point`\n- **sz1**: `Size`\n- **sz2**: `Size`\n- **roi**: `Rect`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\noverlapRoi(tl1, tl2, sz1, sz2, roi) -> retval\n```","ref":"Evision.Detail.html#overlapRoi/5"},{"type":"function","title":"Evision.Detail.restoreImageFromLaplacePyr/1","doc":"restoreImageFromLaplacePyr\n##### Return\n- **pyr**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\nrestoreImageFromLaplacePyr(pyr) -> pyr\n```","ref":"Evision.Detail.html#restoreImageFromLaplacePyr/1"},{"type":"function","title":"Evision.Detail.restoreImageFromLaplacePyrGpu/1","doc":"restoreImageFromLaplacePyrGpu\n##### Return\n- **pyr**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\nrestoreImageFromLaplacePyrGpu(pyr) -> pyr\n```","ref":"Evision.Detail.html#restoreImageFromLaplacePyrGpu/1"},{"type":"function","title":"Evision.Detail.resultRoi/1","doc":"","ref":"Evision.Detail.html#resultRoi/1"},{"type":"function","title":"Evision.Detail.resultRoi/2","doc":"resultRoi\n\n##### Positional Arguments\n- **corners**: `[Point]`\n- **sizes**: `[Size]`\n\n##### Return\n- **retval**: `Rect`\n\nPython prototype (for reference only):\n```python3\nresultRoi(corners, sizes) -> retval\n```","ref":"Evision.Detail.html#resultRoi/2"},{"type":"function","title":"Evision.Detail.resultRoiIntersection/1","doc":"","ref":"Evision.Detail.html#resultRoiIntersection/1"},{"type":"function","title":"Evision.Detail.resultRoiIntersection/2","doc":"resultRoiIntersection\n\n##### Positional Arguments\n- **corners**: `[Point]`\n- **sizes**: `[Size]`\n\n##### Return\n- **retval**: `Rect`\n\nPython prototype (for reference only):\n```python3\nresultRoiIntersection(corners, sizes) -> retval\n```","ref":"Evision.Detail.html#resultRoiIntersection/2"},{"type":"function","title":"Evision.Detail.resultTl/1","doc":"resultTl\n\n##### Positional Arguments\n- **corners**: `[Point]`\n\n##### Return\n- **retval**: `Point`\n\nPython prototype (for reference only):\n```python3\nresultTl(corners) -> retval\n```","ref":"Evision.Detail.html#resultTl/1"},{"type":"function","title":"Evision.Detail.selectRandomSubset/1","doc":"","ref":"Evision.Detail.html#selectRandomSubset/1"},{"type":"function","title":"Evision.Detail.selectRandomSubset/3","doc":"selectRandomSubset\n\n##### Positional Arguments\n- **count**: `integer()`\n- **size**: `integer()`\n- **subset**: `[integer()]`\n\nPython prototype (for reference only):\n```python3\nselectRandomSubset(count, size, subset) -> None\n```","ref":"Evision.Detail.html#selectRandomSubset/3"},{"type":"function","title":"Evision.Detail.stitchingLogLevel/0","doc":"stitchingLogLevel\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nstitchingLogLevel() -> retval\n```","ref":"Evision.Detail.html#stitchingLogLevel/0"},{"type":"function","title":"Evision.Detail.stitchingLogLevel/1","doc":"","ref":"Evision.Detail.html#stitchingLogLevel/1"},{"type":"function","title":"Evision.Detail.waveCorrect/1","doc":"","ref":"Evision.Detail.html#waveCorrect/1"},{"type":"function","title":"Evision.Detail.waveCorrect/2","doc":"Tries to make panorama more horizontal (or vertical).\n\n##### Positional Arguments\n- **kind**: `WaveCorrectKind`.\n\n  Correction kind, see detail::WaveCorrectKind.\n\n##### Return\n- **rmats**: `[Evision.Mat]`.\n\n  Camera rotation matrices.\n\nPython prototype (for reference only):\n```python3\nwaveCorrect(rmats, kind) -> rmats\n```","ref":"Evision.Detail.html#waveCorrect/2"},{"type":"type","title":"Evision.Detail.t/0","doc":"Type that represents an `Detail` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.html#t:t/0"},{"type":"module","title":"Evision.Detail.AffineBasedEstimator","doc":"","ref":"Evision.Detail.AffineBasedEstimator.html"},{"type":"function","title":"Evision.Detail.AffineBasedEstimator.affineBasedEstimator/0","doc":"AffineBasedEstimator\n##### Return\n- **self**: `Evision.Detail.AffineBasedEstimator.t()`\n\nPython prototype (for reference only):\n```python3\nAffineBasedEstimator() ->  \n```","ref":"Evision.Detail.AffineBasedEstimator.html#affineBasedEstimator/0"},{"type":"function","title":"Evision.Detail.AffineBasedEstimator.affineBasedEstimator/1","doc":"","ref":"Evision.Detail.AffineBasedEstimator.html#affineBasedEstimator/1"},{"type":"type","title":"Evision.Detail.AffineBasedEstimator.t/0","doc":"Type that represents an `Detail.AffineBasedEstimator` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.AffineBasedEstimator.html#t:t/0"},{"type":"module","title":"Evision.Detail.AffineBestOf2NearestMatcher","doc":"","ref":"Evision.Detail.AffineBestOf2NearestMatcher.html"},{"type":"function","title":"Evision.Detail.AffineBestOf2NearestMatcher.affineBestOf2NearestMatcher/0","doc":"Constructs a \"best of 2 nearest\" matcher that expects affine transformation\nbetween images\n\n##### Keyword Arguments\n- **full_affine**: `bool`.\n\n  whether to use full affine transformation with 6 degress of freedom or reduced\n  transformation with 4 degrees of freedom using only rotation, translation and uniform scaling\n\n- **try_use_gpu**: `bool`.\n\n  Should try to use GPU or not\n\n- **match_conf**: `float`.\n\n  Match distances ration threshold\n\n- **num_matches_thresh1**: `integer()`.\n\n  Minimum number of matches required for the 2D affine transform\n  estimation used in the inliers classification step\n\n##### Return\n- **self**: `Evision.Detail.AffineBestOf2NearestMatcher.t()`\n\n@sa cv::estimateAffine2D cv::estimateAffinePartial2D\n\nPython prototype (for reference only):\n```python3\nAffineBestOf2NearestMatcher([, full_affine[, try_use_gpu[, match_conf[, num_matches_thresh1]]]]) ->  \n```","ref":"Evision.Detail.AffineBestOf2NearestMatcher.html#affineBestOf2NearestMatcher/0"},{"type":"function","title":"Evision.Detail.AffineBestOf2NearestMatcher.affineBestOf2NearestMatcher/1","doc":"Constructs a \"best of 2 nearest\" matcher that expects affine transformation\nbetween images\n\n##### Keyword Arguments\n- **full_affine**: `bool`.\n\n  whether to use full affine transformation with 6 degress of freedom or reduced\n  transformation with 4 degrees of freedom using only rotation, translation and uniform scaling\n\n- **try_use_gpu**: `bool`.\n\n  Should try to use GPU or not\n\n- **match_conf**: `float`.\n\n  Match distances ration threshold\n\n- **num_matches_thresh1**: `integer()`.\n\n  Minimum number of matches required for the 2D affine transform\n  estimation used in the inliers classification step\n\n##### Return\n- **self**: `Evision.Detail.AffineBestOf2NearestMatcher.t()`\n\n@sa cv::estimateAffine2D cv::estimateAffinePartial2D\n\nPython prototype (for reference only):\n```python3\nAffineBestOf2NearestMatcher([, full_affine[, try_use_gpu[, match_conf[, num_matches_thresh1]]]]) ->  \n```","ref":"Evision.Detail.AffineBestOf2NearestMatcher.html#affineBestOf2NearestMatcher/1"},{"type":"function","title":"Evision.Detail.AffineBestOf2NearestMatcher.apply2/1","doc":"","ref":"Evision.Detail.AffineBestOf2NearestMatcher.html#apply2/1"},{"type":"function","title":"Evision.Detail.AffineBestOf2NearestMatcher.apply2/2","doc":"Performs images matching.\n\n##### Positional Arguments\n- **self**: `Evision.Detail.AffineBestOf2NearestMatcher.t()`\n- **features**: `[Evision.Detail.ImageFeatures]`.\n\n  Features of the source images\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask indicating which image pairs must be matched\n\n##### Return\n- **pairwise_matches**: `[Evision.Detail.MatchesInfo]`.\n\n  Found pairwise matches\n\nThe function is parallelized with the TBB library.\n@sa detail::MatchesInfo\n\nPython prototype (for reference only):\n```python3\napply2(features[, mask]) -> pairwise_matches\n```","ref":"Evision.Detail.AffineBestOf2NearestMatcher.html#apply2/2"},{"type":"function","title":"Evision.Detail.AffineBestOf2NearestMatcher.apply2/3","doc":"Performs images matching.\n\n##### Positional Arguments\n- **self**: `Evision.Detail.AffineBestOf2NearestMatcher.t()`\n- **features**: `[Evision.Detail.ImageFeatures]`.\n\n  Features of the source images\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask indicating which image pairs must be matched\n\n##### Return\n- **pairwise_matches**: `[Evision.Detail.MatchesInfo]`.\n\n  Found pairwise matches\n\nThe function is parallelized with the TBB library.\n@sa detail::MatchesInfo\n\nPython prototype (for reference only):\n```python3\napply2(features[, mask]) -> pairwise_matches\n```","ref":"Evision.Detail.AffineBestOf2NearestMatcher.html#apply2/3"},{"type":"function","title":"Evision.Detail.AffineBestOf2NearestMatcher.apply/1","doc":"","ref":"Evision.Detail.AffineBestOf2NearestMatcher.html#apply/1"},{"type":"function","title":"Evision.Detail.AffineBestOf2NearestMatcher.apply/3","doc":"apply\n\n##### Positional Arguments\n- **self**: `Evision.Detail.AffineBestOf2NearestMatcher.t()`\n- **features1**: `Evision.Detail.ImageFeatures`.\n\n  First image features\n\n- **features2**: `Evision.Detail.ImageFeatures`.\n\n  Second image features\n\n##### Return\n- **matches_info**: `Evision.Detail.MatchesInfo.t()`.\n\n  Found matches\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\napply(features1, features2) -> matches_info\n```","ref":"Evision.Detail.AffineBestOf2NearestMatcher.html#apply/3"},{"type":"function","title":"Evision.Detail.AffineBestOf2NearestMatcher.collectGarbage/1","doc":"collectGarbage\n\n##### Positional Arguments\n- **self**: `Evision.Detail.AffineBestOf2NearestMatcher.t()`\n\nPython prototype (for reference only):\n```python3\ncollectGarbage() -> None\n```","ref":"Evision.Detail.AffineBestOf2NearestMatcher.html#collectGarbage/1"},{"type":"function","title":"Evision.Detail.AffineBestOf2NearestMatcher.create/0","doc":"create\n##### Keyword Arguments\n- **try_use_gpu**: `bool`.\n- **match_conf**: `float`.\n- **num_matches_thresh1**: `integer()`.\n- **num_matches_thresh2**: `integer()`.\n- **matches_confindece_thresh**: `double`.\n\n##### Return\n- **retval**: `Evision.Detail.BestOf2NearestMatcher.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, try_use_gpu[, match_conf[, num_matches_thresh1[, num_matches_thresh2[, matches_confindece_thresh]]]]]) -> retval\n```","ref":"Evision.Detail.AffineBestOf2NearestMatcher.html#create/0"},{"type":"function","title":"Evision.Detail.AffineBestOf2NearestMatcher.create/1","doc":"create\n##### Keyword Arguments\n- **try_use_gpu**: `bool`.\n- **match_conf**: `float`.\n- **num_matches_thresh1**: `integer()`.\n- **num_matches_thresh2**: `integer()`.\n- **matches_confindece_thresh**: `double`.\n\n##### Return\n- **retval**: `Evision.Detail.BestOf2NearestMatcher.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, try_use_gpu[, match_conf[, num_matches_thresh1[, num_matches_thresh2[, matches_confindece_thresh]]]]]) -> retval\n```","ref":"Evision.Detail.AffineBestOf2NearestMatcher.html#create/1"},{"type":"function","title":"Evision.Detail.AffineBestOf2NearestMatcher.isThreadSafe/1","doc":"isThreadSafe\n\n##### Positional Arguments\n- **self**: `Evision.Detail.AffineBestOf2NearestMatcher.t()`\n\n##### Return\n- **retval**: `bool`\n\n@return True, if it's possible to use the same matcher instance in parallel, false otherwise\n\nPython prototype (for reference only):\n```python3\nisThreadSafe() -> retval\n```","ref":"Evision.Detail.AffineBestOf2NearestMatcher.html#isThreadSafe/1"},{"type":"type","title":"Evision.Detail.AffineBestOf2NearestMatcher.t/0","doc":"Type that represents an `Detail.AffineBestOf2NearestMatcher` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.AffineBestOf2NearestMatcher.html#t:t/0"},{"type":"module","title":"Evision.Detail.BestOf2NearestMatcher","doc":"","ref":"Evision.Detail.BestOf2NearestMatcher.html"},{"type":"function","title":"Evision.Detail.BestOf2NearestMatcher.apply2/1","doc":"","ref":"Evision.Detail.BestOf2NearestMatcher.html#apply2/1"},{"type":"function","title":"Evision.Detail.BestOf2NearestMatcher.apply2/2","doc":"Performs images matching.\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BestOf2NearestMatcher.t()`\n- **features**: `[Evision.Detail.ImageFeatures]`.\n\n  Features of the source images\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask indicating which image pairs must be matched\n\n##### Return\n- **pairwise_matches**: `[Evision.Detail.MatchesInfo]`.\n\n  Found pairwise matches\n\nThe function is parallelized with the TBB library.\n@sa detail::MatchesInfo\n\nPython prototype (for reference only):\n```python3\napply2(features[, mask]) -> pairwise_matches\n```","ref":"Evision.Detail.BestOf2NearestMatcher.html#apply2/2"},{"type":"function","title":"Evision.Detail.BestOf2NearestMatcher.apply2/3","doc":"Performs images matching.\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BestOf2NearestMatcher.t()`\n- **features**: `[Evision.Detail.ImageFeatures]`.\n\n  Features of the source images\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask indicating which image pairs must be matched\n\n##### Return\n- **pairwise_matches**: `[Evision.Detail.MatchesInfo]`.\n\n  Found pairwise matches\n\nThe function is parallelized with the TBB library.\n@sa detail::MatchesInfo\n\nPython prototype (for reference only):\n```python3\napply2(features[, mask]) -> pairwise_matches\n```","ref":"Evision.Detail.BestOf2NearestMatcher.html#apply2/3"},{"type":"function","title":"Evision.Detail.BestOf2NearestMatcher.apply/1","doc":"","ref":"Evision.Detail.BestOf2NearestMatcher.html#apply/1"},{"type":"function","title":"Evision.Detail.BestOf2NearestMatcher.apply/3","doc":"apply\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BestOf2NearestMatcher.t()`\n- **features1**: `Evision.Detail.ImageFeatures`.\n\n  First image features\n\n- **features2**: `Evision.Detail.ImageFeatures`.\n\n  Second image features\n\n##### Return\n- **matches_info**: `Evision.Detail.MatchesInfo.t()`.\n\n  Found matches\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\napply(features1, features2) -> matches_info\n```","ref":"Evision.Detail.BestOf2NearestMatcher.html#apply/3"},{"type":"function","title":"Evision.Detail.BestOf2NearestMatcher.bestOf2NearestMatcher/0","doc":"Constructs a \"best of 2 nearest\" matcher.\n##### Keyword Arguments\n- **try_use_gpu**: `bool`.\n\n  Should try to use GPU or not\n\n- **match_conf**: `float`.\n\n  Match distances ration threshold\n\n- **num_matches_thresh1**: `integer()`.\n\n  Minimum number of matches required for the 2D projective transform\n  estimation used in the inliers classification step\n\n- **num_matches_thresh2**: `integer()`.\n\n  Minimum number of matches required for the 2D projective transform\n  re-estimation on inliers\n\n- **matches_confindece_thresh**: `double`.\n\n  Matching confidence threshold to take the match into account.\n  The threshold was determined experimentally and set to 3 by default.\n\n##### Return\n- **self**: `Evision.Detail.BestOf2NearestMatcher.t()`\n\nPython prototype (for reference only):\n```python3\nBestOf2NearestMatcher([, try_use_gpu[, match_conf[, num_matches_thresh1[, num_matches_thresh2[, matches_confindece_thresh]]]]]) ->  \n```","ref":"Evision.Detail.BestOf2NearestMatcher.html#bestOf2NearestMatcher/0"},{"type":"function","title":"Evision.Detail.BestOf2NearestMatcher.bestOf2NearestMatcher/1","doc":"Constructs a \"best of 2 nearest\" matcher.\n##### Keyword Arguments\n- **try_use_gpu**: `bool`.\n\n  Should try to use GPU or not\n\n- **match_conf**: `float`.\n\n  Match distances ration threshold\n\n- **num_matches_thresh1**: `integer()`.\n\n  Minimum number of matches required for the 2D projective transform\n  estimation used in the inliers classification step\n\n- **num_matches_thresh2**: `integer()`.\n\n  Minimum number of matches required for the 2D projective transform\n  re-estimation on inliers\n\n- **matches_confindece_thresh**: `double`.\n\n  Matching confidence threshold to take the match into account.\n  The threshold was determined experimentally and set to 3 by default.\n\n##### Return\n- **self**: `Evision.Detail.BestOf2NearestMatcher.t()`\n\nPython prototype (for reference only):\n```python3\nBestOf2NearestMatcher([, try_use_gpu[, match_conf[, num_matches_thresh1[, num_matches_thresh2[, matches_confindece_thresh]]]]]) ->  \n```","ref":"Evision.Detail.BestOf2NearestMatcher.html#bestOf2NearestMatcher/1"},{"type":"function","title":"Evision.Detail.BestOf2NearestMatcher.collectGarbage/1","doc":"collectGarbage\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BestOf2NearestMatcher.t()`\n\nPython prototype (for reference only):\n```python3\ncollectGarbage() -> None\n```","ref":"Evision.Detail.BestOf2NearestMatcher.html#collectGarbage/1"},{"type":"function","title":"Evision.Detail.BestOf2NearestMatcher.create/0","doc":"create\n##### Keyword Arguments\n- **try_use_gpu**: `bool`.\n- **match_conf**: `float`.\n- **num_matches_thresh1**: `integer()`.\n- **num_matches_thresh2**: `integer()`.\n- **matches_confindece_thresh**: `double`.\n\n##### Return\n- **retval**: `Evision.Detail.BestOf2NearestMatcher.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, try_use_gpu[, match_conf[, num_matches_thresh1[, num_matches_thresh2[, matches_confindece_thresh]]]]]) -> retval\n```","ref":"Evision.Detail.BestOf2NearestMatcher.html#create/0"},{"type":"function","title":"Evision.Detail.BestOf2NearestMatcher.create/1","doc":"create\n##### Keyword Arguments\n- **try_use_gpu**: `bool`.\n- **match_conf**: `float`.\n- **num_matches_thresh1**: `integer()`.\n- **num_matches_thresh2**: `integer()`.\n- **matches_confindece_thresh**: `double`.\n\n##### Return\n- **retval**: `Evision.Detail.BestOf2NearestMatcher.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, try_use_gpu[, match_conf[, num_matches_thresh1[, num_matches_thresh2[, matches_confindece_thresh]]]]]) -> retval\n```","ref":"Evision.Detail.BestOf2NearestMatcher.html#create/1"},{"type":"function","title":"Evision.Detail.BestOf2NearestMatcher.isThreadSafe/1","doc":"isThreadSafe\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BestOf2NearestMatcher.t()`\n\n##### Return\n- **retval**: `bool`\n\n@return True, if it's possible to use the same matcher instance in parallel, false otherwise\n\nPython prototype (for reference only):\n```python3\nisThreadSafe() -> retval\n```","ref":"Evision.Detail.BestOf2NearestMatcher.html#isThreadSafe/1"},{"type":"type","title":"Evision.Detail.BestOf2NearestMatcher.t/0","doc":"Type that represents an `Detail.BestOf2NearestMatcher` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.BestOf2NearestMatcher.html#t:t/0"},{"type":"module","title":"Evision.Detail.BestOf2NearestRangeMatcher","doc":"","ref":"Evision.Detail.BestOf2NearestRangeMatcher.html"},{"type":"function","title":"Evision.Detail.BestOf2NearestRangeMatcher.apply2/1","doc":"","ref":"Evision.Detail.BestOf2NearestRangeMatcher.html#apply2/1"},{"type":"function","title":"Evision.Detail.BestOf2NearestRangeMatcher.apply2/2","doc":"Performs images matching.\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BestOf2NearestRangeMatcher.t()`\n- **features**: `[Evision.Detail.ImageFeatures]`.\n\n  Features of the source images\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask indicating which image pairs must be matched\n\n##### Return\n- **pairwise_matches**: `[Evision.Detail.MatchesInfo]`.\n\n  Found pairwise matches\n\nThe function is parallelized with the TBB library.\n@sa detail::MatchesInfo\n\nPython prototype (for reference only):\n```python3\napply2(features[, mask]) -> pairwise_matches\n```","ref":"Evision.Detail.BestOf2NearestRangeMatcher.html#apply2/2"},{"type":"function","title":"Evision.Detail.BestOf2NearestRangeMatcher.apply2/3","doc":"Performs images matching.\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BestOf2NearestRangeMatcher.t()`\n- **features**: `[Evision.Detail.ImageFeatures]`.\n\n  Features of the source images\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask indicating which image pairs must be matched\n\n##### Return\n- **pairwise_matches**: `[Evision.Detail.MatchesInfo]`.\n\n  Found pairwise matches\n\nThe function is parallelized with the TBB library.\n@sa detail::MatchesInfo\n\nPython prototype (for reference only):\n```python3\napply2(features[, mask]) -> pairwise_matches\n```","ref":"Evision.Detail.BestOf2NearestRangeMatcher.html#apply2/3"},{"type":"function","title":"Evision.Detail.BestOf2NearestRangeMatcher.apply/1","doc":"","ref":"Evision.Detail.BestOf2NearestRangeMatcher.html#apply/1"},{"type":"function","title":"Evision.Detail.BestOf2NearestRangeMatcher.apply/3","doc":"apply\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BestOf2NearestRangeMatcher.t()`\n- **features1**: `Evision.Detail.ImageFeatures`.\n\n  First image features\n\n- **features2**: `Evision.Detail.ImageFeatures`.\n\n  Second image features\n\n##### Return\n- **matches_info**: `Evision.Detail.MatchesInfo.t()`.\n\n  Found matches\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\napply(features1, features2) -> matches_info\n```","ref":"Evision.Detail.BestOf2NearestRangeMatcher.html#apply/3"},{"type":"function","title":"Evision.Detail.BestOf2NearestRangeMatcher.bestOf2NearestRangeMatcher/0","doc":"BestOf2NearestRangeMatcher\n##### Keyword Arguments\n- **range_width**: `integer()`.\n- **try_use_gpu**: `bool`.\n- **match_conf**: `float`.\n- **num_matches_thresh1**: `integer()`.\n- **num_matches_thresh2**: `integer()`.\n\n##### Return\n- **self**: `Evision.Detail.BestOf2NearestRangeMatcher.t()`\n\nPython prototype (for reference only):\n```python3\nBestOf2NearestRangeMatcher([, range_width[, try_use_gpu[, match_conf[, num_matches_thresh1[, num_matches_thresh2]]]]]) ->  \n```","ref":"Evision.Detail.BestOf2NearestRangeMatcher.html#bestOf2NearestRangeMatcher/0"},{"type":"function","title":"Evision.Detail.BestOf2NearestRangeMatcher.bestOf2NearestRangeMatcher/1","doc":"BestOf2NearestRangeMatcher\n##### Keyword Arguments\n- **range_width**: `integer()`.\n- **try_use_gpu**: `bool`.\n- **match_conf**: `float`.\n- **num_matches_thresh1**: `integer()`.\n- **num_matches_thresh2**: `integer()`.\n\n##### Return\n- **self**: `Evision.Detail.BestOf2NearestRangeMatcher.t()`\n\nPython prototype (for reference only):\n```python3\nBestOf2NearestRangeMatcher([, range_width[, try_use_gpu[, match_conf[, num_matches_thresh1[, num_matches_thresh2]]]]]) ->  \n```","ref":"Evision.Detail.BestOf2NearestRangeMatcher.html#bestOf2NearestRangeMatcher/1"},{"type":"function","title":"Evision.Detail.BestOf2NearestRangeMatcher.collectGarbage/1","doc":"collectGarbage\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BestOf2NearestRangeMatcher.t()`\n\nPython prototype (for reference only):\n```python3\ncollectGarbage() -> None\n```","ref":"Evision.Detail.BestOf2NearestRangeMatcher.html#collectGarbage/1"},{"type":"function","title":"Evision.Detail.BestOf2NearestRangeMatcher.create/0","doc":"create\n##### Keyword Arguments\n- **try_use_gpu**: `bool`.\n- **match_conf**: `float`.\n- **num_matches_thresh1**: `integer()`.\n- **num_matches_thresh2**: `integer()`.\n- **matches_confindece_thresh**: `double`.\n\n##### Return\n- **retval**: `Evision.Detail.BestOf2NearestMatcher.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, try_use_gpu[, match_conf[, num_matches_thresh1[, num_matches_thresh2[, matches_confindece_thresh]]]]]) -> retval\n```","ref":"Evision.Detail.BestOf2NearestRangeMatcher.html#create/0"},{"type":"function","title":"Evision.Detail.BestOf2NearestRangeMatcher.create/1","doc":"create\n##### Keyword Arguments\n- **try_use_gpu**: `bool`.\n- **match_conf**: `float`.\n- **num_matches_thresh1**: `integer()`.\n- **num_matches_thresh2**: `integer()`.\n- **matches_confindece_thresh**: `double`.\n\n##### Return\n- **retval**: `Evision.Detail.BestOf2NearestMatcher.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, try_use_gpu[, match_conf[, num_matches_thresh1[, num_matches_thresh2[, matches_confindece_thresh]]]]]) -> retval\n```","ref":"Evision.Detail.BestOf2NearestRangeMatcher.html#create/1"},{"type":"function","title":"Evision.Detail.BestOf2NearestRangeMatcher.isThreadSafe/1","doc":"isThreadSafe\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BestOf2NearestRangeMatcher.t()`\n\n##### Return\n- **retval**: `bool`\n\n@return True, if it's possible to use the same matcher instance in parallel, false otherwise\n\nPython prototype (for reference only):\n```python3\nisThreadSafe() -> retval\n```","ref":"Evision.Detail.BestOf2NearestRangeMatcher.html#isThreadSafe/1"},{"type":"type","title":"Evision.Detail.BestOf2NearestRangeMatcher.t/0","doc":"Type that represents an `Detail.BestOf2NearestRangeMatcher` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.BestOf2NearestRangeMatcher.html#t:t/0"},{"type":"module","title":"Evision.Detail.Blender","doc":"","ref":"Evision.Detail.Blender.html"},{"type":"function","title":"Evision.Detail.Blender.blend/1","doc":"","ref":"Evision.Detail.Blender.html#blend/1"},{"type":"function","title":"Evision.Detail.Blender.blend/3","doc":"Blends and returns the final pano.\n\n##### Positional Arguments\n- **self**: `Evision.Detail.Blender.t()`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Final pano\n\n- **dst_mask**: `Evision.Mat.t()`.\n\n  Final pano mask\n\nPython prototype (for reference only):\n```python3\nblend(dst, dst_mask) -> dst, dst_mask\n```","ref":"Evision.Detail.Blender.html#blend/3"},{"type":"function","title":"Evision.Detail.Blender.createDefault/1","doc":"createDefault\n\n##### Positional Arguments\n- **type**: `integer()`\n\n##### Keyword Arguments\n- **try_gpu**: `bool`.\n\n##### Return\n- **retval**: `Evision.Detail.Blender.t()`\n\nPython prototype (for reference only):\n```python3\ncreateDefault(type[, try_gpu]) -> retval\n```","ref":"Evision.Detail.Blender.html#createDefault/1"},{"type":"function","title":"Evision.Detail.Blender.createDefault/2","doc":"createDefault\n\n##### Positional Arguments\n- **type**: `integer()`\n\n##### Keyword Arguments\n- **try_gpu**: `bool`.\n\n##### Return\n- **retval**: `Evision.Detail.Blender.t()`\n\nPython prototype (for reference only):\n```python3\ncreateDefault(type[, try_gpu]) -> retval\n```","ref":"Evision.Detail.Blender.html#createDefault/2"},{"type":"function","title":"Evision.Detail.Blender.cv_FEATHER/0","doc":"","ref":"Evision.Detail.Blender.html#cv_FEATHER/0"},{"type":"function","title":"Evision.Detail.Blender.cv_MULTI_BAND/0","doc":"","ref":"Evision.Detail.Blender.html#cv_MULTI_BAND/0"},{"type":"function","title":"Evision.Detail.Blender.cv_NO/0","doc":"","ref":"Evision.Detail.Blender.html#cv_NO/0"},{"type":"function","title":"Evision.Detail.Blender.feed/1","doc":"","ref":"Evision.Detail.Blender.html#feed/1"},{"type":"function","title":"Evision.Detail.Blender.feed/4","doc":"Processes the image.\n\n##### Positional Arguments\n- **self**: `Evision.Detail.Blender.t()`\n- **img**: `Evision.Mat`.\n\n  Source image\n\n- **mask**: `Evision.Mat`.\n\n  Source image mask\n\n- **tl**: `Point`.\n\n  Source image top-left corners\n\nPython prototype (for reference only):\n```python3\nfeed(img, mask, tl) -> None\n```","ref":"Evision.Detail.Blender.html#feed/4"},{"type":"function","title":"Evision.Detail.Blender.prepare/1","doc":"","ref":"Evision.Detail.Blender.html#prepare/1"},{"type":"function","title":"Evision.Detail.Blender.prepare/2","doc":"prepare\n\n##### Positional Arguments\n- **self**: `Evision.Detail.Blender.t()`\n- **dst_roi**: `Rect`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nprepare(dst_roi) -> None\n```","ref":"Evision.Detail.Blender.html#prepare/2"},{"type":"function","title":"Evision.Detail.Blender.prepare/3","doc":"Prepares the blender for blending.\n\n##### Positional Arguments\n- **self**: `Evision.Detail.Blender.t()`\n- **corners**: `[Point]`.\n\n  Source images top-left corners\n\n- **sizes**: `[Size]`.\n\n  Source image sizes\n\nPython prototype (for reference only):\n```python3\nprepare(corners, sizes) -> None\n```","ref":"Evision.Detail.Blender.html#prepare/3"},{"type":"type","title":"Evision.Detail.Blender.enum/0","doc":"","ref":"Evision.Detail.Blender.html#t:enum/0"},{"type":"type","title":"Evision.Detail.Blender.t/0","doc":"Type that represents an `Detail.Blender` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.Blender.html#t:t/0"},{"type":"module","title":"Evision.Detail.BlocksChannelsCompensator","doc":"","ref":"Evision.Detail.BlocksChannelsCompensator.html"},{"type":"function","title":"Evision.Detail.BlocksChannelsCompensator.blocksChannelsCompensator/0","doc":"BlocksChannelsCompensator\n##### Keyword Arguments\n- **bl_width**: `integer()`.\n- **bl_height**: `integer()`.\n- **nr_feeds**: `integer()`.\n\n##### Return\n- **self**: `Evision.Detail.BlocksChannelsCompensator.t()`\n\nPython prototype (for reference only):\n```python3\nBlocksChannelsCompensator([, bl_width[, bl_height[, nr_feeds]]]) ->  \n```","ref":"Evision.Detail.BlocksChannelsCompensator.html#blocksChannelsCompensator/0"},{"type":"function","title":"Evision.Detail.BlocksChannelsCompensator.blocksChannelsCompensator/1","doc":"BlocksChannelsCompensator\n##### Keyword Arguments\n- **bl_width**: `integer()`.\n- **bl_height**: `integer()`.\n- **nr_feeds**: `integer()`.\n\n##### Return\n- **self**: `Evision.Detail.BlocksChannelsCompensator.t()`\n\nPython prototype (for reference only):\n```python3\nBlocksChannelsCompensator([, bl_width[, bl_height[, nr_feeds]]]) ->  \n```","ref":"Evision.Detail.BlocksChannelsCompensator.html#blocksChannelsCompensator/1"},{"type":"type","title":"Evision.Detail.BlocksChannelsCompensator.t/0","doc":"Type that represents an `Detail.BlocksChannelsCompensator` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.BlocksChannelsCompensator.html#t:t/0"},{"type":"module","title":"Evision.Detail.BlocksCompensator","doc":"","ref":"Evision.Detail.BlocksCompensator.html"},{"type":"function","title":"Evision.Detail.BlocksCompensator.apply/1","doc":"","ref":"Evision.Detail.BlocksCompensator.html#apply/1"},{"type":"function","title":"Evision.Detail.BlocksCompensator.apply/5","doc":"apply\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BlocksCompensator.t()`\n- **index**: `integer()`\n- **corner**: `Point`\n- **mask**: `Evision.Mat`\n\n##### Return\n- **image**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\napply(index, corner, image, mask) -> image\n```","ref":"Evision.Detail.BlocksCompensator.html#apply/5"},{"type":"function","title":"Evision.Detail.BlocksCompensator.getBlockSize/1","doc":"getBlockSize\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BlocksCompensator.t()`\n\n##### Return\n- **retval**: `Size`\n\nPython prototype (for reference only):\n```python3\ngetBlockSize() -> retval\n```","ref":"Evision.Detail.BlocksCompensator.html#getBlockSize/1"},{"type":"function","title":"Evision.Detail.BlocksCompensator.getMatGains/1","doc":"getMatGains\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BlocksCompensator.t()`\n\n##### Return\n- **umv**: `[Evision.Mat]`.\n\nPython prototype (for reference only):\n```python3\ngetMatGains([, umv]) -> umv\n```","ref":"Evision.Detail.BlocksCompensator.html#getMatGains/1"},{"type":"function","title":"Evision.Detail.BlocksCompensator.getMatGains/2","doc":"getMatGains\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BlocksCompensator.t()`\n\n##### Return\n- **umv**: `[Evision.Mat]`.\n\nPython prototype (for reference only):\n```python3\ngetMatGains([, umv]) -> umv\n```","ref":"Evision.Detail.BlocksCompensator.html#getMatGains/2"},{"type":"function","title":"Evision.Detail.BlocksCompensator.getNrFeeds/1","doc":"getNrFeeds\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BlocksCompensator.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNrFeeds() -> retval\n```","ref":"Evision.Detail.BlocksCompensator.html#getNrFeeds/1"},{"type":"function","title":"Evision.Detail.BlocksCompensator.getNrGainsFilteringIterations/1","doc":"getNrGainsFilteringIterations\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BlocksCompensator.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNrGainsFilteringIterations() -> retval\n```","ref":"Evision.Detail.BlocksCompensator.html#getNrGainsFilteringIterations/1"},{"type":"function","title":"Evision.Detail.BlocksCompensator.getSimilarityThreshold/1","doc":"getSimilarityThreshold\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BlocksCompensator.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetSimilarityThreshold() -> retval\n```","ref":"Evision.Detail.BlocksCompensator.html#getSimilarityThreshold/1"},{"type":"function","title":"Evision.Detail.BlocksCompensator.setBlockSize/1","doc":"","ref":"Evision.Detail.BlocksCompensator.html#setBlockSize/1"},{"type":"function","title":"Evision.Detail.BlocksCompensator.setBlockSize/2","doc":"setBlockSize\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BlocksCompensator.t()`\n- **size**: `Size`\n\nPython prototype (for reference only):\n```python3\nsetBlockSize(size) -> None\n```","ref":"Evision.Detail.BlocksCompensator.html#setBlockSize/2"},{"type":"function","title":"Evision.Detail.BlocksCompensator.setBlockSize/3","doc":"setBlockSize\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BlocksCompensator.t()`\n- **width**: `integer()`\n- **height**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetBlockSize(width, height) -> None\n```","ref":"Evision.Detail.BlocksCompensator.html#setBlockSize/3"},{"type":"function","title":"Evision.Detail.BlocksCompensator.setMatGains/1","doc":"","ref":"Evision.Detail.BlocksCompensator.html#setMatGains/1"},{"type":"function","title":"Evision.Detail.BlocksCompensator.setMatGains/2","doc":"setMatGains\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BlocksCompensator.t()`\n- **umv**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\nsetMatGains(umv) -> None\n```","ref":"Evision.Detail.BlocksCompensator.html#setMatGains/2"},{"type":"function","title":"Evision.Detail.BlocksCompensator.setNrFeeds/1","doc":"","ref":"Evision.Detail.BlocksCompensator.html#setNrFeeds/1"},{"type":"function","title":"Evision.Detail.BlocksCompensator.setNrFeeds/2","doc":"setNrFeeds\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BlocksCompensator.t()`\n- **nr_feeds**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNrFeeds(nr_feeds) -> None\n```","ref":"Evision.Detail.BlocksCompensator.html#setNrFeeds/2"},{"type":"function","title":"Evision.Detail.BlocksCompensator.setNrGainsFilteringIterations/1","doc":"","ref":"Evision.Detail.BlocksCompensator.html#setNrGainsFilteringIterations/1"},{"type":"function","title":"Evision.Detail.BlocksCompensator.setNrGainsFilteringIterations/2","doc":"setNrGainsFilteringIterations\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BlocksCompensator.t()`\n- **nr_iterations**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNrGainsFilteringIterations(nr_iterations) -> None\n```","ref":"Evision.Detail.BlocksCompensator.html#setNrGainsFilteringIterations/2"},{"type":"function","title":"Evision.Detail.BlocksCompensator.setSimilarityThreshold/1","doc":"","ref":"Evision.Detail.BlocksCompensator.html#setSimilarityThreshold/1"},{"type":"function","title":"Evision.Detail.BlocksCompensator.setSimilarityThreshold/2","doc":"setSimilarityThreshold\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BlocksCompensator.t()`\n- **similarity_threshold**: `double`\n\nPython prototype (for reference only):\n```python3\nsetSimilarityThreshold(similarity_threshold) -> None\n```","ref":"Evision.Detail.BlocksCompensator.html#setSimilarityThreshold/2"},{"type":"type","title":"Evision.Detail.BlocksCompensator.t/0","doc":"Type that represents an `Detail.BlocksCompensator` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.BlocksCompensator.html#t:t/0"},{"type":"module","title":"Evision.Detail.BlocksGainCompensator","doc":"","ref":"Evision.Detail.BlocksGainCompensator.html"},{"type":"function","title":"Evision.Detail.BlocksGainCompensator.apply/1","doc":"","ref":"Evision.Detail.BlocksGainCompensator.html#apply/1"},{"type":"function","title":"Evision.Detail.BlocksGainCompensator.apply/5","doc":"apply\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BlocksGainCompensator.t()`\n- **index**: `integer()`\n- **corner**: `Point`\n- **mask**: `Evision.Mat`\n\n##### Return\n- **image**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\napply(index, corner, image, mask) -> image\n```","ref":"Evision.Detail.BlocksGainCompensator.html#apply/5"},{"type":"function","title":"Evision.Detail.BlocksGainCompensator.blocksGainCompensator/0","doc":"BlocksGainCompensator\n##### Keyword Arguments\n- **bl_width**: `integer()`.\n- **bl_height**: `integer()`.\n\n##### Return\n- **self**: `Evision.Detail.BlocksGainCompensator.t()`\n\nPython prototype (for reference only):\n```python3\nBlocksGainCompensator([, bl_width[, bl_height]]) ->  \n```","ref":"Evision.Detail.BlocksGainCompensator.html#blocksGainCompensator/0"},{"type":"function","title":"Evision.Detail.BlocksGainCompensator.blocksGainCompensator/1","doc":"BlocksGainCompensator\n##### Keyword Arguments\n- **bl_width**: `integer()`.\n- **bl_height**: `integer()`.\n\n##### Return\n- **self**: `Evision.Detail.BlocksGainCompensator.t()`\n\nPython prototype (for reference only):\n```python3\nBlocksGainCompensator([, bl_width[, bl_height]]) ->  \n```","ref":"Evision.Detail.BlocksGainCompensator.html#blocksGainCompensator/1"},{"type":"function","title":"Evision.Detail.BlocksGainCompensator.blocksGainCompensator/3","doc":"BlocksGainCompensator\n\n##### Positional Arguments\n- **bl_width**: `integer()`\n- **bl_height**: `integer()`\n- **nr_feeds**: `integer()`\n\n##### Return\n- **self**: `Evision.Detail.BlocksGainCompensator.t()`\n\nPython prototype (for reference only):\n```python3\nBlocksGainCompensator(bl_width, bl_height, nr_feeds) ->  \n```","ref":"Evision.Detail.BlocksGainCompensator.html#blocksGainCompensator/3"},{"type":"function","title":"Evision.Detail.BlocksGainCompensator.getMatGains/1","doc":"getMatGains\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BlocksGainCompensator.t()`\n\n##### Return\n- **umv**: `[Evision.Mat]`.\n\nPython prototype (for reference only):\n```python3\ngetMatGains([, umv]) -> umv\n```","ref":"Evision.Detail.BlocksGainCompensator.html#getMatGains/1"},{"type":"function","title":"Evision.Detail.BlocksGainCompensator.getMatGains/2","doc":"getMatGains\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BlocksGainCompensator.t()`\n\n##### Return\n- **umv**: `[Evision.Mat]`.\n\nPython prototype (for reference only):\n```python3\ngetMatGains([, umv]) -> umv\n```","ref":"Evision.Detail.BlocksGainCompensator.html#getMatGains/2"},{"type":"function","title":"Evision.Detail.BlocksGainCompensator.setMatGains/1","doc":"","ref":"Evision.Detail.BlocksGainCompensator.html#setMatGains/1"},{"type":"function","title":"Evision.Detail.BlocksGainCompensator.setMatGains/2","doc":"setMatGains\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BlocksGainCompensator.t()`\n- **umv**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\nsetMatGains(umv) -> None\n```","ref":"Evision.Detail.BlocksGainCompensator.html#setMatGains/2"},{"type":"type","title":"Evision.Detail.BlocksGainCompensator.t/0","doc":"Type that represents an `Detail.BlocksGainCompensator` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.BlocksGainCompensator.html#t:t/0"},{"type":"module","title":"Evision.Detail.BundleAdjusterAffine","doc":"","ref":"Evision.Detail.BundleAdjusterAffine.html"},{"type":"function","title":"Evision.Detail.BundleAdjusterAffine.bundleAdjusterAffine/0","doc":"BundleAdjusterAffine\n##### Return\n- **self**: `Evision.Detail.BundleAdjusterAffine.t()`\n\nPython prototype (for reference only):\n```python3\nBundleAdjusterAffine() ->  \n```","ref":"Evision.Detail.BundleAdjusterAffine.html#bundleAdjusterAffine/0"},{"type":"function","title":"Evision.Detail.BundleAdjusterAffine.bundleAdjusterAffine/1","doc":"","ref":"Evision.Detail.BundleAdjusterAffine.html#bundleAdjusterAffine/1"},{"type":"type","title":"Evision.Detail.BundleAdjusterAffine.t/0","doc":"Type that represents an `Detail.BundleAdjusterAffine` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.BundleAdjusterAffine.html#t:t/0"},{"type":"module","title":"Evision.Detail.BundleAdjusterAffinePartial","doc":"","ref":"Evision.Detail.BundleAdjusterAffinePartial.html"},{"type":"function","title":"Evision.Detail.BundleAdjusterAffinePartial.bundleAdjusterAffinePartial/0","doc":"BundleAdjusterAffinePartial\n##### Return\n- **self**: `Evision.Detail.BundleAdjusterAffinePartial.t()`\n\nPython prototype (for reference only):\n```python3\nBundleAdjusterAffinePartial() ->  \n```","ref":"Evision.Detail.BundleAdjusterAffinePartial.html#bundleAdjusterAffinePartial/0"},{"type":"function","title":"Evision.Detail.BundleAdjusterAffinePartial.bundleAdjusterAffinePartial/1","doc":"","ref":"Evision.Detail.BundleAdjusterAffinePartial.html#bundleAdjusterAffinePartial/1"},{"type":"type","title":"Evision.Detail.BundleAdjusterAffinePartial.t/0","doc":"Type that represents an `Detail.BundleAdjusterAffinePartial` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.BundleAdjusterAffinePartial.html#t:t/0"},{"type":"module","title":"Evision.Detail.BundleAdjusterBase","doc":"","ref":"Evision.Detail.BundleAdjusterBase.html"},{"type":"function","title":"Evision.Detail.BundleAdjusterBase.confThresh/1","doc":"confThresh\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BundleAdjusterBase.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\nconfThresh() -> retval\n```","ref":"Evision.Detail.BundleAdjusterBase.html#confThresh/1"},{"type":"function","title":"Evision.Detail.BundleAdjusterBase.refinementMask/1","doc":"refinementMask\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BundleAdjusterBase.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nrefinementMask() -> retval\n```","ref":"Evision.Detail.BundleAdjusterBase.html#refinementMask/1"},{"type":"function","title":"Evision.Detail.BundleAdjusterBase.setConfThresh/1","doc":"","ref":"Evision.Detail.BundleAdjusterBase.html#setConfThresh/1"},{"type":"function","title":"Evision.Detail.BundleAdjusterBase.setConfThresh/2","doc":"setConfThresh\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BundleAdjusterBase.t()`\n- **conf_thresh**: `double`\n\nPython prototype (for reference only):\n```python3\nsetConfThresh(conf_thresh) -> None\n```","ref":"Evision.Detail.BundleAdjusterBase.html#setConfThresh/2"},{"type":"function","title":"Evision.Detail.BundleAdjusterBase.setRefinementMask/1","doc":"","ref":"Evision.Detail.BundleAdjusterBase.html#setRefinementMask/1"},{"type":"function","title":"Evision.Detail.BundleAdjusterBase.setRefinementMask/2","doc":"setRefinementMask\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BundleAdjusterBase.t()`\n- **mask**: `Evision.Mat`\n\nPython prototype (for reference only):\n```python3\nsetRefinementMask(mask) -> None\n```","ref":"Evision.Detail.BundleAdjusterBase.html#setRefinementMask/2"},{"type":"function","title":"Evision.Detail.BundleAdjusterBase.setTermCriteria/1","doc":"","ref":"Evision.Detail.BundleAdjusterBase.html#setTermCriteria/1"},{"type":"function","title":"Evision.Detail.BundleAdjusterBase.setTermCriteria/2","doc":"setTermCriteria\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BundleAdjusterBase.t()`\n- **term_criteria**: `TermCriteria`\n\nPython prototype (for reference only):\n```python3\nsetTermCriteria(term_criteria) -> None\n```","ref":"Evision.Detail.BundleAdjusterBase.html#setTermCriteria/2"},{"type":"function","title":"Evision.Detail.BundleAdjusterBase.termCriteria/1","doc":"termCriteria\n\n##### Positional Arguments\n- **self**: `Evision.Detail.BundleAdjusterBase.t()`\n\n##### Return\n- **retval**: `TermCriteria`\n\nPython prototype (for reference only):\n```python3\ntermCriteria() -> retval\n```","ref":"Evision.Detail.BundleAdjusterBase.html#termCriteria/1"},{"type":"type","title":"Evision.Detail.BundleAdjusterBase.t/0","doc":"Type that represents an `Detail.BundleAdjusterBase` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.BundleAdjusterBase.html#t:t/0"},{"type":"module","title":"Evision.Detail.BundleAdjusterRay","doc":"","ref":"Evision.Detail.BundleAdjusterRay.html"},{"type":"function","title":"Evision.Detail.BundleAdjusterRay.bundleAdjusterRay/0","doc":"BundleAdjusterRay\n##### Return\n- **self**: `Evision.Detail.BundleAdjusterRay.t()`\n\nPython prototype (for reference only):\n```python3\nBundleAdjusterRay() ->  \n```","ref":"Evision.Detail.BundleAdjusterRay.html#bundleAdjusterRay/0"},{"type":"function","title":"Evision.Detail.BundleAdjusterRay.bundleAdjusterRay/1","doc":"","ref":"Evision.Detail.BundleAdjusterRay.html#bundleAdjusterRay/1"},{"type":"type","title":"Evision.Detail.BundleAdjusterRay.t/0","doc":"Type that represents an `Detail.BundleAdjusterRay` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.BundleAdjusterRay.html#t:t/0"},{"type":"module","title":"Evision.Detail.BundleAdjusterReproj","doc":"","ref":"Evision.Detail.BundleAdjusterReproj.html"},{"type":"function","title":"Evision.Detail.BundleAdjusterReproj.bundleAdjusterReproj/0","doc":"BundleAdjusterReproj\n##### Return\n- **self**: `Evision.Detail.BundleAdjusterReproj.t()`\n\nPython prototype (for reference only):\n```python3\nBundleAdjusterReproj() ->  \n```","ref":"Evision.Detail.BundleAdjusterReproj.html#bundleAdjusterReproj/0"},{"type":"function","title":"Evision.Detail.BundleAdjusterReproj.bundleAdjusterReproj/1","doc":"","ref":"Evision.Detail.BundleAdjusterReproj.html#bundleAdjusterReproj/1"},{"type":"type","title":"Evision.Detail.BundleAdjusterReproj.t/0","doc":"Type that represents an `Detail.BundleAdjusterReproj` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.BundleAdjusterReproj.html#t:t/0"},{"type":"module","title":"Evision.Detail.CameraParams","doc":"","ref":"Evision.Detail.CameraParams.html"},{"type":"function","title":"Evision.Detail.CameraParams.get_aspect/1","doc":"","ref":"Evision.Detail.CameraParams.html#get_aspect/1"},{"type":"function","title":"Evision.Detail.CameraParams.get_focal/1","doc":"","ref":"Evision.Detail.CameraParams.html#get_focal/1"},{"type":"function","title":"Evision.Detail.CameraParams.get_ppx/1","doc":"","ref":"Evision.Detail.CameraParams.html#get_ppx/1"},{"type":"function","title":"Evision.Detail.CameraParams.get_ppy/1","doc":"","ref":"Evision.Detail.CameraParams.html#get_ppy/1"},{"type":"function","title":"Evision.Detail.CameraParams.get_R/1","doc":"","ref":"Evision.Detail.CameraParams.html#get_R/1"},{"type":"function","title":"Evision.Detail.CameraParams.get_t/1","doc":"","ref":"Evision.Detail.CameraParams.html#get_t/1"},{"type":"function","title":"Evision.Detail.CameraParams.k/1","doc":"K\n\n##### Positional Arguments\n- **self**: `Evision.Detail.CameraParams.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nK() -> retval\n```","ref":"Evision.Detail.CameraParams.html#k/1"},{"type":"function","title":"Evision.Detail.CameraParams.set_aspect/2","doc":"","ref":"Evision.Detail.CameraParams.html#set_aspect/2"},{"type":"function","title":"Evision.Detail.CameraParams.set_focal/2","doc":"","ref":"Evision.Detail.CameraParams.html#set_focal/2"},{"type":"function","title":"Evision.Detail.CameraParams.set_ppx/2","doc":"","ref":"Evision.Detail.CameraParams.html#set_ppx/2"},{"type":"function","title":"Evision.Detail.CameraParams.set_ppy/2","doc":"","ref":"Evision.Detail.CameraParams.html#set_ppy/2"},{"type":"function","title":"Evision.Detail.CameraParams.set_R/2","doc":"","ref":"Evision.Detail.CameraParams.html#set_R/2"},{"type":"function","title":"Evision.Detail.CameraParams.set_t/2","doc":"","ref":"Evision.Detail.CameraParams.html#set_t/2"},{"type":"type","title":"Evision.Detail.CameraParams.t/0","doc":"Type that represents an `Detail.CameraParams` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.CameraParams.html#t:t/0"},{"type":"module","title":"Evision.Detail.ChannelsCompensator","doc":"","ref":"Evision.Detail.ChannelsCompensator.html"},{"type":"function","title":"Evision.Detail.ChannelsCompensator.apply/1","doc":"","ref":"Evision.Detail.ChannelsCompensator.html#apply/1"},{"type":"function","title":"Evision.Detail.ChannelsCompensator.apply/5","doc":"apply\n\n##### Positional Arguments\n- **self**: `Evision.Detail.ChannelsCompensator.t()`\n- **index**: `integer()`\n- **corner**: `Point`\n- **mask**: `Evision.Mat`\n\n##### Return\n- **image**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\napply(index, corner, image, mask) -> image\n```","ref":"Evision.Detail.ChannelsCompensator.html#apply/5"},{"type":"function","title":"Evision.Detail.ChannelsCompensator.channelsCompensator/0","doc":"ChannelsCompensator\n##### Keyword Arguments\n- **nr_feeds**: `integer()`.\n\n##### Return\n- **self**: `Evision.Detail.ChannelsCompensator.t()`\n\nPython prototype (for reference only):\n```python3\nChannelsCompensator([, nr_feeds]) ->  \n```","ref":"Evision.Detail.ChannelsCompensator.html#channelsCompensator/0"},{"type":"function","title":"Evision.Detail.ChannelsCompensator.channelsCompensator/1","doc":"ChannelsCompensator\n##### Keyword Arguments\n- **nr_feeds**: `integer()`.\n\n##### Return\n- **self**: `Evision.Detail.ChannelsCompensator.t()`\n\nPython prototype (for reference only):\n```python3\nChannelsCompensator([, nr_feeds]) ->  \n```","ref":"Evision.Detail.ChannelsCompensator.html#channelsCompensator/1"},{"type":"function","title":"Evision.Detail.ChannelsCompensator.getMatGains/1","doc":"getMatGains\n\n##### Positional Arguments\n- **self**: `Evision.Detail.ChannelsCompensator.t()`\n\n##### Return\n- **umv**: `[Evision.Mat]`.\n\nPython prototype (for reference only):\n```python3\ngetMatGains([, umv]) -> umv\n```","ref":"Evision.Detail.ChannelsCompensator.html#getMatGains/1"},{"type":"function","title":"Evision.Detail.ChannelsCompensator.getMatGains/2","doc":"getMatGains\n\n##### Positional Arguments\n- **self**: `Evision.Detail.ChannelsCompensator.t()`\n\n##### Return\n- **umv**: `[Evision.Mat]`.\n\nPython prototype (for reference only):\n```python3\ngetMatGains([, umv]) -> umv\n```","ref":"Evision.Detail.ChannelsCompensator.html#getMatGains/2"},{"type":"function","title":"Evision.Detail.ChannelsCompensator.getNrFeeds/1","doc":"getNrFeeds\n\n##### Positional Arguments\n- **self**: `Evision.Detail.ChannelsCompensator.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNrFeeds() -> retval\n```","ref":"Evision.Detail.ChannelsCompensator.html#getNrFeeds/1"},{"type":"function","title":"Evision.Detail.ChannelsCompensator.getSimilarityThreshold/1","doc":"getSimilarityThreshold\n\n##### Positional Arguments\n- **self**: `Evision.Detail.ChannelsCompensator.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetSimilarityThreshold() -> retval\n```","ref":"Evision.Detail.ChannelsCompensator.html#getSimilarityThreshold/1"},{"type":"function","title":"Evision.Detail.ChannelsCompensator.setMatGains/1","doc":"","ref":"Evision.Detail.ChannelsCompensator.html#setMatGains/1"},{"type":"function","title":"Evision.Detail.ChannelsCompensator.setMatGains/2","doc":"setMatGains\n\n##### Positional Arguments\n- **self**: `Evision.Detail.ChannelsCompensator.t()`\n- **umv**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\nsetMatGains(umv) -> None\n```","ref":"Evision.Detail.ChannelsCompensator.html#setMatGains/2"},{"type":"function","title":"Evision.Detail.ChannelsCompensator.setNrFeeds/1","doc":"","ref":"Evision.Detail.ChannelsCompensator.html#setNrFeeds/1"},{"type":"function","title":"Evision.Detail.ChannelsCompensator.setNrFeeds/2","doc":"setNrFeeds\n\n##### Positional Arguments\n- **self**: `Evision.Detail.ChannelsCompensator.t()`\n- **nr_feeds**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNrFeeds(nr_feeds) -> None\n```","ref":"Evision.Detail.ChannelsCompensator.html#setNrFeeds/2"},{"type":"function","title":"Evision.Detail.ChannelsCompensator.setSimilarityThreshold/1","doc":"","ref":"Evision.Detail.ChannelsCompensator.html#setSimilarityThreshold/1"},{"type":"function","title":"Evision.Detail.ChannelsCompensator.setSimilarityThreshold/2","doc":"setSimilarityThreshold\n\n##### Positional Arguments\n- **self**: `Evision.Detail.ChannelsCompensator.t()`\n- **similarity_threshold**: `double`\n\nPython prototype (for reference only):\n```python3\nsetSimilarityThreshold(similarity_threshold) -> None\n```","ref":"Evision.Detail.ChannelsCompensator.html#setSimilarityThreshold/2"},{"type":"type","title":"Evision.Detail.ChannelsCompensator.t/0","doc":"Type that represents an `Detail.ChannelsCompensator` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.ChannelsCompensator.html#t:t/0"},{"type":"module","title":"Evision.Detail.CvFeatureParams.FeatureType","doc":"","ref":"Evision.Detail.CvFeatureParams.FeatureType.html"},{"type":"function","title":"Evision.Detail.CvFeatureParams.FeatureType.cv_HAAR/0","doc":"","ref":"Evision.Detail.CvFeatureParams.FeatureType.html#cv_HAAR/0"},{"type":"function","title":"Evision.Detail.CvFeatureParams.FeatureType.cv_HOG/0","doc":"","ref":"Evision.Detail.CvFeatureParams.FeatureType.html#cv_HOG/0"},{"type":"function","title":"Evision.Detail.CvFeatureParams.FeatureType.cv_LBP/0","doc":"","ref":"Evision.Detail.CvFeatureParams.FeatureType.html#cv_LBP/0"},{"type":"type","title":"Evision.Detail.CvFeatureParams.FeatureType.enum/0","doc":"","ref":"Evision.Detail.CvFeatureParams.FeatureType.html#t:enum/0"},{"type":"module","title":"Evision.Detail.DpSeamFinder","doc":"","ref":"Evision.Detail.DpSeamFinder.html"},{"type":"function","title":"Evision.Detail.DpSeamFinder.dpSeamFinder/1","doc":"DpSeamFinder\n\n##### Positional Arguments\n- **costFunc**: `String`\n\n##### Return\n- **self**: `Evision.Detail.DpSeamFinder.t()`\n\nPython prototype (for reference only):\n```python3\nDpSeamFinder(costFunc) ->  \n```","ref":"Evision.Detail.DpSeamFinder.html#dpSeamFinder/1"},{"type":"function","title":"Evision.Detail.DpSeamFinder.setCostFunction/1","doc":"","ref":"Evision.Detail.DpSeamFinder.html#setCostFunction/1"},{"type":"function","title":"Evision.Detail.DpSeamFinder.setCostFunction/2","doc":"setCostFunction\n\n##### Positional Arguments\n- **self**: `Evision.Detail.DpSeamFinder.t()`\n- **val**: `String`\n\nPython prototype (for reference only):\n```python3\nsetCostFunction(val) -> None\n```","ref":"Evision.Detail.DpSeamFinder.html#setCostFunction/2"},{"type":"type","title":"Evision.Detail.DpSeamFinder.t/0","doc":"Type that represents an `Detail.DpSeamFinder` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.DpSeamFinder.html#t:t/0"},{"type":"module","title":"Evision.Detail.DpSeamFinder.CostFunction","doc":"","ref":"Evision.Detail.DpSeamFinder.CostFunction.html"},{"type":"function","title":"Evision.Detail.DpSeamFinder.CostFunction.cv_COLOR/0","doc":"","ref":"Evision.Detail.DpSeamFinder.CostFunction.html#cv_COLOR/0"},{"type":"function","title":"Evision.Detail.DpSeamFinder.CostFunction.cv_COLOR_GRAD/0","doc":"","ref":"Evision.Detail.DpSeamFinder.CostFunction.html#cv_COLOR_GRAD/0"},{"type":"type","title":"Evision.Detail.DpSeamFinder.CostFunction.enum/0","doc":"","ref":"Evision.Detail.DpSeamFinder.CostFunction.html#t:enum/0"},{"type":"module","title":"Evision.Detail.Estimator","doc":"","ref":"Evision.Detail.Estimator.html"},{"type":"function","title":"Evision.Detail.Estimator.apply/1","doc":"","ref":"Evision.Detail.Estimator.html#apply/1"},{"type":"function","title":"Evision.Detail.Estimator.apply/4","doc":"Estimates camera parameters.\n\n##### Positional Arguments\n- **self**: `Evision.Detail.Estimator.t()`\n- **features**: `[Evision.Detail.ImageFeatures]`.\n\n  Features of images\n\n- **pairwise_matches**: `[Evision.Detail.MatchesInfo]`.\n\n  Pairwise matches of images\n\n##### Return\n- **retval**: `bool`\n- **cameras**: `[Evision.Detail.CameraParams]`.\n\n  Estimated camera parameters\n\n@return True in case of success, false otherwise\n\nPython prototype (for reference only):\n```python3\napply(features, pairwise_matches, cameras) -> retval, cameras\n```","ref":"Evision.Detail.Estimator.html#apply/4"},{"type":"type","title":"Evision.Detail.Estimator.t/0","doc":"Type that represents an `Detail.Estimator` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.Estimator.html#t:t/0"},{"type":"module","title":"Evision.Detail.ExposureCompensator","doc":"","ref":"Evision.Detail.ExposureCompensator.html"},{"type":"function","title":"Evision.Detail.ExposureCompensator.apply/1","doc":"","ref":"Evision.Detail.ExposureCompensator.html#apply/1"},{"type":"function","title":"Evision.Detail.ExposureCompensator.apply/5","doc":"Compensate exposure in the specified image.\n\n##### Positional Arguments\n- **self**: `Evision.Detail.ExposureCompensator.t()`\n- **index**: `integer()`.\n\n  Image index\n\n- **corner**: `Point`.\n\n  Image top-left corner\n\n- **mask**: `Evision.Mat`.\n\n  Image mask\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  Image to process\n\nPython prototype (for reference only):\n```python3\napply(index, corner, image, mask) -> image\n```","ref":"Evision.Detail.ExposureCompensator.html#apply/5"},{"type":"function","title":"Evision.Detail.ExposureCompensator.createDefault/1","doc":"createDefault\n\n##### Positional Arguments\n- **type**: `integer()`\n\n##### Return\n- **retval**: `Evision.Detail.ExposureCompensator.t()`\n\nPython prototype (for reference only):\n```python3\ncreateDefault(type) -> retval\n```","ref":"Evision.Detail.ExposureCompensator.html#createDefault/1"},{"type":"function","title":"Evision.Detail.ExposureCompensator.cv_CHANNELS/0","doc":"","ref":"Evision.Detail.ExposureCompensator.html#cv_CHANNELS/0"},{"type":"function","title":"Evision.Detail.ExposureCompensator.cv_CHANNELS_BLOCKS/0","doc":"","ref":"Evision.Detail.ExposureCompensator.html#cv_CHANNELS_BLOCKS/0"},{"type":"function","title":"Evision.Detail.ExposureCompensator.cv_GAIN/0","doc":"","ref":"Evision.Detail.ExposureCompensator.html#cv_GAIN/0"},{"type":"function","title":"Evision.Detail.ExposureCompensator.cv_GAIN_BLOCKS/0","doc":"","ref":"Evision.Detail.ExposureCompensator.html#cv_GAIN_BLOCKS/0"},{"type":"function","title":"Evision.Detail.ExposureCompensator.cv_NO/0","doc":"","ref":"Evision.Detail.ExposureCompensator.html#cv_NO/0"},{"type":"function","title":"Evision.Detail.ExposureCompensator.feed/1","doc":"","ref":"Evision.Detail.ExposureCompensator.html#feed/1"},{"type":"function","title":"Evision.Detail.ExposureCompensator.feed/4","doc":"feed\n\n##### Positional Arguments\n- **self**: `Evision.Detail.ExposureCompensator.t()`\n- **corners**: `[Point]`.\n\n  Source image top-left corners\n\n- **images**: `[Evision.Mat]`.\n\n  Source images\n\n- **masks**: `[Evision.Mat]`.\n\n  Image masks to update (second value in pair specifies the value which should be used\n  to detect where image is)\n\nPython prototype (for reference only):\n```python3\nfeed(corners, images, masks) -> None\n```","ref":"Evision.Detail.ExposureCompensator.html#feed/4"},{"type":"function","title":"Evision.Detail.ExposureCompensator.getMatGains/1","doc":"getMatGains\n\n##### Positional Arguments\n- **self**: `Evision.Detail.ExposureCompensator.t()`\n\n##### Return\n- **arg1**: `[Evision.Mat]`.\n\nPython prototype (for reference only):\n```python3\ngetMatGains([, arg1]) -> arg1\n```","ref":"Evision.Detail.ExposureCompensator.html#getMatGains/1"},{"type":"function","title":"Evision.Detail.ExposureCompensator.getMatGains/2","doc":"getMatGains\n\n##### Positional Arguments\n- **self**: `Evision.Detail.ExposureCompensator.t()`\n\n##### Return\n- **arg1**: `[Evision.Mat]`.\n\nPython prototype (for reference only):\n```python3\ngetMatGains([, arg1]) -> arg1\n```","ref":"Evision.Detail.ExposureCompensator.html#getMatGains/2"},{"type":"function","title":"Evision.Detail.ExposureCompensator.getUpdateGain/1","doc":"getUpdateGain\n\n##### Positional Arguments\n- **self**: `Evision.Detail.ExposureCompensator.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetUpdateGain() -> retval\n```","ref":"Evision.Detail.ExposureCompensator.html#getUpdateGain/1"},{"type":"function","title":"Evision.Detail.ExposureCompensator.setMatGains/1","doc":"","ref":"Evision.Detail.ExposureCompensator.html#setMatGains/1"},{"type":"function","title":"Evision.Detail.ExposureCompensator.setMatGains/2","doc":"setMatGains\n\n##### Positional Arguments\n- **self**: `Evision.Detail.ExposureCompensator.t()`\n- **arg1**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\nsetMatGains(arg1) -> None\n```","ref":"Evision.Detail.ExposureCompensator.html#setMatGains/2"},{"type":"function","title":"Evision.Detail.ExposureCompensator.setUpdateGain/1","doc":"","ref":"Evision.Detail.ExposureCompensator.html#setUpdateGain/1"},{"type":"function","title":"Evision.Detail.ExposureCompensator.setUpdateGain/2","doc":"setUpdateGain\n\n##### Positional Arguments\n- **self**: `Evision.Detail.ExposureCompensator.t()`\n- **b**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetUpdateGain(b) -> None\n```","ref":"Evision.Detail.ExposureCompensator.html#setUpdateGain/2"},{"type":"type","title":"Evision.Detail.ExposureCompensator.enum/0","doc":"","ref":"Evision.Detail.ExposureCompensator.html#t:enum/0"},{"type":"type","title":"Evision.Detail.ExposureCompensator.t/0","doc":"Type that represents an `Detail.ExposureCompensator` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.ExposureCompensator.html#t:t/0"},{"type":"module","title":"Evision.Detail.FeatherBlender","doc":"","ref":"Evision.Detail.FeatherBlender.html"},{"type":"function","title":"Evision.Detail.FeatherBlender.blend/1","doc":"","ref":"Evision.Detail.FeatherBlender.html#blend/1"},{"type":"function","title":"Evision.Detail.FeatherBlender.blend/3","doc":"blend\n\n##### Positional Arguments\n- **self**: `Evision.Detail.FeatherBlender.t()`\n\n##### Return\n- **dst**: `Evision.Mat.t()`\n- **dst_mask**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nblend(dst, dst_mask) -> dst, dst_mask\n```","ref":"Evision.Detail.FeatherBlender.html#blend/3"},{"type":"function","title":"Evision.Detail.FeatherBlender.createWeightMaps/1","doc":"","ref":"Evision.Detail.FeatherBlender.html#createWeightMaps/1"},{"type":"function","title":"Evision.Detail.FeatherBlender.createWeightMaps/4","doc":"createWeightMaps\n\n##### Positional Arguments\n- **self**: `Evision.Detail.FeatherBlender.t()`\n- **masks**: `[Evision.Mat]`\n- **corners**: `[Point]`\n\n##### Return\n- **retval**: `Rect`\n- **weight_maps**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\ncreateWeightMaps(masks, corners, weight_maps) -> retval, weight_maps\n```","ref":"Evision.Detail.FeatherBlender.html#createWeightMaps/4"},{"type":"function","title":"Evision.Detail.FeatherBlender.featherBlender/0","doc":"FeatherBlender\n##### Keyword Arguments\n- **sharpness**: `float`.\n\n##### Return\n- **self**: `Evision.Detail.FeatherBlender.t()`\n\nPython prototype (for reference only):\n```python3\nFeatherBlender([, sharpness]) ->  \n```","ref":"Evision.Detail.FeatherBlender.html#featherBlender/0"},{"type":"function","title":"Evision.Detail.FeatherBlender.featherBlender/1","doc":"FeatherBlender\n##### Keyword Arguments\n- **sharpness**: `float`.\n\n##### Return\n- **self**: `Evision.Detail.FeatherBlender.t()`\n\nPython prototype (for reference only):\n```python3\nFeatherBlender([, sharpness]) ->  \n```","ref":"Evision.Detail.FeatherBlender.html#featherBlender/1"},{"type":"function","title":"Evision.Detail.FeatherBlender.feed/1","doc":"","ref":"Evision.Detail.FeatherBlender.html#feed/1"},{"type":"function","title":"Evision.Detail.FeatherBlender.feed/4","doc":"feed\n\n##### Positional Arguments\n- **self**: `Evision.Detail.FeatherBlender.t()`\n- **img**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n- **tl**: `Point`\n\nPython prototype (for reference only):\n```python3\nfeed(img, mask, tl) -> None\n```","ref":"Evision.Detail.FeatherBlender.html#feed/4"},{"type":"function","title":"Evision.Detail.FeatherBlender.prepare/1","doc":"","ref":"Evision.Detail.FeatherBlender.html#prepare/1"},{"type":"function","title":"Evision.Detail.FeatherBlender.prepare/2","doc":"prepare\n\n##### Positional Arguments\n- **self**: `Evision.Detail.FeatherBlender.t()`\n- **dst_roi**: `Rect`\n\nPython prototype (for reference only):\n```python3\nprepare(dst_roi) -> None\n```","ref":"Evision.Detail.FeatherBlender.html#prepare/2"},{"type":"function","title":"Evision.Detail.FeatherBlender.setSharpness/1","doc":"","ref":"Evision.Detail.FeatherBlender.html#setSharpness/1"},{"type":"function","title":"Evision.Detail.FeatherBlender.setSharpness/2","doc":"setSharpness\n\n##### Positional Arguments\n- **self**: `Evision.Detail.FeatherBlender.t()`\n- **val**: `float`\n\nPython prototype (for reference only):\n```python3\nsetSharpness(val) -> None\n```","ref":"Evision.Detail.FeatherBlender.html#setSharpness/2"},{"type":"function","title":"Evision.Detail.FeatherBlender.sharpness/1","doc":"sharpness\n\n##### Positional Arguments\n- **self**: `Evision.Detail.FeatherBlender.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\nsharpness() -> retval\n```","ref":"Evision.Detail.FeatherBlender.html#sharpness/1"},{"type":"type","title":"Evision.Detail.FeatherBlender.t/0","doc":"Type that represents an `Detail.FeatherBlender` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.FeatherBlender.html#t:t/0"},{"type":"module","title":"Evision.Detail.FeaturesMatcher","doc":"","ref":"Evision.Detail.FeaturesMatcher.html"},{"type":"function","title":"Evision.Detail.FeaturesMatcher.apply2/1","doc":"","ref":"Evision.Detail.FeaturesMatcher.html#apply2/1"},{"type":"function","title":"Evision.Detail.FeaturesMatcher.apply2/2","doc":"Performs images matching.\n\n##### Positional Arguments\n- **self**: `Evision.Detail.FeaturesMatcher.t()`\n- **features**: `[Evision.Detail.ImageFeatures]`.\n\n  Features of the source images\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask indicating which image pairs must be matched\n\n##### Return\n- **pairwise_matches**: `[Evision.Detail.MatchesInfo]`.\n\n  Found pairwise matches\n\nThe function is parallelized with the TBB library.\n@sa detail::MatchesInfo\n\nPython prototype (for reference only):\n```python3\napply2(features[, mask]) -> pairwise_matches\n```","ref":"Evision.Detail.FeaturesMatcher.html#apply2/2"},{"type":"function","title":"Evision.Detail.FeaturesMatcher.apply2/3","doc":"Performs images matching.\n\n##### Positional Arguments\n- **self**: `Evision.Detail.FeaturesMatcher.t()`\n- **features**: `[Evision.Detail.ImageFeatures]`.\n\n  Features of the source images\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask indicating which image pairs must be matched\n\n##### Return\n- **pairwise_matches**: `[Evision.Detail.MatchesInfo]`.\n\n  Found pairwise matches\n\nThe function is parallelized with the TBB library.\n@sa detail::MatchesInfo\n\nPython prototype (for reference only):\n```python3\napply2(features[, mask]) -> pairwise_matches\n```","ref":"Evision.Detail.FeaturesMatcher.html#apply2/3"},{"type":"function","title":"Evision.Detail.FeaturesMatcher.apply/1","doc":"","ref":"Evision.Detail.FeaturesMatcher.html#apply/1"},{"type":"function","title":"Evision.Detail.FeaturesMatcher.apply/3","doc":"apply\n\n##### Positional Arguments\n- **self**: `Evision.Detail.FeaturesMatcher.t()`\n- **features1**: `Evision.Detail.ImageFeatures`.\n\n  First image features\n\n- **features2**: `Evision.Detail.ImageFeatures`.\n\n  Second image features\n\n##### Return\n- **matches_info**: `Evision.Detail.MatchesInfo.t()`.\n\n  Found matches\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\napply(features1, features2) -> matches_info\n```","ref":"Evision.Detail.FeaturesMatcher.html#apply/3"},{"type":"function","title":"Evision.Detail.FeaturesMatcher.collectGarbage/1","doc":"Frees unused memory allocated before if there is any.\n\n##### Positional Arguments\n- **self**: `Evision.Detail.FeaturesMatcher.t()`\n\nPython prototype (for reference only):\n```python3\ncollectGarbage() -> None\n```","ref":"Evision.Detail.FeaturesMatcher.html#collectGarbage/1"},{"type":"function","title":"Evision.Detail.FeaturesMatcher.isThreadSafe/1","doc":"isThreadSafe\n\n##### Positional Arguments\n- **self**: `Evision.Detail.FeaturesMatcher.t()`\n\n##### Return\n- **retval**: `bool`\n\n@return True, if it's possible to use the same matcher instance in parallel, false otherwise\n\nPython prototype (for reference only):\n```python3\nisThreadSafe() -> retval\n```","ref":"Evision.Detail.FeaturesMatcher.html#isThreadSafe/1"},{"type":"type","title":"Evision.Detail.FeaturesMatcher.t/0","doc":"Type that represents an `Detail.FeaturesMatcher` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.FeaturesMatcher.html#t:t/0"},{"type":"module","title":"Evision.Detail.GainCompensator","doc":"","ref":"Evision.Detail.GainCompensator.html"},{"type":"function","title":"Evision.Detail.GainCompensator.apply/1","doc":"","ref":"Evision.Detail.GainCompensator.html#apply/1"},{"type":"function","title":"Evision.Detail.GainCompensator.apply/5","doc":"apply\n\n##### Positional Arguments\n- **self**: `Evision.Detail.GainCompensator.t()`\n- **index**: `integer()`\n- **corner**: `Point`\n- **mask**: `Evision.Mat`\n\n##### Return\n- **image**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\napply(index, corner, image, mask) -> image\n```","ref":"Evision.Detail.GainCompensator.html#apply/5"},{"type":"function","title":"Evision.Detail.GainCompensator.gainCompensator/0","doc":"GainCompensator\n##### Return\n- **self**: `Evision.Detail.GainCompensator.t()`\n\nPython prototype (for reference only):\n```python3\nGainCompensator() ->  \n```","ref":"Evision.Detail.GainCompensator.html#gainCompensator/0"},{"type":"function","title":"Evision.Detail.GainCompensator.gainCompensator/1","doc":"GainCompensator\n\n##### Positional Arguments\n- **nr_feeds**: `integer()`\n\n##### Return\n- **self**: `Evision.Detail.GainCompensator.t()`\n\nPython prototype (for reference only):\n```python3\nGainCompensator(nr_feeds) ->  \n```","ref":"Evision.Detail.GainCompensator.html#gainCompensator/1"},{"type":"function","title":"Evision.Detail.GainCompensator.getMatGains/1","doc":"getMatGains\n\n##### Positional Arguments\n- **self**: `Evision.Detail.GainCompensator.t()`\n\n##### Return\n- **umv**: `[Evision.Mat]`.\n\nPython prototype (for reference only):\n```python3\ngetMatGains([, umv]) -> umv\n```","ref":"Evision.Detail.GainCompensator.html#getMatGains/1"},{"type":"function","title":"Evision.Detail.GainCompensator.getMatGains/2","doc":"getMatGains\n\n##### Positional Arguments\n- **self**: `Evision.Detail.GainCompensator.t()`\n\n##### Return\n- **umv**: `[Evision.Mat]`.\n\nPython prototype (for reference only):\n```python3\ngetMatGains([, umv]) -> umv\n```","ref":"Evision.Detail.GainCompensator.html#getMatGains/2"},{"type":"function","title":"Evision.Detail.GainCompensator.getNrFeeds/1","doc":"getNrFeeds\n\n##### Positional Arguments\n- **self**: `Evision.Detail.GainCompensator.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNrFeeds() -> retval\n```","ref":"Evision.Detail.GainCompensator.html#getNrFeeds/1"},{"type":"function","title":"Evision.Detail.GainCompensator.getSimilarityThreshold/1","doc":"getSimilarityThreshold\n\n##### Positional Arguments\n- **self**: `Evision.Detail.GainCompensator.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetSimilarityThreshold() -> retval\n```","ref":"Evision.Detail.GainCompensator.html#getSimilarityThreshold/1"},{"type":"function","title":"Evision.Detail.GainCompensator.setMatGains/1","doc":"","ref":"Evision.Detail.GainCompensator.html#setMatGains/1"},{"type":"function","title":"Evision.Detail.GainCompensator.setMatGains/2","doc":"setMatGains\n\n##### Positional Arguments\n- **self**: `Evision.Detail.GainCompensator.t()`\n- **umv**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\nsetMatGains(umv) -> None\n```","ref":"Evision.Detail.GainCompensator.html#setMatGains/2"},{"type":"function","title":"Evision.Detail.GainCompensator.setNrFeeds/1","doc":"","ref":"Evision.Detail.GainCompensator.html#setNrFeeds/1"},{"type":"function","title":"Evision.Detail.GainCompensator.setNrFeeds/2","doc":"setNrFeeds\n\n##### Positional Arguments\n- **self**: `Evision.Detail.GainCompensator.t()`\n- **nr_feeds**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNrFeeds(nr_feeds) -> None\n```","ref":"Evision.Detail.GainCompensator.html#setNrFeeds/2"},{"type":"function","title":"Evision.Detail.GainCompensator.setSimilarityThreshold/1","doc":"","ref":"Evision.Detail.GainCompensator.html#setSimilarityThreshold/1"},{"type":"function","title":"Evision.Detail.GainCompensator.setSimilarityThreshold/2","doc":"setSimilarityThreshold\n\n##### Positional Arguments\n- **self**: `Evision.Detail.GainCompensator.t()`\n- **similarity_threshold**: `double`\n\nPython prototype (for reference only):\n```python3\nsetSimilarityThreshold(similarity_threshold) -> None\n```","ref":"Evision.Detail.GainCompensator.html#setSimilarityThreshold/2"},{"type":"type","title":"Evision.Detail.GainCompensator.t/0","doc":"Type that represents an `Detail.GainCompensator` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.GainCompensator.html#t:t/0"},{"type":"module","title":"Evision.Detail.GraphCutSeamFinder","doc":"","ref":"Evision.Detail.GraphCutSeamFinder.html"},{"type":"function","title":"Evision.Detail.GraphCutSeamFinder.find/1","doc":"","ref":"Evision.Detail.GraphCutSeamFinder.html#find/1"},{"type":"function","title":"Evision.Detail.GraphCutSeamFinder.find/4","doc":"find\n\n##### Positional Arguments\n- **self**: `Evision.Detail.GraphCutSeamFinder.t()`\n- **src**: `[Evision.Mat]`\n- **corners**: `[Point]`\n\n##### Return\n- **masks**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\nfind(src, corners, masks) -> masks\n```","ref":"Evision.Detail.GraphCutSeamFinder.html#find/4"},{"type":"function","title":"Evision.Detail.GraphCutSeamFinder.graphCutSeamFinder/1","doc":"GraphCutSeamFinder\n\n##### Positional Arguments\n- **cost_type**: `String`\n\n##### Keyword Arguments\n- **terminal_cost**: `float`.\n- **bad_region_penalty**: `float`.\n\n##### Return\n- **self**: `Evision.Detail.GraphCutSeamFinder.t()`\n\nPython prototype (for reference only):\n```python3\nGraphCutSeamFinder(cost_type[, terminal_cost[, bad_region_penalty]]) ->  \n```","ref":"Evision.Detail.GraphCutSeamFinder.html#graphCutSeamFinder/1"},{"type":"function","title":"Evision.Detail.GraphCutSeamFinder.graphCutSeamFinder/2","doc":"GraphCutSeamFinder\n\n##### Positional Arguments\n- **cost_type**: `String`\n\n##### Keyword Arguments\n- **terminal_cost**: `float`.\n- **bad_region_penalty**: `float`.\n\n##### Return\n- **self**: `Evision.Detail.GraphCutSeamFinder.t()`\n\nPython prototype (for reference only):\n```python3\nGraphCutSeamFinder(cost_type[, terminal_cost[, bad_region_penalty]]) ->  \n```","ref":"Evision.Detail.GraphCutSeamFinder.html#graphCutSeamFinder/2"},{"type":"type","title":"Evision.Detail.GraphCutSeamFinder.t/0","doc":"Type that represents an `Detail.GraphCutSeamFinder` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.GraphCutSeamFinder.html#t:t/0"},{"type":"module","title":"Evision.Detail.GraphCutSeamFinderBase.CostType","doc":"","ref":"Evision.Detail.GraphCutSeamFinderBase.CostType.html"},{"type":"function","title":"Evision.Detail.GraphCutSeamFinderBase.CostType.cv_COST_COLOR/0","doc":"","ref":"Evision.Detail.GraphCutSeamFinderBase.CostType.html#cv_COST_COLOR/0"},{"type":"function","title":"Evision.Detail.GraphCutSeamFinderBase.CostType.cv_COST_COLOR_GRAD/0","doc":"","ref":"Evision.Detail.GraphCutSeamFinderBase.CostType.html#cv_COST_COLOR_GRAD/0"},{"type":"type","title":"Evision.Detail.GraphCutSeamFinderBase.CostType.enum/0","doc":"","ref":"Evision.Detail.GraphCutSeamFinderBase.CostType.html#t:enum/0"},{"type":"module","title":"Evision.Detail.HomographyBasedEstimator","doc":"","ref":"Evision.Detail.HomographyBasedEstimator.html"},{"type":"function","title":"Evision.Detail.HomographyBasedEstimator.homographyBasedEstimator/0","doc":"HomographyBasedEstimator\n##### Keyword Arguments\n- **is_focals_estimated**: `bool`.\n\n##### Return\n- **self**: `Evision.Detail.HomographyBasedEstimator.t()`\n\nPython prototype (for reference only):\n```python3\nHomographyBasedEstimator([, is_focals_estimated]) ->  \n```","ref":"Evision.Detail.HomographyBasedEstimator.html#homographyBasedEstimator/0"},{"type":"function","title":"Evision.Detail.HomographyBasedEstimator.homographyBasedEstimator/1","doc":"HomographyBasedEstimator\n##### Keyword Arguments\n- **is_focals_estimated**: `bool`.\n\n##### Return\n- **self**: `Evision.Detail.HomographyBasedEstimator.t()`\n\nPython prototype (for reference only):\n```python3\nHomographyBasedEstimator([, is_focals_estimated]) ->  \n```","ref":"Evision.Detail.HomographyBasedEstimator.html#homographyBasedEstimator/1"},{"type":"type","title":"Evision.Detail.HomographyBasedEstimator.t/0","doc":"Type that represents an `Detail.HomographyBasedEstimator` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.HomographyBasedEstimator.html#t:t/0"},{"type":"module","title":"Evision.Detail.ImageFeatures","doc":"","ref":"Evision.Detail.ImageFeatures.html"},{"type":"function","title":"Evision.Detail.ImageFeatures.get_descriptors/1","doc":"","ref":"Evision.Detail.ImageFeatures.html#get_descriptors/1"},{"type":"function","title":"Evision.Detail.ImageFeatures.get_img_idx/1","doc":"","ref":"Evision.Detail.ImageFeatures.html#get_img_idx/1"},{"type":"function","title":"Evision.Detail.ImageFeatures.get_img_size/1","doc":"","ref":"Evision.Detail.ImageFeatures.html#get_img_size/1"},{"type":"function","title":"Evision.Detail.ImageFeatures.get_keypoints/1","doc":"","ref":"Evision.Detail.ImageFeatures.html#get_keypoints/1"},{"type":"function","title":"Evision.Detail.ImageFeatures.getKeypoints/1","doc":"getKeypoints\n\n##### Positional Arguments\n- **self**: `Evision.Detail.ImageFeatures.t()`\n\n##### Return\n- **retval**: `[Evision.KeyPoint]`\n\nPython prototype (for reference only):\n```python3\ngetKeypoints() -> retval\n```","ref":"Evision.Detail.ImageFeatures.html#getKeypoints/1"},{"type":"function","title":"Evision.Detail.ImageFeatures.set_descriptors/2","doc":"","ref":"Evision.Detail.ImageFeatures.html#set_descriptors/2"},{"type":"function","title":"Evision.Detail.ImageFeatures.set_img_idx/2","doc":"","ref":"Evision.Detail.ImageFeatures.html#set_img_idx/2"},{"type":"function","title":"Evision.Detail.ImageFeatures.set_img_size/2","doc":"","ref":"Evision.Detail.ImageFeatures.html#set_img_size/2"},{"type":"function","title":"Evision.Detail.ImageFeatures.set_keypoints/2","doc":"","ref":"Evision.Detail.ImageFeatures.html#set_keypoints/2"},{"type":"type","title":"Evision.Detail.ImageFeatures.t/0","doc":"Type that represents an `Detail.ImageFeatures` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.ImageFeatures.html#t:t/0"},{"type":"module","title":"Evision.Detail.MatchesInfo","doc":"","ref":"Evision.Detail.MatchesInfo.html"},{"type":"function","title":"Evision.Detail.MatchesInfo.get_confidence/1","doc":"","ref":"Evision.Detail.MatchesInfo.html#get_confidence/1"},{"type":"function","title":"Evision.Detail.MatchesInfo.get_dst_img_idx/1","doc":"","ref":"Evision.Detail.MatchesInfo.html#get_dst_img_idx/1"},{"type":"function","title":"Evision.Detail.MatchesInfo.get_H/1","doc":"","ref":"Evision.Detail.MatchesInfo.html#get_H/1"},{"type":"function","title":"Evision.Detail.MatchesInfo.get_inliers_mask/1","doc":"","ref":"Evision.Detail.MatchesInfo.html#get_inliers_mask/1"},{"type":"function","title":"Evision.Detail.MatchesInfo.get_matches/1","doc":"","ref":"Evision.Detail.MatchesInfo.html#get_matches/1"},{"type":"function","title":"Evision.Detail.MatchesInfo.get_num_inliers/1","doc":"","ref":"Evision.Detail.MatchesInfo.html#get_num_inliers/1"},{"type":"function","title":"Evision.Detail.MatchesInfo.get_src_img_idx/1","doc":"","ref":"Evision.Detail.MatchesInfo.html#get_src_img_idx/1"},{"type":"function","title":"Evision.Detail.MatchesInfo.getInliers/1","doc":"getInliers\n\n##### Positional Arguments\n- **self**: `Evision.Detail.MatchesInfo.t()`\n\n##### Return\n- **retval**: `[uchar]`\n\nPython prototype (for reference only):\n```python3\ngetInliers() -> retval\n```","ref":"Evision.Detail.MatchesInfo.html#getInliers/1"},{"type":"function","title":"Evision.Detail.MatchesInfo.getMatches/1","doc":"getMatches\n\n##### Positional Arguments\n- **self**: `Evision.Detail.MatchesInfo.t()`\n\n##### Return\n- **retval**: `[Evision.DMatch]`\n\nPython prototype (for reference only):\n```python3\ngetMatches() -> retval\n```","ref":"Evision.Detail.MatchesInfo.html#getMatches/1"},{"type":"function","title":"Evision.Detail.MatchesInfo.set_confidence/2","doc":"","ref":"Evision.Detail.MatchesInfo.html#set_confidence/2"},{"type":"function","title":"Evision.Detail.MatchesInfo.set_dst_img_idx/2","doc":"","ref":"Evision.Detail.MatchesInfo.html#set_dst_img_idx/2"},{"type":"function","title":"Evision.Detail.MatchesInfo.set_H/2","doc":"","ref":"Evision.Detail.MatchesInfo.html#set_H/2"},{"type":"function","title":"Evision.Detail.MatchesInfo.set_inliers_mask/2","doc":"","ref":"Evision.Detail.MatchesInfo.html#set_inliers_mask/2"},{"type":"function","title":"Evision.Detail.MatchesInfo.set_matches/2","doc":"","ref":"Evision.Detail.MatchesInfo.html#set_matches/2"},{"type":"function","title":"Evision.Detail.MatchesInfo.set_num_inliers/2","doc":"","ref":"Evision.Detail.MatchesInfo.html#set_num_inliers/2"},{"type":"function","title":"Evision.Detail.MatchesInfo.set_src_img_idx/2","doc":"","ref":"Evision.Detail.MatchesInfo.html#set_src_img_idx/2"},{"type":"type","title":"Evision.Detail.MatchesInfo.t/0","doc":"Type that represents an `Detail.MatchesInfo` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.MatchesInfo.html#t:t/0"},{"type":"module","title":"Evision.Detail.MultiBandBlender","doc":"","ref":"Evision.Detail.MultiBandBlender.html"},{"type":"function","title":"Evision.Detail.MultiBandBlender.blend/1","doc":"","ref":"Evision.Detail.MultiBandBlender.html#blend/1"},{"type":"function","title":"Evision.Detail.MultiBandBlender.blend/3","doc":"blend\n\n##### Positional Arguments\n- **self**: `Evision.Detail.MultiBandBlender.t()`\n\n##### Return\n- **dst**: `Evision.Mat.t()`\n- **dst_mask**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nblend(dst, dst_mask) -> dst, dst_mask\n```","ref":"Evision.Detail.MultiBandBlender.html#blend/3"},{"type":"function","title":"Evision.Detail.MultiBandBlender.feed/1","doc":"","ref":"Evision.Detail.MultiBandBlender.html#feed/1"},{"type":"function","title":"Evision.Detail.MultiBandBlender.feed/4","doc":"feed\n\n##### Positional Arguments\n- **self**: `Evision.Detail.MultiBandBlender.t()`\n- **img**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n- **tl**: `Point`\n\nPython prototype (for reference only):\n```python3\nfeed(img, mask, tl) -> None\n```","ref":"Evision.Detail.MultiBandBlender.html#feed/4"},{"type":"function","title":"Evision.Detail.MultiBandBlender.multiBandBlender/0","doc":"MultiBandBlender\n##### Keyword Arguments\n- **try_gpu**: `integer()`.\n- **num_bands**: `integer()`.\n- **weight_type**: `integer()`.\n\n##### Return\n- **self**: `Evision.Detail.MultiBandBlender.t()`\n\nPython prototype (for reference only):\n```python3\nMultiBandBlender([, try_gpu[, num_bands[, weight_type]]]) ->  \n```","ref":"Evision.Detail.MultiBandBlender.html#multiBandBlender/0"},{"type":"function","title":"Evision.Detail.MultiBandBlender.multiBandBlender/1","doc":"MultiBandBlender\n##### Keyword Arguments\n- **try_gpu**: `integer()`.\n- **num_bands**: `integer()`.\n- **weight_type**: `integer()`.\n\n##### Return\n- **self**: `Evision.Detail.MultiBandBlender.t()`\n\nPython prototype (for reference only):\n```python3\nMultiBandBlender([, try_gpu[, num_bands[, weight_type]]]) ->  \n```","ref":"Evision.Detail.MultiBandBlender.html#multiBandBlender/1"},{"type":"function","title":"Evision.Detail.MultiBandBlender.numBands/1","doc":"numBands\n\n##### Positional Arguments\n- **self**: `Evision.Detail.MultiBandBlender.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nnumBands() -> retval\n```","ref":"Evision.Detail.MultiBandBlender.html#numBands/1"},{"type":"function","title":"Evision.Detail.MultiBandBlender.prepare/1","doc":"","ref":"Evision.Detail.MultiBandBlender.html#prepare/1"},{"type":"function","title":"Evision.Detail.MultiBandBlender.prepare/2","doc":"prepare\n\n##### Positional Arguments\n- **self**: `Evision.Detail.MultiBandBlender.t()`\n- **dst_roi**: `Rect`\n\nPython prototype (for reference only):\n```python3\nprepare(dst_roi) -> None\n```","ref":"Evision.Detail.MultiBandBlender.html#prepare/2"},{"type":"function","title":"Evision.Detail.MultiBandBlender.setNumBands/1","doc":"","ref":"Evision.Detail.MultiBandBlender.html#setNumBands/1"},{"type":"function","title":"Evision.Detail.MultiBandBlender.setNumBands/2","doc":"setNumBands\n\n##### Positional Arguments\n- **self**: `Evision.Detail.MultiBandBlender.t()`\n- **val**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNumBands(val) -> None\n```","ref":"Evision.Detail.MultiBandBlender.html#setNumBands/2"},{"type":"type","title":"Evision.Detail.MultiBandBlender.t/0","doc":"Type that represents an `Detail.MultiBandBlender` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.MultiBandBlender.html#t:t/0"},{"type":"module","title":"Evision.Detail.NoBundleAdjuster","doc":"","ref":"Evision.Detail.NoBundleAdjuster.html"},{"type":"function","title":"Evision.Detail.NoBundleAdjuster.noBundleAdjuster/0","doc":"NoBundleAdjuster\n##### Return\n- **self**: `Evision.Detail.NoBundleAdjuster.t()`\n\nPython prototype (for reference only):\n```python3\nNoBundleAdjuster() ->  \n```","ref":"Evision.Detail.NoBundleAdjuster.html#noBundleAdjuster/0"},{"type":"function","title":"Evision.Detail.NoBundleAdjuster.noBundleAdjuster/1","doc":"","ref":"Evision.Detail.NoBundleAdjuster.html#noBundleAdjuster/1"},{"type":"type","title":"Evision.Detail.NoBundleAdjuster.t/0","doc":"Type that represents an `Detail.NoBundleAdjuster` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.NoBundleAdjuster.html#t:t/0"},{"type":"module","title":"Evision.Detail.NoExposureCompensator","doc":"","ref":"Evision.Detail.NoExposureCompensator.html"},{"type":"function","title":"Evision.Detail.NoExposureCompensator.apply/1","doc":"","ref":"Evision.Detail.NoExposureCompensator.html#apply/1"},{"type":"function","title":"Evision.Detail.NoExposureCompensator.apply/5","doc":"apply\n\n##### Positional Arguments\n- **self**: `Evision.Detail.NoExposureCompensator.t()`\n- **arg1**: `integer()`\n- **arg2**: `Point`\n- **arg4**: `Evision.Mat`\n\n##### Return\n- **arg3**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\napply(arg1, arg2, arg3, arg4) -> arg3\n```","ref":"Evision.Detail.NoExposureCompensator.html#apply/5"},{"type":"function","title":"Evision.Detail.NoExposureCompensator.getMatGains/1","doc":"getMatGains\n\n##### Positional Arguments\n- **self**: `Evision.Detail.NoExposureCompensator.t()`\n\n##### Return\n- **umv**: `[Evision.Mat]`.\n\nPython prototype (for reference only):\n```python3\ngetMatGains([, umv]) -> umv\n```","ref":"Evision.Detail.NoExposureCompensator.html#getMatGains/1"},{"type":"function","title":"Evision.Detail.NoExposureCompensator.getMatGains/2","doc":"getMatGains\n\n##### Positional Arguments\n- **self**: `Evision.Detail.NoExposureCompensator.t()`\n\n##### Return\n- **umv**: `[Evision.Mat]`.\n\nPython prototype (for reference only):\n```python3\ngetMatGains([, umv]) -> umv\n```","ref":"Evision.Detail.NoExposureCompensator.html#getMatGains/2"},{"type":"function","title":"Evision.Detail.NoExposureCompensator.setMatGains/1","doc":"","ref":"Evision.Detail.NoExposureCompensator.html#setMatGains/1"},{"type":"function","title":"Evision.Detail.NoExposureCompensator.setMatGains/2","doc":"setMatGains\n\n##### Positional Arguments\n- **self**: `Evision.Detail.NoExposureCompensator.t()`\n- **umv**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\nsetMatGains(umv) -> None\n```","ref":"Evision.Detail.NoExposureCompensator.html#setMatGains/2"},{"type":"type","title":"Evision.Detail.NoExposureCompensator.t/0","doc":"Type that represents an `Detail.NoExposureCompensator` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.NoExposureCompensator.html#t:t/0"},{"type":"module","title":"Evision.Detail.NoSeamFinder","doc":"","ref":"Evision.Detail.NoSeamFinder.html"},{"type":"function","title":"Evision.Detail.NoSeamFinder.find/1","doc":"","ref":"Evision.Detail.NoSeamFinder.html#find/1"},{"type":"function","title":"Evision.Detail.NoSeamFinder.find/4","doc":"find\n\n##### Positional Arguments\n- **self**: `Evision.Detail.NoSeamFinder.t()`\n- **arg1**: `[Evision.Mat]`\n- **arg2**: `[Point]`\n\n##### Return\n- **arg3**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\nfind(arg1, arg2, arg3) -> arg3\n```","ref":"Evision.Detail.NoSeamFinder.html#find/4"},{"type":"type","title":"Evision.Detail.NoSeamFinder.t/0","doc":"Type that represents an `Detail.NoSeamFinder` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.NoSeamFinder.html#t:t/0"},{"type":"module","title":"Evision.Detail.PairwiseSeamFinder","doc":"","ref":"Evision.Detail.PairwiseSeamFinder.html"},{"type":"function","title":"Evision.Detail.PairwiseSeamFinder.find/1","doc":"","ref":"Evision.Detail.PairwiseSeamFinder.html#find/1"},{"type":"function","title":"Evision.Detail.PairwiseSeamFinder.find/4","doc":"find\n\n##### Positional Arguments\n- **self**: `Evision.Detail.PairwiseSeamFinder.t()`\n- **src**: `[Evision.Mat]`\n- **corners**: `[Point]`\n\n##### Return\n- **masks**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\nfind(src, corners, masks) -> masks\n```","ref":"Evision.Detail.PairwiseSeamFinder.html#find/4"},{"type":"type","title":"Evision.Detail.PairwiseSeamFinder.t/0","doc":"Type that represents an `Detail.PairwiseSeamFinder` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.PairwiseSeamFinder.html#t:t/0"},{"type":"module","title":"Evision.Detail.ProjectorBase","doc":"","ref":"Evision.Detail.ProjectorBase.html"},{"type":"type","title":"Evision.Detail.ProjectorBase.t/0","doc":"Type that represents an `Detail.ProjectorBase` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.ProjectorBase.html#t:t/0"},{"type":"module","title":"Evision.Detail.SeamFinder","doc":"","ref":"Evision.Detail.SeamFinder.html"},{"type":"function","title":"Evision.Detail.SeamFinder.createDefault/1","doc":"createDefault\n\n##### Positional Arguments\n- **type**: `integer()`\n\n##### Return\n- **retval**: `Evision.Detail.SeamFinder.t()`\n\nPython prototype (for reference only):\n```python3\ncreateDefault(type) -> retval\n```","ref":"Evision.Detail.SeamFinder.html#createDefault/1"},{"type":"function","title":"Evision.Detail.SeamFinder.cv_DP_SEAM/0","doc":"","ref":"Evision.Detail.SeamFinder.html#cv_DP_SEAM/0"},{"type":"function","title":"Evision.Detail.SeamFinder.cv_NO/0","doc":"","ref":"Evision.Detail.SeamFinder.html#cv_NO/0"},{"type":"function","title":"Evision.Detail.SeamFinder.cv_VORONOI_SEAM/0","doc":"","ref":"Evision.Detail.SeamFinder.html#cv_VORONOI_SEAM/0"},{"type":"function","title":"Evision.Detail.SeamFinder.find/1","doc":"","ref":"Evision.Detail.SeamFinder.html#find/1"},{"type":"function","title":"Evision.Detail.SeamFinder.find/4","doc":"Estimates seams.\n\n##### Positional Arguments\n- **self**: `Evision.Detail.SeamFinder.t()`\n- **src**: `[Evision.Mat]`.\n\n  Source images\n\n- **corners**: `[Point]`.\n\n  Source image top-left corners\n\n##### Return\n- **masks**: `[Evision.Mat]`.\n\n  Source image masks to update\n\nPython prototype (for reference only):\n```python3\nfind(src, corners, masks) -> masks\n```","ref":"Evision.Detail.SeamFinder.html#find/4"},{"type":"type","title":"Evision.Detail.SeamFinder.enum/0","doc":"","ref":"Evision.Detail.SeamFinder.html#t:enum/0"},{"type":"type","title":"Evision.Detail.SeamFinder.t/0","doc":"Type that represents an `Detail.SeamFinder` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.SeamFinder.html#t:t/0"},{"type":"module","title":"Evision.Detail.SphericalProjector","doc":"","ref":"Evision.Detail.SphericalProjector.html"},{"type":"function","title":"Evision.Detail.SphericalProjector.mapBackward/1","doc":"","ref":"Evision.Detail.SphericalProjector.html#mapBackward/1"},{"type":"function","title":"Evision.Detail.SphericalProjector.mapBackward/5","doc":"mapBackward\n\n##### Positional Arguments\n- **self**: `Evision.Detail.SphericalProjector.t()`\n- **u**: `float`\n- **v**: `float`\n- **x**: `float`\n- **y**: `float`\n\nPython prototype (for reference only):\n```python3\nmapBackward(u, v, x, y) -> None\n```","ref":"Evision.Detail.SphericalProjector.html#mapBackward/5"},{"type":"function","title":"Evision.Detail.SphericalProjector.mapForward/1","doc":"","ref":"Evision.Detail.SphericalProjector.html#mapForward/1"},{"type":"function","title":"Evision.Detail.SphericalProjector.mapForward/5","doc":"mapForward\n\n##### Positional Arguments\n- **self**: `Evision.Detail.SphericalProjector.t()`\n- **x**: `float`\n- **y**: `float`\n- **u**: `float`\n- **v**: `float`\n\nPython prototype (for reference only):\n```python3\nmapForward(x, y, u, v) -> None\n```","ref":"Evision.Detail.SphericalProjector.html#mapForward/5"},{"type":"type","title":"Evision.Detail.SphericalProjector.t/0","doc":"Type that represents an `Detail.SphericalProjector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.SphericalProjector.html#t:t/0"},{"type":"module","title":"Evision.Detail.TestOp","doc":"","ref":"Evision.Detail.TestOp.html"},{"type":"function","title":"Evision.Detail.TestOp.cv_TEST_CUSTOM/0","doc":"","ref":"Evision.Detail.TestOp.html#cv_TEST_CUSTOM/0"},{"type":"function","title":"Evision.Detail.TestOp.cv_TEST_EQ/0","doc":"","ref":"Evision.Detail.TestOp.html#cv_TEST_EQ/0"},{"type":"function","title":"Evision.Detail.TestOp.cv_TEST_GE/0","doc":"","ref":"Evision.Detail.TestOp.html#cv_TEST_GE/0"},{"type":"function","title":"Evision.Detail.TestOp.cv_TEST_GT/0","doc":"","ref":"Evision.Detail.TestOp.html#cv_TEST_GT/0"},{"type":"function","title":"Evision.Detail.TestOp.cv_TEST_LE/0","doc":"","ref":"Evision.Detail.TestOp.html#cv_TEST_LE/0"},{"type":"function","title":"Evision.Detail.TestOp.cv_TEST_LT/0","doc":"","ref":"Evision.Detail.TestOp.html#cv_TEST_LT/0"},{"type":"function","title":"Evision.Detail.TestOp.cv_TEST_NE/0","doc":"","ref":"Evision.Detail.TestOp.html#cv_TEST_NE/0"},{"type":"type","title":"Evision.Detail.TestOp.enum/0","doc":"","ref":"Evision.Detail.TestOp.html#t:enum/0"},{"type":"module","title":"Evision.Detail.Timelapser","doc":"","ref":"Evision.Detail.Timelapser.html"},{"type":"function","title":"Evision.Detail.Timelapser.createDefault/1","doc":"createDefault\n\n##### Positional Arguments\n- **type**: `integer()`\n\n##### Return\n- **retval**: `Evision.Detail.Timelapser.t()`\n\nPython prototype (for reference only):\n```python3\ncreateDefault(type) -> retval\n```","ref":"Evision.Detail.Timelapser.html#createDefault/1"},{"type":"function","title":"Evision.Detail.Timelapser.cv_AS_IS/0","doc":"","ref":"Evision.Detail.Timelapser.html#cv_AS_IS/0"},{"type":"function","title":"Evision.Detail.Timelapser.cv_CROP/0","doc":"","ref":"Evision.Detail.Timelapser.html#cv_CROP/0"},{"type":"function","title":"Evision.Detail.Timelapser.getDst/1","doc":"getDst\n\n##### Positional Arguments\n- **self**: `Evision.Detail.Timelapser.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetDst() -> retval\n```","ref":"Evision.Detail.Timelapser.html#getDst/1"},{"type":"function","title":"Evision.Detail.Timelapser.initialize/1","doc":"","ref":"Evision.Detail.Timelapser.html#initialize/1"},{"type":"function","title":"Evision.Detail.Timelapser.initialize/3","doc":"initialize\n\n##### Positional Arguments\n- **self**: `Evision.Detail.Timelapser.t()`\n- **corners**: `[Point]`\n- **sizes**: `[Size]`\n\nPython prototype (for reference only):\n```python3\ninitialize(corners, sizes) -> None\n```","ref":"Evision.Detail.Timelapser.html#initialize/3"},{"type":"function","title":"Evision.Detail.Timelapser.process/1","doc":"","ref":"Evision.Detail.Timelapser.html#process/1"},{"type":"function","title":"Evision.Detail.Timelapser.process/4","doc":"process\n\n##### Positional Arguments\n- **self**: `Evision.Detail.Timelapser.t()`\n- **img**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n- **tl**: `Point`\n\nPython prototype (for reference only):\n```python3\nprocess(img, mask, tl) -> None\n```","ref":"Evision.Detail.Timelapser.html#process/4"},{"type":"type","title":"Evision.Detail.Timelapser.enum/0","doc":"","ref":"Evision.Detail.Timelapser.html#t:enum/0"},{"type":"type","title":"Evision.Detail.Timelapser.t/0","doc":"Type that represents an `Detail.Timelapser` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.Timelapser.html#t:t/0"},{"type":"module","title":"Evision.Detail.TimelapserCrop","doc":"","ref":"Evision.Detail.TimelapserCrop.html"},{"type":"type","title":"Evision.Detail.TimelapserCrop.t/0","doc":"Type that represents an `Detail.TimelapserCrop` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.TimelapserCrop.html#t:t/0"},{"type":"module","title":"Evision.Detail.TrackerContribSamplerCSC","doc":"","ref":"Evision.Detail.TrackerContribSamplerCSC.html"},{"type":"function","title":"Evision.Detail.TrackerContribSamplerCSC.cv_MODE_DETECT/0","doc":"","ref":"Evision.Detail.TrackerContribSamplerCSC.html#cv_MODE_DETECT/0"},{"type":"function","title":"Evision.Detail.TrackerContribSamplerCSC.cv_MODE_INIT_NEG/0","doc":"","ref":"Evision.Detail.TrackerContribSamplerCSC.html#cv_MODE_INIT_NEG/0"},{"type":"function","title":"Evision.Detail.TrackerContribSamplerCSC.cv_MODE_INIT_POS/0","doc":"","ref":"Evision.Detail.TrackerContribSamplerCSC.html#cv_MODE_INIT_POS/0"},{"type":"function","title":"Evision.Detail.TrackerContribSamplerCSC.cv_MODE_TRACK_NEG/0","doc":"","ref":"Evision.Detail.TrackerContribSamplerCSC.html#cv_MODE_TRACK_NEG/0"},{"type":"function","title":"Evision.Detail.TrackerContribSamplerCSC.cv_MODE_TRACK_POS/0","doc":"","ref":"Evision.Detail.TrackerContribSamplerCSC.html#cv_MODE_TRACK_POS/0"},{"type":"type","title":"Evision.Detail.TrackerContribSamplerCSC.enum/0","doc":"","ref":"Evision.Detail.TrackerContribSamplerCSC.html#t:enum/0"},{"type":"module","title":"Evision.Detail.TrackerSamplerCS","doc":"","ref":"Evision.Detail.TrackerSamplerCS.html"},{"type":"function","title":"Evision.Detail.TrackerSamplerCS.cv_MODE_CLASSIFY/0","doc":"","ref":"Evision.Detail.TrackerSamplerCS.html#cv_MODE_CLASSIFY/0"},{"type":"function","title":"Evision.Detail.TrackerSamplerCS.cv_MODE_NEGATIVE/0","doc":"","ref":"Evision.Detail.TrackerSamplerCS.html#cv_MODE_NEGATIVE/0"},{"type":"function","title":"Evision.Detail.TrackerSamplerCS.cv_MODE_POSITIVE/0","doc":"","ref":"Evision.Detail.TrackerSamplerCS.html#cv_MODE_POSITIVE/0"},{"type":"type","title":"Evision.Detail.TrackerSamplerCS.enum/0","doc":"","ref":"Evision.Detail.TrackerSamplerCS.html#t:enum/0"},{"type":"module","title":"Evision.Detail.TrackerSamplerCSC.MODE","doc":"","ref":"Evision.Detail.TrackerSamplerCSC.MODE.html"},{"type":"function","title":"Evision.Detail.TrackerSamplerCSC.MODE.cv_MODE_DETECT/0","doc":"","ref":"Evision.Detail.TrackerSamplerCSC.MODE.html#cv_MODE_DETECT/0"},{"type":"function","title":"Evision.Detail.TrackerSamplerCSC.MODE.cv_MODE_INIT_NEG/0","doc":"","ref":"Evision.Detail.TrackerSamplerCSC.MODE.html#cv_MODE_INIT_NEG/0"},{"type":"function","title":"Evision.Detail.TrackerSamplerCSC.MODE.cv_MODE_INIT_POS/0","doc":"","ref":"Evision.Detail.TrackerSamplerCSC.MODE.html#cv_MODE_INIT_POS/0"},{"type":"function","title":"Evision.Detail.TrackerSamplerCSC.MODE.cv_MODE_TRACK_NEG/0","doc":"","ref":"Evision.Detail.TrackerSamplerCSC.MODE.html#cv_MODE_TRACK_NEG/0"},{"type":"function","title":"Evision.Detail.TrackerSamplerCSC.MODE.cv_MODE_TRACK_POS/0","doc":"","ref":"Evision.Detail.TrackerSamplerCSC.MODE.html#cv_MODE_TRACK_POS/0"},{"type":"type","title":"Evision.Detail.TrackerSamplerCSC.MODE.enum/0","doc":"","ref":"Evision.Detail.TrackerSamplerCSC.MODE.html#t:enum/0"},{"type":"module","title":"Evision.Detail.VoronoiSeamFinder","doc":"","ref":"Evision.Detail.VoronoiSeamFinder.html"},{"type":"function","title":"Evision.Detail.VoronoiSeamFinder.find/1","doc":"","ref":"Evision.Detail.VoronoiSeamFinder.html#find/1"},{"type":"function","title":"Evision.Detail.VoronoiSeamFinder.find/4","doc":"find\n\n##### Positional Arguments\n- **self**: `Evision.Detail.VoronoiSeamFinder.t()`\n- **src**: `[Evision.Mat]`\n- **corners**: `[Point]`\n\n##### Return\n- **masks**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\nfind(src, corners, masks) -> masks\n```","ref":"Evision.Detail.VoronoiSeamFinder.html#find/4"},{"type":"type","title":"Evision.Detail.VoronoiSeamFinder.t/0","doc":"Type that represents an `Detail.VoronoiSeamFinder` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Detail.VoronoiSeamFinder.html#t:t/0"},{"type":"module","title":"Evision.Detail.WaveCorrectKind","doc":"","ref":"Evision.Detail.WaveCorrectKind.html"},{"type":"function","title":"Evision.Detail.WaveCorrectKind.cv_WAVE_CORRECT_AUTO/0","doc":"","ref":"Evision.Detail.WaveCorrectKind.html#cv_WAVE_CORRECT_AUTO/0"},{"type":"function","title":"Evision.Detail.WaveCorrectKind.cv_WAVE_CORRECT_HORIZ/0","doc":"","ref":"Evision.Detail.WaveCorrectKind.html#cv_WAVE_CORRECT_HORIZ/0"},{"type":"function","title":"Evision.Detail.WaveCorrectKind.cv_WAVE_CORRECT_VERT/0","doc":"","ref":"Evision.Detail.WaveCorrectKind.html#cv_WAVE_CORRECT_VERT/0"},{"type":"type","title":"Evision.Detail.WaveCorrectKind.enum/0","doc":"","ref":"Evision.Detail.WaveCorrectKind.html#t:enum/0"},{"type":"module","title":"Evision.DftFlags","doc":"","ref":"Evision.DftFlags.html"},{"type":"function","title":"Evision.DftFlags.cv_DCT_INVERSE/0","doc":"","ref":"Evision.DftFlags.html#cv_DCT_INVERSE/0"},{"type":"function","title":"Evision.DftFlags.cv_DCT_ROWS/0","doc":"","ref":"Evision.DftFlags.html#cv_DCT_ROWS/0"},{"type":"function","title":"Evision.DftFlags.cv_DFT_COMPLEX_INPUT/0","doc":"","ref":"Evision.DftFlags.html#cv_DFT_COMPLEX_INPUT/0"},{"type":"function","title":"Evision.DftFlags.cv_DFT_COMPLEX_OUTPUT/0","doc":"","ref":"Evision.DftFlags.html#cv_DFT_COMPLEX_OUTPUT/0"},{"type":"function","title":"Evision.DftFlags.cv_DFT_INVERSE/0","doc":"","ref":"Evision.DftFlags.html#cv_DFT_INVERSE/0"},{"type":"function","title":"Evision.DftFlags.cv_DFT_REAL_OUTPUT/0","doc":"","ref":"Evision.DftFlags.html#cv_DFT_REAL_OUTPUT/0"},{"type":"function","title":"Evision.DftFlags.cv_DFT_ROWS/0","doc":"","ref":"Evision.DftFlags.html#cv_DFT_ROWS/0"},{"type":"function","title":"Evision.DftFlags.cv_DFT_SCALE/0","doc":"","ref":"Evision.DftFlags.html#cv_DFT_SCALE/0"},{"type":"type","title":"Evision.DftFlags.enum/0","doc":"","ref":"Evision.DftFlags.html#t:enum/0"},{"type":"module","title":"Evision.DistanceTransformLabelTypes","doc":"","ref":"Evision.DistanceTransformLabelTypes.html"},{"type":"function","title":"Evision.DistanceTransformLabelTypes.cv_DIST_LABEL_CCOMP/0","doc":"","ref":"Evision.DistanceTransformLabelTypes.html#cv_DIST_LABEL_CCOMP/0"},{"type":"function","title":"Evision.DistanceTransformLabelTypes.cv_DIST_LABEL_PIXEL/0","doc":"","ref":"Evision.DistanceTransformLabelTypes.html#cv_DIST_LABEL_PIXEL/0"},{"type":"type","title":"Evision.DistanceTransformLabelTypes.enum/0","doc":"","ref":"Evision.DistanceTransformLabelTypes.html#t:enum/0"},{"type":"module","title":"Evision.DistanceTransformMasks","doc":"","ref":"Evision.DistanceTransformMasks.html"},{"type":"function","title":"Evision.DistanceTransformMasks.cv_DIST_MASK_3/0","doc":"","ref":"Evision.DistanceTransformMasks.html#cv_DIST_MASK_3/0"},{"type":"function","title":"Evision.DistanceTransformMasks.cv_DIST_MASK_5/0","doc":"","ref":"Evision.DistanceTransformMasks.html#cv_DIST_MASK_5/0"},{"type":"function","title":"Evision.DistanceTransformMasks.cv_DIST_MASK_PRECISE/0","doc":"","ref":"Evision.DistanceTransformMasks.html#cv_DIST_MASK_PRECISE/0"},{"type":"type","title":"Evision.DistanceTransformMasks.enum/0","doc":"","ref":"Evision.DistanceTransformMasks.html#t:enum/0"},{"type":"module","title":"Evision.DistanceTypes","doc":"","ref":"Evision.DistanceTypes.html"},{"type":"function","title":"Evision.DistanceTypes.cv_DIST_C/0","doc":"","ref":"Evision.DistanceTypes.html#cv_DIST_C/0"},{"type":"function","title":"Evision.DistanceTypes.cv_DIST_FAIR/0","doc":"","ref":"Evision.DistanceTypes.html#cv_DIST_FAIR/0"},{"type":"function","title":"Evision.DistanceTypes.cv_DIST_HUBER/0","doc":"","ref":"Evision.DistanceTypes.html#cv_DIST_HUBER/0"},{"type":"function","title":"Evision.DistanceTypes.cv_DIST_L1/0","doc":"","ref":"Evision.DistanceTypes.html#cv_DIST_L1/0"},{"type":"function","title":"Evision.DistanceTypes.cv_DIST_L2/0","doc":"","ref":"Evision.DistanceTypes.html#cv_DIST_L2/0"},{"type":"function","title":"Evision.DistanceTypes.cv_DIST_L12/0","doc":"","ref":"Evision.DistanceTypes.html#cv_DIST_L12/0"},{"type":"function","title":"Evision.DistanceTypes.cv_DIST_USER/0","doc":"","ref":"Evision.DistanceTypes.html#cv_DIST_USER/0"},{"type":"function","title":"Evision.DistanceTypes.cv_DIST_WELSCH/0","doc":"","ref":"Evision.DistanceTypes.html#cv_DIST_WELSCH/0"},{"type":"type","title":"Evision.DistanceTypes.enum/0","doc":"","ref":"Evision.DistanceTypes.html#t:enum/0"},{"type":"module","title":"Evision.DrawMatchesFlags","doc":"","ref":"Evision.DrawMatchesFlags.html"},{"type":"function","title":"Evision.DrawMatchesFlags.cv_DEFAULT/0","doc":"","ref":"Evision.DrawMatchesFlags.html#cv_DEFAULT/0"},{"type":"function","title":"Evision.DrawMatchesFlags.cv_DRAW_OVER_OUTIMG/0","doc":"","ref":"Evision.DrawMatchesFlags.html#cv_DRAW_OVER_OUTIMG/0"},{"type":"function","title":"Evision.DrawMatchesFlags.cv_DRAW_RICH_KEYPOINTS/0","doc":"","ref":"Evision.DrawMatchesFlags.html#cv_DRAW_RICH_KEYPOINTS/0"},{"type":"function","title":"Evision.DrawMatchesFlags.cv_NOT_DRAW_SINGLE_POINTS/0","doc":"","ref":"Evision.DrawMatchesFlags.html#cv_NOT_DRAW_SINGLE_POINTS/0"},{"type":"type","title":"Evision.DrawMatchesFlags.enum/0","doc":"","ref":"Evision.DrawMatchesFlags.html#t:enum/0"},{"type":"module","title":"Evision.DynaFu","doc":"","ref":"Evision.DynaFu.html"},{"type":"type","title":"Evision.DynaFu.t/0","doc":"Type that represents an `DynaFu` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.DynaFu.html#t:t/0"},{"type":"module","title":"Evision.DynaFu.DynaFu","doc":"","ref":"Evision.DynaFu.DynaFu.html"},{"type":"function","title":"Evision.DynaFu.DynaFu.create/1","doc":"create\n\n##### Positional Arguments\n- **params**: `kinfu::Params`\n\n##### Return\n- **retval**: `DynaFu`\n\nPython prototype (for reference only):\n```python3\ncreate(_params) -> retval\n```","ref":"Evision.DynaFu.DynaFu.html#create/1"},{"type":"function","title":"Evision.DynaFu.DynaFu.getCloud/1","doc":"Gets points and normals of current 3d mesh\n\n##### Positional Arguments\n- **self**: `Evision.DynaFu.DynaFu.t()`\n\n##### Return\n- **points**: `Evision.Mat.t()`.\n\n  vector of points which are 4-float vectors\n\n- **normals**: `Evision.Mat.t()`.\n\n  vector of normals which are 4-float vectors\n\nThe order of normals corresponds to order of points.\nThe order of points is undefined.\n\nPython prototype (for reference only):\n```python3\ngetCloud([, points[, normals]]) -> points, normals\n```","ref":"Evision.DynaFu.DynaFu.html#getCloud/1"},{"type":"function","title":"Evision.DynaFu.DynaFu.getCloud/2","doc":"Gets points and normals of current 3d mesh\n\n##### Positional Arguments\n- **self**: `Evision.DynaFu.DynaFu.t()`\n\n##### Return\n- **points**: `Evision.Mat.t()`.\n\n  vector of points which are 4-float vectors\n\n- **normals**: `Evision.Mat.t()`.\n\n  vector of normals which are 4-float vectors\n\nThe order of normals corresponds to order of points.\nThe order of points is undefined.\n\nPython prototype (for reference only):\n```python3\ngetCloud([, points[, normals]]) -> points, normals\n```","ref":"Evision.DynaFu.DynaFu.html#getCloud/2"},{"type":"function","title":"Evision.DynaFu.DynaFu.getNormals/1","doc":"","ref":"Evision.DynaFu.DynaFu.html#getNormals/1"},{"type":"function","title":"Evision.DynaFu.DynaFu.getNormals/2","doc":"Calculates normals for given points\n\n##### Positional Arguments\n- **self**: `Evision.DynaFu.DynaFu.t()`\n- **points**: `Evision.Mat`.\n\n  input vector of points which are 4-float vectors\n\n##### Return\n- **normals**: `Evision.Mat.t()`.\n\n  output vector of corresponding normals which are 4-float vectors\n\nPython prototype (for reference only):\n```python3\ngetNormals(points[, normals]) -> normals\n```","ref":"Evision.DynaFu.DynaFu.html#getNormals/2"},{"type":"function","title":"Evision.DynaFu.DynaFu.getNormals/3","doc":"Calculates normals for given points\n\n##### Positional Arguments\n- **self**: `Evision.DynaFu.DynaFu.t()`\n- **points**: `Evision.Mat`.\n\n  input vector of points which are 4-float vectors\n\n##### Return\n- **normals**: `Evision.Mat.t()`.\n\n  output vector of corresponding normals which are 4-float vectors\n\nPython prototype (for reference only):\n```python3\ngetNormals(points[, normals]) -> normals\n```","ref":"Evision.DynaFu.DynaFu.html#getNormals/3"},{"type":"function","title":"Evision.DynaFu.DynaFu.getPoints/1","doc":"Gets points of current 3d mesh\n\n##### Positional Arguments\n- **self**: `Evision.DynaFu.DynaFu.t()`\n\n##### Return\n- **points**: `Evision.Mat.t()`.\n\n  vector of points which are 4-float vectors\n\nThe order of points is undefined.\n\nPython prototype (for reference only):\n```python3\ngetPoints([, points]) -> points\n```","ref":"Evision.DynaFu.DynaFu.html#getPoints/1"},{"type":"function","title":"Evision.DynaFu.DynaFu.getPoints/2","doc":"Gets points of current 3d mesh\n\n##### Positional Arguments\n- **self**: `Evision.DynaFu.DynaFu.t()`\n\n##### Return\n- **points**: `Evision.Mat.t()`.\n\n  vector of points which are 4-float vectors\n\nThe order of points is undefined.\n\nPython prototype (for reference only):\n```python3\ngetPoints([, points]) -> points\n```","ref":"Evision.DynaFu.DynaFu.html#getPoints/2"},{"type":"function","title":"Evision.DynaFu.DynaFu.render/1","doc":"Renders a volume into an image\n\n##### Positional Arguments\n- **self**: `Evision.DynaFu.DynaFu.t()`\n\n##### Keyword Arguments\n- **cameraPose**: `Evision.Mat`.\n\n  pose of camera to render from. If empty then render from current pose\n  which is a last frame camera pose.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  resulting image\n\nRenders a 0-surface of TSDF using Phong shading into a CV_8UC4 Mat.\nLight pose is fixed in DynaFu params.\n\nPython prototype (for reference only):\n```python3\nrender([, image[, cameraPose]]) -> image\n```","ref":"Evision.DynaFu.DynaFu.html#render/1"},{"type":"function","title":"Evision.DynaFu.DynaFu.render/2","doc":"Renders a volume into an image\n\n##### Positional Arguments\n- **self**: `Evision.DynaFu.DynaFu.t()`\n\n##### Keyword Arguments\n- **cameraPose**: `Evision.Mat`.\n\n  pose of camera to render from. If empty then render from current pose\n  which is a last frame camera pose.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  resulting image\n\nRenders a 0-surface of TSDF using Phong shading into a CV_8UC4 Mat.\nLight pose is fixed in DynaFu params.\n\nPython prototype (for reference only):\n```python3\nrender([, image[, cameraPose]]) -> image\n```","ref":"Evision.DynaFu.DynaFu.html#render/2"},{"type":"function","title":"Evision.DynaFu.DynaFu.reset/1","doc":"Resets the algorithm\n\n##### Positional Arguments\n- **self**: `Evision.DynaFu.DynaFu.t()`\n\nClears current model and resets a pose.\n\nPython prototype (for reference only):\n```python3\nreset() -> None\n```","ref":"Evision.DynaFu.DynaFu.html#reset/1"},{"type":"function","title":"Evision.DynaFu.DynaFu.update/1","doc":"","ref":"Evision.DynaFu.DynaFu.html#update/1"},{"type":"function","title":"Evision.DynaFu.DynaFu.update/2","doc":"Process next depth frame\n\n##### Positional Arguments\n- **self**: `Evision.DynaFu.DynaFu.t()`\n- **depth**: `Evision.Mat`.\n\n  one-channel image which size and depth scale is described in algorithm's parameters\n\n##### Return\n- **retval**: `bool`\n\nIntegrates depth into voxel space with respect to its ICP-calculated pose.\nInput image is converted to CV_32F internally if has another type.\n@return true if succeeded to align new frame with current scene, false if opposite\n\nPython prototype (for reference only):\n```python3\nupdate(depth) -> retval\n```","ref":"Evision.DynaFu.DynaFu.html#update/2"},{"type":"type","title":"Evision.DynaFu.DynaFu.t/0","doc":"Type that represents an `DynaFu.DynaFu` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.DynaFu.DynaFu.html#t:t/0"},{"type":"module","title":"Evision.EMDHistogramCostExtractor","doc":"","ref":"Evision.EMDHistogramCostExtractor.html"},{"type":"function","title":"Evision.EMDHistogramCostExtractor.getNormFlag/1","doc":"getNormFlag\n\n##### Positional Arguments\n- **self**: `Evision.EMDHistogramCostExtractor.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNormFlag() -> retval\n```","ref":"Evision.EMDHistogramCostExtractor.html#getNormFlag/1"},{"type":"function","title":"Evision.EMDHistogramCostExtractor.setNormFlag/1","doc":"","ref":"Evision.EMDHistogramCostExtractor.html#setNormFlag/1"},{"type":"function","title":"Evision.EMDHistogramCostExtractor.setNormFlag/2","doc":"setNormFlag\n\n##### Positional Arguments\n- **self**: `Evision.EMDHistogramCostExtractor.t()`\n- **flag**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNormFlag(flag) -> None\n```","ref":"Evision.EMDHistogramCostExtractor.html#setNormFlag/2"},{"type":"type","title":"Evision.EMDHistogramCostExtractor.t/0","doc":"Type that represents an `EMDHistogramCostExtractor` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.EMDHistogramCostExtractor.html#t:t/0"},{"type":"module","title":"Evision.EMDL1HistogramCostExtractor","doc":"","ref":"Evision.EMDL1HistogramCostExtractor.html"},{"type":"type","title":"Evision.EMDL1HistogramCostExtractor.t/0","doc":"Type that represents an `EMDL1HistogramCostExtractor` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.EMDL1HistogramCostExtractor.html#t:t/0"},{"type":"module","title":"Evision.Error.Code","doc":"","ref":"Evision.Error.Code.html"},{"type":"function","title":"Evision.Error.Code.cv_BadAlign/0","doc":"","ref":"Evision.Error.Code.html#cv_BadAlign/0"},{"type":"function","title":"Evision.Error.Code.cv_BadAlphaChannel/0","doc":"","ref":"Evision.Error.Code.html#cv_BadAlphaChannel/0"},{"type":"function","title":"Evision.Error.Code.cv_BadCallBack/0","doc":"","ref":"Evision.Error.Code.html#cv_BadCallBack/0"},{"type":"function","title":"Evision.Error.Code.cv_BadCOI/0","doc":"","ref":"Evision.Error.Code.html#cv_BadCOI/0"},{"type":"function","title":"Evision.Error.Code.cv_BadDataPtr/0","doc":"","ref":"Evision.Error.Code.html#cv_BadDataPtr/0"},{"type":"function","title":"Evision.Error.Code.cv_BadDepth/0","doc":"","ref":"Evision.Error.Code.html#cv_BadDepth/0"},{"type":"function","title":"Evision.Error.Code.cv_BadImageSize/0","doc":"","ref":"Evision.Error.Code.html#cv_BadImageSize/0"},{"type":"function","title":"Evision.Error.Code.cv_BadModelOrChSeq/0","doc":"","ref":"Evision.Error.Code.html#cv_BadModelOrChSeq/0"},{"type":"function","title":"Evision.Error.Code.cv_BadNumChannel1U/0","doc":"","ref":"Evision.Error.Code.html#cv_BadNumChannel1U/0"},{"type":"function","title":"Evision.Error.Code.cv_BadNumChannels/0","doc":"","ref":"Evision.Error.Code.html#cv_BadNumChannels/0"},{"type":"function","title":"Evision.Error.Code.cv_BadOffset/0","doc":"","ref":"Evision.Error.Code.html#cv_BadOffset/0"},{"type":"function","title":"Evision.Error.Code.cv_BadOrder/0","doc":"","ref":"Evision.Error.Code.html#cv_BadOrder/0"},{"type":"function","title":"Evision.Error.Code.cv_BadOrigin/0","doc":"","ref":"Evision.Error.Code.html#cv_BadOrigin/0"},{"type":"function","title":"Evision.Error.Code.cv_BadROISize/0","doc":"","ref":"Evision.Error.Code.html#cv_BadROISize/0"},{"type":"function","title":"Evision.Error.Code.cv_BadStep/0","doc":"","ref":"Evision.Error.Code.html#cv_BadStep/0"},{"type":"function","title":"Evision.Error.Code.cv_BadTileSize/0","doc":"","ref":"Evision.Error.Code.html#cv_BadTileSize/0"},{"type":"function","title":"Evision.Error.Code.cv_GpuApiCallError/0","doc":"","ref":"Evision.Error.Code.html#cv_GpuApiCallError/0"},{"type":"function","title":"Evision.Error.Code.cv_GpuNotSupported/0","doc":"","ref":"Evision.Error.Code.html#cv_GpuNotSupported/0"},{"type":"function","title":"Evision.Error.Code.cv_HeaderIsNull/0","doc":"","ref":"Evision.Error.Code.html#cv_HeaderIsNull/0"},{"type":"function","title":"Evision.Error.Code.cv_MaskIsTiled/0","doc":"","ref":"Evision.Error.Code.html#cv_MaskIsTiled/0"},{"type":"function","title":"Evision.Error.Code.cv_OpenCLApiCallError/0","doc":"","ref":"Evision.Error.Code.html#cv_OpenCLApiCallError/0"},{"type":"function","title":"Evision.Error.Code.cv_OpenCLDoubleNotSupported/0","doc":"","ref":"Evision.Error.Code.html#cv_OpenCLDoubleNotSupported/0"},{"type":"function","title":"Evision.Error.Code.cv_OpenCLInitError/0","doc":"","ref":"Evision.Error.Code.html#cv_OpenCLInitError/0"},{"type":"function","title":"Evision.Error.Code.cv_OpenCLNoAMDBlasFft/0","doc":"","ref":"Evision.Error.Code.html#cv_OpenCLNoAMDBlasFft/0"},{"type":"function","title":"Evision.Error.Code.cv_OpenGlApiCallError/0","doc":"","ref":"Evision.Error.Code.html#cv_OpenGlApiCallError/0"},{"type":"function","title":"Evision.Error.Code.cv_OpenGlNotSupported/0","doc":"","ref":"Evision.Error.Code.html#cv_OpenGlNotSupported/0"},{"type":"function","title":"Evision.Error.Code.cv_StsAssert/0","doc":"","ref":"Evision.Error.Code.html#cv_StsAssert/0"},{"type":"function","title":"Evision.Error.Code.cv_StsAutoTrace/0","doc":"","ref":"Evision.Error.Code.html#cv_StsAutoTrace/0"},{"type":"function","title":"Evision.Error.Code.cv_StsBackTrace/0","doc":"","ref":"Evision.Error.Code.html#cv_StsBackTrace/0"},{"type":"function","title":"Evision.Error.Code.cv_StsBadArg/0","doc":"","ref":"Evision.Error.Code.html#cv_StsBadArg/0"},{"type":"function","title":"Evision.Error.Code.cv_StsBadFlag/0","doc":"","ref":"Evision.Error.Code.html#cv_StsBadFlag/0"},{"type":"function","title":"Evision.Error.Code.cv_StsBadFunc/0","doc":"","ref":"Evision.Error.Code.html#cv_StsBadFunc/0"},{"type":"function","title":"Evision.Error.Code.cv_StsBadMask/0","doc":"","ref":"Evision.Error.Code.html#cv_StsBadMask/0"},{"type":"function","title":"Evision.Error.Code.cv_StsBadMemBlock/0","doc":"","ref":"Evision.Error.Code.html#cv_StsBadMemBlock/0"},{"type":"function","title":"Evision.Error.Code.cv_StsBadPoint/0","doc":"","ref":"Evision.Error.Code.html#cv_StsBadPoint/0"},{"type":"function","title":"Evision.Error.Code.cv_StsBadSize/0","doc":"","ref":"Evision.Error.Code.html#cv_StsBadSize/0"},{"type":"function","title":"Evision.Error.Code.cv_StsDivByZero/0","doc":"","ref":"Evision.Error.Code.html#cv_StsDivByZero/0"},{"type":"function","title":"Evision.Error.Code.cv_StsError/0","doc":"","ref":"Evision.Error.Code.html#cv_StsError/0"},{"type":"function","title":"Evision.Error.Code.cv_StsFilterOffsetErr/0","doc":"","ref":"Evision.Error.Code.html#cv_StsFilterOffsetErr/0"},{"type":"function","title":"Evision.Error.Code.cv_StsFilterStructContentErr/0","doc":"","ref":"Evision.Error.Code.html#cv_StsFilterStructContentErr/0"},{"type":"function","title":"Evision.Error.Code.cv_StsInplaceNotSupported/0","doc":"","ref":"Evision.Error.Code.html#cv_StsInplaceNotSupported/0"},{"type":"function","title":"Evision.Error.Code.cv_StsInternal/0","doc":"","ref":"Evision.Error.Code.html#cv_StsInternal/0"},{"type":"function","title":"Evision.Error.Code.cv_StsKernelStructContentErr/0","doc":"","ref":"Evision.Error.Code.html#cv_StsKernelStructContentErr/0"},{"type":"function","title":"Evision.Error.Code.cv_StsNoConv/0","doc":"","ref":"Evision.Error.Code.html#cv_StsNoConv/0"},{"type":"function","title":"Evision.Error.Code.cv_StsNoMem/0","doc":"","ref":"Evision.Error.Code.html#cv_StsNoMem/0"},{"type":"function","title":"Evision.Error.Code.cv_StsNotImplemented/0","doc":"","ref":"Evision.Error.Code.html#cv_StsNotImplemented/0"},{"type":"function","title":"Evision.Error.Code.cv_StsNullPtr/0","doc":"","ref":"Evision.Error.Code.html#cv_StsNullPtr/0"},{"type":"function","title":"Evision.Error.Code.cv_StsObjectNotFound/0","doc":"","ref":"Evision.Error.Code.html#cv_StsObjectNotFound/0"},{"type":"function","title":"Evision.Error.Code.cv_StsOk/0","doc":"","ref":"Evision.Error.Code.html#cv_StsOk/0"},{"type":"function","title":"Evision.Error.Code.cv_StsOutOfRange/0","doc":"","ref":"Evision.Error.Code.html#cv_StsOutOfRange/0"},{"type":"function","title":"Evision.Error.Code.cv_StsParseError/0","doc":"","ref":"Evision.Error.Code.html#cv_StsParseError/0"},{"type":"function","title":"Evision.Error.Code.cv_StsUnmatchedFormats/0","doc":"","ref":"Evision.Error.Code.html#cv_StsUnmatchedFormats/0"},{"type":"function","title":"Evision.Error.Code.cv_StsUnmatchedSizes/0","doc":"","ref":"Evision.Error.Code.html#cv_StsUnmatchedSizes/0"},{"type":"function","title":"Evision.Error.Code.cv_StsUnsupportedFormat/0","doc":"","ref":"Evision.Error.Code.html#cv_StsUnsupportedFormat/0"},{"type":"function","title":"Evision.Error.Code.cv_StsVecLengthErr/0","doc":"","ref":"Evision.Error.Code.html#cv_StsVecLengthErr/0"},{"type":"type","title":"Evision.Error.Code.enum/0","doc":"","ref":"Evision.Error.Code.html#t:enum/0"},{"type":"module","title":"Evision.Face","doc":"","ref":"Evision.Face.html"},{"type":"function","title":"Evision.Face.createFacemarkAAM/0","doc":"createFacemarkAAM\n##### Return\n- **retval**: `Evision.Face.Facemark.t()`\n\nPython prototype (for reference only):\n```python3\ncreateFacemarkAAM() -> retval\n```","ref":"Evision.Face.html#createFacemarkAAM/0"},{"type":"function","title":"Evision.Face.createFacemarkAAM/1","doc":"","ref":"Evision.Face.html#createFacemarkAAM/1"},{"type":"function","title":"Evision.Face.createFacemarkKazemi/0","doc":"createFacemarkKazemi\n##### Return\n- **retval**: `Evision.Face.Facemark.t()`\n\nPython prototype (for reference only):\n```python3\ncreateFacemarkKazemi() -> retval\n```","ref":"Evision.Face.html#createFacemarkKazemi/0"},{"type":"function","title":"Evision.Face.createFacemarkKazemi/1","doc":"","ref":"Evision.Face.html#createFacemarkKazemi/1"},{"type":"function","title":"Evision.Face.createFacemarkLBF/0","doc":"createFacemarkLBF\n##### Return\n- **retval**: `Evision.Face.Facemark.t()`\n\nPython prototype (for reference only):\n```python3\ncreateFacemarkLBF() -> retval\n```","ref":"Evision.Face.html#createFacemarkLBF/0"},{"type":"function","title":"Evision.Face.createFacemarkLBF/1","doc":"","ref":"Evision.Face.html#createFacemarkLBF/1"},{"type":"function","title":"Evision.Face.drawFacemarks/1","doc":"","ref":"Evision.Face.html#drawFacemarks/1"},{"type":"function","title":"Evision.Face.drawFacemarks/2","doc":"Utility to draw the detected facial landmark points\n\n##### Positional Arguments\n- **points**: `Evision.Mat`.\n\n  Contains the data of points which will be drawn.\n\n##### Keyword Arguments\n- **color**: `Evision.scalar()`.\n\n  The color of points in BGR format represented by cv::Scalar.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  The input image to be processed.\n\n Example of usage \n```\nstd::vector  faces;\nstd::vector  > landmarks;\nfacemark->getFaces(img, faces);\nfacemark->fit(img, faces, landmarks);\nfor(int j=0;j  image\n```","ref":"Evision.Face.html#drawFacemarks/2"},{"type":"function","title":"Evision.Face.drawFacemarks/3","doc":"Utility to draw the detected facial landmark points\n\n##### Positional Arguments\n- **points**: `Evision.Mat`.\n\n  Contains the data of points which will be drawn.\n\n##### Keyword Arguments\n- **color**: `Evision.scalar()`.\n\n  The color of points in BGR format represented by cv::Scalar.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  The input image to be processed.\n\n Example of usage \n```\nstd::vector  faces;\nstd::vector  > landmarks;\nfacemark->getFaces(img, faces);\nfacemark->fit(img, faces, landmarks);\nfor(int j=0;j  image\n```","ref":"Evision.Face.html#drawFacemarks/3"},{"type":"function","title":"Evision.Face.getFacesHAAR/1","doc":"","ref":"Evision.Face.html#getFacesHAAR/1"},{"type":"function","title":"Evision.Face.getFacesHAAR/2","doc":"Default face detector\nThis function is mainly utilized by the implementation of a Facemark Algorithm.\nEnd users are advised to use function Facemark::getFaces which can be manually defined\nand circumvented to the algorithm by Facemark::setFaceDetector.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  The input image to be processed.\n\n- **face_cascade_name**: `String`\n\n##### Return\n- **retval**: `bool`\n- **faces**: `Evision.Mat.t()`.\n\n  Output of the function which represent region of interest of the detected faces.\n  Each face is stored in cv::Rect container.\n\n Example of usage \n```\nstd::vector  faces;\nCParams params(\"haarcascade_frontalface_alt.xml\");\ncv::face::getFaces(frame, faces, &params);\nfor(int j=0;j  retval, faces\n```","ref":"Evision.Face.html#getFacesHAAR/2"},{"type":"function","title":"Evision.Face.getFacesHAAR/3","doc":"Default face detector\nThis function is mainly utilized by the implementation of a Facemark Algorithm.\nEnd users are advised to use function Facemark::getFaces which can be manually defined\nand circumvented to the algorithm by Facemark::setFaceDetector.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  The input image to be processed.\n\n- **face_cascade_name**: `String`\n\n##### Return\n- **retval**: `bool`\n- **faces**: `Evision.Mat.t()`.\n\n  Output of the function which represent region of interest of the detected faces.\n  Each face is stored in cv::Rect container.\n\n Example of usage \n```\nstd::vector  faces;\nCParams params(\"haarcascade_frontalface_alt.xml\");\ncv::face::getFaces(frame, faces, &params);\nfor(int j=0;j  retval, faces\n```","ref":"Evision.Face.html#getFacesHAAR/3"},{"type":"function","title":"Evision.Face.loadDatasetList/1","doc":"","ref":"Evision.Face.html#loadDatasetList/1"},{"type":"function","title":"Evision.Face.loadDatasetList/4","doc":"A utility to load list of paths to training image and annotation file.\n\n##### Positional Arguments\n- **imageList**: `String`.\n\n  The specified file contains paths to the training images.\n\n- **annotationList**: `String`.\n\n  The specified file contains paths to the training annotations.\n\n- **images**: `[String]`.\n\n  The loaded paths of training images.\n\n- **annotations**: `[String]`.\n\n  The loaded paths of annotation files.\n\n##### Return\n- **retval**: `bool`\n\nExample of usage:\n```\nString imageFiles = \"images_path.txt\";\nString ptsFiles = \"annotations_path.txt\";\nstd::vector  images_train;\nstd::vector  landmarks_train;\nloadDatasetList(imageFiles,ptsFiles,images_train,landmarks_train);\n```\n\nPython prototype (for reference only):\n```python3\nloadDatasetList(imageList, annotationList, images, annotations) -> retval\n```","ref":"Evision.Face.html#loadDatasetList/4"},{"type":"function","title":"Evision.Face.loadFacePoints/1","doc":"A utility to load facial landmark information from a given file.\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  The filename of file contains the facial landmarks data.\n\n##### Keyword Arguments\n- **offset**: `float`.\n\n  An offset value to adjust the loaded points.\n\n##### Return\n- **retval**: `bool`\n- **points**: `Evision.Mat.t()`.\n\n  The loaded facial landmark points.\n\n Example of usage \n```\nstd::vector  points;\nface::loadFacePoints(\"filename.txt\", points, 0.0f);\n```\nThe annotation file should follow the default format which is\n```\nversion: 1\nn_points:  68\n{\n212.716603 499.771793\n230.232816 566.290071\n...\n}\n```\nwhere n_points is the number of points considered\nand each point is represented as its position in x and y.\n\nPython prototype (for reference only):\n```python3\nloadFacePoints(filename[, points[, offset]]) -> retval, points\n```","ref":"Evision.Face.html#loadFacePoints/1"},{"type":"function","title":"Evision.Face.loadFacePoints/2","doc":"A utility to load facial landmark information from a given file.\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  The filename of file contains the facial landmarks data.\n\n##### Keyword Arguments\n- **offset**: `float`.\n\n  An offset value to adjust the loaded points.\n\n##### Return\n- **retval**: `bool`\n- **points**: `Evision.Mat.t()`.\n\n  The loaded facial landmark points.\n\n Example of usage \n```\nstd::vector  points;\nface::loadFacePoints(\"filename.txt\", points, 0.0f);\n```\nThe annotation file should follow the default format which is\n```\nversion: 1\nn_points:  68\n{\n212.716603 499.771793\n230.232816 566.290071\n...\n}\n```\nwhere n_points is the number of points considered\nand each point is represented as its position in x and y.\n\nPython prototype (for reference only):\n```python3\nloadFacePoints(filename[, points[, offset]]) -> retval, points\n```","ref":"Evision.Face.html#loadFacePoints/2"},{"type":"function","title":"Evision.Face.loadTrainingData/1","doc":"","ref":"Evision.Face.html#loadTrainingData/1"},{"type":"function","title":"Evision.Face.loadTrainingData/2","doc":"A utility to load facial landmark dataset from a single file.\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  The filename of a file that contains the dataset information.\n  Each line contains the filename of an image followed by\n  pairs of x and y values of facial landmarks points separated by a space.\n  Example\n\n- **images**: `[String]`.\n\n  A vector where each element represent the filename of image in the dataset.\n  Images are not loaded by default to save the memory.\n\n##### Keyword Arguments\n- **delim**: `char`.\n\n  Delimiter between each element, the default value is a whitespace.\n\n- **offset**: `float`.\n\n  An offset value to adjust the loaded points.\n\n##### Return\n- **retval**: `bool`\n- **facePoints**: `Evision.Mat.t()`.\n\n  The loaded landmark points for all training data.\n\n```\n/home/user/ibug/image_003_1.jpg 336.820955 240.864510 334.238298 260.922709 335.266918 ...\n/home/user/ibug/image_005_1.jpg 376.158428 230.845712 376.736984 254.924635 383.265403 ...\n```\n\n Example of usage \n```\ncv::String imageFiles = \"../data/images_train.txt\";\ncv::String ptsFiles = \"../data/points_train.txt\";\nstd::vector  images;\nstd::vector  > facePoints;\nloadTrainingData(imageFiles, ptsFiles, images, facePoints, 0.0f);\n```\n\nPython prototype (for reference only):\n```python3\nloadTrainingData(filename, images[, facePoints[, delim[, offset]]]) -> retval, facePoints\n```","ref":"Evision.Face.html#loadTrainingData/2"},{"type":"function","title":"Evision.Face.loadTrainingData/3","doc":"#### Variant 1:\nThis function extracts the data for training from .txt files which contains the corresponding image name and landmarks.\nThe first file in each file should give the path of the image whose\nlandmarks are being described in the file. Then in the subsequent\nlines there should be coordinates of the landmarks in the image\ni.e each line should be of the form x,y\nwhere x represents the x coordinate of the landmark and y represents\nthe y coordinate of the landmark.\n\n##### Positional Arguments\n- **filename**: `[String]`.\n\n  A vector of type cv::String containing name of the .txt files.\n\n- **trainlandmarks**: `[[Point2f]]`.\n\n  A vector of type cv::Point2f that would store shape or landmarks of all images.\n\n- **trainimages**: `[String]`.\n\n  A vector of type cv::String which stores the name of images whose landmarks are tracked\n\n##### Return\n- **retval**: `bool`\n\nFor reference you can see the files as provided in the\n HELEN dataset \n@returns A boolean value. It returns true when it reads the data successfully and false otherwise\n\nPython prototype (for reference only):\n```python3\nloadTrainingData(filename, trainlandmarks, trainimages) -> retval\n```\n#### Variant 2:\nA utility to load facial landmark information from the dataset.\n\n##### Positional Arguments\n- **imageList**: `String`.\n\n  A file contains the list of image filenames in the training dataset.\n\n- **groundTruth**: `String`.\n\n  A file contains the list of filenames\n  where the landmarks points information are stored.\n  The content in each file should follow the standard format (see face::loadFacePoints).\n\n- **images**: `[String]`.\n\n  A vector where each element represent the filename of image in the dataset.\n  Images are not loaded by default to save the memory.\n\n##### Keyword Arguments\n- **offset**: `float`.\n\n  An offset value to adjust the loaded points.\n\n##### Return\n- **retval**: `bool`\n- **facePoints**: `Evision.Mat.t()`.\n\n  The loaded landmark points for all training data.\n\n Example of usage \n```\ncv::String imageFiles = \"../data/images_train.txt\";\ncv::String ptsFiles = \"../data/points_train.txt\";\nstd::vector  images;\nstd::vector  > facePoints;\nloadTrainingData(imageFiles, ptsFiles, images, facePoints, 0.0f);\n```\nexample of content in the images_train.txt\n```\n/home/user/ibug/image_003_1.jpg\n/home/user/ibug/image_004_1.jpg\n/home/user/ibug/image_005_1.jpg\n/home/user/ibug/image_006.jpg\n```\nexample of content in the points_train.txt\n```\n/home/user/ibug/image_003_1.pts\n/home/user/ibug/image_004_1.pts\n/home/user/ibug/image_005_1.pts\n/home/user/ibug/image_006.pts\n```\n\nPython prototype (for reference only):\n```python3\nloadTrainingData(imageList, groundTruth, images[, facePoints[, offset]]) -> retval, facePoints\n```\n#### Variant 3:\nA utility to load facial landmark dataset from a single file.\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  The filename of a file that contains the dataset information.\n  Each line contains the filename of an image followed by\n  pairs of x and y values of facial landmarks points separated by a space.\n  Example\n\n- **images**: `[String]`.\n\n  A vector where each element represent the filename of image in the dataset.\n  Images are not loaded by default to save the memory.\n\n##### Keyword Arguments\n- **delim**: `char`.\n\n  Delimiter between each element, the default value is a whitespace.\n\n- **offset**: `float`.\n\n  An offset value to adjust the loaded points.\n\n##### Return\n- **retval**: `bool`\n- **facePoints**: `Evision.Mat.t()`.\n\n  The loaded landmark points for all training data.\n\n```\n/home/user/ibug/image_003_1.jpg 336.820955 240.864510 334.238298 260.922709 335.266918 ...\n/home/user/ibug/image_005_1.jpg 376.158428 230.845712 376.736984 254.924635 383.265403 ...\n```\n\n Example of usage \n```\ncv::String imageFiles = \"../data/images_train.txt\";\ncv::String ptsFiles = \"../data/points_train.txt\";\nstd::vector  images;\nstd::vector  > facePoints;\nloadTrainingData(imageFiles, ptsFiles, images, facePoints, 0.0f);\n```\n\nPython prototype (for reference only):\n```python3\nloadTrainingData(filename, images[, facePoints[, delim[, offset]]]) -> retval, facePoints\n```","ref":"Evision.Face.html#loadTrainingData/3"},{"type":"function","title":"Evision.Face.loadTrainingData/4","doc":"A utility to load facial landmark information from the dataset.\n\n##### Positional Arguments\n- **imageList**: `String`.\n\n  A file contains the list of image filenames in the training dataset.\n\n- **groundTruth**: `String`.\n\n  A file contains the list of filenames\n  where the landmarks points information are stored.\n  The content in each file should follow the standard format (see face::loadFacePoints).\n\n- **images**: `[String]`.\n\n  A vector where each element represent the filename of image in the dataset.\n  Images are not loaded by default to save the memory.\n\n##### Keyword Arguments\n- **offset**: `float`.\n\n  An offset value to adjust the loaded points.\n\n##### Return\n- **retval**: `bool`\n- **facePoints**: `Evision.Mat.t()`.\n\n  The loaded landmark points for all training data.\n\n Example of usage \n```\ncv::String imageFiles = \"../data/images_train.txt\";\ncv::String ptsFiles = \"../data/points_train.txt\";\nstd::vector  images;\nstd::vector  > facePoints;\nloadTrainingData(imageFiles, ptsFiles, images, facePoints, 0.0f);\n```\nexample of content in the images_train.txt\n```\n/home/user/ibug/image_003_1.jpg\n/home/user/ibug/image_004_1.jpg\n/home/user/ibug/image_005_1.jpg\n/home/user/ibug/image_006.jpg\n```\nexample of content in the points_train.txt\n```\n/home/user/ibug/image_003_1.pts\n/home/user/ibug/image_004_1.pts\n/home/user/ibug/image_005_1.pts\n/home/user/ibug/image_006.pts\n```\n\nPython prototype (for reference only):\n```python3\nloadTrainingData(imageList, groundTruth, images[, facePoints[, offset]]) -> retval, facePoints\n```","ref":"Evision.Face.html#loadTrainingData/4"},{"type":"type","title":"Evision.Face.t/0","doc":"Type that represents an `Face` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Face.html#t:t/0"},{"type":"module","title":"Evision.Face.BIF","doc":"","ref":"Evision.Face.BIF.html"},{"type":"function","title":"Evision.Face.BIF.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Face.BIF.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Face.BIF.html#clear/1"},{"type":"function","title":"Evision.Face.BIF.compute/1","doc":"","ref":"Evision.Face.BIF.html#compute/1"},{"type":"function","title":"Evision.Face.BIF.compute/2","doc":"compute\n\n##### Positional Arguments\n- **self**: `Evision.Face.BIF.t()`\n- **image**: `Evision.Mat`.\n\n  Input image (CV_32FC1).\n\n##### Return\n- **features**: `Evision.Mat.t()`.\n\n  Feature vector (CV_32FC1).\n\nComputes features sby input image.\n\nPython prototype (for reference only):\n```python3\ncompute(image[, features]) -> features\n```","ref":"Evision.Face.BIF.html#compute/2"},{"type":"function","title":"Evision.Face.BIF.compute/3","doc":"compute\n\n##### Positional Arguments\n- **self**: `Evision.Face.BIF.t()`\n- **image**: `Evision.Mat`.\n\n  Input image (CV_32FC1).\n\n##### Return\n- **features**: `Evision.Mat.t()`.\n\n  Feature vector (CV_32FC1).\n\nComputes features sby input image.\n\nPython prototype (for reference only):\n```python3\ncompute(image[, features]) -> features\n```","ref":"Evision.Face.BIF.html#compute/3"},{"type":"function","title":"Evision.Face.BIF.create/0","doc":"create\n##### Keyword Arguments\n- **num_bands**: `integer()`.\n\n  The number of filter bands (<=8) used for computing BIF.\n\n- **num_rotations**: `integer()`.\n\n  The number of image rotations for computing BIF.\n\n##### Return\n- **retval**: `BIF`\n\n@returns Object for computing BIF.\n\nPython prototype (for reference only):\n```python3\ncreate([, num_bands[, num_rotations]]) -> retval\n```","ref":"Evision.Face.BIF.html#create/0"},{"type":"function","title":"Evision.Face.BIF.create/1","doc":"create\n##### Keyword Arguments\n- **num_bands**: `integer()`.\n\n  The number of filter bands (<=8) used for computing BIF.\n\n- **num_rotations**: `integer()`.\n\n  The number of image rotations for computing BIF.\n\n##### Return\n- **retval**: `BIF`\n\n@returns Object for computing BIF.\n\nPython prototype (for reference only):\n```python3\ncreate([, num_bands[, num_rotations]]) -> retval\n```","ref":"Evision.Face.BIF.html#create/1"},{"type":"function","title":"Evision.Face.BIF.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Face.BIF.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Face.BIF.html#empty/1"},{"type":"function","title":"Evision.Face.BIF.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Face.BIF.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Face.BIF.html#getDefaultName/1"},{"type":"function","title":"Evision.Face.BIF.getNumBands/1","doc":"getNumBands\n\n##### Positional Arguments\n- **self**: `Evision.Face.BIF.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@returns The number of filter bands used for computing BIF.\n\nPython prototype (for reference only):\n```python3\ngetNumBands() -> retval\n```","ref":"Evision.Face.BIF.html#getNumBands/1"},{"type":"function","title":"Evision.Face.BIF.getNumRotations/1","doc":"getNumRotations\n\n##### Positional Arguments\n- **self**: `Evision.Face.BIF.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@returns The number of image rotations.\n\nPython prototype (for reference only):\n```python3\ngetNumRotations() -> retval\n```","ref":"Evision.Face.BIF.html#getNumRotations/1"},{"type":"function","title":"Evision.Face.BIF.read/1","doc":"","ref":"Evision.Face.BIF.html#read/1"},{"type":"function","title":"Evision.Face.BIF.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Face.BIF.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Face.BIF.html#read/2"},{"type":"function","title":"Evision.Face.BIF.save/1","doc":"","ref":"Evision.Face.BIF.html#save/1"},{"type":"function","title":"Evision.Face.BIF.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Face.BIF.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Face.BIF.html#save/2"},{"type":"function","title":"Evision.Face.BIF.write/1","doc":"","ref":"Evision.Face.BIF.html#write/1"},{"type":"function","title":"Evision.Face.BIF.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Face.BIF.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Face.BIF.html#write/2"},{"type":"function","title":"Evision.Face.BIF.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Face.BIF.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Face.BIF.html#write/3"},{"type":"type","title":"Evision.Face.BIF.t/0","doc":"Type that represents an `Face.BIF` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Face.BIF.html#t:t/0"},{"type":"module","title":"Evision.Face.BasicFaceRecognizer","doc":"","ref":"Evision.Face.BasicFaceRecognizer.html"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Face.BasicFaceRecognizer.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Face.BasicFaceRecognizer.html#clear/1"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Face.BasicFaceRecognizer.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Face.BasicFaceRecognizer.html#empty/1"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Face.BasicFaceRecognizer.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Face.BasicFaceRecognizer.html#getDefaultName/1"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.getEigenValues/1","doc":"getEigenValues\n\n##### Positional Arguments\n- **self**: `Evision.Face.BasicFaceRecognizer.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetEigenValues() -> retval\n```","ref":"Evision.Face.BasicFaceRecognizer.html#getEigenValues/1"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.getEigenVectors/1","doc":"getEigenVectors\n\n##### Positional Arguments\n- **self**: `Evision.Face.BasicFaceRecognizer.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetEigenVectors() -> retval\n```","ref":"Evision.Face.BasicFaceRecognizer.html#getEigenVectors/1"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.getLabelInfo/1","doc":"","ref":"Evision.Face.BasicFaceRecognizer.html#getLabelInfo/1"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.getLabelInfo/2","doc":"Gets string information by label.\n\n##### Positional Arguments\n- **self**: `Evision.Face.BasicFaceRecognizer.t()`\n- **label**: `integer()`\n\n##### Return\n- **retval**: `String`\n\nIf an unknown label id is provided or there is no label information associated with the specified\nlabel id the method returns an empty string.\n\nPython prototype (for reference only):\n```python3\ngetLabelInfo(label) -> retval\n```","ref":"Evision.Face.BasicFaceRecognizer.html#getLabelInfo/2"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.getLabels/1","doc":"getLabels\n\n##### Positional Arguments\n- **self**: `Evision.Face.BasicFaceRecognizer.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetLabels() -> retval\n```","ref":"Evision.Face.BasicFaceRecognizer.html#getLabels/1"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.getLabelsByString/1","doc":"","ref":"Evision.Face.BasicFaceRecognizer.html#getLabelsByString/1"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.getLabelsByString/2","doc":"Gets vector of labels by string.\n\n##### Positional Arguments\n- **self**: `Evision.Face.BasicFaceRecognizer.t()`\n- **str**: `String`\n\n##### Return\n- **retval**: `[integer()]`\n\nThe function searches for the labels containing the specified sub-string in the associated string\ninfo.\n\nPython prototype (for reference only):\n```python3\ngetLabelsByString(str) -> retval\n```","ref":"Evision.Face.BasicFaceRecognizer.html#getLabelsByString/2"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.getMean/1","doc":"getMean\n\n##### Positional Arguments\n- **self**: `Evision.Face.BasicFaceRecognizer.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetMean() -> retval\n```","ref":"Evision.Face.BasicFaceRecognizer.html#getMean/1"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.getNumComponents/1","doc":"getNumComponents\n\n##### Positional Arguments\n- **self**: `Evision.Face.BasicFaceRecognizer.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setNumComponents/2`\n\nPython prototype (for reference only):\n```python3\ngetNumComponents() -> retval\n```","ref":"Evision.Face.BasicFaceRecognizer.html#getNumComponents/1"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.getProjections/1","doc":"getProjections\n\n##### Positional Arguments\n- **self**: `Evision.Face.BasicFaceRecognizer.t()`\n\n##### Return\n- **retval**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\ngetProjections() -> retval\n```","ref":"Evision.Face.BasicFaceRecognizer.html#getProjections/1"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.getThreshold/1","doc":"getThreshold\n\n##### Positional Arguments\n- **self**: `Evision.Face.BasicFaceRecognizer.t()`\n\n##### Return\n- **retval**: `double`\n\n@see `setThreshold/2`\n\nPython prototype (for reference only):\n```python3\ngetThreshold() -> retval\n```","ref":"Evision.Face.BasicFaceRecognizer.html#getThreshold/1"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.predict/1","doc":"","ref":"Evision.Face.BasicFaceRecognizer.html#predict/1"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.predict/2","doc":"Predicts a label and associated confidence (e.g. distance) for a given input image.\n\n##### Positional Arguments\n- **self**: `Evision.Face.BasicFaceRecognizer.t()`\n- **src**: `Evision.Mat`.\n\n  Sample image to get a prediction from.\n\n##### Return\n- **label**: `integer()`.\n\n  The predicted label for the given image.\n\n- **confidence**: `double`.\n\n  Associated confidence (e.g. distance) for the predicted label.\n\nThe suffix const means that prediction does not affect the internal model state, so the method can\nbe safely called from within different threads.\nThe following example shows how to get a prediction from a trained model:\n```\nusing namespace cv;\n// Do your initialization here (create the cv::FaceRecognizer model) ...\n// ...\n// Read in a sample image:\nMat img = imread(\"person1/3.jpg\", IMREAD_GRAYSCALE);\n// And get a prediction from the cv::FaceRecognizer:\nint predicted = model->predict(img);\n```\nOr to get a prediction and the associated confidence (e.g. distance):\n```\nusing namespace cv;\n// Do your initialization here (create the cv::FaceRecognizer model) ...\n// ...\nMat img = imread(\"person1/3.jpg\", IMREAD_GRAYSCALE);\n// Some variables for the predicted label and associated confidence (e.g. distance):\nint predicted_label = -1;\ndouble predicted_confidence = 0.0;\n// Get the prediction and associated confidence from the model\nmodel->predict(img, predicted_label, predicted_confidence);\n```\n\nPython prototype (for reference only):\n```python3\npredict(src) -> label, confidence\n```","ref":"Evision.Face.BasicFaceRecognizer.html#predict/2"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.predict_collect/1","doc":"","ref":"Evision.Face.BasicFaceRecognizer.html#predict_collect/1"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.predict_collect/3","doc":"- if implemented - send all result of prediction to collector that can be used for somehow custom result handling\n\n##### Positional Arguments\n- **self**: `Evision.Face.BasicFaceRecognizer.t()`\n- **src**: `Evision.Mat`.\n\n  Sample image to get a prediction from.\n\n- **collector**: `PredictCollector`.\n\n  User-defined collector object that accepts all results\n\nTo implement this method u just have to do same internal cycle as in predict(InputArray src, CV_OUT int &label, CV_OUT double &confidence) but\nnot try to get \"best@ result, just resend it to caller side with given collector\n\nPython prototype (for reference only):\n```python3\npredict_collect(src, collector) -> None\n```","ref":"Evision.Face.BasicFaceRecognizer.html#predict_collect/3"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.predict_label/1","doc":"","ref":"Evision.Face.BasicFaceRecognizer.html#predict_label/1"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.predict_label/2","doc":"predict_label\n\n##### Positional Arguments\n- **self**: `Evision.Face.BasicFaceRecognizer.t()`\n- **src**: `Evision.Mat`\n\n##### Return\n- **retval**: `integer()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\npredict_label(src) -> retval\n```","ref":"Evision.Face.BasicFaceRecognizer.html#predict_label/2"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.read/1","doc":"","ref":"Evision.Face.BasicFaceRecognizer.html#read/1"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.read/2","doc":"Loads a FaceRecognizer and its model state.\n\n##### Positional Arguments\n- **self**: `Evision.Face.BasicFaceRecognizer.t()`\n- **filename**: `String`\n\nLoads a persisted model and state from a given XML or YAML file . Every FaceRecognizer has to\noverwrite FaceRecognizer::load(FileStorage& fs) to enable loading the model state.\nFaceRecognizer::load(FileStorage& fs) in turn gets called by\nFaceRecognizer::load(const String& filename), to ease saving a model.\n\nPython prototype (for reference only):\n```python3\nread(filename) -> None\n```","ref":"Evision.Face.BasicFaceRecognizer.html#read/2"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.save/1","doc":"","ref":"Evision.Face.BasicFaceRecognizer.html#save/1"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Face.BasicFaceRecognizer.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Face.BasicFaceRecognizer.html#save/2"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.setLabelInfo/1","doc":"","ref":"Evision.Face.BasicFaceRecognizer.html#setLabelInfo/1"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.setLabelInfo/3","doc":"Sets string info for the specified model's label.\n\n##### Positional Arguments\n- **self**: `Evision.Face.BasicFaceRecognizer.t()`\n- **label**: `integer()`\n- **strInfo**: `String`\n\nThe string info is replaced by the provided value if it was set before for the specified label.\n\nPython prototype (for reference only):\n```python3\nsetLabelInfo(label, strInfo) -> None\n```","ref":"Evision.Face.BasicFaceRecognizer.html#setLabelInfo/3"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.setNumComponents/1","doc":"","ref":"Evision.Face.BasicFaceRecognizer.html#setNumComponents/1"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.setNumComponents/2","doc":"setNumComponents\n\n##### Positional Arguments\n- **self**: `Evision.Face.BasicFaceRecognizer.t()`\n- **val**: `integer()`\n\n@see `getNumComponents/1`\n\nPython prototype (for reference only):\n```python3\nsetNumComponents(val) -> None\n```","ref":"Evision.Face.BasicFaceRecognizer.html#setNumComponents/2"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.setThreshold/1","doc":"","ref":"Evision.Face.BasicFaceRecognizer.html#setThreshold/1"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.setThreshold/2","doc":"setThreshold\n\n##### Positional Arguments\n- **self**: `Evision.Face.BasicFaceRecognizer.t()`\n- **val**: `double`\n\n@see `getThreshold/1`\n\nPython prototype (for reference only):\n```python3\nsetThreshold(val) -> None\n```","ref":"Evision.Face.BasicFaceRecognizer.html#setThreshold/2"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.train/1","doc":"","ref":"Evision.Face.BasicFaceRecognizer.html#train/1"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.train/3","doc":"Trains a FaceRecognizer with given data and associated labels.\n\n##### Positional Arguments\n- **self**: `Evision.Face.BasicFaceRecognizer.t()`\n- **src**: `[Evision.Mat]`.\n\n  The training images, that means the faces you want to learn. The data has to be\n  given as a vector\\ .\n\n- **labels**: `Evision.Mat`.\n\n  The labels corresponding to the images have to be given either as a vector\\ \n  or a Mat of type CV_32SC1.\n\nThe following source code snippet shows you how to learn a Fisherfaces model on a given set of\nimages. The images are read with imread and pushed into a std::vector\\ . The labels of each\nimage are stored within a std::vector\\  (you could also use a Mat of type CV_32SC1). Think of\nthe label as the subject (the person) this image belongs to, so same subjects (persons) should have\nthe same label. For the available FaceRecognizer you don't have to pay any attention to the order of\nthe labels, just make sure same persons have the same label:\n```\n// holds images and labels\nvector  images;\nvector  labels;\n// using Mat of type CV_32SC1\n// Mat labels(number_of_samples, 1, CV_32SC1);\n// images for first person\nimages.push_back(imread(\"person0/0.jpg\", IMREAD_GRAYSCALE)); labels.push_back(0);\nimages.push_back(imread(\"person0/1.jpg\", IMREAD_GRAYSCALE)); labels.push_back(0);\nimages.push_back(imread(\"person0/2.jpg\", IMREAD_GRAYSCALE)); labels.push_back(0);\n// images for second person\nimages.push_back(imread(\"person1/0.jpg\", IMREAD_GRAYSCALE)); labels.push_back(1);\nimages.push_back(imread(\"person1/1.jpg\", IMREAD_GRAYSCALE)); labels.push_back(1);\nimages.push_back(imread(\"person1/2.jpg\", IMREAD_GRAYSCALE)); labels.push_back(1);\n```\nNow that you have read some images, we can create a new FaceRecognizer. In this example I'll create\na Fisherfaces model and decide to keep all of the possible Fisherfaces:\n```\n// Create a new Fisherfaces model and retain all available Fisherfaces,\n// this is the most common usage of this specific FaceRecognizer:\n//\nPtr  model =  FisherFaceRecognizer::create();\n```\nAnd finally train it on the given dataset (the face images and labels):\n```\n// This is the common interface to train all of the available cv::FaceRecognizer\n// implementations:\n//\nmodel->train(images, labels);\n```\n\nPython prototype (for reference only):\n```python3\ntrain(src, labels) -> None\n```","ref":"Evision.Face.BasicFaceRecognizer.html#train/3"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.update/1","doc":"","ref":"Evision.Face.BasicFaceRecognizer.html#update/1"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.update/3","doc":"Updates a FaceRecognizer with given data and associated labels.\n\n##### Positional Arguments\n- **self**: `Evision.Face.BasicFaceRecognizer.t()`\n- **src**: `[Evision.Mat]`.\n\n  The training images, that means the faces you want to learn. The data has to be given\n  as a vector\\ .\n\n- **labels**: `Evision.Mat`.\n\n  The labels corresponding to the images have to be given either as a vector\\  or\n  a Mat of type CV_32SC1.\n\nThis method updates a (probably trained) FaceRecognizer, but only if the algorithm supports it. The\nLocal Binary Patterns Histograms (LBPH) recognizer (see createLBPHFaceRecognizer) can be updated.\nFor the Eigenfaces and Fisherfaces method, this is algorithmically not possible and you have to\nre-estimate the model with FaceRecognizer::train. In any case, a call to train empties the existing\nmodel and learns a new model, while update does not delete any model data.\n```\n// Create a new LBPH model (it can be updated) and use the default parameters,\n// this is the most common usage of this specific FaceRecognizer:\n//\nPtr  model =  LBPHFaceRecognizer::create();\n// This is the common interface to train all of the available cv::FaceRecognizer\n// implementations:\n//\nmodel->train(images, labels);\n// Some containers to hold new image:\nvector  newImages;\nvector  newLabels;\n// You should add some images to the containers:\n//\n// ...\n//\n// Now updating the model is as easy as calling:\nmodel->update(newImages,newLabels);\n// This will preserve the old model data and extend the existing model\n// with the new features extracted from newImages!\n```\nCalling update on an Eigenfaces model (see EigenFaceRecognizer::create), which doesn't support\nupdating, will throw an error similar to:\n```\nOpenCV Error: The function/feature is not implemented (This FaceRecognizer (FaceRecognizer.Eigenfaces) does not support updating, you have to use FaceRecognizer::train to update it.) in update, file /home/philipp/git/opencv/modules/contrib/src/facerec.cpp, line 305\nterminate called after throwing an instance of 'cv::Exception'\n```\n**Note**: The FaceRecognizer does not store your training images, because this would be very\nmemory intense and it's not the responsibility of te FaceRecognizer to do so. The caller is\nresponsible for maintaining the dataset, he want to work with.\n\nPython prototype (for reference only):\n```python3\nupdate(src, labels) -> None\n```","ref":"Evision.Face.BasicFaceRecognizer.html#update/3"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.write/1","doc":"","ref":"Evision.Face.BasicFaceRecognizer.html#write/1"},{"type":"function","title":"Evision.Face.BasicFaceRecognizer.write/2","doc":"Saves a FaceRecognizer and its model state.\n\n##### Positional Arguments\n- **self**: `Evision.Face.BasicFaceRecognizer.t()`\n- **filename**: `String`.\n\n  The filename to store this FaceRecognizer to (either XML/YAML).\n\nSaves this model to a given filename, either as XML or YAML.\n\nEvery FaceRecognizer overwrites FaceRecognizer::save(FileStorage& fs) to save the internal model\nstate. FaceRecognizer::save(const String& filename) saves the state of a model to the given\nfilename.\nThe suffix const means that prediction does not affect the internal model state, so the method can\nbe safely called from within different threads.\n\nPython prototype (for reference only):\n```python3\nwrite(filename) -> None\n```","ref":"Evision.Face.BasicFaceRecognizer.html#write/2"},{"type":"type","title":"Evision.Face.BasicFaceRecognizer.t/0","doc":"Type that represents an `Face.BasicFaceRecognizer` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Face.BasicFaceRecognizer.html#t:t/0"},{"type":"module","title":"Evision.Face.EigenFaceRecognizer","doc":"","ref":"Evision.Face.EigenFaceRecognizer.html"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Face.EigenFaceRecognizer.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Face.EigenFaceRecognizer.html#clear/1"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.create/0","doc":"create\n##### Keyword Arguments\n- **num_components**: `integer()`.\n\n  The number of components (read: Eigenfaces) kept for this Principal\n  Component Analysis. As a hint: There's no rule how many components (read: Eigenfaces) should be\n  kept for good reconstruction capabilities. It is based on your input data, so experiment with the\n  number. Keeping 80 components should almost always be sufficient.\n\n- **threshold**: `double`.\n\n  The threshold applied in the prediction.\n\n##### Return\n- **retval**: `EigenFaceRecognizer`","ref":"Evision.Face.EigenFaceRecognizer.html#create/0"},{"type":"function","title":"Notes: - Evision.Face.EigenFaceRecognizer.create/0","doc":"- Training and prediction must be done on grayscale images, use cvtColor to convert between the\n  color spaces.\n\n- **THE EIGENFACES METHOD MAKES THE ASSUMPTION, THAT THE TRAINING AND TEST IMAGES ARE OF EQUAL\n  SIZE.** (caps-lock, because I got so many mails asking for this). You have to make sure your\n  input data has the correct shape, else a meaningful exception is thrown. Use resize to resize\n  the images.\n\n- This model does not support updating.","ref":"Evision.Face.EigenFaceRecognizer.html#create/0-notes"},{"type":"function","title":"Model internal data: - Evision.Face.EigenFaceRecognizer.create/0","doc":"- num_components see EigenFaceRecognizer::create.\n- threshold see EigenFaceRecognizer::create.\n- eigenvalues The eigenvalues for this Principal Component Analysis (ordered descending).\n- eigenvectors The eigenvectors for this Principal Component Analysis (ordered by their\n  eigenvalue).\n\n- mean The sample mean calculated from the training data.\n- projections The projections of the training data.\n- labels The threshold applied in the prediction. If the distance to the nearest neighbor is\n  larger than the threshold, this method returns -1.\n\nPython prototype (for reference only):\n```python3\ncreate([, num_components[, threshold]]) -> retval\n```","ref":"Evision.Face.EigenFaceRecognizer.html#create/0-model-internal-data"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.create/1","doc":"create\n##### Keyword Arguments\n- **num_components**: `integer()`.\n\n  The number of components (read: Eigenfaces) kept for this Principal\n  Component Analysis. As a hint: There's no rule how many components (read: Eigenfaces) should be\n  kept for good reconstruction capabilities. It is based on your input data, so experiment with the\n  number. Keeping 80 components should almost always be sufficient.\n\n- **threshold**: `double`.\n\n  The threshold applied in the prediction.\n\n##### Return\n- **retval**: `EigenFaceRecognizer`","ref":"Evision.Face.EigenFaceRecognizer.html#create/1"},{"type":"function","title":"Notes: - Evision.Face.EigenFaceRecognizer.create/1","doc":"- Training and prediction must be done on grayscale images, use cvtColor to convert between the\n  color spaces.\n\n- **THE EIGENFACES METHOD MAKES THE ASSUMPTION, THAT THE TRAINING AND TEST IMAGES ARE OF EQUAL\n  SIZE.** (caps-lock, because I got so many mails asking for this). You have to make sure your\n  input data has the correct shape, else a meaningful exception is thrown. Use resize to resize\n  the images.\n\n- This model does not support updating.","ref":"Evision.Face.EigenFaceRecognizer.html#create/1-notes"},{"type":"function","title":"Model internal data: - Evision.Face.EigenFaceRecognizer.create/1","doc":"- num_components see EigenFaceRecognizer::create.\n- threshold see EigenFaceRecognizer::create.\n- eigenvalues The eigenvalues for this Principal Component Analysis (ordered descending).\n- eigenvectors The eigenvectors for this Principal Component Analysis (ordered by their\n  eigenvalue).\n\n- mean The sample mean calculated from the training data.\n- projections The projections of the training data.\n- labels The threshold applied in the prediction. If the distance to the nearest neighbor is\n  larger than the threshold, this method returns -1.\n\nPython prototype (for reference only):\n```python3\ncreate([, num_components[, threshold]]) -> retval\n```","ref":"Evision.Face.EigenFaceRecognizer.html#create/1-model-internal-data"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Face.EigenFaceRecognizer.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Face.EigenFaceRecognizer.html#empty/1"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Face.EigenFaceRecognizer.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Face.EigenFaceRecognizer.html#getDefaultName/1"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.getEigenValues/1","doc":"getEigenValues\n\n##### Positional Arguments\n- **self**: `Evision.Face.EigenFaceRecognizer.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetEigenValues() -> retval\n```","ref":"Evision.Face.EigenFaceRecognizer.html#getEigenValues/1"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.getEigenVectors/1","doc":"getEigenVectors\n\n##### Positional Arguments\n- **self**: `Evision.Face.EigenFaceRecognizer.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetEigenVectors() -> retval\n```","ref":"Evision.Face.EigenFaceRecognizer.html#getEigenVectors/1"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.getLabelInfo/1","doc":"","ref":"Evision.Face.EigenFaceRecognizer.html#getLabelInfo/1"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.getLabelInfo/2","doc":"Gets string information by label.\n\n##### Positional Arguments\n- **self**: `Evision.Face.EigenFaceRecognizer.t()`\n- **label**: `integer()`\n\n##### Return\n- **retval**: `String`\n\nIf an unknown label id is provided or there is no label information associated with the specified\nlabel id the method returns an empty string.\n\nPython prototype (for reference only):\n```python3\ngetLabelInfo(label) -> retval\n```","ref":"Evision.Face.EigenFaceRecognizer.html#getLabelInfo/2"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.getLabels/1","doc":"getLabels\n\n##### Positional Arguments\n- **self**: `Evision.Face.EigenFaceRecognizer.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetLabels() -> retval\n```","ref":"Evision.Face.EigenFaceRecognizer.html#getLabels/1"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.getLabelsByString/1","doc":"","ref":"Evision.Face.EigenFaceRecognizer.html#getLabelsByString/1"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.getLabelsByString/2","doc":"Gets vector of labels by string.\n\n##### Positional Arguments\n- **self**: `Evision.Face.EigenFaceRecognizer.t()`\n- **str**: `String`\n\n##### Return\n- **retval**: `[integer()]`\n\nThe function searches for the labels containing the specified sub-string in the associated string\ninfo.\n\nPython prototype (for reference only):\n```python3\ngetLabelsByString(str) -> retval\n```","ref":"Evision.Face.EigenFaceRecognizer.html#getLabelsByString/2"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.getMean/1","doc":"getMean\n\n##### Positional Arguments\n- **self**: `Evision.Face.EigenFaceRecognizer.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetMean() -> retval\n```","ref":"Evision.Face.EigenFaceRecognizer.html#getMean/1"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.getNumComponents/1","doc":"getNumComponents\n\n##### Positional Arguments\n- **self**: `Evision.Face.EigenFaceRecognizer.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setNumComponents/2`\n\nPython prototype (for reference only):\n```python3\ngetNumComponents() -> retval\n```","ref":"Evision.Face.EigenFaceRecognizer.html#getNumComponents/1"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.getProjections/1","doc":"getProjections\n\n##### Positional Arguments\n- **self**: `Evision.Face.EigenFaceRecognizer.t()`\n\n##### Return\n- **retval**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\ngetProjections() -> retval\n```","ref":"Evision.Face.EigenFaceRecognizer.html#getProjections/1"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.getThreshold/1","doc":"getThreshold\n\n##### Positional Arguments\n- **self**: `Evision.Face.EigenFaceRecognizer.t()`\n\n##### Return\n- **retval**: `double`\n\n@see `setThreshold/2`\n\nPython prototype (for reference only):\n```python3\ngetThreshold() -> retval\n```","ref":"Evision.Face.EigenFaceRecognizer.html#getThreshold/1"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.predict/1","doc":"","ref":"Evision.Face.EigenFaceRecognizer.html#predict/1"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.predict/2","doc":"Predicts a label and associated confidence (e.g. distance) for a given input image.\n\n##### Positional Arguments\n- **self**: `Evision.Face.EigenFaceRecognizer.t()`\n- **src**: `Evision.Mat`.\n\n  Sample image to get a prediction from.\n\n##### Return\n- **label**: `integer()`.\n\n  The predicted label for the given image.\n\n- **confidence**: `double`.\n\n  Associated confidence (e.g. distance) for the predicted label.\n\nThe suffix const means that prediction does not affect the internal model state, so the method can\nbe safely called from within different threads.\nThe following example shows how to get a prediction from a trained model:\n```\nusing namespace cv;\n// Do your initialization here (create the cv::FaceRecognizer model) ...\n// ...\n// Read in a sample image:\nMat img = imread(\"person1/3.jpg\", IMREAD_GRAYSCALE);\n// And get a prediction from the cv::FaceRecognizer:\nint predicted = model->predict(img);\n```\nOr to get a prediction and the associated confidence (e.g. distance):\n```\nusing namespace cv;\n// Do your initialization here (create the cv::FaceRecognizer model) ...\n// ...\nMat img = imread(\"person1/3.jpg\", IMREAD_GRAYSCALE);\n// Some variables for the predicted label and associated confidence (e.g. distance):\nint predicted_label = -1;\ndouble predicted_confidence = 0.0;\n// Get the prediction and associated confidence from the model\nmodel->predict(img, predicted_label, predicted_confidence);\n```\n\nPython prototype (for reference only):\n```python3\npredict(src) -> label, confidence\n```","ref":"Evision.Face.EigenFaceRecognizer.html#predict/2"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.predict_collect/1","doc":"","ref":"Evision.Face.EigenFaceRecognizer.html#predict_collect/1"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.predict_collect/3","doc":"- if implemented - send all result of prediction to collector that can be used for somehow custom result handling\n\n##### Positional Arguments\n- **self**: `Evision.Face.EigenFaceRecognizer.t()`\n- **src**: `Evision.Mat`.\n\n  Sample image to get a prediction from.\n\n- **collector**: `PredictCollector`.\n\n  User-defined collector object that accepts all results\n\nTo implement this method u just have to do same internal cycle as in predict(InputArray src, CV_OUT int &label, CV_OUT double &confidence) but\nnot try to get \"best@ result, just resend it to caller side with given collector\n\nPython prototype (for reference only):\n```python3\npredict_collect(src, collector) -> None\n```","ref":"Evision.Face.EigenFaceRecognizer.html#predict_collect/3"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.predict_label/1","doc":"","ref":"Evision.Face.EigenFaceRecognizer.html#predict_label/1"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.predict_label/2","doc":"predict_label\n\n##### Positional Arguments\n- **self**: `Evision.Face.EigenFaceRecognizer.t()`\n- **src**: `Evision.Mat`\n\n##### Return\n- **retval**: `integer()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\npredict_label(src) -> retval\n```","ref":"Evision.Face.EigenFaceRecognizer.html#predict_label/2"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.read/1","doc":"","ref":"Evision.Face.EigenFaceRecognizer.html#read/1"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.read/2","doc":"Loads a FaceRecognizer and its model state.\n\n##### Positional Arguments\n- **self**: `Evision.Face.EigenFaceRecognizer.t()`\n- **filename**: `String`\n\nLoads a persisted model and state from a given XML or YAML file . Every FaceRecognizer has to\noverwrite FaceRecognizer::load(FileStorage& fs) to enable loading the model state.\nFaceRecognizer::load(FileStorage& fs) in turn gets called by\nFaceRecognizer::load(const String& filename), to ease saving a model.\n\nPython prototype (for reference only):\n```python3\nread(filename) -> None\n```","ref":"Evision.Face.EigenFaceRecognizer.html#read/2"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.save/1","doc":"","ref":"Evision.Face.EigenFaceRecognizer.html#save/1"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Face.EigenFaceRecognizer.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Face.EigenFaceRecognizer.html#save/2"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.setLabelInfo/1","doc":"","ref":"Evision.Face.EigenFaceRecognizer.html#setLabelInfo/1"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.setLabelInfo/3","doc":"Sets string info for the specified model's label.\n\n##### Positional Arguments\n- **self**: `Evision.Face.EigenFaceRecognizer.t()`\n- **label**: `integer()`\n- **strInfo**: `String`\n\nThe string info is replaced by the provided value if it was set before for the specified label.\n\nPython prototype (for reference only):\n```python3\nsetLabelInfo(label, strInfo) -> None\n```","ref":"Evision.Face.EigenFaceRecognizer.html#setLabelInfo/3"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.setNumComponents/1","doc":"","ref":"Evision.Face.EigenFaceRecognizer.html#setNumComponents/1"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.setNumComponents/2","doc":"setNumComponents\n\n##### Positional Arguments\n- **self**: `Evision.Face.EigenFaceRecognizer.t()`\n- **val**: `integer()`\n\n@see `getNumComponents/1`\n\nPython prototype (for reference only):\n```python3\nsetNumComponents(val) -> None\n```","ref":"Evision.Face.EigenFaceRecognizer.html#setNumComponents/2"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.setThreshold/1","doc":"","ref":"Evision.Face.EigenFaceRecognizer.html#setThreshold/1"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.setThreshold/2","doc":"setThreshold\n\n##### Positional Arguments\n- **self**: `Evision.Face.EigenFaceRecognizer.t()`\n- **val**: `double`\n\n@see `getThreshold/1`\n\nPython prototype (for reference only):\n```python3\nsetThreshold(val) -> None\n```","ref":"Evision.Face.EigenFaceRecognizer.html#setThreshold/2"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.train/1","doc":"","ref":"Evision.Face.EigenFaceRecognizer.html#train/1"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.train/3","doc":"Trains a FaceRecognizer with given data and associated labels.\n\n##### Positional Arguments\n- **self**: `Evision.Face.EigenFaceRecognizer.t()`\n- **src**: `[Evision.Mat]`.\n\n  The training images, that means the faces you want to learn. The data has to be\n  given as a vector\\ .\n\n- **labels**: `Evision.Mat`.\n\n  The labels corresponding to the images have to be given either as a vector\\ \n  or a Mat of type CV_32SC1.\n\nThe following source code snippet shows you how to learn a Fisherfaces model on a given set of\nimages. The images are read with imread and pushed into a std::vector\\ . The labels of each\nimage are stored within a std::vector\\  (you could also use a Mat of type CV_32SC1). Think of\nthe label as the subject (the person) this image belongs to, so same subjects (persons) should have\nthe same label. For the available FaceRecognizer you don't have to pay any attention to the order of\nthe labels, just make sure same persons have the same label:\n```\n// holds images and labels\nvector  images;\nvector  labels;\n// using Mat of type CV_32SC1\n// Mat labels(number_of_samples, 1, CV_32SC1);\n// images for first person\nimages.push_back(imread(\"person0/0.jpg\", IMREAD_GRAYSCALE)); labels.push_back(0);\nimages.push_back(imread(\"person0/1.jpg\", IMREAD_GRAYSCALE)); labels.push_back(0);\nimages.push_back(imread(\"person0/2.jpg\", IMREAD_GRAYSCALE)); labels.push_back(0);\n// images for second person\nimages.push_back(imread(\"person1/0.jpg\", IMREAD_GRAYSCALE)); labels.push_back(1);\nimages.push_back(imread(\"person1/1.jpg\", IMREAD_GRAYSCALE)); labels.push_back(1);\nimages.push_back(imread(\"person1/2.jpg\", IMREAD_GRAYSCALE)); labels.push_back(1);\n```\nNow that you have read some images, we can create a new FaceRecognizer. In this example I'll create\na Fisherfaces model and decide to keep all of the possible Fisherfaces:\n```\n// Create a new Fisherfaces model and retain all available Fisherfaces,\n// this is the most common usage of this specific FaceRecognizer:\n//\nPtr  model =  FisherFaceRecognizer::create();\n```\nAnd finally train it on the given dataset (the face images and labels):\n```\n// This is the common interface to train all of the available cv::FaceRecognizer\n// implementations:\n//\nmodel->train(images, labels);\n```\n\nPython prototype (for reference only):\n```python3\ntrain(src, labels) -> None\n```","ref":"Evision.Face.EigenFaceRecognizer.html#train/3"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.update/1","doc":"","ref":"Evision.Face.EigenFaceRecognizer.html#update/1"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.update/3","doc":"Updates a FaceRecognizer with given data and associated labels.\n\n##### Positional Arguments\n- **self**: `Evision.Face.EigenFaceRecognizer.t()`\n- **src**: `[Evision.Mat]`.\n\n  The training images, that means the faces you want to learn. The data has to be given\n  as a vector\\ .\n\n- **labels**: `Evision.Mat`.\n\n  The labels corresponding to the images have to be given either as a vector\\  or\n  a Mat of type CV_32SC1.\n\nThis method updates a (probably trained) FaceRecognizer, but only if the algorithm supports it. The\nLocal Binary Patterns Histograms (LBPH) recognizer (see createLBPHFaceRecognizer) can be updated.\nFor the Eigenfaces and Fisherfaces method, this is algorithmically not possible and you have to\nre-estimate the model with FaceRecognizer::train. In any case, a call to train empties the existing\nmodel and learns a new model, while update does not delete any model data.\n```\n// Create a new LBPH model (it can be updated) and use the default parameters,\n// this is the most common usage of this specific FaceRecognizer:\n//\nPtr  model =  LBPHFaceRecognizer::create();\n// This is the common interface to train all of the available cv::FaceRecognizer\n// implementations:\n//\nmodel->train(images, labels);\n// Some containers to hold new image:\nvector  newImages;\nvector  newLabels;\n// You should add some images to the containers:\n//\n// ...\n//\n// Now updating the model is as easy as calling:\nmodel->update(newImages,newLabels);\n// This will preserve the old model data and extend the existing model\n// with the new features extracted from newImages!\n```\nCalling update on an Eigenfaces model (see EigenFaceRecognizer::create), which doesn't support\nupdating, will throw an error similar to:\n```\nOpenCV Error: The function/feature is not implemented (This FaceRecognizer (FaceRecognizer.Eigenfaces) does not support updating, you have to use FaceRecognizer::train to update it.) in update, file /home/philipp/git/opencv/modules/contrib/src/facerec.cpp, line 305\nterminate called after throwing an instance of 'cv::Exception'\n```\n**Note**: The FaceRecognizer does not store your training images, because this would be very\nmemory intense and it's not the responsibility of te FaceRecognizer to do so. The caller is\nresponsible for maintaining the dataset, he want to work with.\n\nPython prototype (for reference only):\n```python3\nupdate(src, labels) -> None\n```","ref":"Evision.Face.EigenFaceRecognizer.html#update/3"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.write/1","doc":"","ref":"Evision.Face.EigenFaceRecognizer.html#write/1"},{"type":"function","title":"Evision.Face.EigenFaceRecognizer.write/2","doc":"Saves a FaceRecognizer and its model state.\n\n##### Positional Arguments\n- **self**: `Evision.Face.EigenFaceRecognizer.t()`\n- **filename**: `String`.\n\n  The filename to store this FaceRecognizer to (either XML/YAML).\n\nSaves this model to a given filename, either as XML or YAML.\n\nEvery FaceRecognizer overwrites FaceRecognizer::save(FileStorage& fs) to save the internal model\nstate. FaceRecognizer::save(const String& filename) saves the state of a model to the given\nfilename.\nThe suffix const means that prediction does not affect the internal model state, so the method can\nbe safely called from within different threads.\n\nPython prototype (for reference only):\n```python3\nwrite(filename) -> None\n```","ref":"Evision.Face.EigenFaceRecognizer.html#write/2"},{"type":"type","title":"Evision.Face.EigenFaceRecognizer.t/0","doc":"Type that represents an `Face.EigenFaceRecognizer` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Face.EigenFaceRecognizer.html#t:t/0"},{"type":"module","title":"Evision.Face.FaceRecognizer","doc":"","ref":"Evision.Face.FaceRecognizer.html"},{"type":"function","title":"Evision.Face.FaceRecognizer.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Face.FaceRecognizer.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Face.FaceRecognizer.html#clear/1"},{"type":"function","title":"Evision.Face.FaceRecognizer.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Face.FaceRecognizer.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Face.FaceRecognizer.html#empty/1"},{"type":"function","title":"Evision.Face.FaceRecognizer.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Face.FaceRecognizer.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Face.FaceRecognizer.html#getDefaultName/1"},{"type":"function","title":"Evision.Face.FaceRecognizer.getLabelInfo/1","doc":"","ref":"Evision.Face.FaceRecognizer.html#getLabelInfo/1"},{"type":"function","title":"Evision.Face.FaceRecognizer.getLabelInfo/2","doc":"Gets string information by label.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FaceRecognizer.t()`\n- **label**: `integer()`\n\n##### Return\n- **retval**: `String`\n\nIf an unknown label id is provided or there is no label information associated with the specified\nlabel id the method returns an empty string.\n\nPython prototype (for reference only):\n```python3\ngetLabelInfo(label) -> retval\n```","ref":"Evision.Face.FaceRecognizer.html#getLabelInfo/2"},{"type":"function","title":"Evision.Face.FaceRecognizer.getLabelsByString/1","doc":"","ref":"Evision.Face.FaceRecognizer.html#getLabelsByString/1"},{"type":"function","title":"Evision.Face.FaceRecognizer.getLabelsByString/2","doc":"Gets vector of labels by string.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FaceRecognizer.t()`\n- **str**: `String`\n\n##### Return\n- **retval**: `[integer()]`\n\nThe function searches for the labels containing the specified sub-string in the associated string\ninfo.\n\nPython prototype (for reference only):\n```python3\ngetLabelsByString(str) -> retval\n```","ref":"Evision.Face.FaceRecognizer.html#getLabelsByString/2"},{"type":"function","title":"Evision.Face.FaceRecognizer.predict/1","doc":"","ref":"Evision.Face.FaceRecognizer.html#predict/1"},{"type":"function","title":"Evision.Face.FaceRecognizer.predict/2","doc":"Predicts a label and associated confidence (e.g. distance) for a given input image.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FaceRecognizer.t()`\n- **src**: `Evision.Mat`.\n\n  Sample image to get a prediction from.\n\n##### Return\n- **label**: `integer()`.\n\n  The predicted label for the given image.\n\n- **confidence**: `double`.\n\n  Associated confidence (e.g. distance) for the predicted label.\n\nThe suffix const means that prediction does not affect the internal model state, so the method can\nbe safely called from within different threads.\nThe following example shows how to get a prediction from a trained model:\n```\nusing namespace cv;\n// Do your initialization here (create the cv::FaceRecognizer model) ...\n// ...\n// Read in a sample image:\nMat img = imread(\"person1/3.jpg\", IMREAD_GRAYSCALE);\n// And get a prediction from the cv::FaceRecognizer:\nint predicted = model->predict(img);\n```\nOr to get a prediction and the associated confidence (e.g. distance):\n```\nusing namespace cv;\n// Do your initialization here (create the cv::FaceRecognizer model) ...\n// ...\nMat img = imread(\"person1/3.jpg\", IMREAD_GRAYSCALE);\n// Some variables for the predicted label and associated confidence (e.g. distance):\nint predicted_label = -1;\ndouble predicted_confidence = 0.0;\n// Get the prediction and associated confidence from the model\nmodel->predict(img, predicted_label, predicted_confidence);\n```\n\nPython prototype (for reference only):\n```python3\npredict(src) -> label, confidence\n```","ref":"Evision.Face.FaceRecognizer.html#predict/2"},{"type":"function","title":"Evision.Face.FaceRecognizer.predict_collect/1","doc":"","ref":"Evision.Face.FaceRecognizer.html#predict_collect/1"},{"type":"function","title":"Evision.Face.FaceRecognizer.predict_collect/3","doc":"- if implemented - send all result of prediction to collector that can be used for somehow custom result handling\n\n##### Positional Arguments\n- **self**: `Evision.Face.FaceRecognizer.t()`\n- **src**: `Evision.Mat`.\n\n  Sample image to get a prediction from.\n\n- **collector**: `PredictCollector`.\n\n  User-defined collector object that accepts all results\n\nTo implement this method u just have to do same internal cycle as in predict(InputArray src, CV_OUT int &label, CV_OUT double &confidence) but\nnot try to get \"best@ result, just resend it to caller side with given collector\n\nPython prototype (for reference only):\n```python3\npredict_collect(src, collector) -> None\n```","ref":"Evision.Face.FaceRecognizer.html#predict_collect/3"},{"type":"function","title":"Evision.Face.FaceRecognizer.predict_label/1","doc":"","ref":"Evision.Face.FaceRecognizer.html#predict_label/1"},{"type":"function","title":"Evision.Face.FaceRecognizer.predict_label/2","doc":"predict_label\n\n##### Positional Arguments\n- **self**: `Evision.Face.FaceRecognizer.t()`\n- **src**: `Evision.Mat`\n\n##### Return\n- **retval**: `integer()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\npredict_label(src) -> retval\n```","ref":"Evision.Face.FaceRecognizer.html#predict_label/2"},{"type":"function","title":"Evision.Face.FaceRecognizer.read/1","doc":"","ref":"Evision.Face.FaceRecognizer.html#read/1"},{"type":"function","title":"Evision.Face.FaceRecognizer.read/2","doc":"Loads a FaceRecognizer and its model state.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FaceRecognizer.t()`\n- **filename**: `String`\n\nLoads a persisted model and state from a given XML or YAML file . Every FaceRecognizer has to\noverwrite FaceRecognizer::load(FileStorage& fs) to enable loading the model state.\nFaceRecognizer::load(FileStorage& fs) in turn gets called by\nFaceRecognizer::load(const String& filename), to ease saving a model.\n\nPython prototype (for reference only):\n```python3\nread(filename) -> None\n```","ref":"Evision.Face.FaceRecognizer.html#read/2"},{"type":"function","title":"Evision.Face.FaceRecognizer.save/1","doc":"","ref":"Evision.Face.FaceRecognizer.html#save/1"},{"type":"function","title":"Evision.Face.FaceRecognizer.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Face.FaceRecognizer.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Face.FaceRecognizer.html#save/2"},{"type":"function","title":"Evision.Face.FaceRecognizer.setLabelInfo/1","doc":"","ref":"Evision.Face.FaceRecognizer.html#setLabelInfo/1"},{"type":"function","title":"Evision.Face.FaceRecognizer.setLabelInfo/3","doc":"Sets string info for the specified model's label.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FaceRecognizer.t()`\n- **label**: `integer()`\n- **strInfo**: `String`\n\nThe string info is replaced by the provided value if it was set before for the specified label.\n\nPython prototype (for reference only):\n```python3\nsetLabelInfo(label, strInfo) -> None\n```","ref":"Evision.Face.FaceRecognizer.html#setLabelInfo/3"},{"type":"function","title":"Evision.Face.FaceRecognizer.train/1","doc":"","ref":"Evision.Face.FaceRecognizer.html#train/1"},{"type":"function","title":"Evision.Face.FaceRecognizer.train/3","doc":"Trains a FaceRecognizer with given data and associated labels.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FaceRecognizer.t()`\n- **src**: `[Evision.Mat]`.\n\n  The training images, that means the faces you want to learn. The data has to be\n  given as a vector\\ .\n\n- **labels**: `Evision.Mat`.\n\n  The labels corresponding to the images have to be given either as a vector\\ \n  or a Mat of type CV_32SC1.\n\nThe following source code snippet shows you how to learn a Fisherfaces model on a given set of\nimages. The images are read with imread and pushed into a std::vector\\ . The labels of each\nimage are stored within a std::vector\\  (you could also use a Mat of type CV_32SC1). Think of\nthe label as the subject (the person) this image belongs to, so same subjects (persons) should have\nthe same label. For the available FaceRecognizer you don't have to pay any attention to the order of\nthe labels, just make sure same persons have the same label:\n```\n// holds images and labels\nvector  images;\nvector  labels;\n// using Mat of type CV_32SC1\n// Mat labels(number_of_samples, 1, CV_32SC1);\n// images for first person\nimages.push_back(imread(\"person0/0.jpg\", IMREAD_GRAYSCALE)); labels.push_back(0);\nimages.push_back(imread(\"person0/1.jpg\", IMREAD_GRAYSCALE)); labels.push_back(0);\nimages.push_back(imread(\"person0/2.jpg\", IMREAD_GRAYSCALE)); labels.push_back(0);\n// images for second person\nimages.push_back(imread(\"person1/0.jpg\", IMREAD_GRAYSCALE)); labels.push_back(1);\nimages.push_back(imread(\"person1/1.jpg\", IMREAD_GRAYSCALE)); labels.push_back(1);\nimages.push_back(imread(\"person1/2.jpg\", IMREAD_GRAYSCALE)); labels.push_back(1);\n```\nNow that you have read some images, we can create a new FaceRecognizer. In this example I'll create\na Fisherfaces model and decide to keep all of the possible Fisherfaces:\n```\n// Create a new Fisherfaces model and retain all available Fisherfaces,\n// this is the most common usage of this specific FaceRecognizer:\n//\nPtr  model =  FisherFaceRecognizer::create();\n```\nAnd finally train it on the given dataset (the face images and labels):\n```\n// This is the common interface to train all of the available cv::FaceRecognizer\n// implementations:\n//\nmodel->train(images, labels);\n```\n\nPython prototype (for reference only):\n```python3\ntrain(src, labels) -> None\n```","ref":"Evision.Face.FaceRecognizer.html#train/3"},{"type":"function","title":"Evision.Face.FaceRecognizer.update/1","doc":"","ref":"Evision.Face.FaceRecognizer.html#update/1"},{"type":"function","title":"Evision.Face.FaceRecognizer.update/3","doc":"Updates a FaceRecognizer with given data and associated labels.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FaceRecognizer.t()`\n- **src**: `[Evision.Mat]`.\n\n  The training images, that means the faces you want to learn. The data has to be given\n  as a vector\\ .\n\n- **labels**: `Evision.Mat`.\n\n  The labels corresponding to the images have to be given either as a vector\\  or\n  a Mat of type CV_32SC1.\n\nThis method updates a (probably trained) FaceRecognizer, but only if the algorithm supports it. The\nLocal Binary Patterns Histograms (LBPH) recognizer (see createLBPHFaceRecognizer) can be updated.\nFor the Eigenfaces and Fisherfaces method, this is algorithmically not possible and you have to\nre-estimate the model with FaceRecognizer::train. In any case, a call to train empties the existing\nmodel and learns a new model, while update does not delete any model data.\n```\n// Create a new LBPH model (it can be updated) and use the default parameters,\n// this is the most common usage of this specific FaceRecognizer:\n//\nPtr  model =  LBPHFaceRecognizer::create();\n// This is the common interface to train all of the available cv::FaceRecognizer\n// implementations:\n//\nmodel->train(images, labels);\n// Some containers to hold new image:\nvector  newImages;\nvector  newLabels;\n// You should add some images to the containers:\n//\n// ...\n//\n// Now updating the model is as easy as calling:\nmodel->update(newImages,newLabels);\n// This will preserve the old model data and extend the existing model\n// with the new features extracted from newImages!\n```\nCalling update on an Eigenfaces model (see EigenFaceRecognizer::create), which doesn't support\nupdating, will throw an error similar to:\n```\nOpenCV Error: The function/feature is not implemented (This FaceRecognizer (FaceRecognizer.Eigenfaces) does not support updating, you have to use FaceRecognizer::train to update it.) in update, file /home/philipp/git/opencv/modules/contrib/src/facerec.cpp, line 305\nterminate called after throwing an instance of 'cv::Exception'\n```\n**Note**: The FaceRecognizer does not store your training images, because this would be very\nmemory intense and it's not the responsibility of te FaceRecognizer to do so. The caller is\nresponsible for maintaining the dataset, he want to work with.\n\nPython prototype (for reference only):\n```python3\nupdate(src, labels) -> None\n```","ref":"Evision.Face.FaceRecognizer.html#update/3"},{"type":"function","title":"Evision.Face.FaceRecognizer.write/1","doc":"","ref":"Evision.Face.FaceRecognizer.html#write/1"},{"type":"function","title":"Evision.Face.FaceRecognizer.write/2","doc":"Saves a FaceRecognizer and its model state.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FaceRecognizer.t()`\n- **filename**: `String`.\n\n  The filename to store this FaceRecognizer to (either XML/YAML).\n\nSaves this model to a given filename, either as XML or YAML.\n\nEvery FaceRecognizer overwrites FaceRecognizer::save(FileStorage& fs) to save the internal model\nstate. FaceRecognizer::save(const String& filename) saves the state of a model to the given\nfilename.\nThe suffix const means that prediction does not affect the internal model state, so the method can\nbe safely called from within different threads.\n\nPython prototype (for reference only):\n```python3\nwrite(filename) -> None\n```","ref":"Evision.Face.FaceRecognizer.html#write/2"},{"type":"type","title":"Evision.Face.FaceRecognizer.t/0","doc":"Type that represents an `Face.FaceRecognizer` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Face.FaceRecognizer.html#t:t/0"},{"type":"module","title":"Evision.Face.Facemark","doc":"","ref":"Evision.Face.Facemark.html"},{"type":"function","title":"Evision.Face.Facemark.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Face.Facemark.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Face.Facemark.html#clear/1"},{"type":"function","title":"Evision.Face.Facemark.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Face.Facemark.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Face.Facemark.html#empty/1"},{"type":"function","title":"Evision.Face.Facemark.fit/1","doc":"","ref":"Evision.Face.Facemark.html#fit/1"},{"type":"function","title":"Evision.Face.Facemark.fit/3","doc":"Detect facial landmarks from an image.\n\n##### Positional Arguments\n- **self**: `Evision.Face.Facemark.t()`\n- **image**: `Evision.Mat`.\n\n  Input image.\n\n- **faces**: `Evision.Mat`.\n\n  Output of the function which represent region of interest of the detected faces.\n  Each face is stored in cv::Rect container.\n\n##### Return\n- **retval**: `bool`\n- **landmarks**: `[Evision.Mat]`.\n\n  The detected landmark points for each faces.\n\n Example of usage \n```\nMat image = imread(\"image.jpg\");\nstd::vector  faces;\nstd::vector  > landmarks;\nfacemark->fit(image, faces, landmarks);\n```\n\nPython prototype (for reference only):\n```python3\nfit(image, faces[, landmarks]) -> retval, landmarks\n```","ref":"Evision.Face.Facemark.html#fit/3"},{"type":"function","title":"Evision.Face.Facemark.fit/4","doc":"Detect facial landmarks from an image.\n\n##### Positional Arguments\n- **self**: `Evision.Face.Facemark.t()`\n- **image**: `Evision.Mat`.\n\n  Input image.\n\n- **faces**: `Evision.Mat`.\n\n  Output of the function which represent region of interest of the detected faces.\n  Each face is stored in cv::Rect container.\n\n##### Return\n- **retval**: `bool`\n- **landmarks**: `[Evision.Mat]`.\n\n  The detected landmark points for each faces.\n\n Example of usage \n```\nMat image = imread(\"image.jpg\");\nstd::vector  faces;\nstd::vector  > landmarks;\nfacemark->fit(image, faces, landmarks);\n```\n\nPython prototype (for reference only):\n```python3\nfit(image, faces[, landmarks]) -> retval, landmarks\n```","ref":"Evision.Face.Facemark.html#fit/4"},{"type":"function","title":"Evision.Face.Facemark.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Face.Facemark.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Face.Facemark.html#getDefaultName/1"},{"type":"function","title":"Evision.Face.Facemark.loadModel/1","doc":"","ref":"Evision.Face.Facemark.html#loadModel/1"},{"type":"function","title":"Evision.Face.Facemark.loadModel/2","doc":"A function to load the trained model before the fitting process.\n\n##### Positional Arguments\n- **self**: `Evision.Face.Facemark.t()`\n- **model**: `String`.\n\n  A string represent the filename of a trained model.\n\n Example of usage \n```\nfacemark->loadModel(\"../data/lbf.model\");\n```\n\nPython prototype (for reference only):\n```python3\nloadModel(model) -> None\n```","ref":"Evision.Face.Facemark.html#loadModel/2"},{"type":"function","title":"Evision.Face.Facemark.read/1","doc":"","ref":"Evision.Face.Facemark.html#read/1"},{"type":"function","title":"Evision.Face.Facemark.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Face.Facemark.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Face.Facemark.html#read/2"},{"type":"function","title":"Evision.Face.Facemark.save/1","doc":"","ref":"Evision.Face.Facemark.html#save/1"},{"type":"function","title":"Evision.Face.Facemark.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Face.Facemark.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Face.Facemark.html#save/2"},{"type":"function","title":"Evision.Face.Facemark.write/1","doc":"","ref":"Evision.Face.Facemark.html#write/1"},{"type":"function","title":"Evision.Face.Facemark.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Face.Facemark.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Face.Facemark.html#write/2"},{"type":"function","title":"Evision.Face.Facemark.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Face.Facemark.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Face.Facemark.html#write/3"},{"type":"type","title":"Evision.Face.Facemark.t/0","doc":"Type that represents an `Face.Facemark` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Face.Facemark.html#t:t/0"},{"type":"module","title":"Evision.Face.FacemarkAAM","doc":"","ref":"Evision.Face.FacemarkAAM.html"},{"type":"function","title":"Evision.Face.FacemarkAAM.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkAAM.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Face.FacemarkAAM.html#clear/1"},{"type":"function","title":"Evision.Face.FacemarkAAM.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkAAM.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Face.FacemarkAAM.html#empty/1"},{"type":"function","title":"Evision.Face.FacemarkAAM.fit/1","doc":"","ref":"Evision.Face.FacemarkAAM.html#fit/1"},{"type":"function","title":"Evision.Face.FacemarkAAM.fit/3","doc":"Detect facial landmarks from an image.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkAAM.t()`\n- **image**: `Evision.Mat`.\n\n  Input image.\n\n- **faces**: `Evision.Mat`.\n\n  Output of the function which represent region of interest of the detected faces.\n  Each face is stored in cv::Rect container.\n\n##### Return\n- **retval**: `bool`\n- **landmarks**: `[Evision.Mat]`.\n\n  The detected landmark points for each faces.\n\n Example of usage \n```\nMat image = imread(\"image.jpg\");\nstd::vector  faces;\nstd::vector  > landmarks;\nfacemark->fit(image, faces, landmarks);\n```\n\nPython prototype (for reference only):\n```python3\nfit(image, faces[, landmarks]) -> retval, landmarks\n```","ref":"Evision.Face.FacemarkAAM.html#fit/3"},{"type":"function","title":"Evision.Face.FacemarkAAM.fit/4","doc":"Detect facial landmarks from an image.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkAAM.t()`\n- **image**: `Evision.Mat`.\n\n  Input image.\n\n- **faces**: `Evision.Mat`.\n\n  Output of the function which represent region of interest of the detected faces.\n  Each face is stored in cv::Rect container.\n\n##### Return\n- **retval**: `bool`\n- **landmarks**: `[Evision.Mat]`.\n\n  The detected landmark points for each faces.\n\n Example of usage \n```\nMat image = imread(\"image.jpg\");\nstd::vector  faces;\nstd::vector  > landmarks;\nfacemark->fit(image, faces, landmarks);\n```\n\nPython prototype (for reference only):\n```python3\nfit(image, faces[, landmarks]) -> retval, landmarks\n```","ref":"Evision.Face.FacemarkAAM.html#fit/4"},{"type":"function","title":"Evision.Face.FacemarkAAM.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkAAM.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Face.FacemarkAAM.html#getDefaultName/1"},{"type":"function","title":"Evision.Face.FacemarkAAM.loadModel/1","doc":"","ref":"Evision.Face.FacemarkAAM.html#loadModel/1"},{"type":"function","title":"Evision.Face.FacemarkAAM.loadModel/2","doc":"A function to load the trained model before the fitting process.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkAAM.t()`\n- **model**: `String`.\n\n  A string represent the filename of a trained model.\n\n Example of usage \n```\nfacemark->loadModel(\"../data/lbf.model\");\n```\n\nPython prototype (for reference only):\n```python3\nloadModel(model) -> None\n```","ref":"Evision.Face.FacemarkAAM.html#loadModel/2"},{"type":"function","title":"Evision.Face.FacemarkAAM.read/1","doc":"","ref":"Evision.Face.FacemarkAAM.html#read/1"},{"type":"function","title":"Evision.Face.FacemarkAAM.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkAAM.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Face.FacemarkAAM.html#read/2"},{"type":"function","title":"Evision.Face.FacemarkAAM.save/1","doc":"","ref":"Evision.Face.FacemarkAAM.html#save/1"},{"type":"function","title":"Evision.Face.FacemarkAAM.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkAAM.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Face.FacemarkAAM.html#save/2"},{"type":"function","title":"Evision.Face.FacemarkAAM.write/1","doc":"","ref":"Evision.Face.FacemarkAAM.html#write/1"},{"type":"function","title":"Evision.Face.FacemarkAAM.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkAAM.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Face.FacemarkAAM.html#write/2"},{"type":"function","title":"Evision.Face.FacemarkAAM.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkAAM.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Face.FacemarkAAM.html#write/3"},{"type":"type","title":"Evision.Face.FacemarkAAM.t/0","doc":"Type that represents an `Face.FacemarkAAM` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Face.FacemarkAAM.html#t:t/0"},{"type":"module","title":"Evision.Face.FacemarkKazemi","doc":"","ref":"Evision.Face.FacemarkKazemi.html"},{"type":"function","title":"Evision.Face.FacemarkKazemi.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkKazemi.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Face.FacemarkKazemi.html#clear/1"},{"type":"function","title":"Evision.Face.FacemarkKazemi.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkKazemi.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Face.FacemarkKazemi.html#empty/1"},{"type":"function","title":"Evision.Face.FacemarkKazemi.fit/1","doc":"","ref":"Evision.Face.FacemarkKazemi.html#fit/1"},{"type":"function","title":"Evision.Face.FacemarkKazemi.fit/3","doc":"Detect facial landmarks from an image.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkKazemi.t()`\n- **image**: `Evision.Mat`.\n\n  Input image.\n\n- **faces**: `Evision.Mat`.\n\n  Output of the function which represent region of interest of the detected faces.\n  Each face is stored in cv::Rect container.\n\n##### Return\n- **retval**: `bool`\n- **landmarks**: `[Evision.Mat]`.\n\n  The detected landmark points for each faces.\n\n Example of usage \n```\nMat image = imread(\"image.jpg\");\nstd::vector  faces;\nstd::vector  > landmarks;\nfacemark->fit(image, faces, landmarks);\n```\n\nPython prototype (for reference only):\n```python3\nfit(image, faces[, landmarks]) -> retval, landmarks\n```","ref":"Evision.Face.FacemarkKazemi.html#fit/3"},{"type":"function","title":"Evision.Face.FacemarkKazemi.fit/4","doc":"Detect facial landmarks from an image.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkKazemi.t()`\n- **image**: `Evision.Mat`.\n\n  Input image.\n\n- **faces**: `Evision.Mat`.\n\n  Output of the function which represent region of interest of the detected faces.\n  Each face is stored in cv::Rect container.\n\n##### Return\n- **retval**: `bool`\n- **landmarks**: `[Evision.Mat]`.\n\n  The detected landmark points for each faces.\n\n Example of usage \n```\nMat image = imread(\"image.jpg\");\nstd::vector  faces;\nstd::vector  > landmarks;\nfacemark->fit(image, faces, landmarks);\n```\n\nPython prototype (for reference only):\n```python3\nfit(image, faces[, landmarks]) -> retval, landmarks\n```","ref":"Evision.Face.FacemarkKazemi.html#fit/4"},{"type":"function","title":"Evision.Face.FacemarkKazemi.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkKazemi.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Face.FacemarkKazemi.html#getDefaultName/1"},{"type":"function","title":"Evision.Face.FacemarkKazemi.loadModel/1","doc":"","ref":"Evision.Face.FacemarkKazemi.html#loadModel/1"},{"type":"function","title":"Evision.Face.FacemarkKazemi.loadModel/2","doc":"A function to load the trained model before the fitting process.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkKazemi.t()`\n- **model**: `String`.\n\n  A string represent the filename of a trained model.\n\n Example of usage \n```\nfacemark->loadModel(\"../data/lbf.model\");\n```\n\nPython prototype (for reference only):\n```python3\nloadModel(model) -> None\n```","ref":"Evision.Face.FacemarkKazemi.html#loadModel/2"},{"type":"function","title":"Evision.Face.FacemarkKazemi.read/1","doc":"","ref":"Evision.Face.FacemarkKazemi.html#read/1"},{"type":"function","title":"Evision.Face.FacemarkKazemi.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkKazemi.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Face.FacemarkKazemi.html#read/2"},{"type":"function","title":"Evision.Face.FacemarkKazemi.save/1","doc":"","ref":"Evision.Face.FacemarkKazemi.html#save/1"},{"type":"function","title":"Evision.Face.FacemarkKazemi.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkKazemi.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Face.FacemarkKazemi.html#save/2"},{"type":"function","title":"Evision.Face.FacemarkKazemi.write/1","doc":"","ref":"Evision.Face.FacemarkKazemi.html#write/1"},{"type":"function","title":"Evision.Face.FacemarkKazemi.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkKazemi.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Face.FacemarkKazemi.html#write/2"},{"type":"function","title":"Evision.Face.FacemarkKazemi.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkKazemi.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Face.FacemarkKazemi.html#write/3"},{"type":"type","title":"Evision.Face.FacemarkKazemi.t/0","doc":"Type that represents an `Face.FacemarkKazemi` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Face.FacemarkKazemi.html#t:t/0"},{"type":"module","title":"Evision.Face.FacemarkLBF","doc":"","ref":"Evision.Face.FacemarkLBF.html"},{"type":"function","title":"Evision.Face.FacemarkLBF.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkLBF.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Face.FacemarkLBF.html#clear/1"},{"type":"function","title":"Evision.Face.FacemarkLBF.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkLBF.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Face.FacemarkLBF.html#empty/1"},{"type":"function","title":"Evision.Face.FacemarkLBF.fit/1","doc":"","ref":"Evision.Face.FacemarkLBF.html#fit/1"},{"type":"function","title":"Evision.Face.FacemarkLBF.fit/3","doc":"Detect facial landmarks from an image.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkLBF.t()`\n- **image**: `Evision.Mat`.\n\n  Input image.\n\n- **faces**: `Evision.Mat`.\n\n  Output of the function which represent region of interest of the detected faces.\n  Each face is stored in cv::Rect container.\n\n##### Return\n- **retval**: `bool`\n- **landmarks**: `[Evision.Mat]`.\n\n  The detected landmark points for each faces.\n\n Example of usage \n```\nMat image = imread(\"image.jpg\");\nstd::vector  faces;\nstd::vector  > landmarks;\nfacemark->fit(image, faces, landmarks);\n```\n\nPython prototype (for reference only):\n```python3\nfit(image, faces[, landmarks]) -> retval, landmarks\n```","ref":"Evision.Face.FacemarkLBF.html#fit/3"},{"type":"function","title":"Evision.Face.FacemarkLBF.fit/4","doc":"Detect facial landmarks from an image.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkLBF.t()`\n- **image**: `Evision.Mat`.\n\n  Input image.\n\n- **faces**: `Evision.Mat`.\n\n  Output of the function which represent region of interest of the detected faces.\n  Each face is stored in cv::Rect container.\n\n##### Return\n- **retval**: `bool`\n- **landmarks**: `[Evision.Mat]`.\n\n  The detected landmark points for each faces.\n\n Example of usage \n```\nMat image = imread(\"image.jpg\");\nstd::vector  faces;\nstd::vector  > landmarks;\nfacemark->fit(image, faces, landmarks);\n```\n\nPython prototype (for reference only):\n```python3\nfit(image, faces[, landmarks]) -> retval, landmarks\n```","ref":"Evision.Face.FacemarkLBF.html#fit/4"},{"type":"function","title":"Evision.Face.FacemarkLBF.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkLBF.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Face.FacemarkLBF.html#getDefaultName/1"},{"type":"function","title":"Evision.Face.FacemarkLBF.loadModel/1","doc":"","ref":"Evision.Face.FacemarkLBF.html#loadModel/1"},{"type":"function","title":"Evision.Face.FacemarkLBF.loadModel/2","doc":"A function to load the trained model before the fitting process.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkLBF.t()`\n- **model**: `String`.\n\n  A string represent the filename of a trained model.\n\n Example of usage \n```\nfacemark->loadModel(\"../data/lbf.model\");\n```\n\nPython prototype (for reference only):\n```python3\nloadModel(model) -> None\n```","ref":"Evision.Face.FacemarkLBF.html#loadModel/2"},{"type":"function","title":"Evision.Face.FacemarkLBF.read/1","doc":"","ref":"Evision.Face.FacemarkLBF.html#read/1"},{"type":"function","title":"Evision.Face.FacemarkLBF.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkLBF.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Face.FacemarkLBF.html#read/2"},{"type":"function","title":"Evision.Face.FacemarkLBF.save/1","doc":"","ref":"Evision.Face.FacemarkLBF.html#save/1"},{"type":"function","title":"Evision.Face.FacemarkLBF.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkLBF.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Face.FacemarkLBF.html#save/2"},{"type":"function","title":"Evision.Face.FacemarkLBF.write/1","doc":"","ref":"Evision.Face.FacemarkLBF.html#write/1"},{"type":"function","title":"Evision.Face.FacemarkLBF.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkLBF.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Face.FacemarkLBF.html#write/2"},{"type":"function","title":"Evision.Face.FacemarkLBF.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkLBF.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Face.FacemarkLBF.html#write/3"},{"type":"type","title":"Evision.Face.FacemarkLBF.t/0","doc":"Type that represents an `Face.FacemarkLBF` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Face.FacemarkLBF.html#t:t/0"},{"type":"module","title":"Evision.Face.FacemarkTrain","doc":"","ref":"Evision.Face.FacemarkTrain.html"},{"type":"function","title":"Evision.Face.FacemarkTrain.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkTrain.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Face.FacemarkTrain.html#clear/1"},{"type":"function","title":"Evision.Face.FacemarkTrain.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkTrain.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Face.FacemarkTrain.html#empty/1"},{"type":"function","title":"Evision.Face.FacemarkTrain.fit/1","doc":"","ref":"Evision.Face.FacemarkTrain.html#fit/1"},{"type":"function","title":"Evision.Face.FacemarkTrain.fit/3","doc":"Detect facial landmarks from an image.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkTrain.t()`\n- **image**: `Evision.Mat`.\n\n  Input image.\n\n- **faces**: `Evision.Mat`.\n\n  Output of the function which represent region of interest of the detected faces.\n  Each face is stored in cv::Rect container.\n\n##### Return\n- **retval**: `bool`\n- **landmarks**: `[Evision.Mat]`.\n\n  The detected landmark points for each faces.\n\n Example of usage \n```\nMat image = imread(\"image.jpg\");\nstd::vector  faces;\nstd::vector  > landmarks;\nfacemark->fit(image, faces, landmarks);\n```\n\nPython prototype (for reference only):\n```python3\nfit(image, faces[, landmarks]) -> retval, landmarks\n```","ref":"Evision.Face.FacemarkTrain.html#fit/3"},{"type":"function","title":"Evision.Face.FacemarkTrain.fit/4","doc":"Detect facial landmarks from an image.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkTrain.t()`\n- **image**: `Evision.Mat`.\n\n  Input image.\n\n- **faces**: `Evision.Mat`.\n\n  Output of the function which represent region of interest of the detected faces.\n  Each face is stored in cv::Rect container.\n\n##### Return\n- **retval**: `bool`\n- **landmarks**: `[Evision.Mat]`.\n\n  The detected landmark points for each faces.\n\n Example of usage \n```\nMat image = imread(\"image.jpg\");\nstd::vector  faces;\nstd::vector  > landmarks;\nfacemark->fit(image, faces, landmarks);\n```\n\nPython prototype (for reference only):\n```python3\nfit(image, faces[, landmarks]) -> retval, landmarks\n```","ref":"Evision.Face.FacemarkTrain.html#fit/4"},{"type":"function","title":"Evision.Face.FacemarkTrain.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkTrain.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Face.FacemarkTrain.html#getDefaultName/1"},{"type":"function","title":"Evision.Face.FacemarkTrain.loadModel/1","doc":"","ref":"Evision.Face.FacemarkTrain.html#loadModel/1"},{"type":"function","title":"Evision.Face.FacemarkTrain.loadModel/2","doc":"A function to load the trained model before the fitting process.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkTrain.t()`\n- **model**: `String`.\n\n  A string represent the filename of a trained model.\n\n Example of usage \n```\nfacemark->loadModel(\"../data/lbf.model\");\n```\n\nPython prototype (for reference only):\n```python3\nloadModel(model) -> None\n```","ref":"Evision.Face.FacemarkTrain.html#loadModel/2"},{"type":"function","title":"Evision.Face.FacemarkTrain.read/1","doc":"","ref":"Evision.Face.FacemarkTrain.html#read/1"},{"type":"function","title":"Evision.Face.FacemarkTrain.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkTrain.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Face.FacemarkTrain.html#read/2"},{"type":"function","title":"Evision.Face.FacemarkTrain.save/1","doc":"","ref":"Evision.Face.FacemarkTrain.html#save/1"},{"type":"function","title":"Evision.Face.FacemarkTrain.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkTrain.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Face.FacemarkTrain.html#save/2"},{"type":"function","title":"Evision.Face.FacemarkTrain.write/1","doc":"","ref":"Evision.Face.FacemarkTrain.html#write/1"},{"type":"function","title":"Evision.Face.FacemarkTrain.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkTrain.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Face.FacemarkTrain.html#write/2"},{"type":"function","title":"Evision.Face.FacemarkTrain.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Face.FacemarkTrain.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Face.FacemarkTrain.html#write/3"},{"type":"type","title":"Evision.Face.FacemarkTrain.t/0","doc":"Type that represents an `Face.FacemarkTrain` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Face.FacemarkTrain.html#t:t/0"},{"type":"module","title":"Evision.Face.FisherFaceRecognizer","doc":"","ref":"Evision.Face.FisherFaceRecognizer.html"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Face.FisherFaceRecognizer.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Face.FisherFaceRecognizer.html#clear/1"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.create/0","doc":"create\n##### Keyword Arguments\n- **num_components**: `integer()`.\n\n  The number of components (read: Fisherfaces) kept for this Linear\n  Discriminant Analysis with the Fisherfaces criterion. It's useful to keep all components, that\n  means the number of your classes c (read: subjects, persons you want to recognize). If you leave\n  this at the default (0) or set it to a value less-equal 0 or greater (c-1), it will be set to the\n  correct number (c-1) automatically.\n\n- **threshold**: `double`.\n\n  The threshold applied in the prediction. If the distance to the nearest neighbor\n  is larger than the threshold, this method returns -1.\n\n##### Return\n- **retval**: `FisherFaceRecognizer`","ref":"Evision.Face.FisherFaceRecognizer.html#create/0"},{"type":"function","title":"Notes: - Evision.Face.FisherFaceRecognizer.create/0","doc":"- Training and prediction must be done on grayscale images, use cvtColor to convert between the\n  color spaces.\n\n- **THE FISHERFACES METHOD MAKES THE ASSUMPTION, THAT THE TRAINING AND TEST IMAGES ARE OF EQUAL\n  SIZE.** (caps-lock, because I got so many mails asking for this). You have to make sure your\n  input data has the correct shape, else a meaningful exception is thrown. Use resize to resize\n  the images.\n\n- This model does not support updating.","ref":"Evision.Face.FisherFaceRecognizer.html#create/0-notes"},{"type":"function","title":"Model internal data: - Evision.Face.FisherFaceRecognizer.create/0","doc":"- num_components see FisherFaceRecognizer::create.\n- threshold see FisherFaceRecognizer::create.\n- eigenvalues The eigenvalues for this Linear Discriminant Analysis (ordered descending).\n- eigenvectors The eigenvectors for this Linear Discriminant Analysis (ordered by their\n  eigenvalue).\n\n- mean The sample mean calculated from the training data.\n- projections The projections of the training data.\n- labels The labels corresponding to the projections.\n\nPython prototype (for reference only):\n```python3\ncreate([, num_components[, threshold]]) -> retval\n```","ref":"Evision.Face.FisherFaceRecognizer.html#create/0-model-internal-data"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.create/1","doc":"create\n##### Keyword Arguments\n- **num_components**: `integer()`.\n\n  The number of components (read: Fisherfaces) kept for this Linear\n  Discriminant Analysis with the Fisherfaces criterion. It's useful to keep all components, that\n  means the number of your classes c (read: subjects, persons you want to recognize). If you leave\n  this at the default (0) or set it to a value less-equal 0 or greater (c-1), it will be set to the\n  correct number (c-1) automatically.\n\n- **threshold**: `double`.\n\n  The threshold applied in the prediction. If the distance to the nearest neighbor\n  is larger than the threshold, this method returns -1.\n\n##### Return\n- **retval**: `FisherFaceRecognizer`","ref":"Evision.Face.FisherFaceRecognizer.html#create/1"},{"type":"function","title":"Notes: - Evision.Face.FisherFaceRecognizer.create/1","doc":"- Training and prediction must be done on grayscale images, use cvtColor to convert between the\n  color spaces.\n\n- **THE FISHERFACES METHOD MAKES THE ASSUMPTION, THAT THE TRAINING AND TEST IMAGES ARE OF EQUAL\n  SIZE.** (caps-lock, because I got so many mails asking for this). You have to make sure your\n  input data has the correct shape, else a meaningful exception is thrown. Use resize to resize\n  the images.\n\n- This model does not support updating.","ref":"Evision.Face.FisherFaceRecognizer.html#create/1-notes"},{"type":"function","title":"Model internal data: - Evision.Face.FisherFaceRecognizer.create/1","doc":"- num_components see FisherFaceRecognizer::create.\n- threshold see FisherFaceRecognizer::create.\n- eigenvalues The eigenvalues for this Linear Discriminant Analysis (ordered descending).\n- eigenvectors The eigenvectors for this Linear Discriminant Analysis (ordered by their\n  eigenvalue).\n\n- mean The sample mean calculated from the training data.\n- projections The projections of the training data.\n- labels The labels corresponding to the projections.\n\nPython prototype (for reference only):\n```python3\ncreate([, num_components[, threshold]]) -> retval\n```","ref":"Evision.Face.FisherFaceRecognizer.html#create/1-model-internal-data"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Face.FisherFaceRecognizer.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Face.FisherFaceRecognizer.html#empty/1"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Face.FisherFaceRecognizer.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Face.FisherFaceRecognizer.html#getDefaultName/1"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.getEigenValues/1","doc":"getEigenValues\n\n##### Positional Arguments\n- **self**: `Evision.Face.FisherFaceRecognizer.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetEigenValues() -> retval\n```","ref":"Evision.Face.FisherFaceRecognizer.html#getEigenValues/1"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.getEigenVectors/1","doc":"getEigenVectors\n\n##### Positional Arguments\n- **self**: `Evision.Face.FisherFaceRecognizer.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetEigenVectors() -> retval\n```","ref":"Evision.Face.FisherFaceRecognizer.html#getEigenVectors/1"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.getLabelInfo/1","doc":"","ref":"Evision.Face.FisherFaceRecognizer.html#getLabelInfo/1"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.getLabelInfo/2","doc":"Gets string information by label.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FisherFaceRecognizer.t()`\n- **label**: `integer()`\n\n##### Return\n- **retval**: `String`\n\nIf an unknown label id is provided or there is no label information associated with the specified\nlabel id the method returns an empty string.\n\nPython prototype (for reference only):\n```python3\ngetLabelInfo(label) -> retval\n```","ref":"Evision.Face.FisherFaceRecognizer.html#getLabelInfo/2"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.getLabels/1","doc":"getLabels\n\n##### Positional Arguments\n- **self**: `Evision.Face.FisherFaceRecognizer.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetLabels() -> retval\n```","ref":"Evision.Face.FisherFaceRecognizer.html#getLabels/1"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.getLabelsByString/1","doc":"","ref":"Evision.Face.FisherFaceRecognizer.html#getLabelsByString/1"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.getLabelsByString/2","doc":"Gets vector of labels by string.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FisherFaceRecognizer.t()`\n- **str**: `String`\n\n##### Return\n- **retval**: `[integer()]`\n\nThe function searches for the labels containing the specified sub-string in the associated string\ninfo.\n\nPython prototype (for reference only):\n```python3\ngetLabelsByString(str) -> retval\n```","ref":"Evision.Face.FisherFaceRecognizer.html#getLabelsByString/2"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.getMean/1","doc":"getMean\n\n##### Positional Arguments\n- **self**: `Evision.Face.FisherFaceRecognizer.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetMean() -> retval\n```","ref":"Evision.Face.FisherFaceRecognizer.html#getMean/1"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.getNumComponents/1","doc":"getNumComponents\n\n##### Positional Arguments\n- **self**: `Evision.Face.FisherFaceRecognizer.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setNumComponents/2`\n\nPython prototype (for reference only):\n```python3\ngetNumComponents() -> retval\n```","ref":"Evision.Face.FisherFaceRecognizer.html#getNumComponents/1"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.getProjections/1","doc":"getProjections\n\n##### Positional Arguments\n- **self**: `Evision.Face.FisherFaceRecognizer.t()`\n\n##### Return\n- **retval**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\ngetProjections() -> retval\n```","ref":"Evision.Face.FisherFaceRecognizer.html#getProjections/1"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.getThreshold/1","doc":"getThreshold\n\n##### Positional Arguments\n- **self**: `Evision.Face.FisherFaceRecognizer.t()`\n\n##### Return\n- **retval**: `double`\n\n@see `setThreshold/2`\n\nPython prototype (for reference only):\n```python3\ngetThreshold() -> retval\n```","ref":"Evision.Face.FisherFaceRecognizer.html#getThreshold/1"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.predict/1","doc":"","ref":"Evision.Face.FisherFaceRecognizer.html#predict/1"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.predict/2","doc":"Predicts a label and associated confidence (e.g. distance) for a given input image.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FisherFaceRecognizer.t()`\n- **src**: `Evision.Mat`.\n\n  Sample image to get a prediction from.\n\n##### Return\n- **label**: `integer()`.\n\n  The predicted label for the given image.\n\n- **confidence**: `double`.\n\n  Associated confidence (e.g. distance) for the predicted label.\n\nThe suffix const means that prediction does not affect the internal model state, so the method can\nbe safely called from within different threads.\nThe following example shows how to get a prediction from a trained model:\n```\nusing namespace cv;\n// Do your initialization here (create the cv::FaceRecognizer model) ...\n// ...\n// Read in a sample image:\nMat img = imread(\"person1/3.jpg\", IMREAD_GRAYSCALE);\n// And get a prediction from the cv::FaceRecognizer:\nint predicted = model->predict(img);\n```\nOr to get a prediction and the associated confidence (e.g. distance):\n```\nusing namespace cv;\n// Do your initialization here (create the cv::FaceRecognizer model) ...\n// ...\nMat img = imread(\"person1/3.jpg\", IMREAD_GRAYSCALE);\n// Some variables for the predicted label and associated confidence (e.g. distance):\nint predicted_label = -1;\ndouble predicted_confidence = 0.0;\n// Get the prediction and associated confidence from the model\nmodel->predict(img, predicted_label, predicted_confidence);\n```\n\nPython prototype (for reference only):\n```python3\npredict(src) -> label, confidence\n```","ref":"Evision.Face.FisherFaceRecognizer.html#predict/2"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.predict_collect/1","doc":"","ref":"Evision.Face.FisherFaceRecognizer.html#predict_collect/1"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.predict_collect/3","doc":"- if implemented - send all result of prediction to collector that can be used for somehow custom result handling\n\n##### Positional Arguments\n- **self**: `Evision.Face.FisherFaceRecognizer.t()`\n- **src**: `Evision.Mat`.\n\n  Sample image to get a prediction from.\n\n- **collector**: `PredictCollector`.\n\n  User-defined collector object that accepts all results\n\nTo implement this method u just have to do same internal cycle as in predict(InputArray src, CV_OUT int &label, CV_OUT double &confidence) but\nnot try to get \"best@ result, just resend it to caller side with given collector\n\nPython prototype (for reference only):\n```python3\npredict_collect(src, collector) -> None\n```","ref":"Evision.Face.FisherFaceRecognizer.html#predict_collect/3"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.predict_label/1","doc":"","ref":"Evision.Face.FisherFaceRecognizer.html#predict_label/1"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.predict_label/2","doc":"predict_label\n\n##### Positional Arguments\n- **self**: `Evision.Face.FisherFaceRecognizer.t()`\n- **src**: `Evision.Mat`\n\n##### Return\n- **retval**: `integer()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\npredict_label(src) -> retval\n```","ref":"Evision.Face.FisherFaceRecognizer.html#predict_label/2"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.read/1","doc":"","ref":"Evision.Face.FisherFaceRecognizer.html#read/1"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.read/2","doc":"Loads a FaceRecognizer and its model state.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FisherFaceRecognizer.t()`\n- **filename**: `String`\n\nLoads a persisted model and state from a given XML or YAML file . Every FaceRecognizer has to\noverwrite FaceRecognizer::load(FileStorage& fs) to enable loading the model state.\nFaceRecognizer::load(FileStorage& fs) in turn gets called by\nFaceRecognizer::load(const String& filename), to ease saving a model.\n\nPython prototype (for reference only):\n```python3\nread(filename) -> None\n```","ref":"Evision.Face.FisherFaceRecognizer.html#read/2"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.save/1","doc":"","ref":"Evision.Face.FisherFaceRecognizer.html#save/1"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Face.FisherFaceRecognizer.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Face.FisherFaceRecognizer.html#save/2"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.setLabelInfo/1","doc":"","ref":"Evision.Face.FisherFaceRecognizer.html#setLabelInfo/1"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.setLabelInfo/3","doc":"Sets string info for the specified model's label.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FisherFaceRecognizer.t()`\n- **label**: `integer()`\n- **strInfo**: `String`\n\nThe string info is replaced by the provided value if it was set before for the specified label.\n\nPython prototype (for reference only):\n```python3\nsetLabelInfo(label, strInfo) -> None\n```","ref":"Evision.Face.FisherFaceRecognizer.html#setLabelInfo/3"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.setNumComponents/1","doc":"","ref":"Evision.Face.FisherFaceRecognizer.html#setNumComponents/1"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.setNumComponents/2","doc":"setNumComponents\n\n##### Positional Arguments\n- **self**: `Evision.Face.FisherFaceRecognizer.t()`\n- **val**: `integer()`\n\n@see `getNumComponents/1`\n\nPython prototype (for reference only):\n```python3\nsetNumComponents(val) -> None\n```","ref":"Evision.Face.FisherFaceRecognizer.html#setNumComponents/2"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.setThreshold/1","doc":"","ref":"Evision.Face.FisherFaceRecognizer.html#setThreshold/1"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.setThreshold/2","doc":"setThreshold\n\n##### Positional Arguments\n- **self**: `Evision.Face.FisherFaceRecognizer.t()`\n- **val**: `double`\n\n@see `getThreshold/1`\n\nPython prototype (for reference only):\n```python3\nsetThreshold(val) -> None\n```","ref":"Evision.Face.FisherFaceRecognizer.html#setThreshold/2"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.train/1","doc":"","ref":"Evision.Face.FisherFaceRecognizer.html#train/1"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.train/3","doc":"Trains a FaceRecognizer with given data and associated labels.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FisherFaceRecognizer.t()`\n- **src**: `[Evision.Mat]`.\n\n  The training images, that means the faces you want to learn. The data has to be\n  given as a vector\\ .\n\n- **labels**: `Evision.Mat`.\n\n  The labels corresponding to the images have to be given either as a vector\\ \n  or a Mat of type CV_32SC1.\n\nThe following source code snippet shows you how to learn a Fisherfaces model on a given set of\nimages. The images are read with imread and pushed into a std::vector\\ . The labels of each\nimage are stored within a std::vector\\  (you could also use a Mat of type CV_32SC1). Think of\nthe label as the subject (the person) this image belongs to, so same subjects (persons) should have\nthe same label. For the available FaceRecognizer you don't have to pay any attention to the order of\nthe labels, just make sure same persons have the same label:\n```\n// holds images and labels\nvector  images;\nvector  labels;\n// using Mat of type CV_32SC1\n// Mat labels(number_of_samples, 1, CV_32SC1);\n// images for first person\nimages.push_back(imread(\"person0/0.jpg\", IMREAD_GRAYSCALE)); labels.push_back(0);\nimages.push_back(imread(\"person0/1.jpg\", IMREAD_GRAYSCALE)); labels.push_back(0);\nimages.push_back(imread(\"person0/2.jpg\", IMREAD_GRAYSCALE)); labels.push_back(0);\n// images for second person\nimages.push_back(imread(\"person1/0.jpg\", IMREAD_GRAYSCALE)); labels.push_back(1);\nimages.push_back(imread(\"person1/1.jpg\", IMREAD_GRAYSCALE)); labels.push_back(1);\nimages.push_back(imread(\"person1/2.jpg\", IMREAD_GRAYSCALE)); labels.push_back(1);\n```\nNow that you have read some images, we can create a new FaceRecognizer. In this example I'll create\na Fisherfaces model and decide to keep all of the possible Fisherfaces:\n```\n// Create a new Fisherfaces model and retain all available Fisherfaces,\n// this is the most common usage of this specific FaceRecognizer:\n//\nPtr  model =  FisherFaceRecognizer::create();\n```\nAnd finally train it on the given dataset (the face images and labels):\n```\n// This is the common interface to train all of the available cv::FaceRecognizer\n// implementations:\n//\nmodel->train(images, labels);\n```\n\nPython prototype (for reference only):\n```python3\ntrain(src, labels) -> None\n```","ref":"Evision.Face.FisherFaceRecognizer.html#train/3"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.update/1","doc":"","ref":"Evision.Face.FisherFaceRecognizer.html#update/1"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.update/3","doc":"Updates a FaceRecognizer with given data and associated labels.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FisherFaceRecognizer.t()`\n- **src**: `[Evision.Mat]`.\n\n  The training images, that means the faces you want to learn. The data has to be given\n  as a vector\\ .\n\n- **labels**: `Evision.Mat`.\n\n  The labels corresponding to the images have to be given either as a vector\\  or\n  a Mat of type CV_32SC1.\n\nThis method updates a (probably trained) FaceRecognizer, but only if the algorithm supports it. The\nLocal Binary Patterns Histograms (LBPH) recognizer (see createLBPHFaceRecognizer) can be updated.\nFor the Eigenfaces and Fisherfaces method, this is algorithmically not possible and you have to\nre-estimate the model with FaceRecognizer::train. In any case, a call to train empties the existing\nmodel and learns a new model, while update does not delete any model data.\n```\n// Create a new LBPH model (it can be updated) and use the default parameters,\n// this is the most common usage of this specific FaceRecognizer:\n//\nPtr  model =  LBPHFaceRecognizer::create();\n// This is the common interface to train all of the available cv::FaceRecognizer\n// implementations:\n//\nmodel->train(images, labels);\n// Some containers to hold new image:\nvector  newImages;\nvector  newLabels;\n// You should add some images to the containers:\n//\n// ...\n//\n// Now updating the model is as easy as calling:\nmodel->update(newImages,newLabels);\n// This will preserve the old model data and extend the existing model\n// with the new features extracted from newImages!\n```\nCalling update on an Eigenfaces model (see EigenFaceRecognizer::create), which doesn't support\nupdating, will throw an error similar to:\n```\nOpenCV Error: The function/feature is not implemented (This FaceRecognizer (FaceRecognizer.Eigenfaces) does not support updating, you have to use FaceRecognizer::train to update it.) in update, file /home/philipp/git/opencv/modules/contrib/src/facerec.cpp, line 305\nterminate called after throwing an instance of 'cv::Exception'\n```\n**Note**: The FaceRecognizer does not store your training images, because this would be very\nmemory intense and it's not the responsibility of te FaceRecognizer to do so. The caller is\nresponsible for maintaining the dataset, he want to work with.\n\nPython prototype (for reference only):\n```python3\nupdate(src, labels) -> None\n```","ref":"Evision.Face.FisherFaceRecognizer.html#update/3"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.write/1","doc":"","ref":"Evision.Face.FisherFaceRecognizer.html#write/1"},{"type":"function","title":"Evision.Face.FisherFaceRecognizer.write/2","doc":"Saves a FaceRecognizer and its model state.\n\n##### Positional Arguments\n- **self**: `Evision.Face.FisherFaceRecognizer.t()`\n- **filename**: `String`.\n\n  The filename to store this FaceRecognizer to (either XML/YAML).\n\nSaves this model to a given filename, either as XML or YAML.\n\nEvery FaceRecognizer overwrites FaceRecognizer::save(FileStorage& fs) to save the internal model\nstate. FaceRecognizer::save(const String& filename) saves the state of a model to the given\nfilename.\nThe suffix const means that prediction does not affect the internal model state, so the method can\nbe safely called from within different threads.\n\nPython prototype (for reference only):\n```python3\nwrite(filename) -> None\n```","ref":"Evision.Face.FisherFaceRecognizer.html#write/2"},{"type":"type","title":"Evision.Face.FisherFaceRecognizer.t/0","doc":"Type that represents an `Face.FisherFaceRecognizer` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Face.FisherFaceRecognizer.html#t:t/0"},{"type":"module","title":"Evision.Face.LBPHFaceRecognizer","doc":"","ref":"Evision.Face.LBPHFaceRecognizer.html"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#clear/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.create/0","doc":"create\n##### Keyword Arguments\n- **radius**: `integer()`.\n\n  The radius used for building the Circular Local Binary Pattern. The greater the\n  radius, the smoother the image but more spatial information you can get.\n\n- **neighbors**: `integer()`.\n\n  The number of sample points to build a Circular Local Binary Pattern from. An\n  appropriate value is to use `8` sample points. Keep in mind: the more sample points you include,\n  the higher the computational cost.\n\n- **grid_x**: `integer()`.\n\n  The number of cells in the horizontal direction, 8 is a common value used in\n  publications. The more cells, the finer the grid, the higher the dimensionality of the resulting\n  feature vector.\n\n- **grid_y**: `integer()`.\n\n  The number of cells in the vertical direction, 8 is a common value used in\n  publications. The more cells, the finer the grid, the higher the dimensionality of the resulting\n  feature vector.\n\n- **threshold**: `double`.\n\n  The threshold applied in the prediction. If the distance to the nearest neighbor\n  is larger than the threshold, this method returns -1.\n\n##### Return\n- **retval**: `LBPHFaceRecognizer`","ref":"Evision.Face.LBPHFaceRecognizer.html#create/0"},{"type":"function","title":"Notes: - Evision.Face.LBPHFaceRecognizer.create/0","doc":"- The Circular Local Binary Patterns (used in training and prediction) expect the data given as\n  grayscale images, use cvtColor to convert between the color spaces.\n\n- This model supports updating.","ref":"Evision.Face.LBPHFaceRecognizer.html#create/0-notes"},{"type":"function","title":"Model internal data: - Evision.Face.LBPHFaceRecognizer.create/0","doc":"- radius see LBPHFaceRecognizer::create.\n- neighbors see LBPHFaceRecognizer::create.\n- grid_x see LLBPHFaceRecognizer::create.\n- grid_y see LBPHFaceRecognizer::create.\n- threshold see LBPHFaceRecognizer::create.\n- histograms Local Binary Patterns Histograms calculated from the given training data (empty if\n  none was given).\n\n- labels Labels corresponding to the calculated Local Binary Patterns Histograms.\n\nPython prototype (for reference only):\n```python3\ncreate([, radius[, neighbors[, grid_x[, grid_y[, threshold]]]]]) -> retval\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#create/0-model-internal-data"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.create/1","doc":"create\n##### Keyword Arguments\n- **radius**: `integer()`.\n\n  The radius used for building the Circular Local Binary Pattern. The greater the\n  radius, the smoother the image but more spatial information you can get.\n\n- **neighbors**: `integer()`.\n\n  The number of sample points to build a Circular Local Binary Pattern from. An\n  appropriate value is to use `8` sample points. Keep in mind: the more sample points you include,\n  the higher the computational cost.\n\n- **grid_x**: `integer()`.\n\n  The number of cells in the horizontal direction, 8 is a common value used in\n  publications. The more cells, the finer the grid, the higher the dimensionality of the resulting\n  feature vector.\n\n- **grid_y**: `integer()`.\n\n  The number of cells in the vertical direction, 8 is a common value used in\n  publications. The more cells, the finer the grid, the higher the dimensionality of the resulting\n  feature vector.\n\n- **threshold**: `double`.\n\n  The threshold applied in the prediction. If the distance to the nearest neighbor\n  is larger than the threshold, this method returns -1.\n\n##### Return\n- **retval**: `LBPHFaceRecognizer`","ref":"Evision.Face.LBPHFaceRecognizer.html#create/1"},{"type":"function","title":"Notes: - Evision.Face.LBPHFaceRecognizer.create/1","doc":"- The Circular Local Binary Patterns (used in training and prediction) expect the data given as\n  grayscale images, use cvtColor to convert between the color spaces.\n\n- This model supports updating.","ref":"Evision.Face.LBPHFaceRecognizer.html#create/1-notes"},{"type":"function","title":"Model internal data: - Evision.Face.LBPHFaceRecognizer.create/1","doc":"- radius see LBPHFaceRecognizer::create.\n- neighbors see LBPHFaceRecognizer::create.\n- grid_x see LLBPHFaceRecognizer::create.\n- grid_y see LBPHFaceRecognizer::create.\n- threshold see LBPHFaceRecognizer::create.\n- histograms Local Binary Patterns Histograms calculated from the given training data (empty if\n  none was given).\n\n- labels Labels corresponding to the calculated Local Binary Patterns Histograms.\n\nPython prototype (for reference only):\n```python3\ncreate([, radius[, neighbors[, grid_x[, grid_y[, threshold]]]]]) -> retval\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#create/1-model-internal-data"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#empty/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#getDefaultName/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.getGridX/1","doc":"getGridX\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setGridX/2`\n\nPython prototype (for reference only):\n```python3\ngetGridX() -> retval\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#getGridX/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.getGridY/1","doc":"getGridY\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setGridY/2`\n\nPython prototype (for reference only):\n```python3\ngetGridY() -> retval\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#getGridY/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.getHistograms/1","doc":"getHistograms\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n\n##### Return\n- **retval**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\ngetHistograms() -> retval\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#getHistograms/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.getLabelInfo/1","doc":"","ref":"Evision.Face.LBPHFaceRecognizer.html#getLabelInfo/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.getLabelInfo/2","doc":"Gets string information by label.\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n- **label**: `integer()`\n\n##### Return\n- **retval**: `String`\n\nIf an unknown label id is provided or there is no label information associated with the specified\nlabel id the method returns an empty string.\n\nPython prototype (for reference only):\n```python3\ngetLabelInfo(label) -> retval\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#getLabelInfo/2"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.getLabels/1","doc":"getLabels\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetLabels() -> retval\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#getLabels/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.getLabelsByString/1","doc":"","ref":"Evision.Face.LBPHFaceRecognizer.html#getLabelsByString/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.getLabelsByString/2","doc":"Gets vector of labels by string.\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n- **str**: `String`\n\n##### Return\n- **retval**: `[integer()]`\n\nThe function searches for the labels containing the specified sub-string in the associated string\ninfo.\n\nPython prototype (for reference only):\n```python3\ngetLabelsByString(str) -> retval\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#getLabelsByString/2"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.getNeighbors/1","doc":"getNeighbors\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setNeighbors/2`\n\nPython prototype (for reference only):\n```python3\ngetNeighbors() -> retval\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#getNeighbors/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.getRadius/1","doc":"getRadius\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setRadius/2`\n\nPython prototype (for reference only):\n```python3\ngetRadius() -> retval\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#getRadius/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.getThreshold/1","doc":"getThreshold\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n\n##### Return\n- **retval**: `double`\n\n@see `setThreshold/2`\n\nPython prototype (for reference only):\n```python3\ngetThreshold() -> retval\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#getThreshold/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.predict/1","doc":"","ref":"Evision.Face.LBPHFaceRecognizer.html#predict/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.predict/2","doc":"Predicts a label and associated confidence (e.g. distance) for a given input image.\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n- **src**: `Evision.Mat`.\n\n  Sample image to get a prediction from.\n\n##### Return\n- **label**: `integer()`.\n\n  The predicted label for the given image.\n\n- **confidence**: `double`.\n\n  Associated confidence (e.g. distance) for the predicted label.\n\nThe suffix const means that prediction does not affect the internal model state, so the method can\nbe safely called from within different threads.\nThe following example shows how to get a prediction from a trained model:\n```\nusing namespace cv;\n// Do your initialization here (create the cv::FaceRecognizer model) ...\n// ...\n// Read in a sample image:\nMat img = imread(\"person1/3.jpg\", IMREAD_GRAYSCALE);\n// And get a prediction from the cv::FaceRecognizer:\nint predicted = model->predict(img);\n```\nOr to get a prediction and the associated confidence (e.g. distance):\n```\nusing namespace cv;\n// Do your initialization here (create the cv::FaceRecognizer model) ...\n// ...\nMat img = imread(\"person1/3.jpg\", IMREAD_GRAYSCALE);\n// Some variables for the predicted label and associated confidence (e.g. distance):\nint predicted_label = -1;\ndouble predicted_confidence = 0.0;\n// Get the prediction and associated confidence from the model\nmodel->predict(img, predicted_label, predicted_confidence);\n```\n\nPython prototype (for reference only):\n```python3\npredict(src) -> label, confidence\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#predict/2"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.predict_collect/1","doc":"","ref":"Evision.Face.LBPHFaceRecognizer.html#predict_collect/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.predict_collect/3","doc":"- if implemented - send all result of prediction to collector that can be used for somehow custom result handling\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n- **src**: `Evision.Mat`.\n\n  Sample image to get a prediction from.\n\n- **collector**: `PredictCollector`.\n\n  User-defined collector object that accepts all results\n\nTo implement this method u just have to do same internal cycle as in predict(InputArray src, CV_OUT int &label, CV_OUT double &confidence) but\nnot try to get \"best@ result, just resend it to caller side with given collector\n\nPython prototype (for reference only):\n```python3\npredict_collect(src, collector) -> None\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#predict_collect/3"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.predict_label/1","doc":"","ref":"Evision.Face.LBPHFaceRecognizer.html#predict_label/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.predict_label/2","doc":"predict_label\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n- **src**: `Evision.Mat`\n\n##### Return\n- **retval**: `integer()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\npredict_label(src) -> retval\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#predict_label/2"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.read/1","doc":"","ref":"Evision.Face.LBPHFaceRecognizer.html#read/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.read/2","doc":"Loads a FaceRecognizer and its model state.\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n- **filename**: `String`\n\nLoads a persisted model and state from a given XML or YAML file . Every FaceRecognizer has to\noverwrite FaceRecognizer::load(FileStorage& fs) to enable loading the model state.\nFaceRecognizer::load(FileStorage& fs) in turn gets called by\nFaceRecognizer::load(const String& filename), to ease saving a model.\n\nPython prototype (for reference only):\n```python3\nread(filename) -> None\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#read/2"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.save/1","doc":"","ref":"Evision.Face.LBPHFaceRecognizer.html#save/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#save/2"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.setGridX/1","doc":"","ref":"Evision.Face.LBPHFaceRecognizer.html#setGridX/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.setGridX/2","doc":"setGridX\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n- **val**: `integer()`\n\n@see `getGridX/1`\n\nPython prototype (for reference only):\n```python3\nsetGridX(val) -> None\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#setGridX/2"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.setGridY/1","doc":"","ref":"Evision.Face.LBPHFaceRecognizer.html#setGridY/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.setGridY/2","doc":"setGridY\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n- **val**: `integer()`\n\n@see `getGridY/1`\n\nPython prototype (for reference only):\n```python3\nsetGridY(val) -> None\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#setGridY/2"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.setLabelInfo/1","doc":"","ref":"Evision.Face.LBPHFaceRecognizer.html#setLabelInfo/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.setLabelInfo/3","doc":"Sets string info for the specified model's label.\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n- **label**: `integer()`\n- **strInfo**: `String`\n\nThe string info is replaced by the provided value if it was set before for the specified label.\n\nPython prototype (for reference only):\n```python3\nsetLabelInfo(label, strInfo) -> None\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#setLabelInfo/3"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.setNeighbors/1","doc":"","ref":"Evision.Face.LBPHFaceRecognizer.html#setNeighbors/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.setNeighbors/2","doc":"setNeighbors\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n- **val**: `integer()`\n\n@see `getNeighbors/1`\n\nPython prototype (for reference only):\n```python3\nsetNeighbors(val) -> None\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#setNeighbors/2"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.setRadius/1","doc":"","ref":"Evision.Face.LBPHFaceRecognizer.html#setRadius/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.setRadius/2","doc":"setRadius\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n- **val**: `integer()`\n\n@see `getRadius/1`\n\nPython prototype (for reference only):\n```python3\nsetRadius(val) -> None\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#setRadius/2"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.setThreshold/1","doc":"","ref":"Evision.Face.LBPHFaceRecognizer.html#setThreshold/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.setThreshold/2","doc":"setThreshold\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n- **val**: `double`\n\n@see `getThreshold/1`\n\nPython prototype (for reference only):\n```python3\nsetThreshold(val) -> None\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#setThreshold/2"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.train/1","doc":"","ref":"Evision.Face.LBPHFaceRecognizer.html#train/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.train/3","doc":"Trains a FaceRecognizer with given data and associated labels.\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n- **src**: `[Evision.Mat]`.\n\n  The training images, that means the faces you want to learn. The data has to be\n  given as a vector\\ .\n\n- **labels**: `Evision.Mat`.\n\n  The labels corresponding to the images have to be given either as a vector\\ \n  or a Mat of type CV_32SC1.\n\nThe following source code snippet shows you how to learn a Fisherfaces model on a given set of\nimages. The images are read with imread and pushed into a std::vector\\ . The labels of each\nimage are stored within a std::vector\\  (you could also use a Mat of type CV_32SC1). Think of\nthe label as the subject (the person) this image belongs to, so same subjects (persons) should have\nthe same label. For the available FaceRecognizer you don't have to pay any attention to the order of\nthe labels, just make sure same persons have the same label:\n```\n// holds images and labels\nvector  images;\nvector  labels;\n// using Mat of type CV_32SC1\n// Mat labels(number_of_samples, 1, CV_32SC1);\n// images for first person\nimages.push_back(imread(\"person0/0.jpg\", IMREAD_GRAYSCALE)); labels.push_back(0);\nimages.push_back(imread(\"person0/1.jpg\", IMREAD_GRAYSCALE)); labels.push_back(0);\nimages.push_back(imread(\"person0/2.jpg\", IMREAD_GRAYSCALE)); labels.push_back(0);\n// images for second person\nimages.push_back(imread(\"person1/0.jpg\", IMREAD_GRAYSCALE)); labels.push_back(1);\nimages.push_back(imread(\"person1/1.jpg\", IMREAD_GRAYSCALE)); labels.push_back(1);\nimages.push_back(imread(\"person1/2.jpg\", IMREAD_GRAYSCALE)); labels.push_back(1);\n```\nNow that you have read some images, we can create a new FaceRecognizer. In this example I'll create\na Fisherfaces model and decide to keep all of the possible Fisherfaces:\n```\n// Create a new Fisherfaces model and retain all available Fisherfaces,\n// this is the most common usage of this specific FaceRecognizer:\n//\nPtr  model =  FisherFaceRecognizer::create();\n```\nAnd finally train it on the given dataset (the face images and labels):\n```\n// This is the common interface to train all of the available cv::FaceRecognizer\n// implementations:\n//\nmodel->train(images, labels);\n```\n\nPython prototype (for reference only):\n```python3\ntrain(src, labels) -> None\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#train/3"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.update/1","doc":"","ref":"Evision.Face.LBPHFaceRecognizer.html#update/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.update/3","doc":"Updates a FaceRecognizer with given data and associated labels.\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n- **src**: `[Evision.Mat]`.\n\n  The training images, that means the faces you want to learn. The data has to be given\n  as a vector\\ .\n\n- **labels**: `Evision.Mat`.\n\n  The labels corresponding to the images have to be given either as a vector\\  or\n  a Mat of type CV_32SC1.\n\nThis method updates a (probably trained) FaceRecognizer, but only if the algorithm supports it. The\nLocal Binary Patterns Histograms (LBPH) recognizer (see createLBPHFaceRecognizer) can be updated.\nFor the Eigenfaces and Fisherfaces method, this is algorithmically not possible and you have to\nre-estimate the model with FaceRecognizer::train. In any case, a call to train empties the existing\nmodel and learns a new model, while update does not delete any model data.\n```\n// Create a new LBPH model (it can be updated) and use the default parameters,\n// this is the most common usage of this specific FaceRecognizer:\n//\nPtr  model =  LBPHFaceRecognizer::create();\n// This is the common interface to train all of the available cv::FaceRecognizer\n// implementations:\n//\nmodel->train(images, labels);\n// Some containers to hold new image:\nvector  newImages;\nvector  newLabels;\n// You should add some images to the containers:\n//\n// ...\n//\n// Now updating the model is as easy as calling:\nmodel->update(newImages,newLabels);\n// This will preserve the old model data and extend the existing model\n// with the new features extracted from newImages!\n```\nCalling update on an Eigenfaces model (see EigenFaceRecognizer::create), which doesn't support\nupdating, will throw an error similar to:\n```\nOpenCV Error: The function/feature is not implemented (This FaceRecognizer (FaceRecognizer.Eigenfaces) does not support updating, you have to use FaceRecognizer::train to update it.) in update, file /home/philipp/git/opencv/modules/contrib/src/facerec.cpp, line 305\nterminate called after throwing an instance of 'cv::Exception'\n```\n**Note**: The FaceRecognizer does not store your training images, because this would be very\nmemory intense and it's not the responsibility of te FaceRecognizer to do so. The caller is\nresponsible for maintaining the dataset, he want to work with.\n\nPython prototype (for reference only):\n```python3\nupdate(src, labels) -> None\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#update/3"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.write/1","doc":"","ref":"Evision.Face.LBPHFaceRecognizer.html#write/1"},{"type":"function","title":"Evision.Face.LBPHFaceRecognizer.write/2","doc":"Saves a FaceRecognizer and its model state.\n\n##### Positional Arguments\n- **self**: `Evision.Face.LBPHFaceRecognizer.t()`\n- **filename**: `String`.\n\n  The filename to store this FaceRecognizer to (either XML/YAML).\n\nSaves this model to a given filename, either as XML or YAML.\n\nEvery FaceRecognizer overwrites FaceRecognizer::save(FileStorage& fs) to save the internal model\nstate. FaceRecognizer::save(const String& filename) saves the state of a model to the given\nfilename.\nThe suffix const means that prediction does not affect the internal model state, so the method can\nbe safely called from within different threads.\n\nPython prototype (for reference only):\n```python3\nwrite(filename) -> None\n```","ref":"Evision.Face.LBPHFaceRecognizer.html#write/2"},{"type":"type","title":"Evision.Face.LBPHFaceRecognizer.t/0","doc":"Type that represents an `Face.LBPHFaceRecognizer` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Face.LBPHFaceRecognizer.html#t:t/0"},{"type":"module","title":"Evision.Face.MACE","doc":"","ref":"Evision.Face.MACE.html"},{"type":"function","title":"Evision.Face.MACE.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Face.MACE.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Face.MACE.html#clear/1"},{"type":"function","title":"Evision.Face.MACE.create/0","doc":"constructor\n##### Keyword Arguments\n- **iMGSIZE**: `integer()`.\n\n  images will get resized to this (should be an even number)\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ncreate([, IMGSIZE]) -> retval\n```","ref":"Evision.Face.MACE.html#create/0"},{"type":"function","title":"Evision.Face.MACE.create/1","doc":"constructor\n##### Keyword Arguments\n- **iMGSIZE**: `integer()`.\n\n  images will get resized to this (should be an even number)\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ncreate([, IMGSIZE]) -> retval\n```","ref":"Evision.Face.MACE.html#create/1"},{"type":"function","title":"Evision.Face.MACE.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Face.MACE.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Face.MACE.html#empty/1"},{"type":"function","title":"Evision.Face.MACE.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Face.MACE.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Face.MACE.html#getDefaultName/1"},{"type":"function","title":"Evision.Face.MACE.load/1","doc":"constructor\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  build a new MACE instance from a pre-serialized FileStorage\n\n##### Keyword Arguments\n- **objname**: `String`.\n\n  (optional) top-level node in the FileStorage\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\nload(filename[, objname]) -> retval\n```","ref":"Evision.Face.MACE.html#load/1"},{"type":"function","title":"Evision.Face.MACE.load/2","doc":"constructor\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  build a new MACE instance from a pre-serialized FileStorage\n\n##### Keyword Arguments\n- **objname**: `String`.\n\n  (optional) top-level node in the FileStorage\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\nload(filename[, objname]) -> retval\n```","ref":"Evision.Face.MACE.html#load/2"},{"type":"function","title":"Evision.Face.MACE.read/1","doc":"","ref":"Evision.Face.MACE.html#read/1"},{"type":"function","title":"Evision.Face.MACE.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Face.MACE.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Face.MACE.html#read/2"},{"type":"function","title":"Evision.Face.MACE.salt/1","doc":"","ref":"Evision.Face.MACE.html#salt/1"},{"type":"function","title":"Evision.Face.MACE.salt/2","doc":"optionally encrypt images with random convolution\n\n##### Positional Arguments\n- **self**: `Evision.Face.MACE.t()`\n- **passphrase**: `String`.\n\n  a crc64 random seed will get generated from this\n\nPython prototype (for reference only):\n```python3\nsalt(passphrase) -> None\n```","ref":"Evision.Face.MACE.html#salt/2"},{"type":"function","title":"Evision.Face.MACE.same/1","doc":"","ref":"Evision.Face.MACE.html#same/1"},{"type":"function","title":"Evision.Face.MACE.same/2","doc":"correlate query img and threshold to min class value\n\n##### Positional Arguments\n- **self**: `Evision.Face.MACE.t()`\n- **query**: `Evision.Mat`.\n\n  a Mat with query image\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nsame(query) -> retval\n```","ref":"Evision.Face.MACE.html#same/2"},{"type":"function","title":"Evision.Face.MACE.save/1","doc":"","ref":"Evision.Face.MACE.html#save/1"},{"type":"function","title":"Evision.Face.MACE.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Face.MACE.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Face.MACE.html#save/2"},{"type":"function","title":"Evision.Face.MACE.train/1","doc":"","ref":"Evision.Face.MACE.html#train/1"},{"type":"function","title":"Evision.Face.MACE.train/2","doc":"train it on positive features\ncompute the mace filter: `h = D(-1) * X * (X(+) * D(-1) * X)(-1) * C`\nalso calculate a minimal threshold for this class, the smallest self-similarity from the train images\n\n##### Positional Arguments\n- **self**: `Evision.Face.MACE.t()`\n- **images**: `[Evision.Mat]`.\n\n  a vector  with the train images\n\nPython prototype (for reference only):\n```python3\ntrain(images) -> None\n```","ref":"Evision.Face.MACE.html#train/2"},{"type":"function","title":"Evision.Face.MACE.write/1","doc":"","ref":"Evision.Face.MACE.html#write/1"},{"type":"function","title":"Evision.Face.MACE.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Face.MACE.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Face.MACE.html#write/2"},{"type":"function","title":"Evision.Face.MACE.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Face.MACE.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Face.MACE.html#write/3"},{"type":"type","title":"Evision.Face.MACE.t/0","doc":"Type that represents an `Face.MACE` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Face.MACE.html#t:t/0"},{"type":"module","title":"Evision.Face.PredictCollector","doc":"","ref":"Evision.Face.PredictCollector.html"},{"type":"type","title":"Evision.Face.PredictCollector.t/0","doc":"Type that represents an `Face.PredictCollector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Face.PredictCollector.html#t:t/0"},{"type":"module","title":"Evision.Face.StandardCollector","doc":"","ref":"Evision.Face.StandardCollector.html"},{"type":"function","title":"Evision.Face.StandardCollector.create/0","doc":"Static constructor\n##### Keyword Arguments\n- **threshold**: `double`.\n\n  set threshold\n\n##### Return\n- **retval**: `StandardCollector`\n\nPython prototype (for reference only):\n```python3\ncreate([, threshold]) -> retval\n```","ref":"Evision.Face.StandardCollector.html#create/0"},{"type":"function","title":"Evision.Face.StandardCollector.create/1","doc":"Static constructor\n##### Keyword Arguments\n- **threshold**: `double`.\n\n  set threshold\n\n##### Return\n- **retval**: `StandardCollector`\n\nPython prototype (for reference only):\n```python3\ncreate([, threshold]) -> retval\n```","ref":"Evision.Face.StandardCollector.html#create/1"},{"type":"function","title":"Evision.Face.StandardCollector.getMinDist/1","doc":"Returns minimal distance value\n\n##### Positional Arguments\n- **self**: `Evision.Face.StandardCollector.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMinDist() -> retval\n```","ref":"Evision.Face.StandardCollector.html#getMinDist/1"},{"type":"function","title":"Evision.Face.StandardCollector.getMinLabel/1","doc":"Returns label with minimal distance\n\n##### Positional Arguments\n- **self**: `Evision.Face.StandardCollector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMinLabel() -> retval\n```","ref":"Evision.Face.StandardCollector.html#getMinLabel/1"},{"type":"function","title":"Evision.Face.StandardCollector.getResults/1","doc":"Return results as vector\n\n##### Positional Arguments\n- **self**: `Evision.Face.StandardCollector.t()`\n\n##### Keyword Arguments\n- **sorted**: `bool`.\n\n  If set, results will be sorted by distance\n  Each values is a pair of label and distance.\n\n##### Return\n- **retval**: `[pair ]`\n\nPython prototype (for reference only):\n```python3\ngetResults([, sorted]) -> retval\n```","ref":"Evision.Face.StandardCollector.html#getResults/1"},{"type":"function","title":"Evision.Face.StandardCollector.getResults/2","doc":"Return results as vector\n\n##### Positional Arguments\n- **self**: `Evision.Face.StandardCollector.t()`\n\n##### Keyword Arguments\n- **sorted**: `bool`.\n\n  If set, results will be sorted by distance\n  Each values is a pair of label and distance.\n\n##### Return\n- **retval**: `[pair ]`\n\nPython prototype (for reference only):\n```python3\ngetResults([, sorted]) -> retval\n```","ref":"Evision.Face.StandardCollector.html#getResults/2"},{"type":"type","title":"Evision.Face.StandardCollector.t/0","doc":"Type that represents an `Face.StandardCollector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Face.StandardCollector.html#t:t/0"},{"type":"module","title":"Evision.FaceDetectorYN","doc":"","ref":"Evision.FaceDetectorYN.html"},{"type":"function","title":"Evision.FaceDetectorYN.create/1","doc":"","ref":"Evision.FaceDetectorYN.html#create/1"},{"type":"function","title":"Evision.FaceDetectorYN.create/3","doc":"Creates an instance of face detector class with given parameters\n\n##### Positional Arguments\n- **model**: `String`.\n\n  the path to the requested model\n\n- **config**: `String`.\n\n  the path to the config file for compability, which is not requested for ONNX models\n\n- **input_size**: `Size`.\n\n  the size of the input image\n\n##### Keyword Arguments\n- **score_threshold**: `float`.\n\n  the threshold to filter out bounding boxes of score smaller than the given value\n\n- **nms_threshold**: `float`.\n\n  the threshold to suppress bounding boxes of IoU bigger than the given value\n\n- **top_k**: `integer()`.\n\n  keep top K bboxes before NMS\n\n- **backend_id**: `integer()`.\n\n  the id of backend\n\n- **target_id**: `integer()`.\n\n  the id of target device\n\n##### Return\n- **retval**: `Evision.FaceDetectorYN.t()`\n\nPython prototype (for reference only):\n```python3\ncreate(model, config, input_size[, score_threshold[, nms_threshold[, top_k[, backend_id[, target_id]]]]]) -> retval\n```","ref":"Evision.FaceDetectorYN.html#create/3"},{"type":"function","title":"Evision.FaceDetectorYN.create/4","doc":"#### Variant 1:\ncreate\n\n##### Positional Arguments\n- **framework**: `String`.\n\n  Name of origin framework\n\n- **bufferModel**: `[uchar]`.\n\n  A buffer with a content of binary file with weights\n\n- **bufferConfig**: `[uchar]`.\n\n  A buffer with a content of text file contains network configuration\n\n- **input_size**: `Size`.\n\n  the size of the input image\n\n##### Keyword Arguments\n- **score_threshold**: `float`.\n\n  the threshold to filter out bounding boxes of score smaller than the given value\n\n- **nms_threshold**: `float`.\n\n  the threshold to suppress bounding boxes of IoU bigger than the given value\n\n- **top_k**: `integer()`.\n\n  keep top K bboxes before NMS\n\n- **backend_id**: `integer()`.\n\n  the id of backend\n\n- **target_id**: `integer()`.\n\n  the id of target device\n\n##### Return\n- **retval**: `Evision.FaceDetectorYN.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncreate(framework, bufferModel, bufferConfig, input_size[, score_threshold[, nms_threshold[, top_k[, backend_id[, target_id]]]]]) -> retval\n```\n#### Variant 2:\nCreates an instance of face detector class with given parameters\n\n##### Positional Arguments\n- **model**: `String`.\n\n  the path to the requested model\n\n- **config**: `String`.\n\n  the path to the config file for compability, which is not requested for ONNX models\n\n- **input_size**: `Size`.\n\n  the size of the input image\n\n##### Keyword Arguments\n- **score_threshold**: `float`.\n\n  the threshold to filter out bounding boxes of score smaller than the given value\n\n- **nms_threshold**: `float`.\n\n  the threshold to suppress bounding boxes of IoU bigger than the given value\n\n- **top_k**: `integer()`.\n\n  keep top K bboxes before NMS\n\n- **backend_id**: `integer()`.\n\n  the id of backend\n\n- **target_id**: `integer()`.\n\n  the id of target device\n\n##### Return\n- **retval**: `Evision.FaceDetectorYN.t()`\n\nPython prototype (for reference only):\n```python3\ncreate(model, config, input_size[, score_threshold[, nms_threshold[, top_k[, backend_id[, target_id]]]]]) -> retval\n```","ref":"Evision.FaceDetectorYN.html#create/4"},{"type":"function","title":"Evision.FaceDetectorYN.create/5","doc":"create\n\n##### Positional Arguments\n- **framework**: `String`.\n\n  Name of origin framework\n\n- **bufferModel**: `[uchar]`.\n\n  A buffer with a content of binary file with weights\n\n- **bufferConfig**: `[uchar]`.\n\n  A buffer with a content of text file contains network configuration\n\n- **input_size**: `Size`.\n\n  the size of the input image\n\n##### Keyword Arguments\n- **score_threshold**: `float`.\n\n  the threshold to filter out bounding boxes of score smaller than the given value\n\n- **nms_threshold**: `float`.\n\n  the threshold to suppress bounding boxes of IoU bigger than the given value\n\n- **top_k**: `integer()`.\n\n  keep top K bboxes before NMS\n\n- **backend_id**: `integer()`.\n\n  the id of backend\n\n- **target_id**: `integer()`.\n\n  the id of target device\n\n##### Return\n- **retval**: `Evision.FaceDetectorYN.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncreate(framework, bufferModel, bufferConfig, input_size[, score_threshold[, nms_threshold[, top_k[, backend_id[, target_id]]]]]) -> retval\n```","ref":"Evision.FaceDetectorYN.html#create/5"},{"type":"function","title":"Evision.FaceDetectorYN.detect/1","doc":"","ref":"Evision.FaceDetectorYN.html#detect/1"},{"type":"function","title":"Evision.FaceDetectorYN.detect/2","doc":"Detects faces in the input image. Following is an example output.\n\n##### Positional Arguments\n- **self**: `Evision.FaceDetectorYN.t()`\n- **image**: `Evision.Mat`.\n\n  an image to detect\n\n##### Return\n- **retval**: `integer()`\n- **faces**: `Evision.Mat.t()`.\n\n  detection results stored in a 2D cv::Mat of shape [num_faces, 15]\n  - 0-1: x, y of bbox top left corner\n  - 2-3: width, height of bbox\n  - 4-5: x, y of right eye (blue point in the example image)\n  - 6-7: x, y of left eye (red point in the example image)\n  - 8-9: x, y of nose tip (green point in the example image)\n  - 10-11: x, y of right corner of mouth (pink point in the example image)\n  - 12-13: x, y of left corner of mouth (yellow point in the example image)\n  - 14: face score\n\n ![image](pics/lena-face-detection.jpg)\n\nPython prototype (for reference only):\n```python3\ndetect(image[, faces]) -> retval, faces\n```","ref":"Evision.FaceDetectorYN.html#detect/2"},{"type":"function","title":"Evision.FaceDetectorYN.detect/3","doc":"Detects faces in the input image. Following is an example output.\n\n##### Positional Arguments\n- **self**: `Evision.FaceDetectorYN.t()`\n- **image**: `Evision.Mat`.\n\n  an image to detect\n\n##### Return\n- **retval**: `integer()`\n- **faces**: `Evision.Mat.t()`.\n\n  detection results stored in a 2D cv::Mat of shape [num_faces, 15]\n  - 0-1: x, y of bbox top left corner\n  - 2-3: width, height of bbox\n  - 4-5: x, y of right eye (blue point in the example image)\n  - 6-7: x, y of left eye (red point in the example image)\n  - 8-9: x, y of nose tip (green point in the example image)\n  - 10-11: x, y of right corner of mouth (pink point in the example image)\n  - 12-13: x, y of left corner of mouth (yellow point in the example image)\n  - 14: face score\n\n ![image](pics/lena-face-detection.jpg)\n\nPython prototype (for reference only):\n```python3\ndetect(image[, faces]) -> retval, faces\n```","ref":"Evision.FaceDetectorYN.html#detect/3"},{"type":"function","title":"Evision.FaceDetectorYN.getInputSize/1","doc":"getInputSize\n\n##### Positional Arguments\n- **self**: `Evision.FaceDetectorYN.t()`\n\n##### Return\n- **retval**: `Size`\n\nPython prototype (for reference only):\n```python3\ngetInputSize() -> retval\n```","ref":"Evision.FaceDetectorYN.html#getInputSize/1"},{"type":"function","title":"Evision.FaceDetectorYN.getNMSThreshold/1","doc":"getNMSThreshold\n\n##### Positional Arguments\n- **self**: `Evision.FaceDetectorYN.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetNMSThreshold() -> retval\n```","ref":"Evision.FaceDetectorYN.html#getNMSThreshold/1"},{"type":"function","title":"Evision.FaceDetectorYN.getScoreThreshold/1","doc":"getScoreThreshold\n\n##### Positional Arguments\n- **self**: `Evision.FaceDetectorYN.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetScoreThreshold() -> retval\n```","ref":"Evision.FaceDetectorYN.html#getScoreThreshold/1"},{"type":"function","title":"Evision.FaceDetectorYN.getTopK/1","doc":"getTopK\n\n##### Positional Arguments\n- **self**: `Evision.FaceDetectorYN.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetTopK() -> retval\n```","ref":"Evision.FaceDetectorYN.html#getTopK/1"},{"type":"function","title":"Evision.FaceDetectorYN.setInputSize/1","doc":"","ref":"Evision.FaceDetectorYN.html#setInputSize/1"},{"type":"function","title":"Evision.FaceDetectorYN.setInputSize/2","doc":"Set the size for the network input, which overwrites the input size of creating model. Call this method when the size of input image does not match the input size when creating model\n\n##### Positional Arguments\n- **self**: `Evision.FaceDetectorYN.t()`\n- **input_size**: `Size`.\n\n  the size of the input image\n\nPython prototype (for reference only):\n```python3\nsetInputSize(input_size) -> None\n```","ref":"Evision.FaceDetectorYN.html#setInputSize/2"},{"type":"function","title":"Evision.FaceDetectorYN.setNMSThreshold/1","doc":"","ref":"Evision.FaceDetectorYN.html#setNMSThreshold/1"},{"type":"function","title":"Evision.FaceDetectorYN.setNMSThreshold/2","doc":"Set the Non-maximum-suppression threshold to suppress bounding boxes that have IoU greater than the given value\n\n##### Positional Arguments\n- **self**: `Evision.FaceDetectorYN.t()`\n- **nms_threshold**: `float`.\n\n  threshold for NMS operation\n\nPython prototype (for reference only):\n```python3\nsetNMSThreshold(nms_threshold) -> None\n```","ref":"Evision.FaceDetectorYN.html#setNMSThreshold/2"},{"type":"function","title":"Evision.FaceDetectorYN.setScoreThreshold/1","doc":"","ref":"Evision.FaceDetectorYN.html#setScoreThreshold/1"},{"type":"function","title":"Evision.FaceDetectorYN.setScoreThreshold/2","doc":"Set the score threshold to filter out bounding boxes of score less than the given value\n\n##### Positional Arguments\n- **self**: `Evision.FaceDetectorYN.t()`\n- **score_threshold**: `float`.\n\n  threshold for filtering out bounding boxes\n\nPython prototype (for reference only):\n```python3\nsetScoreThreshold(score_threshold) -> None\n```","ref":"Evision.FaceDetectorYN.html#setScoreThreshold/2"},{"type":"function","title":"Evision.FaceDetectorYN.setTopK/1","doc":"","ref":"Evision.FaceDetectorYN.html#setTopK/1"},{"type":"function","title":"Evision.FaceDetectorYN.setTopK/2","doc":"Set the number of bounding boxes preserved before NMS\n\n##### Positional Arguments\n- **self**: `Evision.FaceDetectorYN.t()`\n- **top_k**: `integer()`.\n\n  the number of bounding boxes to preserve from top rank based on score\n\nPython prototype (for reference only):\n```python3\nsetTopK(top_k) -> None\n```","ref":"Evision.FaceDetectorYN.html#setTopK/2"},{"type":"type","title":"Evision.FaceDetectorYN.t/0","doc":"Type that represents an `FaceDetectorYN` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.FaceDetectorYN.html#t:t/0"},{"type":"module","title":"Evision.FaceRecognizerSF","doc":"","ref":"Evision.FaceRecognizerSF.html"},{"type":"function","title":"Evision.FaceRecognizerSF.alignCrop/1","doc":"","ref":"Evision.FaceRecognizerSF.html#alignCrop/1"},{"type":"function","title":"Evision.FaceRecognizerSF.alignCrop/3","doc":"Aligning image to put face on the standard position\n\n##### Positional Arguments\n- **self**: `Evision.FaceRecognizerSF.t()`\n- **src_img**: `Evision.Mat`.\n\n  input image\n\n- **face_box**: `Evision.Mat`.\n\n  the detection result used for indicate face in input image\n\n##### Return\n- **aligned_img**: `Evision.Mat.t()`.\n\n  output aligned image\n\nPython prototype (for reference only):\n```python3\nalignCrop(src_img, face_box[, aligned_img]) -> aligned_img\n```","ref":"Evision.FaceRecognizerSF.html#alignCrop/3"},{"type":"function","title":"Evision.FaceRecognizerSF.alignCrop/4","doc":"Aligning image to put face on the standard position\n\n##### Positional Arguments\n- **self**: `Evision.FaceRecognizerSF.t()`\n- **src_img**: `Evision.Mat`.\n\n  input image\n\n- **face_box**: `Evision.Mat`.\n\n  the detection result used for indicate face in input image\n\n##### Return\n- **aligned_img**: `Evision.Mat.t()`.\n\n  output aligned image\n\nPython prototype (for reference only):\n```python3\nalignCrop(src_img, face_box[, aligned_img]) -> aligned_img\n```","ref":"Evision.FaceRecognizerSF.html#alignCrop/4"},{"type":"function","title":"Evision.FaceRecognizerSF.create/1","doc":"","ref":"Evision.FaceRecognizerSF.html#create/1"},{"type":"function","title":"Evision.FaceRecognizerSF.create/2","doc":"Creates an instance of this class with given parameters\n\n##### Positional Arguments\n- **model**: `String`.\n\n  the path of the onnx model used for face recognition\n\n- **config**: `String`.\n\n  the path to the config file for compability, which is not requested for ONNX models\n\n##### Keyword Arguments\n- **backend_id**: `integer()`.\n\n  the id of backend\n\n- **target_id**: `integer()`.\n\n  the id of target device\n\n##### Return\n- **retval**: `Evision.FaceRecognizerSF.t()`\n\nPython prototype (for reference only):\n```python3\ncreate(model, config[, backend_id[, target_id]]) -> retval\n```","ref":"Evision.FaceRecognizerSF.html#create/2"},{"type":"function","title":"Evision.FaceRecognizerSF.create/3","doc":"Creates an instance of this class with given parameters\n\n##### Positional Arguments\n- **model**: `String`.\n\n  the path of the onnx model used for face recognition\n\n- **config**: `String`.\n\n  the path to the config file for compability, which is not requested for ONNX models\n\n##### Keyword Arguments\n- **backend_id**: `integer()`.\n\n  the id of backend\n\n- **target_id**: `integer()`.\n\n  the id of target device\n\n##### Return\n- **retval**: `Evision.FaceRecognizerSF.t()`\n\nPython prototype (for reference only):\n```python3\ncreate(model, config[, backend_id[, target_id]]) -> retval\n```","ref":"Evision.FaceRecognizerSF.html#create/3"},{"type":"function","title":"Evision.FaceRecognizerSF.feature/1","doc":"","ref":"Evision.FaceRecognizerSF.html#feature/1"},{"type":"function","title":"Evision.FaceRecognizerSF.feature/2","doc":"Extracting face feature from aligned image\n\n##### Positional Arguments\n- **self**: `Evision.FaceRecognizerSF.t()`\n- **aligned_img**: `Evision.Mat`.\n\n  input aligned image\n\n##### Return\n- **face_feature**: `Evision.Mat.t()`.\n\n  output face feature\n\nPython prototype (for reference only):\n```python3\nfeature(aligned_img[, face_feature]) -> face_feature\n```","ref":"Evision.FaceRecognizerSF.html#feature/2"},{"type":"function","title":"Evision.FaceRecognizerSF.feature/3","doc":"Extracting face feature from aligned image\n\n##### Positional Arguments\n- **self**: `Evision.FaceRecognizerSF.t()`\n- **aligned_img**: `Evision.Mat`.\n\n  input aligned image\n\n##### Return\n- **face_feature**: `Evision.Mat.t()`.\n\n  output face feature\n\nPython prototype (for reference only):\n```python3\nfeature(aligned_img[, face_feature]) -> face_feature\n```","ref":"Evision.FaceRecognizerSF.html#feature/3"},{"type":"function","title":"Evision.FaceRecognizerSF.match/1","doc":"","ref":"Evision.FaceRecognizerSF.html#match/1"},{"type":"function","title":"Evision.FaceRecognizerSF.match/3","doc":"Calculating the distance between two face features\n\n##### Positional Arguments\n- **self**: `Evision.FaceRecognizerSF.t()`\n- **face_feature1**: `Evision.Mat`.\n\n  the first input feature\n\n- **face_feature2**: `Evision.Mat`.\n\n  the second input feature of the same size and the same type as face_feature1\n\n##### Keyword Arguments\n- **dis_type**: `integer()`.\n\n  defining the similarity with optional values \"FR_OSINE\" or \"FR_NORM_L2\"\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\nmatch(face_feature1, face_feature2[, dis_type]) -> retval\n```","ref":"Evision.FaceRecognizerSF.html#match/3"},{"type":"function","title":"Evision.FaceRecognizerSF.match/4","doc":"Calculating the distance between two face features\n\n##### Positional Arguments\n- **self**: `Evision.FaceRecognizerSF.t()`\n- **face_feature1**: `Evision.Mat`.\n\n  the first input feature\n\n- **face_feature2**: `Evision.Mat`.\n\n  the second input feature of the same size and the same type as face_feature1\n\n##### Keyword Arguments\n- **dis_type**: `integer()`.\n\n  defining the similarity with optional values \"FR_OSINE\" or \"FR_NORM_L2\"\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\nmatch(face_feature1, face_feature2[, dis_type]) -> retval\n```","ref":"Evision.FaceRecognizerSF.html#match/4"},{"type":"type","title":"Evision.FaceRecognizerSF.t/0","doc":"Type that represents an `FaceRecognizerSF` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.FaceRecognizerSF.html#t:t/0"},{"type":"module","title":"Evision.FaceRecognizerSF.DisType","doc":"","ref":"Evision.FaceRecognizerSF.DisType.html"},{"type":"function","title":"Evision.FaceRecognizerSF.DisType.cv_FR_COSINE/0","doc":"","ref":"Evision.FaceRecognizerSF.DisType.html#cv_FR_COSINE/0"},{"type":"function","title":"Evision.FaceRecognizerSF.DisType.cv_FR_NORM_L2/0","doc":"","ref":"Evision.FaceRecognizerSF.DisType.html#cv_FR_NORM_L2/0"},{"type":"type","title":"Evision.FaceRecognizerSF.DisType.enum/0","doc":"","ref":"Evision.FaceRecognizerSF.DisType.html#t:enum/0"},{"type":"module","title":"Evision.FarnebackOpticalFlow","doc":"","ref":"Evision.FarnebackOpticalFlow.html"},{"type":"function","title":"Evision.FarnebackOpticalFlow.create/0","doc":"create\n##### Keyword Arguments\n- **numLevels**: `integer()`.\n- **pyrScale**: `double`.\n- **fastPyramids**: `bool`.\n- **winSize**: `integer()`.\n- **numIters**: `integer()`.\n- **polyN**: `integer()`.\n- **polySigma**: `double`.\n- **flags**: `integer()`.\n\n##### Return\n- **retval**: `Evision.FarnebackOpticalFlow.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, numLevels[, pyrScale[, fastPyramids[, winSize[, numIters[, polyN[, polySigma[, flags]]]]]]]]) -> retval\n```","ref":"Evision.FarnebackOpticalFlow.html#create/0"},{"type":"function","title":"Evision.FarnebackOpticalFlow.create/1","doc":"create\n##### Keyword Arguments\n- **numLevels**: `integer()`.\n- **pyrScale**: `double`.\n- **fastPyramids**: `bool`.\n- **winSize**: `integer()`.\n- **numIters**: `integer()`.\n- **polyN**: `integer()`.\n- **polySigma**: `double`.\n- **flags**: `integer()`.\n\n##### Return\n- **retval**: `Evision.FarnebackOpticalFlow.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, numLevels[, pyrScale[, fastPyramids[, winSize[, numIters[, polyN[, polySigma[, flags]]]]]]]]) -> retval\n```","ref":"Evision.FarnebackOpticalFlow.html#create/1"},{"type":"function","title":"Evision.FarnebackOpticalFlow.getFastPyramids/1","doc":"getFastPyramids\n\n##### Positional Arguments\n- **self**: `Evision.FarnebackOpticalFlow.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetFastPyramids() -> retval\n```","ref":"Evision.FarnebackOpticalFlow.html#getFastPyramids/1"},{"type":"function","title":"Evision.FarnebackOpticalFlow.getFlags/1","doc":"getFlags\n\n##### Positional Arguments\n- **self**: `Evision.FarnebackOpticalFlow.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetFlags() -> retval\n```","ref":"Evision.FarnebackOpticalFlow.html#getFlags/1"},{"type":"function","title":"Evision.FarnebackOpticalFlow.getNumIters/1","doc":"getNumIters\n\n##### Positional Arguments\n- **self**: `Evision.FarnebackOpticalFlow.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNumIters() -> retval\n```","ref":"Evision.FarnebackOpticalFlow.html#getNumIters/1"},{"type":"function","title":"Evision.FarnebackOpticalFlow.getNumLevels/1","doc":"getNumLevels\n\n##### Positional Arguments\n- **self**: `Evision.FarnebackOpticalFlow.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNumLevels() -> retval\n```","ref":"Evision.FarnebackOpticalFlow.html#getNumLevels/1"},{"type":"function","title":"Evision.FarnebackOpticalFlow.getPolyN/1","doc":"getPolyN\n\n##### Positional Arguments\n- **self**: `Evision.FarnebackOpticalFlow.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetPolyN() -> retval\n```","ref":"Evision.FarnebackOpticalFlow.html#getPolyN/1"},{"type":"function","title":"Evision.FarnebackOpticalFlow.getPolySigma/1","doc":"getPolySigma\n\n##### Positional Arguments\n- **self**: `Evision.FarnebackOpticalFlow.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetPolySigma() -> retval\n```","ref":"Evision.FarnebackOpticalFlow.html#getPolySigma/1"},{"type":"function","title":"Evision.FarnebackOpticalFlow.getPyrScale/1","doc":"getPyrScale\n\n##### Positional Arguments\n- **self**: `Evision.FarnebackOpticalFlow.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetPyrScale() -> retval\n```","ref":"Evision.FarnebackOpticalFlow.html#getPyrScale/1"},{"type":"function","title":"Evision.FarnebackOpticalFlow.getWinSize/1","doc":"getWinSize\n\n##### Positional Arguments\n- **self**: `Evision.FarnebackOpticalFlow.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetWinSize() -> retval\n```","ref":"Evision.FarnebackOpticalFlow.html#getWinSize/1"},{"type":"function","title":"Evision.FarnebackOpticalFlow.setFastPyramids/1","doc":"","ref":"Evision.FarnebackOpticalFlow.html#setFastPyramids/1"},{"type":"function","title":"Evision.FarnebackOpticalFlow.setFastPyramids/2","doc":"setFastPyramids\n\n##### Positional Arguments\n- **self**: `Evision.FarnebackOpticalFlow.t()`\n- **fastPyramids**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetFastPyramids(fastPyramids) -> None\n```","ref":"Evision.FarnebackOpticalFlow.html#setFastPyramids/2"},{"type":"function","title":"Evision.FarnebackOpticalFlow.setFlags/1","doc":"","ref":"Evision.FarnebackOpticalFlow.html#setFlags/1"},{"type":"function","title":"Evision.FarnebackOpticalFlow.setFlags/2","doc":"setFlags\n\n##### Positional Arguments\n- **self**: `Evision.FarnebackOpticalFlow.t()`\n- **flags**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetFlags(flags) -> None\n```","ref":"Evision.FarnebackOpticalFlow.html#setFlags/2"},{"type":"function","title":"Evision.FarnebackOpticalFlow.setNumIters/1","doc":"","ref":"Evision.FarnebackOpticalFlow.html#setNumIters/1"},{"type":"function","title":"Evision.FarnebackOpticalFlow.setNumIters/2","doc":"setNumIters\n\n##### Positional Arguments\n- **self**: `Evision.FarnebackOpticalFlow.t()`\n- **numIters**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNumIters(numIters) -> None\n```","ref":"Evision.FarnebackOpticalFlow.html#setNumIters/2"},{"type":"function","title":"Evision.FarnebackOpticalFlow.setNumLevels/1","doc":"","ref":"Evision.FarnebackOpticalFlow.html#setNumLevels/1"},{"type":"function","title":"Evision.FarnebackOpticalFlow.setNumLevels/2","doc":"setNumLevels\n\n##### Positional Arguments\n- **self**: `Evision.FarnebackOpticalFlow.t()`\n- **numLevels**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNumLevels(numLevels) -> None\n```","ref":"Evision.FarnebackOpticalFlow.html#setNumLevels/2"},{"type":"function","title":"Evision.FarnebackOpticalFlow.setPolyN/1","doc":"","ref":"Evision.FarnebackOpticalFlow.html#setPolyN/1"},{"type":"function","title":"Evision.FarnebackOpticalFlow.setPolyN/2","doc":"setPolyN\n\n##### Positional Arguments\n- **self**: `Evision.FarnebackOpticalFlow.t()`\n- **polyN**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetPolyN(polyN) -> None\n```","ref":"Evision.FarnebackOpticalFlow.html#setPolyN/2"},{"type":"function","title":"Evision.FarnebackOpticalFlow.setPolySigma/1","doc":"","ref":"Evision.FarnebackOpticalFlow.html#setPolySigma/1"},{"type":"function","title":"Evision.FarnebackOpticalFlow.setPolySigma/2","doc":"setPolySigma\n\n##### Positional Arguments\n- **self**: `Evision.FarnebackOpticalFlow.t()`\n- **polySigma**: `double`\n\nPython prototype (for reference only):\n```python3\nsetPolySigma(polySigma) -> None\n```","ref":"Evision.FarnebackOpticalFlow.html#setPolySigma/2"},{"type":"function","title":"Evision.FarnebackOpticalFlow.setPyrScale/1","doc":"","ref":"Evision.FarnebackOpticalFlow.html#setPyrScale/1"},{"type":"function","title":"Evision.FarnebackOpticalFlow.setPyrScale/2","doc":"setPyrScale\n\n##### Positional Arguments\n- **self**: `Evision.FarnebackOpticalFlow.t()`\n- **pyrScale**: `double`\n\nPython prototype (for reference only):\n```python3\nsetPyrScale(pyrScale) -> None\n```","ref":"Evision.FarnebackOpticalFlow.html#setPyrScale/2"},{"type":"function","title":"Evision.FarnebackOpticalFlow.setWinSize/1","doc":"","ref":"Evision.FarnebackOpticalFlow.html#setWinSize/1"},{"type":"function","title":"Evision.FarnebackOpticalFlow.setWinSize/2","doc":"setWinSize\n\n##### Positional Arguments\n- **self**: `Evision.FarnebackOpticalFlow.t()`\n- **winSize**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetWinSize(winSize) -> None\n```","ref":"Evision.FarnebackOpticalFlow.html#setWinSize/2"},{"type":"type","title":"Evision.FarnebackOpticalFlow.t/0","doc":"Type that represents an `FarnebackOpticalFlow` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.FarnebackOpticalFlow.html#t:t/0"},{"type":"module","title":"Evision.FastFeatureDetector","doc":"","ref":"Evision.FastFeatureDetector.html"},{"type":"function","title":"Evision.FastFeatureDetector.compute/1","doc":"","ref":"Evision.FastFeatureDetector.html#compute/1"},{"type":"function","title":"Evision.FastFeatureDetector.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.FastFeatureDetector.html#compute/3"},{"type":"function","title":"Evision.FastFeatureDetector.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.FastFeatureDetector.html#compute/4"},{"type":"function","title":"Evision.FastFeatureDetector.create/0","doc":"create\n##### Keyword Arguments\n- **threshold**: `integer()`.\n- **nonmaxSuppression**: `bool`.\n- **type**: `FastFeatureDetector_DetectorType`.\n\n##### Return\n- **retval**: `Evision.FastFeatureDetector.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, threshold[, nonmaxSuppression[, type]]]) -> retval\n```","ref":"Evision.FastFeatureDetector.html#create/0"},{"type":"function","title":"Evision.FastFeatureDetector.create/1","doc":"create\n##### Keyword Arguments\n- **threshold**: `integer()`.\n- **nonmaxSuppression**: `bool`.\n- **type**: `FastFeatureDetector_DetectorType`.\n\n##### Return\n- **retval**: `Evision.FastFeatureDetector.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, threshold[, nonmaxSuppression[, type]]]) -> retval\n```","ref":"Evision.FastFeatureDetector.html#create/1"},{"type":"function","title":"Evision.FastFeatureDetector.cv_FAST_N/0","doc":"","ref":"Evision.FastFeatureDetector.html#cv_FAST_N/0"},{"type":"function","title":"Evision.FastFeatureDetector.cv_NONMAX_SUPPRESSION/0","doc":"","ref":"Evision.FastFeatureDetector.html#cv_NONMAX_SUPPRESSION/0"},{"type":"function","title":"Evision.FastFeatureDetector.cv_THRESHOLD/0","doc":"","ref":"Evision.FastFeatureDetector.html#cv_THRESHOLD/0"},{"type":"function","title":"Evision.FastFeatureDetector.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.FastFeatureDetector.html#defaultNorm/1"},{"type":"function","title":"Evision.FastFeatureDetector.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.FastFeatureDetector.html#descriptorSize/1"},{"type":"function","title":"Evision.FastFeatureDetector.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.FastFeatureDetector.html#descriptorType/1"},{"type":"function","title":"Evision.FastFeatureDetector.detect/1","doc":"","ref":"Evision.FastFeatureDetector.html#detect/1"},{"type":"function","title":"Evision.FastFeatureDetector.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.FastFeatureDetector.html#detect/2"},{"type":"function","title":"Evision.FastFeatureDetector.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.FastFeatureDetector.html#detect/3"},{"type":"function","title":"Evision.FastFeatureDetector.detectAndCompute/1","doc":"","ref":"Evision.FastFeatureDetector.html#detectAndCompute/1"},{"type":"function","title":"Evision.FastFeatureDetector.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.FastFeatureDetector.html#detectAndCompute/3"},{"type":"function","title":"Evision.FastFeatureDetector.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.FastFeatureDetector.html#detectAndCompute/4"},{"type":"function","title":"Evision.FastFeatureDetector.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.FastFeatureDetector.html#empty/1"},{"type":"function","title":"Evision.FastFeatureDetector.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.FastFeatureDetector.html#getDefaultName/1"},{"type":"function","title":"Evision.FastFeatureDetector.getNonmaxSuppression/1","doc":"getNonmaxSuppression\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetNonmaxSuppression() -> retval\n```","ref":"Evision.FastFeatureDetector.html#getNonmaxSuppression/1"},{"type":"function","title":"Evision.FastFeatureDetector.getThreshold/1","doc":"getThreshold\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetThreshold() -> retval\n```","ref":"Evision.FastFeatureDetector.html#getThreshold/1"},{"type":"function","title":"Evision.FastFeatureDetector.getType/1","doc":"getType\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n\n##### Return\n- **retval**: `FastFeatureDetector::DetectorType`\n\nPython prototype (for reference only):\n```python3\ngetType() -> retval\n```","ref":"Evision.FastFeatureDetector.html#getType/1"},{"type":"function","title":"Evision.FastFeatureDetector.read/1","doc":"","ref":"Evision.FastFeatureDetector.html#read/1"},{"type":"function","title":"Evision.FastFeatureDetector.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.FastFeatureDetector.html#read/2"},{"type":"function","title":"Evision.FastFeatureDetector.setNonmaxSuppression/1","doc":"","ref":"Evision.FastFeatureDetector.html#setNonmaxSuppression/1"},{"type":"function","title":"Evision.FastFeatureDetector.setNonmaxSuppression/2","doc":"setNonmaxSuppression\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n- **f**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetNonmaxSuppression(f) -> None\n```","ref":"Evision.FastFeatureDetector.html#setNonmaxSuppression/2"},{"type":"function","title":"Evision.FastFeatureDetector.setThreshold/1","doc":"","ref":"Evision.FastFeatureDetector.html#setThreshold/1"},{"type":"function","title":"Evision.FastFeatureDetector.setThreshold/2","doc":"setThreshold\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n- **threshold**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetThreshold(threshold) -> None\n```","ref":"Evision.FastFeatureDetector.html#setThreshold/2"},{"type":"function","title":"Evision.FastFeatureDetector.setType/1","doc":"","ref":"Evision.FastFeatureDetector.html#setType/1"},{"type":"function","title":"Evision.FastFeatureDetector.setType/2","doc":"setType\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n- **type**: `FastFeatureDetector_DetectorType`\n\nPython prototype (for reference only):\n```python3\nsetType(type) -> None\n```","ref":"Evision.FastFeatureDetector.html#setType/2"},{"type":"function","title":"Evision.FastFeatureDetector.write/1","doc":"","ref":"Evision.FastFeatureDetector.html#write/1"},{"type":"function","title":"Evision.FastFeatureDetector.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.FastFeatureDetector.html#write/2"},{"type":"function","title":"Evision.FastFeatureDetector.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.FastFeatureDetector.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.FastFeatureDetector.html#write/3"},{"type":"type","title":"Evision.FastFeatureDetector.enum/0","doc":"","ref":"Evision.FastFeatureDetector.html#t:enum/0"},{"type":"type","title":"Evision.FastFeatureDetector.t/0","doc":"Type that represents an `FastFeatureDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.FastFeatureDetector.html#t:t/0"},{"type":"module","title":"Evision.FastFeatureDetector.DetectorType","doc":"","ref":"Evision.FastFeatureDetector.DetectorType.html"},{"type":"function","title":"Evision.FastFeatureDetector.DetectorType.cv_TYPE_5_8/0","doc":"","ref":"Evision.FastFeatureDetector.DetectorType.html#cv_TYPE_5_8/0"},{"type":"function","title":"Evision.FastFeatureDetector.DetectorType.cv_TYPE_7_12/0","doc":"","ref":"Evision.FastFeatureDetector.DetectorType.html#cv_TYPE_7_12/0"},{"type":"function","title":"Evision.FastFeatureDetector.DetectorType.cv_TYPE_9_16/0","doc":"","ref":"Evision.FastFeatureDetector.DetectorType.html#cv_TYPE_9_16/0"},{"type":"type","title":"Evision.FastFeatureDetector.DetectorType.enum/0","doc":"","ref":"Evision.FastFeatureDetector.DetectorType.html#t:enum/0"},{"type":"module","title":"Evision.Feature2D","doc":"","ref":"Evision.Feature2D.html"},{"type":"function","title":"Evision.Feature2D.compute/1","doc":"","ref":"Evision.Feature2D.html#compute/1"},{"type":"function","title":"Evision.Feature2D.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.Feature2D.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.Feature2D.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.Feature2D.html#compute/3"},{"type":"function","title":"Evision.Feature2D.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.Feature2D.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.Feature2D.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.Feature2D.html#compute/4"},{"type":"function","title":"Evision.Feature2D.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.Feature2D.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.Feature2D.html#defaultNorm/1"},{"type":"function","title":"Evision.Feature2D.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.Feature2D.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.Feature2D.html#descriptorSize/1"},{"type":"function","title":"Evision.Feature2D.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.Feature2D.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.Feature2D.html#descriptorType/1"},{"type":"function","title":"Evision.Feature2D.detect/1","doc":"","ref":"Evision.Feature2D.html#detect/1"},{"type":"function","title":"Evision.Feature2D.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.Feature2D.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.Feature2D.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.Feature2D.html#detect/2"},{"type":"function","title":"Evision.Feature2D.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.Feature2D.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.Feature2D.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.Feature2D.html#detect/3"},{"type":"function","title":"Evision.Feature2D.detectAndCompute/1","doc":"","ref":"Evision.Feature2D.html#detectAndCompute/1"},{"type":"function","title":"Evision.Feature2D.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.Feature2D.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.Feature2D.html#detectAndCompute/3"},{"type":"function","title":"Evision.Feature2D.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.Feature2D.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.Feature2D.html#detectAndCompute/4"},{"type":"function","title":"Evision.Feature2D.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.Feature2D.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Feature2D.html#empty/1"},{"type":"function","title":"Evision.Feature2D.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Feature2D.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Feature2D.html#getDefaultName/1"},{"type":"function","title":"Evision.Feature2D.read/1","doc":"","ref":"Evision.Feature2D.html#read/1"},{"type":"function","title":"Evision.Feature2D.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.Feature2D.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.Feature2D.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.Feature2D.html#read/2"},{"type":"function","title":"Evision.Feature2D.write/1","doc":"","ref":"Evision.Feature2D.html#write/1"},{"type":"function","title":"Evision.Feature2D.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Feature2D.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.Feature2D.html#write/2"},{"type":"function","title":"Evision.Feature2D.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Feature2D.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Feature2D.html#write/3"},{"type":"type","title":"Evision.Feature2D.t/0","doc":"Type that represents an `Feature2D` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Feature2D.html#t:t/0"},{"type":"module","title":"Evision.FileNode","doc":"","ref":"Evision.FileNode.html"},{"type":"function","title":"Evision.FileNode.at/1","doc":"","ref":"Evision.FileNode.html#at/1"},{"type":"function","title":"Evision.FileNode.at/2","doc":"at\n\n##### Positional Arguments\n- **self**: `Evision.FileNode.t()`\n- **i**: `integer()`.\n\n  Index of an element in the sequence node.\n\n##### Return\n- **retval**: `Evision.FileNode.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nat(i) -> retval\n```","ref":"Evision.FileNode.html#at/2"},{"type":"function","title":"Evision.FileNode.cv_EMPTY/0","doc":"","ref":"Evision.FileNode.html#cv_EMPTY/0"},{"type":"function","title":"Evision.FileNode.cv_FLOAT/0","doc":"","ref":"Evision.FileNode.html#cv_FLOAT/0"},{"type":"function","title":"Evision.FileNode.cv_FLOW/0","doc":"","ref":"Evision.FileNode.html#cv_FLOW/0"},{"type":"function","title":"Evision.FileNode.cv_INT/0","doc":"","ref":"Evision.FileNode.html#cv_INT/0"},{"type":"function","title":"Evision.FileNode.cv_MAP/0","doc":"","ref":"Evision.FileNode.html#cv_MAP/0"},{"type":"function","title":"Evision.FileNode.cv_NAMED/0","doc":"","ref":"Evision.FileNode.html#cv_NAMED/0"},{"type":"function","title":"Evision.FileNode.cv_NONE/0","doc":"","ref":"Evision.FileNode.html#cv_NONE/0"},{"type":"function","title":"Evision.FileNode.cv_REAL/0","doc":"","ref":"Evision.FileNode.html#cv_REAL/0"},{"type":"function","title":"Evision.FileNode.cv_SEQ/0","doc":"","ref":"Evision.FileNode.html#cv_SEQ/0"},{"type":"function","title":"Evision.FileNode.cv_STR/0","doc":"","ref":"Evision.FileNode.html#cv_STR/0"},{"type":"function","title":"Evision.FileNode.cv_STRING/0","doc":"","ref":"Evision.FileNode.html#cv_STRING/0"},{"type":"function","title":"Evision.FileNode.cv_TYPE_MASK/0","doc":"","ref":"Evision.FileNode.html#cv_TYPE_MASK/0"},{"type":"function","title":"Evision.FileNode.cv_UNIFORM/0","doc":"","ref":"Evision.FileNode.html#cv_UNIFORM/0"},{"type":"function","title":"Evision.FileNode.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.FileNode.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.FileNode.html#empty/1"},{"type":"function","title":"Evision.FileNode.fileNode/0","doc":"The constructors.\n##### Return\n- **self**: `Evision.FileNode.t()`\n\nThese constructors are used to create a default file node, construct it from obsolete structures or\nfrom the another file node.\n\nPython prototype (for reference only):\n```python3\nFileNode() ->  \n```","ref":"Evision.FileNode.html#fileNode/0"},{"type":"function","title":"Evision.FileNode.fileNode/1","doc":"","ref":"Evision.FileNode.html#fileNode/1"},{"type":"function","title":"Evision.FileNode.getNode/1","doc":"","ref":"Evision.FileNode.html#getNode/1"},{"type":"function","title":"Evision.FileNode.getNode/2","doc":"getNode\n\n##### Positional Arguments\n- **self**: `Evision.FileNode.t()`\n- **nodename**: `c_string`.\n\n  Name of an element in the mapping node.\n\n##### Return\n- **retval**: `Evision.FileNode.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ngetNode(nodename) -> retval\n```","ref":"Evision.FileNode.html#getNode/2"},{"type":"function","title":"Evision.FileNode.isInt/1","doc":"isInt\n\n##### Positional Arguments\n- **self**: `Evision.FileNode.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisInt() -> retval\n```","ref":"Evision.FileNode.html#isInt/1"},{"type":"function","title":"Evision.FileNode.isMap/1","doc":"isMap\n\n##### Positional Arguments\n- **self**: `Evision.FileNode.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisMap() -> retval\n```","ref":"Evision.FileNode.html#isMap/1"},{"type":"function","title":"Evision.FileNode.isNamed/1","doc":"isNamed\n\n##### Positional Arguments\n- **self**: `Evision.FileNode.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisNamed() -> retval\n```","ref":"Evision.FileNode.html#isNamed/1"},{"type":"function","title":"Evision.FileNode.isNone/1","doc":"isNone\n\n##### Positional Arguments\n- **self**: `Evision.FileNode.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisNone() -> retval\n```","ref":"Evision.FileNode.html#isNone/1"},{"type":"function","title":"Evision.FileNode.isReal/1","doc":"isReal\n\n##### Positional Arguments\n- **self**: `Evision.FileNode.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisReal() -> retval\n```","ref":"Evision.FileNode.html#isReal/1"},{"type":"function","title":"Evision.FileNode.isSeq/1","doc":"isSeq\n\n##### Positional Arguments\n- **self**: `Evision.FileNode.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisSeq() -> retval\n```","ref":"Evision.FileNode.html#isSeq/1"},{"type":"function","title":"Evision.FileNode.isString/1","doc":"isString\n\n##### Positional Arguments\n- **self**: `Evision.FileNode.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisString() -> retval\n```","ref":"Evision.FileNode.html#isString/1"},{"type":"function","title":"Evision.FileNode.keys/1","doc":"Returns keys of a mapping node.\n\n##### Positional Arguments\n- **self**: `Evision.FileNode.t()`\n\n##### Return\n- **retval**: `[String]`\n\n@returns Keys of a mapping node.\n\nPython prototype (for reference only):\n```python3\nkeys() -> retval\n```","ref":"Evision.FileNode.html#keys/1"},{"type":"function","title":"Evision.FileNode.mat/1","doc":"mat\n\n##### Positional Arguments\n- **self**: `Evision.FileNode.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nmat() -> retval\n```","ref":"Evision.FileNode.html#mat/1"},{"type":"function","title":"Evision.FileNode.name/1","doc":"name\n\n##### Positional Arguments\n- **self**: `Evision.FileNode.t()`\n\n##### Return\n- **retval**: `string`\n\nPython prototype (for reference only):\n```python3\nname() -> retval\n```","ref":"Evision.FileNode.html#name/1"},{"type":"function","title":"Evision.FileNode.rawSize/1","doc":"rawSize\n\n##### Positional Arguments\n- **self**: `Evision.FileNode.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nrawSize() -> retval\n```","ref":"Evision.FileNode.html#rawSize/1"},{"type":"function","title":"Evision.FileNode.real/1","doc":"real\n\n##### Positional Arguments\n- **self**: `Evision.FileNode.t()`\n\n##### Return\n- **retval**: `double`\n\nInternal method used when reading FileStorage.\nSets the type (int, real or string) and value of the previously created node.\n\nPython prototype (for reference only):\n```python3\nreal() -> retval\n```","ref":"Evision.FileNode.html#real/1"},{"type":"function","title":"Evision.FileNode.size/1","doc":"size\n\n##### Positional Arguments\n- **self**: `Evision.FileNode.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nsize() -> retval\n```","ref":"Evision.FileNode.html#size/1"},{"type":"function","title":"Evision.FileNode.string/1","doc":"string\n\n##### Positional Arguments\n- **self**: `Evision.FileNode.t()`\n\n##### Return\n- **retval**: `string`\n\nPython prototype (for reference only):\n```python3\nstring() -> retval\n```","ref":"Evision.FileNode.html#string/1"},{"type":"function","title":"Evision.FileNode.type/1","doc":"Returns type of the node.\n\n##### Positional Arguments\n- **self**: `Evision.FileNode.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@returns Type of the node. See FileNode::Type\n\nPython prototype (for reference only):\n```python3\ntype() -> retval\n```","ref":"Evision.FileNode.html#type/1"},{"type":"type","title":"Evision.FileNode.enum/0","doc":"","ref":"Evision.FileNode.html#t:enum/0"},{"type":"type","title":"Evision.FileNode.t/0","doc":"Type that represents an `FileNode` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.FileNode.html#t:t/0"},{"type":"module","title":"Evision.FileStorage","doc":"","ref":"Evision.FileStorage.html"},{"type":"function","title":"Evision.FileStorage.endWriteStruct/1","doc":"Finishes writing nested structure (should pair startWriteStruct())\n\n##### Positional Arguments\n- **self**: `Evision.FileStorage.t()`\n\nPython prototype (for reference only):\n```python3\nendWriteStruct() -> None\n```","ref":"Evision.FileStorage.html#endWriteStruct/1"},{"type":"function","title":"Evision.FileStorage.fileStorage/0","doc":"The constructors.\n##### Return\n- **self**: `Evision.FileStorage.t()`\n\nThe full constructor opens the file. Alternatively you can use the default constructor and then\ncall FileStorage::open.\n\nPython prototype (for reference only):\n```python3\nFileStorage() ->  \n```","ref":"Evision.FileStorage.html#fileStorage/0"},{"type":"function","title":"Evision.FileStorage.fileStorage/1","doc":"","ref":"Evision.FileStorage.html#fileStorage/1"},{"type":"function","title":"Evision.FileStorage.fileStorage/2","doc":"FileStorage\n\n##### Positional Arguments\n- **filename**: `String`\n- **flags**: `integer()`\n\n##### Keyword Arguments\n- **encoding**: `String`.\n\n##### Return\n- **self**: `Evision.FileStorage.t()`\n\nHas overloading in C++\n\n@copydoc open()\n\nPython prototype (for reference only):\n```python3\nFileStorage(filename, flags[, encoding]) ->  \n```","ref":"Evision.FileStorage.html#fileStorage/2"},{"type":"function","title":"Evision.FileStorage.fileStorage/3","doc":"FileStorage\n\n##### Positional Arguments\n- **filename**: `String`\n- **flags**: `integer()`\n\n##### Keyword Arguments\n- **encoding**: `String`.\n\n##### Return\n- **self**: `Evision.FileStorage.t()`\n\nHas overloading in C++\n\n@copydoc open()\n\nPython prototype (for reference only):\n```python3\nFileStorage(filename, flags[, encoding]) ->  \n```","ref":"Evision.FileStorage.html#fileStorage/3"},{"type":"function","title":"Evision.FileStorage.getFirstTopLevelNode/1","doc":"Returns the first element of the top-level mapping.\n\n##### Positional Arguments\n- **self**: `Evision.FileStorage.t()`\n\n##### Return\n- **retval**: `Evision.FileNode.t()`\n\n@returns The first element of the top-level mapping.\n\nPython prototype (for reference only):\n```python3\ngetFirstTopLevelNode() -> retval\n```","ref":"Evision.FileStorage.html#getFirstTopLevelNode/1"},{"type":"function","title":"Evision.FileStorage.getFormat/1","doc":"Returns the current format.\n\n##### Positional Arguments\n- **self**: `Evision.FileStorage.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@returns The current format, see FileStorage::Mode\n\nPython prototype (for reference only):\n```python3\ngetFormat() -> retval\n```","ref":"Evision.FileStorage.html#getFormat/1"},{"type":"function","title":"Evision.FileStorage.getNode/1","doc":"","ref":"Evision.FileStorage.html#getNode/1"},{"type":"function","title":"Evision.FileStorage.getNode/2","doc":"getNode\n\n##### Positional Arguments\n- **self**: `Evision.FileStorage.t()`\n- **nodename**: `c_string`\n\n##### Return\n- **retval**: `Evision.FileNode.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ngetNode(nodename) -> retval\n```","ref":"Evision.FileStorage.html#getNode/2"},{"type":"function","title":"Evision.FileStorage.isOpened/1","doc":"Checks whether the file is opened.\n\n##### Positional Arguments\n- **self**: `Evision.FileStorage.t()`\n\n##### Return\n- **retval**: `bool`\n\n@returns true if the object is associated with the current file and false otherwise. It is a\ngood practice to call this method after you tried to open a file.\n\nPython prototype (for reference only):\n```python3\nisOpened() -> retval\n```","ref":"Evision.FileStorage.html#isOpened/1"},{"type":"function","title":"Evision.FileStorage.open/1","doc":"","ref":"Evision.FileStorage.html#open/1"},{"type":"function","title":"Evision.FileStorage.open/3","doc":"Opens a file.\n\n##### Positional Arguments\n- **self**: `Evision.FileStorage.t()`\n- **filename**: `String`.\n\n  Name of the file to open or the text string to read the data from.\n  Extension of the file (.xml, .yml/.yaml or .json) determines its format (XML, YAML or JSON\n  respectively). Also you can append .gz to work with compressed files, for example myHugeMatrix.xml.gz. If both\n  FileStorage::WRITE and FileStorage::MEMORY flags are specified, source is used just to specify\n  the output file format (e.g. mydata.xml, .yml etc.). A file name can also contain parameters.\n  You can use this format, \"*?base64\" (e.g. \"file.json?base64\" (case sensitive)), as an alternative to\n  FileStorage::BASE64 flag.\n\n- **flags**: `integer()`.\n\n  Mode of operation. One of FileStorage::Mode\n\n##### Keyword Arguments\n- **encoding**: `String`.\n\n  Encoding of the file. Note that UTF-16 XML encoding is not supported currently and\n  you should use 8-bit encoding instead of it.\n\n##### Return\n- **retval**: `bool`\n\nSee description of parameters in FileStorage::FileStorage. The method calls FileStorage::release\nbefore opening the file.\n\nPython prototype (for reference only):\n```python3\nopen(filename, flags[, encoding]) -> retval\n```","ref":"Evision.FileStorage.html#open/3"},{"type":"function","title":"Evision.FileStorage.open/4","doc":"Opens a file.\n\n##### Positional Arguments\n- **self**: `Evision.FileStorage.t()`\n- **filename**: `String`.\n\n  Name of the file to open or the text string to read the data from.\n  Extension of the file (.xml, .yml/.yaml or .json) determines its format (XML, YAML or JSON\n  respectively). Also you can append .gz to work with compressed files, for example myHugeMatrix.xml.gz. If both\n  FileStorage::WRITE and FileStorage::MEMORY flags are specified, source is used just to specify\n  the output file format (e.g. mydata.xml, .yml etc.). A file name can also contain parameters.\n  You can use this format, \"*?base64\" (e.g. \"file.json?base64\" (case sensitive)), as an alternative to\n  FileStorage::BASE64 flag.\n\n- **flags**: `integer()`.\n\n  Mode of operation. One of FileStorage::Mode\n\n##### Keyword Arguments\n- **encoding**: `String`.\n\n  Encoding of the file. Note that UTF-16 XML encoding is not supported currently and\n  you should use 8-bit encoding instead of it.\n\n##### Return\n- **retval**: `bool`\n\nSee description of parameters in FileStorage::FileStorage. The method calls FileStorage::release\nbefore opening the file.\n\nPython prototype (for reference only):\n```python3\nopen(filename, flags[, encoding]) -> retval\n```","ref":"Evision.FileStorage.html#open/4"},{"type":"function","title":"Evision.FileStorage.release/1","doc":"Closes the file and releases all the memory buffers.\n\n##### Positional Arguments\n- **self**: `Evision.FileStorage.t()`\n\nCall this method after all I/O operations with the storage are finished.\n\nPython prototype (for reference only):\n```python3\nrelease() -> None\n```","ref":"Evision.FileStorage.html#release/1"},{"type":"function","title":"Evision.FileStorage.releaseAndGetString/1","doc":"Closes the file and releases all the memory buffers.\n\n##### Positional Arguments\n- **self**: `Evision.FileStorage.t()`\n\n##### Return\n- **retval**: `String`\n\nCall this method after all I/O operations with the storage are finished. If the storage was\nopened for writing data and FileStorage::WRITE was specified\n\nPython prototype (for reference only):\n```python3\nreleaseAndGetString() -> retval\n```","ref":"Evision.FileStorage.html#releaseAndGetString/1"},{"type":"function","title":"Evision.FileStorage.root/1","doc":"Returns the top-level mapping\n\n##### Positional Arguments\n- **self**: `Evision.FileStorage.t()`\n\n##### Keyword Arguments\n- **streamidx**: `integer()`.\n\n  Zero-based index of the stream. In most cases there is only one stream in the file.\n  However, YAML supports multiple streams and so there can be several.\n\n##### Return\n- **retval**: `Evision.FileNode.t()`\n\n@returns The top-level mapping.\n\nPython prototype (for reference only):\n```python3\nroot([, streamidx]) -> retval\n```","ref":"Evision.FileStorage.html#root/1"},{"type":"function","title":"Evision.FileStorage.root/2","doc":"Returns the top-level mapping\n\n##### Positional Arguments\n- **self**: `Evision.FileStorage.t()`\n\n##### Keyword Arguments\n- **streamidx**: `integer()`.\n\n  Zero-based index of the stream. In most cases there is only one stream in the file.\n  However, YAML supports multiple streams and so there can be several.\n\n##### Return\n- **retval**: `Evision.FileNode.t()`\n\n@returns The top-level mapping.\n\nPython prototype (for reference only):\n```python3\nroot([, streamidx]) -> retval\n```","ref":"Evision.FileStorage.html#root/2"},{"type":"function","title":"Evision.FileStorage.startWriteStruct/1","doc":"","ref":"Evision.FileStorage.html#startWriteStruct/1"},{"type":"function","title":"Evision.FileStorage.startWriteStruct/3","doc":"Starts to write a nested structure (sequence or a mapping).\n\n##### Positional Arguments\n- **self**: `Evision.FileStorage.t()`\n- **name**: `String`.\n\n  name of the structure. When writing to sequences (a.k.a. \"arrays\"), pass an empty string.\n\n- **flags**: `integer()`.\n\n  type of the structure (FileNode::MAP or FileNode::SEQ (both with optional FileNode::FLOW)).\n\n##### Keyword Arguments\n- **typeName**: `String`.\n\n  optional name of the type you store. The effect of setting this depends on the storage format.\n  I.e. if the format has a specification for storing type information, this parameter is used.\n\nPython prototype (for reference only):\n```python3\nstartWriteStruct(name, flags[, typeName]) -> None\n```","ref":"Evision.FileStorage.html#startWriteStruct/3"},{"type":"function","title":"Evision.FileStorage.startWriteStruct/4","doc":"Starts to write a nested structure (sequence or a mapping).\n\n##### Positional Arguments\n- **self**: `Evision.FileStorage.t()`\n- **name**: `String`.\n\n  name of the structure. When writing to sequences (a.k.a. \"arrays\"), pass an empty string.\n\n- **flags**: `integer()`.\n\n  type of the structure (FileNode::MAP or FileNode::SEQ (both with optional FileNode::FLOW)).\n\n##### Keyword Arguments\n- **typeName**: `String`.\n\n  optional name of the type you store. The effect of setting this depends on the storage format.\n  I.e. if the format has a specification for storing type information, this parameter is used.\n\nPython prototype (for reference only):\n```python3\nstartWriteStruct(name, flags[, typeName]) -> None\n```","ref":"Evision.FileStorage.html#startWriteStruct/4"},{"type":"function","title":"Evision.FileStorage.write/1","doc":"","ref":"Evision.FileStorage.html#write/1"},{"type":"function","title":"Evision.FileStorage.write/3","doc":"#### Variant 1:\nwrite\n\n##### Positional Arguments\n- **self**: `Evision.FileStorage.t()`\n- **name**: `String`\n- **val**: `[String]`\n\nPython prototype (for reference only):\n```python3\nwrite(name, val) -> None\n```\n#### Variant 2:\nwrite\n\n##### Positional Arguments\n- **self**: `Evision.FileStorage.t()`\n- **name**: `String`\n- **val**: `Evision.Mat`\n\nPython prototype (for reference only):\n```python3\nwrite(name, val) -> None\n```\n#### Variant 3:\nwrite\n\n##### Positional Arguments\n- **self**: `Evision.FileStorage.t()`\n- **name**: `String`\n- **val**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(name, val) -> None\n```\n#### Variant 4:\nwrite\n\n##### Positional Arguments\n- **self**: `Evision.FileStorage.t()`\n- **name**: `String`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nwrite(name, val) -> None\n```\n#### Variant 5:\nSimplified writing API to use with bindings.\n\n##### Positional Arguments\n- **self**: `Evision.FileStorage.t()`\n- **name**: `String`.\n\n  Name of the written object. When writing to sequences (a.k.a. \"arrays\"), pass an empty string.\n\n- **val**: `integer()`.\n\n  Value of the written object.\n\nPython prototype (for reference only):\n```python3\nwrite(name, val) -> None\n```","ref":"Evision.FileStorage.html#write/3"},{"type":"function","title":"Evision.FileStorage.writeComment/1","doc":"","ref":"Evision.FileStorage.html#writeComment/1"},{"type":"function","title":"Evision.FileStorage.writeComment/2","doc":"Writes a comment.\n\n##### Positional Arguments\n- **self**: `Evision.FileStorage.t()`\n- **comment**: `String`.\n\n  The written comment, single-line or multi-line\n\n##### Keyword Arguments\n- **append**: `bool`.\n\n  If true, the function tries to put the comment at the end of current line.\n  Else if the comment is multi-line, or if it does not fit at the end of the current\n  line, the comment starts a new line.\n\nThe function writes a comment into file storage. The comments are skipped when the storage is read.\n\nPython prototype (for reference only):\n```python3\nwriteComment(comment[, append]) -> None\n```","ref":"Evision.FileStorage.html#writeComment/2"},{"type":"function","title":"Evision.FileStorage.writeComment/3","doc":"Writes a comment.\n\n##### Positional Arguments\n- **self**: `Evision.FileStorage.t()`\n- **comment**: `String`.\n\n  The written comment, single-line or multi-line\n\n##### Keyword Arguments\n- **append**: `bool`.\n\n  If true, the function tries to put the comment at the end of current line.\n  Else if the comment is multi-line, or if it does not fit at the end of the current\n  line, the comment starts a new line.\n\nThe function writes a comment into file storage. The comments are skipped when the storage is read.\n\nPython prototype (for reference only):\n```python3\nwriteComment(comment[, append]) -> None\n```","ref":"Evision.FileStorage.html#writeComment/3"},{"type":"type","title":"Evision.FileStorage.t/0","doc":"Type that represents an `FileStorage` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.FileStorage.html#t:t/0"},{"type":"module","title":"Evision.FileStorage.Mode","doc":"","ref":"Evision.FileStorage.Mode.html"},{"type":"function","title":"Evision.FileStorage.Mode.cv_APPEND/0","doc":"","ref":"Evision.FileStorage.Mode.html#cv_APPEND/0"},{"type":"function","title":"Evision.FileStorage.Mode.cv_BASE64/0","doc":"","ref":"Evision.FileStorage.Mode.html#cv_BASE64/0"},{"type":"function","title":"Evision.FileStorage.Mode.cv_FORMAT_AUTO/0","doc":"","ref":"Evision.FileStorage.Mode.html#cv_FORMAT_AUTO/0"},{"type":"function","title":"Evision.FileStorage.Mode.cv_FORMAT_JSON/0","doc":"","ref":"Evision.FileStorage.Mode.html#cv_FORMAT_JSON/0"},{"type":"function","title":"Evision.FileStorage.Mode.cv_FORMAT_MASK/0","doc":"","ref":"Evision.FileStorage.Mode.html#cv_FORMAT_MASK/0"},{"type":"function","title":"Evision.FileStorage.Mode.cv_FORMAT_XML/0","doc":"","ref":"Evision.FileStorage.Mode.html#cv_FORMAT_XML/0"},{"type":"function","title":"Evision.FileStorage.Mode.cv_FORMAT_YAML/0","doc":"","ref":"Evision.FileStorage.Mode.html#cv_FORMAT_YAML/0"},{"type":"function","title":"Evision.FileStorage.Mode.cv_MEMORY/0","doc":"","ref":"Evision.FileStorage.Mode.html#cv_MEMORY/0"},{"type":"function","title":"Evision.FileStorage.Mode.cv_READ/0","doc":"","ref":"Evision.FileStorage.Mode.html#cv_READ/0"},{"type":"function","title":"Evision.FileStorage.Mode.cv_WRITE/0","doc":"","ref":"Evision.FileStorage.Mode.html#cv_WRITE/0"},{"type":"function","title":"Evision.FileStorage.Mode.cv_WRITE_BASE64/0","doc":"","ref":"Evision.FileStorage.Mode.html#cv_WRITE_BASE64/0"},{"type":"type","title":"Evision.FileStorage.Mode.enum/0","doc":"","ref":"Evision.FileStorage.Mode.html#t:enum/0"},{"type":"module","title":"Evision.FileStorage.State","doc":"","ref":"Evision.FileStorage.State.html"},{"type":"function","title":"Evision.FileStorage.State.cv_INSIDE_MAP/0","doc":"","ref":"Evision.FileStorage.State.html#cv_INSIDE_MAP/0"},{"type":"function","title":"Evision.FileStorage.State.cv_NAME_EXPECTED/0","doc":"","ref":"Evision.FileStorage.State.html#cv_NAME_EXPECTED/0"},{"type":"function","title":"Evision.FileStorage.State.cv_UNDEFINED/0","doc":"","ref":"Evision.FileStorage.State.html#cv_UNDEFINED/0"},{"type":"function","title":"Evision.FileStorage.State.cv_VALUE_EXPECTED/0","doc":"","ref":"Evision.FileStorage.State.html#cv_VALUE_EXPECTED/0"},{"type":"type","title":"Evision.FileStorage.State.enum/0","doc":"","ref":"Evision.FileStorage.State.html#t:enum/0"},{"type":"module","title":"Evision.FishEye","doc":"","ref":"Evision.FishEye.html"},{"type":"function","title":"Evision.FishEye.calibrate/1","doc":"","ref":"Evision.FishEye.html#calibrate/1"},{"type":"function","title":"Evision.FishEye.calibrate/5","doc":"Performs camera calibration\n\n##### Positional Arguments\n- **objectPoints**: `[Evision.Mat]`.\n\n  vector of vectors of calibration pattern points in the calibration pattern\n  coordinate space.\n\n- **imagePoints**: `[Evision.Mat]`.\n\n  vector of vectors of the projections of calibration pattern points.\n  imagePoints.size() and objectPoints.size() and imagePoints[i].size() must be equal to\n  objectPoints[i].size() for each i.\n\n- **image_size**: `Size`.\n\n  Size of the image used only to initialize the camera intrinsic matrix.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Different flags that may be zero or a combination of the following values:\n  - @ref fisheye::CALIB_USE_INTRINSIC_GUESS  cameraMatrix contains valid initial values of\n    fx, fy, cx, cy that are optimized further. Otherwise, (cx, cy) is initially set to the image\n    center ( imageSize is used), and focal distances are computed in a least-squares fashion.\n  - @ref fisheye::CALIB_RECOMPUTE_EXTRINSIC  Extrinsic will be recomputed after each iteration\n    of intrinsic optimization.\n  - @ref fisheye::CALIB_CHECK_COND  The functions will check validity of condition number.\n  - @ref fisheye::CALIB_FIX_SKEW  Skew coefficient (alpha) is set to zero and stay zero.\n  - @ref fisheye::CALIB_FIX_K1,..., @ref fisheye::CALIB_FIX_K4 Selected distortion coefficients\n    are set to zeros and stay zero.\n  - @ref fisheye::CALIB_FIX_PRINCIPAL_POINT  The principal point is not changed during the global\n    optimization. It stays at the center or at a different location specified when @ref fisheye::CALIB_USE_INTRINSIC_GUESS is set too.\n  - @ref fisheye::CALIB_FIX_FOCAL_LENGTH The focal length is not changed during the global\n    optimization. It is the \\f$max(width,height)/\\pi\\f$ or the provided \\f$f_x\\f$, \\f$f_y\\f$ when @ref fisheye::CALIB_USE_INTRINSIC_GUESS is set too.\n\n- **criteria**: `TermCriteria`.\n\n  Termination criteria for the iterative optimization algorithm.\n\n##### Return\n- **retval**: `double`\n- **k**: `Evision.Mat.t()`.\n\n  Output 3x3 floating-point camera intrinsic matrix\n  \\f$\\cameramatrix{A}\\f$ . If\n\n- **d**: `Evision.Mat.t()`.\n\n  Output vector of distortion coefficients \\f$\\distcoeffsfisheye\\f$.\n\n- **rvecs**: `[Evision.Mat]`.\n\n  Output vector of rotation vectors (see Rodrigues ) estimated for each pattern view.\n  That is, each k-th rotation vector together with the corresponding k-th translation vector (see\n  the next output parameter description) brings the calibration pattern from the model coordinate\n  space (in which object points are specified) to the world coordinate space, that is, a real\n  position of the calibration pattern in the k-th pattern view (k=0.. *M* -1).\n\n- **tvecs**: `[Evision.Mat]`.\n\n  Output vector of translation vectors estimated for each pattern view.\n\n@ref fisheye::CALIB_USE_INTRINSIC_GUESS is specified, some or all of fx, fy, cx, cy must be\ninitialized before calling the function.\n\nPython prototype (for reference only):\n```python3\ncalibrate(objectPoints, imagePoints, image_size, K, D[, rvecs[, tvecs[, flags[, criteria]]]]) -> retval, K, D, rvecs, tvecs\n```","ref":"Evision.FishEye.html#calibrate/5"},{"type":"function","title":"Evision.FishEye.calibrate/6","doc":"Performs camera calibration\n\n##### Positional Arguments\n- **objectPoints**: `[Evision.Mat]`.\n\n  vector of vectors of calibration pattern points in the calibration pattern\n  coordinate space.\n\n- **imagePoints**: `[Evision.Mat]`.\n\n  vector of vectors of the projections of calibration pattern points.\n  imagePoints.size() and objectPoints.size() and imagePoints[i].size() must be equal to\n  objectPoints[i].size() for each i.\n\n- **image_size**: `Size`.\n\n  Size of the image used only to initialize the camera intrinsic matrix.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Different flags that may be zero or a combination of the following values:\n  - @ref fisheye::CALIB_USE_INTRINSIC_GUESS  cameraMatrix contains valid initial values of\n    fx, fy, cx, cy that are optimized further. Otherwise, (cx, cy) is initially set to the image\n    center ( imageSize is used), and focal distances are computed in a least-squares fashion.\n  - @ref fisheye::CALIB_RECOMPUTE_EXTRINSIC  Extrinsic will be recomputed after each iteration\n    of intrinsic optimization.\n  - @ref fisheye::CALIB_CHECK_COND  The functions will check validity of condition number.\n  - @ref fisheye::CALIB_FIX_SKEW  Skew coefficient (alpha) is set to zero and stay zero.\n  - @ref fisheye::CALIB_FIX_K1,..., @ref fisheye::CALIB_FIX_K4 Selected distortion coefficients\n    are set to zeros and stay zero.\n  - @ref fisheye::CALIB_FIX_PRINCIPAL_POINT  The principal point is not changed during the global\n    optimization. It stays at the center or at a different location specified when @ref fisheye::CALIB_USE_INTRINSIC_GUESS is set too.\n  - @ref fisheye::CALIB_FIX_FOCAL_LENGTH The focal length is not changed during the global\n    optimization. It is the \\f$max(width,height)/\\pi\\f$ or the provided \\f$f_x\\f$, \\f$f_y\\f$ when @ref fisheye::CALIB_USE_INTRINSIC_GUESS is set too.\n\n- **criteria**: `TermCriteria`.\n\n  Termination criteria for the iterative optimization algorithm.\n\n##### Return\n- **retval**: `double`\n- **k**: `Evision.Mat.t()`.\n\n  Output 3x3 floating-point camera intrinsic matrix\n  \\f$\\cameramatrix{A}\\f$ . If\n\n- **d**: `Evision.Mat.t()`.\n\n  Output vector of distortion coefficients \\f$\\distcoeffsfisheye\\f$.\n\n- **rvecs**: `[Evision.Mat]`.\n\n  Output vector of rotation vectors (see Rodrigues ) estimated for each pattern view.\n  That is, each k-th rotation vector together with the corresponding k-th translation vector (see\n  the next output parameter description) brings the calibration pattern from the model coordinate\n  space (in which object points are specified) to the world coordinate space, that is, a real\n  position of the calibration pattern in the k-th pattern view (k=0.. *M* -1).\n\n- **tvecs**: `[Evision.Mat]`.\n\n  Output vector of translation vectors estimated for each pattern view.\n\n@ref fisheye::CALIB_USE_INTRINSIC_GUESS is specified, some or all of fx, fy, cx, cy must be\ninitialized before calling the function.\n\nPython prototype (for reference only):\n```python3\ncalibrate(objectPoints, imagePoints, image_size, K, D[, rvecs[, tvecs[, flags[, criteria]]]]) -> retval, K, D, rvecs, tvecs\n```","ref":"Evision.FishEye.html#calibrate/6"},{"type":"function","title":"Evision.FishEye.cv_CALIB_CHECK_COND/0","doc":"","ref":"Evision.FishEye.html#cv_CALIB_CHECK_COND/0"},{"type":"function","title":"Evision.FishEye.cv_CALIB_FIX_FOCAL_LENGTH/0","doc":"","ref":"Evision.FishEye.html#cv_CALIB_FIX_FOCAL_LENGTH/0"},{"type":"function","title":"Evision.FishEye.cv_CALIB_FIX_INTRINSIC/0","doc":"","ref":"Evision.FishEye.html#cv_CALIB_FIX_INTRINSIC/0"},{"type":"function","title":"Evision.FishEye.cv_CALIB_FIX_K1/0","doc":"","ref":"Evision.FishEye.html#cv_CALIB_FIX_K1/0"},{"type":"function","title":"Evision.FishEye.cv_CALIB_FIX_K2/0","doc":"","ref":"Evision.FishEye.html#cv_CALIB_FIX_K2/0"},{"type":"function","title":"Evision.FishEye.cv_CALIB_FIX_K3/0","doc":"","ref":"Evision.FishEye.html#cv_CALIB_FIX_K3/0"},{"type":"function","title":"Evision.FishEye.cv_CALIB_FIX_K4/0","doc":"","ref":"Evision.FishEye.html#cv_CALIB_FIX_K4/0"},{"type":"function","title":"Evision.FishEye.cv_CALIB_FIX_PRINCIPAL_POINT/0","doc":"","ref":"Evision.FishEye.html#cv_CALIB_FIX_PRINCIPAL_POINT/0"},{"type":"function","title":"Evision.FishEye.cv_CALIB_FIX_SKEW/0","doc":"","ref":"Evision.FishEye.html#cv_CALIB_FIX_SKEW/0"},{"type":"function","title":"Evision.FishEye.cv_CALIB_RECOMPUTE_EXTRINSIC/0","doc":"","ref":"Evision.FishEye.html#cv_CALIB_RECOMPUTE_EXTRINSIC/0"},{"type":"function","title":"Evision.FishEye.cv_CALIB_USE_INTRINSIC_GUESS/0","doc":"","ref":"Evision.FishEye.html#cv_CALIB_USE_INTRINSIC_GUESS/0"},{"type":"function","title":"Evision.FishEye.cv_CALIB_ZERO_DISPARITY/0","doc":"","ref":"Evision.FishEye.html#cv_CALIB_ZERO_DISPARITY/0"},{"type":"function","title":"Evision.FishEye.distortPoints/1","doc":"","ref":"Evision.FishEye.html#distortPoints/1"},{"type":"function","title":"Evision.FishEye.distortPoints/3","doc":"Distorts 2D points using fisheye model.\n\n##### Positional Arguments\n- **undistorted**: `Evision.Mat`.\n\n  Array of object points, 1xN/Nx1 2-channel (or vector\\  ), where N is\n  the number of points in the view.\n\n- **k**: `Evision.Mat`.\n\n  Camera intrinsic matrix \\f$cameramatrix{K}\\f$.\n\n- **d**: `Evision.Mat`.\n\n  Input vector of distortion coefficients \\f$\\distcoeffsfisheye\\f$.\n\n##### Keyword Arguments\n- **alpha**: `double`.\n\n  The skew coefficient.\n\n##### Return\n- **distorted**: `Evision.Mat.t()`.\n\n  Output array of image points, 1xN/Nx1 2-channel, or vector\\  .\n\nNote that the function assumes the camera intrinsic matrix of the undistorted points to be identity.\nThis means if you want to distort image points you have to multiply them with \\f$K^{-1}\\f$.\n\nPython prototype (for reference only):\n```python3\ndistortPoints(undistorted, K, D[, distorted[, alpha]]) -> distorted\n```","ref":"Evision.FishEye.html#distortPoints/3"},{"type":"function","title":"Evision.FishEye.distortPoints/4","doc":"Distorts 2D points using fisheye model.\n\n##### Positional Arguments\n- **undistorted**: `Evision.Mat`.\n\n  Array of object points, 1xN/Nx1 2-channel (or vector\\  ), where N is\n  the number of points in the view.\n\n- **k**: `Evision.Mat`.\n\n  Camera intrinsic matrix \\f$cameramatrix{K}\\f$.\n\n- **d**: `Evision.Mat`.\n\n  Input vector of distortion coefficients \\f$\\distcoeffsfisheye\\f$.\n\n##### Keyword Arguments\n- **alpha**: `double`.\n\n  The skew coefficient.\n\n##### Return\n- **distorted**: `Evision.Mat.t()`.\n\n  Output array of image points, 1xN/Nx1 2-channel, or vector\\  .\n\nNote that the function assumes the camera intrinsic matrix of the undistorted points to be identity.\nThis means if you want to distort image points you have to multiply them with \\f$K^{-1}\\f$.\n\nPython prototype (for reference only):\n```python3\ndistortPoints(undistorted, K, D[, distorted[, alpha]]) -> distorted\n```","ref":"Evision.FishEye.html#distortPoints/4"},{"type":"function","title":"Evision.FishEye.estimateNewCameraMatrixForUndistortRectify/1","doc":"","ref":"Evision.FishEye.html#estimateNewCameraMatrixForUndistortRectify/1"},{"type":"function","title":"Evision.FishEye.estimateNewCameraMatrixForUndistortRectify/4","doc":"Estimates new camera intrinsic matrix for undistortion or rectification.\n\n##### Positional Arguments\n- **k**: `Evision.Mat`.\n\n  Camera intrinsic matrix \\f$cameramatrix{K}\\f$.\n\n- **d**: `Evision.Mat`.\n\n  Input vector of distortion coefficients \\f$\\distcoeffsfisheye\\f$.\n\n- **image_size**: `Size`.\n\n  Size of the image\n\n- **r**: `Evision.Mat`.\n\n  Rectification transformation in the object space: 3x3 1-channel, or vector: 3x1/1x3\n  1-channel or 1x1 3-channel\n\n##### Keyword Arguments\n- **balance**: `double`.\n\n  Sets the new focal length in range between the min focal length and the max focal\n  length. Balance is in range of [0, 1].\n\n- **new_size**: `Size`.\n\n  the new size\n\n- **fov_scale**: `double`.\n\n  Divisor for new focal length.\n\n##### Return\n- **p**: `Evision.Mat.t()`.\n\n  New camera intrinsic matrix (3x3) or new projection matrix (3x4)\n\nPython prototype (for reference only):\n```python3\nestimateNewCameraMatrixForUndistortRectify(K, D, image_size, R[, P[, balance[, new_size[, fov_scale]]]]) -> P\n```","ref":"Evision.FishEye.html#estimateNewCameraMatrixForUndistortRectify/4"},{"type":"function","title":"Evision.FishEye.estimateNewCameraMatrixForUndistortRectify/5","doc":"Estimates new camera intrinsic matrix for undistortion or rectification.\n\n##### Positional Arguments\n- **k**: `Evision.Mat`.\n\n  Camera intrinsic matrix \\f$cameramatrix{K}\\f$.\n\n- **d**: `Evision.Mat`.\n\n  Input vector of distortion coefficients \\f$\\distcoeffsfisheye\\f$.\n\n- **image_size**: `Size`.\n\n  Size of the image\n\n- **r**: `Evision.Mat`.\n\n  Rectification transformation in the object space: 3x3 1-channel, or vector: 3x1/1x3\n  1-channel or 1x1 3-channel\n\n##### Keyword Arguments\n- **balance**: `double`.\n\n  Sets the new focal length in range between the min focal length and the max focal\n  length. Balance is in range of [0, 1].\n\n- **new_size**: `Size`.\n\n  the new size\n\n- **fov_scale**: `double`.\n\n  Divisor for new focal length.\n\n##### Return\n- **p**: `Evision.Mat.t()`.\n\n  New camera intrinsic matrix (3x3) or new projection matrix (3x4)\n\nPython prototype (for reference only):\n```python3\nestimateNewCameraMatrixForUndistortRectify(K, D, image_size, R[, P[, balance[, new_size[, fov_scale]]]]) -> P\n```","ref":"Evision.FishEye.html#estimateNewCameraMatrixForUndistortRectify/5"},{"type":"function","title":"Evision.FishEye.initUndistortRectifyMap/1","doc":"","ref":"Evision.FishEye.html#initUndistortRectifyMap/1"},{"type":"function","title":"Evision.FishEye.initUndistortRectifyMap/6","doc":"Computes undistortion and rectification maps for image transform by #remap. If D is empty zero\ndistortion is used, if R or P is empty identity matrixes are used.\n\n##### Positional Arguments\n- **k**: `Evision.Mat`.\n\n  Camera intrinsic matrix \\f$cameramatrix{K}\\f$.\n\n- **d**: `Evision.Mat`.\n\n  Input vector of distortion coefficients \\f$\\distcoeffsfisheye\\f$.\n\n- **r**: `Evision.Mat`.\n\n  Rectification transformation in the object space: 3x3 1-channel, or vector: 3x1/1x3\n  1-channel or 1x1 3-channel\n\n- **p**: `Evision.Mat`.\n\n  New camera intrinsic matrix (3x3) or new projection matrix (3x4)\n\n- **size**: `Size`.\n\n  Undistorted image size.\n\n- **m1type**: `integer()`.\n\n  Type of the first output map that can be CV_32FC1 or CV_16SC2 . See #convertMaps\n  for details.\n\n##### Return\n- **map1**: `Evision.Mat.t()`.\n\n  The first output map.\n\n- **map2**: `Evision.Mat.t()`.\n\n  The second output map.\n\nPython prototype (for reference only):\n```python3\ninitUndistortRectifyMap(K, D, R, P, size, m1type[, map1[, map2]]) -> map1, map2\n```","ref":"Evision.FishEye.html#initUndistortRectifyMap/6"},{"type":"function","title":"Evision.FishEye.initUndistortRectifyMap/7","doc":"Computes undistortion and rectification maps for image transform by #remap. If D is empty zero\ndistortion is used, if R or P is empty identity matrixes are used.\n\n##### Positional Arguments\n- **k**: `Evision.Mat`.\n\n  Camera intrinsic matrix \\f$cameramatrix{K}\\f$.\n\n- **d**: `Evision.Mat`.\n\n  Input vector of distortion coefficients \\f$\\distcoeffsfisheye\\f$.\n\n- **r**: `Evision.Mat`.\n\n  Rectification transformation in the object space: 3x3 1-channel, or vector: 3x1/1x3\n  1-channel or 1x1 3-channel\n\n- **p**: `Evision.Mat`.\n\n  New camera intrinsic matrix (3x3) or new projection matrix (3x4)\n\n- **size**: `Size`.\n\n  Undistorted image size.\n\n- **m1type**: `integer()`.\n\n  Type of the first output map that can be CV_32FC1 or CV_16SC2 . See #convertMaps\n  for details.\n\n##### Return\n- **map1**: `Evision.Mat.t()`.\n\n  The first output map.\n\n- **map2**: `Evision.Mat.t()`.\n\n  The second output map.\n\nPython prototype (for reference only):\n```python3\ninitUndistortRectifyMap(K, D, R, P, size, m1type[, map1[, map2]]) -> map1, map2\n```","ref":"Evision.FishEye.html#initUndistortRectifyMap/7"},{"type":"function","title":"Evision.FishEye.projectPoints/1","doc":"","ref":"Evision.FishEye.html#projectPoints/1"},{"type":"function","title":"Evision.FishEye.projectPoints/5","doc":"projectPoints\n\n##### Positional Arguments\n- **objectPoints**: `Evision.Mat`\n- **rvec**: `Evision.Mat`\n- **tvec**: `Evision.Mat`\n- **k**: `Evision.Mat`\n- **d**: `Evision.Mat`\n\n##### Keyword Arguments\n- **alpha**: `double`.\n\n##### Return\n- **imagePoints**: `Evision.Mat.t()`.\n- **jacobian**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nprojectPoints(objectPoints, rvec, tvec, K, D[, imagePoints[, alpha[, jacobian]]]) -> imagePoints, jacobian\n```","ref":"Evision.FishEye.html#projectPoints/5"},{"type":"function","title":"Evision.FishEye.projectPoints/6","doc":"projectPoints\n\n##### Positional Arguments\n- **objectPoints**: `Evision.Mat`\n- **rvec**: `Evision.Mat`\n- **tvec**: `Evision.Mat`\n- **k**: `Evision.Mat`\n- **d**: `Evision.Mat`\n\n##### Keyword Arguments\n- **alpha**: `double`.\n\n##### Return\n- **imagePoints**: `Evision.Mat.t()`.\n- **jacobian**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nprojectPoints(objectPoints, rvec, tvec, K, D[, imagePoints[, alpha[, jacobian]]]) -> imagePoints, jacobian\n```","ref":"Evision.FishEye.html#projectPoints/6"},{"type":"function","title":"Evision.FishEye.solvePnP/1","doc":"","ref":"Evision.FishEye.html#solvePnP/1"},{"type":"function","title":"Evision.FishEye.solvePnP/4","doc":"Finds an object pose from 3D-2D point correspondences for fisheye camera moodel.\n\n##### Positional Arguments\n- **objectPoints**: `Evision.Mat`.\n\n  Array of object points in the object coordinate space, Nx3 1-channel or\n  1xN/Nx1 3-channel, where N is the number of points. vector\\  can be also passed here.\n\n- **imagePoints**: `Evision.Mat`.\n\n  Array of corresponding image points, Nx2 1-channel or 1xN/Nx1 2-channel,\n  where N is the number of points. vector\\  can be also passed here.\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input camera intrinsic matrix \\f$\\cameramatrix{A}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients (4x1/1x4).\n\n##### Keyword Arguments\n- **useExtrinsicGuess**: `bool`.\n\n  Parameter used for #SOLVEPNP_ITERATIVE. If true (1), the function uses\n  the provided rvec and tvec values as initial approximations of the rotation and translation\n  vectors, respectively, and further optimizes them.\n\n- **flags**: `integer()`.\n\n  Method for solving a PnP problem: see @ref calib3d_solvePnP_flags\n  This function returns the rotation and the translation vectors that transform a 3D point expressed in the object\n  coordinate frame to the camera coordinate frame, using different methods:\n  - P3P methods (@ref SOLVEPNP_P3P, @ref SOLVEPNP_AP3P): need 4 input points to return a unique solution.\n  - @ref SOLVEPNP_IPPE Input points must be >= 4 and object points must be coplanar.\n  - @ref SOLVEPNP_IPPE_SQUARE Special case suitable for marker pose estimation.\n    Number of input points must be 4. Object points must be defined in the following order:\n  - point 0: [-squareLength / 2,  squareLength / 2, 0]\n  - point 1: [ squareLength / 2,  squareLength / 2, 0]\n  - point 2: [ squareLength / 2, -squareLength / 2, 0]\n  - point 3: [-squareLength / 2, -squareLength / 2, 0]\n  - for all the other flags, number of input points must be >= 4 and object points can be in any configuration.\n\n- **criteria**: `TermCriteria`.\n\n  Termination criteria for internal undistortPoints call.\n  The function interally undistorts points with @ref undistortPoints and call @ref cv::solvePnP,\n  thus the input are very similar. Check there and Perspective-n-Points is described in @ref calib3d_solvePnP\n  for more information.\n\n##### Return\n- **retval**: `bool`\n- **rvec**: `Evision.Mat.t()`.\n\n  Output rotation vector (see @ref Rodrigues ) that, together with tvec, brings points from\n  the model coordinate system to the camera coordinate system.\n\n- **tvec**: `Evision.Mat.t()`.\n\n  Output translation vector.\n\nPython prototype (for reference only):\n```python3\nsolvePnP(objectPoints, imagePoints, cameraMatrix, distCoeffs[, rvec[, tvec[, useExtrinsicGuess[, flags[, criteria]]]]]) -> retval, rvec, tvec\n```","ref":"Evision.FishEye.html#solvePnP/4"},{"type":"function","title":"Evision.FishEye.solvePnP/5","doc":"Finds an object pose from 3D-2D point correspondences for fisheye camera moodel.\n\n##### Positional Arguments\n- **objectPoints**: `Evision.Mat`.\n\n  Array of object points in the object coordinate space, Nx3 1-channel or\n  1xN/Nx1 3-channel, where N is the number of points. vector\\  can be also passed here.\n\n- **imagePoints**: `Evision.Mat`.\n\n  Array of corresponding image points, Nx2 1-channel or 1xN/Nx1 2-channel,\n  where N is the number of points. vector\\  can be also passed here.\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Input camera intrinsic matrix \\f$\\cameramatrix{A}\\f$ .\n\n- **distCoeffs**: `Evision.Mat`.\n\n  Input vector of distortion coefficients (4x1/1x4).\n\n##### Keyword Arguments\n- **useExtrinsicGuess**: `bool`.\n\n  Parameter used for #SOLVEPNP_ITERATIVE. If true (1), the function uses\n  the provided rvec and tvec values as initial approximations of the rotation and translation\n  vectors, respectively, and further optimizes them.\n\n- **flags**: `integer()`.\n\n  Method for solving a PnP problem: see @ref calib3d_solvePnP_flags\n  This function returns the rotation and the translation vectors that transform a 3D point expressed in the object\n  coordinate frame to the camera coordinate frame, using different methods:\n  - P3P methods (@ref SOLVEPNP_P3P, @ref SOLVEPNP_AP3P): need 4 input points to return a unique solution.\n  - @ref SOLVEPNP_IPPE Input points must be >= 4 and object points must be coplanar.\n  - @ref SOLVEPNP_IPPE_SQUARE Special case suitable for marker pose estimation.\n    Number of input points must be 4. Object points must be defined in the following order:\n  - point 0: [-squareLength / 2,  squareLength / 2, 0]\n  - point 1: [ squareLength / 2,  squareLength / 2, 0]\n  - point 2: [ squareLength / 2, -squareLength / 2, 0]\n  - point 3: [-squareLength / 2, -squareLength / 2, 0]\n  - for all the other flags, number of input points must be >= 4 and object points can be in any configuration.\n\n- **criteria**: `TermCriteria`.\n\n  Termination criteria for internal undistortPoints call.\n  The function interally undistorts points with @ref undistortPoints and call @ref cv::solvePnP,\n  thus the input are very similar. Check there and Perspective-n-Points is described in @ref calib3d_solvePnP\n  for more information.\n\n##### Return\n- **retval**: `bool`\n- **rvec**: `Evision.Mat.t()`.\n\n  Output rotation vector (see @ref Rodrigues ) that, together with tvec, brings points from\n  the model coordinate system to the camera coordinate system.\n\n- **tvec**: `Evision.Mat.t()`.\n\n  Output translation vector.\n\nPython prototype (for reference only):\n```python3\nsolvePnP(objectPoints, imagePoints, cameraMatrix, distCoeffs[, rvec[, tvec[, useExtrinsicGuess[, flags[, criteria]]]]]) -> retval, rvec, tvec\n```","ref":"Evision.FishEye.html#solvePnP/5"},{"type":"function","title":"Evision.FishEye.stereoCalibrate/1","doc":"","ref":"Evision.FishEye.html#stereoCalibrate/1"},{"type":"function","title":"Evision.FishEye.stereoCalibrate/8","doc":"stereoCalibrate\n\n##### Positional Arguments\n- **objectPoints**: `[Evision.Mat]`\n- **imagePoints1**: `[Evision.Mat]`\n- **imagePoints2**: `[Evision.Mat]`\n- **imageSize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **criteria**: `TermCriteria`.\n\n##### Return\n- **retval**: `double`\n- **k1**: `Evision.Mat.t()`\n- **d1**: `Evision.Mat.t()`\n- **k2**: `Evision.Mat.t()`\n- **d2**: `Evision.Mat.t()`\n- **r**: `Evision.Mat.t()`.\n- **t**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nstereoCalibrate(objectPoints, imagePoints1, imagePoints2, K1, D1, K2, D2, imageSize[, R[, T[, flags[, criteria]]]]) -> retval, K1, D1, K2, D2, R, T\n```","ref":"Evision.FishEye.html#stereoCalibrate/8"},{"type":"function","title":"Evision.FishEye.stereoCalibrate/9","doc":"stereoCalibrate\n\n##### Positional Arguments\n- **objectPoints**: `[Evision.Mat]`\n- **imagePoints1**: `[Evision.Mat]`\n- **imagePoints2**: `[Evision.Mat]`\n- **imageSize**: `Size`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n- **criteria**: `TermCriteria`.\n\n##### Return\n- **retval**: `double`\n- **k1**: `Evision.Mat.t()`\n- **d1**: `Evision.Mat.t()`\n- **k2**: `Evision.Mat.t()`\n- **d2**: `Evision.Mat.t()`\n- **r**: `Evision.Mat.t()`.\n- **t**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nstereoCalibrate(objectPoints, imagePoints1, imagePoints2, K1, D1, K2, D2, imageSize[, R[, T[, flags[, criteria]]]]) -> retval, K1, D1, K2, D2, R, T\n```","ref":"Evision.FishEye.html#stereoCalibrate/9"},{"type":"function","title":"Evision.FishEye.stereoRectify/1","doc":"","ref":"Evision.FishEye.html#stereoRectify/1"},{"type":"function","title":"Evision.FishEye.stereoRectify/8","doc":"Stereo rectification for fisheye camera model\n\n##### Positional Arguments\n- **k1**: `Evision.Mat`.\n\n  First camera intrinsic matrix.\n\n- **d1**: `Evision.Mat`.\n\n  First camera distortion parameters.\n\n- **k2**: `Evision.Mat`.\n\n  Second camera intrinsic matrix.\n\n- **d2**: `Evision.Mat`.\n\n  Second camera distortion parameters.\n\n- **imageSize**: `Size`.\n\n  Size of the image used for stereo calibration.\n\n- **r**: `Evision.Mat`.\n\n  Rotation matrix between the coordinate systems of the first and the second\n  cameras.\n\n- **tvec**: `Evision.Mat`.\n\n  Translation vector between coordinate systems of the cameras.\n\n- **flags**: `integer()`.\n\n  Operation flags that may be zero or @ref fisheye::CALIB_ZERO_DISPARITY . If the flag is set,\n  the function makes the principal points of each camera have the same pixel coordinates in the\n  rectified views. And if the flag is not set, the function may still shift the images in the\n  horizontal or vertical direction (depending on the orientation of epipolar lines) to maximize the\n  useful image area.\n\n##### Keyword Arguments\n- **newImageSize**: `Size`.\n\n  New image resolution after rectification. The same size should be passed to\n  #initUndistortRectifyMap (see the stereo_calib.cpp sample in OpenCV samples directory). When (0,0)\n  is passed (default), it is set to the original imageSize . Setting it to larger value can help you\n  preserve details in the original image, especially when there is a big radial distortion.\n\n- **balance**: `double`.\n\n  Sets the new focal length in range between the min focal length and the max focal\n  length. Balance is in range of [0, 1].\n\n- **fov_scale**: `double`.\n\n  Divisor for new focal length.\n\n##### Return\n- **r1**: `Evision.Mat.t()`.\n\n  Output 3x3 rectification transform (rotation matrix) for the first camera.\n\n- **r2**: `Evision.Mat.t()`.\n\n  Output 3x3 rectification transform (rotation matrix) for the second camera.\n\n- **p1**: `Evision.Mat.t()`.\n\n  Output 3x4 projection matrix in the new (rectified) coordinate systems for the first\n  camera.\n\n- **p2**: `Evision.Mat.t()`.\n\n  Output 3x4 projection matrix in the new (rectified) coordinate systems for the second\n  camera.\n\n- **q**: `Evision.Mat.t()`.\n\n  Output \\f$4 \\times 4\\f$ disparity-to-depth mapping matrix (see #reprojectImageTo3D ).\n\nPython prototype (for reference only):\n```python3\nstereoRectify(K1, D1, K2, D2, imageSize, R, tvec, flags[, R1[, R2[, P1[, P2[, Q[, newImageSize[, balance[, fov_scale]]]]]]]]) -> R1, R2, P1, P2, Q\n```","ref":"Evision.FishEye.html#stereoRectify/8"},{"type":"function","title":"Evision.FishEye.stereoRectify/9","doc":"Stereo rectification for fisheye camera model\n\n##### Positional Arguments\n- **k1**: `Evision.Mat`.\n\n  First camera intrinsic matrix.\n\n- **d1**: `Evision.Mat`.\n\n  First camera distortion parameters.\n\n- **k2**: `Evision.Mat`.\n\n  Second camera intrinsic matrix.\n\n- **d2**: `Evision.Mat`.\n\n  Second camera distortion parameters.\n\n- **imageSize**: `Size`.\n\n  Size of the image used for stereo calibration.\n\n- **r**: `Evision.Mat`.\n\n  Rotation matrix between the coordinate systems of the first and the second\n  cameras.\n\n- **tvec**: `Evision.Mat`.\n\n  Translation vector between coordinate systems of the cameras.\n\n- **flags**: `integer()`.\n\n  Operation flags that may be zero or @ref fisheye::CALIB_ZERO_DISPARITY . If the flag is set,\n  the function makes the principal points of each camera have the same pixel coordinates in the\n  rectified views. And if the flag is not set, the function may still shift the images in the\n  horizontal or vertical direction (depending on the orientation of epipolar lines) to maximize the\n  useful image area.\n\n##### Keyword Arguments\n- **newImageSize**: `Size`.\n\n  New image resolution after rectification. The same size should be passed to\n  #initUndistortRectifyMap (see the stereo_calib.cpp sample in OpenCV samples directory). When (0,0)\n  is passed (default), it is set to the original imageSize . Setting it to larger value can help you\n  preserve details in the original image, especially when there is a big radial distortion.\n\n- **balance**: `double`.\n\n  Sets the new focal length in range between the min focal length and the max focal\n  length. Balance is in range of [0, 1].\n\n- **fov_scale**: `double`.\n\n  Divisor for new focal length.\n\n##### Return\n- **r1**: `Evision.Mat.t()`.\n\n  Output 3x3 rectification transform (rotation matrix) for the first camera.\n\n- **r2**: `Evision.Mat.t()`.\n\n  Output 3x3 rectification transform (rotation matrix) for the second camera.\n\n- **p1**: `Evision.Mat.t()`.\n\n  Output 3x4 projection matrix in the new (rectified) coordinate systems for the first\n  camera.\n\n- **p2**: `Evision.Mat.t()`.\n\n  Output 3x4 projection matrix in the new (rectified) coordinate systems for the second\n  camera.\n\n- **q**: `Evision.Mat.t()`.\n\n  Output \\f$4 \\times 4\\f$ disparity-to-depth mapping matrix (see #reprojectImageTo3D ).\n\nPython prototype (for reference only):\n```python3\nstereoRectify(K1, D1, K2, D2, imageSize, R, tvec, flags[, R1[, R2[, P1[, P2[, Q[, newImageSize[, balance[, fov_scale]]]]]]]]) -> R1, R2, P1, P2, Q\n```","ref":"Evision.FishEye.html#stereoRectify/9"},{"type":"function","title":"Evision.FishEye.undistortImage/1","doc":"","ref":"Evision.FishEye.html#undistortImage/1"},{"type":"function","title":"Evision.FishEye.undistortImage/3","doc":"Transforms an image to compensate for fisheye lens distortion.\n\n##### Positional Arguments\n- **distorted**: `Evision.Mat`.\n\n  image with fisheye lens distortion.\n\n- **k**: `Evision.Mat`.\n\n  Camera intrinsic matrix \\f$cameramatrix{K}\\f$.\n\n- **d**: `Evision.Mat`.\n\n  Input vector of distortion coefficients \\f$\\distcoeffsfisheye\\f$.\n\n##### Keyword Arguments\n- **knew**: `Evision.Mat`.\n\n  Camera intrinsic matrix of the distorted image. By default, it is the identity matrix but you\n  may additionally scale and shift the result by using a different matrix.\n\n- **new_size**: `Size`.\n\n  the new size\n\n##### Return\n- **undistorted**: `Evision.Mat.t()`.\n\n  Output image with compensated fisheye lens distortion.\n\nThe function transforms an image to compensate radial and tangential lens distortion.\nThe function is simply a combination of #fisheye::initUndistortRectifyMap (with unity R ) and #remap\n(with bilinear interpolation). See the former function for details of the transformation being\nperformed.\nSee below the results of undistortImage.\n- a\\) result of undistort of perspective camera model (all possible coefficients (k_1, k_2, k_3,\n  k_4, k_5, k_6) of distortion were optimized under calibration)\n\n- b\\) result of #fisheye::undistortImage of fisheye camera model (all possible coefficients (k_1, k_2,\n  k_3, k_4) of fisheye distortion were optimized under calibration)\n\n- c\\) original image was captured with fisheye lens\n\nPictures a) and b) almost the same. But if we consider points of image located far from the center\nof image, we can notice that on image a) these points are distorted.\n![image](pics/fisheye_undistorted.jpg)\n\nPython prototype (for reference only):\n```python3\nundistortImage(distorted, K, D[, undistorted[, Knew[, new_size]]]) -> undistorted\n```","ref":"Evision.FishEye.html#undistortImage/3"},{"type":"function","title":"Evision.FishEye.undistortImage/4","doc":"Transforms an image to compensate for fisheye lens distortion.\n\n##### Positional Arguments\n- **distorted**: `Evision.Mat`.\n\n  image with fisheye lens distortion.\n\n- **k**: `Evision.Mat`.\n\n  Camera intrinsic matrix \\f$cameramatrix{K}\\f$.\n\n- **d**: `Evision.Mat`.\n\n  Input vector of distortion coefficients \\f$\\distcoeffsfisheye\\f$.\n\n##### Keyword Arguments\n- **knew**: `Evision.Mat`.\n\n  Camera intrinsic matrix of the distorted image. By default, it is the identity matrix but you\n  may additionally scale and shift the result by using a different matrix.\n\n- **new_size**: `Size`.\n\n  the new size\n\n##### Return\n- **undistorted**: `Evision.Mat.t()`.\n\n  Output image with compensated fisheye lens distortion.\n\nThe function transforms an image to compensate radial and tangential lens distortion.\nThe function is simply a combination of #fisheye::initUndistortRectifyMap (with unity R ) and #remap\n(with bilinear interpolation). See the former function for details of the transformation being\nperformed.\nSee below the results of undistortImage.\n- a\\) result of undistort of perspective camera model (all possible coefficients (k_1, k_2, k_3,\n  k_4, k_5, k_6) of distortion were optimized under calibration)\n\n- b\\) result of #fisheye::undistortImage of fisheye camera model (all possible coefficients (k_1, k_2,\n  k_3, k_4) of fisheye distortion were optimized under calibration)\n\n- c\\) original image was captured with fisheye lens\n\nPictures a) and b) almost the same. But if we consider points of image located far from the center\nof image, we can notice that on image a) these points are distorted.\n![image](pics/fisheye_undistorted.jpg)\n\nPython prototype (for reference only):\n```python3\nundistortImage(distorted, K, D[, undistorted[, Knew[, new_size]]]) -> undistorted\n```","ref":"Evision.FishEye.html#undistortImage/4"},{"type":"function","title":"Evision.FishEye.undistortPoints/1","doc":"","ref":"Evision.FishEye.html#undistortPoints/1"},{"type":"function","title":"Evision.FishEye.undistortPoints/3","doc":"Undistorts 2D points using fisheye model\n\n##### Positional Arguments\n- **distorted**: `Evision.Mat`.\n\n  Array of object points, 1xN/Nx1 2-channel (or vector\\  ), where N is the\n  number of points in the view.\n\n- **k**: `Evision.Mat`.\n\n  Camera intrinsic matrix \\f$cameramatrix{K}\\f$.\n\n- **d**: `Evision.Mat`.\n\n  Input vector of distortion coefficients \\f$\\distcoeffsfisheye\\f$.\n\n##### Keyword Arguments\n- **r**: `Evision.Mat`.\n\n  Rectification transformation in the object space: 3x3 1-channel, or vector: 3x1/1x3\n  1-channel or 1x1 3-channel\n\n- **p**: `Evision.Mat`.\n\n  New camera intrinsic matrix (3x3) or new projection matrix (3x4)\n\n- **criteria**: `TermCriteria`.\n\n  Termination criteria\n\n##### Return\n- **undistorted**: `Evision.Mat.t()`.\n\n  Output array of image points, 1xN/Nx1 2-channel, or vector\\  .\n\nPython prototype (for reference only):\n```python3\nundistortPoints(distorted, K, D[, undistorted[, R[, P[, criteria]]]]) -> undistorted\n```","ref":"Evision.FishEye.html#undistortPoints/3"},{"type":"function","title":"Evision.FishEye.undistortPoints/4","doc":"Undistorts 2D points using fisheye model\n\n##### Positional Arguments\n- **distorted**: `Evision.Mat`.\n\n  Array of object points, 1xN/Nx1 2-channel (or vector\\  ), where N is the\n  number of points in the view.\n\n- **k**: `Evision.Mat`.\n\n  Camera intrinsic matrix \\f$cameramatrix{K}\\f$.\n\n- **d**: `Evision.Mat`.\n\n  Input vector of distortion coefficients \\f$\\distcoeffsfisheye\\f$.\n\n##### Keyword Arguments\n- **r**: `Evision.Mat`.\n\n  Rectification transformation in the object space: 3x3 1-channel, or vector: 3x1/1x3\n  1-channel or 1x1 3-channel\n\n- **p**: `Evision.Mat`.\n\n  New camera intrinsic matrix (3x3) or new projection matrix (3x4)\n\n- **criteria**: `TermCriteria`.\n\n  Termination criteria\n\n##### Return\n- **undistorted**: `Evision.Mat.t()`.\n\n  Output array of image points, 1xN/Nx1 2-channel, or vector\\  .\n\nPython prototype (for reference only):\n```python3\nundistortPoints(distorted, K, D[, undistorted[, R[, P[, criteria]]]]) -> undistorted\n```","ref":"Evision.FishEye.html#undistortPoints/4"},{"type":"type","title":"Evision.FishEye.enum/0","doc":"","ref":"Evision.FishEye.html#t:enum/0"},{"type":"type","title":"Evision.FishEye.t/0","doc":"Type that represents an `FishEye` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.FishEye.html#t:t/0"},{"type":"module","title":"Evision.Flann","doc":"","ref":"Evision.Flann.html"},{"type":"function","title":"Evision.Flann.cv_FLANN_CHECKS_AUTOTUNED/0","doc":"","ref":"Evision.Flann.html#cv_FLANN_CHECKS_AUTOTUNED/0"},{"type":"function","title":"Evision.Flann.cv_FLANN_CHECKS_UNLIMITED/0","doc":"","ref":"Evision.Flann.html#cv_FLANN_CHECKS_UNLIMITED/0"},{"type":"type","title":"Evision.Flann.enum/0","doc":"","ref":"Evision.Flann.html#t:enum/0"},{"type":"type","title":"Evision.Flann.t/0","doc":"Type that represents an `Flann` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Flann.html#t:t/0"},{"type":"module","title":"Evision.Flann.Algorithm","doc":"","ref":"Evision.Flann.Algorithm.html"},{"type":"function","title":"Evision.Flann.Algorithm.cv_FLANN_INDEX_AUTOTUNED/0","doc":"","ref":"Evision.Flann.Algorithm.html#cv_FLANN_INDEX_AUTOTUNED/0"},{"type":"function","title":"Evision.Flann.Algorithm.cv_FLANN_INDEX_COMPOSITE/0","doc":"","ref":"Evision.Flann.Algorithm.html#cv_FLANN_INDEX_COMPOSITE/0"},{"type":"function","title":"Evision.Flann.Algorithm.cv_FLANN_INDEX_HIERARCHICAL/0","doc":"","ref":"Evision.Flann.Algorithm.html#cv_FLANN_INDEX_HIERARCHICAL/0"},{"type":"function","title":"Evision.Flann.Algorithm.cv_FLANN_INDEX_KDTREE/0","doc":"","ref":"Evision.Flann.Algorithm.html#cv_FLANN_INDEX_KDTREE/0"},{"type":"function","title":"Evision.Flann.Algorithm.cv_FLANN_INDEX_KDTREE_SINGLE/0","doc":"","ref":"Evision.Flann.Algorithm.html#cv_FLANN_INDEX_KDTREE_SINGLE/0"},{"type":"function","title":"Evision.Flann.Algorithm.cv_FLANN_INDEX_KMEANS/0","doc":"","ref":"Evision.Flann.Algorithm.html#cv_FLANN_INDEX_KMEANS/0"},{"type":"function","title":"Evision.Flann.Algorithm.cv_FLANN_INDEX_LINEAR/0","doc":"","ref":"Evision.Flann.Algorithm.html#cv_FLANN_INDEX_LINEAR/0"},{"type":"function","title":"Evision.Flann.Algorithm.cv_FLANN_INDEX_LSH/0","doc":"","ref":"Evision.Flann.Algorithm.html#cv_FLANN_INDEX_LSH/0"},{"type":"function","title":"Evision.Flann.Algorithm.cv_FLANN_INDEX_SAVED/0","doc":"","ref":"Evision.Flann.Algorithm.html#cv_FLANN_INDEX_SAVED/0"},{"type":"type","title":"Evision.Flann.Algorithm.enum/0","doc":"","ref":"Evision.Flann.Algorithm.html#t:enum/0"},{"type":"module","title":"Evision.Flann.CentersInit","doc":"","ref":"Evision.Flann.CentersInit.html"},{"type":"function","title":"Evision.Flann.CentersInit.cv_FLANN_CENTERS_GONZALES/0","doc":"","ref":"Evision.Flann.CentersInit.html#cv_FLANN_CENTERS_GONZALES/0"},{"type":"function","title":"Evision.Flann.CentersInit.cv_FLANN_CENTERS_GROUPWISE/0","doc":"","ref":"Evision.Flann.CentersInit.html#cv_FLANN_CENTERS_GROUPWISE/0"},{"type":"function","title":"Evision.Flann.CentersInit.cv_FLANN_CENTERS_KMEANSPP/0","doc":"","ref":"Evision.Flann.CentersInit.html#cv_FLANN_CENTERS_KMEANSPP/0"},{"type":"function","title":"Evision.Flann.CentersInit.cv_FLANN_CENTERS_RANDOM/0","doc":"","ref":"Evision.Flann.CentersInit.html#cv_FLANN_CENTERS_RANDOM/0"},{"type":"type","title":"Evision.Flann.CentersInit.enum/0","doc":"","ref":"Evision.Flann.CentersInit.html#t:enum/0"},{"type":"module","title":"Evision.Flann.Datatype","doc":"","ref":"Evision.Flann.Datatype.html"},{"type":"function","title":"Evision.Flann.Datatype.cv_FLANN_FLOAT32/0","doc":"","ref":"Evision.Flann.Datatype.html#cv_FLANN_FLOAT32/0"},{"type":"function","title":"Evision.Flann.Datatype.cv_FLANN_FLOAT64/0","doc":"","ref":"Evision.Flann.Datatype.html#cv_FLANN_FLOAT64/0"},{"type":"function","title":"Evision.Flann.Datatype.cv_FLANN_INT8/0","doc":"","ref":"Evision.Flann.Datatype.html#cv_FLANN_INT8/0"},{"type":"function","title":"Evision.Flann.Datatype.cv_FLANN_INT16/0","doc":"","ref":"Evision.Flann.Datatype.html#cv_FLANN_INT16/0"},{"type":"function","title":"Evision.Flann.Datatype.cv_FLANN_INT32/0","doc":"","ref":"Evision.Flann.Datatype.html#cv_FLANN_INT32/0"},{"type":"function","title":"Evision.Flann.Datatype.cv_FLANN_INT64/0","doc":"","ref":"Evision.Flann.Datatype.html#cv_FLANN_INT64/0"},{"type":"function","title":"Evision.Flann.Datatype.cv_FLANN_UINT8/0","doc":"","ref":"Evision.Flann.Datatype.html#cv_FLANN_UINT8/0"},{"type":"function","title":"Evision.Flann.Datatype.cv_FLANN_UINT16/0","doc":"","ref":"Evision.Flann.Datatype.html#cv_FLANN_UINT16/0"},{"type":"function","title":"Evision.Flann.Datatype.cv_FLANN_UINT32/0","doc":"","ref":"Evision.Flann.Datatype.html#cv_FLANN_UINT32/0"},{"type":"function","title":"Evision.Flann.Datatype.cv_FLANN_UINT64/0","doc":"","ref":"Evision.Flann.Datatype.html#cv_FLANN_UINT64/0"},{"type":"type","title":"Evision.Flann.Datatype.enum/0","doc":"","ref":"Evision.Flann.Datatype.html#t:enum/0"},{"type":"module","title":"Evision.Flann.Distance","doc":"","ref":"Evision.Flann.Distance.html"},{"type":"function","title":"Evision.Flann.Distance.cv_FLANN_DIST_CHI_SQUARE/0","doc":"","ref":"Evision.Flann.Distance.html#cv_FLANN_DIST_CHI_SQUARE/0"},{"type":"function","title":"Evision.Flann.Distance.cv_FLANN_DIST_CS/0","doc":"","ref":"Evision.Flann.Distance.html#cv_FLANN_DIST_CS/0"},{"type":"function","title":"Evision.Flann.Distance.cv_FLANN_DIST_DNAMMING/0","doc":"","ref":"Evision.Flann.Distance.html#cv_FLANN_DIST_DNAMMING/0"},{"type":"function","title":"Evision.Flann.Distance.cv_FLANN_DIST_EUCLIDEAN/0","doc":"","ref":"Evision.Flann.Distance.html#cv_FLANN_DIST_EUCLIDEAN/0"},{"type":"function","title":"Evision.Flann.Distance.cv_FLANN_DIST_HAMMING/0","doc":"","ref":"Evision.Flann.Distance.html#cv_FLANN_DIST_HAMMING/0"},{"type":"function","title":"Evision.Flann.Distance.cv_FLANN_DIST_HELLINGER/0","doc":"","ref":"Evision.Flann.Distance.html#cv_FLANN_DIST_HELLINGER/0"},{"type":"function","title":"Evision.Flann.Distance.cv_FLANN_DIST_HIST_INTERSECT/0","doc":"","ref":"Evision.Flann.Distance.html#cv_FLANN_DIST_HIST_INTERSECT/0"},{"type":"function","title":"Evision.Flann.Distance.cv_FLANN_DIST_KL/0","doc":"","ref":"Evision.Flann.Distance.html#cv_FLANN_DIST_KL/0"},{"type":"function","title":"Evision.Flann.Distance.cv_FLANN_DIST_KULLBACK_LEIBLER/0","doc":"","ref":"Evision.Flann.Distance.html#cv_FLANN_DIST_KULLBACK_LEIBLER/0"},{"type":"function","title":"Evision.Flann.Distance.cv_FLANN_DIST_L1/0","doc":"","ref":"Evision.Flann.Distance.html#cv_FLANN_DIST_L1/0"},{"type":"function","title":"Evision.Flann.Distance.cv_FLANN_DIST_L2/0","doc":"","ref":"Evision.Flann.Distance.html#cv_FLANN_DIST_L2/0"},{"type":"function","title":"Evision.Flann.Distance.cv_FLANN_DIST_MANHATTAN/0","doc":"","ref":"Evision.Flann.Distance.html#cv_FLANN_DIST_MANHATTAN/0"},{"type":"function","title":"Evision.Flann.Distance.cv_FLANN_DIST_MAX/0","doc":"","ref":"Evision.Flann.Distance.html#cv_FLANN_DIST_MAX/0"},{"type":"function","title":"Evision.Flann.Distance.cv_FLANN_DIST_MINKOWSKI/0","doc":"","ref":"Evision.Flann.Distance.html#cv_FLANN_DIST_MINKOWSKI/0"},{"type":"type","title":"Evision.Flann.Distance.enum/0","doc":"","ref":"Evision.Flann.Distance.html#t:enum/0"},{"type":"module","title":"Evision.Flann.FlannIndexType","doc":"","ref":"Evision.Flann.FlannIndexType.html"},{"type":"function","title":"Evision.Flann.FlannIndexType.cv_FLANN_INDEX_TYPE_8S/0","doc":"","ref":"Evision.Flann.FlannIndexType.html#cv_FLANN_INDEX_TYPE_8S/0"},{"type":"function","title":"Evision.Flann.FlannIndexType.cv_FLANN_INDEX_TYPE_8U/0","doc":"","ref":"Evision.Flann.FlannIndexType.html#cv_FLANN_INDEX_TYPE_8U/0"},{"type":"function","title":"Evision.Flann.FlannIndexType.cv_FLANN_INDEX_TYPE_16S/0","doc":"","ref":"Evision.Flann.FlannIndexType.html#cv_FLANN_INDEX_TYPE_16S/0"},{"type":"function","title":"Evision.Flann.FlannIndexType.cv_FLANN_INDEX_TYPE_16U/0","doc":"","ref":"Evision.Flann.FlannIndexType.html#cv_FLANN_INDEX_TYPE_16U/0"},{"type":"function","title":"Evision.Flann.FlannIndexType.cv_FLANN_INDEX_TYPE_32F/0","doc":"","ref":"Evision.Flann.FlannIndexType.html#cv_FLANN_INDEX_TYPE_32F/0"},{"type":"function","title":"Evision.Flann.FlannIndexType.cv_FLANN_INDEX_TYPE_32S/0","doc":"","ref":"Evision.Flann.FlannIndexType.html#cv_FLANN_INDEX_TYPE_32S/0"},{"type":"function","title":"Evision.Flann.FlannIndexType.cv_FLANN_INDEX_TYPE_64F/0","doc":"","ref":"Evision.Flann.FlannIndexType.html#cv_FLANN_INDEX_TYPE_64F/0"},{"type":"function","title":"Evision.Flann.FlannIndexType.cv_FLANN_INDEX_TYPE_ALGORITHM/0","doc":"","ref":"Evision.Flann.FlannIndexType.html#cv_FLANN_INDEX_TYPE_ALGORITHM/0"},{"type":"function","title":"Evision.Flann.FlannIndexType.cv_FLANN_INDEX_TYPE_BOOL/0","doc":"","ref":"Evision.Flann.FlannIndexType.html#cv_FLANN_INDEX_TYPE_BOOL/0"},{"type":"function","title":"Evision.Flann.FlannIndexType.cv_FLANN_INDEX_TYPE_STRING/0","doc":"","ref":"Evision.Flann.FlannIndexType.html#cv_FLANN_INDEX_TYPE_STRING/0"},{"type":"function","title":"Evision.Flann.FlannIndexType.cv_LAST_VALUE_FLANN_INDEX_TYPE/0","doc":"","ref":"Evision.Flann.FlannIndexType.html#cv_LAST_VALUE_FLANN_INDEX_TYPE/0"},{"type":"type","title":"Evision.Flann.FlannIndexType.enum/0","doc":"","ref":"Evision.Flann.FlannIndexType.html#t:enum/0"},{"type":"module","title":"Evision.Flann.Index","doc":"","ref":"Evision.Flann.Index.html"},{"type":"function","title":"Evision.Flann.Index.build/1","doc":"","ref":"Evision.Flann.Index.html#build/1"},{"type":"function","title":"Evision.Flann.Index.build/3","doc":"build\n\n##### Positional Arguments\n- **self**: `Evision.Flann.Index.t()`\n- **features**: `Evision.Mat`\n- **params**: `IndexParams`\n\n##### Keyword Arguments\n- **distType**: `cvflann_flann_distance_t`.\n\nPython prototype (for reference only):\n```python3\nbuild(features, params[, distType]) -> None\n```","ref":"Evision.Flann.Index.html#build/3"},{"type":"function","title":"Evision.Flann.Index.build/4","doc":"build\n\n##### Positional Arguments\n- **self**: `Evision.Flann.Index.t()`\n- **features**: `Evision.Mat`\n- **params**: `IndexParams`\n\n##### Keyword Arguments\n- **distType**: `cvflann_flann_distance_t`.\n\nPython prototype (for reference only):\n```python3\nbuild(features, params[, distType]) -> None\n```","ref":"Evision.Flann.Index.html#build/4"},{"type":"function","title":"Evision.Flann.Index.getAlgorithm/1","doc":"getAlgorithm\n\n##### Positional Arguments\n- **self**: `Evision.Flann.Index.t()`\n\n##### Return\n- **retval**: `cvflann::flann_algorithm_t`\n\nPython prototype (for reference only):\n```python3\ngetAlgorithm() -> retval\n```","ref":"Evision.Flann.Index.html#getAlgorithm/1"},{"type":"function","title":"Evision.Flann.Index.getDistance/1","doc":"getDistance\n\n##### Positional Arguments\n- **self**: `Evision.Flann.Index.t()`\n\n##### Return\n- **retval**: `cvflann::flann_distance_t`\n\nPython prototype (for reference only):\n```python3\ngetDistance() -> retval\n```","ref":"Evision.Flann.Index.html#getDistance/1"},{"type":"function","title":"Evision.Flann.Index.index/0","doc":"Index\n##### Return\n- **self**: `Evision.Flann.Index.t()`\n\nPython prototype (for reference only):\n```python3\nIndex() ->  \n```","ref":"Evision.Flann.Index.html#index/0"},{"type":"function","title":"Evision.Flann.Index.index/1","doc":"","ref":"Evision.Flann.Index.html#index/1"},{"type":"function","title":"Evision.Flann.Index.index/2","doc":"Index\n\n##### Positional Arguments\n- **features**: `Evision.Mat`\n- **params**: `IndexParams`\n\n##### Keyword Arguments\n- **distType**: `cvflann_flann_distance_t`.\n\n##### Return\n- **self**: `Evision.Flann.Index.t()`\n\nPython prototype (for reference only):\n```python3\nIndex(features, params[, distType]) ->  \n```","ref":"Evision.Flann.Index.html#index/2"},{"type":"function","title":"Evision.Flann.Index.index/3","doc":"Index\n\n##### Positional Arguments\n- **features**: `Evision.Mat`\n- **params**: `IndexParams`\n\n##### Keyword Arguments\n- **distType**: `cvflann_flann_distance_t`.\n\n##### Return\n- **self**: `Evision.Flann.Index.t()`\n\nPython prototype (for reference only):\n```python3\nIndex(features, params[, distType]) ->  \n```","ref":"Evision.Flann.Index.html#index/3"},{"type":"function","title":"Evision.Flann.Index.knnSearch/1","doc":"","ref":"Evision.Flann.Index.html#knnSearch/1"},{"type":"function","title":"Evision.Flann.Index.knnSearch/3","doc":"knnSearch\n\n##### Positional Arguments\n- **self**: `Evision.Flann.Index.t()`\n- **query**: `Evision.Mat`\n- **knn**: `integer()`\n\n##### Keyword Arguments\n- **params**: `SearchParams`.\n\n##### Return\n- **indices**: `Evision.Mat.t()`.\n- **dists**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nknnSearch(query, knn[, indices[, dists[, params]]]) -> indices, dists\n```","ref":"Evision.Flann.Index.html#knnSearch/3"},{"type":"function","title":"Evision.Flann.Index.knnSearch/4","doc":"knnSearch\n\n##### Positional Arguments\n- **self**: `Evision.Flann.Index.t()`\n- **query**: `Evision.Mat`\n- **knn**: `integer()`\n\n##### Keyword Arguments\n- **params**: `SearchParams`.\n\n##### Return\n- **indices**: `Evision.Mat.t()`.\n- **dists**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nknnSearch(query, knn[, indices[, dists[, params]]]) -> indices, dists\n```","ref":"Evision.Flann.Index.html#knnSearch/4"},{"type":"function","title":"Evision.Flann.Index.load/1","doc":"","ref":"Evision.Flann.Index.html#load/1"},{"type":"function","title":"Evision.Flann.Index.load/3","doc":"load\n\n##### Positional Arguments\n- **self**: `Evision.Flann.Index.t()`\n- **features**: `Evision.Mat`\n- **filename**: `String`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nload(features, filename) -> retval\n```","ref":"Evision.Flann.Index.html#load/3"},{"type":"function","title":"Evision.Flann.Index.radiusSearch/1","doc":"","ref":"Evision.Flann.Index.html#radiusSearch/1"},{"type":"function","title":"Evision.Flann.Index.radiusSearch/4","doc":"radiusSearch\n\n##### Positional Arguments\n- **self**: `Evision.Flann.Index.t()`\n- **query**: `Evision.Mat`\n- **radius**: `double`\n- **maxResults**: `integer()`\n\n##### Keyword Arguments\n- **params**: `SearchParams`.\n\n##### Return\n- **retval**: `integer()`\n- **indices**: `Evision.Mat.t()`.\n- **dists**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nradiusSearch(query, radius, maxResults[, indices[, dists[, params]]]) -> retval, indices, dists\n```","ref":"Evision.Flann.Index.html#radiusSearch/4"},{"type":"function","title":"Evision.Flann.Index.radiusSearch/5","doc":"radiusSearch\n\n##### Positional Arguments\n- **self**: `Evision.Flann.Index.t()`\n- **query**: `Evision.Mat`\n- **radius**: `double`\n- **maxResults**: `integer()`\n\n##### Keyword Arguments\n- **params**: `SearchParams`.\n\n##### Return\n- **retval**: `integer()`\n- **indices**: `Evision.Mat.t()`.\n- **dists**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nradiusSearch(query, radius, maxResults[, indices[, dists[, params]]]) -> retval, indices, dists\n```","ref":"Evision.Flann.Index.html#radiusSearch/5"},{"type":"function","title":"Evision.Flann.Index.release/1","doc":"release\n\n##### Positional Arguments\n- **self**: `Evision.Flann.Index.t()`\n\nPython prototype (for reference only):\n```python3\nrelease() -> None\n```","ref":"Evision.Flann.Index.html#release/1"},{"type":"function","title":"Evision.Flann.Index.save/1","doc":"","ref":"Evision.Flann.Index.html#save/1"},{"type":"function","title":"Evision.Flann.Index.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Flann.Index.t()`\n- **filename**: `String`\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Flann.Index.html#save/2"},{"type":"type","title":"Evision.Flann.Index.t/0","doc":"Type that represents an `Flann.Index` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Flann.Index.html#t:t/0"},{"type":"module","title":"Evision.Flann.LogLevel","doc":"","ref":"Evision.Flann.LogLevel.html"},{"type":"function","title":"Evision.Flann.LogLevel.cv_FLANN_LOG_ERROR/0","doc":"","ref":"Evision.Flann.LogLevel.html#cv_FLANN_LOG_ERROR/0"},{"type":"function","title":"Evision.Flann.LogLevel.cv_FLANN_LOG_FATAL/0","doc":"","ref":"Evision.Flann.LogLevel.html#cv_FLANN_LOG_FATAL/0"},{"type":"function","title":"Evision.Flann.LogLevel.cv_FLANN_LOG_INFO/0","doc":"","ref":"Evision.Flann.LogLevel.html#cv_FLANN_LOG_INFO/0"},{"type":"function","title":"Evision.Flann.LogLevel.cv_FLANN_LOG_NONE/0","doc":"","ref":"Evision.Flann.LogLevel.html#cv_FLANN_LOG_NONE/0"},{"type":"function","title":"Evision.Flann.LogLevel.cv_FLANN_LOG_WARN/0","doc":"","ref":"Evision.Flann.LogLevel.html#cv_FLANN_LOG_WARN/0"},{"type":"type","title":"Evision.Flann.LogLevel.enum/0","doc":"","ref":"Evision.Flann.LogLevel.html#t:enum/0"},{"type":"module","title":"Evision.FlannBasedMatcher","doc":"","ref":"Evision.FlannBasedMatcher.html"},{"type":"function","title":"Evision.FlannBasedMatcher.add/1","doc":"","ref":"Evision.FlannBasedMatcher.html#add/1"},{"type":"function","title":"Evision.FlannBasedMatcher.add/2","doc":"Adds descriptors to train a CPU(trainDescCollectionis) or GPU(utrainDescCollectionis) descriptor\ncollection.\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n- **descriptors**: `[Evision.Mat]`.\n\n  Descriptors to add. Each descriptors[i] is a set of descriptors from the same\n  train image.\n\nIf the collection is not empty, the new descriptors are added to existing train descriptors.\n\nPython prototype (for reference only):\n```python3\nadd(descriptors) -> None\n```","ref":"Evision.FlannBasedMatcher.html#add/2"},{"type":"function","title":"Evision.FlannBasedMatcher.clear/1","doc":"Clears the train descriptor collections.\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.FlannBasedMatcher.html#clear/1"},{"type":"function","title":"Evision.FlannBasedMatcher.clone/1","doc":"Clones the matcher.\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n\n##### Keyword Arguments\n- **emptyTrainData**: `bool`.\n\n  If emptyTrainData is false, the method creates a deep copy of the object,\n  that is, copies both parameters and train data. If emptyTrainData is true, the method creates an\n  object copy with the current parameters but with empty train data.\n\n##### Return\n- **retval**: `Evision.DescriptorMatcher.t()`\n\nPython prototype (for reference only):\n```python3\nclone([, emptyTrainData]) -> retval\n```","ref":"Evision.FlannBasedMatcher.html#clone/1"},{"type":"function","title":"Evision.FlannBasedMatcher.clone/2","doc":"Clones the matcher.\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n\n##### Keyword Arguments\n- **emptyTrainData**: `bool`.\n\n  If emptyTrainData is false, the method creates a deep copy of the object,\n  that is, copies both parameters and train data. If emptyTrainData is true, the method creates an\n  object copy with the current parameters but with empty train data.\n\n##### Return\n- **retval**: `Evision.DescriptorMatcher.t()`\n\nPython prototype (for reference only):\n```python3\nclone([, emptyTrainData]) -> retval\n```","ref":"Evision.FlannBasedMatcher.html#clone/2"},{"type":"function","title":"Evision.FlannBasedMatcher.create/0","doc":"create\n##### Return\n- **retval**: `Evision.FlannBasedMatcher.t()`\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.FlannBasedMatcher.html#create/0"},{"type":"function","title":"Evision.FlannBasedMatcher.create/1","doc":"","ref":"Evision.FlannBasedMatcher.html#create/1"},{"type":"function","title":"Evision.FlannBasedMatcher.empty/1","doc":"Returns true if there are no train descriptors in the both collections.\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.FlannBasedMatcher.html#empty/1"},{"type":"function","title":"Evision.FlannBasedMatcher.flannBasedMatcher/0","doc":"FlannBasedMatcher\n##### Keyword Arguments\n- **indexParams**: `flann::IndexParams`.\n- **searchParams**: `flann::SearchParams`.\n\n##### Return\n- **self**: `Evision.FlannBasedMatcher.t()`\n\nPython prototype (for reference only):\n```python3\nFlannBasedMatcher([, indexParams[, searchParams]]) ->  \n```","ref":"Evision.FlannBasedMatcher.html#flannBasedMatcher/0"},{"type":"function","title":"Evision.FlannBasedMatcher.flannBasedMatcher/1","doc":"FlannBasedMatcher\n##### Keyword Arguments\n- **indexParams**: `flann::IndexParams`.\n- **searchParams**: `flann::SearchParams`.\n\n##### Return\n- **self**: `Evision.FlannBasedMatcher.t()`\n\nPython prototype (for reference only):\n```python3\nFlannBasedMatcher([, indexParams[, searchParams]]) ->  \n```","ref":"Evision.FlannBasedMatcher.html#flannBasedMatcher/1"},{"type":"function","title":"Evision.FlannBasedMatcher.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.FlannBasedMatcher.html#getDefaultName/1"},{"type":"function","title":"Evision.FlannBasedMatcher.getTrainDescriptors/1","doc":"Returns a constant link to the train descriptor collection trainDescCollection .\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n\n##### Return\n- **retval**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\ngetTrainDescriptors() -> retval\n```","ref":"Evision.FlannBasedMatcher.html#getTrainDescriptors/1"},{"type":"function","title":"Evision.FlannBasedMatcher.isMaskSupported/1","doc":"Returns true if the descriptor matcher supports masking permissible matches.\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisMaskSupported() -> retval\n```","ref":"Evision.FlannBasedMatcher.html#isMaskSupported/1"},{"type":"function","title":"Evision.FlannBasedMatcher.knnMatch/1","doc":"","ref":"Evision.FlannBasedMatcher.html#knnMatch/1"},{"type":"function","title":"Evision.FlannBasedMatcher.knnMatch/3","doc":"knnMatch\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **k**: `integer()`.\n\n  Count of best matches found per each query descriptor or less if a query descriptor has\n  less than k possible matches in total.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Set of masks. Each masks[i] specifies permissible matches between the input query\n  descriptors and stored train descriptors from the i-th image trainDescCollection[i].\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Matches. Each matches[i] is k or less matches for the same query descriptor.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nknnMatch(queryDescriptors, k[, masks[, compactResult]]) -> matches\n```","ref":"Evision.FlannBasedMatcher.html#knnMatch/3"},{"type":"function","title":"Evision.FlannBasedMatcher.knnMatch/4","doc":"#### Variant 1:\nFinds the k best matches for each descriptor from a query set.\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **k**: `integer()`.\n\n  Count of best matches found per each query descriptor or less if a query descriptor has\n  less than k possible matches in total.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Matches. Each matches[i] is k or less matches for the same query descriptor.\n\nThese extended variants of DescriptorMatcher::match methods find several best matches for each query\ndescriptor. The matches are returned in the distance increasing order. See DescriptorMatcher::match\nfor the details about query and train descriptors.\n\nPython prototype (for reference only):\n```python3\nknnMatch(queryDescriptors, trainDescriptors, k[, mask[, compactResult]]) -> matches\n```\n#### Variant 2:\nknnMatch\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **k**: `integer()`.\n\n  Count of best matches found per each query descriptor or less if a query descriptor has\n  less than k possible matches in total.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Set of masks. Each masks[i] specifies permissible matches between the input query\n  descriptors and stored train descriptors from the i-th image trainDescCollection[i].\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Matches. Each matches[i] is k or less matches for the same query descriptor.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nknnMatch(queryDescriptors, k[, masks[, compactResult]]) -> matches\n```","ref":"Evision.FlannBasedMatcher.html#knnMatch/4"},{"type":"function","title":"Evision.FlannBasedMatcher.knnMatch/5","doc":"Finds the k best matches for each descriptor from a query set.\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **k**: `integer()`.\n\n  Count of best matches found per each query descriptor or less if a query descriptor has\n  less than k possible matches in total.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Matches. Each matches[i] is k or less matches for the same query descriptor.\n\nThese extended variants of DescriptorMatcher::match methods find several best matches for each query\ndescriptor. The matches are returned in the distance increasing order. See DescriptorMatcher::match\nfor the details about query and train descriptors.\n\nPython prototype (for reference only):\n```python3\nknnMatch(queryDescriptors, trainDescriptors, k[, mask[, compactResult]]) -> matches\n```","ref":"Evision.FlannBasedMatcher.html#knnMatch/5"},{"type":"function","title":"Evision.FlannBasedMatcher.match/1","doc":"","ref":"Evision.FlannBasedMatcher.html#match/1"},{"type":"function","title":"Evision.FlannBasedMatcher.match/2","doc":"match\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Set of masks. Each masks[i] specifies permissible matches between the input query\n  descriptors and stored train descriptors from the i-th image trainDescCollection[i].\n\n##### Return\n- **matches**: `[Evision.DMatch]`.\n\n  Matches. If a query descriptor is masked out in mask , no match is added for this\n  descriptor. So, matches size may be smaller than the query descriptors count.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmatch(queryDescriptors[, masks]) -> matches\n```","ref":"Evision.FlannBasedMatcher.html#match/2"},{"type":"function","title":"Evision.FlannBasedMatcher.match/3","doc":"#### Variant 1:\nFinds the best match for each descriptor from a query set.\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n##### Return\n- **matches**: `[Evision.DMatch]`.\n\n  Matches. If a query descriptor is masked out in mask , no match is added for this\n  descriptor. So, matches size may be smaller than the query descriptors count.\n\nIn the first variant of this method, the train descriptors are passed as an input argument. In the\nsecond variant of the method, train descriptors collection that was set by DescriptorMatcher::add is\nused. Optional mask (or masks) can be passed to specify which query and training descriptors can be\nmatched. Namely, queryDescriptors[i] can be matched with trainDescriptors[j] only if\nmask.at\\ (i,j) is non-zero.\n\nPython prototype (for reference only):\n```python3\nmatch(queryDescriptors, trainDescriptors[, mask]) -> matches\n```\n#### Variant 2:\nmatch\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Set of masks. Each masks[i] specifies permissible matches between the input query\n  descriptors and stored train descriptors from the i-th image trainDescCollection[i].\n\n##### Return\n- **matches**: `[Evision.DMatch]`.\n\n  Matches. If a query descriptor is masked out in mask , no match is added for this\n  descriptor. So, matches size may be smaller than the query descriptors count.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmatch(queryDescriptors[, masks]) -> matches\n```","ref":"Evision.FlannBasedMatcher.html#match/3"},{"type":"function","title":"Evision.FlannBasedMatcher.match/4","doc":"Finds the best match for each descriptor from a query set.\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n##### Return\n- **matches**: `[Evision.DMatch]`.\n\n  Matches. If a query descriptor is masked out in mask , no match is added for this\n  descriptor. So, matches size may be smaller than the query descriptors count.\n\nIn the first variant of this method, the train descriptors are passed as an input argument. In the\nsecond variant of the method, train descriptors collection that was set by DescriptorMatcher::add is\nused. Optional mask (or masks) can be passed to specify which query and training descriptors can be\nmatched. Namely, queryDescriptors[i] can be matched with trainDescriptors[j] only if\nmask.at\\ (i,j) is non-zero.\n\nPython prototype (for reference only):\n```python3\nmatch(queryDescriptors, trainDescriptors[, mask]) -> matches\n```","ref":"Evision.FlannBasedMatcher.html#match/4"},{"type":"function","title":"Evision.FlannBasedMatcher.radiusMatch/1","doc":"","ref":"Evision.FlannBasedMatcher.html#radiusMatch/1"},{"type":"function","title":"Evision.FlannBasedMatcher.radiusMatch/3","doc":"radiusMatch\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **maxDistance**: `float`.\n\n  Threshold for the distance between matched descriptors. Distance means here\n  metric distance (e.g. Hamming distance), not the distance between coordinates (which is measured\n  in Pixels)!\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Set of masks. Each masks[i] specifies permissible matches between the input query\n  descriptors and stored train descriptors from the i-th image trainDescCollection[i].\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Found matches.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nradiusMatch(queryDescriptors, maxDistance[, masks[, compactResult]]) -> matches\n```","ref":"Evision.FlannBasedMatcher.html#radiusMatch/3"},{"type":"function","title":"Evision.FlannBasedMatcher.radiusMatch/4","doc":"#### Variant 1:\nFor each query descriptor, finds the training descriptors not farther than the specified distance.\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **maxDistance**: `float`.\n\n  Threshold for the distance between matched descriptors. Distance means here\n  metric distance (e.g. Hamming distance), not the distance between coordinates (which is measured\n  in Pixels)!\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Found matches.\n\nFor each query descriptor, the methods find such training descriptors that the distance between the\nquery descriptor and the training descriptor is equal or smaller than maxDistance. Found matches are\nreturned in the distance increasing order.\n\nPython prototype (for reference only):\n```python3\nradiusMatch(queryDescriptors, trainDescriptors, maxDistance[, mask[, compactResult]]) -> matches\n```\n#### Variant 2:\nradiusMatch\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **maxDistance**: `float`.\n\n  Threshold for the distance between matched descriptors. Distance means here\n  metric distance (e.g. Hamming distance), not the distance between coordinates (which is measured\n  in Pixels)!\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Set of masks. Each masks[i] specifies permissible matches between the input query\n  descriptors and stored train descriptors from the i-th image trainDescCollection[i].\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Found matches.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nradiusMatch(queryDescriptors, maxDistance[, masks[, compactResult]]) -> matches\n```","ref":"Evision.FlannBasedMatcher.html#radiusMatch/4"},{"type":"function","title":"Evision.FlannBasedMatcher.radiusMatch/5","doc":"For each query descriptor, finds the training descriptors not farther than the specified distance.\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  Query set of descriptors.\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  Train set of descriptors. This set is not added to the train descriptors\n  collection stored in the class object.\n\n- **maxDistance**: `float`.\n\n  Threshold for the distance between matched descriptors. Distance means here\n  metric distance (e.g. Hamming distance), not the distance between coordinates (which is measured\n  in Pixels)!\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying permissible matches between an input query and train matrices of\n  descriptors.\n\n- **compactResult**: `bool`.\n\n  Parameter used when the mask (or masks) is not empty. If compactResult is\n  false, the matches vector has the same size as queryDescriptors rows. If compactResult is true,\n  the matches vector does not contain matches for fully masked-out query descriptors.\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  Found matches.\n\nFor each query descriptor, the methods find such training descriptors that the distance between the\nquery descriptor and the training descriptor is equal or smaller than maxDistance. Found matches are\nreturned in the distance increasing order.\n\nPython prototype (for reference only):\n```python3\nradiusMatch(queryDescriptors, trainDescriptors, maxDistance[, mask[, compactResult]]) -> matches\n```","ref":"Evision.FlannBasedMatcher.html#radiusMatch/5"},{"type":"function","title":"Evision.FlannBasedMatcher.read/1","doc":"","ref":"Evision.FlannBasedMatcher.html#read/1"},{"type":"function","title":"Evision.FlannBasedMatcher.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.FlannBasedMatcher.html#read/2"},{"type":"function","title":"Evision.FlannBasedMatcher.save/1","doc":"","ref":"Evision.FlannBasedMatcher.html#save/1"},{"type":"function","title":"Evision.FlannBasedMatcher.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.FlannBasedMatcher.html#save/2"},{"type":"function","title":"Evision.FlannBasedMatcher.train/1","doc":"Trains a descriptor matcher\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n\nTrains a descriptor matcher (for example, the flann index). In all methods to match, the method\ntrain() is run every time before matching. Some descriptor matchers (for example, BruteForceMatcher)\nhave an empty implementation of this method. Other matchers really train their inner structures (for\nexample, FlannBasedMatcher trains flann::Index ).\n\nPython prototype (for reference only):\n```python3\ntrain() -> None\n```","ref":"Evision.FlannBasedMatcher.html#train/1"},{"type":"function","title":"Evision.FlannBasedMatcher.write/1","doc":"","ref":"Evision.FlannBasedMatcher.html#write/1"},{"type":"function","title":"Evision.FlannBasedMatcher.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.FlannBasedMatcher.html#write/2"},{"type":"function","title":"Evision.FlannBasedMatcher.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.FlannBasedMatcher.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.FlannBasedMatcher.html#write/3"},{"type":"type","title":"Evision.FlannBasedMatcher.t/0","doc":"Type that represents an `FlannBasedMatcher` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.FlannBasedMatcher.html#t:t/0"},{"type":"module","title":"Evision.FloodFillFlags","doc":"","ref":"Evision.FloodFillFlags.html"},{"type":"function","title":"Evision.FloodFillFlags.cv_FLOODFILL_FIXED_RANGE/0","doc":"","ref":"Evision.FloodFillFlags.html#cv_FLOODFILL_FIXED_RANGE/0"},{"type":"function","title":"Evision.FloodFillFlags.cv_FLOODFILL_MASK_ONLY/0","doc":"","ref":"Evision.FloodFillFlags.html#cv_FLOODFILL_MASK_ONLY/0"},{"type":"type","title":"Evision.FloodFillFlags.enum/0","doc":"","ref":"Evision.FloodFillFlags.html#t:enum/0"},{"type":"module","title":"Evision.Formatter.FormatType","doc":"","ref":"Evision.Formatter.FormatType.html"},{"type":"function","title":"Evision.Formatter.FormatType.cv_FMT_C/0","doc":"","ref":"Evision.Formatter.FormatType.html#cv_FMT_C/0"},{"type":"function","title":"Evision.Formatter.FormatType.cv_FMT_CSV/0","doc":"","ref":"Evision.Formatter.FormatType.html#cv_FMT_CSV/0"},{"type":"function","title":"Evision.Formatter.FormatType.cv_FMT_DEFAULT/0","doc":"","ref":"Evision.Formatter.FormatType.html#cv_FMT_DEFAULT/0"},{"type":"function","title":"Evision.Formatter.FormatType.cv_FMT_MATLAB/0","doc":"","ref":"Evision.Formatter.FormatType.html#cv_FMT_MATLAB/0"},{"type":"function","title":"Evision.Formatter.FormatType.cv_FMT_NUMPY/0","doc":"","ref":"Evision.Formatter.FormatType.html#cv_FMT_NUMPY/0"},{"type":"function","title":"Evision.Formatter.FormatType.cv_FMT_PYTHON/0","doc":"","ref":"Evision.Formatter.FormatType.html#cv_FMT_PYTHON/0"},{"type":"type","title":"Evision.Formatter.FormatType.enum/0","doc":"","ref":"Evision.Formatter.FormatType.html#t:enum/0"},{"type":"module","title":"Evision.Ft","doc":"","ref":"Evision.Ft.html"},{"type":"function","title":"Evision.Ft.createKernel1/1","doc":"","ref":"Evision.Ft.html#createKernel1/1"},{"type":"function","title":"Evision.Ft.createKernel1/3","doc":"Creates kernel from basic functions.\n\n##### Positional Arguments\n- **a**: `Evision.Mat`.\n\n  Basic function used in axis **x**.\n\n- **b**: `Evision.Mat`.\n\n  Basic function used in axis **y**.\n\n- **chn**: `integer()`.\n\n  Number of kernel channels.\n\n##### Return\n- **kernel**: `Evision.Mat.t()`.\n\n  Final 32-bit kernel derived from **A** and **B**.\n\nThe function creates kernel usable for latter fuzzy image processing.\n\nPython prototype (for reference only):\n```python3\ncreateKernel1(A, B, chn[, kernel]) -> kernel\n```","ref":"Evision.Ft.html#createKernel1/3"},{"type":"function","title":"Evision.Ft.createKernel1/4","doc":"Creates kernel from basic functions.\n\n##### Positional Arguments\n- **a**: `Evision.Mat`.\n\n  Basic function used in axis **x**.\n\n- **b**: `Evision.Mat`.\n\n  Basic function used in axis **y**.\n\n- **chn**: `integer()`.\n\n  Number of kernel channels.\n\n##### Return\n- **kernel**: `Evision.Mat.t()`.\n\n  Final 32-bit kernel derived from **A** and **B**.\n\nThe function creates kernel usable for latter fuzzy image processing.\n\nPython prototype (for reference only):\n```python3\ncreateKernel1(A, B, chn[, kernel]) -> kernel\n```","ref":"Evision.Ft.html#createKernel1/4"},{"type":"function","title":"Evision.Ft.createKernel/1","doc":"","ref":"Evision.Ft.html#createKernel/1"},{"type":"function","title":"Evision.Ft.createKernel/3","doc":"Creates kernel from general functions.\n\n##### Positional Arguments\n- **function**: `integer()`.\n\n  Function type could be one of the following:\n  - **LINEAR** Linear basic function.\n\n- **radius**: `integer()`.\n\n  Radius of the basic function.\n\n- **chn**: `integer()`.\n\n  Number of kernel channels.\n\n##### Return\n- **kernel**: `Evision.Mat.t()`.\n\n  Final 32-bit kernel.\n\nThe function creates kernel from predefined functions.\n\nPython prototype (for reference only):\n```python3\ncreateKernel(function, radius, chn[, kernel]) -> kernel\n```","ref":"Evision.Ft.html#createKernel/3"},{"type":"function","title":"Evision.Ft.createKernel/4","doc":"Creates kernel from general functions.\n\n##### Positional Arguments\n- **function**: `integer()`.\n\n  Function type could be one of the following:\n  - **LINEAR** Linear basic function.\n\n- **radius**: `integer()`.\n\n  Radius of the basic function.\n\n- **chn**: `integer()`.\n\n  Number of kernel channels.\n\n##### Return\n- **kernel**: `Evision.Mat.t()`.\n\n  Final 32-bit kernel.\n\nThe function creates kernel from predefined functions.\n\nPython prototype (for reference only):\n```python3\ncreateKernel(function, radius, chn[, kernel]) -> kernel\n```","ref":"Evision.Ft.html#createKernel/4"},{"type":"function","title":"Evision.Ft.cv_ITERATIVE/0","doc":"","ref":"Evision.Ft.html#cv_ITERATIVE/0"},{"type":"function","title":"Evision.Ft.cv_LINEAR/0","doc":"","ref":"Evision.Ft.html#cv_LINEAR/0"},{"type":"function","title":"Evision.Ft.cv_MULTI_STEP/0","doc":"","ref":"Evision.Ft.html#cv_MULTI_STEP/0"},{"type":"function","title":"Evision.Ft.cv_ONE_STEP/0","doc":"","ref":"Evision.Ft.html#cv_ONE_STEP/0"},{"type":"function","title":"Evision.Ft.cv_SINUS/0","doc":"","ref":"Evision.Ft.html#cv_SINUS/0"},{"type":"function","title":"Evision.Ft.filter/1","doc":"","ref":"Evision.Ft.html#filter/1"},{"type":"function","title":"Evision.Ft.filter/2","doc":"Image filtering\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Input image.\n\n- **kernel**: `Evision.Mat`.\n\n  Final 32-bit kernel.\n\n##### Return\n- **output**: `Evision.Mat.t()`.\n\n  Output 32-bit image.\n\nFiltering of the input image by means of F-transform.\n\nPython prototype (for reference only):\n```python3\nfilter(image, kernel[, output]) -> output\n```","ref":"Evision.Ft.html#filter/2"},{"type":"function","title":"Evision.Ft.filter/3","doc":"Image filtering\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Input image.\n\n- **kernel**: `Evision.Mat`.\n\n  Final 32-bit kernel.\n\n##### Return\n- **output**: `Evision.Mat.t()`.\n\n  Output 32-bit image.\n\nFiltering of the input image by means of F-transform.\n\nPython prototype (for reference only):\n```python3\nfilter(image, kernel[, output]) -> output\n```","ref":"Evision.Ft.html#filter/3"},{"type":"function","title":"Evision.Ft.inpaint/1","doc":"","ref":"Evision.Ft.html#inpaint/1"},{"type":"function","title":"Evision.Ft.inpaint/5","doc":"Image inpainting\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Input image.\n\n- **mask**: `Evision.Mat`.\n\n  Mask used for unwanted area marking.\n\n- **radius**: `integer()`.\n\n  Radius of the basic function.\n\n- **function**: `integer()`.\n\n  Function type could be one of the following:\n  - `ft::LINEAR` Linear basic function.\n\n- **algorithm**: `integer()`.\n\n  Algorithm could be one of the following:\n  - `ft::ONE_STEP` One step algorithm.\n  - `ft::MULTI_STEP` This algorithm automaticaly increases radius of the basic function.\n  - `ft::ITERATIVE` Iterative algorithm running in more steps using partial computations.\n\n##### Return\n- **output**: `Evision.Mat.t()`.\n\n  Output 32-bit image.\n\nThis function provides inpainting technique based on the fuzzy mathematic.\n**Note**: \nThe algorithms are described in paper @cite Perf:rec.\n\nPython prototype (for reference only):\n```python3\ninpaint(image, mask, radius, function, algorithm[, output]) -> output\n```","ref":"Evision.Ft.html#inpaint/5"},{"type":"function","title":"Evision.Ft.inpaint/6","doc":"Image inpainting\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Input image.\n\n- **mask**: `Evision.Mat`.\n\n  Mask used for unwanted area marking.\n\n- **radius**: `integer()`.\n\n  Radius of the basic function.\n\n- **function**: `integer()`.\n\n  Function type could be one of the following:\n  - `ft::LINEAR` Linear basic function.\n\n- **algorithm**: `integer()`.\n\n  Algorithm could be one of the following:\n  - `ft::ONE_STEP` One step algorithm.\n  - `ft::MULTI_STEP` This algorithm automaticaly increases radius of the basic function.\n  - `ft::ITERATIVE` Iterative algorithm running in more steps using partial computations.\n\n##### Return\n- **output**: `Evision.Mat.t()`.\n\n  Output 32-bit image.\n\nThis function provides inpainting technique based on the fuzzy mathematic.\n**Note**: \nThe algorithms are described in paper @cite Perf:rec.\n\nPython prototype (for reference only):\n```python3\ninpaint(image, mask, radius, function, algorithm[, output]) -> output\n```","ref":"Evision.Ft.html#inpaint/6"},{"type":"type","title":"Evision.Ft.enum/0","doc":"","ref":"Evision.Ft.html#t:enum/0"},{"type":"type","title":"Evision.Ft.t/0","doc":"Type that represents an `Ft` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Ft.html#t:t/0"},{"type":"module","title":"Evision.GFTTDetector","doc":"","ref":"Evision.GFTTDetector.html"},{"type":"function","title":"Evision.GFTTDetector.compute/1","doc":"","ref":"Evision.GFTTDetector.html#compute/1"},{"type":"function","title":"Evision.GFTTDetector.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.GFTTDetector.html#compute/3"},{"type":"function","title":"Evision.GFTTDetector.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.GFTTDetector.html#compute/4"},{"type":"function","title":"Evision.GFTTDetector.create/0","doc":"create\n##### Keyword Arguments\n- **maxCorners**: `integer()`.\n- **qualityLevel**: `double`.\n- **minDistance**: `double`.\n- **blockSize**: `integer()`.\n- **useHarrisDetector**: `bool`.\n- **k**: `double`.\n\n##### Return\n- **retval**: `Evision.GFTTDetector.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, maxCorners[, qualityLevel[, minDistance[, blockSize[, useHarrisDetector[, k]]]]]]) -> retval\n```","ref":"Evision.GFTTDetector.html#create/0"},{"type":"function","title":"Evision.GFTTDetector.create/1","doc":"create\n##### Keyword Arguments\n- **maxCorners**: `integer()`.\n- **qualityLevel**: `double`.\n- **minDistance**: `double`.\n- **blockSize**: `integer()`.\n- **useHarrisDetector**: `bool`.\n- **k**: `double`.\n\n##### Return\n- **retval**: `Evision.GFTTDetector.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, maxCorners[, qualityLevel[, minDistance[, blockSize[, useHarrisDetector[, k]]]]]]) -> retval\n```","ref":"Evision.GFTTDetector.html#create/1"},{"type":"function","title":"Evision.GFTTDetector.create/5","doc":"create\n\n##### Positional Arguments\n- **maxCorners**: `integer()`\n- **qualityLevel**: `double`\n- **minDistance**: `double`\n- **blockSize**: `integer()`\n- **gradiantSize**: `integer()`\n\n##### Keyword Arguments\n- **useHarrisDetector**: `bool`.\n- **k**: `double`.\n\n##### Return\n- **retval**: `Evision.GFTTDetector.t()`\n\nPython prototype (for reference only):\n```python3\ncreate(maxCorners, qualityLevel, minDistance, blockSize, gradiantSize[, useHarrisDetector[, k]]) -> retval\n```","ref":"Evision.GFTTDetector.html#create/5"},{"type":"function","title":"Evision.GFTTDetector.create/6","doc":"create\n\n##### Positional Arguments\n- **maxCorners**: `integer()`\n- **qualityLevel**: `double`\n- **minDistance**: `double`\n- **blockSize**: `integer()`\n- **gradiantSize**: `integer()`\n\n##### Keyword Arguments\n- **useHarrisDetector**: `bool`.\n- **k**: `double`.\n\n##### Return\n- **retval**: `Evision.GFTTDetector.t()`\n\nPython prototype (for reference only):\n```python3\ncreate(maxCorners, qualityLevel, minDistance, blockSize, gradiantSize[, useHarrisDetector[, k]]) -> retval\n```","ref":"Evision.GFTTDetector.html#create/6"},{"type":"function","title":"Evision.GFTTDetector.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.GFTTDetector.html#defaultNorm/1"},{"type":"function","title":"Evision.GFTTDetector.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.GFTTDetector.html#descriptorSize/1"},{"type":"function","title":"Evision.GFTTDetector.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.GFTTDetector.html#descriptorType/1"},{"type":"function","title":"Evision.GFTTDetector.detect/1","doc":"","ref":"Evision.GFTTDetector.html#detect/1"},{"type":"function","title":"Evision.GFTTDetector.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.GFTTDetector.html#detect/2"},{"type":"function","title":"Evision.GFTTDetector.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.GFTTDetector.html#detect/3"},{"type":"function","title":"Evision.GFTTDetector.detectAndCompute/1","doc":"","ref":"Evision.GFTTDetector.html#detectAndCompute/1"},{"type":"function","title":"Evision.GFTTDetector.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.GFTTDetector.html#detectAndCompute/3"},{"type":"function","title":"Evision.GFTTDetector.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.GFTTDetector.html#detectAndCompute/4"},{"type":"function","title":"Evision.GFTTDetector.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.GFTTDetector.html#empty/1"},{"type":"function","title":"Evision.GFTTDetector.getBlockSize/1","doc":"getBlockSize\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetBlockSize() -> retval\n```","ref":"Evision.GFTTDetector.html#getBlockSize/1"},{"type":"function","title":"Evision.GFTTDetector.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.GFTTDetector.html#getDefaultName/1"},{"type":"function","title":"Evision.GFTTDetector.getGradientSize/1","doc":"getGradientSize\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetGradientSize() -> retval\n```","ref":"Evision.GFTTDetector.html#getGradientSize/1"},{"type":"function","title":"Evision.GFTTDetector.getHarrisDetector/1","doc":"getHarrisDetector\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetHarrisDetector() -> retval\n```","ref":"Evision.GFTTDetector.html#getHarrisDetector/1"},{"type":"function","title":"Evision.GFTTDetector.getK/1","doc":"getK\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetK() -> retval\n```","ref":"Evision.GFTTDetector.html#getK/1"},{"type":"function","title":"Evision.GFTTDetector.getMaxFeatures/1","doc":"getMaxFeatures\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxFeatures() -> retval\n```","ref":"Evision.GFTTDetector.html#getMaxFeatures/1"},{"type":"function","title":"Evision.GFTTDetector.getMinDistance/1","doc":"getMinDistance\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMinDistance() -> retval\n```","ref":"Evision.GFTTDetector.html#getMinDistance/1"},{"type":"function","title":"Evision.GFTTDetector.getQualityLevel/1","doc":"getQualityLevel\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetQualityLevel() -> retval\n```","ref":"Evision.GFTTDetector.html#getQualityLevel/1"},{"type":"function","title":"Evision.GFTTDetector.read/1","doc":"","ref":"Evision.GFTTDetector.html#read/1"},{"type":"function","title":"Evision.GFTTDetector.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.GFTTDetector.html#read/2"},{"type":"function","title":"Evision.GFTTDetector.setBlockSize/1","doc":"","ref":"Evision.GFTTDetector.html#setBlockSize/1"},{"type":"function","title":"Evision.GFTTDetector.setBlockSize/2","doc":"setBlockSize\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n- **blockSize**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetBlockSize(blockSize) -> None\n```","ref":"Evision.GFTTDetector.html#setBlockSize/2"},{"type":"function","title":"Evision.GFTTDetector.setGradientSize/1","doc":"","ref":"Evision.GFTTDetector.html#setGradientSize/1"},{"type":"function","title":"Evision.GFTTDetector.setGradientSize/2","doc":"setGradientSize\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n- **gradientSize_**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetGradientSize(gradientSize_) -> None\n```","ref":"Evision.GFTTDetector.html#setGradientSize/2"},{"type":"function","title":"Evision.GFTTDetector.setHarrisDetector/1","doc":"","ref":"Evision.GFTTDetector.html#setHarrisDetector/1"},{"type":"function","title":"Evision.GFTTDetector.setHarrisDetector/2","doc":"setHarrisDetector\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n- **val**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetHarrisDetector(val) -> None\n```","ref":"Evision.GFTTDetector.html#setHarrisDetector/2"},{"type":"function","title":"Evision.GFTTDetector.setK/1","doc":"","ref":"Evision.GFTTDetector.html#setK/1"},{"type":"function","title":"Evision.GFTTDetector.setK/2","doc":"setK\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n- **k**: `double`\n\nPython prototype (for reference only):\n```python3\nsetK(k) -> None\n```","ref":"Evision.GFTTDetector.html#setK/2"},{"type":"function","title":"Evision.GFTTDetector.setMaxFeatures/1","doc":"","ref":"Evision.GFTTDetector.html#setMaxFeatures/1"},{"type":"function","title":"Evision.GFTTDetector.setMaxFeatures/2","doc":"setMaxFeatures\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n- **maxFeatures**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxFeatures(maxFeatures) -> None\n```","ref":"Evision.GFTTDetector.html#setMaxFeatures/2"},{"type":"function","title":"Evision.GFTTDetector.setMinDistance/1","doc":"","ref":"Evision.GFTTDetector.html#setMinDistance/1"},{"type":"function","title":"Evision.GFTTDetector.setMinDistance/2","doc":"setMinDistance\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n- **minDistance**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMinDistance(minDistance) -> None\n```","ref":"Evision.GFTTDetector.html#setMinDistance/2"},{"type":"function","title":"Evision.GFTTDetector.setQualityLevel/1","doc":"","ref":"Evision.GFTTDetector.html#setQualityLevel/1"},{"type":"function","title":"Evision.GFTTDetector.setQualityLevel/2","doc":"setQualityLevel\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n- **qlevel**: `double`\n\nPython prototype (for reference only):\n```python3\nsetQualityLevel(qlevel) -> None\n```","ref":"Evision.GFTTDetector.html#setQualityLevel/2"},{"type":"function","title":"Evision.GFTTDetector.write/1","doc":"","ref":"Evision.GFTTDetector.html#write/1"},{"type":"function","title":"Evision.GFTTDetector.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.GFTTDetector.html#write/2"},{"type":"function","title":"Evision.GFTTDetector.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.GFTTDetector.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.GFTTDetector.html#write/3"},{"type":"type","title":"Evision.GFTTDetector.t/0","doc":"Type that represents an `GFTTDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.GFTTDetector.html#t:t/0"},{"type":"module","title":"Evision.GemmFlags","doc":"","ref":"Evision.GemmFlags.html"},{"type":"function","title":"Evision.GemmFlags.cv_GEMM_1_T/0","doc":"","ref":"Evision.GemmFlags.html#cv_GEMM_1_T/0"},{"type":"function","title":"Evision.GemmFlags.cv_GEMM_2_T/0","doc":"","ref":"Evision.GemmFlags.html#cv_GEMM_2_T/0"},{"type":"function","title":"Evision.GemmFlags.cv_GEMM_3_T/0","doc":"","ref":"Evision.GemmFlags.html#cv_GEMM_3_T/0"},{"type":"type","title":"Evision.GemmFlags.enum/0","doc":"","ref":"Evision.GemmFlags.html#t:enum/0"},{"type":"module","title":"Evision.GeneralizedHough","doc":"","ref":"Evision.GeneralizedHough.html"},{"type":"function","title":"Evision.GeneralizedHough.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.GeneralizedHough.html#clear/1"},{"type":"function","title":"Evision.GeneralizedHough.detect/1","doc":"","ref":"Evision.GeneralizedHough.html#detect/1"},{"type":"function","title":"Evision.GeneralizedHough.detect/2","doc":"detect\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n- **image**: `Evision.Mat`\n\n##### Return\n- **positions**: `Evision.Mat.t()`.\n- **votes**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ndetect(image[, positions[, votes]]) -> positions, votes\n```","ref":"Evision.GeneralizedHough.html#detect/2"},{"type":"function","title":"Evision.GeneralizedHough.detect/3","doc":"detect\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n- **image**: `Evision.Mat`\n\n##### Return\n- **positions**: `Evision.Mat.t()`.\n- **votes**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ndetect(image[, positions[, votes]]) -> positions, votes\n```","ref":"Evision.GeneralizedHough.html#detect/3"},{"type":"function","title":"Evision.GeneralizedHough.detect/4","doc":"detect\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n- **edges**: `Evision.Mat`\n- **dx**: `Evision.Mat`\n- **dy**: `Evision.Mat`\n\n##### Return\n- **positions**: `Evision.Mat.t()`.\n- **votes**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ndetect(edges, dx, dy[, positions[, votes]]) -> positions, votes\n```","ref":"Evision.GeneralizedHough.html#detect/4"},{"type":"function","title":"Evision.GeneralizedHough.detect/5","doc":"detect\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n- **edges**: `Evision.Mat`\n- **dx**: `Evision.Mat`\n- **dy**: `Evision.Mat`\n\n##### Return\n- **positions**: `Evision.Mat.t()`.\n- **votes**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ndetect(edges, dx, dy[, positions[, votes]]) -> positions, votes\n```","ref":"Evision.GeneralizedHough.html#detect/5"},{"type":"function","title":"Evision.GeneralizedHough.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.GeneralizedHough.html#empty/1"},{"type":"function","title":"Evision.GeneralizedHough.getCannyHighThresh/1","doc":"getCannyHighThresh\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetCannyHighThresh() -> retval\n```","ref":"Evision.GeneralizedHough.html#getCannyHighThresh/1"},{"type":"function","title":"Evision.GeneralizedHough.getCannyLowThresh/1","doc":"getCannyLowThresh\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetCannyLowThresh() -> retval\n```","ref":"Evision.GeneralizedHough.html#getCannyLowThresh/1"},{"type":"function","title":"Evision.GeneralizedHough.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.GeneralizedHough.html#getDefaultName/1"},{"type":"function","title":"Evision.GeneralizedHough.getDp/1","doc":"getDp\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetDp() -> retval\n```","ref":"Evision.GeneralizedHough.html#getDp/1"},{"type":"function","title":"Evision.GeneralizedHough.getMaxBufferSize/1","doc":"getMaxBufferSize\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxBufferSize() -> retval\n```","ref":"Evision.GeneralizedHough.html#getMaxBufferSize/1"},{"type":"function","title":"Evision.GeneralizedHough.getMinDist/1","doc":"getMinDist\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMinDist() -> retval\n```","ref":"Evision.GeneralizedHough.html#getMinDist/1"},{"type":"function","title":"Evision.GeneralizedHough.read/1","doc":"","ref":"Evision.GeneralizedHough.html#read/1"},{"type":"function","title":"Evision.GeneralizedHough.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.GeneralizedHough.html#read/2"},{"type":"function","title":"Evision.GeneralizedHough.save/1","doc":"","ref":"Evision.GeneralizedHough.html#save/1"},{"type":"function","title":"Evision.GeneralizedHough.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.GeneralizedHough.html#save/2"},{"type":"function","title":"Evision.GeneralizedHough.setCannyHighThresh/1","doc":"","ref":"Evision.GeneralizedHough.html#setCannyHighThresh/1"},{"type":"function","title":"Evision.GeneralizedHough.setCannyHighThresh/2","doc":"setCannyHighThresh\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n- **cannyHighThresh**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetCannyHighThresh(cannyHighThresh) -> None\n```","ref":"Evision.GeneralizedHough.html#setCannyHighThresh/2"},{"type":"function","title":"Evision.GeneralizedHough.setCannyLowThresh/1","doc":"","ref":"Evision.GeneralizedHough.html#setCannyLowThresh/1"},{"type":"function","title":"Evision.GeneralizedHough.setCannyLowThresh/2","doc":"setCannyLowThresh\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n- **cannyLowThresh**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetCannyLowThresh(cannyLowThresh) -> None\n```","ref":"Evision.GeneralizedHough.html#setCannyLowThresh/2"},{"type":"function","title":"Evision.GeneralizedHough.setDp/1","doc":"","ref":"Evision.GeneralizedHough.html#setDp/1"},{"type":"function","title":"Evision.GeneralizedHough.setDp/2","doc":"setDp\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n- **dp**: `double`\n\nPython prototype (for reference only):\n```python3\nsetDp(dp) -> None\n```","ref":"Evision.GeneralizedHough.html#setDp/2"},{"type":"function","title":"Evision.GeneralizedHough.setMaxBufferSize/1","doc":"","ref":"Evision.GeneralizedHough.html#setMaxBufferSize/1"},{"type":"function","title":"Evision.GeneralizedHough.setMaxBufferSize/2","doc":"setMaxBufferSize\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n- **maxBufferSize**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxBufferSize(maxBufferSize) -> None\n```","ref":"Evision.GeneralizedHough.html#setMaxBufferSize/2"},{"type":"function","title":"Evision.GeneralizedHough.setMinDist/1","doc":"","ref":"Evision.GeneralizedHough.html#setMinDist/1"},{"type":"function","title":"Evision.GeneralizedHough.setMinDist/2","doc":"setMinDist\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n- **minDist**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMinDist(minDist) -> None\n```","ref":"Evision.GeneralizedHough.html#setMinDist/2"},{"type":"function","title":"Evision.GeneralizedHough.setTemplate/1","doc":"","ref":"Evision.GeneralizedHough.html#setTemplate/1"},{"type":"function","title":"Evision.GeneralizedHough.setTemplate/2","doc":"setTemplate\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n- **templ**: `Evision.Mat`\n\n##### Keyword Arguments\n- **templCenter**: `Point`.\n\nPython prototype (for reference only):\n```python3\nsetTemplate(templ[, templCenter]) -> None\n```","ref":"Evision.GeneralizedHough.html#setTemplate/2"},{"type":"function","title":"Evision.GeneralizedHough.setTemplate/3","doc":"setTemplate\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n- **templ**: `Evision.Mat`\n\n##### Keyword Arguments\n- **templCenter**: `Point`.\n\nPython prototype (for reference only):\n```python3\nsetTemplate(templ[, templCenter]) -> None\n```","ref":"Evision.GeneralizedHough.html#setTemplate/3"},{"type":"function","title":"Evision.GeneralizedHough.setTemplate/4","doc":"setTemplate\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n- **edges**: `Evision.Mat`\n- **dx**: `Evision.Mat`\n- **dy**: `Evision.Mat`\n\n##### Keyword Arguments\n- **templCenter**: `Point`.\n\nPython prototype (for reference only):\n```python3\nsetTemplate(edges, dx, dy[, templCenter]) -> None\n```","ref":"Evision.GeneralizedHough.html#setTemplate/4"},{"type":"function","title":"Evision.GeneralizedHough.setTemplate/5","doc":"setTemplate\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n- **edges**: `Evision.Mat`\n- **dx**: `Evision.Mat`\n- **dy**: `Evision.Mat`\n\n##### Keyword Arguments\n- **templCenter**: `Point`.\n\nPython prototype (for reference only):\n```python3\nsetTemplate(edges, dx, dy[, templCenter]) -> None\n```","ref":"Evision.GeneralizedHough.html#setTemplate/5"},{"type":"function","title":"Evision.GeneralizedHough.write/1","doc":"","ref":"Evision.GeneralizedHough.html#write/1"},{"type":"function","title":"Evision.GeneralizedHough.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.GeneralizedHough.html#write/2"},{"type":"function","title":"Evision.GeneralizedHough.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHough.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.GeneralizedHough.html#write/3"},{"type":"type","title":"Evision.GeneralizedHough.t/0","doc":"Type that represents an `GeneralizedHough` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.GeneralizedHough.html#t:t/0"},{"type":"module","title":"Evision.GeneralizedHoughBallard","doc":"","ref":"Evision.GeneralizedHoughBallard.html"},{"type":"function","title":"Evision.GeneralizedHoughBallard.getLevels/1","doc":"getLevels\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughBallard.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetLevels() -> retval\n```","ref":"Evision.GeneralizedHoughBallard.html#getLevels/1"},{"type":"function","title":"Evision.GeneralizedHoughBallard.getVotesThreshold/1","doc":"getVotesThreshold\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughBallard.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetVotesThreshold() -> retval\n```","ref":"Evision.GeneralizedHoughBallard.html#getVotesThreshold/1"},{"type":"function","title":"Evision.GeneralizedHoughBallard.setLevels/1","doc":"","ref":"Evision.GeneralizedHoughBallard.html#setLevels/1"},{"type":"function","title":"Evision.GeneralizedHoughBallard.setLevels/2","doc":"setLevels\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughBallard.t()`\n- **levels**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetLevels(levels) -> None\n```","ref":"Evision.GeneralizedHoughBallard.html#setLevels/2"},{"type":"function","title":"Evision.GeneralizedHoughBallard.setVotesThreshold/1","doc":"","ref":"Evision.GeneralizedHoughBallard.html#setVotesThreshold/1"},{"type":"function","title":"Evision.GeneralizedHoughBallard.setVotesThreshold/2","doc":"setVotesThreshold\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughBallard.t()`\n- **votesThreshold**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetVotesThreshold(votesThreshold) -> None\n```","ref":"Evision.GeneralizedHoughBallard.html#setVotesThreshold/2"},{"type":"type","title":"Evision.GeneralizedHoughBallard.t/0","doc":"Type that represents an `GeneralizedHoughBallard` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.GeneralizedHoughBallard.html#t:t/0"},{"type":"module","title":"Evision.GeneralizedHoughGuil","doc":"","ref":"Evision.GeneralizedHoughGuil.html"},{"type":"function","title":"Evision.GeneralizedHoughGuil.getAngleEpsilon/1","doc":"getAngleEpsilon\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetAngleEpsilon() -> retval\n```","ref":"Evision.GeneralizedHoughGuil.html#getAngleEpsilon/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.getAngleStep/1","doc":"getAngleStep\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetAngleStep() -> retval\n```","ref":"Evision.GeneralizedHoughGuil.html#getAngleStep/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.getAngleThresh/1","doc":"getAngleThresh\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetAngleThresh() -> retval\n```","ref":"Evision.GeneralizedHoughGuil.html#getAngleThresh/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.getLevels/1","doc":"getLevels\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetLevels() -> retval\n```","ref":"Evision.GeneralizedHoughGuil.html#getLevels/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.getMaxAngle/1","doc":"getMaxAngle\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxAngle() -> retval\n```","ref":"Evision.GeneralizedHoughGuil.html#getMaxAngle/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.getMaxScale/1","doc":"getMaxScale\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxScale() -> retval\n```","ref":"Evision.GeneralizedHoughGuil.html#getMaxScale/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.getMinAngle/1","doc":"getMinAngle\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMinAngle() -> retval\n```","ref":"Evision.GeneralizedHoughGuil.html#getMinAngle/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.getMinScale/1","doc":"getMinScale\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMinScale() -> retval\n```","ref":"Evision.GeneralizedHoughGuil.html#getMinScale/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.getPosThresh/1","doc":"getPosThresh\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetPosThresh() -> retval\n```","ref":"Evision.GeneralizedHoughGuil.html#getPosThresh/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.getScaleStep/1","doc":"getScaleStep\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetScaleStep() -> retval\n```","ref":"Evision.GeneralizedHoughGuil.html#getScaleStep/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.getScaleThresh/1","doc":"getScaleThresh\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetScaleThresh() -> retval\n```","ref":"Evision.GeneralizedHoughGuil.html#getScaleThresh/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.getXi/1","doc":"getXi\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetXi() -> retval\n```","ref":"Evision.GeneralizedHoughGuil.html#getXi/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setAngleEpsilon/1","doc":"","ref":"Evision.GeneralizedHoughGuil.html#setAngleEpsilon/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setAngleEpsilon/2","doc":"setAngleEpsilon\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n- **angleEpsilon**: `double`\n\nPython prototype (for reference only):\n```python3\nsetAngleEpsilon(angleEpsilon) -> None\n```","ref":"Evision.GeneralizedHoughGuil.html#setAngleEpsilon/2"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setAngleStep/1","doc":"","ref":"Evision.GeneralizedHoughGuil.html#setAngleStep/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setAngleStep/2","doc":"setAngleStep\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n- **angleStep**: `double`\n\nPython prototype (for reference only):\n```python3\nsetAngleStep(angleStep) -> None\n```","ref":"Evision.GeneralizedHoughGuil.html#setAngleStep/2"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setAngleThresh/1","doc":"","ref":"Evision.GeneralizedHoughGuil.html#setAngleThresh/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setAngleThresh/2","doc":"setAngleThresh\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n- **angleThresh**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetAngleThresh(angleThresh) -> None\n```","ref":"Evision.GeneralizedHoughGuil.html#setAngleThresh/2"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setLevels/1","doc":"","ref":"Evision.GeneralizedHoughGuil.html#setLevels/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setLevels/2","doc":"setLevels\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n- **levels**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetLevels(levels) -> None\n```","ref":"Evision.GeneralizedHoughGuil.html#setLevels/2"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setMaxAngle/1","doc":"","ref":"Evision.GeneralizedHoughGuil.html#setMaxAngle/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setMaxAngle/2","doc":"setMaxAngle\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n- **maxAngle**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxAngle(maxAngle) -> None\n```","ref":"Evision.GeneralizedHoughGuil.html#setMaxAngle/2"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setMaxScale/1","doc":"","ref":"Evision.GeneralizedHoughGuil.html#setMaxScale/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setMaxScale/2","doc":"setMaxScale\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n- **maxScale**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxScale(maxScale) -> None\n```","ref":"Evision.GeneralizedHoughGuil.html#setMaxScale/2"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setMinAngle/1","doc":"","ref":"Evision.GeneralizedHoughGuil.html#setMinAngle/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setMinAngle/2","doc":"setMinAngle\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n- **minAngle**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMinAngle(minAngle) -> None\n```","ref":"Evision.GeneralizedHoughGuil.html#setMinAngle/2"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setMinScale/1","doc":"","ref":"Evision.GeneralizedHoughGuil.html#setMinScale/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setMinScale/2","doc":"setMinScale\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n- **minScale**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMinScale(minScale) -> None\n```","ref":"Evision.GeneralizedHoughGuil.html#setMinScale/2"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setPosThresh/1","doc":"","ref":"Evision.GeneralizedHoughGuil.html#setPosThresh/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setPosThresh/2","doc":"setPosThresh\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n- **posThresh**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetPosThresh(posThresh) -> None\n```","ref":"Evision.GeneralizedHoughGuil.html#setPosThresh/2"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setScaleStep/1","doc":"","ref":"Evision.GeneralizedHoughGuil.html#setScaleStep/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setScaleStep/2","doc":"setScaleStep\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n- **scaleStep**: `double`\n\nPython prototype (for reference only):\n```python3\nsetScaleStep(scaleStep) -> None\n```","ref":"Evision.GeneralizedHoughGuil.html#setScaleStep/2"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setScaleThresh/1","doc":"","ref":"Evision.GeneralizedHoughGuil.html#setScaleThresh/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setScaleThresh/2","doc":"setScaleThresh\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n- **scaleThresh**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetScaleThresh(scaleThresh) -> None\n```","ref":"Evision.GeneralizedHoughGuil.html#setScaleThresh/2"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setXi/1","doc":"","ref":"Evision.GeneralizedHoughGuil.html#setXi/1"},{"type":"function","title":"Evision.GeneralizedHoughGuil.setXi/2","doc":"setXi\n\n##### Positional Arguments\n- **self**: `Evision.GeneralizedHoughGuil.t()`\n- **xi**: `double`\n\nPython prototype (for reference only):\n```python3\nsetXi(xi) -> None\n```","ref":"Evision.GeneralizedHoughGuil.html#setXi/2"},{"type":"type","title":"Evision.GeneralizedHoughGuil.t/0","doc":"Type that represents an `GeneralizedHoughGuil` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.GeneralizedHoughGuil.html#t:t/0"},{"type":"module","title":"Evision.GrabCutClasses","doc":"","ref":"Evision.GrabCutClasses.html"},{"type":"function","title":"Evision.GrabCutClasses.cv_GC_BGD/0","doc":"","ref":"Evision.GrabCutClasses.html#cv_GC_BGD/0"},{"type":"function","title":"Evision.GrabCutClasses.cv_GC_FGD/0","doc":"","ref":"Evision.GrabCutClasses.html#cv_GC_FGD/0"},{"type":"function","title":"Evision.GrabCutClasses.cv_GC_PR_BGD/0","doc":"","ref":"Evision.GrabCutClasses.html#cv_GC_PR_BGD/0"},{"type":"function","title":"Evision.GrabCutClasses.cv_GC_PR_FGD/0","doc":"","ref":"Evision.GrabCutClasses.html#cv_GC_PR_FGD/0"},{"type":"type","title":"Evision.GrabCutClasses.enum/0","doc":"","ref":"Evision.GrabCutClasses.html#t:enum/0"},{"type":"module","title":"Evision.GrabCutModes","doc":"","ref":"Evision.GrabCutModes.html"},{"type":"function","title":"Evision.GrabCutModes.cv_GC_EVAL/0","doc":"","ref":"Evision.GrabCutModes.html#cv_GC_EVAL/0"},{"type":"function","title":"Evision.GrabCutModes.cv_GC_EVAL_FREEZE_MODEL/0","doc":"","ref":"Evision.GrabCutModes.html#cv_GC_EVAL_FREEZE_MODEL/0"},{"type":"function","title":"Evision.GrabCutModes.cv_GC_INIT_WITH_MASK/0","doc":"","ref":"Evision.GrabCutModes.html#cv_GC_INIT_WITH_MASK/0"},{"type":"function","title":"Evision.GrabCutModes.cv_GC_INIT_WITH_RECT/0","doc":"","ref":"Evision.GrabCutModes.html#cv_GC_INIT_WITH_RECT/0"},{"type":"type","title":"Evision.GrabCutModes.enum/0","doc":"","ref":"Evision.GrabCutModes.html#t:enum/0"},{"type":"module","title":"Evision.GraphicalCodeDetector","doc":"","ref":"Evision.GraphicalCodeDetector.html"},{"type":"function","title":"Evision.GraphicalCodeDetector.decode/1","doc":"","ref":"Evision.GraphicalCodeDetector.html#decode/1"},{"type":"function","title":"Evision.GraphicalCodeDetector.decode/3","doc":"Decodes graphical code in image once it's found by the detect() method.\n\n##### Positional Arguments\n- **self**: `Evision.GraphicalCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical code.\n\n- **points**: `Evision.Mat`.\n\n  Quadrangle vertices found by detect() method (or some other algorithm).\n\n##### Return\n- **retval**: `string`\n- **straight_code**: `Evision.Mat.t()`.\n\n  The optional output image containing binarized code, will be empty if not found.\n\nReturns UTF8-encoded output string or empty string if the code cannot be decoded.\n\nPython prototype (for reference only):\n```python3\ndecode(img, points[, straight_code]) -> retval, straight_code\n```","ref":"Evision.GraphicalCodeDetector.html#decode/3"},{"type":"function","title":"Evision.GraphicalCodeDetector.decode/4","doc":"Decodes graphical code in image once it's found by the detect() method.\n\n##### Positional Arguments\n- **self**: `Evision.GraphicalCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical code.\n\n- **points**: `Evision.Mat`.\n\n  Quadrangle vertices found by detect() method (or some other algorithm).\n\n##### Return\n- **retval**: `string`\n- **straight_code**: `Evision.Mat.t()`.\n\n  The optional output image containing binarized code, will be empty if not found.\n\nReturns UTF8-encoded output string or empty string if the code cannot be decoded.\n\nPython prototype (for reference only):\n```python3\ndecode(img, points[, straight_code]) -> retval, straight_code\n```","ref":"Evision.GraphicalCodeDetector.html#decode/4"},{"type":"function","title":"Evision.GraphicalCodeDetector.decodeMulti/1","doc":"","ref":"Evision.GraphicalCodeDetector.html#decodeMulti/1"},{"type":"function","title":"Evision.GraphicalCodeDetector.decodeMulti/3","doc":"Decodes graphical codes in image once it's found by the detect() method.\n\n##### Positional Arguments\n- **self**: `Evision.GraphicalCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical codes.\n\n- **points**: `Evision.Mat`.\n\n  vector of Quadrangle vertices found by detect() method (or some other algorithm).\n\n##### Return\n- **retval**: `bool`\n- **decoded_info**: `[string]`.\n\n  UTF8-encoded output vector of string or empty vector of string if the codes cannot be decoded.\n\n- **straight_code**: `[Evision.Mat]`.\n\n  The optional output vector of images containing binarized codes\n\nPython prototype (for reference only):\n```python3\ndecodeMulti(img, points[, straight_code]) -> retval, decoded_info, straight_code\n```","ref":"Evision.GraphicalCodeDetector.html#decodeMulti/3"},{"type":"function","title":"Evision.GraphicalCodeDetector.decodeMulti/4","doc":"Decodes graphical codes in image once it's found by the detect() method.\n\n##### Positional Arguments\n- **self**: `Evision.GraphicalCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical codes.\n\n- **points**: `Evision.Mat`.\n\n  vector of Quadrangle vertices found by detect() method (or some other algorithm).\n\n##### Return\n- **retval**: `bool`\n- **decoded_info**: `[string]`.\n\n  UTF8-encoded output vector of string or empty vector of string if the codes cannot be decoded.\n\n- **straight_code**: `[Evision.Mat]`.\n\n  The optional output vector of images containing binarized codes\n\nPython prototype (for reference only):\n```python3\ndecodeMulti(img, points[, straight_code]) -> retval, decoded_info, straight_code\n```","ref":"Evision.GraphicalCodeDetector.html#decodeMulti/4"},{"type":"function","title":"Evision.GraphicalCodeDetector.detect/1","doc":"","ref":"Evision.GraphicalCodeDetector.html#detect/1"},{"type":"function","title":"Evision.GraphicalCodeDetector.detect/2","doc":"Detects graphical code in image and returns the quadrangle containing the code.\n\n##### Positional Arguments\n- **self**: `Evision.GraphicalCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing (or not) graphical code.\n\n##### Return\n- **retval**: `bool`\n- **points**: `Evision.Mat.t()`.\n\n  Output vector of vertices of the minimum-area quadrangle containing the code.\n\nPython prototype (for reference only):\n```python3\ndetect(img[, points]) -> retval, points\n```","ref":"Evision.GraphicalCodeDetector.html#detect/2"},{"type":"function","title":"Evision.GraphicalCodeDetector.detect/3","doc":"Detects graphical code in image and returns the quadrangle containing the code.\n\n##### Positional Arguments\n- **self**: `Evision.GraphicalCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing (or not) graphical code.\n\n##### Return\n- **retval**: `bool`\n- **points**: `Evision.Mat.t()`.\n\n  Output vector of vertices of the minimum-area quadrangle containing the code.\n\nPython prototype (for reference only):\n```python3\ndetect(img[, points]) -> retval, points\n```","ref":"Evision.GraphicalCodeDetector.html#detect/3"},{"type":"function","title":"Evision.GraphicalCodeDetector.detectAndDecode/1","doc":"","ref":"Evision.GraphicalCodeDetector.html#detectAndDecode/1"},{"type":"function","title":"Evision.GraphicalCodeDetector.detectAndDecode/2","doc":"Both detects and decodes graphical code\n\n##### Positional Arguments\n- **self**: `Evision.GraphicalCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical code.\n\n##### Return\n- **retval**: `string`\n- **points**: `Evision.Mat.t()`.\n\n  optional output array of vertices of the found graphical code quadrangle, will be empty if not found.\n\n- **straight_code**: `Evision.Mat.t()`.\n\n  The optional output image containing binarized code\n\nPython prototype (for reference only):\n```python3\ndetectAndDecode(img[, points[, straight_code]]) -> retval, points, straight_code\n```","ref":"Evision.GraphicalCodeDetector.html#detectAndDecode/2"},{"type":"function","title":"Evision.GraphicalCodeDetector.detectAndDecode/3","doc":"Both detects and decodes graphical code\n\n##### Positional Arguments\n- **self**: `Evision.GraphicalCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical code.\n\n##### Return\n- **retval**: `string`\n- **points**: `Evision.Mat.t()`.\n\n  optional output array of vertices of the found graphical code quadrangle, will be empty if not found.\n\n- **straight_code**: `Evision.Mat.t()`.\n\n  The optional output image containing binarized code\n\nPython prototype (for reference only):\n```python3\ndetectAndDecode(img[, points[, straight_code]]) -> retval, points, straight_code\n```","ref":"Evision.GraphicalCodeDetector.html#detectAndDecode/3"},{"type":"function","title":"Evision.GraphicalCodeDetector.detectAndDecodeMulti/1","doc":"","ref":"Evision.GraphicalCodeDetector.html#detectAndDecodeMulti/1"},{"type":"function","title":"Evision.GraphicalCodeDetector.detectAndDecodeMulti/2","doc":"Both detects and decodes graphical codes\n\n##### Positional Arguments\n- **self**: `Evision.GraphicalCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical codes.\n\n##### Return\n- **retval**: `bool`\n- **decoded_info**: `[string]`.\n\n  UTF8-encoded output vector of string or empty vector of string if the codes cannot be decoded.\n\n- **points**: `Evision.Mat.t()`.\n\n  optional output vector of vertices of the found graphical code quadrangles. Will be empty if not found.\n\n- **straight_code**: `[Evision.Mat]`.\n\n  The optional vector of images containing binarized codes\n\n- If there are QR codes encoded with a Structured Append mode on the image and all of them detected and decoded correctly,\n  method writes a full message to position corresponds to 0-th code in a sequence. The rest of QR codes from the same sequence\n  have empty string.\n\nPython prototype (for reference only):\n```python3\ndetectAndDecodeMulti(img[, points[, straight_code]]) -> retval, decoded_info, points, straight_code\n```","ref":"Evision.GraphicalCodeDetector.html#detectAndDecodeMulti/2"},{"type":"function","title":"Evision.GraphicalCodeDetector.detectAndDecodeMulti/3","doc":"Both detects and decodes graphical codes\n\n##### Positional Arguments\n- **self**: `Evision.GraphicalCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical codes.\n\n##### Return\n- **retval**: `bool`\n- **decoded_info**: `[string]`.\n\n  UTF8-encoded output vector of string or empty vector of string if the codes cannot be decoded.\n\n- **points**: `Evision.Mat.t()`.\n\n  optional output vector of vertices of the found graphical code quadrangles. Will be empty if not found.\n\n- **straight_code**: `[Evision.Mat]`.\n\n  The optional vector of images containing binarized codes\n\n- If there are QR codes encoded with a Structured Append mode on the image and all of them detected and decoded correctly,\n  method writes a full message to position corresponds to 0-th code in a sequence. The rest of QR codes from the same sequence\n  have empty string.\n\nPython prototype (for reference only):\n```python3\ndetectAndDecodeMulti(img[, points[, straight_code]]) -> retval, decoded_info, points, straight_code\n```","ref":"Evision.GraphicalCodeDetector.html#detectAndDecodeMulti/3"},{"type":"function","title":"Evision.GraphicalCodeDetector.detectMulti/1","doc":"","ref":"Evision.GraphicalCodeDetector.html#detectMulti/1"},{"type":"function","title":"Evision.GraphicalCodeDetector.detectMulti/2","doc":"Detects graphical codes in image and returns the vector of the quadrangles containing the codes.\n\n##### Positional Arguments\n- **self**: `Evision.GraphicalCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing (or not) graphical codes.\n\n##### Return\n- **retval**: `bool`\n- **points**: `Evision.Mat.t()`.\n\n  Output vector of vector of vertices of the minimum-area quadrangle containing the codes.\n\nPython prototype (for reference only):\n```python3\ndetectMulti(img[, points]) -> retval, points\n```","ref":"Evision.GraphicalCodeDetector.html#detectMulti/2"},{"type":"function","title":"Evision.GraphicalCodeDetector.detectMulti/3","doc":"Detects graphical codes in image and returns the vector of the quadrangles containing the codes.\n\n##### Positional Arguments\n- **self**: `Evision.GraphicalCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing (or not) graphical codes.\n\n##### Return\n- **retval**: `bool`\n- **points**: `Evision.Mat.t()`.\n\n  Output vector of vector of vertices of the minimum-area quadrangle containing the codes.\n\nPython prototype (for reference only):\n```python3\ndetectMulti(img[, points]) -> retval, points\n```","ref":"Evision.GraphicalCodeDetector.html#detectMulti/3"},{"type":"type","title":"Evision.GraphicalCodeDetector.t/0","doc":"Type that represents an `GraphicalCodeDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.GraphicalCodeDetector.html#t:t/0"},{"type":"module","title":"Evision.HFS","doc":"","ref":"Evision.HFS.html"},{"type":"type","title":"Evision.HFS.t/0","doc":"Type that represents an `HFS` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.HFS.html#t:t/0"},{"type":"module","title":"Evision.HFS.HfsSegment","doc":"","ref":"Evision.HFS.HfsSegment.html"},{"type":"function","title":"Evision.HFS.HfsSegment.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.HFS.HfsSegment.html#clear/1"},{"type":"function","title":"Evision.HFS.HfsSegment.create/1","doc":"","ref":"Evision.HFS.HfsSegment.html#create/1"},{"type":"function","title":"Evision.HFS.HfsSegment.create/2","doc":": create a hfs object\n\n##### Positional Arguments\n- **height**: `integer()`.\n\n  the height of the input image\n\n- **width**: `integer()`.\n\n  the width of the input image\n\n##### Keyword Arguments\n- **segEgbThresholdI**: `float`.\n\n  parameter segEgbThresholdI\n\n- **minRegionSizeI**: `integer()`.\n\n  parameter minRegionSizeI\n\n- **segEgbThresholdII**: `float`.\n\n  parameter segEgbThresholdII\n\n- **minRegionSizeII**: `integer()`.\n\n  parameter minRegionSizeII\n\n- **spatialWeight**: `float`.\n\n  parameter spatialWeight\n\n- **slicSpixelSize**: `integer()`.\n\n  parameter slicSpixelSize\n\n- **numSlicIter**: `integer()`.\n\n  parameter numSlicIter\n\n##### Return\n- **retval**: `HfsSegment`\n\nPython prototype (for reference only):\n```python3\ncreate(height, width[, segEgbThresholdI[, minRegionSizeI[, segEgbThresholdII[, minRegionSizeII[, spatialWeight[, slicSpixelSize[, numSlicIter]]]]]]]) -> retval\n```","ref":"Evision.HFS.HfsSegment.html#create/2"},{"type":"function","title":"Evision.HFS.HfsSegment.create/3","doc":": create a hfs object\n\n##### Positional Arguments\n- **height**: `integer()`.\n\n  the height of the input image\n\n- **width**: `integer()`.\n\n  the width of the input image\n\n##### Keyword Arguments\n- **segEgbThresholdI**: `float`.\n\n  parameter segEgbThresholdI\n\n- **minRegionSizeI**: `integer()`.\n\n  parameter minRegionSizeI\n\n- **segEgbThresholdII**: `float`.\n\n  parameter segEgbThresholdII\n\n- **minRegionSizeII**: `integer()`.\n\n  parameter minRegionSizeII\n\n- **spatialWeight**: `float`.\n\n  parameter spatialWeight\n\n- **slicSpixelSize**: `integer()`.\n\n  parameter slicSpixelSize\n\n- **numSlicIter**: `integer()`.\n\n  parameter numSlicIter\n\n##### Return\n- **retval**: `HfsSegment`\n\nPython prototype (for reference only):\n```python3\ncreate(height, width[, segEgbThresholdI[, minRegionSizeI[, segEgbThresholdII[, minRegionSizeII[, spatialWeight[, slicSpixelSize[, numSlicIter]]]]]]]) -> retval\n```","ref":"Evision.HFS.HfsSegment.html#create/3"},{"type":"function","title":"Evision.HFS.HfsSegment.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.HFS.HfsSegment.html#empty/1"},{"type":"function","title":"Evision.HFS.HfsSegment.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.HFS.HfsSegment.html#getDefaultName/1"},{"type":"function","title":"Evision.HFS.HfsSegment.getMinRegionSizeI/1","doc":"getMinRegionSizeI\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMinRegionSizeI() -> retval\n```","ref":"Evision.HFS.HfsSegment.html#getMinRegionSizeI/1"},{"type":"function","title":"Evision.HFS.HfsSegment.getMinRegionSizeII/1","doc":"getMinRegionSizeII\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMinRegionSizeII() -> retval\n```","ref":"Evision.HFS.HfsSegment.html#getMinRegionSizeII/1"},{"type":"function","title":"Evision.HFS.HfsSegment.getNumSlicIter/1","doc":"getNumSlicIter\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNumSlicIter() -> retval\n```","ref":"Evision.HFS.HfsSegment.html#getNumSlicIter/1"},{"type":"function","title":"Evision.HFS.HfsSegment.getSegEgbThresholdI/1","doc":"getSegEgbThresholdI\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetSegEgbThresholdI() -> retval\n```","ref":"Evision.HFS.HfsSegment.html#getSegEgbThresholdI/1"},{"type":"function","title":"Evision.HFS.HfsSegment.getSegEgbThresholdII/1","doc":"getSegEgbThresholdII\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetSegEgbThresholdII() -> retval\n```","ref":"Evision.HFS.HfsSegment.html#getSegEgbThresholdII/1"},{"type":"function","title":"Evision.HFS.HfsSegment.getSlicSpixelSize/1","doc":"getSlicSpixelSize\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetSlicSpixelSize() -> retval\n```","ref":"Evision.HFS.HfsSegment.html#getSlicSpixelSize/1"},{"type":"function","title":"Evision.HFS.HfsSegment.getSpatialWeight/1","doc":"getSpatialWeight\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetSpatialWeight() -> retval\n```","ref":"Evision.HFS.HfsSegment.html#getSpatialWeight/1"},{"type":"function","title":"Evision.HFS.HfsSegment.performSegmentCpu/1","doc":"","ref":"Evision.HFS.HfsSegment.html#performSegmentCpu/1"},{"type":"function","title":"Evision.HFS.HfsSegment.performSegmentCpu/2","doc":"do segmentation with cpu\nThis method is only implemented for reference.\nIt is highly NOT recommanded to use it.\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **ifDraw**: `bool`.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nperformSegmentCpu(src[, ifDraw]) -> retval\n```","ref":"Evision.HFS.HfsSegment.html#performSegmentCpu/2"},{"type":"function","title":"Evision.HFS.HfsSegment.performSegmentCpu/3","doc":"do segmentation with cpu\nThis method is only implemented for reference.\nIt is highly NOT recommanded to use it.\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **ifDraw**: `bool`.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nperformSegmentCpu(src[, ifDraw]) -> retval\n```","ref":"Evision.HFS.HfsSegment.html#performSegmentCpu/3"},{"type":"function","title":"Evision.HFS.HfsSegment.performSegmentGpu/1","doc":"","ref":"Evision.HFS.HfsSegment.html#performSegmentGpu/1"},{"type":"function","title":"Evision.HFS.HfsSegment.performSegmentGpu/2","doc":"do segmentation gpu\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n- **src**: `Evision.Mat`.\n\n  the input image\n\n##### Keyword Arguments\n- **ifDraw**: `bool`.\n\n  if draw the image in the returned Mat. if this parameter is false,\n  then the content of the returned Mat is a matrix of index, describing the region\n  each pixel belongs to. And it's data type is CV_16U. If this parameter is true,\n  then the returned Mat is a segmented picture, and color of each region is the\n  average color of all pixels in that region. And it's data type is the same as\n  the input image\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nperformSegmentGpu(src[, ifDraw]) -> retval\n```","ref":"Evision.HFS.HfsSegment.html#performSegmentGpu/2"},{"type":"function","title":"Evision.HFS.HfsSegment.performSegmentGpu/3","doc":"do segmentation gpu\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n- **src**: `Evision.Mat`.\n\n  the input image\n\n##### Keyword Arguments\n- **ifDraw**: `bool`.\n\n  if draw the image in the returned Mat. if this parameter is false,\n  then the content of the returned Mat is a matrix of index, describing the region\n  each pixel belongs to. And it's data type is CV_16U. If this parameter is true,\n  then the returned Mat is a segmented picture, and color of each region is the\n  average color of all pixels in that region. And it's data type is the same as\n  the input image\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nperformSegmentGpu(src[, ifDraw]) -> retval\n```","ref":"Evision.HFS.HfsSegment.html#performSegmentGpu/3"},{"type":"function","title":"Evision.HFS.HfsSegment.read/1","doc":"","ref":"Evision.HFS.HfsSegment.html#read/1"},{"type":"function","title":"Evision.HFS.HfsSegment.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.HFS.HfsSegment.html#read/2"},{"type":"function","title":"Evision.HFS.HfsSegment.save/1","doc":"","ref":"Evision.HFS.HfsSegment.html#save/1"},{"type":"function","title":"Evision.HFS.HfsSegment.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.HFS.HfsSegment.html#save/2"},{"type":"function","title":"Evision.HFS.HfsSegment.setMinRegionSizeI/1","doc":"","ref":"Evision.HFS.HfsSegment.html#setMinRegionSizeI/1"},{"type":"function","title":"Evision.HFS.HfsSegment.setMinRegionSizeI/2","doc":": set and get the parameter minRegionSizeI.\nThis parameter is used in the second stage\nmentioned above. After the EGB segmentation, regions that have fewer\npixels then this parameter will be merged into it's adjacent region.\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n- **n**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMinRegionSizeI(n) -> None\n```","ref":"Evision.HFS.HfsSegment.html#setMinRegionSizeI/2"},{"type":"function","title":"Evision.HFS.HfsSegment.setMinRegionSizeII/1","doc":"","ref":"Evision.HFS.HfsSegment.html#setMinRegionSizeII/1"},{"type":"function","title":"Evision.HFS.HfsSegment.setMinRegionSizeII/2","doc":": set and get the parameter minRegionSizeII.\nThis parameter is used in the third stage\nmentioned above. It serves the same purpose as minRegionSizeI\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n- **n**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMinRegionSizeII(n) -> None\n```","ref":"Evision.HFS.HfsSegment.html#setMinRegionSizeII/2"},{"type":"function","title":"Evision.HFS.HfsSegment.setNumSlicIter/1","doc":"","ref":"Evision.HFS.HfsSegment.html#setNumSlicIter/1"},{"type":"function","title":"Evision.HFS.HfsSegment.setNumSlicIter/2","doc":": set and get the parameter numSlicIter.\nThis parameter is used in the first stage. It\ndescribes how many iteration to perform when executing SLIC.\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n- **n**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNumSlicIter(n) -> None\n```","ref":"Evision.HFS.HfsSegment.html#setNumSlicIter/2"},{"type":"function","title":"Evision.HFS.HfsSegment.setSegEgbThresholdI/1","doc":"","ref":"Evision.HFS.HfsSegment.html#setSegEgbThresholdI/1"},{"type":"function","title":"Evision.HFS.HfsSegment.setSegEgbThresholdI/2","doc":": set and get the parameter segEgbThresholdI.\nThis parameter is used in the second stage mentioned above.\nIt is a constant used to threshold weights of the edge when merging\nadjacent nodes when applying EGB algorithm. The segmentation result\ntends to have more regions remained if this value is large and vice versa.\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n- **c**: `float`\n\nPython prototype (for reference only):\n```python3\nsetSegEgbThresholdI(c) -> None\n```","ref":"Evision.HFS.HfsSegment.html#setSegEgbThresholdI/2"},{"type":"function","title":"Evision.HFS.HfsSegment.setSegEgbThresholdII/1","doc":"","ref":"Evision.HFS.HfsSegment.html#setSegEgbThresholdII/1"},{"type":"function","title":"Evision.HFS.HfsSegment.setSegEgbThresholdII/2","doc":": set and get the parameter segEgbThresholdII.\nThis parameter is used in the third stage\nmentioned above. It serves the same purpose as segEgbThresholdI.\nThe segmentation result tends to have more regions remained if\nthis value is large and vice versa.\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n- **c**: `float`\n\nPython prototype (for reference only):\n```python3\nsetSegEgbThresholdII(c) -> None\n```","ref":"Evision.HFS.HfsSegment.html#setSegEgbThresholdII/2"},{"type":"function","title":"Evision.HFS.HfsSegment.setSlicSpixelSize/1","doc":"","ref":"Evision.HFS.HfsSegment.html#setSlicSpixelSize/1"},{"type":"function","title":"Evision.HFS.HfsSegment.setSlicSpixelSize/2","doc":": set and get the parameter slicSpixelSize.\nThis parameter is used in the first stage mentioned\nabove(the SLIC stage). It describes the size of each\nsuperpixel when initializing SLIC. Every superpixel\napproximately has \\f$slicSpixelSize \\times slicSpixelSize\\f$\npixels in the beginning.\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n- **n**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetSlicSpixelSize(n) -> None\n```","ref":"Evision.HFS.HfsSegment.html#setSlicSpixelSize/2"},{"type":"function","title":"Evision.HFS.HfsSegment.setSpatialWeight/1","doc":"","ref":"Evision.HFS.HfsSegment.html#setSpatialWeight/1"},{"type":"function","title":"Evision.HFS.HfsSegment.setSpatialWeight/2","doc":": set and get the parameter spatialWeight.\nThis parameter is used in the first stage\nmentioned above(the SLIC stage). It describes how important is the role\nof position when calculating the distance between each pixel and it's\ncenter. The exact formula to calculate the distance is\n\\f$colorDistance + spatialWeight \\times spatialDistance\\f$.\nThe segmentation result tends to have more local consistency\nif this value is larger.\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n- **w**: `float`\n\nPython prototype (for reference only):\n```python3\nsetSpatialWeight(w) -> None\n```","ref":"Evision.HFS.HfsSegment.html#setSpatialWeight/2"},{"type":"function","title":"Evision.HFS.HfsSegment.write/1","doc":"","ref":"Evision.HFS.HfsSegment.html#write/1"},{"type":"function","title":"Evision.HFS.HfsSegment.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.HFS.HfsSegment.html#write/2"},{"type":"function","title":"Evision.HFS.HfsSegment.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.HFS.HfsSegment.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.HFS.HfsSegment.html#write/3"},{"type":"type","title":"Evision.HFS.HfsSegment.t/0","doc":"Type that represents an `HFS.HfsSegment` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.HFS.HfsSegment.html#t:t/0"},{"type":"module","title":"Evision.HOGDescriptor","doc":"","ref":"Evision.HOGDescriptor.html"},{"type":"function","title":"Evision.HOGDescriptor.checkDetectorSize/1","doc":"Checks if detector size equal to descriptor size.\n\n##### Positional Arguments\n- **self**: `Evision.HOGDescriptor.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ncheckDetectorSize() -> retval\n```","ref":"Evision.HOGDescriptor.html#checkDetectorSize/1"},{"type":"function","title":"Evision.HOGDescriptor.compute/1","doc":"","ref":"Evision.HOGDescriptor.html#compute/1"},{"type":"function","title":"Evision.HOGDescriptor.compute/2","doc":"Computes HOG descriptors of given image.\n\n##### Positional Arguments\n- **self**: `Evision.HOGDescriptor.t()`\n- **img**: `Evision.Mat`.\n\n  Matrix of the type CV_8U containing an image where HOG features will be calculated.\n\n##### Keyword Arguments\n- **winStride**: `Size`.\n\n  Window stride. It must be a multiple of block stride.\n\n- **padding**: `Size`.\n\n  Padding\n\n- **locations**: `[Point]`.\n\n  Vector of Point\n\n##### Return\n- **descriptors**: `[float]`.\n\n  Matrix of the type CV_32F\n\nPython prototype (for reference only):\n```python3\ncompute(img[, winStride[, padding[, locations]]]) -> descriptors\n```","ref":"Evision.HOGDescriptor.html#compute/2"},{"type":"function","title":"Evision.HOGDescriptor.compute/3","doc":"Computes HOG descriptors of given image.\n\n##### Positional Arguments\n- **self**: `Evision.HOGDescriptor.t()`\n- **img**: `Evision.Mat`.\n\n  Matrix of the type CV_8U containing an image where HOG features will be calculated.\n\n##### Keyword Arguments\n- **winStride**: `Size`.\n\n  Window stride. It must be a multiple of block stride.\n\n- **padding**: `Size`.\n\n  Padding\n\n- **locations**: `[Point]`.\n\n  Vector of Point\n\n##### Return\n- **descriptors**: `[float]`.\n\n  Matrix of the type CV_32F\n\nPython prototype (for reference only):\n```python3\ncompute(img[, winStride[, padding[, locations]]]) -> descriptors\n```","ref":"Evision.HOGDescriptor.html#compute/3"},{"type":"function","title":"Evision.HOGDescriptor.computeGradient/1","doc":"","ref":"Evision.HOGDescriptor.html#computeGradient/1"},{"type":"function","title":"Evision.HOGDescriptor.computeGradient/4","doc":"Computes gradients and quantized gradient orientations.\n\n##### Positional Arguments\n- **self**: `Evision.HOGDescriptor.t()`\n- **img**: `Evision.Mat`.\n\n  Matrix contains the image to be computed\n\n##### Keyword Arguments\n- **paddingTL**: `Size`.\n\n  Padding from top-left\n\n- **paddingBR**: `Size`.\n\n  Padding from bottom-right\n\n##### Return\n- **grad**: `Evision.Mat.t()`.\n\n  Matrix of type CV_32FC2 contains computed gradients\n\n- **angleOfs**: `Evision.Mat.t()`.\n\n  Matrix of type CV_8UC2 contains quantized gradient orientations\n\nPython prototype (for reference only):\n```python3\ncomputeGradient(img, grad, angleOfs[, paddingTL[, paddingBR]]) -> grad, angleOfs\n```","ref":"Evision.HOGDescriptor.html#computeGradient/4"},{"type":"function","title":"Evision.HOGDescriptor.computeGradient/5","doc":"Computes gradients and quantized gradient orientations.\n\n##### Positional Arguments\n- **self**: `Evision.HOGDescriptor.t()`\n- **img**: `Evision.Mat`.\n\n  Matrix contains the image to be computed\n\n##### Keyword Arguments\n- **paddingTL**: `Size`.\n\n  Padding from top-left\n\n- **paddingBR**: `Size`.\n\n  Padding from bottom-right\n\n##### Return\n- **grad**: `Evision.Mat.t()`.\n\n  Matrix of type CV_32FC2 contains computed gradients\n\n- **angleOfs**: `Evision.Mat.t()`.\n\n  Matrix of type CV_8UC2 contains quantized gradient orientations\n\nPython prototype (for reference only):\n```python3\ncomputeGradient(img, grad, angleOfs[, paddingTL[, paddingBR]]) -> grad, angleOfs\n```","ref":"Evision.HOGDescriptor.html#computeGradient/5"},{"type":"function","title":"Evision.HOGDescriptor.cv_DEFAULT_NLEVELS/0","doc":"","ref":"Evision.HOGDescriptor.html#cv_DEFAULT_NLEVELS/0"},{"type":"function","title":"Evision.HOGDescriptor.detect/1","doc":"","ref":"Evision.HOGDescriptor.html#detect/1"},{"type":"function","title":"Evision.HOGDescriptor.detect/2","doc":"Performs object detection without a multi-scale window.\n\n##### Positional Arguments\n- **self**: `Evision.HOGDescriptor.t()`\n- **img**: `Evision.Mat`.\n\n  Matrix of the type CV_8U or CV_8UC3 containing an image where objects are detected.\n\n##### Keyword Arguments\n- **hitThreshold**: `double`.\n\n  Threshold for the distance between features and SVM classifying plane.\n  Usually it is 0 and should be specified in the detector coefficients (as the last free coefficient).\n  But if the free coefficient is omitted (which is allowed), you can specify it manually here.\n\n- **winStride**: `Size`.\n\n  Window stride. It must be a multiple of block stride.\n\n- **padding**: `Size`.\n\n  Padding\n\n- **searchLocations**: `[Point]`.\n\n  Vector of Point includes set of requested locations to be evaluated.\n\n##### Return\n- **foundLocations**: `[Point]`.\n\n  Vector of point where each point contains left-top corner point of detected object boundaries.\n\n- **weights**: `[double]`.\n\n  Vector that will contain confidence values for each detected object.\n\nPython prototype (for reference only):\n```python3\ndetect(img[, hitThreshold[, winStride[, padding[, searchLocations]]]]) -> foundLocations, weights\n```","ref":"Evision.HOGDescriptor.html#detect/2"},{"type":"function","title":"Evision.HOGDescriptor.detect/3","doc":"Performs object detection without a multi-scale window.\n\n##### Positional Arguments\n- **self**: `Evision.HOGDescriptor.t()`\n- **img**: `Evision.Mat`.\n\n  Matrix of the type CV_8U or CV_8UC3 containing an image where objects are detected.\n\n##### Keyword Arguments\n- **hitThreshold**: `double`.\n\n  Threshold for the distance between features and SVM classifying plane.\n  Usually it is 0 and should be specified in the detector coefficients (as the last free coefficient).\n  But if the free coefficient is omitted (which is allowed), you can specify it manually here.\n\n- **winStride**: `Size`.\n\n  Window stride. It must be a multiple of block stride.\n\n- **padding**: `Size`.\n\n  Padding\n\n- **searchLocations**: `[Point]`.\n\n  Vector of Point includes set of requested locations to be evaluated.\n\n##### Return\n- **foundLocations**: `[Point]`.\n\n  Vector of point where each point contains left-top corner point of detected object boundaries.\n\n- **weights**: `[double]`.\n\n  Vector that will contain confidence values for each detected object.\n\nPython prototype (for reference only):\n```python3\ndetect(img[, hitThreshold[, winStride[, padding[, searchLocations]]]]) -> foundLocations, weights\n```","ref":"Evision.HOGDescriptor.html#detect/3"},{"type":"function","title":"Evision.HOGDescriptor.detectMultiScale/1","doc":"","ref":"Evision.HOGDescriptor.html#detectMultiScale/1"},{"type":"function","title":"Evision.HOGDescriptor.detectMultiScale/2","doc":"Detects objects of different sizes in the input image. The detected objects are returned as a list\nof rectangles.\n\n##### Positional Arguments\n- **self**: `Evision.HOGDescriptor.t()`\n- **img**: `Evision.Mat`.\n\n  Matrix of the type CV_8U or CV_8UC3 containing an image where objects are detected.\n\n##### Keyword Arguments\n- **hitThreshold**: `double`.\n\n  Threshold for the distance between features and SVM classifying plane.\n  Usually it is 0 and should be specified in the detector coefficients (as the last free coefficient).\n  But if the free coefficient is omitted (which is allowed), you can specify it manually here.\n\n- **winStride**: `Size`.\n\n  Window stride. It must be a multiple of block stride.\n\n- **padding**: `Size`.\n\n  Padding\n\n- **scale**: `double`.\n\n  Coefficient of the detection window increase.\n\n- **groupThreshold**: `double`.\n\n  Coefficient to regulate the similarity threshold. When detected, some objects can be covered\n  by many rectangles. 0 means not to perform grouping.\n\n- **useMeanshiftGrouping**: `bool`.\n\n  indicates grouping algorithm\n\n##### Return\n- **foundLocations**: `[Rect]`.\n\n  Vector of rectangles where each rectangle contains the detected object.\n\n- **foundWeights**: `[double]`.\n\n  Vector that will contain confidence values for each detected object.\n\nPython prototype (for reference only):\n```python3\ndetectMultiScale(img[, hitThreshold[, winStride[, padding[, scale[, groupThreshold[, useMeanshiftGrouping]]]]]]) -> foundLocations, foundWeights\n```","ref":"Evision.HOGDescriptor.html#detectMultiScale/2"},{"type":"function","title":"Evision.HOGDescriptor.detectMultiScale/3","doc":"Detects objects of different sizes in the input image. The detected objects are returned as a list\nof rectangles.\n\n##### Positional Arguments\n- **self**: `Evision.HOGDescriptor.t()`\n- **img**: `Evision.Mat`.\n\n  Matrix of the type CV_8U or CV_8UC3 containing an image where objects are detected.\n\n##### Keyword Arguments\n- **hitThreshold**: `double`.\n\n  Threshold for the distance between features and SVM classifying plane.\n  Usually it is 0 and should be specified in the detector coefficients (as the last free coefficient).\n  But if the free coefficient is omitted (which is allowed), you can specify it manually here.\n\n- **winStride**: `Size`.\n\n  Window stride. It must be a multiple of block stride.\n\n- **padding**: `Size`.\n\n  Padding\n\n- **scale**: `double`.\n\n  Coefficient of the detection window increase.\n\n- **groupThreshold**: `double`.\n\n  Coefficient to regulate the similarity threshold. When detected, some objects can be covered\n  by many rectangles. 0 means not to perform grouping.\n\n- **useMeanshiftGrouping**: `bool`.\n\n  indicates grouping algorithm\n\n##### Return\n- **foundLocations**: `[Rect]`.\n\n  Vector of rectangles where each rectangle contains the detected object.\n\n- **foundWeights**: `[double]`.\n\n  Vector that will contain confidence values for each detected object.\n\nPython prototype (for reference only):\n```python3\ndetectMultiScale(img[, hitThreshold[, winStride[, padding[, scale[, groupThreshold[, useMeanshiftGrouping]]]]]]) -> foundLocations, foundWeights\n```","ref":"Evision.HOGDescriptor.html#detectMultiScale/3"},{"type":"function","title":"Evision.HOGDescriptor.get_blockSize/1","doc":"","ref":"Evision.HOGDescriptor.html#get_blockSize/1"},{"type":"function","title":"Evision.HOGDescriptor.get_blockStride/1","doc":"","ref":"Evision.HOGDescriptor.html#get_blockStride/1"},{"type":"function","title":"Evision.HOGDescriptor.get_cellSize/1","doc":"","ref":"Evision.HOGDescriptor.html#get_cellSize/1"},{"type":"function","title":"Evision.HOGDescriptor.get_derivAperture/1","doc":"","ref":"Evision.HOGDescriptor.html#get_derivAperture/1"},{"type":"function","title":"Evision.HOGDescriptor.get_gammaCorrection/1","doc":"","ref":"Evision.HOGDescriptor.html#get_gammaCorrection/1"},{"type":"function","title":"Evision.HOGDescriptor.get_histogramNormType/1","doc":"","ref":"Evision.HOGDescriptor.html#get_histogramNormType/1"},{"type":"function","title":"Evision.HOGDescriptor.get_L2HysThreshold/1","doc":"","ref":"Evision.HOGDescriptor.html#get_L2HysThreshold/1"},{"type":"function","title":"Evision.HOGDescriptor.get_nbins/1","doc":"","ref":"Evision.HOGDescriptor.html#get_nbins/1"},{"type":"function","title":"Evision.HOGDescriptor.get_nlevels/1","doc":"","ref":"Evision.HOGDescriptor.html#get_nlevels/1"},{"type":"function","title":"Evision.HOGDescriptor.get_signedGradient/1","doc":"","ref":"Evision.HOGDescriptor.html#get_signedGradient/1"},{"type":"function","title":"Evision.HOGDescriptor.get_svmDetector/1","doc":"","ref":"Evision.HOGDescriptor.html#get_svmDetector/1"},{"type":"function","title":"Evision.HOGDescriptor.get_winSigma/1","doc":"","ref":"Evision.HOGDescriptor.html#get_winSigma/1"},{"type":"function","title":"Evision.HOGDescriptor.get_winSize/1","doc":"","ref":"Evision.HOGDescriptor.html#get_winSize/1"},{"type":"function","title":"Evision.HOGDescriptor.getDaimlerPeopleDetector/0","doc":"Returns coefficients of the classifier trained for people detection (for 48x96 windows).\n##### Return\n- **retval**: `[float]`\n\nPython prototype (for reference only):\n```python3\ngetDaimlerPeopleDetector() -> retval\n```","ref":"Evision.HOGDescriptor.html#getDaimlerPeopleDetector/0"},{"type":"function","title":"Evision.HOGDescriptor.getDaimlerPeopleDetector/1","doc":"","ref":"Evision.HOGDescriptor.html#getDaimlerPeopleDetector/1"},{"type":"function","title":"Evision.HOGDescriptor.getDefaultPeopleDetector/0","doc":"Returns coefficients of the classifier trained for people detection (for 64x128 windows).\n##### Return\n- **retval**: `[float]`\n\nPython prototype (for reference only):\n```python3\ngetDefaultPeopleDetector() -> retval\n```","ref":"Evision.HOGDescriptor.html#getDefaultPeopleDetector/0"},{"type":"function","title":"Evision.HOGDescriptor.getDefaultPeopleDetector/1","doc":"","ref":"Evision.HOGDescriptor.html#getDefaultPeopleDetector/1"},{"type":"function","title":"Evision.HOGDescriptor.getDescriptorSize/1","doc":"Returns the number of coefficients required for the classification.\n\n##### Positional Arguments\n- **self**: `Evision.HOGDescriptor.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\ngetDescriptorSize() -> retval\n```","ref":"Evision.HOGDescriptor.html#getDescriptorSize/1"},{"type":"function","title":"Evision.HOGDescriptor.getWinSigma/1","doc":"Returns winSigma value\n\n##### Positional Arguments\n- **self**: `Evision.HOGDescriptor.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetWinSigma() -> retval\n```","ref":"Evision.HOGDescriptor.html#getWinSigma/1"},{"type":"function","title":"Evision.HOGDescriptor.hogDescriptor/0","doc":"Creates the HOG descriptor and detector with default parameters.\n##### Return\n- **self**: `Evision.HOGDescriptor.t()`\n\naqual to HOGDescriptor(Size(64,128), Size(16,16), Size(8,8), Size(8,8), 9 )\n\nPython prototype (for reference only):\n```python3\nHOGDescriptor() ->  \n```","ref":"Evision.HOGDescriptor.html#hogDescriptor/0"},{"type":"function","title":"Evision.HOGDescriptor.hogDescriptor/1","doc":"HOGDescriptor\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  The file name containing HOGDescriptor properties and coefficients for the linear SVM classifier.\n\n##### Return\n- **self**: `Evision.HOGDescriptor.t()`\n\nHas overloading in C++\n\nCreates the HOG descriptor and detector and loads HOGDescriptor parameters and coefficients for the linear SVM classifier from a file.\n\nPython prototype (for reference only):\n```python3\nHOGDescriptor(filename) ->  \n```","ref":"Evision.HOGDescriptor.html#hogDescriptor/1"},{"type":"function","title":"Evision.HOGDescriptor.hogDescriptor/5","doc":"HOGDescriptor\n\n##### Positional Arguments\n- **winSize**: `Size`.\n\n  sets winSize with given value.\n\n- **blockSize**: `Size`.\n\n  sets blockSize with given value.\n\n- **blockStride**: `Size`.\n\n  sets blockStride with given value.\n\n- **cellSize**: `Size`.\n\n  sets cellSize with given value.\n\n- **nbins**: `integer()`.\n\n  sets nbins with given value.\n\n##### Keyword Arguments\n- **derivAperture**: `integer()`.\n\n  sets derivAperture with given value.\n\n- **winSigma**: `double`.\n\n  sets winSigma with given value.\n\n- **histogramNormType**: `HOGDescriptor_HistogramNormType`.\n\n  sets histogramNormType with given value.\n\n- **l2HysThreshold**: `double`.\n\n  sets L2HysThreshold with given value.\n\n- **gammaCorrection**: `bool`.\n\n  sets gammaCorrection with given value.\n\n- **nlevels**: `integer()`.\n\n  sets nlevels with given value.\n\n- **signedGradient**: `bool`.\n\n  sets signedGradient with given value.\n\n##### Return\n- **self**: `Evision.HOGDescriptor.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nHOGDescriptor(_winSize, _blockSize, _blockStride, _cellSize, _nbins[, _derivAperture[, _winSigma[, _histogramNormType[, _L2HysThreshold[, _gammaCorrection[, _nlevels[, _signedGradient]]]]]]]) ->  \n```","ref":"Evision.HOGDescriptor.html#hogDescriptor/5"},{"type":"function","title":"Evision.HOGDescriptor.hogDescriptor/6","doc":"HOGDescriptor\n\n##### Positional Arguments\n- **winSize**: `Size`.\n\n  sets winSize with given value.\n\n- **blockSize**: `Size`.\n\n  sets blockSize with given value.\n\n- **blockStride**: `Size`.\n\n  sets blockStride with given value.\n\n- **cellSize**: `Size`.\n\n  sets cellSize with given value.\n\n- **nbins**: `integer()`.\n\n  sets nbins with given value.\n\n##### Keyword Arguments\n- **derivAperture**: `integer()`.\n\n  sets derivAperture with given value.\n\n- **winSigma**: `double`.\n\n  sets winSigma with given value.\n\n- **histogramNormType**: `HOGDescriptor_HistogramNormType`.\n\n  sets histogramNormType with given value.\n\n- **l2HysThreshold**: `double`.\n\n  sets L2HysThreshold with given value.\n\n- **gammaCorrection**: `bool`.\n\n  sets gammaCorrection with given value.\n\n- **nlevels**: `integer()`.\n\n  sets nlevels with given value.\n\n- **signedGradient**: `bool`.\n\n  sets signedGradient with given value.\n\n##### Return\n- **self**: `Evision.HOGDescriptor.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nHOGDescriptor(_winSize, _blockSize, _blockStride, _cellSize, _nbins[, _derivAperture[, _winSigma[, _histogramNormType[, _L2HysThreshold[, _gammaCorrection[, _nlevels[, _signedGradient]]]]]]]) ->  \n```","ref":"Evision.HOGDescriptor.html#hogDescriptor/6"},{"type":"function","title":"Evision.HOGDescriptor.load/1","doc":"","ref":"Evision.HOGDescriptor.html#load/1"},{"type":"function","title":"Evision.HOGDescriptor.load/2","doc":"loads HOGDescriptor parameters and coefficients for the linear SVM classifier from a file\n\n##### Positional Arguments\n- **self**: `Evision.HOGDescriptor.t()`\n- **filename**: `String`.\n\n  Name of the file to read.\n\n##### Keyword Arguments\n- **objname**: `String`.\n\n  The optional name of the node to read (if empty, the first top-level node will be used).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nload(filename[, objname]) -> retval\n```","ref":"Evision.HOGDescriptor.html#load/2"},{"type":"function","title":"Evision.HOGDescriptor.load/3","doc":"loads HOGDescriptor parameters and coefficients for the linear SVM classifier from a file\n\n##### Positional Arguments\n- **self**: `Evision.HOGDescriptor.t()`\n- **filename**: `String`.\n\n  Name of the file to read.\n\n##### Keyword Arguments\n- **objname**: `String`.\n\n  The optional name of the node to read (if empty, the first top-level node will be used).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nload(filename[, objname]) -> retval\n```","ref":"Evision.HOGDescriptor.html#load/3"},{"type":"function","title":"Evision.HOGDescriptor.save/1","doc":"","ref":"Evision.HOGDescriptor.html#save/1"},{"type":"function","title":"Evision.HOGDescriptor.save/2","doc":"saves HOGDescriptor parameters and coefficients for the linear SVM classifier to a file\n\n##### Positional Arguments\n- **self**: `Evision.HOGDescriptor.t()`\n- **filename**: `String`.\n\n  File name\n\n##### Keyword Arguments\n- **objname**: `String`.\n\n  Object name\n\nPython prototype (for reference only):\n```python3\nsave(filename[, objname]) -> None\n```","ref":"Evision.HOGDescriptor.html#save/2"},{"type":"function","title":"Evision.HOGDescriptor.save/3","doc":"saves HOGDescriptor parameters and coefficients for the linear SVM classifier to a file\n\n##### Positional Arguments\n- **self**: `Evision.HOGDescriptor.t()`\n- **filename**: `String`.\n\n  File name\n\n##### Keyword Arguments\n- **objname**: `String`.\n\n  Object name\n\nPython prototype (for reference only):\n```python3\nsave(filename[, objname]) -> None\n```","ref":"Evision.HOGDescriptor.html#save/3"},{"type":"function","title":"Evision.HOGDescriptor.setSVMDetector/1","doc":"","ref":"Evision.HOGDescriptor.html#setSVMDetector/1"},{"type":"function","title":"Evision.HOGDescriptor.setSVMDetector/2","doc":"Sets coefficients for the linear SVM classifier.\n\n##### Positional Arguments\n- **self**: `Evision.HOGDescriptor.t()`\n- **svmdetector**: `Evision.Mat`.\n\n  coefficients for the linear SVM classifier.\n\nPython prototype (for reference only):\n```python3\nsetSVMDetector(svmdetector) -> None\n```","ref":"Evision.HOGDescriptor.html#setSVMDetector/2"},{"type":"type","title":"Evision.HOGDescriptor.enum/0","doc":"","ref":"Evision.HOGDescriptor.html#t:enum/0"},{"type":"type","title":"Evision.HOGDescriptor.t/0","doc":"Type that represents an `HOGDescriptor` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.HOGDescriptor.html#t:t/0"},{"type":"module","title":"Evision.HOGDescriptor.DescriptorStorageFormat","doc":"","ref":"Evision.HOGDescriptor.DescriptorStorageFormat.html"},{"type":"function","title":"Evision.HOGDescriptor.DescriptorStorageFormat.cv_DESCR_FORMAT_COL_BY_COL/0","doc":"","ref":"Evision.HOGDescriptor.DescriptorStorageFormat.html#cv_DESCR_FORMAT_COL_BY_COL/0"},{"type":"function","title":"Evision.HOGDescriptor.DescriptorStorageFormat.cv_DESCR_FORMAT_ROW_BY_ROW/0","doc":"","ref":"Evision.HOGDescriptor.DescriptorStorageFormat.html#cv_DESCR_FORMAT_ROW_BY_ROW/0"},{"type":"type","title":"Evision.HOGDescriptor.DescriptorStorageFormat.enum/0","doc":"","ref":"Evision.HOGDescriptor.DescriptorStorageFormat.html#t:enum/0"},{"type":"module","title":"Evision.HOGDescriptor.HistogramNormType","doc":"","ref":"Evision.HOGDescriptor.HistogramNormType.html"},{"type":"function","title":"Evision.HOGDescriptor.HistogramNormType.cv_L2Hys/0","doc":"","ref":"Evision.HOGDescriptor.HistogramNormType.html#cv_L2Hys/0"},{"type":"type","title":"Evision.HOGDescriptor.HistogramNormType.enum/0","doc":"","ref":"Evision.HOGDescriptor.HistogramNormType.html#t:enum/0"},{"type":"module","title":"Evision.HandEyeCalibrationMethod","doc":"","ref":"Evision.HandEyeCalibrationMethod.html"},{"type":"function","title":"Evision.HandEyeCalibrationMethod.cv_CALIB_HAND_EYE_ANDREFF/0","doc":"","ref":"Evision.HandEyeCalibrationMethod.html#cv_CALIB_HAND_EYE_ANDREFF/0"},{"type":"function","title":"Evision.HandEyeCalibrationMethod.cv_CALIB_HAND_EYE_DANIILIDIS/0","doc":"","ref":"Evision.HandEyeCalibrationMethod.html#cv_CALIB_HAND_EYE_DANIILIDIS/0"},{"type":"function","title":"Evision.HandEyeCalibrationMethod.cv_CALIB_HAND_EYE_HORAUD/0","doc":"","ref":"Evision.HandEyeCalibrationMethod.html#cv_CALIB_HAND_EYE_HORAUD/0"},{"type":"function","title":"Evision.HandEyeCalibrationMethod.cv_CALIB_HAND_EYE_PARK/0","doc":"","ref":"Evision.HandEyeCalibrationMethod.html#cv_CALIB_HAND_EYE_PARK/0"},{"type":"function","title":"Evision.HandEyeCalibrationMethod.cv_CALIB_HAND_EYE_TSAI/0","doc":"","ref":"Evision.HandEyeCalibrationMethod.html#cv_CALIB_HAND_EYE_TSAI/0"},{"type":"type","title":"Evision.HandEyeCalibrationMethod.enum/0","doc":"","ref":"Evision.HandEyeCalibrationMethod.html#t:enum/0"},{"type":"module","title":"Evision.HausdorffDistanceExtractor","doc":"","ref":"Evision.HausdorffDistanceExtractor.html"},{"type":"function","title":"Evision.HausdorffDistanceExtractor.getDistanceFlag/1","doc":"getDistanceFlag\n\n##### Positional Arguments\n- **self**: `Evision.HausdorffDistanceExtractor.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetDistanceFlag() -> retval\n```","ref":"Evision.HausdorffDistanceExtractor.html#getDistanceFlag/1"},{"type":"function","title":"Evision.HausdorffDistanceExtractor.getRankProportion/1","doc":"getRankProportion\n\n##### Positional Arguments\n- **self**: `Evision.HausdorffDistanceExtractor.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetRankProportion() -> retval\n```","ref":"Evision.HausdorffDistanceExtractor.html#getRankProportion/1"},{"type":"function","title":"Evision.HausdorffDistanceExtractor.setDistanceFlag/1","doc":"","ref":"Evision.HausdorffDistanceExtractor.html#setDistanceFlag/1"},{"type":"function","title":"Evision.HausdorffDistanceExtractor.setDistanceFlag/2","doc":"Set the norm used to compute the Hausdorff value between two shapes. It can be L1 or L2 norm.\n\n##### Positional Arguments\n- **self**: `Evision.HausdorffDistanceExtractor.t()`\n- **distanceFlag**: `integer()`.\n\n  Flag indicating which norm is used to compute the Hausdorff distance\n  (NORM_L1, NORM_L2).\n\nPython prototype (for reference only):\n```python3\nsetDistanceFlag(distanceFlag) -> None\n```","ref":"Evision.HausdorffDistanceExtractor.html#setDistanceFlag/2"},{"type":"function","title":"Evision.HausdorffDistanceExtractor.setRankProportion/1","doc":"","ref":"Evision.HausdorffDistanceExtractor.html#setRankProportion/1"},{"type":"function","title":"Evision.HausdorffDistanceExtractor.setRankProportion/2","doc":"This method sets the rank proportion (or fractional value) that establish the Kth ranked value of\nthe partial Hausdorff distance. Experimentally had been shown that 0.6 is a good value to compare\nshapes.\n\n##### Positional Arguments\n- **self**: `Evision.HausdorffDistanceExtractor.t()`\n- **rankProportion**: `float`.\n\n  fractional value (between 0 and 1).\n\nPython prototype (for reference only):\n```python3\nsetRankProportion(rankProportion) -> None\n```","ref":"Evision.HausdorffDistanceExtractor.html#setRankProportion/2"},{"type":"type","title":"Evision.HausdorffDistanceExtractor.t/0","doc":"Type that represents an `HausdorffDistanceExtractor` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.HausdorffDistanceExtractor.html#t:t/0"},{"type":"module","title":"Evision.HersheyFonts","doc":"","ref":"Evision.HersheyFonts.html"},{"type":"function","title":"Evision.HersheyFonts.cv_FONT_HERSHEY_COMPLEX/0","doc":"","ref":"Evision.HersheyFonts.html#cv_FONT_HERSHEY_COMPLEX/0"},{"type":"function","title":"Evision.HersheyFonts.cv_FONT_HERSHEY_COMPLEX_SMALL/0","doc":"","ref":"Evision.HersheyFonts.html#cv_FONT_HERSHEY_COMPLEX_SMALL/0"},{"type":"function","title":"Evision.HersheyFonts.cv_FONT_HERSHEY_DUPLEX/0","doc":"","ref":"Evision.HersheyFonts.html#cv_FONT_HERSHEY_DUPLEX/0"},{"type":"function","title":"Evision.HersheyFonts.cv_FONT_HERSHEY_PLAIN/0","doc":"","ref":"Evision.HersheyFonts.html#cv_FONT_HERSHEY_PLAIN/0"},{"type":"function","title":"Evision.HersheyFonts.cv_FONT_HERSHEY_SCRIPT_COMPLEX/0","doc":"","ref":"Evision.HersheyFonts.html#cv_FONT_HERSHEY_SCRIPT_COMPLEX/0"},{"type":"function","title":"Evision.HersheyFonts.cv_FONT_HERSHEY_SCRIPT_SIMPLEX/0","doc":"","ref":"Evision.HersheyFonts.html#cv_FONT_HERSHEY_SCRIPT_SIMPLEX/0"},{"type":"function","title":"Evision.HersheyFonts.cv_FONT_HERSHEY_SIMPLEX/0","doc":"","ref":"Evision.HersheyFonts.html#cv_FONT_HERSHEY_SIMPLEX/0"},{"type":"function","title":"Evision.HersheyFonts.cv_FONT_HERSHEY_TRIPLEX/0","doc":"","ref":"Evision.HersheyFonts.html#cv_FONT_HERSHEY_TRIPLEX/0"},{"type":"function","title":"Evision.HersheyFonts.cv_FONT_ITALIC/0","doc":"","ref":"Evision.HersheyFonts.html#cv_FONT_ITALIC/0"},{"type":"type","title":"Evision.HersheyFonts.enum/0","doc":"","ref":"Evision.HersheyFonts.html#t:enum/0"},{"type":"module","title":"Evision.HighGui","doc":"High-level Graphical User Interface","ref":"Evision.HighGui.html"},{"type":"function","title":"Evision.HighGui.destroyAllWindows/0","doc":"Close all windows","ref":"Evision.HighGui.html#destroyAllWindows/0"},{"type":"function","title":"Evision.HighGui.destroyWindow/1","doc":"Close a named window\n\n#### Positional Arguments\n\n- **winname**. `String`\n\n  The name of the window.","ref":"Evision.HighGui.html#destroyWindow/1"},{"type":"function","title":"Evision.HighGui.imshow/2","doc":"Show a mat in a named window\n\n#### Positional Arguments\n\n- **winname**. `String`\n\n  The name of the window.\n\n- **mat**. `Evision.Mat`\n\n  The image.\n\n#### Example\n\n```elixir\niex> mat = Evision.imread!(\"example.jpg\")\niex> Evision.imshow(\"OpenCV\", mat)\n# the following line may be necessary on your system\n# will try to improve this later\niex> Evision.waitkey(0)\n```","ref":"Evision.HighGui.html#imshow/2"},{"type":"function","title":"Evision.HighGui.waitKey/1","doc":"Wait for user keyboard event for a `delay` amount of time (ms)\n\n#### Positional Arguments\n\n- **delay**. `int`\n\n  Wait for `delay` ms.","ref":"Evision.HighGui.html#waitKey/1"},{"type":"module","title":"Evision.HistCompMethods","doc":"","ref":"Evision.HistCompMethods.html"},{"type":"function","title":"Evision.HistCompMethods.cv_HISTCMP_BHATTACHARYYA/0","doc":"","ref":"Evision.HistCompMethods.html#cv_HISTCMP_BHATTACHARYYA/0"},{"type":"function","title":"Evision.HistCompMethods.cv_HISTCMP_CHISQR/0","doc":"","ref":"Evision.HistCompMethods.html#cv_HISTCMP_CHISQR/0"},{"type":"function","title":"Evision.HistCompMethods.cv_HISTCMP_CHISQR_ALT/0","doc":"","ref":"Evision.HistCompMethods.html#cv_HISTCMP_CHISQR_ALT/0"},{"type":"function","title":"Evision.HistCompMethods.cv_HISTCMP_CORREL/0","doc":"","ref":"Evision.HistCompMethods.html#cv_HISTCMP_CORREL/0"},{"type":"function","title":"Evision.HistCompMethods.cv_HISTCMP_HELLINGER/0","doc":"","ref":"Evision.HistCompMethods.html#cv_HISTCMP_HELLINGER/0"},{"type":"function","title":"Evision.HistCompMethods.cv_HISTCMP_INTERSECT/0","doc":"","ref":"Evision.HistCompMethods.html#cv_HISTCMP_INTERSECT/0"},{"type":"function","title":"Evision.HistCompMethods.cv_HISTCMP_KL_DIV/0","doc":"","ref":"Evision.HistCompMethods.html#cv_HISTCMP_KL_DIV/0"},{"type":"type","title":"Evision.HistCompMethods.enum/0","doc":"","ref":"Evision.HistCompMethods.html#t:enum/0"},{"type":"module","title":"Evision.HistogramCostExtractor","doc":"","ref":"Evision.HistogramCostExtractor.html"},{"type":"function","title":"Evision.HistogramCostExtractor.buildCostMatrix/1","doc":"","ref":"Evision.HistogramCostExtractor.html#buildCostMatrix/1"},{"type":"function","title":"Evision.HistogramCostExtractor.buildCostMatrix/3","doc":"buildCostMatrix\n\n##### Positional Arguments\n- **self**: `Evision.HistogramCostExtractor.t()`\n- **descriptors1**: `Evision.Mat`\n- **descriptors2**: `Evision.Mat`\n\n##### Return\n- **costMatrix**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nbuildCostMatrix(descriptors1, descriptors2[, costMatrix]) -> costMatrix\n```","ref":"Evision.HistogramCostExtractor.html#buildCostMatrix/3"},{"type":"function","title":"Evision.HistogramCostExtractor.buildCostMatrix/4","doc":"buildCostMatrix\n\n##### Positional Arguments\n- **self**: `Evision.HistogramCostExtractor.t()`\n- **descriptors1**: `Evision.Mat`\n- **descriptors2**: `Evision.Mat`\n\n##### Return\n- **costMatrix**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nbuildCostMatrix(descriptors1, descriptors2[, costMatrix]) -> costMatrix\n```","ref":"Evision.HistogramCostExtractor.html#buildCostMatrix/4"},{"type":"function","title":"Evision.HistogramCostExtractor.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.HistogramCostExtractor.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.HistogramCostExtractor.html#clear/1"},{"type":"function","title":"Evision.HistogramCostExtractor.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.HistogramCostExtractor.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.HistogramCostExtractor.html#empty/1"},{"type":"function","title":"Evision.HistogramCostExtractor.getDefaultCost/1","doc":"getDefaultCost\n\n##### Positional Arguments\n- **self**: `Evision.HistogramCostExtractor.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetDefaultCost() -> retval\n```","ref":"Evision.HistogramCostExtractor.html#getDefaultCost/1"},{"type":"function","title":"Evision.HistogramCostExtractor.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.HistogramCostExtractor.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.HistogramCostExtractor.html#getDefaultName/1"},{"type":"function","title":"Evision.HistogramCostExtractor.getNDummies/1","doc":"getNDummies\n\n##### Positional Arguments\n- **self**: `Evision.HistogramCostExtractor.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNDummies() -> retval\n```","ref":"Evision.HistogramCostExtractor.html#getNDummies/1"},{"type":"function","title":"Evision.HistogramCostExtractor.read/1","doc":"","ref":"Evision.HistogramCostExtractor.html#read/1"},{"type":"function","title":"Evision.HistogramCostExtractor.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.HistogramCostExtractor.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.HistogramCostExtractor.html#read/2"},{"type":"function","title":"Evision.HistogramCostExtractor.save/1","doc":"","ref":"Evision.HistogramCostExtractor.html#save/1"},{"type":"function","title":"Evision.HistogramCostExtractor.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.HistogramCostExtractor.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.HistogramCostExtractor.html#save/2"},{"type":"function","title":"Evision.HistogramCostExtractor.setDefaultCost/1","doc":"","ref":"Evision.HistogramCostExtractor.html#setDefaultCost/1"},{"type":"function","title":"Evision.HistogramCostExtractor.setDefaultCost/2","doc":"setDefaultCost\n\n##### Positional Arguments\n- **self**: `Evision.HistogramCostExtractor.t()`\n- **defaultCost**: `float`\n\nPython prototype (for reference only):\n```python3\nsetDefaultCost(defaultCost) -> None\n```","ref":"Evision.HistogramCostExtractor.html#setDefaultCost/2"},{"type":"function","title":"Evision.HistogramCostExtractor.setNDummies/1","doc":"","ref":"Evision.HistogramCostExtractor.html#setNDummies/1"},{"type":"function","title":"Evision.HistogramCostExtractor.setNDummies/2","doc":"setNDummies\n\n##### Positional Arguments\n- **self**: `Evision.HistogramCostExtractor.t()`\n- **nDummies**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNDummies(nDummies) -> None\n```","ref":"Evision.HistogramCostExtractor.html#setNDummies/2"},{"type":"function","title":"Evision.HistogramCostExtractor.write/1","doc":"","ref":"Evision.HistogramCostExtractor.html#write/1"},{"type":"function","title":"Evision.HistogramCostExtractor.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.HistogramCostExtractor.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.HistogramCostExtractor.html#write/2"},{"type":"function","title":"Evision.HistogramCostExtractor.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.HistogramCostExtractor.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.HistogramCostExtractor.html#write/3"},{"type":"type","title":"Evision.HistogramCostExtractor.t/0","doc":"Type that represents an `HistogramCostExtractor` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.HistogramCostExtractor.html#t:t/0"},{"type":"module","title":"Evision.HoughModes","doc":"","ref":"Evision.HoughModes.html"},{"type":"function","title":"Evision.HoughModes.cv_HOUGH_GRADIENT/0","doc":"","ref":"Evision.HoughModes.html#cv_HOUGH_GRADIENT/0"},{"type":"function","title":"Evision.HoughModes.cv_HOUGH_GRADIENT_ALT/0","doc":"","ref":"Evision.HoughModes.html#cv_HOUGH_GRADIENT_ALT/0"},{"type":"function","title":"Evision.HoughModes.cv_HOUGH_MULTI_SCALE/0","doc":"","ref":"Evision.HoughModes.html#cv_HOUGH_MULTI_SCALE/0"},{"type":"function","title":"Evision.HoughModes.cv_HOUGH_PROBABILISTIC/0","doc":"","ref":"Evision.HoughModes.html#cv_HOUGH_PROBABILISTIC/0"},{"type":"function","title":"Evision.HoughModes.cv_HOUGH_STANDARD/0","doc":"","ref":"Evision.HoughModes.html#cv_HOUGH_STANDARD/0"},{"type":"type","title":"Evision.HoughModes.enum/0","doc":"","ref":"Evision.HoughModes.html#t:enum/0"},{"type":"module","title":"Evision.IPCHandle.CUDA","doc":"Represents a CUDA IPC handle for sharing data allocated on CUDA device between different OS processes.\n\n- `:handle`, a binary-encoded `cudaIpcMemHandle_t` that can be loaded\n  at the native level via `memcpy` or similar functions.\n\n- `:step`, the number of bytes between two consecutive rows.\n\n  When there are no gaps between successive rows, the value of `step` \n  is equal to the number of columns times the size of the data type. \n\n- `:rows`, the number of rows.\n- `:cols`, the number of columns.\n- `:channels`, the number of channels.\n- `:type`, the data type.\n- `:device_id` is the CUDA device ID that the memory is allocated on.","ref":"Evision.IPCHandle.CUDA.html"},{"type":"module","title":"Evision.IPCHandle.Host","doc":"Represents a host IPC handle for sharing data allocated on the CUDA device between different OS processes.\n\n- `:name` is the name of the shared memory object.\n- `:fd` is the file descriptor of the shared memory object.\n- `:size` is the size of the mapped shared memory in bytes.\n- `:rows`, the number of rows.\n- `:cols`, the number of columns.\n- `:channels`, the number of channels.\n- `:type`, the data type.","ref":"Evision.IPCHandle.Host.html"},{"type":"module","title":"Evision.IPCHandle.Local","doc":"Represents a local CUDA handle for sharing data allocated on the same CUDA device within the same OS processes.\n\n- `:handle`, a pointer to the memory that can be accessed within the same OS process.\n\n  when `:type` is `:cuda_ipc`, is a pointer to the memory that can be accessed\n  by other OS processes via CUDA IPC.\n\n- `:step`, the number of bytes between two consecutive rows.\n\n  When there are no gaps between successive rows, the value of `step` \n  is equal to the number of columns times the size of the data type. \n\n- `:rows`, the number of rows.\n- `:cols`, the number of columns.\n- `:channels`, the number of channels.\n- `:type`, the data type.\n- `:device_id` is the CUDA device ID that the memory is allocated on.","ref":"Evision.IPCHandle.Local.html"},{"type":"module","title":"Evision.ImgHash","doc":"","ref":"Evision.ImgHash.html"},{"type":"function","title":"Evision.ImgHash.averageHash/1","doc":"Calculates img_hash::AverageHash in one call\n\n##### Positional Arguments\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value, type should be CV_8UC4, CV_8UC3 or CV_8UC1.\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  Hash value of input, it will contain 16 hex decimal number, return type is CV_8U\n\nPython prototype (for reference only):\n```python3\naverageHash(inputArr[, outputArr]) -> outputArr\n```","ref":"Evision.ImgHash.html#averageHash/1"},{"type":"function","title":"Evision.ImgHash.averageHash/2","doc":"Calculates img_hash::AverageHash in one call\n\n##### Positional Arguments\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value, type should be CV_8UC4, CV_8UC3 or CV_8UC1.\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  Hash value of input, it will contain 16 hex decimal number, return type is CV_8U\n\nPython prototype (for reference only):\n```python3\naverageHash(inputArr[, outputArr]) -> outputArr\n```","ref":"Evision.ImgHash.html#averageHash/2"},{"type":"function","title":"Evision.ImgHash.blockMeanHash/1","doc":"Computes block mean hash of the input image\n\n##### Positional Arguments\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value, type should be CV_8UC4, CV_8UC3 or CV_8UC1.\n\n##### Keyword Arguments\n- **mode**: `integer()`.\n\n  the mode\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  Hash value of input, it will contain 16 hex decimal number, return type is CV_8U\n\nPython prototype (for reference only):\n```python3\nblockMeanHash(inputArr[, outputArr[, mode]]) -> outputArr\n```","ref":"Evision.ImgHash.html#blockMeanHash/1"},{"type":"function","title":"Evision.ImgHash.blockMeanHash/2","doc":"Computes block mean hash of the input image\n\n##### Positional Arguments\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value, type should be CV_8UC4, CV_8UC3 or CV_8UC1.\n\n##### Keyword Arguments\n- **mode**: `integer()`.\n\n  the mode\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  Hash value of input, it will contain 16 hex decimal number, return type is CV_8U\n\nPython prototype (for reference only):\n```python3\nblockMeanHash(inputArr[, outputArr[, mode]]) -> outputArr\n```","ref":"Evision.ImgHash.html#blockMeanHash/2"},{"type":"function","title":"Evision.ImgHash.colorMomentHash/1","doc":"Computes color moment hash of the input, the algorithm\nis come from the paper \"Perceptual  Hashing  for  Color  Images\nUsing  Invariant Moments\"\n\n##### Positional Arguments\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value,\n  type should be CV_8UC4, CV_8UC3 or CV_8UC1.\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  42 hash values with type CV_64F(double)\n\nPython prototype (for reference only):\n```python3\ncolorMomentHash(inputArr[, outputArr]) -> outputArr\n```","ref":"Evision.ImgHash.html#colorMomentHash/1"},{"type":"function","title":"Evision.ImgHash.colorMomentHash/2","doc":"Computes color moment hash of the input, the algorithm\nis come from the paper \"Perceptual  Hashing  for  Color  Images\nUsing  Invariant Moments\"\n\n##### Positional Arguments\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value,\n  type should be CV_8UC4, CV_8UC3 or CV_8UC1.\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  42 hash values with type CV_64F(double)\n\nPython prototype (for reference only):\n```python3\ncolorMomentHash(inputArr[, outputArr]) -> outputArr\n```","ref":"Evision.ImgHash.html#colorMomentHash/2"},{"type":"function","title":"Evision.ImgHash.marrHildrethHash/1","doc":"Computes average hash value of the input image\n\n##### Positional Arguments\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value,\n  type should be CV_8UC4, CV_8UC3, CV_8UC1.\n\n##### Keyword Arguments\n- **alpha**: `float`.\n\n  int scale factor for marr wavelet (default=2).\n\n- **scale**: `float`.\n\n  int level of scale factor (default = 1)\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  Hash value of input, it will contain 16 hex\n  decimal number, return type is CV_8U\n\nPython prototype (for reference only):\n```python3\nmarrHildrethHash(inputArr[, outputArr[, alpha[, scale]]]) -> outputArr\n```","ref":"Evision.ImgHash.html#marrHildrethHash/1"},{"type":"function","title":"Evision.ImgHash.marrHildrethHash/2","doc":"Computes average hash value of the input image\n\n##### Positional Arguments\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value,\n  type should be CV_8UC4, CV_8UC3, CV_8UC1.\n\n##### Keyword Arguments\n- **alpha**: `float`.\n\n  int scale factor for marr wavelet (default=2).\n\n- **scale**: `float`.\n\n  int level of scale factor (default = 1)\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  Hash value of input, it will contain 16 hex\n  decimal number, return type is CV_8U\n\nPython prototype (for reference only):\n```python3\nmarrHildrethHash(inputArr[, outputArr[, alpha[, scale]]]) -> outputArr\n```","ref":"Evision.ImgHash.html#marrHildrethHash/2"},{"type":"function","title":"Evision.ImgHash.pHash/1","doc":"Computes pHash value of the input image\n\n##### Positional Arguments\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value,\n  type should be CV_8UC4, CV_8UC3, CV_8UC1.\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  Hash value of input, it will contain 8 uchar value\n\nPython prototype (for reference only):\n```python3\npHash(inputArr[, outputArr]) -> outputArr\n```","ref":"Evision.ImgHash.html#pHash/1"},{"type":"function","title":"Evision.ImgHash.pHash/2","doc":"Computes pHash value of the input image\n\n##### Positional Arguments\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value,\n  type should be CV_8UC4, CV_8UC3, CV_8UC1.\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  Hash value of input, it will contain 8 uchar value\n\nPython prototype (for reference only):\n```python3\npHash(inputArr[, outputArr]) -> outputArr\n```","ref":"Evision.ImgHash.html#pHash/2"},{"type":"function","title":"Evision.ImgHash.radialVarianceHash/1","doc":"Computes radial variance hash of the input image\n\n##### Positional Arguments\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value,\n  type should be CV_8UC4, CV_8UC3, CV_8UC1.\n\n##### Keyword Arguments\n- **sigma**: `double`.\n\n  Gaussian kernel standard deviation\n\n- **numOfAngleLine**: `integer()`.\n\n  The number of angles to consider\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  Hash value of input\n\nPython prototype (for reference only):\n```python3\nradialVarianceHash(inputArr[, outputArr[, sigma[, numOfAngleLine]]]) -> outputArr\n```","ref":"Evision.ImgHash.html#radialVarianceHash/1"},{"type":"function","title":"Evision.ImgHash.radialVarianceHash/2","doc":"Computes radial variance hash of the input image\n\n##### Positional Arguments\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value,\n  type should be CV_8UC4, CV_8UC3, CV_8UC1.\n\n##### Keyword Arguments\n- **sigma**: `double`.\n\n  Gaussian kernel standard deviation\n\n- **numOfAngleLine**: `integer()`.\n\n  The number of angles to consider\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  Hash value of input\n\nPython prototype (for reference only):\n```python3\nradialVarianceHash(inputArr[, outputArr[, sigma[, numOfAngleLine]]]) -> outputArr\n```","ref":"Evision.ImgHash.html#radialVarianceHash/2"},{"type":"type","title":"Evision.ImgHash.t/0","doc":"Type that represents an `ImgHash` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ImgHash.html#t:t/0"},{"type":"module","title":"Evision.ImgHash.AverageHash","doc":"","ref":"Evision.ImgHash.AverageHash.html"},{"type":"function","title":"Evision.ImgHash.AverageHash.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.AverageHash.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.ImgHash.AverageHash.html#clear/1"},{"type":"function","title":"Evision.ImgHash.AverageHash.compare/1","doc":"","ref":"Evision.ImgHash.AverageHash.html#compare/1"},{"type":"function","title":"Evision.ImgHash.AverageHash.compare/3","doc":"Compare the hash value between inOne and inTwo\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.AverageHash.t()`\n- **hashOne**: `Evision.Mat`.\n\n  Hash value one\n\n- **hashTwo**: `Evision.Mat`.\n\n  Hash value two\n\n##### Return\n- **retval**: `double`\n\n@return value indicate similarity between inOne and inTwo, the meaning\nof the value vary from algorithms to algorithms\n\nPython prototype (for reference only):\n```python3\ncompare(hashOne, hashTwo) -> retval\n```","ref":"Evision.ImgHash.AverageHash.html#compare/3"},{"type":"function","title":"Evision.ImgHash.AverageHash.compute/1","doc":"","ref":"Evision.ImgHash.AverageHash.html#compute/1"},{"type":"function","title":"Evision.ImgHash.AverageHash.compute/2","doc":"Computes hash of the input image\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.AverageHash.t()`\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  hash of the image\n\nPython prototype (for reference only):\n```python3\ncompute(inputArr[, outputArr]) -> outputArr\n```","ref":"Evision.ImgHash.AverageHash.html#compute/2"},{"type":"function","title":"Evision.ImgHash.AverageHash.compute/3","doc":"Computes hash of the input image\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.AverageHash.t()`\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  hash of the image\n\nPython prototype (for reference only):\n```python3\ncompute(inputArr[, outputArr]) -> outputArr\n```","ref":"Evision.ImgHash.AverageHash.html#compute/3"},{"type":"function","title":"Evision.ImgHash.AverageHash.create/0","doc":"create\n##### Return\n- **retval**: `AverageHash`\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.ImgHash.AverageHash.html#create/0"},{"type":"function","title":"Evision.ImgHash.AverageHash.create/1","doc":"","ref":"Evision.ImgHash.AverageHash.html#create/1"},{"type":"function","title":"Evision.ImgHash.AverageHash.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.AverageHash.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.ImgHash.AverageHash.html#empty/1"},{"type":"function","title":"Evision.ImgHash.AverageHash.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.AverageHash.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.ImgHash.AverageHash.html#getDefaultName/1"},{"type":"function","title":"Evision.ImgHash.AverageHash.read/1","doc":"","ref":"Evision.ImgHash.AverageHash.html#read/1"},{"type":"function","title":"Evision.ImgHash.AverageHash.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.AverageHash.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.ImgHash.AverageHash.html#read/2"},{"type":"function","title":"Evision.ImgHash.AverageHash.save/1","doc":"","ref":"Evision.ImgHash.AverageHash.html#save/1"},{"type":"function","title":"Evision.ImgHash.AverageHash.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.AverageHash.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.ImgHash.AverageHash.html#save/2"},{"type":"function","title":"Evision.ImgHash.AverageHash.write/1","doc":"","ref":"Evision.ImgHash.AverageHash.html#write/1"},{"type":"function","title":"Evision.ImgHash.AverageHash.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.AverageHash.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.ImgHash.AverageHash.html#write/2"},{"type":"function","title":"Evision.ImgHash.AverageHash.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.AverageHash.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.ImgHash.AverageHash.html#write/3"},{"type":"type","title":"Evision.ImgHash.AverageHash.t/0","doc":"Type that represents an `ImgHash.AverageHash` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ImgHash.AverageHash.html#t:t/0"},{"type":"module","title":"Evision.ImgHash.BlockMeanHash","doc":"","ref":"Evision.ImgHash.BlockMeanHash.html"},{"type":"function","title":"Evision.ImgHash.BlockMeanHash.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.BlockMeanHash.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.ImgHash.BlockMeanHash.html#clear/1"},{"type":"function","title":"Evision.ImgHash.BlockMeanHash.compare/1","doc":"","ref":"Evision.ImgHash.BlockMeanHash.html#compare/1"},{"type":"function","title":"Evision.ImgHash.BlockMeanHash.compare/3","doc":"Compare the hash value between inOne and inTwo\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.BlockMeanHash.t()`\n- **hashOne**: `Evision.Mat`.\n\n  Hash value one\n\n- **hashTwo**: `Evision.Mat`.\n\n  Hash value two\n\n##### Return\n- **retval**: `double`\n\n@return value indicate similarity between inOne and inTwo, the meaning\nof the value vary from algorithms to algorithms\n\nPython prototype (for reference only):\n```python3\ncompare(hashOne, hashTwo) -> retval\n```","ref":"Evision.ImgHash.BlockMeanHash.html#compare/3"},{"type":"function","title":"Evision.ImgHash.BlockMeanHash.compute/1","doc":"","ref":"Evision.ImgHash.BlockMeanHash.html#compute/1"},{"type":"function","title":"Evision.ImgHash.BlockMeanHash.compute/2","doc":"Computes hash of the input image\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.BlockMeanHash.t()`\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  hash of the image\n\nPython prototype (for reference only):\n```python3\ncompute(inputArr[, outputArr]) -> outputArr\n```","ref":"Evision.ImgHash.BlockMeanHash.html#compute/2"},{"type":"function","title":"Evision.ImgHash.BlockMeanHash.compute/3","doc":"Computes hash of the input image\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.BlockMeanHash.t()`\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  hash of the image\n\nPython prototype (for reference only):\n```python3\ncompute(inputArr[, outputArr]) -> outputArr\n```","ref":"Evision.ImgHash.BlockMeanHash.html#compute/3"},{"type":"function","title":"Evision.ImgHash.BlockMeanHash.create/0","doc":"create\n##### Keyword Arguments\n- **mode**: `integer()`.\n\n##### Return\n- **retval**: `BlockMeanHash`\n\nPython prototype (for reference only):\n```python3\ncreate([, mode]) -> retval\n```","ref":"Evision.ImgHash.BlockMeanHash.html#create/0"},{"type":"function","title":"Evision.ImgHash.BlockMeanHash.create/1","doc":"create\n##### Keyword Arguments\n- **mode**: `integer()`.\n\n##### Return\n- **retval**: `BlockMeanHash`\n\nPython prototype (for reference only):\n```python3\ncreate([, mode]) -> retval\n```","ref":"Evision.ImgHash.BlockMeanHash.html#create/1"},{"type":"function","title":"Evision.ImgHash.BlockMeanHash.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.BlockMeanHash.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.ImgHash.BlockMeanHash.html#empty/1"},{"type":"function","title":"Evision.ImgHash.BlockMeanHash.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.BlockMeanHash.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.ImgHash.BlockMeanHash.html#getDefaultName/1"},{"type":"function","title":"Evision.ImgHash.BlockMeanHash.getMean/1","doc":"getMean\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.BlockMeanHash.t()`\n\n##### Return\n- **retval**: `[double]`\n\nPython prototype (for reference only):\n```python3\ngetMean() -> retval\n```","ref":"Evision.ImgHash.BlockMeanHash.html#getMean/1"},{"type":"function","title":"Evision.ImgHash.BlockMeanHash.read/1","doc":"","ref":"Evision.ImgHash.BlockMeanHash.html#read/1"},{"type":"function","title":"Evision.ImgHash.BlockMeanHash.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.BlockMeanHash.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.ImgHash.BlockMeanHash.html#read/2"},{"type":"function","title":"Evision.ImgHash.BlockMeanHash.save/1","doc":"","ref":"Evision.ImgHash.BlockMeanHash.html#save/1"},{"type":"function","title":"Evision.ImgHash.BlockMeanHash.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.BlockMeanHash.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.ImgHash.BlockMeanHash.html#save/2"},{"type":"function","title":"Evision.ImgHash.BlockMeanHash.setMode/1","doc":"","ref":"Evision.ImgHash.BlockMeanHash.html#setMode/1"},{"type":"function","title":"Evision.ImgHash.BlockMeanHash.setMode/2","doc":"Create BlockMeanHash object\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.BlockMeanHash.t()`\n- **mode**: `integer()`.\n\n  the mode\n\nPython prototype (for reference only):\n```python3\nsetMode(mode) -> None\n```","ref":"Evision.ImgHash.BlockMeanHash.html#setMode/2"},{"type":"function","title":"Evision.ImgHash.BlockMeanHash.write/1","doc":"","ref":"Evision.ImgHash.BlockMeanHash.html#write/1"},{"type":"function","title":"Evision.ImgHash.BlockMeanHash.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.BlockMeanHash.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.ImgHash.BlockMeanHash.html#write/2"},{"type":"function","title":"Evision.ImgHash.BlockMeanHash.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.BlockMeanHash.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.ImgHash.BlockMeanHash.html#write/3"},{"type":"type","title":"Evision.ImgHash.BlockMeanHash.t/0","doc":"Type that represents an `ImgHash.BlockMeanHash` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ImgHash.BlockMeanHash.html#t:t/0"},{"type":"module","title":"Evision.ImgHash.BlockMeanHashMode","doc":"","ref":"Evision.ImgHash.BlockMeanHashMode.html"},{"type":"function","title":"Evision.ImgHash.BlockMeanHashMode.cv_BLOCK_MEAN_HASH_MODE_0/0","doc":"","ref":"Evision.ImgHash.BlockMeanHashMode.html#cv_BLOCK_MEAN_HASH_MODE_0/0"},{"type":"function","title":"Evision.ImgHash.BlockMeanHashMode.cv_BLOCK_MEAN_HASH_MODE_1/0","doc":"","ref":"Evision.ImgHash.BlockMeanHashMode.html#cv_BLOCK_MEAN_HASH_MODE_1/0"},{"type":"type","title":"Evision.ImgHash.BlockMeanHashMode.enum/0","doc":"","ref":"Evision.ImgHash.BlockMeanHashMode.html#t:enum/0"},{"type":"module","title":"Evision.ImgHash.ColorMomentHash","doc":"","ref":"Evision.ImgHash.ColorMomentHash.html"},{"type":"function","title":"Evision.ImgHash.ColorMomentHash.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.ColorMomentHash.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.ImgHash.ColorMomentHash.html#clear/1"},{"type":"function","title":"Evision.ImgHash.ColorMomentHash.compare/1","doc":"","ref":"Evision.ImgHash.ColorMomentHash.html#compare/1"},{"type":"function","title":"Evision.ImgHash.ColorMomentHash.compare/3","doc":"Compare the hash value between inOne and inTwo\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.ColorMomentHash.t()`\n- **hashOne**: `Evision.Mat`.\n\n  Hash value one\n\n- **hashTwo**: `Evision.Mat`.\n\n  Hash value two\n\n##### Return\n- **retval**: `double`\n\n@return value indicate similarity between inOne and inTwo, the meaning\nof the value vary from algorithms to algorithms\n\nPython prototype (for reference only):\n```python3\ncompare(hashOne, hashTwo) -> retval\n```","ref":"Evision.ImgHash.ColorMomentHash.html#compare/3"},{"type":"function","title":"Evision.ImgHash.ColorMomentHash.compute/1","doc":"","ref":"Evision.ImgHash.ColorMomentHash.html#compute/1"},{"type":"function","title":"Evision.ImgHash.ColorMomentHash.compute/2","doc":"Computes hash of the input image\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.ColorMomentHash.t()`\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  hash of the image\n\nPython prototype (for reference only):\n```python3\ncompute(inputArr[, outputArr]) -> outputArr\n```","ref":"Evision.ImgHash.ColorMomentHash.html#compute/2"},{"type":"function","title":"Evision.ImgHash.ColorMomentHash.compute/3","doc":"Computes hash of the input image\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.ColorMomentHash.t()`\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  hash of the image\n\nPython prototype (for reference only):\n```python3\ncompute(inputArr[, outputArr]) -> outputArr\n```","ref":"Evision.ImgHash.ColorMomentHash.html#compute/3"},{"type":"function","title":"Evision.ImgHash.ColorMomentHash.create/0","doc":"create\n##### Return\n- **retval**: `Evision.ImgHash.ColorMomentHash.t()`\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.ImgHash.ColorMomentHash.html#create/0"},{"type":"function","title":"Evision.ImgHash.ColorMomentHash.create/1","doc":"","ref":"Evision.ImgHash.ColorMomentHash.html#create/1"},{"type":"function","title":"Evision.ImgHash.ColorMomentHash.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.ColorMomentHash.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.ImgHash.ColorMomentHash.html#empty/1"},{"type":"function","title":"Evision.ImgHash.ColorMomentHash.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.ColorMomentHash.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.ImgHash.ColorMomentHash.html#getDefaultName/1"},{"type":"function","title":"Evision.ImgHash.ColorMomentHash.read/1","doc":"","ref":"Evision.ImgHash.ColorMomentHash.html#read/1"},{"type":"function","title":"Evision.ImgHash.ColorMomentHash.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.ColorMomentHash.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.ImgHash.ColorMomentHash.html#read/2"},{"type":"function","title":"Evision.ImgHash.ColorMomentHash.save/1","doc":"","ref":"Evision.ImgHash.ColorMomentHash.html#save/1"},{"type":"function","title":"Evision.ImgHash.ColorMomentHash.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.ColorMomentHash.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.ImgHash.ColorMomentHash.html#save/2"},{"type":"function","title":"Evision.ImgHash.ColorMomentHash.write/1","doc":"","ref":"Evision.ImgHash.ColorMomentHash.html#write/1"},{"type":"function","title":"Evision.ImgHash.ColorMomentHash.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.ColorMomentHash.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.ImgHash.ColorMomentHash.html#write/2"},{"type":"function","title":"Evision.ImgHash.ColorMomentHash.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.ColorMomentHash.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.ImgHash.ColorMomentHash.html#write/3"},{"type":"type","title":"Evision.ImgHash.ColorMomentHash.t/0","doc":"Type that represents an `ImgHash.ColorMomentHash` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ImgHash.ColorMomentHash.html#t:t/0"},{"type":"module","title":"Evision.ImgHash.ImgHashBase","doc":"","ref":"Evision.ImgHash.ImgHashBase.html"},{"type":"function","title":"Evision.ImgHash.ImgHashBase.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.ImgHashBase.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.ImgHash.ImgHashBase.html#clear/1"},{"type":"function","title":"Evision.ImgHash.ImgHashBase.compare/1","doc":"","ref":"Evision.ImgHash.ImgHashBase.html#compare/1"},{"type":"function","title":"Evision.ImgHash.ImgHashBase.compare/3","doc":"Compare the hash value between inOne and inTwo\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.ImgHashBase.t()`\n- **hashOne**: `Evision.Mat`.\n\n  Hash value one\n\n- **hashTwo**: `Evision.Mat`.\n\n  Hash value two\n\n##### Return\n- **retval**: `double`\n\n@return value indicate similarity between inOne and inTwo, the meaning\nof the value vary from algorithms to algorithms\n\nPython prototype (for reference only):\n```python3\ncompare(hashOne, hashTwo) -> retval\n```","ref":"Evision.ImgHash.ImgHashBase.html#compare/3"},{"type":"function","title":"Evision.ImgHash.ImgHashBase.compute/1","doc":"","ref":"Evision.ImgHash.ImgHashBase.html#compute/1"},{"type":"function","title":"Evision.ImgHash.ImgHashBase.compute/2","doc":"Computes hash of the input image\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.ImgHashBase.t()`\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  hash of the image\n\nPython prototype (for reference only):\n```python3\ncompute(inputArr[, outputArr]) -> outputArr\n```","ref":"Evision.ImgHash.ImgHashBase.html#compute/2"},{"type":"function","title":"Evision.ImgHash.ImgHashBase.compute/3","doc":"Computes hash of the input image\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.ImgHashBase.t()`\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  hash of the image\n\nPython prototype (for reference only):\n```python3\ncompute(inputArr[, outputArr]) -> outputArr\n```","ref":"Evision.ImgHash.ImgHashBase.html#compute/3"},{"type":"function","title":"Evision.ImgHash.ImgHashBase.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.ImgHashBase.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.ImgHash.ImgHashBase.html#empty/1"},{"type":"function","title":"Evision.ImgHash.ImgHashBase.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.ImgHashBase.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.ImgHash.ImgHashBase.html#getDefaultName/1"},{"type":"function","title":"Evision.ImgHash.ImgHashBase.read/1","doc":"","ref":"Evision.ImgHash.ImgHashBase.html#read/1"},{"type":"function","title":"Evision.ImgHash.ImgHashBase.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.ImgHashBase.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.ImgHash.ImgHashBase.html#read/2"},{"type":"function","title":"Evision.ImgHash.ImgHashBase.save/1","doc":"","ref":"Evision.ImgHash.ImgHashBase.html#save/1"},{"type":"function","title":"Evision.ImgHash.ImgHashBase.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.ImgHashBase.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.ImgHash.ImgHashBase.html#save/2"},{"type":"function","title":"Evision.ImgHash.ImgHashBase.write/1","doc":"","ref":"Evision.ImgHash.ImgHashBase.html#write/1"},{"type":"function","title":"Evision.ImgHash.ImgHashBase.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.ImgHashBase.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.ImgHash.ImgHashBase.html#write/2"},{"type":"function","title":"Evision.ImgHash.ImgHashBase.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.ImgHashBase.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.ImgHash.ImgHashBase.html#write/3"},{"type":"type","title":"Evision.ImgHash.ImgHashBase.t/0","doc":"Type that represents an `ImgHash.ImgHashBase` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ImgHash.ImgHashBase.html#t:t/0"},{"type":"module","title":"Evision.ImgHash.MarrHildrethHash","doc":"","ref":"Evision.ImgHash.MarrHildrethHash.html"},{"type":"function","title":"Evision.ImgHash.MarrHildrethHash.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.MarrHildrethHash.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.ImgHash.MarrHildrethHash.html#clear/1"},{"type":"function","title":"Evision.ImgHash.MarrHildrethHash.compare/1","doc":"","ref":"Evision.ImgHash.MarrHildrethHash.html#compare/1"},{"type":"function","title":"Evision.ImgHash.MarrHildrethHash.compare/3","doc":"Compare the hash value between inOne and inTwo\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.MarrHildrethHash.t()`\n- **hashOne**: `Evision.Mat`.\n\n  Hash value one\n\n- **hashTwo**: `Evision.Mat`.\n\n  Hash value two\n\n##### Return\n- **retval**: `double`\n\n@return value indicate similarity between inOne and inTwo, the meaning\nof the value vary from algorithms to algorithms\n\nPython prototype (for reference only):\n```python3\ncompare(hashOne, hashTwo) -> retval\n```","ref":"Evision.ImgHash.MarrHildrethHash.html#compare/3"},{"type":"function","title":"Evision.ImgHash.MarrHildrethHash.compute/1","doc":"","ref":"Evision.ImgHash.MarrHildrethHash.html#compute/1"},{"type":"function","title":"Evision.ImgHash.MarrHildrethHash.compute/2","doc":"Computes hash of the input image\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.MarrHildrethHash.t()`\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  hash of the image\n\nPython prototype (for reference only):\n```python3\ncompute(inputArr[, outputArr]) -> outputArr\n```","ref":"Evision.ImgHash.MarrHildrethHash.html#compute/2"},{"type":"function","title":"Evision.ImgHash.MarrHildrethHash.compute/3","doc":"Computes hash of the input image\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.MarrHildrethHash.t()`\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  hash of the image\n\nPython prototype (for reference only):\n```python3\ncompute(inputArr[, outputArr]) -> outputArr\n```","ref":"Evision.ImgHash.MarrHildrethHash.html#compute/3"},{"type":"function","title":"Evision.ImgHash.MarrHildrethHash.create/0","doc":"create\n##### Keyword Arguments\n- **alpha**: `float`.\n\n  int scale factor for marr wavelet (default=2).\n\n- **scale**: `float`.\n\n  int level of scale factor (default = 1)\n\n##### Return\n- **retval**: `Evision.ImgHash.MarrHildrethHash.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, alpha[, scale]]) -> retval\n```","ref":"Evision.ImgHash.MarrHildrethHash.html#create/0"},{"type":"function","title":"Evision.ImgHash.MarrHildrethHash.create/1","doc":"create\n##### Keyword Arguments\n- **alpha**: `float`.\n\n  int scale factor for marr wavelet (default=2).\n\n- **scale**: `float`.\n\n  int level of scale factor (default = 1)\n\n##### Return\n- **retval**: `Evision.ImgHash.MarrHildrethHash.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, alpha[, scale]]) -> retval\n```","ref":"Evision.ImgHash.MarrHildrethHash.html#create/1"},{"type":"function","title":"Evision.ImgHash.MarrHildrethHash.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.MarrHildrethHash.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.ImgHash.MarrHildrethHash.html#empty/1"},{"type":"function","title":"Evision.ImgHash.MarrHildrethHash.getAlpha/1","doc":"self explain\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.MarrHildrethHash.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetAlpha() -> retval\n```","ref":"Evision.ImgHash.MarrHildrethHash.html#getAlpha/1"},{"type":"function","title":"Evision.ImgHash.MarrHildrethHash.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.MarrHildrethHash.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.ImgHash.MarrHildrethHash.html#getDefaultName/1"},{"type":"function","title":"Evision.ImgHash.MarrHildrethHash.getScale/1","doc":"self explain\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.MarrHildrethHash.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetScale() -> retval\n```","ref":"Evision.ImgHash.MarrHildrethHash.html#getScale/1"},{"type":"function","title":"Evision.ImgHash.MarrHildrethHash.read/1","doc":"","ref":"Evision.ImgHash.MarrHildrethHash.html#read/1"},{"type":"function","title":"Evision.ImgHash.MarrHildrethHash.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.MarrHildrethHash.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.ImgHash.MarrHildrethHash.html#read/2"},{"type":"function","title":"Evision.ImgHash.MarrHildrethHash.save/1","doc":"","ref":"Evision.ImgHash.MarrHildrethHash.html#save/1"},{"type":"function","title":"Evision.ImgHash.MarrHildrethHash.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.MarrHildrethHash.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.ImgHash.MarrHildrethHash.html#save/2"},{"type":"function","title":"Evision.ImgHash.MarrHildrethHash.setKernelParam/1","doc":"","ref":"Evision.ImgHash.MarrHildrethHash.html#setKernelParam/1"},{"type":"function","title":"Evision.ImgHash.MarrHildrethHash.setKernelParam/3","doc":"Set Mh kernel parameters\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.MarrHildrethHash.t()`\n- **alpha**: `float`.\n\n  int scale factor for marr wavelet (default=2).\n\n- **scale**: `float`.\n\n  int level of scale factor (default = 1)\n\nPython prototype (for reference only):\n```python3\nsetKernelParam(alpha, scale) -> None\n```","ref":"Evision.ImgHash.MarrHildrethHash.html#setKernelParam/3"},{"type":"function","title":"Evision.ImgHash.MarrHildrethHash.write/1","doc":"","ref":"Evision.ImgHash.MarrHildrethHash.html#write/1"},{"type":"function","title":"Evision.ImgHash.MarrHildrethHash.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.MarrHildrethHash.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.ImgHash.MarrHildrethHash.html#write/2"},{"type":"function","title":"Evision.ImgHash.MarrHildrethHash.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.MarrHildrethHash.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.ImgHash.MarrHildrethHash.html#write/3"},{"type":"type","title":"Evision.ImgHash.MarrHildrethHash.t/0","doc":"Type that represents an `ImgHash.MarrHildrethHash` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ImgHash.MarrHildrethHash.html#t:t/0"},{"type":"module","title":"Evision.ImgHash.PHash","doc":"","ref":"Evision.ImgHash.PHash.html"},{"type":"function","title":"Evision.ImgHash.PHash.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.PHash.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.ImgHash.PHash.html#clear/1"},{"type":"function","title":"Evision.ImgHash.PHash.compare/1","doc":"","ref":"Evision.ImgHash.PHash.html#compare/1"},{"type":"function","title":"Evision.ImgHash.PHash.compare/3","doc":"Compare the hash value between inOne and inTwo\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.PHash.t()`\n- **hashOne**: `Evision.Mat`.\n\n  Hash value one\n\n- **hashTwo**: `Evision.Mat`.\n\n  Hash value two\n\n##### Return\n- **retval**: `double`\n\n@return value indicate similarity between inOne and inTwo, the meaning\nof the value vary from algorithms to algorithms\n\nPython prototype (for reference only):\n```python3\ncompare(hashOne, hashTwo) -> retval\n```","ref":"Evision.ImgHash.PHash.html#compare/3"},{"type":"function","title":"Evision.ImgHash.PHash.compute/1","doc":"","ref":"Evision.ImgHash.PHash.html#compute/1"},{"type":"function","title":"Evision.ImgHash.PHash.compute/2","doc":"Computes hash of the input image\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.PHash.t()`\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  hash of the image\n\nPython prototype (for reference only):\n```python3\ncompute(inputArr[, outputArr]) -> outputArr\n```","ref":"Evision.ImgHash.PHash.html#compute/2"},{"type":"function","title":"Evision.ImgHash.PHash.compute/3","doc":"Computes hash of the input image\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.PHash.t()`\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  hash of the image\n\nPython prototype (for reference only):\n```python3\ncompute(inputArr[, outputArr]) -> outputArr\n```","ref":"Evision.ImgHash.PHash.html#compute/3"},{"type":"function","title":"Evision.ImgHash.PHash.create/0","doc":"create\n##### Return\n- **retval**: `Evision.ImgHash.PHash.t()`\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.ImgHash.PHash.html#create/0"},{"type":"function","title":"Evision.ImgHash.PHash.create/1","doc":"","ref":"Evision.ImgHash.PHash.html#create/1"},{"type":"function","title":"Evision.ImgHash.PHash.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.PHash.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.ImgHash.PHash.html#empty/1"},{"type":"function","title":"Evision.ImgHash.PHash.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.PHash.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.ImgHash.PHash.html#getDefaultName/1"},{"type":"function","title":"Evision.ImgHash.PHash.read/1","doc":"","ref":"Evision.ImgHash.PHash.html#read/1"},{"type":"function","title":"Evision.ImgHash.PHash.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.PHash.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.ImgHash.PHash.html#read/2"},{"type":"function","title":"Evision.ImgHash.PHash.save/1","doc":"","ref":"Evision.ImgHash.PHash.html#save/1"},{"type":"function","title":"Evision.ImgHash.PHash.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.PHash.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.ImgHash.PHash.html#save/2"},{"type":"function","title":"Evision.ImgHash.PHash.write/1","doc":"","ref":"Evision.ImgHash.PHash.html#write/1"},{"type":"function","title":"Evision.ImgHash.PHash.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.PHash.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.ImgHash.PHash.html#write/2"},{"type":"function","title":"Evision.ImgHash.PHash.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.PHash.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.ImgHash.PHash.html#write/3"},{"type":"type","title":"Evision.ImgHash.PHash.t/0","doc":"Type that represents an `ImgHash.PHash` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ImgHash.PHash.html#t:t/0"},{"type":"module","title":"Evision.ImgHash.RadialVarianceHash","doc":"","ref":"Evision.ImgHash.RadialVarianceHash.html"},{"type":"function","title":"Evision.ImgHash.RadialVarianceHash.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.RadialVarianceHash.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.ImgHash.RadialVarianceHash.html#clear/1"},{"type":"function","title":"Evision.ImgHash.RadialVarianceHash.compare/1","doc":"","ref":"Evision.ImgHash.RadialVarianceHash.html#compare/1"},{"type":"function","title":"Evision.ImgHash.RadialVarianceHash.compare/3","doc":"Compare the hash value between inOne and inTwo\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.RadialVarianceHash.t()`\n- **hashOne**: `Evision.Mat`.\n\n  Hash value one\n\n- **hashTwo**: `Evision.Mat`.\n\n  Hash value two\n\n##### Return\n- **retval**: `double`\n\n@return value indicate similarity between inOne and inTwo, the meaning\nof the value vary from algorithms to algorithms\n\nPython prototype (for reference only):\n```python3\ncompare(hashOne, hashTwo) -> retval\n```","ref":"Evision.ImgHash.RadialVarianceHash.html#compare/3"},{"type":"function","title":"Evision.ImgHash.RadialVarianceHash.compute/1","doc":"","ref":"Evision.ImgHash.RadialVarianceHash.html#compute/1"},{"type":"function","title":"Evision.ImgHash.RadialVarianceHash.compute/2","doc":"Computes hash of the input image\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.RadialVarianceHash.t()`\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  hash of the image\n\nPython prototype (for reference only):\n```python3\ncompute(inputArr[, outputArr]) -> outputArr\n```","ref":"Evision.ImgHash.RadialVarianceHash.html#compute/2"},{"type":"function","title":"Evision.ImgHash.RadialVarianceHash.compute/3","doc":"Computes hash of the input image\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.RadialVarianceHash.t()`\n- **inputArr**: `Evision.Mat`.\n\n  input image want to compute hash value\n\n##### Return\n- **outputArr**: `Evision.Mat.t()`.\n\n  hash of the image\n\nPython prototype (for reference only):\n```python3\ncompute(inputArr[, outputArr]) -> outputArr\n```","ref":"Evision.ImgHash.RadialVarianceHash.html#compute/3"},{"type":"function","title":"Evision.ImgHash.RadialVarianceHash.create/0","doc":"create\n##### Keyword Arguments\n- **sigma**: `double`.\n- **numOfAngleLine**: `integer()`.\n\n##### Return\n- **retval**: `Evision.ImgHash.RadialVarianceHash.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, sigma[, numOfAngleLine]]) -> retval\n```","ref":"Evision.ImgHash.RadialVarianceHash.html#create/0"},{"type":"function","title":"Evision.ImgHash.RadialVarianceHash.create/1","doc":"create\n##### Keyword Arguments\n- **sigma**: `double`.\n- **numOfAngleLine**: `integer()`.\n\n##### Return\n- **retval**: `Evision.ImgHash.RadialVarianceHash.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, sigma[, numOfAngleLine]]) -> retval\n```","ref":"Evision.ImgHash.RadialVarianceHash.html#create/1"},{"type":"function","title":"Evision.ImgHash.RadialVarianceHash.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.RadialVarianceHash.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.ImgHash.RadialVarianceHash.html#empty/1"},{"type":"function","title":"Evision.ImgHash.RadialVarianceHash.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.RadialVarianceHash.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.ImgHash.RadialVarianceHash.html#getDefaultName/1"},{"type":"function","title":"Evision.ImgHash.RadialVarianceHash.getNumOfAngleLine/1","doc":"getNumOfAngleLine\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.RadialVarianceHash.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNumOfAngleLine() -> retval\n```","ref":"Evision.ImgHash.RadialVarianceHash.html#getNumOfAngleLine/1"},{"type":"function","title":"Evision.ImgHash.RadialVarianceHash.getSigma/1","doc":"getSigma\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.RadialVarianceHash.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetSigma() -> retval\n```","ref":"Evision.ImgHash.RadialVarianceHash.html#getSigma/1"},{"type":"function","title":"Evision.ImgHash.RadialVarianceHash.read/1","doc":"","ref":"Evision.ImgHash.RadialVarianceHash.html#read/1"},{"type":"function","title":"Evision.ImgHash.RadialVarianceHash.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.RadialVarianceHash.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.ImgHash.RadialVarianceHash.html#read/2"},{"type":"function","title":"Evision.ImgHash.RadialVarianceHash.save/1","doc":"","ref":"Evision.ImgHash.RadialVarianceHash.html#save/1"},{"type":"function","title":"Evision.ImgHash.RadialVarianceHash.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.RadialVarianceHash.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.ImgHash.RadialVarianceHash.html#save/2"},{"type":"function","title":"Evision.ImgHash.RadialVarianceHash.setNumOfAngleLine/1","doc":"","ref":"Evision.ImgHash.RadialVarianceHash.html#setNumOfAngleLine/1"},{"type":"function","title":"Evision.ImgHash.RadialVarianceHash.setNumOfAngleLine/2","doc":"setNumOfAngleLine\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.RadialVarianceHash.t()`\n- **value**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNumOfAngleLine(value) -> None\n```","ref":"Evision.ImgHash.RadialVarianceHash.html#setNumOfAngleLine/2"},{"type":"function","title":"Evision.ImgHash.RadialVarianceHash.setSigma/1","doc":"","ref":"Evision.ImgHash.RadialVarianceHash.html#setSigma/1"},{"type":"function","title":"Evision.ImgHash.RadialVarianceHash.setSigma/2","doc":"setSigma\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.RadialVarianceHash.t()`\n- **value**: `double`\n\nPython prototype (for reference only):\n```python3\nsetSigma(value) -> None\n```","ref":"Evision.ImgHash.RadialVarianceHash.html#setSigma/2"},{"type":"function","title":"Evision.ImgHash.RadialVarianceHash.write/1","doc":"","ref":"Evision.ImgHash.RadialVarianceHash.html#write/1"},{"type":"function","title":"Evision.ImgHash.RadialVarianceHash.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.RadialVarianceHash.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.ImgHash.RadialVarianceHash.html#write/2"},{"type":"function","title":"Evision.ImgHash.RadialVarianceHash.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.ImgHash.RadialVarianceHash.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.ImgHash.RadialVarianceHash.html#write/3"},{"type":"type","title":"Evision.ImgHash.RadialVarianceHash.t/0","doc":"Type that represents an `ImgHash.RadialVarianceHash` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ImgHash.RadialVarianceHash.html#t:t/0"},{"type":"module","title":"Evision.ImreadModes","doc":"","ref":"Evision.ImreadModes.html"},{"type":"function","title":"Evision.ImreadModes.cv_IMREAD_ANYCOLOR/0","doc":"","ref":"Evision.ImreadModes.html#cv_IMREAD_ANYCOLOR/0"},{"type":"function","title":"Evision.ImreadModes.cv_IMREAD_ANYDEPTH/0","doc":"","ref":"Evision.ImreadModes.html#cv_IMREAD_ANYDEPTH/0"},{"type":"function","title":"Evision.ImreadModes.cv_IMREAD_COLOR/0","doc":"","ref":"Evision.ImreadModes.html#cv_IMREAD_COLOR/0"},{"type":"function","title":"Evision.ImreadModes.cv_IMREAD_GRAYSCALE/0","doc":"","ref":"Evision.ImreadModes.html#cv_IMREAD_GRAYSCALE/0"},{"type":"function","title":"Evision.ImreadModes.cv_IMREAD_IGNORE_ORIENTATION/0","doc":"","ref":"Evision.ImreadModes.html#cv_IMREAD_IGNORE_ORIENTATION/0"},{"type":"function","title":"Evision.ImreadModes.cv_IMREAD_LOAD_GDAL/0","doc":"","ref":"Evision.ImreadModes.html#cv_IMREAD_LOAD_GDAL/0"},{"type":"function","title":"Evision.ImreadModes.cv_IMREAD_REDUCED_COLOR_2/0","doc":"","ref":"Evision.ImreadModes.html#cv_IMREAD_REDUCED_COLOR_2/0"},{"type":"function","title":"Evision.ImreadModes.cv_IMREAD_REDUCED_COLOR_4/0","doc":"","ref":"Evision.ImreadModes.html#cv_IMREAD_REDUCED_COLOR_4/0"},{"type":"function","title":"Evision.ImreadModes.cv_IMREAD_REDUCED_COLOR_8/0","doc":"","ref":"Evision.ImreadModes.html#cv_IMREAD_REDUCED_COLOR_8/0"},{"type":"function","title":"Evision.ImreadModes.cv_IMREAD_REDUCED_GRAYSCALE_2/0","doc":"","ref":"Evision.ImreadModes.html#cv_IMREAD_REDUCED_GRAYSCALE_2/0"},{"type":"function","title":"Evision.ImreadModes.cv_IMREAD_REDUCED_GRAYSCALE_4/0","doc":"","ref":"Evision.ImreadModes.html#cv_IMREAD_REDUCED_GRAYSCALE_4/0"},{"type":"function","title":"Evision.ImreadModes.cv_IMREAD_REDUCED_GRAYSCALE_8/0","doc":"","ref":"Evision.ImreadModes.html#cv_IMREAD_REDUCED_GRAYSCALE_8/0"},{"type":"function","title":"Evision.ImreadModes.cv_IMREAD_UNCHANGED/0","doc":"","ref":"Evision.ImreadModes.html#cv_IMREAD_UNCHANGED/0"},{"type":"type","title":"Evision.ImreadModes.enum/0","doc":"","ref":"Evision.ImreadModes.html#t:enum/0"},{"type":"module","title":"Evision.ImwriteEXRCompressionFlags","doc":"","ref":"Evision.ImwriteEXRCompressionFlags.html"},{"type":"function","title":"Evision.ImwriteEXRCompressionFlags.cv_IMWRITE_EXR_COMPRESSION_B44/0","doc":"","ref":"Evision.ImwriteEXRCompressionFlags.html#cv_IMWRITE_EXR_COMPRESSION_B44/0"},{"type":"function","title":"Evision.ImwriteEXRCompressionFlags.cv_IMWRITE_EXR_COMPRESSION_B44A/0","doc":"","ref":"Evision.ImwriteEXRCompressionFlags.html#cv_IMWRITE_EXR_COMPRESSION_B44A/0"},{"type":"function","title":"Evision.ImwriteEXRCompressionFlags.cv_IMWRITE_EXR_COMPRESSION_DWAA/0","doc":"","ref":"Evision.ImwriteEXRCompressionFlags.html#cv_IMWRITE_EXR_COMPRESSION_DWAA/0"},{"type":"function","title":"Evision.ImwriteEXRCompressionFlags.cv_IMWRITE_EXR_COMPRESSION_DWAB/0","doc":"","ref":"Evision.ImwriteEXRCompressionFlags.html#cv_IMWRITE_EXR_COMPRESSION_DWAB/0"},{"type":"function","title":"Evision.ImwriteEXRCompressionFlags.cv_IMWRITE_EXR_COMPRESSION_NO/0","doc":"","ref":"Evision.ImwriteEXRCompressionFlags.html#cv_IMWRITE_EXR_COMPRESSION_NO/0"},{"type":"function","title":"Evision.ImwriteEXRCompressionFlags.cv_IMWRITE_EXR_COMPRESSION_PIZ/0","doc":"","ref":"Evision.ImwriteEXRCompressionFlags.html#cv_IMWRITE_EXR_COMPRESSION_PIZ/0"},{"type":"function","title":"Evision.ImwriteEXRCompressionFlags.cv_IMWRITE_EXR_COMPRESSION_PXR24/0","doc":"","ref":"Evision.ImwriteEXRCompressionFlags.html#cv_IMWRITE_EXR_COMPRESSION_PXR24/0"},{"type":"function","title":"Evision.ImwriteEXRCompressionFlags.cv_IMWRITE_EXR_COMPRESSION_RLE/0","doc":"","ref":"Evision.ImwriteEXRCompressionFlags.html#cv_IMWRITE_EXR_COMPRESSION_RLE/0"},{"type":"function","title":"Evision.ImwriteEXRCompressionFlags.cv_IMWRITE_EXR_COMPRESSION_ZIP/0","doc":"","ref":"Evision.ImwriteEXRCompressionFlags.html#cv_IMWRITE_EXR_COMPRESSION_ZIP/0"},{"type":"function","title":"Evision.ImwriteEXRCompressionFlags.cv_IMWRITE_EXR_COMPRESSION_ZIPS/0","doc":"","ref":"Evision.ImwriteEXRCompressionFlags.html#cv_IMWRITE_EXR_COMPRESSION_ZIPS/0"},{"type":"type","title":"Evision.ImwriteEXRCompressionFlags.enum/0","doc":"","ref":"Evision.ImwriteEXRCompressionFlags.html#t:enum/0"},{"type":"module","title":"Evision.ImwriteEXRTypeFlags","doc":"","ref":"Evision.ImwriteEXRTypeFlags.html"},{"type":"function","title":"Evision.ImwriteEXRTypeFlags.cv_IMWRITE_EXR_TYPE_FLOAT/0","doc":"","ref":"Evision.ImwriteEXRTypeFlags.html#cv_IMWRITE_EXR_TYPE_FLOAT/0"},{"type":"function","title":"Evision.ImwriteEXRTypeFlags.cv_IMWRITE_EXR_TYPE_HALF/0","doc":"","ref":"Evision.ImwriteEXRTypeFlags.html#cv_IMWRITE_EXR_TYPE_HALF/0"},{"type":"type","title":"Evision.ImwriteEXRTypeFlags.enum/0","doc":"","ref":"Evision.ImwriteEXRTypeFlags.html#t:enum/0"},{"type":"module","title":"Evision.ImwriteFlags","doc":"","ref":"Evision.ImwriteFlags.html"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_AVIF_DEPTH/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_AVIF_DEPTH/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_AVIF_QUALITY/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_AVIF_QUALITY/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_AVIF_SPEED/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_AVIF_SPEED/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_EXR_COMPRESSION/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_EXR_COMPRESSION/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_EXR_DWA_COMPRESSION_LEVEL/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_EXR_DWA_COMPRESSION_LEVEL/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_EXR_TYPE/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_EXR_TYPE/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_HDR_COMPRESSION/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_HDR_COMPRESSION/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_JPEG2000_COMPRESSION_X1000/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_JPEG2000_COMPRESSION_X1000/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_JPEG_CHROMA_QUALITY/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_JPEG_CHROMA_QUALITY/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_JPEG_LUMA_QUALITY/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_JPEG_LUMA_QUALITY/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_JPEG_OPTIMIZE/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_JPEG_OPTIMIZE/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_JPEG_PROGRESSIVE/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_JPEG_PROGRESSIVE/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_JPEG_QUALITY/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_JPEG_QUALITY/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_JPEG_RST_INTERVAL/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_JPEG_RST_INTERVAL/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_JPEG_SAMPLING_FACTOR/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_JPEG_SAMPLING_FACTOR/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_PAM_TUPLETYPE/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_PAM_TUPLETYPE/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_PNG_BILEVEL/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_PNG_BILEVEL/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_PNG_COMPRESSION/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_PNG_COMPRESSION/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_PNG_STRATEGY/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_PNG_STRATEGY/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_PXM_BINARY/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_PXM_BINARY/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_TIFF_COMPRESSION/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_TIFF_COMPRESSION/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_TIFF_PREDICTOR/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_TIFF_PREDICTOR/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_TIFF_RESUNIT/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_TIFF_RESUNIT/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_TIFF_ROWSPERSTRIP/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_TIFF_ROWSPERSTRIP/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_TIFF_XDPI/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_TIFF_XDPI/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_TIFF_YDPI/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_TIFF_YDPI/0"},{"type":"function","title":"Evision.ImwriteFlags.cv_IMWRITE_WEBP_QUALITY/0","doc":"","ref":"Evision.ImwriteFlags.html#cv_IMWRITE_WEBP_QUALITY/0"},{"type":"type","title":"Evision.ImwriteFlags.enum/0","doc":"","ref":"Evision.ImwriteFlags.html#t:enum/0"},{"type":"module","title":"Evision.ImwriteHDRCompressionFlags","doc":"","ref":"Evision.ImwriteHDRCompressionFlags.html"},{"type":"function","title":"Evision.ImwriteHDRCompressionFlags.cv_IMWRITE_HDR_COMPRESSION_NONE/0","doc":"","ref":"Evision.ImwriteHDRCompressionFlags.html#cv_IMWRITE_HDR_COMPRESSION_NONE/0"},{"type":"function","title":"Evision.ImwriteHDRCompressionFlags.cv_IMWRITE_HDR_COMPRESSION_RLE/0","doc":"","ref":"Evision.ImwriteHDRCompressionFlags.html#cv_IMWRITE_HDR_COMPRESSION_RLE/0"},{"type":"type","title":"Evision.ImwriteHDRCompressionFlags.enum/0","doc":"","ref":"Evision.ImwriteHDRCompressionFlags.html#t:enum/0"},{"type":"module","title":"Evision.ImwriteJPEGSamplingFactorParams","doc":"","ref":"Evision.ImwriteJPEGSamplingFactorParams.html"},{"type":"function","title":"Evision.ImwriteJPEGSamplingFactorParams.cv_IMWRITE_JPEG_SAMPLING_FACTOR_411/0","doc":"","ref":"Evision.ImwriteJPEGSamplingFactorParams.html#cv_IMWRITE_JPEG_SAMPLING_FACTOR_411/0"},{"type":"function","title":"Evision.ImwriteJPEGSamplingFactorParams.cv_IMWRITE_JPEG_SAMPLING_FACTOR_420/0","doc":"","ref":"Evision.ImwriteJPEGSamplingFactorParams.html#cv_IMWRITE_JPEG_SAMPLING_FACTOR_420/0"},{"type":"function","title":"Evision.ImwriteJPEGSamplingFactorParams.cv_IMWRITE_JPEG_SAMPLING_FACTOR_422/0","doc":"","ref":"Evision.ImwriteJPEGSamplingFactorParams.html#cv_IMWRITE_JPEG_SAMPLING_FACTOR_422/0"},{"type":"function","title":"Evision.ImwriteJPEGSamplingFactorParams.cv_IMWRITE_JPEG_SAMPLING_FACTOR_440/0","doc":"","ref":"Evision.ImwriteJPEGSamplingFactorParams.html#cv_IMWRITE_JPEG_SAMPLING_FACTOR_440/0"},{"type":"function","title":"Evision.ImwriteJPEGSamplingFactorParams.cv_IMWRITE_JPEG_SAMPLING_FACTOR_444/0","doc":"","ref":"Evision.ImwriteJPEGSamplingFactorParams.html#cv_IMWRITE_JPEG_SAMPLING_FACTOR_444/0"},{"type":"type","title":"Evision.ImwriteJPEGSamplingFactorParams.enum/0","doc":"","ref":"Evision.ImwriteJPEGSamplingFactorParams.html#t:enum/0"},{"type":"module","title":"Evision.ImwritePAMFlags","doc":"","ref":"Evision.ImwritePAMFlags.html"},{"type":"function","title":"Evision.ImwritePAMFlags.cv_IMWRITE_PAM_FORMAT_BLACKANDWHITE/0","doc":"","ref":"Evision.ImwritePAMFlags.html#cv_IMWRITE_PAM_FORMAT_BLACKANDWHITE/0"},{"type":"function","title":"Evision.ImwritePAMFlags.cv_IMWRITE_PAM_FORMAT_GRAYSCALE/0","doc":"","ref":"Evision.ImwritePAMFlags.html#cv_IMWRITE_PAM_FORMAT_GRAYSCALE/0"},{"type":"function","title":"Evision.ImwritePAMFlags.cv_IMWRITE_PAM_FORMAT_GRAYSCALE_ALPHA/0","doc":"","ref":"Evision.ImwritePAMFlags.html#cv_IMWRITE_PAM_FORMAT_GRAYSCALE_ALPHA/0"},{"type":"function","title":"Evision.ImwritePAMFlags.cv_IMWRITE_PAM_FORMAT_NULL/0","doc":"","ref":"Evision.ImwritePAMFlags.html#cv_IMWRITE_PAM_FORMAT_NULL/0"},{"type":"function","title":"Evision.ImwritePAMFlags.cv_IMWRITE_PAM_FORMAT_RGB/0","doc":"","ref":"Evision.ImwritePAMFlags.html#cv_IMWRITE_PAM_FORMAT_RGB/0"},{"type":"function","title":"Evision.ImwritePAMFlags.cv_IMWRITE_PAM_FORMAT_RGB_ALPHA/0","doc":"","ref":"Evision.ImwritePAMFlags.html#cv_IMWRITE_PAM_FORMAT_RGB_ALPHA/0"},{"type":"type","title":"Evision.ImwritePAMFlags.enum/0","doc":"","ref":"Evision.ImwritePAMFlags.html#t:enum/0"},{"type":"module","title":"Evision.ImwritePNGFlags","doc":"","ref":"Evision.ImwritePNGFlags.html"},{"type":"function","title":"Evision.ImwritePNGFlags.cv_IMWRITE_PNG_STRATEGY_DEFAULT/0","doc":"","ref":"Evision.ImwritePNGFlags.html#cv_IMWRITE_PNG_STRATEGY_DEFAULT/0"},{"type":"function","title":"Evision.ImwritePNGFlags.cv_IMWRITE_PNG_STRATEGY_FILTERED/0","doc":"","ref":"Evision.ImwritePNGFlags.html#cv_IMWRITE_PNG_STRATEGY_FILTERED/0"},{"type":"function","title":"Evision.ImwritePNGFlags.cv_IMWRITE_PNG_STRATEGY_FIXED/0","doc":"","ref":"Evision.ImwritePNGFlags.html#cv_IMWRITE_PNG_STRATEGY_FIXED/0"},{"type":"function","title":"Evision.ImwritePNGFlags.cv_IMWRITE_PNG_STRATEGY_HUFFMAN_ONLY/0","doc":"","ref":"Evision.ImwritePNGFlags.html#cv_IMWRITE_PNG_STRATEGY_HUFFMAN_ONLY/0"},{"type":"function","title":"Evision.ImwritePNGFlags.cv_IMWRITE_PNG_STRATEGY_RLE/0","doc":"","ref":"Evision.ImwritePNGFlags.html#cv_IMWRITE_PNG_STRATEGY_RLE/0"},{"type":"type","title":"Evision.ImwritePNGFlags.enum/0","doc":"","ref":"Evision.ImwritePNGFlags.html#t:enum/0"},{"type":"module","title":"Evision.ImwriteTiffCompressionFlags","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_ADOBE_DEFLATE/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_ADOBE_DEFLATE/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_CCITT_T4/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_CCITT_T4/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_CCITT_T6/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_CCITT_T6/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_CCITTFAX3/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_CCITTFAX3/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_CCITTFAX4/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_CCITTFAX4/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_CCITTRLE/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_CCITTRLE/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_CCITTRLEW/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_CCITTRLEW/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_DCS/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_DCS/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_DEFLATE/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_DEFLATE/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_IT8BL/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_IT8BL/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_IT8CTPAD/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_IT8CTPAD/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_IT8LW/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_IT8LW/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_IT8MP/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_IT8MP/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_JBIG/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_JBIG/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_JP2000/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_JP2000/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_JPEG/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_JPEG/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_JXL/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_JXL/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_LERC/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_LERC/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_LZMA/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_LZMA/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_LZW/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_LZW/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_NEXT/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_NEXT/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_NONE/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_NONE/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_OJPEG/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_OJPEG/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_PACKBITS/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_PACKBITS/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_PIXARFILM/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_PIXARFILM/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_PIXARLOG/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_PIXARLOG/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_SGILOG24/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_SGILOG24/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_SGILOG/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_SGILOG/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_T43/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_T43/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_T85/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_T85/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_THUNDERSCAN/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_THUNDERSCAN/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_WEBP/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_WEBP/0"},{"type":"function","title":"Evision.ImwriteTiffCompressionFlags.cv_IMWRITE_TIFF_COMPRESSION_ZSTD/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#cv_IMWRITE_TIFF_COMPRESSION_ZSTD/0"},{"type":"type","title":"Evision.ImwriteTiffCompressionFlags.enum/0","doc":"","ref":"Evision.ImwriteTiffCompressionFlags.html#t:enum/0"},{"type":"module","title":"Evision.ImwriteTiffPredictorFlags","doc":"","ref":"Evision.ImwriteTiffPredictorFlags.html"},{"type":"function","title":"Evision.ImwriteTiffPredictorFlags.cv_IMWRITE_TIFF_PREDICTOR_FLOATINGPOINT/0","doc":"","ref":"Evision.ImwriteTiffPredictorFlags.html#cv_IMWRITE_TIFF_PREDICTOR_FLOATINGPOINT/0"},{"type":"function","title":"Evision.ImwriteTiffPredictorFlags.cv_IMWRITE_TIFF_PREDICTOR_HORIZONTAL/0","doc":"","ref":"Evision.ImwriteTiffPredictorFlags.html#cv_IMWRITE_TIFF_PREDICTOR_HORIZONTAL/0"},{"type":"function","title":"Evision.ImwriteTiffPredictorFlags.cv_IMWRITE_TIFF_PREDICTOR_NONE/0","doc":"","ref":"Evision.ImwriteTiffPredictorFlags.html#cv_IMWRITE_TIFF_PREDICTOR_NONE/0"},{"type":"type","title":"Evision.ImwriteTiffPredictorFlags.enum/0","doc":"","ref":"Evision.ImwriteTiffPredictorFlags.html#t:enum/0"},{"type":"module","title":"Evision.Intensitytransform","doc":"","ref":"Evision.Intensitytransform.html"},{"type":"function","title":"Evision.Intensitytransform.autoscaling/1","doc":"","ref":"Evision.Intensitytransform.html#autoscaling/1"},{"type":"function","title":"Evision.Intensitytransform.autoscaling/2","doc":"Given an input bgr or grayscale image, apply autoscaling on domain [0, 255] to increase\nthe contrast of the input image and return the resulting image.\n\n##### Positional Arguments\n- **input**: `Evision.Mat`.\n\n  input bgr or grayscale image.\n\n- **output**: `Evision.Mat`.\n\n  resulting image of autoscaling.\n\nPython prototype (for reference only):\n```python3\nautoscaling(input, output) -> None\n```","ref":"Evision.Intensitytransform.html#autoscaling/2"},{"type":"function","title":"Evision.Intensitytransform.bimef2/1","doc":"","ref":"Evision.Intensitytransform.html#bimef2/1"},{"type":"function","title":"Evision.Intensitytransform.bimef2/5","doc":"Given an input color image, enhance low-light images using the BIMEF method (@cite ying2017bio @cite ying2017new).\n\n##### Positional Arguments\n- **input**: `Evision.Mat`.\n\n  input color image.\n\n- **k**: `float`.\n\n  exposure ratio.\n\n- **mu**: `float`.\n\n  enhancement ratio.\n\n- **a**: `float`.\n\n  a-parameter in the Camera Response Function (CRF).\n\n- **b**: `float`.\n\n  b-parameter in the Camera Response Function (CRF).\n\n##### Return\n- **output**: `Evision.Mat.t()`.\n\n  resulting image.\n\n This is an overloaded function with the exposure ratio given as parameter.\n\n@warning This is a C++ implementation of the [original MATLAB algorithm](https://github.com/baidut/BIMEF).\n Compared to the original code, this implementation is a little bit slower and does not provide the same results.\n In particular, quality of the image enhancement is degraded for the bright areas in certain conditions.\n\nPython prototype (for reference only):\n```python3\nBIMEF2(input, k, mu, a, b[, output]) -> output\n```","ref":"Evision.Intensitytransform.html#bimef2/5"},{"type":"function","title":"Evision.Intensitytransform.bimef2/6","doc":"Given an input color image, enhance low-light images using the BIMEF method (@cite ying2017bio @cite ying2017new).\n\n##### Positional Arguments\n- **input**: `Evision.Mat`.\n\n  input color image.\n\n- **k**: `float`.\n\n  exposure ratio.\n\n- **mu**: `float`.\n\n  enhancement ratio.\n\n- **a**: `float`.\n\n  a-parameter in the Camera Response Function (CRF).\n\n- **b**: `float`.\n\n  b-parameter in the Camera Response Function (CRF).\n\n##### Return\n- **output**: `Evision.Mat.t()`.\n\n  resulting image.\n\n This is an overloaded function with the exposure ratio given as parameter.\n\n@warning This is a C++ implementation of the [original MATLAB algorithm](https://github.com/baidut/BIMEF).\n Compared to the original code, this implementation is a little bit slower and does not provide the same results.\n In particular, quality of the image enhancement is degraded for the bright areas in certain conditions.\n\nPython prototype (for reference only):\n```python3\nBIMEF2(input, k, mu, a, b[, output]) -> output\n```","ref":"Evision.Intensitytransform.html#bimef2/6"},{"type":"function","title":"Evision.Intensitytransform.bimef/1","doc":"Given an input color image, enhance low-light images using the BIMEF method (@cite ying2017bio @cite ying2017new).\n\n##### Positional Arguments\n- **input**: `Evision.Mat`.\n\n  input color image.\n\n##### Keyword Arguments\n- **mu**: `float`.\n\n  enhancement ratio.\n\n- **a**: `float`.\n\n  a-parameter in the Camera Response Function (CRF).\n\n- **b**: `float`.\n\n  b-parameter in the Camera Response Function (CRF).\n\n##### Return\n- **output**: `Evision.Mat.t()`.\n\n  resulting image.\n\n@warning This is a C++ implementation of the [original MATLAB algorithm](https://github.com/baidut/BIMEF).\n Compared to the original code, this implementation is a little bit slower and does not provide the same results.\n In particular, quality of the image enhancement is degraded for the bright areas in certain conditions.\n\nPython prototype (for reference only):\n```python3\nBIMEF(input[, output[, mu[, a[, b]]]]) -> output\n```","ref":"Evision.Intensitytransform.html#bimef/1"},{"type":"function","title":"Evision.Intensitytransform.bimef/2","doc":"Given an input color image, enhance low-light images using the BIMEF method (@cite ying2017bio @cite ying2017new).\n\n##### Positional Arguments\n- **input**: `Evision.Mat`.\n\n  input color image.\n\n##### Keyword Arguments\n- **mu**: `float`.\n\n  enhancement ratio.\n\n- **a**: `float`.\n\n  a-parameter in the Camera Response Function (CRF).\n\n- **b**: `float`.\n\n  b-parameter in the Camera Response Function (CRF).\n\n##### Return\n- **output**: `Evision.Mat.t()`.\n\n  resulting image.\n\n@warning This is a C++ implementation of the [original MATLAB algorithm](https://github.com/baidut/BIMEF).\n Compared to the original code, this implementation is a little bit slower and does not provide the same results.\n In particular, quality of the image enhancement is degraded for the bright areas in certain conditions.\n\nPython prototype (for reference only):\n```python3\nBIMEF(input[, output[, mu[, a[, b]]]]) -> output\n```","ref":"Evision.Intensitytransform.html#bimef/2"},{"type":"function","title":"Evision.Intensitytransform.contrastStretching/1","doc":"","ref":"Evision.Intensitytransform.html#contrastStretching/1"},{"type":"function","title":"Evision.Intensitytransform.contrastStretching/6","doc":"Given an input bgr or grayscale image, apply linear contrast stretching on domain [0, 255]\nand return the resulting image.\n\n##### Positional Arguments\n- **input**: `Evision.Mat`.\n\n  input bgr or grayscale image.\n\n- **output**: `Evision.Mat`.\n\n  resulting image of contrast stretching.\n\n- **r1**: `integer()`.\n\n  x coordinate of first point (r1, s1) in the transformation function.\n\n- **s1**: `integer()`.\n\n  y coordinate of first point (r1, s1) in the transformation function.\n\n- **r2**: `integer()`.\n\n  x coordinate of second point (r2, s2) in the transformation function.\n\n- **s2**: `integer()`.\n\n  y coordinate of second point (r2, s2) in the transformation function.\n\nPython prototype (for reference only):\n```python3\ncontrastStretching(input, output, r1, s1, r2, s2) -> None\n```","ref":"Evision.Intensitytransform.html#contrastStretching/6"},{"type":"function","title":"Evision.Intensitytransform.gammaCorrection/1","doc":"","ref":"Evision.Intensitytransform.html#gammaCorrection/1"},{"type":"function","title":"Evision.Intensitytransform.gammaCorrection/3","doc":"Given an input bgr or grayscale image and constant gamma, apply power-law transformation,\na.k.a. gamma correction to the image on domain [0, 255] and return the resulting image.\n\n##### Positional Arguments\n- **input**: `Evision.Mat`.\n\n  input bgr or grayscale image.\n\n- **output**: `Evision.Mat`.\n\n  resulting image of gamma corrections.\n\n- **gamma**: `float`.\n\n  constant in c*r^gamma where r is pixel value.\n\nPython prototype (for reference only):\n```python3\ngammaCorrection(input, output, gamma) -> None\n```","ref":"Evision.Intensitytransform.html#gammaCorrection/3"},{"type":"function","title":"Evision.Intensitytransform.logTransform/1","doc":"","ref":"Evision.Intensitytransform.html#logTransform/1"},{"type":"function","title":"Evision.Intensitytransform.logTransform/2","doc":"Given an input bgr or grayscale image and constant c, apply log transformation to the image\non domain [0, 255] and return the resulting image.\n\n##### Positional Arguments\n- **input**: `Evision.Mat`.\n\n  input bgr or grayscale image.\n\n- **output**: `Evision.Mat`.\n\n  resulting image of log transformations.\n\nPython prototype (for reference only):\n```python3\nlogTransform(input, output) -> None\n```","ref":"Evision.Intensitytransform.html#logTransform/2"},{"type":"type","title":"Evision.Intensitytransform.t/0","doc":"Type that represents an `Intensitytransform` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Intensitytransform.html#t:t/0"},{"type":"module","title":"Evision.InterpolationFlags","doc":"","ref":"Evision.InterpolationFlags.html"},{"type":"function","title":"Evision.InterpolationFlags.cv_INTER_AREA/0","doc":"","ref":"Evision.InterpolationFlags.html#cv_INTER_AREA/0"},{"type":"function","title":"Evision.InterpolationFlags.cv_INTER_CUBIC/0","doc":"","ref":"Evision.InterpolationFlags.html#cv_INTER_CUBIC/0"},{"type":"function","title":"Evision.InterpolationFlags.cv_INTER_LANCZOS4/0","doc":"","ref":"Evision.InterpolationFlags.html#cv_INTER_LANCZOS4/0"},{"type":"function","title":"Evision.InterpolationFlags.cv_INTER_LINEAR/0","doc":"","ref":"Evision.InterpolationFlags.html#cv_INTER_LINEAR/0"},{"type":"function","title":"Evision.InterpolationFlags.cv_INTER_LINEAR_EXACT/0","doc":"","ref":"Evision.InterpolationFlags.html#cv_INTER_LINEAR_EXACT/0"},{"type":"function","title":"Evision.InterpolationFlags.cv_INTER_MAX/0","doc":"","ref":"Evision.InterpolationFlags.html#cv_INTER_MAX/0"},{"type":"function","title":"Evision.InterpolationFlags.cv_INTER_NEAREST/0","doc":"","ref":"Evision.InterpolationFlags.html#cv_INTER_NEAREST/0"},{"type":"function","title":"Evision.InterpolationFlags.cv_INTER_NEAREST_EXACT/0","doc":"","ref":"Evision.InterpolationFlags.html#cv_INTER_NEAREST_EXACT/0"},{"type":"function","title":"Evision.InterpolationFlags.cv_WARP_FILL_OUTLIERS/0","doc":"","ref":"Evision.InterpolationFlags.html#cv_WARP_FILL_OUTLIERS/0"},{"type":"function","title":"Evision.InterpolationFlags.cv_WARP_INVERSE_MAP/0","doc":"","ref":"Evision.InterpolationFlags.html#cv_WARP_INVERSE_MAP/0"},{"type":"function","title":"Evision.InterpolationFlags.cv_WARP_RELATIVE_MAP/0","doc":"","ref":"Evision.InterpolationFlags.html#cv_WARP_RELATIVE_MAP/0"},{"type":"type","title":"Evision.InterpolationFlags.enum/0","doc":"","ref":"Evision.InterpolationFlags.html#t:enum/0"},{"type":"module","title":"Evision.InterpolationMasks","doc":"","ref":"Evision.InterpolationMasks.html"},{"type":"function","title":"Evision.InterpolationMasks.cv_INTER_BITS2/0","doc":"","ref":"Evision.InterpolationMasks.html#cv_INTER_BITS2/0"},{"type":"function","title":"Evision.InterpolationMasks.cv_INTER_BITS/0","doc":"","ref":"Evision.InterpolationMasks.html#cv_INTER_BITS/0"},{"type":"function","title":"Evision.InterpolationMasks.cv_INTER_TAB_SIZE2/0","doc":"","ref":"Evision.InterpolationMasks.html#cv_INTER_TAB_SIZE2/0"},{"type":"function","title":"Evision.InterpolationMasks.cv_INTER_TAB_SIZE/0","doc":"","ref":"Evision.InterpolationMasks.html#cv_INTER_TAB_SIZE/0"},{"type":"type","title":"Evision.InterpolationMasks.enum/0","doc":"","ref":"Evision.InterpolationMasks.html#t:enum/0"},{"type":"module","title":"Evision.Ipp","doc":"","ref":"Evision.Ipp.html"},{"type":"function","title":"Evision.Ipp.getIppVersion/0","doc":"getIppVersion\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetIppVersion() -> retval\n```","ref":"Evision.Ipp.html#getIppVersion/0"},{"type":"function","title":"Evision.Ipp.getIppVersion/1","doc":"","ref":"Evision.Ipp.html#getIppVersion/1"},{"type":"function","title":"Evision.Ipp.setUseIPP/1","doc":"setUseIPP\n\n##### Positional Arguments\n- **flag**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetUseIPP(flag) -> None\n```","ref":"Evision.Ipp.html#setUseIPP/1"},{"type":"function","title":"Evision.Ipp.useIPP/0","doc":"useIPP\n##### Return\n- **retval**: `bool`\n\nproxy for hal::Cholesky\n\nPython prototype (for reference only):\n```python3\nuseIPP() -> retval\n```","ref":"Evision.Ipp.html#useIPP/0"},{"type":"function","title":"Evision.Ipp.useIPP/1","doc":"","ref":"Evision.Ipp.html#useIPP/1"},{"type":"type","title":"Evision.Ipp.t/0","doc":"Type that represents an `Ipp` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Ipp.html#t:t/0"},{"type":"module","title":"Evision.KAZE","doc":"","ref":"Evision.KAZE.html"},{"type":"function","title":"Evision.KAZE.compute/1","doc":"","ref":"Evision.KAZE.html#compute/1"},{"type":"function","title":"Evision.KAZE.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.KAZE.html#compute/3"},{"type":"function","title":"Evision.KAZE.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.KAZE.html#compute/4"},{"type":"function","title":"Evision.KAZE.create/0","doc":"The KAZE constructor\n##### Keyword Arguments\n- **extended**: `bool`.\n\n  Set to enable extraction of extended (128-byte) descriptor.\n\n- **upright**: `bool`.\n\n  Set to enable use of upright descriptors (non rotation-invariant).\n\n- **threshold**: `float`.\n\n  Detector response threshold to accept point\n\n- **nOctaves**: `integer()`.\n\n  Maximum octave evolution of the image\n\n- **nOctaveLayers**: `integer()`.\n\n  Default number of sublevels per scale level\n\n- **diffusivity**: `KAZE_DiffusivityType`.\n\n  Diffusivity type. DIFF_PM_G1, DIFF_PM_G2, DIFF_WEICKERT or\n  DIFF_CHARBONNIER\n\n##### Return\n- **retval**: `Evision.KAZE.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, extended[, upright[, threshold[, nOctaves[, nOctaveLayers[, diffusivity]]]]]]) -> retval\n```","ref":"Evision.KAZE.html#create/0"},{"type":"function","title":"Evision.KAZE.create/1","doc":"The KAZE constructor\n##### Keyword Arguments\n- **extended**: `bool`.\n\n  Set to enable extraction of extended (128-byte) descriptor.\n\n- **upright**: `bool`.\n\n  Set to enable use of upright descriptors (non rotation-invariant).\n\n- **threshold**: `float`.\n\n  Detector response threshold to accept point\n\n- **nOctaves**: `integer()`.\n\n  Maximum octave evolution of the image\n\n- **nOctaveLayers**: `integer()`.\n\n  Default number of sublevels per scale level\n\n- **diffusivity**: `KAZE_DiffusivityType`.\n\n  Diffusivity type. DIFF_PM_G1, DIFF_PM_G2, DIFF_WEICKERT or\n  DIFF_CHARBONNIER\n\n##### Return\n- **retval**: `Evision.KAZE.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, extended[, upright[, threshold[, nOctaves[, nOctaveLayers[, diffusivity]]]]]]) -> retval\n```","ref":"Evision.KAZE.html#create/1"},{"type":"function","title":"Evision.KAZE.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.KAZE.html#defaultNorm/1"},{"type":"function","title":"Evision.KAZE.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.KAZE.html#descriptorSize/1"},{"type":"function","title":"Evision.KAZE.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.KAZE.html#descriptorType/1"},{"type":"function","title":"Evision.KAZE.detect/1","doc":"","ref":"Evision.KAZE.html#detect/1"},{"type":"function","title":"Evision.KAZE.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.KAZE.html#detect/2"},{"type":"function","title":"Evision.KAZE.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.KAZE.html#detect/3"},{"type":"function","title":"Evision.KAZE.detectAndCompute/1","doc":"","ref":"Evision.KAZE.html#detectAndCompute/1"},{"type":"function","title":"Evision.KAZE.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.KAZE.html#detectAndCompute/3"},{"type":"function","title":"Evision.KAZE.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.KAZE.html#detectAndCompute/4"},{"type":"function","title":"Evision.KAZE.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.KAZE.html#empty/1"},{"type":"function","title":"Evision.KAZE.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.KAZE.html#getDefaultName/1"},{"type":"function","title":"Evision.KAZE.getDiffusivity/1","doc":"getDiffusivity\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n\n##### Return\n- **retval**: `KAZE::DiffusivityType`\n\nPython prototype (for reference only):\n```python3\ngetDiffusivity() -> retval\n```","ref":"Evision.KAZE.html#getDiffusivity/1"},{"type":"function","title":"Evision.KAZE.getExtended/1","doc":"getExtended\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetExtended() -> retval\n```","ref":"Evision.KAZE.html#getExtended/1"},{"type":"function","title":"Evision.KAZE.getNOctaveLayers/1","doc":"getNOctaveLayers\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNOctaveLayers() -> retval\n```","ref":"Evision.KAZE.html#getNOctaveLayers/1"},{"type":"function","title":"Evision.KAZE.getNOctaves/1","doc":"getNOctaves\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNOctaves() -> retval\n```","ref":"Evision.KAZE.html#getNOctaves/1"},{"type":"function","title":"Evision.KAZE.getThreshold/1","doc":"getThreshold\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetThreshold() -> retval\n```","ref":"Evision.KAZE.html#getThreshold/1"},{"type":"function","title":"Evision.KAZE.getUpright/1","doc":"getUpright\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetUpright() -> retval\n```","ref":"Evision.KAZE.html#getUpright/1"},{"type":"function","title":"Evision.KAZE.read/1","doc":"","ref":"Evision.KAZE.html#read/1"},{"type":"function","title":"Evision.KAZE.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.KAZE.html#read/2"},{"type":"function","title":"Evision.KAZE.setDiffusivity/1","doc":"","ref":"Evision.KAZE.html#setDiffusivity/1"},{"type":"function","title":"Evision.KAZE.setDiffusivity/2","doc":"setDiffusivity\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n- **diff**: `KAZE_DiffusivityType`\n\nPython prototype (for reference only):\n```python3\nsetDiffusivity(diff) -> None\n```","ref":"Evision.KAZE.html#setDiffusivity/2"},{"type":"function","title":"Evision.KAZE.setExtended/1","doc":"","ref":"Evision.KAZE.html#setExtended/1"},{"type":"function","title":"Evision.KAZE.setExtended/2","doc":"setExtended\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n- **extended**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetExtended(extended) -> None\n```","ref":"Evision.KAZE.html#setExtended/2"},{"type":"function","title":"Evision.KAZE.setNOctaveLayers/1","doc":"","ref":"Evision.KAZE.html#setNOctaveLayers/1"},{"type":"function","title":"Evision.KAZE.setNOctaveLayers/2","doc":"setNOctaveLayers\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n- **octaveLayers**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNOctaveLayers(octaveLayers) -> None\n```","ref":"Evision.KAZE.html#setNOctaveLayers/2"},{"type":"function","title":"Evision.KAZE.setNOctaves/1","doc":"","ref":"Evision.KAZE.html#setNOctaves/1"},{"type":"function","title":"Evision.KAZE.setNOctaves/2","doc":"setNOctaves\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n- **octaves**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNOctaves(octaves) -> None\n```","ref":"Evision.KAZE.html#setNOctaves/2"},{"type":"function","title":"Evision.KAZE.setThreshold/1","doc":"","ref":"Evision.KAZE.html#setThreshold/1"},{"type":"function","title":"Evision.KAZE.setThreshold/2","doc":"setThreshold\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n- **threshold**: `double`\n\nPython prototype (for reference only):\n```python3\nsetThreshold(threshold) -> None\n```","ref":"Evision.KAZE.html#setThreshold/2"},{"type":"function","title":"Evision.KAZE.setUpright/1","doc":"","ref":"Evision.KAZE.html#setUpright/1"},{"type":"function","title":"Evision.KAZE.setUpright/2","doc":"setUpright\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n- **upright**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetUpright(upright) -> None\n```","ref":"Evision.KAZE.html#setUpright/2"},{"type":"function","title":"Evision.KAZE.write/1","doc":"","ref":"Evision.KAZE.html#write/1"},{"type":"function","title":"Evision.KAZE.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.KAZE.html#write/2"},{"type":"function","title":"Evision.KAZE.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.KAZE.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.KAZE.html#write/3"},{"type":"type","title":"Evision.KAZE.t/0","doc":"Type that represents an `KAZE` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.KAZE.html#t:t/0"},{"type":"module","title":"Evision.KAZE.DiffusivityType","doc":"","ref":"Evision.KAZE.DiffusivityType.html"},{"type":"function","title":"Evision.KAZE.DiffusivityType.cv_DIFF_CHARBONNIER/0","doc":"","ref":"Evision.KAZE.DiffusivityType.html#cv_DIFF_CHARBONNIER/0"},{"type":"function","title":"Evision.KAZE.DiffusivityType.cv_DIFF_PM_G1/0","doc":"","ref":"Evision.KAZE.DiffusivityType.html#cv_DIFF_PM_G1/0"},{"type":"function","title":"Evision.KAZE.DiffusivityType.cv_DIFF_PM_G2/0","doc":"","ref":"Evision.KAZE.DiffusivityType.html#cv_DIFF_PM_G2/0"},{"type":"function","title":"Evision.KAZE.DiffusivityType.cv_DIFF_WEICKERT/0","doc":"","ref":"Evision.KAZE.DiffusivityType.html#cv_DIFF_WEICKERT/0"},{"type":"type","title":"Evision.KAZE.DiffusivityType.enum/0","doc":"","ref":"Evision.KAZE.DiffusivityType.html#t:enum/0"},{"type":"module","title":"Evision.KalmanFilter","doc":"","ref":"Evision.KalmanFilter.html"},{"type":"function","title":"Evision.KalmanFilter.correct/1","doc":"","ref":"Evision.KalmanFilter.html#correct/1"},{"type":"function","title":"Evision.KalmanFilter.correct/2","doc":"Updates the predicted state from the measurement.\n\n##### Positional Arguments\n- **self**: `Evision.KalmanFilter.t()`\n- **measurement**: `Evision.Mat`.\n\n  The measured system parameters\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ncorrect(measurement) -> retval\n```","ref":"Evision.KalmanFilter.html#correct/2"},{"type":"function","title":"Evision.KalmanFilter.get_controlMatrix/1","doc":"","ref":"Evision.KalmanFilter.html#get_controlMatrix/1"},{"type":"function","title":"Evision.KalmanFilter.get_errorCovPost/1","doc":"","ref":"Evision.KalmanFilter.html#get_errorCovPost/1"},{"type":"function","title":"Evision.KalmanFilter.get_errorCovPre/1","doc":"","ref":"Evision.KalmanFilter.html#get_errorCovPre/1"},{"type":"function","title":"Evision.KalmanFilter.get_gain/1","doc":"","ref":"Evision.KalmanFilter.html#get_gain/1"},{"type":"function","title":"Evision.KalmanFilter.get_measurementMatrix/1","doc":"","ref":"Evision.KalmanFilter.html#get_measurementMatrix/1"},{"type":"function","title":"Evision.KalmanFilter.get_measurementNoiseCov/1","doc":"","ref":"Evision.KalmanFilter.html#get_measurementNoiseCov/1"},{"type":"function","title":"Evision.KalmanFilter.get_processNoiseCov/1","doc":"","ref":"Evision.KalmanFilter.html#get_processNoiseCov/1"},{"type":"function","title":"Evision.KalmanFilter.get_statePost/1","doc":"","ref":"Evision.KalmanFilter.html#get_statePost/1"},{"type":"function","title":"Evision.KalmanFilter.get_statePre/1","doc":"","ref":"Evision.KalmanFilter.html#get_statePre/1"},{"type":"function","title":"Evision.KalmanFilter.get_transitionMatrix/1","doc":"","ref":"Evision.KalmanFilter.html#get_transitionMatrix/1"},{"type":"function","title":"Evision.KalmanFilter.kalmanFilter/0","doc":"KalmanFilter\n##### Return\n- **self**: `Evision.KalmanFilter.t()`\n\nPython prototype (for reference only):\n```python3\nKalmanFilter() ->  \n```","ref":"Evision.KalmanFilter.html#kalmanFilter/0"},{"type":"function","title":"Evision.KalmanFilter.kalmanFilter/1","doc":"","ref":"Evision.KalmanFilter.html#kalmanFilter/1"},{"type":"function","title":"Evision.KalmanFilter.kalmanFilter/2","doc":"KalmanFilter\n\n##### Positional Arguments\n- **dynamParams**: `integer()`.\n\n  Dimensionality of the state.\n\n- **measureParams**: `integer()`.\n\n  Dimensionality of the measurement.\n\n##### Keyword Arguments\n- **controlParams**: `integer()`.\n\n  Dimensionality of the control vector.\n\n- **type**: `integer()`.\n\n  Type of the created matrices that should be CV_32F or CV_64F.\n\n##### Return\n- **self**: `Evision.KalmanFilter.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nKalmanFilter(dynamParams, measureParams[, controlParams[, type]]) ->  \n```","ref":"Evision.KalmanFilter.html#kalmanFilter/2"},{"type":"function","title":"Evision.KalmanFilter.kalmanFilter/3","doc":"KalmanFilter\n\n##### Positional Arguments\n- **dynamParams**: `integer()`.\n\n  Dimensionality of the state.\n\n- **measureParams**: `integer()`.\n\n  Dimensionality of the measurement.\n\n##### Keyword Arguments\n- **controlParams**: `integer()`.\n\n  Dimensionality of the control vector.\n\n- **type**: `integer()`.\n\n  Type of the created matrices that should be CV_32F or CV_64F.\n\n##### Return\n- **self**: `Evision.KalmanFilter.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nKalmanFilter(dynamParams, measureParams[, controlParams[, type]]) ->  \n```","ref":"Evision.KalmanFilter.html#kalmanFilter/3"},{"type":"function","title":"Evision.KalmanFilter.predict/1","doc":"Computes a predicted state.\n\n##### Positional Arguments\n- **self**: `Evision.KalmanFilter.t()`\n\n##### Keyword Arguments\n- **control**: `Evision.Mat`.\n\n  The optional input control\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\npredict([, control]) -> retval\n```","ref":"Evision.KalmanFilter.html#predict/1"},{"type":"function","title":"Evision.KalmanFilter.predict/2","doc":"Computes a predicted state.\n\n##### Positional Arguments\n- **self**: `Evision.KalmanFilter.t()`\n\n##### Keyword Arguments\n- **control**: `Evision.Mat`.\n\n  The optional input control\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\npredict([, control]) -> retval\n```","ref":"Evision.KalmanFilter.html#predict/2"},{"type":"function","title":"Evision.KalmanFilter.set_controlMatrix/2","doc":"","ref":"Evision.KalmanFilter.html#set_controlMatrix/2"},{"type":"function","title":"Evision.KalmanFilter.set_errorCovPost/2","doc":"","ref":"Evision.KalmanFilter.html#set_errorCovPost/2"},{"type":"function","title":"Evision.KalmanFilter.set_errorCovPre/2","doc":"","ref":"Evision.KalmanFilter.html#set_errorCovPre/2"},{"type":"function","title":"Evision.KalmanFilter.set_gain/2","doc":"","ref":"Evision.KalmanFilter.html#set_gain/2"},{"type":"function","title":"Evision.KalmanFilter.set_measurementMatrix/2","doc":"","ref":"Evision.KalmanFilter.html#set_measurementMatrix/2"},{"type":"function","title":"Evision.KalmanFilter.set_measurementNoiseCov/2","doc":"","ref":"Evision.KalmanFilter.html#set_measurementNoiseCov/2"},{"type":"function","title":"Evision.KalmanFilter.set_processNoiseCov/2","doc":"","ref":"Evision.KalmanFilter.html#set_processNoiseCov/2"},{"type":"function","title":"Evision.KalmanFilter.set_statePost/2","doc":"","ref":"Evision.KalmanFilter.html#set_statePost/2"},{"type":"function","title":"Evision.KalmanFilter.set_statePre/2","doc":"","ref":"Evision.KalmanFilter.html#set_statePre/2"},{"type":"function","title":"Evision.KalmanFilter.set_transitionMatrix/2","doc":"","ref":"Evision.KalmanFilter.html#set_transitionMatrix/2"},{"type":"type","title":"Evision.KalmanFilter.t/0","doc":"Type that represents an `KalmanFilter` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.KalmanFilter.html#t:t/0"},{"type":"module","title":"Evision.KeyPoint","doc":"","ref":"Evision.KeyPoint.html"},{"type":"function","title":"Evision.KeyPoint.convert/1","doc":"convert\n\n##### Positional Arguments\n- **points2f**: `[Point2f]`.\n\n  Array of (x,y) coordinates of each keypoint\n\n##### Keyword Arguments\n- **size**: `float`.\n\n  keypoint diameter\n\n- **response**: `float`.\n\n  keypoint detector response on the keypoint (that is, strength of the keypoint)\n\n- **octave**: `integer()`.\n\n  pyramid octave in which the keypoint has been detected\n\n- **class_id**: `integer()`.\n\n  object id\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Keypoints obtained from any feature detection algorithm like SIFT/SURF/ORB\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nconvert(points2f[, size[, response[, octave[, class_id]]]]) -> keypoints\n```","ref":"Evision.KeyPoint.html#convert/1"},{"type":"function","title":"Evision.KeyPoint.convert/2","doc":"convert\n\n##### Positional Arguments\n- **points2f**: `[Point2f]`.\n\n  Array of (x,y) coordinates of each keypoint\n\n##### Keyword Arguments\n- **size**: `float`.\n\n  keypoint diameter\n\n- **response**: `float`.\n\n  keypoint detector response on the keypoint (that is, strength of the keypoint)\n\n- **octave**: `integer()`.\n\n  pyramid octave in which the keypoint has been detected\n\n- **class_id**: `integer()`.\n\n  object id\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Keypoints obtained from any feature detection algorithm like SIFT/SURF/ORB\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nconvert(points2f[, size[, response[, octave[, class_id]]]]) -> keypoints\n```","ref":"Evision.KeyPoint.html#convert/2"},{"type":"function","title":"Evision.KeyPoint.get_angle/1","doc":"","ref":"Evision.KeyPoint.html#get_angle/1"},{"type":"function","title":"Evision.KeyPoint.get_class_id/1","doc":"","ref":"Evision.KeyPoint.html#get_class_id/1"},{"type":"function","title":"Evision.KeyPoint.get_octave/1","doc":"","ref":"Evision.KeyPoint.html#get_octave/1"},{"type":"function","title":"Evision.KeyPoint.get_pt/1","doc":"","ref":"Evision.KeyPoint.html#get_pt/1"},{"type":"function","title":"Evision.KeyPoint.get_response/1","doc":"","ref":"Evision.KeyPoint.html#get_response/1"},{"type":"function","title":"Evision.KeyPoint.get_size/1","doc":"","ref":"Evision.KeyPoint.html#get_size/1"},{"type":"function","title":"Evision.KeyPoint.keyPoint/0","doc":"KeyPoint\n##### Return\n- **self**: `Evision.KeyPoint.t()`\n\nPython prototype (for reference only):\n```python3\nKeyPoint() ->  \n```","ref":"Evision.KeyPoint.html#keyPoint/0"},{"type":"function","title":"Evision.KeyPoint.keyPoint/1","doc":"","ref":"Evision.KeyPoint.html#keyPoint/1"},{"type":"function","title":"Evision.KeyPoint.keyPoint/3","doc":"KeyPoint\n\n##### Positional Arguments\n- **x**: `float`.\n\n  x-coordinate of the keypoint\n\n- **y**: `float`.\n\n  y-coordinate of the keypoint\n\n- **size**: `float`.\n\n  keypoint diameter\n\n##### Keyword Arguments\n- **angle**: `float`.\n\n  keypoint orientation\n\n- **response**: `float`.\n\n  keypoint detector response on the keypoint (that is, strength of the keypoint)\n\n- **octave**: `integer()`.\n\n  pyramid octave in which the keypoint has been detected\n\n- **class_id**: `integer()`.\n\n  object id\n\n##### Return\n- **self**: `Evision.KeyPoint.t()`\n\nPython prototype (for reference only):\n```python3\nKeyPoint(x, y, size[, angle[, response[, octave[, class_id]]]]) ->  \n```","ref":"Evision.KeyPoint.html#keyPoint/3"},{"type":"function","title":"Evision.KeyPoint.keyPoint/4","doc":"KeyPoint\n\n##### Positional Arguments\n- **x**: `float`.\n\n  x-coordinate of the keypoint\n\n- **y**: `float`.\n\n  y-coordinate of the keypoint\n\n- **size**: `float`.\n\n  keypoint diameter\n\n##### Keyword Arguments\n- **angle**: `float`.\n\n  keypoint orientation\n\n- **response**: `float`.\n\n  keypoint detector response on the keypoint (that is, strength of the keypoint)\n\n- **octave**: `integer()`.\n\n  pyramid octave in which the keypoint has been detected\n\n- **class_id**: `integer()`.\n\n  object id\n\n##### Return\n- **self**: `Evision.KeyPoint.t()`\n\nPython prototype (for reference only):\n```python3\nKeyPoint(x, y, size[, angle[, response[, octave[, class_id]]]]) ->  \n```","ref":"Evision.KeyPoint.html#keyPoint/4"},{"type":"function","title":"Evision.KeyPoint.overlap/1","doc":"","ref":"Evision.KeyPoint.html#overlap/1"},{"type":"function","title":"Evision.KeyPoint.overlap/2","doc":"overlap\n\n##### Positional Arguments\n- **kp1**: `Evision.KeyPoint`.\n\n  First keypoint\n\n- **kp2**: `Evision.KeyPoint`.\n\n  Second keypoint\n\n##### Return\n- **retval**: `float`\n\nThis method computes overlap for pair of keypoints. Overlap is the ratio between area of keypoint\nregions' intersection and area of keypoint regions' union (considering keypoint region as circle).\nIf they don't overlap, we get zero. If they coincide at same location with same size, we get 1.\n\nPython prototype (for reference only):\n```python3\noverlap(kp1, kp2) -> retval\n```","ref":"Evision.KeyPoint.html#overlap/2"},{"type":"function","title":"Evision.KeyPoint.set_angle/2","doc":"","ref":"Evision.KeyPoint.html#set_angle/2"},{"type":"function","title":"Evision.KeyPoint.set_class_id/2","doc":"","ref":"Evision.KeyPoint.html#set_class_id/2"},{"type":"function","title":"Evision.KeyPoint.set_octave/2","doc":"","ref":"Evision.KeyPoint.html#set_octave/2"},{"type":"function","title":"Evision.KeyPoint.set_pt/2","doc":"","ref":"Evision.KeyPoint.html#set_pt/2"},{"type":"function","title":"Evision.KeyPoint.set_response/2","doc":"","ref":"Evision.KeyPoint.html#set_response/2"},{"type":"function","title":"Evision.KeyPoint.set_size/2","doc":"","ref":"Evision.KeyPoint.html#set_size/2"},{"type":"type","title":"Evision.KeyPoint.t/0","doc":"Type that represents an `KeyPoint` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.KeyPoint.html#t:t/0"},{"type":"module","title":"Evision.KinFu","doc":"","ref":"Evision.KinFu.html"},{"type":"function","title":"Evision.KinFu.makeVolume/1","doc":"","ref":"Evision.KinFu.html#makeVolume/1"},{"type":"function","title":"Evision.KinFu.makeVolume/8","doc":"makeVolume\n\n##### Positional Arguments\n- **volumeType**: `VolumeType`\n- **voxelSize**: `float`\n- **pose**: `Evision.Mat`\n- **raycastStepFactor**: `float`\n- **truncDist**: `float`\n- **maxWeight**: `integer()`\n- **truncateThreshold**: `float`\n- **resolution**: `Vec3i`\n\n##### Return\n- **retval**: `Volume`\n\nPython prototype (for reference only):\n```python3\nmakeVolume(_volumeType, _voxelSize, _pose, _raycastStepFactor, _truncDist, _maxWeight, _truncateThreshold, _resolution) -> retval\n```","ref":"Evision.KinFu.html#makeVolume/8"},{"type":"type","title":"Evision.KinFu.t/0","doc":"Type that represents an `KinFu` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.KinFu.html#t:t/0"},{"type":"module","title":"Evision.KinFu.Detail.PoseGraph","doc":"","ref":"Evision.KinFu.Detail.PoseGraph.html"},{"type":"type","title":"Evision.KinFu.Detail.PoseGraph.t/0","doc":"Type that represents an `KinFu.Detail.PoseGraph` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.KinFu.Detail.PoseGraph.html#t:t/0"},{"type":"module","title":"Evision.KinFu.KinFu","doc":"","ref":"Evision.KinFu.KinFu.html"},{"type":"function","title":"Evision.KinFu.KinFu.create/1","doc":"create\n\n##### Positional Arguments\n- **params**: `Params`\n\n##### Return\n- **retval**: `KinFu`\n\nPython prototype (for reference only):\n```python3\ncreate(_params) -> retval\n```","ref":"Evision.KinFu.KinFu.html#create/1"},{"type":"function","title":"Evision.KinFu.KinFu.getCloud/1","doc":"Gets points and normals of current 3d mesh\n\n##### Positional Arguments\n- **self**: `Evision.KinFu.KinFu.t()`\n\n##### Return\n- **points**: `Evision.Mat.t()`.\n\n  vector of points which are 4-float vectors\n\n- **normals**: `Evision.Mat.t()`.\n\n  vector of normals which are 4-float vectors\n\nThe order of normals corresponds to order of points.\nThe order of points is undefined.\n\nPython prototype (for reference only):\n```python3\ngetCloud([, points[, normals]]) -> points, normals\n```","ref":"Evision.KinFu.KinFu.html#getCloud/1"},{"type":"function","title":"Evision.KinFu.KinFu.getCloud/2","doc":"Gets points and normals of current 3d mesh\n\n##### Positional Arguments\n- **self**: `Evision.KinFu.KinFu.t()`\n\n##### Return\n- **points**: `Evision.Mat.t()`.\n\n  vector of points which are 4-float vectors\n\n- **normals**: `Evision.Mat.t()`.\n\n  vector of normals which are 4-float vectors\n\nThe order of normals corresponds to order of points.\nThe order of points is undefined.\n\nPython prototype (for reference only):\n```python3\ngetCloud([, points[, normals]]) -> points, normals\n```","ref":"Evision.KinFu.KinFu.html#getCloud/2"},{"type":"function","title":"Evision.KinFu.KinFu.getNormals/1","doc":"","ref":"Evision.KinFu.KinFu.html#getNormals/1"},{"type":"function","title":"Evision.KinFu.KinFu.getNormals/2","doc":"Calculates normals for given points\n\n##### Positional Arguments\n- **self**: `Evision.KinFu.KinFu.t()`\n- **points**: `Evision.Mat`.\n\n  input vector of points which are 4-float vectors\n\n##### Return\n- **normals**: `Evision.Mat.t()`.\n\n  output vector of corresponding normals which are 4-float vectors\n\nPython prototype (for reference only):\n```python3\ngetNormals(points[, normals]) -> normals\n```","ref":"Evision.KinFu.KinFu.html#getNormals/2"},{"type":"function","title":"Evision.KinFu.KinFu.getNormals/3","doc":"Calculates normals for given points\n\n##### Positional Arguments\n- **self**: `Evision.KinFu.KinFu.t()`\n- **points**: `Evision.Mat`.\n\n  input vector of points which are 4-float vectors\n\n##### Return\n- **normals**: `Evision.Mat.t()`.\n\n  output vector of corresponding normals which are 4-float vectors\n\nPython prototype (for reference only):\n```python3\ngetNormals(points[, normals]) -> normals\n```","ref":"Evision.KinFu.KinFu.html#getNormals/3"},{"type":"function","title":"Evision.KinFu.KinFu.getPoints/1","doc":"Gets points of current 3d mesh\n\n##### Positional Arguments\n- **self**: `Evision.KinFu.KinFu.t()`\n\n##### Return\n- **points**: `Evision.Mat.t()`.\n\n  vector of points which are 4-float vectors\n\nThe order of points is undefined.\n\nPython prototype (for reference only):\n```python3\ngetPoints([, points]) -> points\n```","ref":"Evision.KinFu.KinFu.html#getPoints/1"},{"type":"function","title":"Evision.KinFu.KinFu.getPoints/2","doc":"Gets points of current 3d mesh\n\n##### Positional Arguments\n- **self**: `Evision.KinFu.KinFu.t()`\n\n##### Return\n- **points**: `Evision.Mat.t()`.\n\n  vector of points which are 4-float vectors\n\nThe order of points is undefined.\n\nPython prototype (for reference only):\n```python3\ngetPoints([, points]) -> points\n```","ref":"Evision.KinFu.KinFu.html#getPoints/2"},{"type":"function","title":"Evision.KinFu.KinFu.render/1","doc":"Renders a volume into an image\n\n##### Positional Arguments\n- **self**: `Evision.KinFu.KinFu.t()`\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  resulting image\n\nRenders a 0-surface of TSDF using Phong shading into a CV_8UC4 Mat.\nLight pose is fixed in KinFu params.\n\nPython prototype (for reference only):\n```python3\nrender([, image]) -> image\n```","ref":"Evision.KinFu.KinFu.html#render/1"},{"type":"function","title":"Evision.KinFu.KinFu.render/2","doc":"#### Variant 1:\nRenders a volume into an image\n\n##### Positional Arguments\n- **self**: `Evision.KinFu.KinFu.t()`\n- **cameraPose**: `Evision.Mat`.\n\n  pose of camera to render from. If empty then render from current pose\n  which is a last frame camera pose.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  resulting image\n\nRenders a 0-surface of TSDF using Phong shading into a CV_8UC4 Mat.\nLight pose is fixed in KinFu params.\n\nPython prototype (for reference only):\n```python3\nrender(cameraPose[, image]) -> image\n```\n#### Variant 2:\nRenders a volume into an image\n\n##### Positional Arguments\n- **self**: `Evision.KinFu.KinFu.t()`\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  resulting image\n\nRenders a 0-surface of TSDF using Phong shading into a CV_8UC4 Mat.\nLight pose is fixed in KinFu params.\n\nPython prototype (for reference only):\n```python3\nrender([, image]) -> image\n```","ref":"Evision.KinFu.KinFu.html#render/2"},{"type":"function","title":"Evision.KinFu.KinFu.render/3","doc":"Renders a volume into an image\n\n##### Positional Arguments\n- **self**: `Evision.KinFu.KinFu.t()`\n- **cameraPose**: `Evision.Mat`.\n\n  pose of camera to render from. If empty then render from current pose\n  which is a last frame camera pose.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  resulting image\n\nRenders a 0-surface of TSDF using Phong shading into a CV_8UC4 Mat.\nLight pose is fixed in KinFu params.\n\nPython prototype (for reference only):\n```python3\nrender(cameraPose[, image]) -> image\n```","ref":"Evision.KinFu.KinFu.html#render/3"},{"type":"function","title":"Evision.KinFu.KinFu.reset/1","doc":"Resets the algorithm\n\n##### Positional Arguments\n- **self**: `Evision.KinFu.KinFu.t()`\n\nClears current model and resets a pose.\n\nPython prototype (for reference only):\n```python3\nreset() -> None\n```","ref":"Evision.KinFu.KinFu.html#reset/1"},{"type":"function","title":"Evision.KinFu.KinFu.update/1","doc":"","ref":"Evision.KinFu.KinFu.html#update/1"},{"type":"function","title":"Evision.KinFu.KinFu.update/2","doc":"Process next depth frame\n\n##### Positional Arguments\n- **self**: `Evision.KinFu.KinFu.t()`\n- **depth**: `Evision.Mat`.\n\n  one-channel image which size and depth scale is described in algorithm's parameters\n\n##### Return\n- **retval**: `bool`\n\nIntegrates depth into voxel space with respect to its ICP-calculated pose.\nInput image is converted to CV_32F internally if has another type.\n@return true if succeeded to align new frame with current scene, false if opposite\n\nPython prototype (for reference only):\n```python3\nupdate(depth) -> retval\n```","ref":"Evision.KinFu.KinFu.html#update/2"},{"type":"type","title":"Evision.KinFu.KinFu.t/0","doc":"Type that represents an `KinFu.KinFu` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.KinFu.KinFu.html#t:t/0"},{"type":"module","title":"Evision.KinFu.Params","doc":"","ref":"Evision.KinFu.Params.html"},{"type":"function","title":"Evision.KinFu.Params.coarseParams/0","doc":"Coarse parameters\nA set of parameters which provides better speed, can fail to match frames\nin case of rapid sensor motion.\n\n##### Return\n- **retval**: `Params`\n\nPython prototype (for reference only):\n```python3\ncoarseParams() -> retval\n```","ref":"Evision.KinFu.Params.html#coarseParams/0"},{"type":"function","title":"Evision.KinFu.Params.coarseParams/1","doc":"","ref":"Evision.KinFu.Params.html#coarseParams/1"},{"type":"function","title":"Evision.KinFu.Params.coloredTSDFParams/1","doc":"ColoredTSDF parameters\nA set of parameters suitable for use with ColoredTSDFVolume\n\n##### Positional Arguments\n- **isCoarse**: `bool`\n\n##### Return\n- **retval**: `Params`\n\nPython prototype (for reference only):\n```python3\ncoloredTSDFParams(isCoarse) -> retval\n```","ref":"Evision.KinFu.Params.html#coloredTSDFParams/1"},{"type":"function","title":"Evision.KinFu.Params.defaultParams/0","doc":"Default parameters\nA set of parameters which provides better model quality, can be very slow.\n\n##### Return\n- **retval**: `Params`\n\nPython prototype (for reference only):\n```python3\ndefaultParams() -> retval\n```","ref":"Evision.KinFu.Params.html#defaultParams/0"},{"type":"function","title":"Evision.KinFu.Params.defaultParams/1","doc":"","ref":"Evision.KinFu.Params.html#defaultParams/1"},{"type":"function","title":"Evision.KinFu.Params.get_bilateral_kernel_size/1","doc":"","ref":"Evision.KinFu.Params.html#get_bilateral_kernel_size/1"},{"type":"function","title":"Evision.KinFu.Params.get_bilateral_sigma_depth/1","doc":"","ref":"Evision.KinFu.Params.html#get_bilateral_sigma_depth/1"},{"type":"function","title":"Evision.KinFu.Params.get_bilateral_sigma_spatial/1","doc":"","ref":"Evision.KinFu.Params.html#get_bilateral_sigma_spatial/1"},{"type":"function","title":"Evision.KinFu.Params.get_depthFactor/1","doc":"","ref":"Evision.KinFu.Params.html#get_depthFactor/1"},{"type":"function","title":"Evision.KinFu.Params.get_frameSize/1","doc":"","ref":"Evision.KinFu.Params.html#get_frameSize/1"},{"type":"function","title":"Evision.KinFu.Params.get_icpAngleThresh/1","doc":"","ref":"Evision.KinFu.Params.html#get_icpAngleThresh/1"},{"type":"function","title":"Evision.KinFu.Params.get_icpDistThresh/1","doc":"","ref":"Evision.KinFu.Params.html#get_icpDistThresh/1"},{"type":"function","title":"Evision.KinFu.Params.get_icpIterations/1","doc":"","ref":"Evision.KinFu.Params.html#get_icpIterations/1"},{"type":"function","title":"Evision.KinFu.Params.get_intr/1","doc":"","ref":"Evision.KinFu.Params.html#get_intr/1"},{"type":"function","title":"Evision.KinFu.Params.get_lightPose/1","doc":"","ref":"Evision.KinFu.Params.html#get_lightPose/1"},{"type":"function","title":"Evision.KinFu.Params.get_pyramidLevels/1","doc":"","ref":"Evision.KinFu.Params.html#get_pyramidLevels/1"},{"type":"function","title":"Evision.KinFu.Params.get_raycast_step_factor/1","doc":"","ref":"Evision.KinFu.Params.html#get_raycast_step_factor/1"},{"type":"function","title":"Evision.KinFu.Params.get_rgb_intr/1","doc":"","ref":"Evision.KinFu.Params.html#get_rgb_intr/1"},{"type":"function","title":"Evision.KinFu.Params.get_truncateThreshold/1","doc":"","ref":"Evision.KinFu.Params.html#get_truncateThreshold/1"},{"type":"function","title":"Evision.KinFu.Params.get_tsdf_max_weight/1","doc":"","ref":"Evision.KinFu.Params.html#get_tsdf_max_weight/1"},{"type":"function","title":"Evision.KinFu.Params.get_tsdf_min_camera_movement/1","doc":"","ref":"Evision.KinFu.Params.html#get_tsdf_min_camera_movement/1"},{"type":"function","title":"Evision.KinFu.Params.get_tsdf_trunc_dist/1","doc":"","ref":"Evision.KinFu.Params.html#get_tsdf_trunc_dist/1"},{"type":"function","title":"Evision.KinFu.Params.get_volumeDims/1","doc":"","ref":"Evision.KinFu.Params.html#get_volumeDims/1"},{"type":"function","title":"Evision.KinFu.Params.get_volumeType/1","doc":"","ref":"Evision.KinFu.Params.html#get_volumeType/1"},{"type":"function","title":"Evision.KinFu.Params.get_voxelSize/1","doc":"","ref":"Evision.KinFu.Params.html#get_voxelSize/1"},{"type":"function","title":"Evision.KinFu.Params.hashTSDFParams/1","doc":"HashTSDF parameters\nA set of parameters suitable for use with HashTSDFVolume\n\n##### Positional Arguments\n- **isCoarse**: `bool`\n\n##### Return\n- **retval**: `Params`\n\nPython prototype (for reference only):\n```python3\nhashTSDFParams(isCoarse) -> retval\n```","ref":"Evision.KinFu.Params.html#hashTSDFParams/1"},{"type":"function","title":"Evision.KinFu.Params.params/0","doc":"Params\n##### Return\n- **self**: `Params`\n\nPython prototype (for reference only):\n```python3\nParams() ->  \n```","ref":"Evision.KinFu.Params.html#params/0"},{"type":"function","title":"Evision.KinFu.Params.params/1","doc":"Constructor for Params\nSets the initial pose of the TSDF volume.\n\n##### Positional Arguments\n- **volumeInitialPose**: `Evision.Mat`.\n\n  4 by 4 Homogeneous Transform matrix to set the intial pose of TSDF volume\n\n##### Return\n- **self**: `Params`\n\nPython prototype (for reference only):\n```python3\nParams(volumeInitialPose) ->  \n```","ref":"Evision.KinFu.Params.html#params/1"},{"type":"function","title":"Evision.KinFu.Params.params/2","doc":"Constructor for Params\nSets the initial pose of the TSDF volume.\n\n##### Positional Arguments\n- **volumeInitialPoseRot**: `Evision.Mat`.\n\n  rotation matrix\n\n- **volumeInitialPoseTransl**: `Vec3f`.\n\n  translation vector\n\n##### Return\n- **self**: `Params`\n\nPython prototype (for reference only):\n```python3\nParams(volumeInitialPoseRot, volumeInitialPoseTransl) ->  \n```","ref":"Evision.KinFu.Params.html#params/2"},{"type":"function","title":"Evision.KinFu.Params.set_bilateral_kernel_size/2","doc":"","ref":"Evision.KinFu.Params.html#set_bilateral_kernel_size/2"},{"type":"function","title":"Evision.KinFu.Params.set_bilateral_sigma_depth/2","doc":"","ref":"Evision.KinFu.Params.html#set_bilateral_sigma_depth/2"},{"type":"function","title":"Evision.KinFu.Params.set_bilateral_sigma_spatial/2","doc":"","ref":"Evision.KinFu.Params.html#set_bilateral_sigma_spatial/2"},{"type":"function","title":"Evision.KinFu.Params.set_depthFactor/2","doc":"","ref":"Evision.KinFu.Params.html#set_depthFactor/2"},{"type":"function","title":"Evision.KinFu.Params.set_frameSize/2","doc":"","ref":"Evision.KinFu.Params.html#set_frameSize/2"},{"type":"function","title":"Evision.KinFu.Params.set_icpAngleThresh/2","doc":"","ref":"Evision.KinFu.Params.html#set_icpAngleThresh/2"},{"type":"function","title":"Evision.KinFu.Params.set_icpDistThresh/2","doc":"","ref":"Evision.KinFu.Params.html#set_icpDistThresh/2"},{"type":"function","title":"Evision.KinFu.Params.set_icpIterations/2","doc":"","ref":"Evision.KinFu.Params.html#set_icpIterations/2"},{"type":"function","title":"Evision.KinFu.Params.set_intr/2","doc":"","ref":"Evision.KinFu.Params.html#set_intr/2"},{"type":"function","title":"Evision.KinFu.Params.set_lightPose/2","doc":"","ref":"Evision.KinFu.Params.html#set_lightPose/2"},{"type":"function","title":"Evision.KinFu.Params.set_pyramidLevels/2","doc":"","ref":"Evision.KinFu.Params.html#set_pyramidLevels/2"},{"type":"function","title":"Evision.KinFu.Params.set_raycast_step_factor/2","doc":"","ref":"Evision.KinFu.Params.html#set_raycast_step_factor/2"},{"type":"function","title":"Evision.KinFu.Params.set_rgb_intr/2","doc":"","ref":"Evision.KinFu.Params.html#set_rgb_intr/2"},{"type":"function","title":"Evision.KinFu.Params.set_truncateThreshold/2","doc":"","ref":"Evision.KinFu.Params.html#set_truncateThreshold/2"},{"type":"function","title":"Evision.KinFu.Params.set_tsdf_max_weight/2","doc":"","ref":"Evision.KinFu.Params.html#set_tsdf_max_weight/2"},{"type":"function","title":"Evision.KinFu.Params.set_tsdf_min_camera_movement/2","doc":"","ref":"Evision.KinFu.Params.html#set_tsdf_min_camera_movement/2"},{"type":"function","title":"Evision.KinFu.Params.set_tsdf_trunc_dist/2","doc":"","ref":"Evision.KinFu.Params.html#set_tsdf_trunc_dist/2"},{"type":"function","title":"Evision.KinFu.Params.set_volumeDims/2","doc":"","ref":"Evision.KinFu.Params.html#set_volumeDims/2"},{"type":"function","title":"Evision.KinFu.Params.set_volumeType/2","doc":"","ref":"Evision.KinFu.Params.html#set_volumeType/2"},{"type":"function","title":"Evision.KinFu.Params.set_voxelSize/2","doc":"","ref":"Evision.KinFu.Params.html#set_voxelSize/2"},{"type":"function","title":"Evision.KinFu.Params.setInitialVolumePose/1","doc":"","ref":"Evision.KinFu.Params.html#setInitialVolumePose/1"},{"type":"function","title":"Evision.KinFu.Params.setInitialVolumePose/2","doc":"Set Initial Volume Pose\nSets the initial pose of the TSDF volume.\n\n##### Positional Arguments\n- **self**: `Evision.KinFu.Params.t()`\n- **homogen_tf**: `Evision.Mat`.\n\n  4 by 4 Homogeneous Transform matrix to set the intial pose of TSDF volume\n\nPython prototype (for reference only):\n```python3\nsetInitialVolumePose(homogen_tf) -> None\n```","ref":"Evision.KinFu.Params.html#setInitialVolumePose/2"},{"type":"function","title":"Evision.KinFu.Params.setInitialVolumePose/3","doc":"Set Initial Volume Pose\nSets the initial pose of the TSDF volume.\n\n##### Positional Arguments\n- **self**: `Evision.KinFu.Params.t()`\n- **r**: `Evision.Mat`.\n\n  rotation matrix\n\n- **t**: `Vec3f`.\n\n  translation vector\n\nPython prototype (for reference only):\n```python3\nsetInitialVolumePose(R, t) -> None\n```","ref":"Evision.KinFu.Params.html#setInitialVolumePose/3"},{"type":"type","title":"Evision.KinFu.Params.t/0","doc":"Type that represents an `KinFu.Params` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.KinFu.Params.html#t:t/0"},{"type":"module","title":"Evision.KinFu.Volume","doc":"","ref":"Evision.KinFu.Volume.html"},{"type":"type","title":"Evision.KinFu.Volume.t/0","doc":"Type that represents an `KinFu.Volume` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.KinFu.Volume.html#t:t/0"},{"type":"module","title":"Evision.KinFu.VolumeParams","doc":"","ref":"Evision.KinFu.VolumeParams.html"},{"type":"function","title":"Evision.KinFu.VolumeParams.coarseParams/1","doc":"Coarse set of parameters that provides relatively higher performance\nat the cost of reconstrution quality.\n\n##### Positional Arguments\n- **volumeType**: `VolumeType`\n\n##### Return\n- **retval**: `VolumeParams`\n\nPython prototype (for reference only):\n```python3\ncoarseParams(_volumeType) -> retval\n```","ref":"Evision.KinFu.VolumeParams.html#coarseParams/1"},{"type":"function","title":"Evision.KinFu.VolumeParams.defaultParams/1","doc":"Default set of parameters that provide higher quality reconstruction\nat the cost of slow performance.\n\n##### Positional Arguments\n- **volumeType**: `VolumeType`\n\n##### Return\n- **retval**: `VolumeParams`\n\nPython prototype (for reference only):\n```python3\ndefaultParams(_volumeType) -> retval\n```","ref":"Evision.KinFu.VolumeParams.html#defaultParams/1"},{"type":"function","title":"Evision.KinFu.VolumeParams.get_depthTruncThreshold/1","doc":"","ref":"Evision.KinFu.VolumeParams.html#get_depthTruncThreshold/1"},{"type":"function","title":"Evision.KinFu.VolumeParams.get_maxWeight/1","doc":"","ref":"Evision.KinFu.VolumeParams.html#get_maxWeight/1"},{"type":"function","title":"Evision.KinFu.VolumeParams.get_raycastStepFactor/1","doc":"","ref":"Evision.KinFu.VolumeParams.html#get_raycastStepFactor/1"},{"type":"function","title":"Evision.KinFu.VolumeParams.get_resolution/1","doc":"","ref":"Evision.KinFu.VolumeParams.html#get_resolution/1"},{"type":"function","title":"Evision.KinFu.VolumeParams.get_tsdfTruncDist/1","doc":"","ref":"Evision.KinFu.VolumeParams.html#get_tsdfTruncDist/1"},{"type":"function","title":"Evision.KinFu.VolumeParams.get_type/1","doc":"","ref":"Evision.KinFu.VolumeParams.html#get_type/1"},{"type":"function","title":"Evision.KinFu.VolumeParams.get_voxelSize/1","doc":"","ref":"Evision.KinFu.VolumeParams.html#get_voxelSize/1"},{"type":"function","title":"Evision.KinFu.VolumeParams.set_depthTruncThreshold/2","doc":"","ref":"Evision.KinFu.VolumeParams.html#set_depthTruncThreshold/2"},{"type":"function","title":"Evision.KinFu.VolumeParams.set_maxWeight/2","doc":"","ref":"Evision.KinFu.VolumeParams.html#set_maxWeight/2"},{"type":"function","title":"Evision.KinFu.VolumeParams.set_raycastStepFactor/2","doc":"","ref":"Evision.KinFu.VolumeParams.html#set_raycastStepFactor/2"},{"type":"function","title":"Evision.KinFu.VolumeParams.set_resolution/2","doc":"","ref":"Evision.KinFu.VolumeParams.html#set_resolution/2"},{"type":"function","title":"Evision.KinFu.VolumeParams.set_tsdfTruncDist/2","doc":"","ref":"Evision.KinFu.VolumeParams.html#set_tsdfTruncDist/2"},{"type":"function","title":"Evision.KinFu.VolumeParams.set_type/2","doc":"","ref":"Evision.KinFu.VolumeParams.html#set_type/2"},{"type":"function","title":"Evision.KinFu.VolumeParams.set_voxelSize/2","doc":"","ref":"Evision.KinFu.VolumeParams.html#set_voxelSize/2"},{"type":"type","title":"Evision.KinFu.VolumeParams.t/0","doc":"Type that represents an `KinFu.VolumeParams` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.KinFu.VolumeParams.html#t:t/0"},{"type":"module","title":"Evision.KinFu.VolumeType","doc":"","ref":"Evision.KinFu.VolumeType.html"},{"type":"function","title":"Evision.KinFu.VolumeType.cv_COLOREDTSDF/0","doc":"","ref":"Evision.KinFu.VolumeType.html#cv_COLOREDTSDF/0"},{"type":"function","title":"Evision.KinFu.VolumeType.cv_HASHTSDF/0","doc":"","ref":"Evision.KinFu.VolumeType.html#cv_HASHTSDF/0"},{"type":"function","title":"Evision.KinFu.VolumeType.cv_TSDF/0","doc":"","ref":"Evision.KinFu.VolumeType.html#cv_TSDF/0"},{"type":"type","title":"Evision.KinFu.VolumeType.enum/0","doc":"","ref":"Evision.KinFu.VolumeType.html#t:enum/0"},{"type":"module","title":"Evision.KmeansFlags","doc":"","ref":"Evision.KmeansFlags.html"},{"type":"function","title":"Evision.KmeansFlags.cv_KMEANS_PP_CENTERS/0","doc":"","ref":"Evision.KmeansFlags.html#cv_KMEANS_PP_CENTERS/0"},{"type":"function","title":"Evision.KmeansFlags.cv_KMEANS_RANDOM_CENTERS/0","doc":"","ref":"Evision.KmeansFlags.html#cv_KMEANS_RANDOM_CENTERS/0"},{"type":"function","title":"Evision.KmeansFlags.cv_KMEANS_USE_INITIAL_LABELS/0","doc":"","ref":"Evision.KmeansFlags.html#cv_KMEANS_USE_INITIAL_LABELS/0"},{"type":"type","title":"Evision.KmeansFlags.enum/0","doc":"","ref":"Evision.KmeansFlags.html#t:enum/0"},{"type":"module","title":"Evision.LargeKinfu","doc":"","ref":"Evision.LargeKinfu.html"},{"type":"type","title":"Evision.LargeKinfu.t/0","doc":"Type that represents an `LargeKinfu` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.LargeKinfu.html#t:t/0"},{"type":"module","title":"Evision.LargeKinfu.LargeKinfu","doc":"","ref":"Evision.LargeKinfu.LargeKinfu.html"},{"type":"function","title":"Evision.LargeKinfu.LargeKinfu.create/1","doc":"create\n\n##### Positional Arguments\n- **params**: `Params`\n\n##### Return\n- **retval**: `Evision.LargeKinfu.t()`\n\nPython prototype (for reference only):\n```python3\ncreate(_params) -> retval\n```","ref":"Evision.LargeKinfu.LargeKinfu.html#create/1"},{"type":"function","title":"Evision.LargeKinfu.LargeKinfu.getCloud/1","doc":"getCloud\n\n##### Positional Arguments\n- **self**: `Evision.LargeKinfu.LargeKinfu.t()`\n\n##### Return\n- **points**: `Evision.Mat.t()`.\n- **normals**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetCloud([, points[, normals]]) -> points, normals\n```","ref":"Evision.LargeKinfu.LargeKinfu.html#getCloud/1"},{"type":"function","title":"Evision.LargeKinfu.LargeKinfu.getCloud/2","doc":"getCloud\n\n##### Positional Arguments\n- **self**: `Evision.LargeKinfu.LargeKinfu.t()`\n\n##### Return\n- **points**: `Evision.Mat.t()`.\n- **normals**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetCloud([, points[, normals]]) -> points, normals\n```","ref":"Evision.LargeKinfu.LargeKinfu.html#getCloud/2"},{"type":"function","title":"Evision.LargeKinfu.LargeKinfu.getNormals/1","doc":"","ref":"Evision.LargeKinfu.LargeKinfu.html#getNormals/1"},{"type":"function","title":"Evision.LargeKinfu.LargeKinfu.getNormals/2","doc":"getNormals\n\n##### Positional Arguments\n- **self**: `Evision.LargeKinfu.LargeKinfu.t()`\n- **points**: `Evision.Mat`\n\n##### Return\n- **normals**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetNormals(points[, normals]) -> normals\n```","ref":"Evision.LargeKinfu.LargeKinfu.html#getNormals/2"},{"type":"function","title":"Evision.LargeKinfu.LargeKinfu.getNormals/3","doc":"getNormals\n\n##### Positional Arguments\n- **self**: `Evision.LargeKinfu.LargeKinfu.t()`\n- **points**: `Evision.Mat`\n\n##### Return\n- **normals**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetNormals(points[, normals]) -> normals\n```","ref":"Evision.LargeKinfu.LargeKinfu.html#getNormals/3"},{"type":"function","title":"Evision.LargeKinfu.LargeKinfu.getPoints/1","doc":"getPoints\n\n##### Positional Arguments\n- **self**: `Evision.LargeKinfu.LargeKinfu.t()`\n\n##### Return\n- **points**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetPoints([, points]) -> points\n```","ref":"Evision.LargeKinfu.LargeKinfu.html#getPoints/1"},{"type":"function","title":"Evision.LargeKinfu.LargeKinfu.getPoints/2","doc":"getPoints\n\n##### Positional Arguments\n- **self**: `Evision.LargeKinfu.LargeKinfu.t()`\n\n##### Return\n- **points**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetPoints([, points]) -> points\n```","ref":"Evision.LargeKinfu.LargeKinfu.html#getPoints/2"},{"type":"function","title":"Evision.LargeKinfu.LargeKinfu.render/1","doc":"render\n\n##### Positional Arguments\n- **self**: `Evision.LargeKinfu.LargeKinfu.t()`\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nrender([, image]) -> image\n```","ref":"Evision.LargeKinfu.LargeKinfu.html#render/1"},{"type":"function","title":"Evision.LargeKinfu.LargeKinfu.render/2","doc":"#### Variant 1:\nrender\n\n##### Positional Arguments\n- **self**: `Evision.LargeKinfu.LargeKinfu.t()`\n- **cameraPose**: `Evision.Mat`\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nrender(cameraPose[, image]) -> image\n```\n#### Variant 2:\nrender\n\n##### Positional Arguments\n- **self**: `Evision.LargeKinfu.LargeKinfu.t()`\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nrender([, image]) -> image\n```","ref":"Evision.LargeKinfu.LargeKinfu.html#render/2"},{"type":"function","title":"Evision.LargeKinfu.LargeKinfu.render/3","doc":"render\n\n##### Positional Arguments\n- **self**: `Evision.LargeKinfu.LargeKinfu.t()`\n- **cameraPose**: `Evision.Mat`\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nrender(cameraPose[, image]) -> image\n```","ref":"Evision.LargeKinfu.LargeKinfu.html#render/3"},{"type":"function","title":"Evision.LargeKinfu.LargeKinfu.reset/1","doc":"reset\n\n##### Positional Arguments\n- **self**: `Evision.LargeKinfu.LargeKinfu.t()`\n\nPython prototype (for reference only):\n```python3\nreset() -> None\n```","ref":"Evision.LargeKinfu.LargeKinfu.html#reset/1"},{"type":"function","title":"Evision.LargeKinfu.LargeKinfu.update/1","doc":"","ref":"Evision.LargeKinfu.LargeKinfu.html#update/1"},{"type":"function","title":"Evision.LargeKinfu.LargeKinfu.update/2","doc":"update\n\n##### Positional Arguments\n- **self**: `Evision.LargeKinfu.LargeKinfu.t()`\n- **depth**: `Evision.Mat`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nupdate(depth) -> retval\n```","ref":"Evision.LargeKinfu.LargeKinfu.html#update/2"},{"type":"type","title":"Evision.LargeKinfu.LargeKinfu.t/0","doc":"Type that represents an `LargeKinfu.LargeKinfu` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.LargeKinfu.LargeKinfu.html#t:t/0"},{"type":"module","title":"Evision.LargeKinfu.Params","doc":"","ref":"Evision.LargeKinfu.Params.html"},{"type":"function","title":"Evision.LargeKinfu.Params.coarseParams/0","doc":"Coarse parameters\nA set of parameters which provides better speed, can fail to match frames\nin case of rapid sensor motion.\n\n##### Return\n- **retval**: `Params`\n\nPython prototype (for reference only):\n```python3\ncoarseParams() -> retval\n```","ref":"Evision.LargeKinfu.Params.html#coarseParams/0"},{"type":"function","title":"Evision.LargeKinfu.Params.coarseParams/1","doc":"","ref":"Evision.LargeKinfu.Params.html#coarseParams/1"},{"type":"function","title":"Evision.LargeKinfu.Params.defaultParams/0","doc":"Default parameters\nA set of parameters which provides better model quality, can be very slow.\n\n##### Return\n- **retval**: `Params`\n\nPython prototype (for reference only):\n```python3\ndefaultParams() -> retval\n```","ref":"Evision.LargeKinfu.Params.html#defaultParams/0"},{"type":"function","title":"Evision.LargeKinfu.Params.defaultParams/1","doc":"","ref":"Evision.LargeKinfu.Params.html#defaultParams/1"},{"type":"function","title":"Evision.LargeKinfu.Params.get_bilateral_kernel_size/1","doc":"","ref":"Evision.LargeKinfu.Params.html#get_bilateral_kernel_size/1"},{"type":"function","title":"Evision.LargeKinfu.Params.get_bilateral_sigma_depth/1","doc":"","ref":"Evision.LargeKinfu.Params.html#get_bilateral_sigma_depth/1"},{"type":"function","title":"Evision.LargeKinfu.Params.get_bilateral_sigma_spatial/1","doc":"","ref":"Evision.LargeKinfu.Params.html#get_bilateral_sigma_spatial/1"},{"type":"function","title":"Evision.LargeKinfu.Params.get_depthFactor/1","doc":"","ref":"Evision.LargeKinfu.Params.html#get_depthFactor/1"},{"type":"function","title":"Evision.LargeKinfu.Params.get_frameSize/1","doc":"","ref":"Evision.LargeKinfu.Params.html#get_frameSize/1"},{"type":"function","title":"Evision.LargeKinfu.Params.get_icpAngleThresh/1","doc":"","ref":"Evision.LargeKinfu.Params.html#get_icpAngleThresh/1"},{"type":"function","title":"Evision.LargeKinfu.Params.get_icpDistThresh/1","doc":"","ref":"Evision.LargeKinfu.Params.html#get_icpDistThresh/1"},{"type":"function","title":"Evision.LargeKinfu.Params.get_icpIterations/1","doc":"","ref":"Evision.LargeKinfu.Params.html#get_icpIterations/1"},{"type":"function","title":"Evision.LargeKinfu.Params.get_intr/1","doc":"","ref":"Evision.LargeKinfu.Params.html#get_intr/1"},{"type":"function","title":"Evision.LargeKinfu.Params.get_lightPose/1","doc":"","ref":"Evision.LargeKinfu.Params.html#get_lightPose/1"},{"type":"function","title":"Evision.LargeKinfu.Params.get_pyramidLevels/1","doc":"","ref":"Evision.LargeKinfu.Params.html#get_pyramidLevels/1"},{"type":"function","title":"Evision.LargeKinfu.Params.get_rgb_intr/1","doc":"","ref":"Evision.LargeKinfu.Params.html#get_rgb_intr/1"},{"type":"function","title":"Evision.LargeKinfu.Params.get_truncateThreshold/1","doc":"","ref":"Evision.LargeKinfu.Params.html#get_truncateThreshold/1"},{"type":"function","title":"Evision.LargeKinfu.Params.get_tsdf_min_camera_movement/1","doc":"","ref":"Evision.LargeKinfu.Params.html#get_tsdf_min_camera_movement/1"},{"type":"function","title":"Evision.LargeKinfu.Params.hashTSDFParams/1","doc":"HashTSDF parameters\nA set of parameters suitable for use with HashTSDFVolume\n\n##### Positional Arguments\n- **isCoarse**: `bool`\n\n##### Return\n- **retval**: `Params`\n\nPython prototype (for reference only):\n```python3\nhashTSDFParams(isCoarse) -> retval\n```","ref":"Evision.LargeKinfu.Params.html#hashTSDFParams/1"},{"type":"function","title":"Evision.LargeKinfu.Params.set_bilateral_kernel_size/2","doc":"","ref":"Evision.LargeKinfu.Params.html#set_bilateral_kernel_size/2"},{"type":"function","title":"Evision.LargeKinfu.Params.set_bilateral_sigma_depth/2","doc":"","ref":"Evision.LargeKinfu.Params.html#set_bilateral_sigma_depth/2"},{"type":"function","title":"Evision.LargeKinfu.Params.set_bilateral_sigma_spatial/2","doc":"","ref":"Evision.LargeKinfu.Params.html#set_bilateral_sigma_spatial/2"},{"type":"function","title":"Evision.LargeKinfu.Params.set_depthFactor/2","doc":"","ref":"Evision.LargeKinfu.Params.html#set_depthFactor/2"},{"type":"function","title":"Evision.LargeKinfu.Params.set_frameSize/2","doc":"","ref":"Evision.LargeKinfu.Params.html#set_frameSize/2"},{"type":"function","title":"Evision.LargeKinfu.Params.set_icpAngleThresh/2","doc":"","ref":"Evision.LargeKinfu.Params.html#set_icpAngleThresh/2"},{"type":"function","title":"Evision.LargeKinfu.Params.set_icpDistThresh/2","doc":"","ref":"Evision.LargeKinfu.Params.html#set_icpDistThresh/2"},{"type":"function","title":"Evision.LargeKinfu.Params.set_icpIterations/2","doc":"","ref":"Evision.LargeKinfu.Params.html#set_icpIterations/2"},{"type":"function","title":"Evision.LargeKinfu.Params.set_intr/2","doc":"","ref":"Evision.LargeKinfu.Params.html#set_intr/2"},{"type":"function","title":"Evision.LargeKinfu.Params.set_lightPose/2","doc":"","ref":"Evision.LargeKinfu.Params.html#set_lightPose/2"},{"type":"function","title":"Evision.LargeKinfu.Params.set_pyramidLevels/2","doc":"","ref":"Evision.LargeKinfu.Params.html#set_pyramidLevels/2"},{"type":"function","title":"Evision.LargeKinfu.Params.set_rgb_intr/2","doc":"","ref":"Evision.LargeKinfu.Params.html#set_rgb_intr/2"},{"type":"function","title":"Evision.LargeKinfu.Params.set_truncateThreshold/2","doc":"","ref":"Evision.LargeKinfu.Params.html#set_truncateThreshold/2"},{"type":"function","title":"Evision.LargeKinfu.Params.set_tsdf_min_camera_movement/2","doc":"","ref":"Evision.LargeKinfu.Params.html#set_tsdf_min_camera_movement/2"},{"type":"type","title":"Evision.LargeKinfu.Params.t/0","doc":"Type that represents an `LargeKinfu.Params` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.LargeKinfu.Params.html#t:t/0"},{"type":"module","title":"Evision.Legacy","doc":"","ref":"Evision.Legacy.html"},{"type":"function","title":"Evision.Legacy.upgradeTrackingAPI/1","doc":"upgradeTrackingAPI\n\n##### Positional Arguments\n- **legacy_tracker**: `Evision.Legacy.MultiTracker`\n\n##### Return\n- **retval**: `Evision.Tracker.t()`\n\nPython prototype (for reference only):\n```python3\nupgradeTrackingAPI(legacy_tracker) -> retval\n```","ref":"Evision.Legacy.html#upgradeTrackingAPI/1"},{"type":"type","title":"Evision.Legacy.t/0","doc":"Type that represents an `Legacy` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Legacy.html#t:t/0"},{"type":"module","title":"Evision.Legacy.MultiTracker","doc":"","ref":"Evision.Legacy.MultiTracker.html"},{"type":"function","title":"Evision.Legacy.MultiTracker.add/1","doc":"","ref":"Evision.Legacy.MultiTracker.html#add/1"},{"type":"function","title":"Evision.Legacy.MultiTracker.add/4","doc":"add\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.MultiTracker.t()`\n- **newTracker**: `Evision.Legacy.MultiTracker`.\n\n  tracking algorithm to be used\n\n- **image**: `Evision.Mat`.\n\n  input image\n\n- **boundingBox**: `Rect2d`.\n\n  a rectangle represents ROI of the tracked object\n\n##### Return\n- **retval**: `bool`\n\n \\brief Add a new object to be tracked.\n\nPython prototype (for reference only):\n```python3\nadd(newTracker, image, boundingBox) -> retval\n```","ref":"Evision.Legacy.MultiTracker.html#add/4"},{"type":"function","title":"Evision.Legacy.MultiTracker.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.MultiTracker.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Legacy.MultiTracker.html#clear/1"},{"type":"function","title":"Evision.Legacy.MultiTracker.create/0","doc":"create\n##### Return\n- **retval**: `MultiTracker`\n\n \\brief Returns a pointer to a new instance of MultiTracker\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.Legacy.MultiTracker.html#create/0"},{"type":"function","title":"Evision.Legacy.MultiTracker.create/1","doc":"","ref":"Evision.Legacy.MultiTracker.html#create/1"},{"type":"function","title":"Evision.Legacy.MultiTracker.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.MultiTracker.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Legacy.MultiTracker.html#empty/1"},{"type":"function","title":"Evision.Legacy.MultiTracker.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.MultiTracker.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Legacy.MultiTracker.html#getDefaultName/1"},{"type":"function","title":"Evision.Legacy.MultiTracker.getObjects/1","doc":"getObjects\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.MultiTracker.t()`\n\n##### Return\n- **retval**: `[Rect2d]`\n\n \\brief Returns a reference to a storage for the tracked objects, each object corresponds to one tracker algorithm\n\nPython prototype (for reference only):\n```python3\ngetObjects() -> retval\n```","ref":"Evision.Legacy.MultiTracker.html#getObjects/1"},{"type":"function","title":"Evision.Legacy.MultiTracker.multiTracker/0","doc":"MultiTracker\n##### Return\n- **self**: `MultiTracker`\n\n \\brief Constructor.\n\nPython prototype (for reference only):\n```python3\nMultiTracker() ->  \n```","ref":"Evision.Legacy.MultiTracker.html#multiTracker/0"},{"type":"function","title":"Evision.Legacy.MultiTracker.multiTracker/1","doc":"","ref":"Evision.Legacy.MultiTracker.html#multiTracker/1"},{"type":"function","title":"Evision.Legacy.MultiTracker.read/1","doc":"","ref":"Evision.Legacy.MultiTracker.html#read/1"},{"type":"function","title":"Evision.Legacy.MultiTracker.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.MultiTracker.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Legacy.MultiTracker.html#read/2"},{"type":"function","title":"Evision.Legacy.MultiTracker.save/1","doc":"","ref":"Evision.Legacy.MultiTracker.html#save/1"},{"type":"function","title":"Evision.Legacy.MultiTracker.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.MultiTracker.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Legacy.MultiTracker.html#save/2"},{"type":"function","title":"Evision.Legacy.MultiTracker.update/1","doc":"","ref":"Evision.Legacy.MultiTracker.html#update/1"},{"type":"function","title":"Evision.Legacy.MultiTracker.update/2","doc":"update\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.MultiTracker.t()`\n- **image**: `Evision.Mat`.\n\n  input image\n\n##### Return\n- **retval**: `bool`\n- **boundingBox**: `[Rect2d]`.\n\n  the tracking result, represent a list of ROIs of the tracked objects.\n\n \\brief Update the current tracking status.\n\nPython prototype (for reference only):\n```python3\nupdate(image) -> retval, boundingBox\n```","ref":"Evision.Legacy.MultiTracker.html#update/2"},{"type":"function","title":"Evision.Legacy.MultiTracker.write/1","doc":"","ref":"Evision.Legacy.MultiTracker.html#write/1"},{"type":"function","title":"Evision.Legacy.MultiTracker.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.MultiTracker.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Legacy.MultiTracker.html#write/2"},{"type":"function","title":"Evision.Legacy.MultiTracker.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.MultiTracker.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Legacy.MultiTracker.html#write/3"},{"type":"type","title":"Evision.Legacy.MultiTracker.t/0","doc":"Type that represents an `Legacy.MultiTracker` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Legacy.MultiTracker.html#t:t/0"},{"type":"module","title":"Evision.Legacy.Tracker","doc":"","ref":"Evision.Legacy.Tracker.html"},{"type":"function","title":"Evision.Legacy.Tracker.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.Tracker.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Legacy.Tracker.html#clear/1"},{"type":"function","title":"Evision.Legacy.Tracker.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.Tracker.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Legacy.Tracker.html#empty/1"},{"type":"function","title":"Evision.Legacy.Tracker.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.Tracker.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Legacy.Tracker.html#getDefaultName/1"},{"type":"function","title":"Evision.Legacy.Tracker.init/1","doc":"","ref":"Evision.Legacy.Tracker.html#init/1"},{"type":"function","title":"Evision.Legacy.Tracker.init/3","doc":"Initialize the tracker with a known bounding box that surrounded the target\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.Tracker.t()`\n- **image**: `Evision.Mat`.\n\n  The initial frame\n\n- **boundingBox**: `Rect2d`.\n\n  The initial bounding box\n\n##### Return\n- **retval**: `bool`\n\n@return True if initialization went succesfully, false otherwise\n\nPython prototype (for reference only):\n```python3\ninit(image, boundingBox) -> retval\n```","ref":"Evision.Legacy.Tracker.html#init/3"},{"type":"function","title":"Evision.Legacy.Tracker.read/1","doc":"","ref":"Evision.Legacy.Tracker.html#read/1"},{"type":"function","title":"Evision.Legacy.Tracker.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.Tracker.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Legacy.Tracker.html#read/2"},{"type":"function","title":"Evision.Legacy.Tracker.save/1","doc":"","ref":"Evision.Legacy.Tracker.html#save/1"},{"type":"function","title":"Evision.Legacy.Tracker.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.Tracker.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Legacy.Tracker.html#save/2"},{"type":"function","title":"Evision.Legacy.Tracker.update/1","doc":"","ref":"Evision.Legacy.Tracker.html#update/1"},{"type":"function","title":"Evision.Legacy.Tracker.update/2","doc":"Update the tracker, find the new most likely bounding box for the target\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.Tracker.t()`\n- **image**: `Evision.Mat`.\n\n  The current frame\n\n##### Return\n- **retval**: `bool`\n- **boundingBox**: `Rect2d`.\n\n  The bounding box that represent the new target location, if true was returned, not\n  modified otherwise\n\n@return True means that target was located and false means that tracker cannot locate target in\ncurrent frame. Note, that latter *does not* imply that tracker has failed, maybe target is indeed\nmissing from the frame (say, out of sight)\n\nPython prototype (for reference only):\n```python3\nupdate(image) -> retval, boundingBox\n```","ref":"Evision.Legacy.Tracker.html#update/2"},{"type":"function","title":"Evision.Legacy.Tracker.write/1","doc":"","ref":"Evision.Legacy.Tracker.html#write/1"},{"type":"function","title":"Evision.Legacy.Tracker.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.Tracker.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Legacy.Tracker.html#write/2"},{"type":"function","title":"Evision.Legacy.Tracker.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.Tracker.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Legacy.Tracker.html#write/3"},{"type":"type","title":"Evision.Legacy.Tracker.t/0","doc":"Type that represents an `Legacy.Tracker` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Legacy.Tracker.html#t:t/0"},{"type":"module","title":"Evision.Legacy.TrackerBoosting","doc":"","ref":"Evision.Legacy.TrackerBoosting.html"},{"type":"function","title":"Evision.Legacy.TrackerBoosting.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerBoosting.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Legacy.TrackerBoosting.html#clear/1"},{"type":"function","title":"Evision.Legacy.TrackerBoosting.create/0","doc":"Constructor\n##### Return\n- **retval**: `legacy::TrackerBoosting`\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.Legacy.TrackerBoosting.html#create/0"},{"type":"function","title":"Evision.Legacy.TrackerBoosting.create/1","doc":"","ref":"Evision.Legacy.TrackerBoosting.html#create/1"},{"type":"function","title":"Evision.Legacy.TrackerBoosting.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerBoosting.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Legacy.TrackerBoosting.html#empty/1"},{"type":"function","title":"Evision.Legacy.TrackerBoosting.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerBoosting.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Legacy.TrackerBoosting.html#getDefaultName/1"},{"type":"function","title":"Evision.Legacy.TrackerBoosting.init/1","doc":"","ref":"Evision.Legacy.TrackerBoosting.html#init/1"},{"type":"function","title":"Evision.Legacy.TrackerBoosting.init/3","doc":"Initialize the tracker with a known bounding box that surrounded the target\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerBoosting.t()`\n- **image**: `Evision.Mat`.\n\n  The initial frame\n\n- **boundingBox**: `Rect2d`.\n\n  The initial bounding box\n\n##### Return\n- **retval**: `bool`\n\n@return True if initialization went succesfully, false otherwise\n\nPython prototype (for reference only):\n```python3\ninit(image, boundingBox) -> retval\n```","ref":"Evision.Legacy.TrackerBoosting.html#init/3"},{"type":"function","title":"Evision.Legacy.TrackerBoosting.read/1","doc":"","ref":"Evision.Legacy.TrackerBoosting.html#read/1"},{"type":"function","title":"Evision.Legacy.TrackerBoosting.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerBoosting.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Legacy.TrackerBoosting.html#read/2"},{"type":"function","title":"Evision.Legacy.TrackerBoosting.save/1","doc":"","ref":"Evision.Legacy.TrackerBoosting.html#save/1"},{"type":"function","title":"Evision.Legacy.TrackerBoosting.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerBoosting.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Legacy.TrackerBoosting.html#save/2"},{"type":"function","title":"Evision.Legacy.TrackerBoosting.update/1","doc":"","ref":"Evision.Legacy.TrackerBoosting.html#update/1"},{"type":"function","title":"Evision.Legacy.TrackerBoosting.update/2","doc":"Update the tracker, find the new most likely bounding box for the target\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerBoosting.t()`\n- **image**: `Evision.Mat`.\n\n  The current frame\n\n##### Return\n- **retval**: `bool`\n- **boundingBox**: `Rect2d`.\n\n  The bounding box that represent the new target location, if true was returned, not\n  modified otherwise\n\n@return True means that target was located and false means that tracker cannot locate target in\ncurrent frame. Note, that latter *does not* imply that tracker has failed, maybe target is indeed\nmissing from the frame (say, out of sight)\n\nPython prototype (for reference only):\n```python3\nupdate(image) -> retval, boundingBox\n```","ref":"Evision.Legacy.TrackerBoosting.html#update/2"},{"type":"function","title":"Evision.Legacy.TrackerBoosting.write/1","doc":"","ref":"Evision.Legacy.TrackerBoosting.html#write/1"},{"type":"function","title":"Evision.Legacy.TrackerBoosting.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerBoosting.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Legacy.TrackerBoosting.html#write/2"},{"type":"function","title":"Evision.Legacy.TrackerBoosting.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerBoosting.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Legacy.TrackerBoosting.html#write/3"},{"type":"type","title":"Evision.Legacy.TrackerBoosting.t/0","doc":"Type that represents an `Legacy.TrackerBoosting` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Legacy.TrackerBoosting.html#t:t/0"},{"type":"module","title":"Evision.Legacy.TrackerCSRT","doc":"","ref":"Evision.Legacy.TrackerCSRT.html"},{"type":"function","title":"Evision.Legacy.TrackerCSRT.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerCSRT.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Legacy.TrackerCSRT.html#clear/1"},{"type":"function","title":"Evision.Legacy.TrackerCSRT.create/0","doc":"Constructor\n##### Return\n- **retval**: `legacy::TrackerCSRT`\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.Legacy.TrackerCSRT.html#create/0"},{"type":"function","title":"Evision.Legacy.TrackerCSRT.create/1","doc":"","ref":"Evision.Legacy.TrackerCSRT.html#create/1"},{"type":"function","title":"Evision.Legacy.TrackerCSRT.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerCSRT.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Legacy.TrackerCSRT.html#empty/1"},{"type":"function","title":"Evision.Legacy.TrackerCSRT.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerCSRT.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Legacy.TrackerCSRT.html#getDefaultName/1"},{"type":"function","title":"Evision.Legacy.TrackerCSRT.init/1","doc":"","ref":"Evision.Legacy.TrackerCSRT.html#init/1"},{"type":"function","title":"Evision.Legacy.TrackerCSRT.init/3","doc":"Initialize the tracker with a known bounding box that surrounded the target\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerCSRT.t()`\n- **image**: `Evision.Mat`.\n\n  The initial frame\n\n- **boundingBox**: `Rect2d`.\n\n  The initial bounding box\n\n##### Return\n- **retval**: `bool`\n\n@return True if initialization went succesfully, false otherwise\n\nPython prototype (for reference only):\n```python3\ninit(image, boundingBox) -> retval\n```","ref":"Evision.Legacy.TrackerCSRT.html#init/3"},{"type":"function","title":"Evision.Legacy.TrackerCSRT.read/1","doc":"","ref":"Evision.Legacy.TrackerCSRT.html#read/1"},{"type":"function","title":"Evision.Legacy.TrackerCSRT.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerCSRT.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Legacy.TrackerCSRT.html#read/2"},{"type":"function","title":"Evision.Legacy.TrackerCSRT.save/1","doc":"","ref":"Evision.Legacy.TrackerCSRT.html#save/1"},{"type":"function","title":"Evision.Legacy.TrackerCSRT.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerCSRT.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Legacy.TrackerCSRT.html#save/2"},{"type":"function","title":"Evision.Legacy.TrackerCSRT.setInitialMask/1","doc":"","ref":"Evision.Legacy.TrackerCSRT.html#setInitialMask/1"},{"type":"function","title":"Evision.Legacy.TrackerCSRT.setInitialMask/2","doc":"setInitialMask\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerCSRT.t()`\n- **mask**: `Evision.Mat`\n\nPython prototype (for reference only):\n```python3\nsetInitialMask(mask) -> None\n```","ref":"Evision.Legacy.TrackerCSRT.html#setInitialMask/2"},{"type":"function","title":"Evision.Legacy.TrackerCSRT.update/1","doc":"","ref":"Evision.Legacy.TrackerCSRT.html#update/1"},{"type":"function","title":"Evision.Legacy.TrackerCSRT.update/2","doc":"Update the tracker, find the new most likely bounding box for the target\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerCSRT.t()`\n- **image**: `Evision.Mat`.\n\n  The current frame\n\n##### Return\n- **retval**: `bool`\n- **boundingBox**: `Rect2d`.\n\n  The bounding box that represent the new target location, if true was returned, not\n  modified otherwise\n\n@return True means that target was located and false means that tracker cannot locate target in\ncurrent frame. Note, that latter *does not* imply that tracker has failed, maybe target is indeed\nmissing from the frame (say, out of sight)\n\nPython prototype (for reference only):\n```python3\nupdate(image) -> retval, boundingBox\n```","ref":"Evision.Legacy.TrackerCSRT.html#update/2"},{"type":"function","title":"Evision.Legacy.TrackerCSRT.write/1","doc":"","ref":"Evision.Legacy.TrackerCSRT.html#write/1"},{"type":"function","title":"Evision.Legacy.TrackerCSRT.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerCSRT.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Legacy.TrackerCSRT.html#write/2"},{"type":"function","title":"Evision.Legacy.TrackerCSRT.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerCSRT.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Legacy.TrackerCSRT.html#write/3"},{"type":"type","title":"Evision.Legacy.TrackerCSRT.t/0","doc":"Type that represents an `Legacy.TrackerCSRT` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Legacy.TrackerCSRT.html#t:t/0"},{"type":"module","title":"Evision.Legacy.TrackerKCF","doc":"","ref":"Evision.Legacy.TrackerKCF.html"},{"type":"function","title":"Evision.Legacy.TrackerKCF.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerKCF.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Legacy.TrackerKCF.html#clear/1"},{"type":"function","title":"Evision.Legacy.TrackerKCF.create/0","doc":"Constructor\n##### Return\n- **retval**: `legacy::TrackerKCF`\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.Legacy.TrackerKCF.html#create/0"},{"type":"function","title":"Evision.Legacy.TrackerKCF.create/1","doc":"","ref":"Evision.Legacy.TrackerKCF.html#create/1"},{"type":"function","title":"Evision.Legacy.TrackerKCF.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerKCF.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Legacy.TrackerKCF.html#empty/1"},{"type":"function","title":"Evision.Legacy.TrackerKCF.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerKCF.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Legacy.TrackerKCF.html#getDefaultName/1"},{"type":"function","title":"Evision.Legacy.TrackerKCF.init/1","doc":"","ref":"Evision.Legacy.TrackerKCF.html#init/1"},{"type":"function","title":"Evision.Legacy.TrackerKCF.init/3","doc":"Initialize the tracker with a known bounding box that surrounded the target\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerKCF.t()`\n- **image**: `Evision.Mat`.\n\n  The initial frame\n\n- **boundingBox**: `Rect2d`.\n\n  The initial bounding box\n\n##### Return\n- **retval**: `bool`\n\n@return True if initialization went succesfully, false otherwise\n\nPython prototype (for reference only):\n```python3\ninit(image, boundingBox) -> retval\n```","ref":"Evision.Legacy.TrackerKCF.html#init/3"},{"type":"function","title":"Evision.Legacy.TrackerKCF.read/1","doc":"","ref":"Evision.Legacy.TrackerKCF.html#read/1"},{"type":"function","title":"Evision.Legacy.TrackerKCF.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerKCF.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Legacy.TrackerKCF.html#read/2"},{"type":"function","title":"Evision.Legacy.TrackerKCF.save/1","doc":"","ref":"Evision.Legacy.TrackerKCF.html#save/1"},{"type":"function","title":"Evision.Legacy.TrackerKCF.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerKCF.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Legacy.TrackerKCF.html#save/2"},{"type":"function","title":"Evision.Legacy.TrackerKCF.update/1","doc":"","ref":"Evision.Legacy.TrackerKCF.html#update/1"},{"type":"function","title":"Evision.Legacy.TrackerKCF.update/2","doc":"Update the tracker, find the new most likely bounding box for the target\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerKCF.t()`\n- **image**: `Evision.Mat`.\n\n  The current frame\n\n##### Return\n- **retval**: `bool`\n- **boundingBox**: `Rect2d`.\n\n  The bounding box that represent the new target location, if true was returned, not\n  modified otherwise\n\n@return True means that target was located and false means that tracker cannot locate target in\ncurrent frame. Note, that latter *does not* imply that tracker has failed, maybe target is indeed\nmissing from the frame (say, out of sight)\n\nPython prototype (for reference only):\n```python3\nupdate(image) -> retval, boundingBox\n```","ref":"Evision.Legacy.TrackerKCF.html#update/2"},{"type":"function","title":"Evision.Legacy.TrackerKCF.write/1","doc":"","ref":"Evision.Legacy.TrackerKCF.html#write/1"},{"type":"function","title":"Evision.Legacy.TrackerKCF.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerKCF.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Legacy.TrackerKCF.html#write/2"},{"type":"function","title":"Evision.Legacy.TrackerKCF.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerKCF.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Legacy.TrackerKCF.html#write/3"},{"type":"type","title":"Evision.Legacy.TrackerKCF.t/0","doc":"Type that represents an `Legacy.TrackerKCF` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Legacy.TrackerKCF.html#t:t/0"},{"type":"module","title":"Evision.Legacy.TrackerMIL","doc":"","ref":"Evision.Legacy.TrackerMIL.html"},{"type":"function","title":"Evision.Legacy.TrackerMIL.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMIL.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Legacy.TrackerMIL.html#clear/1"},{"type":"function","title":"Evision.Legacy.TrackerMIL.create/0","doc":"Constructor\n##### Return\n- **retval**: `legacy::TrackerMIL`\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.Legacy.TrackerMIL.html#create/0"},{"type":"function","title":"Evision.Legacy.TrackerMIL.create/1","doc":"","ref":"Evision.Legacy.TrackerMIL.html#create/1"},{"type":"function","title":"Evision.Legacy.TrackerMIL.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMIL.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Legacy.TrackerMIL.html#empty/1"},{"type":"function","title":"Evision.Legacy.TrackerMIL.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMIL.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Legacy.TrackerMIL.html#getDefaultName/1"},{"type":"function","title":"Evision.Legacy.TrackerMIL.init/1","doc":"","ref":"Evision.Legacy.TrackerMIL.html#init/1"},{"type":"function","title":"Evision.Legacy.TrackerMIL.init/3","doc":"Initialize the tracker with a known bounding box that surrounded the target\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMIL.t()`\n- **image**: `Evision.Mat`.\n\n  The initial frame\n\n- **boundingBox**: `Rect2d`.\n\n  The initial bounding box\n\n##### Return\n- **retval**: `bool`\n\n@return True if initialization went succesfully, false otherwise\n\nPython prototype (for reference only):\n```python3\ninit(image, boundingBox) -> retval\n```","ref":"Evision.Legacy.TrackerMIL.html#init/3"},{"type":"function","title":"Evision.Legacy.TrackerMIL.read/1","doc":"","ref":"Evision.Legacy.TrackerMIL.html#read/1"},{"type":"function","title":"Evision.Legacy.TrackerMIL.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMIL.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Legacy.TrackerMIL.html#read/2"},{"type":"function","title":"Evision.Legacy.TrackerMIL.save/1","doc":"","ref":"Evision.Legacy.TrackerMIL.html#save/1"},{"type":"function","title":"Evision.Legacy.TrackerMIL.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMIL.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Legacy.TrackerMIL.html#save/2"},{"type":"function","title":"Evision.Legacy.TrackerMIL.update/1","doc":"","ref":"Evision.Legacy.TrackerMIL.html#update/1"},{"type":"function","title":"Evision.Legacy.TrackerMIL.update/2","doc":"Update the tracker, find the new most likely bounding box for the target\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMIL.t()`\n- **image**: `Evision.Mat`.\n\n  The current frame\n\n##### Return\n- **retval**: `bool`\n- **boundingBox**: `Rect2d`.\n\n  The bounding box that represent the new target location, if true was returned, not\n  modified otherwise\n\n@return True means that target was located and false means that tracker cannot locate target in\ncurrent frame. Note, that latter *does not* imply that tracker has failed, maybe target is indeed\nmissing from the frame (say, out of sight)\n\nPython prototype (for reference only):\n```python3\nupdate(image) -> retval, boundingBox\n```","ref":"Evision.Legacy.TrackerMIL.html#update/2"},{"type":"function","title":"Evision.Legacy.TrackerMIL.write/1","doc":"","ref":"Evision.Legacy.TrackerMIL.html#write/1"},{"type":"function","title":"Evision.Legacy.TrackerMIL.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMIL.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Legacy.TrackerMIL.html#write/2"},{"type":"function","title":"Evision.Legacy.TrackerMIL.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMIL.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Legacy.TrackerMIL.html#write/3"},{"type":"type","title":"Evision.Legacy.TrackerMIL.t/0","doc":"Type that represents an `Legacy.TrackerMIL` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Legacy.TrackerMIL.html#t:t/0"},{"type":"module","title":"Evision.Legacy.TrackerMOSSE","doc":"","ref":"Evision.Legacy.TrackerMOSSE.html"},{"type":"function","title":"Evision.Legacy.TrackerMOSSE.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMOSSE.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Legacy.TrackerMOSSE.html#clear/1"},{"type":"function","title":"Evision.Legacy.TrackerMOSSE.create/0","doc":"Constructor\n##### Return\n- **retval**: `legacy::TrackerMOSSE`\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.Legacy.TrackerMOSSE.html#create/0"},{"type":"function","title":"Evision.Legacy.TrackerMOSSE.create/1","doc":"","ref":"Evision.Legacy.TrackerMOSSE.html#create/1"},{"type":"function","title":"Evision.Legacy.TrackerMOSSE.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMOSSE.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Legacy.TrackerMOSSE.html#empty/1"},{"type":"function","title":"Evision.Legacy.TrackerMOSSE.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMOSSE.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Legacy.TrackerMOSSE.html#getDefaultName/1"},{"type":"function","title":"Evision.Legacy.TrackerMOSSE.init/1","doc":"","ref":"Evision.Legacy.TrackerMOSSE.html#init/1"},{"type":"function","title":"Evision.Legacy.TrackerMOSSE.init/3","doc":"Initialize the tracker with a known bounding box that surrounded the target\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMOSSE.t()`\n- **image**: `Evision.Mat`.\n\n  The initial frame\n\n- **boundingBox**: `Rect2d`.\n\n  The initial bounding box\n\n##### Return\n- **retval**: `bool`\n\n@return True if initialization went succesfully, false otherwise\n\nPython prototype (for reference only):\n```python3\ninit(image, boundingBox) -> retval\n```","ref":"Evision.Legacy.TrackerMOSSE.html#init/3"},{"type":"function","title":"Evision.Legacy.TrackerMOSSE.read/1","doc":"","ref":"Evision.Legacy.TrackerMOSSE.html#read/1"},{"type":"function","title":"Evision.Legacy.TrackerMOSSE.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMOSSE.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Legacy.TrackerMOSSE.html#read/2"},{"type":"function","title":"Evision.Legacy.TrackerMOSSE.save/1","doc":"","ref":"Evision.Legacy.TrackerMOSSE.html#save/1"},{"type":"function","title":"Evision.Legacy.TrackerMOSSE.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMOSSE.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Legacy.TrackerMOSSE.html#save/2"},{"type":"function","title":"Evision.Legacy.TrackerMOSSE.update/1","doc":"","ref":"Evision.Legacy.TrackerMOSSE.html#update/1"},{"type":"function","title":"Evision.Legacy.TrackerMOSSE.update/2","doc":"Update the tracker, find the new most likely bounding box for the target\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMOSSE.t()`\n- **image**: `Evision.Mat`.\n\n  The current frame\n\n##### Return\n- **retval**: `bool`\n- **boundingBox**: `Rect2d`.\n\n  The bounding box that represent the new target location, if true was returned, not\n  modified otherwise\n\n@return True means that target was located and false means that tracker cannot locate target in\ncurrent frame. Note, that latter *does not* imply that tracker has failed, maybe target is indeed\nmissing from the frame (say, out of sight)\n\nPython prototype (for reference only):\n```python3\nupdate(image) -> retval, boundingBox\n```","ref":"Evision.Legacy.TrackerMOSSE.html#update/2"},{"type":"function","title":"Evision.Legacy.TrackerMOSSE.write/1","doc":"","ref":"Evision.Legacy.TrackerMOSSE.html#write/1"},{"type":"function","title":"Evision.Legacy.TrackerMOSSE.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMOSSE.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Legacy.TrackerMOSSE.html#write/2"},{"type":"function","title":"Evision.Legacy.TrackerMOSSE.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMOSSE.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Legacy.TrackerMOSSE.html#write/3"},{"type":"type","title":"Evision.Legacy.TrackerMOSSE.t/0","doc":"Type that represents an `Legacy.TrackerMOSSE` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Legacy.TrackerMOSSE.html#t:t/0"},{"type":"module","title":"Evision.Legacy.TrackerMedianFlow","doc":"","ref":"Evision.Legacy.TrackerMedianFlow.html"},{"type":"function","title":"Evision.Legacy.TrackerMedianFlow.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMedianFlow.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Legacy.TrackerMedianFlow.html#clear/1"},{"type":"function","title":"Evision.Legacy.TrackerMedianFlow.create/0","doc":"Constructor\n##### Return\n- **retval**: `legacy::TrackerMedianFlow`\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.Legacy.TrackerMedianFlow.html#create/0"},{"type":"function","title":"Evision.Legacy.TrackerMedianFlow.create/1","doc":"","ref":"Evision.Legacy.TrackerMedianFlow.html#create/1"},{"type":"function","title":"Evision.Legacy.TrackerMedianFlow.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMedianFlow.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Legacy.TrackerMedianFlow.html#empty/1"},{"type":"function","title":"Evision.Legacy.TrackerMedianFlow.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMedianFlow.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Legacy.TrackerMedianFlow.html#getDefaultName/1"},{"type":"function","title":"Evision.Legacy.TrackerMedianFlow.init/1","doc":"","ref":"Evision.Legacy.TrackerMedianFlow.html#init/1"},{"type":"function","title":"Evision.Legacy.TrackerMedianFlow.init/3","doc":"Initialize the tracker with a known bounding box that surrounded the target\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMedianFlow.t()`\n- **image**: `Evision.Mat`.\n\n  The initial frame\n\n- **boundingBox**: `Rect2d`.\n\n  The initial bounding box\n\n##### Return\n- **retval**: `bool`\n\n@return True if initialization went succesfully, false otherwise\n\nPython prototype (for reference only):\n```python3\ninit(image, boundingBox) -> retval\n```","ref":"Evision.Legacy.TrackerMedianFlow.html#init/3"},{"type":"function","title":"Evision.Legacy.TrackerMedianFlow.read/1","doc":"","ref":"Evision.Legacy.TrackerMedianFlow.html#read/1"},{"type":"function","title":"Evision.Legacy.TrackerMedianFlow.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMedianFlow.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Legacy.TrackerMedianFlow.html#read/2"},{"type":"function","title":"Evision.Legacy.TrackerMedianFlow.save/1","doc":"","ref":"Evision.Legacy.TrackerMedianFlow.html#save/1"},{"type":"function","title":"Evision.Legacy.TrackerMedianFlow.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMedianFlow.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Legacy.TrackerMedianFlow.html#save/2"},{"type":"function","title":"Evision.Legacy.TrackerMedianFlow.update/1","doc":"","ref":"Evision.Legacy.TrackerMedianFlow.html#update/1"},{"type":"function","title":"Evision.Legacy.TrackerMedianFlow.update/2","doc":"Update the tracker, find the new most likely bounding box for the target\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMedianFlow.t()`\n- **image**: `Evision.Mat`.\n\n  The current frame\n\n##### Return\n- **retval**: `bool`\n- **boundingBox**: `Rect2d`.\n\n  The bounding box that represent the new target location, if true was returned, not\n  modified otherwise\n\n@return True means that target was located and false means that tracker cannot locate target in\ncurrent frame. Note, that latter *does not* imply that tracker has failed, maybe target is indeed\nmissing from the frame (say, out of sight)\n\nPython prototype (for reference only):\n```python3\nupdate(image) -> retval, boundingBox\n```","ref":"Evision.Legacy.TrackerMedianFlow.html#update/2"},{"type":"function","title":"Evision.Legacy.TrackerMedianFlow.write/1","doc":"","ref":"Evision.Legacy.TrackerMedianFlow.html#write/1"},{"type":"function","title":"Evision.Legacy.TrackerMedianFlow.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMedianFlow.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Legacy.TrackerMedianFlow.html#write/2"},{"type":"function","title":"Evision.Legacy.TrackerMedianFlow.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerMedianFlow.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Legacy.TrackerMedianFlow.html#write/3"},{"type":"type","title":"Evision.Legacy.TrackerMedianFlow.t/0","doc":"Type that represents an `Legacy.TrackerMedianFlow` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Legacy.TrackerMedianFlow.html#t:t/0"},{"type":"module","title":"Evision.Legacy.TrackerTLD","doc":"","ref":"Evision.Legacy.TrackerTLD.html"},{"type":"function","title":"Evision.Legacy.TrackerTLD.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerTLD.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Legacy.TrackerTLD.html#clear/1"},{"type":"function","title":"Evision.Legacy.TrackerTLD.create/0","doc":"Constructor\n##### Return\n- **retval**: `legacy::TrackerTLD`\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.Legacy.TrackerTLD.html#create/0"},{"type":"function","title":"Evision.Legacy.TrackerTLD.create/1","doc":"","ref":"Evision.Legacy.TrackerTLD.html#create/1"},{"type":"function","title":"Evision.Legacy.TrackerTLD.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerTLD.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Legacy.TrackerTLD.html#empty/1"},{"type":"function","title":"Evision.Legacy.TrackerTLD.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerTLD.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Legacy.TrackerTLD.html#getDefaultName/1"},{"type":"function","title":"Evision.Legacy.TrackerTLD.init/1","doc":"","ref":"Evision.Legacy.TrackerTLD.html#init/1"},{"type":"function","title":"Evision.Legacy.TrackerTLD.init/3","doc":"Initialize the tracker with a known bounding box that surrounded the target\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerTLD.t()`\n- **image**: `Evision.Mat`.\n\n  The initial frame\n\n- **boundingBox**: `Rect2d`.\n\n  The initial bounding box\n\n##### Return\n- **retval**: `bool`\n\n@return True if initialization went succesfully, false otherwise\n\nPython prototype (for reference only):\n```python3\ninit(image, boundingBox) -> retval\n```","ref":"Evision.Legacy.TrackerTLD.html#init/3"},{"type":"function","title":"Evision.Legacy.TrackerTLD.read/1","doc":"","ref":"Evision.Legacy.TrackerTLD.html#read/1"},{"type":"function","title":"Evision.Legacy.TrackerTLD.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerTLD.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Legacy.TrackerTLD.html#read/2"},{"type":"function","title":"Evision.Legacy.TrackerTLD.save/1","doc":"","ref":"Evision.Legacy.TrackerTLD.html#save/1"},{"type":"function","title":"Evision.Legacy.TrackerTLD.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerTLD.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Legacy.TrackerTLD.html#save/2"},{"type":"function","title":"Evision.Legacy.TrackerTLD.update/1","doc":"","ref":"Evision.Legacy.TrackerTLD.html#update/1"},{"type":"function","title":"Evision.Legacy.TrackerTLD.update/2","doc":"Update the tracker, find the new most likely bounding box for the target\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerTLD.t()`\n- **image**: `Evision.Mat`.\n\n  The current frame\n\n##### Return\n- **retval**: `bool`\n- **boundingBox**: `Rect2d`.\n\n  The bounding box that represent the new target location, if true was returned, not\n  modified otherwise\n\n@return True means that target was located and false means that tracker cannot locate target in\ncurrent frame. Note, that latter *does not* imply that tracker has failed, maybe target is indeed\nmissing from the frame (say, out of sight)\n\nPython prototype (for reference only):\n```python3\nupdate(image) -> retval, boundingBox\n```","ref":"Evision.Legacy.TrackerTLD.html#update/2"},{"type":"function","title":"Evision.Legacy.TrackerTLD.write/1","doc":"","ref":"Evision.Legacy.TrackerTLD.html#write/1"},{"type":"function","title":"Evision.Legacy.TrackerTLD.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerTLD.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Legacy.TrackerTLD.html#write/2"},{"type":"function","title":"Evision.Legacy.TrackerTLD.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Legacy.TrackerTLD.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Legacy.TrackerTLD.html#write/3"},{"type":"type","title":"Evision.Legacy.TrackerTLD.t/0","doc":"Type that represents an `Legacy.TrackerTLD` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Legacy.TrackerTLD.html#t:t/0"},{"type":"module","title":"Evision.LineDescriptor","doc":"","ref":"Evision.LineDescriptor.html"},{"type":"function","title":"Evision.LineDescriptor.drawKeylines/1","doc":"","ref":"Evision.LineDescriptor.html#drawKeylines/1"},{"type":"function","title":"Evision.LineDescriptor.drawKeylines/2","doc":"Draws keylines.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  input image\n\n- **keylines**: `[Evision.LineDescriptor.KeyLine]`.\n\n  keylines to be drawn\n\n##### Keyword Arguments\n- **color**: `Evision.scalar()`.\n\n  color of lines to be drawn (if set to defaul value, color is chosen randomly)\n\n- **flags**: `integer()`.\n\n  drawing flags\n\n##### Return\n- **outImage**: `Evision.Mat.t()`.\n\n  output image to draw on\n\nPython prototype (for reference only):\n```python3\ndrawKeylines(image, keylines[, outImage[, color[, flags]]]) -> outImage\n```","ref":"Evision.LineDescriptor.html#drawKeylines/2"},{"type":"function","title":"Evision.LineDescriptor.drawKeylines/3","doc":"Draws keylines.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  input image\n\n- **keylines**: `[Evision.LineDescriptor.KeyLine]`.\n\n  keylines to be drawn\n\n##### Keyword Arguments\n- **color**: `Evision.scalar()`.\n\n  color of lines to be drawn (if set to defaul value, color is chosen randomly)\n\n- **flags**: `integer()`.\n\n  drawing flags\n\n##### Return\n- **outImage**: `Evision.Mat.t()`.\n\n  output image to draw on\n\nPython prototype (for reference only):\n```python3\ndrawKeylines(image, keylines[, outImage[, color[, flags]]]) -> outImage\n```","ref":"Evision.LineDescriptor.html#drawKeylines/3"},{"type":"function","title":"Evision.LineDescriptor.drawLineMatches/1","doc":"","ref":"Evision.LineDescriptor.html#drawLineMatches/1"},{"type":"function","title":"Evision.LineDescriptor.drawLineMatches/5","doc":"Draws the found matches of keylines from two images.\n\n##### Positional Arguments\n- **img1**: `Evision.Mat`.\n\n  first image\n\n- **keylines1**: `[Evision.LineDescriptor.KeyLine]`.\n\n  keylines extracted from first image\n\n- **img2**: `Evision.Mat`.\n\n  second image\n\n- **keylines2**: `[Evision.LineDescriptor.KeyLine]`.\n\n  keylines extracted from second image\n\n- **matches1to2**: `[Evision.DMatch]`.\n\n  vector of matches\n\n##### Keyword Arguments\n- **matchColor**: `Evision.scalar()`.\n\n  drawing color for matches (chosen randomly in case of default value)\n\n- **singleLineColor**: `Evision.scalar()`.\n\n  drawing color for keylines (chosen randomly in case of default value)\n\n- **matchesMask**: `[char]`.\n\n  mask to indicate which matches must be drawn\n\n- **flags**: `integer()`.\n\n  drawing flags, see DrawLinesMatchesFlags\n\n##### Return\n- **outImg**: `Evision.Mat.t()`.\n\n  output matrix to draw on\n\n**Note**: If both *matchColor* and *singleLineColor* are set to their default values, function draws\nmatched lines and line connecting them with same color\n\nPython prototype (for reference only):\n```python3\ndrawLineMatches(img1, keylines1, img2, keylines2, matches1to2[, outImg[, matchColor[, singleLineColor[, matchesMask[, flags]]]]]) -> outImg\n```","ref":"Evision.LineDescriptor.html#drawLineMatches/5"},{"type":"function","title":"Evision.LineDescriptor.drawLineMatches/6","doc":"Draws the found matches of keylines from two images.\n\n##### Positional Arguments\n- **img1**: `Evision.Mat`.\n\n  first image\n\n- **keylines1**: `[Evision.LineDescriptor.KeyLine]`.\n\n  keylines extracted from first image\n\n- **img2**: `Evision.Mat`.\n\n  second image\n\n- **keylines2**: `[Evision.LineDescriptor.KeyLine]`.\n\n  keylines extracted from second image\n\n- **matches1to2**: `[Evision.DMatch]`.\n\n  vector of matches\n\n##### Keyword Arguments\n- **matchColor**: `Evision.scalar()`.\n\n  drawing color for matches (chosen randomly in case of default value)\n\n- **singleLineColor**: `Evision.scalar()`.\n\n  drawing color for keylines (chosen randomly in case of default value)\n\n- **matchesMask**: `[char]`.\n\n  mask to indicate which matches must be drawn\n\n- **flags**: `integer()`.\n\n  drawing flags, see DrawLinesMatchesFlags\n\n##### Return\n- **outImg**: `Evision.Mat.t()`.\n\n  output matrix to draw on\n\n**Note**: If both *matchColor* and *singleLineColor* are set to their default values, function draws\nmatched lines and line connecting them with same color\n\nPython prototype (for reference only):\n```python3\ndrawLineMatches(img1, keylines1, img2, keylines2, matches1to2[, outImg[, matchColor[, singleLineColor[, matchesMask[, flags]]]]]) -> outImg\n```","ref":"Evision.LineDescriptor.html#drawLineMatches/6"},{"type":"type","title":"Evision.LineDescriptor.t/0","doc":"Type that represents an `LineDescriptor` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.LineDescriptor.html#t:t/0"},{"type":"module","title":"Evision.LineDescriptor.BinaryDescriptor","doc":"","ref":"Evision.LineDescriptor.BinaryDescriptor.html"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptor.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.LineDescriptor.BinaryDescriptor.html#clear/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.compute/1","doc":"","ref":"Evision.LineDescriptor.BinaryDescriptor.html#compute/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.compute/3","doc":"Requires descriptors computation\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptor.t()`\n- **image**: `Evision.Mat`.\n\n  input image\n\n##### Keyword Arguments\n- **returnFloatDescr**: `bool`.\n\n  flag (when set to true, original non-binary descriptors are returned)\n\n##### Return\n- **keylines**: `[Evision.LineDescriptor.KeyLine]`.\n\n  vector containing lines for which descriptors must be computed\n\n- **descriptors**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keylines[, descriptors[, returnFloatDescr]]) -> keylines, descriptors\n```","ref":"Evision.LineDescriptor.BinaryDescriptor.html#compute/3"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.compute/4","doc":"Requires descriptors computation\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptor.t()`\n- **image**: `Evision.Mat`.\n\n  input image\n\n##### Keyword Arguments\n- **returnFloatDescr**: `bool`.\n\n  flag (when set to true, original non-binary descriptors are returned)\n\n##### Return\n- **keylines**: `[Evision.LineDescriptor.KeyLine]`.\n\n  vector containing lines for which descriptors must be computed\n\n- **descriptors**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keylines[, descriptors[, returnFloatDescr]]) -> keylines, descriptors\n```","ref":"Evision.LineDescriptor.BinaryDescriptor.html#compute/4"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.createBinaryDescriptor/0","doc":"Create a BinaryDescriptor object with default parameters (or with the ones provided)\nand return a smart pointer to it\n\n##### Return\n- **retval**: `Evision.LineDescriptor.BinaryDescriptor.t()`\n\nPython prototype (for reference only):\n```python3\ncreateBinaryDescriptor() -> retval\n```","ref":"Evision.LineDescriptor.BinaryDescriptor.html#createBinaryDescriptor/0"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.createBinaryDescriptor/1","doc":"","ref":"Evision.LineDescriptor.BinaryDescriptor.html#createBinaryDescriptor/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.detect/1","doc":"","ref":"Evision.LineDescriptor.BinaryDescriptor.html#detect/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.detect/2","doc":"Requires line detection\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptor.t()`\n- **image**: `Evision.Mat`.\n\n  input image\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  mask matrix to detect only KeyLines of interest\n\n##### Return\n- **keypoints**: `[Evision.LineDescriptor.KeyLine]`.\n\n  vector that will store extracted lines for one or more images\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.LineDescriptor.BinaryDescriptor.html#detect/2"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.detect/3","doc":"Requires line detection\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptor.t()`\n- **image**: `Evision.Mat`.\n\n  input image\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  mask matrix to detect only KeyLines of interest\n\n##### Return\n- **keypoints**: `[Evision.LineDescriptor.KeyLine]`.\n\n  vector that will store extracted lines for one or more images\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.LineDescriptor.BinaryDescriptor.html#detect/3"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptor.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.LineDescriptor.BinaryDescriptor.html#empty/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptor.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.LineDescriptor.BinaryDescriptor.html#getDefaultName/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.getNumOfOctaves/1","doc":"Get current number of octaves\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptor.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNumOfOctaves() -> retval\n```","ref":"Evision.LineDescriptor.BinaryDescriptor.html#getNumOfOctaves/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.getReductionRatio/1","doc":"Get current reduction ratio (used in Gaussian pyramids)\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptor.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetReductionRatio() -> retval\n```","ref":"Evision.LineDescriptor.BinaryDescriptor.html#getReductionRatio/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.getWidthOfBand/1","doc":"Get current width of bands\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptor.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetWidthOfBand() -> retval\n```","ref":"Evision.LineDescriptor.BinaryDescriptor.html#getWidthOfBand/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.read/1","doc":"","ref":"Evision.LineDescriptor.BinaryDescriptor.html#read/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptor.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.LineDescriptor.BinaryDescriptor.html#read/2"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.save/1","doc":"","ref":"Evision.LineDescriptor.BinaryDescriptor.html#save/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptor.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.LineDescriptor.BinaryDescriptor.html#save/2"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.setNumOfOctaves/1","doc":"","ref":"Evision.LineDescriptor.BinaryDescriptor.html#setNumOfOctaves/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.setNumOfOctaves/2","doc":"Set number of octaves\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptor.t()`\n- **octaves**: `integer()`.\n\n  number of octaves\n\nPython prototype (for reference only):\n```python3\nsetNumOfOctaves(octaves) -> None\n```","ref":"Evision.LineDescriptor.BinaryDescriptor.html#setNumOfOctaves/2"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.setReductionRatio/1","doc":"","ref":"Evision.LineDescriptor.BinaryDescriptor.html#setReductionRatio/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.setReductionRatio/2","doc":"Set reduction ratio (used in Gaussian pyramids)\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptor.t()`\n- **rRatio**: `integer()`.\n\n  reduction ratio\n\nPython prototype (for reference only):\n```python3\nsetReductionRatio(rRatio) -> None\n```","ref":"Evision.LineDescriptor.BinaryDescriptor.html#setReductionRatio/2"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.setWidthOfBand/1","doc":"","ref":"Evision.LineDescriptor.BinaryDescriptor.html#setWidthOfBand/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.setWidthOfBand/2","doc":"Set width of bands\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptor.t()`\n- **width**: `integer()`.\n\n  width of bands\n\nPython prototype (for reference only):\n```python3\nsetWidthOfBand(width) -> None\n```","ref":"Evision.LineDescriptor.BinaryDescriptor.html#setWidthOfBand/2"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.write/1","doc":"","ref":"Evision.LineDescriptor.BinaryDescriptor.html#write/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptor.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.LineDescriptor.BinaryDescriptor.html#write/2"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptor.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptor.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.LineDescriptor.BinaryDescriptor.html#write/3"},{"type":"type","title":"Evision.LineDescriptor.BinaryDescriptor.t/0","doc":"Type that represents an `LineDescriptor.BinaryDescriptor` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.LineDescriptor.BinaryDescriptor.html#t:t/0"},{"type":"module","title":"Evision.LineDescriptor.BinaryDescriptorMatcher","doc":"","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.binaryDescriptorMatcher/0","doc":"Constructor.\n##### Return\n- **self**: `Evision.LineDescriptor.BinaryDescriptorMatcher.t()`\n\nThe BinaryDescriptorMatcher constructed is able to store and manage 256-bits long entries.\n\nPython prototype (for reference only):\n```python3\nBinaryDescriptorMatcher() ->  \n```","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#binaryDescriptorMatcher/0"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.binaryDescriptorMatcher/1","doc":"","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#binaryDescriptorMatcher/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptorMatcher.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#clear/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptorMatcher.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#empty/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptorMatcher.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#getDefaultName/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.knnMatch/1","doc":"","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#knnMatch/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.knnMatch/4","doc":"For every input query descriptor, retrieve the best *k* matching ones from a dataset provided from\nuser or from the one internal to class\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  query descriptors\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  dataset of descriptors furnished by user\n\n- **k**: `integer()`.\n\n  number of the closest descriptors to be returned for every input query\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  mask to select which input descriptors must be matched to ones in dataset\n\n- **compactResult**: `bool`.\n\n  flag to obtain a compact result (if true, a vector that doesn't contain any\n  matches for a given query is not inserted in final result)\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  vector to host retrieved matches\n\nPython prototype (for reference only):\n```python3\nknnMatch(queryDescriptors, trainDescriptors, k[, mask[, compactResult]]) -> matches\n```","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#knnMatch/4"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.knnMatch/5","doc":"For every input query descriptor, retrieve the best *k* matching ones from a dataset provided from\nuser or from the one internal to class\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  query descriptors\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  dataset of descriptors furnished by user\n\n- **k**: `integer()`.\n\n  number of the closest descriptors to be returned for every input query\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  mask to select which input descriptors must be matched to ones in dataset\n\n- **compactResult**: `bool`.\n\n  flag to obtain a compact result (if true, a vector that doesn't contain any\n  matches for a given query is not inserted in final result)\n\n##### Return\n- **matches**: `[[Evision.DMatch]]`.\n\n  vector to host retrieved matches\n\nPython prototype (for reference only):\n```python3\nknnMatch(queryDescriptors, trainDescriptors, k[, mask[, compactResult]]) -> matches\n```","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#knnMatch/5"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.knnMatchQuery/1","doc":"","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#knnMatchQuery/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.knnMatchQuery/4","doc":"knnMatchQuery\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  query descriptors\n\n- **matches**: `[[Evision.DMatch]]`.\n\n  vector to host retrieved matches\n\n- **k**: `integer()`.\n\n  number of the closest descriptors to be returned for every input query\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  vector of masks to select which input descriptors must be matched to ones in dataset\n  (the *i*-th mask in vector indicates whether each input query can be matched with descriptors in\n  dataset relative to *i*-th image)\n\n- **compactResult**: `bool`.\n\n  flag to obtain a compact result (if true, a vector that doesn't contain any\n  matches for a given query is not inserted in final result)\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nknnMatchQuery(queryDescriptors, matches, k[, masks[, compactResult]]) -> None\n```","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#knnMatchQuery/4"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.knnMatchQuery/5","doc":"knnMatchQuery\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  query descriptors\n\n- **matches**: `[[Evision.DMatch]]`.\n\n  vector to host retrieved matches\n\n- **k**: `integer()`.\n\n  number of the closest descriptors to be returned for every input query\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  vector of masks to select which input descriptors must be matched to ones in dataset\n  (the *i*-th mask in vector indicates whether each input query can be matched with descriptors in\n  dataset relative to *i*-th image)\n\n- **compactResult**: `bool`.\n\n  flag to obtain a compact result (if true, a vector that doesn't contain any\n  matches for a given query is not inserted in final result)\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nknnMatchQuery(queryDescriptors, matches, k[, masks[, compactResult]]) -> None\n```","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#knnMatchQuery/5"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.match/1","doc":"","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#match/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.match/3","doc":"For every input query descriptor, retrieve the best matching one from a dataset provided from user\nor from the one internal to class\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  query descriptors\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  dataset of descriptors furnished by user\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  mask to select which input descriptors must be matched to one in dataset\n\n##### Return\n- **matches**: `[Evision.DMatch]`.\n\n  vector to host retrieved matches\n\nPython prototype (for reference only):\n```python3\nmatch(queryDescriptors, trainDescriptors[, mask]) -> matches\n```","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#match/3"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.match/4","doc":"For every input query descriptor, retrieve the best matching one from a dataset provided from user\nor from the one internal to class\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  query descriptors\n\n- **trainDescriptors**: `Evision.Mat`.\n\n  dataset of descriptors furnished by user\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  mask to select which input descriptors must be matched to one in dataset\n\n##### Return\n- **matches**: `[Evision.DMatch]`.\n\n  vector to host retrieved matches\n\nPython prototype (for reference only):\n```python3\nmatch(queryDescriptors, trainDescriptors[, mask]) -> matches\n```","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#match/4"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.matchQuery/1","doc":"","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#matchQuery/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.matchQuery/2","doc":"matchQuery\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  query descriptors\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  vector of masks to select which input descriptors must be matched to one in dataset\n  (the *i*-th mask in vector indicates whether each input query can be matched with descriptors in\n  dataset relative to *i*-th image)\n\n##### Return\n- **matches**: `[Evision.DMatch]`.\n\n  vector to host retrieved matches\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmatchQuery(queryDescriptors[, masks]) -> matches\n```","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#matchQuery/2"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.matchQuery/3","doc":"matchQuery\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptorMatcher.t()`\n- **queryDescriptors**: `Evision.Mat`.\n\n  query descriptors\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  vector of masks to select which input descriptors must be matched to one in dataset\n  (the *i*-th mask in vector indicates whether each input query can be matched with descriptors in\n  dataset relative to *i*-th image)\n\n##### Return\n- **matches**: `[Evision.DMatch]`.\n\n  vector to host retrieved matches\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nmatchQuery(queryDescriptors[, masks]) -> matches\n```","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#matchQuery/3"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.read/1","doc":"","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#read/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptorMatcher.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#read/2"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.save/1","doc":"","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#save/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptorMatcher.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#save/2"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.write/1","doc":"","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#write/1"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptorMatcher.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#write/2"},{"type":"function","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.BinaryDescriptorMatcher.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#write/3"},{"type":"type","title":"Evision.LineDescriptor.BinaryDescriptorMatcher.t/0","doc":"Type that represents an `LineDescriptor.BinaryDescriptorMatcher` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.LineDescriptor.BinaryDescriptorMatcher.html#t:t/0"},{"type":"module","title":"Evision.LineDescriptor.DrawLinesMatchesFlags","doc":"","ref":"Evision.LineDescriptor.DrawLinesMatchesFlags.html"},{"type":"type","title":"Evision.LineDescriptor.DrawLinesMatchesFlags.t/0","doc":"Type that represents an `LineDescriptor.DrawLinesMatchesFlags` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.LineDescriptor.DrawLinesMatchesFlags.html#t:t/0"},{"type":"module","title":"Evision.LineDescriptor.KeyLine","doc":"","ref":"Evision.LineDescriptor.KeyLine.html"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.get_angle/1","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#get_angle/1"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.get_class_id/1","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#get_class_id/1"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.get_endPointX/1","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#get_endPointX/1"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.get_endPointY/1","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#get_endPointY/1"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.get_ePointInOctaveX/1","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#get_ePointInOctaveX/1"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.get_ePointInOctaveY/1","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#get_ePointInOctaveY/1"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.get_lineLength/1","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#get_lineLength/1"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.get_numOfPixels/1","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#get_numOfPixels/1"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.get_octave/1","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#get_octave/1"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.get_pt/1","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#get_pt/1"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.get_response/1","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#get_response/1"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.get_size/1","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#get_size/1"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.get_sPointInOctaveX/1","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#get_sPointInOctaveX/1"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.get_sPointInOctaveY/1","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#get_sPointInOctaveY/1"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.get_startPointX/1","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#get_startPointX/1"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.get_startPointY/1","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#get_startPointY/1"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.getEndPoint/1","doc":"getEndPoint\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.KeyLine.t()`\n\n##### Return\n- **retval**: `Point2f`\n\nReturns the end point of the line in the original image\n\nPython prototype (for reference only):\n```python3\ngetEndPoint() -> retval\n```","ref":"Evision.LineDescriptor.KeyLine.html#getEndPoint/1"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.getEndPointInOctave/1","doc":"getEndPointInOctave\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.KeyLine.t()`\n\n##### Return\n- **retval**: `Point2f`\n\nReturns the end point of the line in the octave it was extracted from\n\nPython prototype (for reference only):\n```python3\ngetEndPointInOctave() -> retval\n```","ref":"Evision.LineDescriptor.KeyLine.html#getEndPointInOctave/1"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.getStartPoint/1","doc":"getStartPoint\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.KeyLine.t()`\n\n##### Return\n- **retval**: `Point2f`\n\nReturns the start point of the line in the original image\n\nPython prototype (for reference only):\n```python3\ngetStartPoint() -> retval\n```","ref":"Evision.LineDescriptor.KeyLine.html#getStartPoint/1"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.getStartPointInOctave/1","doc":"getStartPointInOctave\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.KeyLine.t()`\n\n##### Return\n- **retval**: `Point2f`\n\nReturns the start point of the line in the octave it was extracted from\n\nPython prototype (for reference only):\n```python3\ngetStartPointInOctave() -> retval\n```","ref":"Evision.LineDescriptor.KeyLine.html#getStartPointInOctave/1"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.keyLine/0","doc":"KeyLine\n##### Return\n- **self**: `Evision.LineDescriptor.KeyLine.t()`\n\nconstructor\n\nPython prototype (for reference only):\n```python3\nKeyLine() ->  \n```","ref":"Evision.LineDescriptor.KeyLine.html#keyLine/0"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.keyLine/1","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#keyLine/1"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.set_angle/2","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#set_angle/2"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.set_class_id/2","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#set_class_id/2"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.set_endPointX/2","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#set_endPointX/2"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.set_endPointY/2","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#set_endPointY/2"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.set_ePointInOctaveX/2","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#set_ePointInOctaveX/2"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.set_ePointInOctaveY/2","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#set_ePointInOctaveY/2"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.set_lineLength/2","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#set_lineLength/2"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.set_numOfPixels/2","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#set_numOfPixels/2"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.set_octave/2","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#set_octave/2"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.set_pt/2","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#set_pt/2"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.set_response/2","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#set_response/2"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.set_size/2","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#set_size/2"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.set_sPointInOctaveX/2","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#set_sPointInOctaveX/2"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.set_sPointInOctaveY/2","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#set_sPointInOctaveY/2"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.set_startPointX/2","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#set_startPointX/2"},{"type":"function","title":"Evision.LineDescriptor.KeyLine.set_startPointY/2","doc":"","ref":"Evision.LineDescriptor.KeyLine.html#set_startPointY/2"},{"type":"type","title":"Evision.LineDescriptor.KeyLine.t/0","doc":"Type that represents an `LineDescriptor.KeyLine` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.LineDescriptor.KeyLine.html#t:t/0"},{"type":"module","title":"Evision.LineDescriptor.LSDDetector","doc":"","ref":"Evision.LineDescriptor.LSDDetector.html"},{"type":"function","title":"Evision.LineDescriptor.LSDDetector.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.LSDDetector.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.LineDescriptor.LSDDetector.html#clear/1"},{"type":"function","title":"Evision.LineDescriptor.LSDDetector.createLSDDetector/0","doc":"Creates ad LSDDetector object, using smart pointers.\n##### Return\n- **retval**: `Evision.LineDescriptor.LSDDetector.t()`\n\nPython prototype (for reference only):\n```python3\ncreateLSDDetector() -> retval\n```","ref":"Evision.LineDescriptor.LSDDetector.html#createLSDDetector/0"},{"type":"function","title":"Evision.LineDescriptor.LSDDetector.createLSDDetector/1","doc":"","ref":"Evision.LineDescriptor.LSDDetector.html#createLSDDetector/1"},{"type":"function","title":"Evision.LineDescriptor.LSDDetector.createLSDDetectorWithParams/1","doc":"createLSDDetectorWithParams\n\n##### Positional Arguments\n- **params**: `Evision.LineDescriptor.LSDParam`\n\n##### Return\n- **retval**: `Evision.LineDescriptor.LSDDetector.t()`\n\nPython prototype (for reference only):\n```python3\ncreateLSDDetectorWithParams(params) -> retval\n```","ref":"Evision.LineDescriptor.LSDDetector.html#createLSDDetectorWithParams/1"},{"type":"function","title":"Evision.LineDescriptor.LSDDetector.detect/1","doc":"","ref":"Evision.LineDescriptor.LSDDetector.html#detect/1"},{"type":"function","title":"Evision.LineDescriptor.LSDDetector.detect/4","doc":"Detect lines inside an image.\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.LSDDetector.t()`\n- **image**: `Evision.Mat`.\n\n  input image\n\n- **scale**: `integer()`.\n\n  scale factor used in pyramids generation\n\n- **numOctaves**: `integer()`.\n\n  number of octaves inside pyramid\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  mask matrix to detect only KeyLines of interest\n\n##### Return\n- **keypoints**: `[Evision.LineDescriptor.KeyLine]`.\n\n  vector that will store extracted lines for one or more images\n\nPython prototype (for reference only):\n```python3\ndetect(image, scale, numOctaves[, mask]) -> keypoints\n```","ref":"Evision.LineDescriptor.LSDDetector.html#detect/4"},{"type":"function","title":"Evision.LineDescriptor.LSDDetector.detect/5","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.LSDDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  input images\n\n- **keylines**: `[[Evision.LineDescriptor.KeyLine]]`.\n\n  set of vectors that will store extracted lines for one or more images\n\n- **scale**: `integer()`.\n\n  scale factor used in pyramids generation\n\n- **numOctaves**: `integer()`.\n\n  number of octaves inside pyramid\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  vector of mask matrices to detect only KeyLines of interest from each input image\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images, keylines, scale, numOctaves[, masks]) -> None\n```\n#### Variant 2:\nDetect lines inside an image.\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.LSDDetector.t()`\n- **image**: `Evision.Mat`.\n\n  input image\n\n- **scale**: `integer()`.\n\n  scale factor used in pyramids generation\n\n- **numOctaves**: `integer()`.\n\n  number of octaves inside pyramid\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  mask matrix to detect only KeyLines of interest\n\n##### Return\n- **keypoints**: `[Evision.LineDescriptor.KeyLine]`.\n\n  vector that will store extracted lines for one or more images\n\nPython prototype (for reference only):\n```python3\ndetect(image, scale, numOctaves[, mask]) -> keypoints\n```","ref":"Evision.LineDescriptor.LSDDetector.html#detect/5"},{"type":"function","title":"Evision.LineDescriptor.LSDDetector.detect/6","doc":"detect\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.LSDDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  input images\n\n- **keylines**: `[[Evision.LineDescriptor.KeyLine]]`.\n\n  set of vectors that will store extracted lines for one or more images\n\n- **scale**: `integer()`.\n\n  scale factor used in pyramids generation\n\n- **numOctaves**: `integer()`.\n\n  number of octaves inside pyramid\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  vector of mask matrices to detect only KeyLines of interest from each input image\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images, keylines, scale, numOctaves[, masks]) -> None\n```","ref":"Evision.LineDescriptor.LSDDetector.html#detect/6"},{"type":"function","title":"Evision.LineDescriptor.LSDDetector.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.LSDDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.LineDescriptor.LSDDetector.html#empty/1"},{"type":"function","title":"Evision.LineDescriptor.LSDDetector.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.LSDDetector.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.LineDescriptor.LSDDetector.html#getDefaultName/1"},{"type":"function","title":"Evision.LineDescriptor.LSDDetector.lSDDetector/1","doc":"LSDDetectorWithParams\n\n##### Positional Arguments\n- **params**: `Evision.LineDescriptor.LSDParam`\n\n##### Return\n- **self**: `Evision.LineDescriptor.LSDDetector.t()`\n\nPython prototype (for reference only):\n```python3\nLSDDetectorWithParams(_params) ->  \n```","ref":"Evision.LineDescriptor.LSDDetector.html#lSDDetector/1"},{"type":"function","title":"Evision.LineDescriptor.LSDDetector.read/1","doc":"","ref":"Evision.LineDescriptor.LSDDetector.html#read/1"},{"type":"function","title":"Evision.LineDescriptor.LSDDetector.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.LSDDetector.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.LineDescriptor.LSDDetector.html#read/2"},{"type":"function","title":"Evision.LineDescriptor.LSDDetector.save/1","doc":"","ref":"Evision.LineDescriptor.LSDDetector.html#save/1"},{"type":"function","title":"Evision.LineDescriptor.LSDDetector.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.LSDDetector.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.LineDescriptor.LSDDetector.html#save/2"},{"type":"function","title":"Evision.LineDescriptor.LSDDetector.write/1","doc":"","ref":"Evision.LineDescriptor.LSDDetector.html#write/1"},{"type":"function","title":"Evision.LineDescriptor.LSDDetector.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.LSDDetector.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.LineDescriptor.LSDDetector.html#write/2"},{"type":"function","title":"Evision.LineDescriptor.LSDDetector.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.LineDescriptor.LSDDetector.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.LineDescriptor.LSDDetector.html#write/3"},{"type":"type","title":"Evision.LineDescriptor.LSDDetector.t/0","doc":"Type that represents an `LineDescriptor.LSDDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.LineDescriptor.LSDDetector.html#t:t/0"},{"type":"module","title":"Evision.LineDescriptor.LSDParam","doc":"","ref":"Evision.LineDescriptor.LSDParam.html"},{"type":"function","title":"Evision.LineDescriptor.LSDParam.get_ang_th/1","doc":"","ref":"Evision.LineDescriptor.LSDParam.html#get_ang_th/1"},{"type":"function","title":"Evision.LineDescriptor.LSDParam.get_density_th/1","doc":"","ref":"Evision.LineDescriptor.LSDParam.html#get_density_th/1"},{"type":"function","title":"Evision.LineDescriptor.LSDParam.get_log_eps/1","doc":"","ref":"Evision.LineDescriptor.LSDParam.html#get_log_eps/1"},{"type":"function","title":"Evision.LineDescriptor.LSDParam.get_n_bins/1","doc":"","ref":"Evision.LineDescriptor.LSDParam.html#get_n_bins/1"},{"type":"function","title":"Evision.LineDescriptor.LSDParam.get_quant/1","doc":"","ref":"Evision.LineDescriptor.LSDParam.html#get_quant/1"},{"type":"function","title":"Evision.LineDescriptor.LSDParam.get_scale/1","doc":"","ref":"Evision.LineDescriptor.LSDParam.html#get_scale/1"},{"type":"function","title":"Evision.LineDescriptor.LSDParam.get_sigma_scale/1","doc":"","ref":"Evision.LineDescriptor.LSDParam.html#get_sigma_scale/1"},{"type":"function","title":"Evision.LineDescriptor.LSDParam.lSDParam/0","doc":"LSDParam\n##### Return\n- **self**: `Evision.LineDescriptor.LSDParam.t()`\n\nPython prototype (for reference only):\n```python3\nLSDParam() ->  \n```","ref":"Evision.LineDescriptor.LSDParam.html#lSDParam/0"},{"type":"function","title":"Evision.LineDescriptor.LSDParam.lSDParam/1","doc":"","ref":"Evision.LineDescriptor.LSDParam.html#lSDParam/1"},{"type":"function","title":"Evision.LineDescriptor.LSDParam.set_ang_th/2","doc":"","ref":"Evision.LineDescriptor.LSDParam.html#set_ang_th/2"},{"type":"function","title":"Evision.LineDescriptor.LSDParam.set_density_th/2","doc":"","ref":"Evision.LineDescriptor.LSDParam.html#set_density_th/2"},{"type":"function","title":"Evision.LineDescriptor.LSDParam.set_log_eps/2","doc":"","ref":"Evision.LineDescriptor.LSDParam.html#set_log_eps/2"},{"type":"function","title":"Evision.LineDescriptor.LSDParam.set_n_bins/2","doc":"","ref":"Evision.LineDescriptor.LSDParam.html#set_n_bins/2"},{"type":"function","title":"Evision.LineDescriptor.LSDParam.set_quant/2","doc":"","ref":"Evision.LineDescriptor.LSDParam.html#set_quant/2"},{"type":"function","title":"Evision.LineDescriptor.LSDParam.set_scale/2","doc":"","ref":"Evision.LineDescriptor.LSDParam.html#set_scale/2"},{"type":"function","title":"Evision.LineDescriptor.LSDParam.set_sigma_scale/2","doc":"","ref":"Evision.LineDescriptor.LSDParam.html#set_sigma_scale/2"},{"type":"type","title":"Evision.LineDescriptor.LSDParam.t/0","doc":"Type that represents an `LineDescriptor.LSDParam` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.LineDescriptor.LSDParam.html#t:t/0"},{"type":"module","title":"Evision.LineMod","doc":"","ref":"Evision.LineMod.html"},{"type":"function","title":"Evision.LineMod.colormap/1","doc":"colormap\n\n##### Positional Arguments\n- **quantized**: `Evision.Mat`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n \\brief Debug function to colormap a quantized image for viewing.\n\nPython prototype (for reference only):\n```python3\ncolormap(quantized[, dst]) -> dst\n```","ref":"Evision.LineMod.html#colormap/1"},{"type":"function","title":"Evision.LineMod.colormap/2","doc":"colormap\n\n##### Positional Arguments\n- **quantized**: `Evision.Mat`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n \\brief Debug function to colormap a quantized image for viewing.\n\nPython prototype (for reference only):\n```python3\ncolormap(quantized[, dst]) -> dst\n```","ref":"Evision.LineMod.html#colormap/2"},{"type":"function","title":"Evision.LineMod.drawFeatures/1","doc":"","ref":"Evision.LineMod.html#drawFeatures/1"},{"type":"function","title":"Evision.LineMod.drawFeatures/3","doc":"drawFeatures\n\n##### Positional Arguments\n- **templates**: `[Evision.LineMod.Template]`.\n\n  see @ref Detector::addTemplate\n\n- **tl**: `Point2i`.\n\n  template bbox top-left offset see @ref Detector::addTemplate\n\n##### Keyword Arguments\n- **size**: `integer()`.\n\n  marker size see @ref cv::drawMarker\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n \\brief Debug function to draw linemod features\n\nPython prototype (for reference only):\n```python3\ndrawFeatures(img, templates, tl[, size]) -> img\n```","ref":"Evision.LineMod.html#drawFeatures/3"},{"type":"function","title":"Evision.LineMod.drawFeatures/4","doc":"drawFeatures\n\n##### Positional Arguments\n- **templates**: `[Evision.LineMod.Template]`.\n\n  see @ref Detector::addTemplate\n\n- **tl**: `Point2i`.\n\n  template bbox top-left offset see @ref Detector::addTemplate\n\n##### Keyword Arguments\n- **size**: `integer()`.\n\n  marker size see @ref cv::drawMarker\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n \\brief Debug function to draw linemod features\n\nPython prototype (for reference only):\n```python3\ndrawFeatures(img, templates, tl[, size]) -> img\n```","ref":"Evision.LineMod.html#drawFeatures/4"},{"type":"function","title":"Evision.LineMod.getDefaultLINE/0","doc":"getDefaultLINE\n##### Return\n- **retval**: `Evision.LineMod.Detector.t()`\n\n \\brief Factory function for detector using LINE algorithm with color gradients.\n Default parameter settings suitable for VGA images.\n\nPython prototype (for reference only):\n```python3\ngetDefaultLINE() -> retval\n```","ref":"Evision.LineMod.html#getDefaultLINE/0"},{"type":"function","title":"Evision.LineMod.getDefaultLINE/1","doc":"","ref":"Evision.LineMod.html#getDefaultLINE/1"},{"type":"function","title":"Evision.LineMod.getDefaultLINEMOD/0","doc":"getDefaultLINEMOD\n##### Return\n- **retval**: `Evision.LineMod.Detector.t()`\n\n \\brief Factory function for detector using LINE-MOD algorithm with color gradients\n and depth normals.\n Default parameter settings suitable for VGA images.\n\nPython prototype (for reference only):\n```python3\ngetDefaultLINEMOD() -> retval\n```","ref":"Evision.LineMod.html#getDefaultLINEMOD/0"},{"type":"function","title":"Evision.LineMod.getDefaultLINEMOD/1","doc":"","ref":"Evision.LineMod.html#getDefaultLINEMOD/1"},{"type":"type","title":"Evision.LineMod.t/0","doc":"Type that represents an `LineMod` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.LineMod.html#t:t/0"},{"type":"module","title":"Evision.LineMod.ColorGradient","doc":"","ref":"Evision.LineMod.ColorGradient.html"},{"type":"function","title":"Evision.LineMod.ColorGradient.create/1","doc":"","ref":"Evision.LineMod.ColorGradient.html#create/1"},{"type":"function","title":"Evision.LineMod.ColorGradient.create/3","doc":"create\n\n##### Positional Arguments\n- **weak_threshold**: `float`\n- **num_features**: `size_t`\n- **strong_threshold**: `float`\n\n##### Return\n- **retval**: `ColorGradient`\n\n \\brief Constructor.\n \\param weak_threshold   When quantizing, discard gradients with magnitude less than this.\n \\param num_features     How many features a template must contain.\n \\param strong_threshold Consider as candidate features only gradients whose norms are\n                         larger than this.\n\nPython prototype (for reference only):\n```python3\ncreate(weak_threshold, num_features, strong_threshold) -> retval\n```","ref":"Evision.LineMod.ColorGradient.html#create/3"},{"type":"function","title":"Evision.LineMod.ColorGradient.get_num_features/1","doc":"","ref":"Evision.LineMod.ColorGradient.html#get_num_features/1"},{"type":"function","title":"Evision.LineMod.ColorGradient.get_strong_threshold/1","doc":"","ref":"Evision.LineMod.ColorGradient.html#get_strong_threshold/1"},{"type":"function","title":"Evision.LineMod.ColorGradient.get_weak_threshold/1","doc":"","ref":"Evision.LineMod.ColorGradient.html#get_weak_threshold/1"},{"type":"type","title":"Evision.LineMod.ColorGradient.t/0","doc":"Type that represents an `LineMod.ColorGradient` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.LineMod.ColorGradient.html#t:t/0"},{"type":"module","title":"Evision.LineMod.DepthNormal","doc":"","ref":"Evision.LineMod.DepthNormal.html"},{"type":"function","title":"Evision.LineMod.DepthNormal.create/1","doc":"","ref":"Evision.LineMod.DepthNormal.html#create/1"},{"type":"function","title":"Evision.LineMod.DepthNormal.create/4","doc":"create\n\n##### Positional Arguments\n- **distance_threshold**: `integer()`\n- **difference_threshold**: `integer()`\n- **num_features**: `size_t`\n- **extract_threshold**: `integer()`\n\n##### Return\n- **retval**: `DepthNormal`\n\n \\brief Constructor.\n \\param distance_threshold   Ignore pixels beyond this distance.\n \\param difference_threshold When computing normals, ignore contributions of pixels whose\n                             depth difference with the central pixel is above this threshold.\n \\param num_features         How many features a template must contain.\n \\param extract_threshold    Consider as candidate feature only if there are no differing\n                             orientations within a distance of extract_threshold.\n\nPython prototype (for reference only):\n```python3\ncreate(distance_threshold, difference_threshold, num_features, extract_threshold) -> retval\n```","ref":"Evision.LineMod.DepthNormal.html#create/4"},{"type":"function","title":"Evision.LineMod.DepthNormal.get_difference_threshold/1","doc":"","ref":"Evision.LineMod.DepthNormal.html#get_difference_threshold/1"},{"type":"function","title":"Evision.LineMod.DepthNormal.get_distance_threshold/1","doc":"","ref":"Evision.LineMod.DepthNormal.html#get_distance_threshold/1"},{"type":"function","title":"Evision.LineMod.DepthNormal.get_extract_threshold/1","doc":"","ref":"Evision.LineMod.DepthNormal.html#get_extract_threshold/1"},{"type":"function","title":"Evision.LineMod.DepthNormal.get_num_features/1","doc":"","ref":"Evision.LineMod.DepthNormal.html#get_num_features/1"},{"type":"type","title":"Evision.LineMod.DepthNormal.t/0","doc":"Type that represents an `LineMod.DepthNormal` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.LineMod.DepthNormal.html#t:t/0"},{"type":"module","title":"Evision.LineMod.Detector","doc":"","ref":"Evision.LineMod.Detector.html"},{"type":"function","title":"Evision.LineMod.Detector.addSyntheticTemplate/1","doc":"","ref":"Evision.LineMod.Detector.html#addSyntheticTemplate/1"},{"type":"function","title":"Evision.LineMod.Detector.addSyntheticTemplate/3","doc":"addSyntheticTemplate\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.Detector.t()`\n- **templates**: `[Evision.LineMod.Template]`\n- **class_id**: `String`\n\n##### Return\n- **retval**: `integer()`\n\n \\brief Add a new object template computed by external means.\n\nPython prototype (for reference only):\n```python3\naddSyntheticTemplate(templates, class_id) -> retval\n```","ref":"Evision.LineMod.Detector.html#addSyntheticTemplate/3"},{"type":"function","title":"Evision.LineMod.Detector.addTemplate/1","doc":"","ref":"Evision.LineMod.Detector.html#addTemplate/1"},{"type":"function","title":"Evision.LineMod.Detector.addTemplate/4","doc":"addTemplate\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.Detector.t()`\n- **sources**: `[Evision.Mat]`\n- **class_id**: `String`\n- **object_mask**: `Evision.Mat`\n\n##### Return\n- **retval**: `integer()`\n- **bounding_box**: `Rect*`\n\n \\brief Add new object template.\n \\param      sources      Source images, one for each modality.\n \\param      class_id     Object class ID.\n \\param      object_mask  Mask separating object from background.\n \\param[out] bounding_box Optionally return bounding box of the extracted features.\n \\return Template ID, or -1 if failed to extract a valid template.\n\nPython prototype (for reference only):\n```python3\naddTemplate(sources, class_id, object_mask) -> retval, bounding_box\n```","ref":"Evision.LineMod.Detector.html#addTemplate/4"},{"type":"function","title":"Evision.LineMod.Detector.classIds/1","doc":"classIds\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.Detector.t()`\n\n##### Return\n- **retval**: `[String]`\n\nPython prototype (for reference only):\n```python3\nclassIds() -> retval\n```","ref":"Evision.LineMod.Detector.html#classIds/1"},{"type":"function","title":"Evision.LineMod.Detector.detector/0","doc":"Detector\n##### Return\n- **self**: `Detector`\n\n \\brief Empty constructor, initialize with read().\n\nPython prototype (for reference only):\n```python3\nDetector() ->  \n```","ref":"Evision.LineMod.Detector.html#detector/0"},{"type":"function","title":"Evision.LineMod.Detector.detector/1","doc":"","ref":"Evision.LineMod.Detector.html#detector/1"},{"type":"function","title":"Evision.LineMod.Detector.detector/2","doc":"Detector\n\n##### Positional Arguments\n- **modalities**: `[Ptr_Modality]`\n- **t_pyramid**: `[integer()]`\n\n##### Return\n- **self**: `Detector`\n\n \\brief Constructor.\n \\param modalities       Modalities to use (color gradients, depth normals, ...).\n \\param T_pyramid        Value of the sampling step T at each pyramid level. The\n                         number of pyramid levels is T_pyramid.size().\n\nPython prototype (for reference only):\n```python3\nDetector(modalities, T_pyramid) ->  \n```","ref":"Evision.LineMod.Detector.html#detector/2"},{"type":"function","title":"Evision.LineMod.Detector.getModalities/1","doc":"getModalities\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.Detector.t()`\n\n##### Return\n- **retval**: `[Modality]`\n\n \\brief Get the modalities used by this detector.\n You are not permitted to add/remove modalities, but you may dynamic_cast them to\n tweak parameters.\n\nPython prototype (for reference only):\n```python3\ngetModalities() -> retval\n```","ref":"Evision.LineMod.Detector.html#getModalities/1"},{"type":"function","title":"Evision.LineMod.Detector.getT/1","doc":"","ref":"Evision.LineMod.Detector.html#getT/1"},{"type":"function","title":"Evision.LineMod.Detector.getT/2","doc":"getT\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.Detector.t()`\n- **pyramid_level**: `integer()`\n\n##### Return\n- **retval**: `integer()`\n\n \\brief Get sampling step T at pyramid_level.\n\nPython prototype (for reference only):\n```python3\ngetT(pyramid_level) -> retval\n```","ref":"Evision.LineMod.Detector.html#getT/2"},{"type":"function","title":"Evision.LineMod.Detector.getTemplates/1","doc":"","ref":"Evision.LineMod.Detector.html#getTemplates/1"},{"type":"function","title":"Evision.LineMod.Detector.getTemplates/3","doc":"getTemplates\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.Detector.t()`\n- **class_id**: `String`\n- **template_id**: `integer()`\n\n##### Return\n- **retval**: `[Evision.LineMod.Template]`\n\n \\brief Get the template pyramid identified by template_id.\n For example, with 2 modalities (Gradient, Normal) and two pyramid levels\n (L0, L1), the order is (GradientL0, NormalL0, GradientL1, NormalL1).\n\nPython prototype (for reference only):\n```python3\ngetTemplates(class_id, template_id) -> retval\n```","ref":"Evision.LineMod.Detector.html#getTemplates/3"},{"type":"function","title":"Evision.LineMod.Detector.match/1","doc":"","ref":"Evision.LineMod.Detector.html#match/1"},{"type":"function","title":"Evision.LineMod.Detector.match/3","doc":"match\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.Detector.t()`\n- **sources**: `[Evision.Mat]`\n- **threshold**: `float`\n\n##### Keyword Arguments\n- **class_ids**: `[String]`.\n- **masks**: `[Evision.Mat]`.\n\n##### Return\n- **matches**: `[Match]`\n- **quantized_images**: `[Evision.Mat]`.\n\n \\brief Detect objects by template matching.\n Matches globally at the lowest pyramid level, then refines locally stepping up the pyramid.\n \\param      sources   Source images, one for each modality.\n \\param      threshold Similarity threshold, a percentage between 0 and 100.\n \\param[out] matches   Template matches, sorted by similarity score.\n \\param      class_ids If non-empty, only search for the desired object classes.\n \\param[out] quantized_images Optionally return vector  of quantized images.\n \\param      masks     The masks for consideration during matching. The masks should be CV_8UC1\n                       where 255 represents a valid pixel.  If non-empty, the vector must be\n                       the same size as sources.  Each element must be\n                       empty or the same size as its corresponding source.\n\nPython prototype (for reference only):\n```python3\nmatch(sources, threshold[, class_ids[, quantized_images[, masks]]]) -> matches, quantized_images\n```","ref":"Evision.LineMod.Detector.html#match/3"},{"type":"function","title":"Evision.LineMod.Detector.match/4","doc":"match\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.Detector.t()`\n- **sources**: `[Evision.Mat]`\n- **threshold**: `float`\n\n##### Keyword Arguments\n- **class_ids**: `[String]`.\n- **masks**: `[Evision.Mat]`.\n\n##### Return\n- **matches**: `[Match]`\n- **quantized_images**: `[Evision.Mat]`.\n\n \\brief Detect objects by template matching.\n Matches globally at the lowest pyramid level, then refines locally stepping up the pyramid.\n \\param      sources   Source images, one for each modality.\n \\param      threshold Similarity threshold, a percentage between 0 and 100.\n \\param[out] matches   Template matches, sorted by similarity score.\n \\param      class_ids If non-empty, only search for the desired object classes.\n \\param[out] quantized_images Optionally return vector  of quantized images.\n \\param      masks     The masks for consideration during matching. The masks should be CV_8UC1\n                       where 255 represents a valid pixel.  If non-empty, the vector must be\n                       the same size as sources.  Each element must be\n                       empty or the same size as its corresponding source.\n\nPython prototype (for reference only):\n```python3\nmatch(sources, threshold[, class_ids[, quantized_images[, masks]]]) -> matches, quantized_images\n```","ref":"Evision.LineMod.Detector.html#match/4"},{"type":"function","title":"Evision.LineMod.Detector.numClasses/1","doc":"numClasses\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.Detector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nnumClasses() -> retval\n```","ref":"Evision.LineMod.Detector.html#numClasses/1"},{"type":"function","title":"Evision.LineMod.Detector.numTemplates/1","doc":"numTemplates\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.Detector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nnumTemplates() -> retval\n```","ref":"Evision.LineMod.Detector.html#numTemplates/1"},{"type":"function","title":"Evision.LineMod.Detector.numTemplates/2","doc":"numTemplates\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.Detector.t()`\n- **class_id**: `String`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nnumTemplates(class_id) -> retval\n```","ref":"Evision.LineMod.Detector.html#numTemplates/2"},{"type":"function","title":"Evision.LineMod.Detector.pyramidLevels/1","doc":"pyramidLevels\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.Detector.t()`\n\n##### Return\n- **retval**: `integer()`\n\n \\brief Get number of pyramid levels used by this detector.\n\nPython prototype (for reference only):\n```python3\npyramidLevels() -> retval\n```","ref":"Evision.LineMod.Detector.html#pyramidLevels/1"},{"type":"function","title":"Evision.LineMod.Detector.read/1","doc":"","ref":"Evision.LineMod.Detector.html#read/1"},{"type":"function","title":"Evision.LineMod.Detector.read/2","doc":"read\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.Detector.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.LineMod.Detector.html#read/2"},{"type":"function","title":"Evision.LineMod.Detector.readClasses/1","doc":"","ref":"Evision.LineMod.Detector.html#readClasses/1"},{"type":"function","title":"Evision.LineMod.Detector.readClasses/2","doc":"readClasses\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.Detector.t()`\n- **class_ids**: `[String]`\n\n##### Keyword Arguments\n- **format**: `String`.\n\nPython prototype (for reference only):\n```python3\nreadClasses(class_ids[, format]) -> None\n```","ref":"Evision.LineMod.Detector.html#readClasses/2"},{"type":"function","title":"Evision.LineMod.Detector.readClasses/3","doc":"readClasses\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.Detector.t()`\n- **class_ids**: `[String]`\n\n##### Keyword Arguments\n- **format**: `String`.\n\nPython prototype (for reference only):\n```python3\nreadClasses(class_ids[, format]) -> None\n```","ref":"Evision.LineMod.Detector.html#readClasses/3"},{"type":"function","title":"Evision.LineMod.Detector.writeClasses/1","doc":"writeClasses\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.Detector.t()`\n\n##### Keyword Arguments\n- **format**: `String`.\n\nPython prototype (for reference only):\n```python3\nwriteClasses([, format]) -> None\n```","ref":"Evision.LineMod.Detector.html#writeClasses/1"},{"type":"function","title":"Evision.LineMod.Detector.writeClasses/2","doc":"writeClasses\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.Detector.t()`\n\n##### Keyword Arguments\n- **format**: `String`.\n\nPython prototype (for reference only):\n```python3\nwriteClasses([, format]) -> None\n```","ref":"Evision.LineMod.Detector.html#writeClasses/2"},{"type":"type","title":"Evision.LineMod.Detector.t/0","doc":"Type that represents an `LineMod.Detector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.LineMod.Detector.html#t:t/0"},{"type":"module","title":"Evision.LineMod.Feature","doc":"","ref":"Evision.LineMod.Feature.html"},{"type":"function","title":"Evision.LineMod.Feature.feature/0","doc":"Feature\n##### Return\n- **self**: `Feature`\n\nPython prototype (for reference only):\n```python3\nFeature() ->  \n```","ref":"Evision.LineMod.Feature.html#feature/0"},{"type":"function","title":"Evision.LineMod.Feature.feature/1","doc":"","ref":"Evision.LineMod.Feature.html#feature/1"},{"type":"function","title":"Evision.LineMod.Feature.feature/3","doc":"Feature\n\n##### Positional Arguments\n- **x**: `integer()`\n- **y**: `integer()`\n- **label**: `integer()`\n\n##### Return\n- **self**: `Feature`\n\nPython prototype (for reference only):\n```python3\nFeature(x, y, label) ->  \n```","ref":"Evision.LineMod.Feature.html#feature/3"},{"type":"function","title":"Evision.LineMod.Feature.get_label/1","doc":"","ref":"Evision.LineMod.Feature.html#get_label/1"},{"type":"function","title":"Evision.LineMod.Feature.get_x/1","doc":"","ref":"Evision.LineMod.Feature.html#get_x/1"},{"type":"function","title":"Evision.LineMod.Feature.get_y/1","doc":"","ref":"Evision.LineMod.Feature.html#get_y/1"},{"type":"function","title":"Evision.LineMod.Feature.set_label/2","doc":"","ref":"Evision.LineMod.Feature.html#set_label/2"},{"type":"function","title":"Evision.LineMod.Feature.set_x/2","doc":"","ref":"Evision.LineMod.Feature.html#set_x/2"},{"type":"function","title":"Evision.LineMod.Feature.set_y/2","doc":"","ref":"Evision.LineMod.Feature.html#set_y/2"},{"type":"type","title":"Evision.LineMod.Feature.t/0","doc":"Type that represents an `LineMod.Feature` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.LineMod.Feature.html#t:t/0"},{"type":"module","title":"Evision.LineMod.Match","doc":"","ref":"Evision.LineMod.Match.html"},{"type":"function","title":"Evision.LineMod.Match.get_class_id/1","doc":"","ref":"Evision.LineMod.Match.html#get_class_id/1"},{"type":"function","title":"Evision.LineMod.Match.get_similarity/1","doc":"","ref":"Evision.LineMod.Match.html#get_similarity/1"},{"type":"function","title":"Evision.LineMod.Match.get_template_id/1","doc":"","ref":"Evision.LineMod.Match.html#get_template_id/1"},{"type":"function","title":"Evision.LineMod.Match.get_x/1","doc":"","ref":"Evision.LineMod.Match.html#get_x/1"},{"type":"function","title":"Evision.LineMod.Match.get_y/1","doc":"","ref":"Evision.LineMod.Match.html#get_y/1"},{"type":"function","title":"Evision.LineMod.Match.match/0","doc":"Match\n##### Return\n- **self**: `Match`\n\nPython prototype (for reference only):\n```python3\nMatch() ->  \n```","ref":"Evision.LineMod.Match.html#match/0"},{"type":"function","title":"Evision.LineMod.Match.match/1","doc":"","ref":"Evision.LineMod.Match.html#match/1"},{"type":"function","title":"Evision.LineMod.Match.match/5","doc":"Match\n\n##### Positional Arguments\n- **x**: `integer()`\n- **y**: `integer()`\n- **similarity**: `float`\n- **class_id**: `String`\n- **template_id**: `integer()`\n\n##### Return\n- **self**: `Match`\n\nPython prototype (for reference only):\n```python3\nMatch(x, y, similarity, class_id, template_id) ->  \n```","ref":"Evision.LineMod.Match.html#match/5"},{"type":"function","title":"Evision.LineMod.Match.set_class_id/2","doc":"","ref":"Evision.LineMod.Match.html#set_class_id/2"},{"type":"function","title":"Evision.LineMod.Match.set_similarity/2","doc":"","ref":"Evision.LineMod.Match.html#set_similarity/2"},{"type":"function","title":"Evision.LineMod.Match.set_template_id/2","doc":"","ref":"Evision.LineMod.Match.html#set_template_id/2"},{"type":"function","title":"Evision.LineMod.Match.set_x/2","doc":"","ref":"Evision.LineMod.Match.html#set_x/2"},{"type":"function","title":"Evision.LineMod.Match.set_y/2","doc":"","ref":"Evision.LineMod.Match.html#set_y/2"},{"type":"type","title":"Evision.LineMod.Match.t/0","doc":"Type that represents an `LineMod.Match` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.LineMod.Match.html#t:t/0"},{"type":"module","title":"Evision.LineMod.Modality","doc":"","ref":"Evision.LineMod.Modality.html"},{"type":"function","title":"Evision.LineMod.Modality.create/1","doc":"#### Variant 1:\ncreate\n\n##### Positional Arguments\n- **func**: `Evision.FileNode`\n\n##### Return\n- **retval**: `Modality`\n\n \\brief Load a modality from file.\n\nPython prototype (for reference only):\n```python3\ncreate(fn) -> retval\n```\n#### Variant 2:\ncreate\n\n##### Positional Arguments\n- **modality_type**: `String`\n\n##### Return\n- **retval**: `Modality`\n\n \\brief Create modality by name.\n The following modality types are supported:\n- \"ColorGradient\"\n- \"DepthNormal\"\n\nPython prototype (for reference only):\n```python3\ncreate(modality_type) -> retval\n```","ref":"Evision.LineMod.Modality.html#create/1"},{"type":"function","title":"Evision.LineMod.Modality.name/1","doc":"name\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.Modality.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\nname() -> retval\n```","ref":"Evision.LineMod.Modality.html#name/1"},{"type":"function","title":"Evision.LineMod.Modality.process/1","doc":"","ref":"Evision.LineMod.Modality.html#process/1"},{"type":"function","title":"Evision.LineMod.Modality.process/2","doc":"process\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.Modality.t()`\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n##### Return\n- **retval**: `QuantizedPyramid`\n\n \\brief Form a quantized image pyramid from a source image.\n \\param[in] src  The source image. Type depends on the modality.\n \\param[in] mask Optional mask. If not empty, unmasked pixels are set to zero\n                 in quantized image and cannot be extracted as features.\n\nPython prototype (for reference only):\n```python3\nprocess(src[, mask]) -> retval\n```","ref":"Evision.LineMod.Modality.html#process/2"},{"type":"function","title":"Evision.LineMod.Modality.process/3","doc":"process\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.Modality.t()`\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n##### Return\n- **retval**: `QuantizedPyramid`\n\n \\brief Form a quantized image pyramid from a source image.\n \\param[in] src  The source image. Type depends on the modality.\n \\param[in] mask Optional mask. If not empty, unmasked pixels are set to zero\n                 in quantized image and cannot be extracted as features.\n\nPython prototype (for reference only):\n```python3\nprocess(src[, mask]) -> retval\n```","ref":"Evision.LineMod.Modality.html#process/3"},{"type":"function","title":"Evision.LineMod.Modality.read/1","doc":"","ref":"Evision.LineMod.Modality.html#read/1"},{"type":"function","title":"Evision.LineMod.Modality.read/2","doc":"read\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.Modality.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.LineMod.Modality.html#read/2"},{"type":"type","title":"Evision.LineMod.Modality.t/0","doc":"Type that represents an `LineMod.Modality` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.LineMod.Modality.html#t:t/0"},{"type":"module","title":"Evision.LineMod.QuantizedPyramid","doc":"","ref":"Evision.LineMod.QuantizedPyramid.html"},{"type":"function","title":"Evision.LineMod.QuantizedPyramid.extractTemplate/1","doc":"extractTemplate\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.QuantizedPyramid.t()`\n\n##### Return\n- **retval**: `bool`\n- **templ**: `Evision.LineMod.Template.t()`\n\n \\brief Extract most discriminant features at current pyramid level to form a new template.\n \\param[out] templ The new template.\n\nPython prototype (for reference only):\n```python3\nextractTemplate() -> retval, templ\n```","ref":"Evision.LineMod.QuantizedPyramid.html#extractTemplate/1"},{"type":"function","title":"Evision.LineMod.QuantizedPyramid.pyrDown/1","doc":"pyrDown\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.QuantizedPyramid.t()`\n\n \\brief Go to the next pyramid level.\n \\todo Allow pyramid scale factor other than 2\n\nPython prototype (for reference only):\n```python3\npyrDown() -> None\n```","ref":"Evision.LineMod.QuantizedPyramid.html#pyrDown/1"},{"type":"function","title":"Evision.LineMod.QuantizedPyramid.quantize/1","doc":"quantize\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.QuantizedPyramid.t()`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n \\brief Compute quantized image at current pyramid level for online detection.\n \\param[out] dst The destination 8-bit image. For each pixel at most one bit is set,\n                 representing its classification.\n\nPython prototype (for reference only):\n```python3\nquantize([, dst]) -> dst\n```","ref":"Evision.LineMod.QuantizedPyramid.html#quantize/1"},{"type":"function","title":"Evision.LineMod.QuantizedPyramid.quantize/2","doc":"quantize\n\n##### Positional Arguments\n- **self**: `Evision.LineMod.QuantizedPyramid.t()`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n \\brief Compute quantized image at current pyramid level for online detection.\n \\param[out] dst The destination 8-bit image. For each pixel at most one bit is set,\n                 representing its classification.\n\nPython prototype (for reference only):\n```python3\nquantize([, dst]) -> dst\n```","ref":"Evision.LineMod.QuantizedPyramid.html#quantize/2"},{"type":"type","title":"Evision.LineMod.QuantizedPyramid.t/0","doc":"Type that represents an `LineMod.QuantizedPyramid` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.LineMod.QuantizedPyramid.html#t:t/0"},{"type":"module","title":"Evision.LineMod.Template","doc":"","ref":"Evision.LineMod.Template.html"},{"type":"function","title":"Evision.LineMod.Template.get_features/1","doc":"","ref":"Evision.LineMod.Template.html#get_features/1"},{"type":"function","title":"Evision.LineMod.Template.get_height/1","doc":"","ref":"Evision.LineMod.Template.html#get_height/1"},{"type":"function","title":"Evision.LineMod.Template.get_pyramid_level/1","doc":"","ref":"Evision.LineMod.Template.html#get_pyramid_level/1"},{"type":"function","title":"Evision.LineMod.Template.get_width/1","doc":"","ref":"Evision.LineMod.Template.html#get_width/1"},{"type":"type","title":"Evision.LineMod.Template.t/0","doc":"Type that represents an `LineMod.Template` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.LineMod.Template.html#t:t/0"},{"type":"module","title":"Evision.LineSegmentDetector","doc":"","ref":"Evision.LineSegmentDetector.html"},{"type":"function","title":"Evision.LineSegmentDetector.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.LineSegmentDetector.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.LineSegmentDetector.html#clear/1"},{"type":"function","title":"Evision.LineSegmentDetector.compareSegments/1","doc":"","ref":"Evision.LineSegmentDetector.html#compareSegments/1"},{"type":"function","title":"Evision.LineSegmentDetector.compareSegments/4","doc":"Draws two groups of lines in blue and red, counting the non overlapping (mismatching) pixels.\n\n##### Positional Arguments\n- **self**: `Evision.LineSegmentDetector.t()`\n- **size**: `Size`.\n\n  The size of the image, where lines1 and lines2 were found.\n\n- **lines1**: `Evision.Mat`.\n\n  The first group of lines that needs to be drawn. It is visualized in blue color.\n\n- **lines2**: `Evision.Mat`.\n\n  The second group of lines. They visualized in red color.\n\n##### Return\n- **retval**: `integer()`\n- **image**: `Evision.Mat.t()`.\n\n  Optional image, where the lines will be drawn. The image should be color(3-channel)\n  in order for lines1 and lines2 to be drawn in the above mentioned colors.\n\nPython prototype (for reference only):\n```python3\ncompareSegments(size, lines1, lines2[, image]) -> retval, image\n```","ref":"Evision.LineSegmentDetector.html#compareSegments/4"},{"type":"function","title":"Evision.LineSegmentDetector.compareSegments/5","doc":"Draws two groups of lines in blue and red, counting the non overlapping (mismatching) pixels.\n\n##### Positional Arguments\n- **self**: `Evision.LineSegmentDetector.t()`\n- **size**: `Size`.\n\n  The size of the image, where lines1 and lines2 were found.\n\n- **lines1**: `Evision.Mat`.\n\n  The first group of lines that needs to be drawn. It is visualized in blue color.\n\n- **lines2**: `Evision.Mat`.\n\n  The second group of lines. They visualized in red color.\n\n##### Return\n- **retval**: `integer()`\n- **image**: `Evision.Mat.t()`.\n\n  Optional image, where the lines will be drawn. The image should be color(3-channel)\n  in order for lines1 and lines2 to be drawn in the above mentioned colors.\n\nPython prototype (for reference only):\n```python3\ncompareSegments(size, lines1, lines2[, image]) -> retval, image\n```","ref":"Evision.LineSegmentDetector.html#compareSegments/5"},{"type":"function","title":"Evision.LineSegmentDetector.detect/1","doc":"","ref":"Evision.LineSegmentDetector.html#detect/1"},{"type":"function","title":"Evision.LineSegmentDetector.detect/2","doc":"Finds lines in the input image.\n\n##### Positional Arguments\n- **self**: `Evision.LineSegmentDetector.t()`\n- **image**: `Evision.Mat`.\n\n  A grayscale (CV_8UC1) input image. If only a roi needs to be selected, use:\n  `lsd_ptr-\\>detect(image(roi), lines, ...); lines += Scalar(roi.x, roi.y, roi.x, roi.y);`\n\n##### Return\n- **lines**: `Evision.Mat.t()`.\n\n  A vector of Vec4f elements specifying the beginning and ending point of a line. Where\n  Vec4f is (x1, y1, x2, y2), point 1 is the start, point 2 - end. Returned lines are strictly\n  oriented depending on the gradient.\n\n- **width**: `Evision.Mat.t()`.\n\n  Vector of widths of the regions, where the lines are found. E.g. Width of line.\n\n- **prec**: `Evision.Mat.t()`.\n\n  Vector of precisions with which the lines are found.\n\n- **nfa**: `Evision.Mat.t()`.\n\n  Vector containing number of false alarms in the line region, with precision of 10%. The\n  bigger the value, logarithmically better the detection.\n  - -1 corresponds to 10 mean false alarms\n  - 0 corresponds to 1 mean false alarm\n  - 1 corresponds to 0.1 mean false alarms\n    This vector will be calculated only when the objects type is #LSD_REFINE_ADV.\n\nThis is the output of the default parameters of the algorithm on the above shown image.\n![image](pics/building_lsd.png)\n\nPython prototype (for reference only):\n```python3\ndetect(image[, lines[, width[, prec[, nfa]]]]) -> lines, width, prec, nfa\n```","ref":"Evision.LineSegmentDetector.html#detect/2"},{"type":"function","title":"Evision.LineSegmentDetector.detect/3","doc":"Finds lines in the input image.\n\n##### Positional Arguments\n- **self**: `Evision.LineSegmentDetector.t()`\n- **image**: `Evision.Mat`.\n\n  A grayscale (CV_8UC1) input image. If only a roi needs to be selected, use:\n  `lsd_ptr-\\>detect(image(roi), lines, ...); lines += Scalar(roi.x, roi.y, roi.x, roi.y);`\n\n##### Return\n- **lines**: `Evision.Mat.t()`.\n\n  A vector of Vec4f elements specifying the beginning and ending point of a line. Where\n  Vec4f is (x1, y1, x2, y2), point 1 is the start, point 2 - end. Returned lines are strictly\n  oriented depending on the gradient.\n\n- **width**: `Evision.Mat.t()`.\n\n  Vector of widths of the regions, where the lines are found. E.g. Width of line.\n\n- **prec**: `Evision.Mat.t()`.\n\n  Vector of precisions with which the lines are found.\n\n- **nfa**: `Evision.Mat.t()`.\n\n  Vector containing number of false alarms in the line region, with precision of 10%. The\n  bigger the value, logarithmically better the detection.\n  - -1 corresponds to 10 mean false alarms\n  - 0 corresponds to 1 mean false alarm\n  - 1 corresponds to 0.1 mean false alarms\n    This vector will be calculated only when the objects type is #LSD_REFINE_ADV.\n\nThis is the output of the default parameters of the algorithm on the above shown image.\n![image](pics/building_lsd.png)\n\nPython prototype (for reference only):\n```python3\ndetect(image[, lines[, width[, prec[, nfa]]]]) -> lines, width, prec, nfa\n```","ref":"Evision.LineSegmentDetector.html#detect/3"},{"type":"function","title":"Evision.LineSegmentDetector.drawSegments/1","doc":"","ref":"Evision.LineSegmentDetector.html#drawSegments/1"},{"type":"function","title":"Evision.LineSegmentDetector.drawSegments/3","doc":"Draws the line segments on a given image.\n\n##### Positional Arguments\n- **self**: `Evision.LineSegmentDetector.t()`\n- **lines**: `Evision.Mat`.\n\n  A vector of the lines that needed to be drawn.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  The image, where the lines will be drawn. Should be bigger or equal to the image,\n  where the lines were found.\n\nPython prototype (for reference only):\n```python3\ndrawSegments(image, lines) -> image\n```","ref":"Evision.LineSegmentDetector.html#drawSegments/3"},{"type":"function","title":"Evision.LineSegmentDetector.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.LineSegmentDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.LineSegmentDetector.html#empty/1"},{"type":"function","title":"Evision.LineSegmentDetector.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.LineSegmentDetector.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.LineSegmentDetector.html#getDefaultName/1"},{"type":"function","title":"Evision.LineSegmentDetector.read/1","doc":"","ref":"Evision.LineSegmentDetector.html#read/1"},{"type":"function","title":"Evision.LineSegmentDetector.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.LineSegmentDetector.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.LineSegmentDetector.html#read/2"},{"type":"function","title":"Evision.LineSegmentDetector.save/1","doc":"","ref":"Evision.LineSegmentDetector.html#save/1"},{"type":"function","title":"Evision.LineSegmentDetector.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.LineSegmentDetector.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.LineSegmentDetector.html#save/2"},{"type":"function","title":"Evision.LineSegmentDetector.write/1","doc":"","ref":"Evision.LineSegmentDetector.html#write/1"},{"type":"function","title":"Evision.LineSegmentDetector.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.LineSegmentDetector.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.LineSegmentDetector.html#write/2"},{"type":"function","title":"Evision.LineSegmentDetector.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.LineSegmentDetector.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.LineSegmentDetector.html#write/3"},{"type":"type","title":"Evision.LineSegmentDetector.t/0","doc":"Type that represents an `LineSegmentDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.LineSegmentDetector.html#t:t/0"},{"type":"module","title":"Evision.LineSegmentDetectorModes","doc":"","ref":"Evision.LineSegmentDetectorModes.html"},{"type":"function","title":"Evision.LineSegmentDetectorModes.cv_LSD_REFINE_ADV/0","doc":"","ref":"Evision.LineSegmentDetectorModes.html#cv_LSD_REFINE_ADV/0"},{"type":"function","title":"Evision.LineSegmentDetectorModes.cv_LSD_REFINE_NONE/0","doc":"","ref":"Evision.LineSegmentDetectorModes.html#cv_LSD_REFINE_NONE/0"},{"type":"function","title":"Evision.LineSegmentDetectorModes.cv_LSD_REFINE_STD/0","doc":"","ref":"Evision.LineSegmentDetectorModes.html#cv_LSD_REFINE_STD/0"},{"type":"type","title":"Evision.LineSegmentDetectorModes.enum/0","doc":"","ref":"Evision.LineSegmentDetectorModes.html#t:enum/0"},{"type":"module","title":"Evision.LineTypes","doc":"","ref":"Evision.LineTypes.html"},{"type":"function","title":"Evision.LineTypes.cv_FILLED/0","doc":"","ref":"Evision.LineTypes.html#cv_FILLED/0"},{"type":"function","title":"Evision.LineTypes.cv_LINE_4/0","doc":"","ref":"Evision.LineTypes.html#cv_LINE_4/0"},{"type":"function","title":"Evision.LineTypes.cv_LINE_8/0","doc":"","ref":"Evision.LineTypes.html#cv_LINE_8/0"},{"type":"function","title":"Evision.LineTypes.cv_LINE_AA/0","doc":"","ref":"Evision.LineTypes.html#cv_LINE_AA/0"},{"type":"type","title":"Evision.LineTypes.enum/0","doc":"","ref":"Evision.LineTypes.html#t:enum/0"},{"type":"module","title":"Evision.LocalOptimMethod","doc":"","ref":"Evision.LocalOptimMethod.html"},{"type":"function","title":"Evision.LocalOptimMethod.cv_LOCAL_OPTIM_GC/0","doc":"","ref":"Evision.LocalOptimMethod.html#cv_LOCAL_OPTIM_GC/0"},{"type":"function","title":"Evision.LocalOptimMethod.cv_LOCAL_OPTIM_INNER_AND_ITER_LO/0","doc":"","ref":"Evision.LocalOptimMethod.html#cv_LOCAL_OPTIM_INNER_AND_ITER_LO/0"},{"type":"function","title":"Evision.LocalOptimMethod.cv_LOCAL_OPTIM_INNER_LO/0","doc":"","ref":"Evision.LocalOptimMethod.html#cv_LOCAL_OPTIM_INNER_LO/0"},{"type":"function","title":"Evision.LocalOptimMethod.cv_LOCAL_OPTIM_NULL/0","doc":"","ref":"Evision.LocalOptimMethod.html#cv_LOCAL_OPTIM_NULL/0"},{"type":"function","title":"Evision.LocalOptimMethod.cv_LOCAL_OPTIM_SIGMA/0","doc":"","ref":"Evision.LocalOptimMethod.html#cv_LOCAL_OPTIM_SIGMA/0"},{"type":"type","title":"Evision.LocalOptimMethod.enum/0","doc":"","ref":"Evision.LocalOptimMethod.html#t:enum/0"},{"type":"module","title":"Evision.MCC","doc":"","ref":"Evision.MCC.html"},{"type":"type","title":"Evision.MCC.t/0","doc":"Type that represents an `MCC` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.MCC.html#t:t/0"},{"type":"module","title":"Evision.MCC.CChecker","doc":"","ref":"Evision.MCC.CChecker.html"},{"type":"function","title":"Evision.MCC.CChecker.create/0","doc":"create\n##### Return\n- **retval**: `CChecker`\n\n\\brief Create a new CChecker object.\n \\return A pointer to the implementation of the CChecker\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.MCC.CChecker.html#create/0"},{"type":"function","title":"Evision.MCC.CChecker.create/1","doc":"","ref":"Evision.MCC.CChecker.html#create/1"},{"type":"function","title":"Evision.MCC.CChecker.getBox/1","doc":"getBox\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CChecker.t()`\n\n##### Return\n- **retval**: `[Point2f]`\n\nPython prototype (for reference only):\n```python3\ngetBox() -> retval\n```","ref":"Evision.MCC.CChecker.html#getBox/1"},{"type":"function","title":"Evision.MCC.CChecker.getCenter/1","doc":"getCenter\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CChecker.t()`\n\n##### Return\n- **retval**: `Point2f`\n\nPython prototype (for reference only):\n```python3\ngetCenter() -> retval\n```","ref":"Evision.MCC.CChecker.html#getCenter/1"},{"type":"function","title":"Evision.MCC.CChecker.getChartsRGB/1","doc":"getChartsRGB\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CChecker.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetChartsRGB() -> retval\n```","ref":"Evision.MCC.CChecker.html#getChartsRGB/1"},{"type":"function","title":"Evision.MCC.CChecker.getChartsYCbCr/1","doc":"getChartsYCbCr\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CChecker.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetChartsYCbCr() -> retval\n```","ref":"Evision.MCC.CChecker.html#getChartsYCbCr/1"},{"type":"function","title":"Evision.MCC.CChecker.getColorCharts/1","doc":"Computes and returns the coordinates of the central parts of the charts modules.\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CChecker.t()`\n\n##### Return\n- **retval**: `[Point2f]`\n\n This method computes transformation matrix from the checkers's coordinates (`cv::mcc::CChecker::getBox()`)\n and find by this the coordinates of the central parts of the charts modules.\n It is used in `cv::mcc::CCheckerDraw::draw()` and in `ChartsRGB` calculation.\n\nPython prototype (for reference only):\n```python3\ngetColorCharts() -> retval\n```","ref":"Evision.MCC.CChecker.html#getColorCharts/1"},{"type":"function","title":"Evision.MCC.CChecker.getCost/1","doc":"getCost\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CChecker.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetCost() -> retval\n```","ref":"Evision.MCC.CChecker.html#getCost/1"},{"type":"function","title":"Evision.MCC.CChecker.getTarget/1","doc":"getTarget\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CChecker.t()`\n\n##### Return\n- **retval**: `TYPECHART`\n\nPython prototype (for reference only):\n```python3\ngetTarget() -> retval\n```","ref":"Evision.MCC.CChecker.html#getTarget/1"},{"type":"function","title":"Evision.MCC.CChecker.setBox/1","doc":"","ref":"Evision.MCC.CChecker.html#setBox/1"},{"type":"function","title":"Evision.MCC.CChecker.setBox/2","doc":"setBox\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CChecker.t()`\n- **box**: `[Point2f]`\n\nPython prototype (for reference only):\n```python3\nsetBox(_box) -> None\n```","ref":"Evision.MCC.CChecker.html#setBox/2"},{"type":"function","title":"Evision.MCC.CChecker.setCenter/1","doc":"","ref":"Evision.MCC.CChecker.html#setCenter/1"},{"type":"function","title":"Evision.MCC.CChecker.setCenter/2","doc":"setCenter\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CChecker.t()`\n- **center**: `Point2f`\n\nPython prototype (for reference only):\n```python3\nsetCenter(_center) -> None\n```","ref":"Evision.MCC.CChecker.html#setCenter/2"},{"type":"function","title":"Evision.MCC.CChecker.setChartsRGB/1","doc":"","ref":"Evision.MCC.CChecker.html#setChartsRGB/1"},{"type":"function","title":"Evision.MCC.CChecker.setChartsRGB/2","doc":"setChartsRGB\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CChecker.t()`\n- **chartsRGB**: `Evision.Mat`\n\nPython prototype (for reference only):\n```python3\nsetChartsRGB(_chartsRGB) -> None\n```","ref":"Evision.MCC.CChecker.html#setChartsRGB/2"},{"type":"function","title":"Evision.MCC.CChecker.setChartsYCbCr/1","doc":"","ref":"Evision.MCC.CChecker.html#setChartsYCbCr/1"},{"type":"function","title":"Evision.MCC.CChecker.setChartsYCbCr/2","doc":"setChartsYCbCr\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CChecker.t()`\n- **chartsYCbCr**: `Evision.Mat`\n\nPython prototype (for reference only):\n```python3\nsetChartsYCbCr(_chartsYCbCr) -> None\n```","ref":"Evision.MCC.CChecker.html#setChartsYCbCr/2"},{"type":"function","title":"Evision.MCC.CChecker.setCost/1","doc":"","ref":"Evision.MCC.CChecker.html#setCost/1"},{"type":"function","title":"Evision.MCC.CChecker.setCost/2","doc":"setCost\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CChecker.t()`\n- **cost**: `float`\n\nPython prototype (for reference only):\n```python3\nsetCost(_cost) -> None\n```","ref":"Evision.MCC.CChecker.html#setCost/2"},{"type":"function","title":"Evision.MCC.CChecker.setTarget/1","doc":"","ref":"Evision.MCC.CChecker.html#setTarget/1"},{"type":"function","title":"Evision.MCC.CChecker.setTarget/2","doc":"setTarget\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CChecker.t()`\n- **target**: `TYPECHART`\n\nPython prototype (for reference only):\n```python3\nsetTarget(_target) -> None\n```","ref":"Evision.MCC.CChecker.html#setTarget/2"},{"type":"type","title":"Evision.MCC.CChecker.t/0","doc":"Type that represents an `MCC.CChecker` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.MCC.CChecker.html#t:t/0"},{"type":"module","title":"Evision.MCC.CCheckerDetector","doc":"","ref":"Evision.MCC.CCheckerDetector.html"},{"type":"function","title":"Evision.MCC.CCheckerDetector.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CCheckerDetector.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.MCC.CCheckerDetector.html#clear/1"},{"type":"function","title":"Evision.MCC.CCheckerDetector.create/0","doc":"create\n##### Return\n- **retval**: `CCheckerDetector`\n\n\\brief Returns the implementation of the CCheckerDetector.\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.MCC.CCheckerDetector.html#create/0"},{"type":"function","title":"Evision.MCC.CCheckerDetector.create/1","doc":"","ref":"Evision.MCC.CCheckerDetector.html#create/1"},{"type":"function","title":"Evision.MCC.CCheckerDetector.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CCheckerDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.MCC.CCheckerDetector.html#empty/1"},{"type":"function","title":"Evision.MCC.CCheckerDetector.getBestColorChecker/1","doc":"getBestColorChecker\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CCheckerDetector.t()`\n\n##### Return\n- **retval**: `Evision.MCC.CCheckerDetector.t()`\n\n\\brief Get the best color checker. By the best it means the one\n         detected with the highest confidence.\n \\return checker A single colorchecker, if atleast one colorchecker\n                 was detected, 'nullptr' otherwise.\n\nPython prototype (for reference only):\n```python3\ngetBestColorChecker() -> retval\n```","ref":"Evision.MCC.CCheckerDetector.html#getBestColorChecker/1"},{"type":"function","title":"Evision.MCC.CCheckerDetector.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CCheckerDetector.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.MCC.CCheckerDetector.html#getDefaultName/1"},{"type":"function","title":"Evision.MCC.CCheckerDetector.getListColorChecker/1","doc":"getListColorChecker\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CCheckerDetector.t()`\n\n##### Return\n- **retval**: `[CChecker]`\n\n\\brief Get the list of all detected colorcheckers\n \\return checkers vector of colorcheckers\n\nPython prototype (for reference only):\n```python3\ngetListColorChecker() -> retval\n```","ref":"Evision.MCC.CCheckerDetector.html#getListColorChecker/1"},{"type":"function","title":"Evision.MCC.CCheckerDetector.process/1","doc":"","ref":"Evision.MCC.CCheckerDetector.html#process/1"},{"type":"function","title":"Evision.MCC.CCheckerDetector.process/3","doc":"process\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CCheckerDetector.t()`\n- **image**: `Evision.Mat`\n- **chartType**: `TYPECHART`\n\n##### Keyword Arguments\n- **nc**: `integer()`.\n- **useNet**: `bool`.\n- **params**: `DetectorParameters`.\n\n##### Return\n- **retval**: `bool`\n\n\\brief Find the ColorCharts in the given image.\n Differs from the above one only in the arguments.\n This version searches for the chart in the full image.\n The found charts are not returned but instead stored in the\n detector, these can be accessed later on using getBestColorChecker()\n and getListColorChecker()\n \\param image image in color space BGR\n \\param chartType type of the chart to detect\n \\param nc number of charts in the image, if you don't know the exact\n           then keeping this number high helps.\n \\param useNet if it is true the network provided using the setNet()\n               is used for preliminary search for regions where chart\n               could be present, inside the regionsOfInterest provied.\n \\param params parameters of the detection system. More information\n               about them can be found in the struct DetectorParameters.\n \\return true if atleast one chart is detected otherwise false\n\nPython prototype (for reference only):\n```python3\nprocess(image, chartType[, nc[, useNet[, params]]]) -> retval\n```","ref":"Evision.MCC.CCheckerDetector.html#process/3"},{"type":"function","title":"Evision.MCC.CCheckerDetector.process/4","doc":"process\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CCheckerDetector.t()`\n- **image**: `Evision.Mat`\n- **chartType**: `TYPECHART`\n\n##### Keyword Arguments\n- **nc**: `integer()`.\n- **useNet**: `bool`.\n- **params**: `DetectorParameters`.\n\n##### Return\n- **retval**: `bool`\n\n\\brief Find the ColorCharts in the given image.\n Differs from the above one only in the arguments.\n This version searches for the chart in the full image.\n The found charts are not returned but instead stored in the\n detector, these can be accessed later on using getBestColorChecker()\n and getListColorChecker()\n \\param image image in color space BGR\n \\param chartType type of the chart to detect\n \\param nc number of charts in the image, if you don't know the exact\n           then keeping this number high helps.\n \\param useNet if it is true the network provided using the setNet()\n               is used for preliminary search for regions where chart\n               could be present, inside the regionsOfInterest provied.\n \\param params parameters of the detection system. More information\n               about them can be found in the struct DetectorParameters.\n \\return true if atleast one chart is detected otherwise false\n\nPython prototype (for reference only):\n```python3\nprocess(image, chartType[, nc[, useNet[, params]]]) -> retval\n```","ref":"Evision.MCC.CCheckerDetector.html#process/4"},{"type":"function","title":"Evision.MCC.CCheckerDetector.processWithROI/1","doc":"","ref":"Evision.MCC.CCheckerDetector.html#processWithROI/1"},{"type":"function","title":"Evision.MCC.CCheckerDetector.processWithROI/4","doc":"processWithROI\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CCheckerDetector.t()`\n- **image**: `Evision.Mat`\n- **chartType**: `TYPECHART`\n- **regionsOfInterest**: `[Rect]`\n\n##### Keyword Arguments\n- **nc**: `integer()`.\n- **useNet**: `bool`.\n- **params**: `DetectorParameters`.\n\n##### Return\n- **retval**: `bool`\n\n\\brief Find the ColorCharts in the given image.\n The found charts are not returned but instead stored in the\n detector, these can be accessed later on using getBestColorChecker()\n and getListColorChecker()\n \\param image image in color space BGR\n \\param chartType type of the chart to detect\n \\param regionsOfInterest regions of image to look for the chart, if\n                          it is empty, charts are looked for in the\n                          entire image\n \\param nc number of charts in the image, if you don't know the exact\n           then keeping this number high helps.\n \\param useNet if it is true the network provided using the setNet()\n               is used for preliminary search for regions where chart\n               could be present, inside the regionsOfInterest provied.\n \\param params parameters of the detection system. More information\n               about them can be found in the struct DetectorParameters.\n \\return true if atleast one chart is detected otherwise false\n\nPython prototype (for reference only):\n```python3\nprocessWithROI(image, chartType, regionsOfInterest[, nc[, useNet[, params]]]) -> retval\n```","ref":"Evision.MCC.CCheckerDetector.html#processWithROI/4"},{"type":"function","title":"Evision.MCC.CCheckerDetector.processWithROI/5","doc":"processWithROI\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CCheckerDetector.t()`\n- **image**: `Evision.Mat`\n- **chartType**: `TYPECHART`\n- **regionsOfInterest**: `[Rect]`\n\n##### Keyword Arguments\n- **nc**: `integer()`.\n- **useNet**: `bool`.\n- **params**: `DetectorParameters`.\n\n##### Return\n- **retval**: `bool`\n\n\\brief Find the ColorCharts in the given image.\n The found charts are not returned but instead stored in the\n detector, these can be accessed later on using getBestColorChecker()\n and getListColorChecker()\n \\param image image in color space BGR\n \\param chartType type of the chart to detect\n \\param regionsOfInterest regions of image to look for the chart, if\n                          it is empty, charts are looked for in the\n                          entire image\n \\param nc number of charts in the image, if you don't know the exact\n           then keeping this number high helps.\n \\param useNet if it is true the network provided using the setNet()\n               is used for preliminary search for regions where chart\n               could be present, inside the regionsOfInterest provied.\n \\param params parameters of the detection system. More information\n               about them can be found in the struct DetectorParameters.\n \\return true if atleast one chart is detected otherwise false\n\nPython prototype (for reference only):\n```python3\nprocessWithROI(image, chartType, regionsOfInterest[, nc[, useNet[, params]]]) -> retval\n```","ref":"Evision.MCC.CCheckerDetector.html#processWithROI/5"},{"type":"function","title":"Evision.MCC.CCheckerDetector.read/1","doc":"","ref":"Evision.MCC.CCheckerDetector.html#read/1"},{"type":"function","title":"Evision.MCC.CCheckerDetector.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CCheckerDetector.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.MCC.CCheckerDetector.html#read/2"},{"type":"function","title":"Evision.MCC.CCheckerDetector.save/1","doc":"","ref":"Evision.MCC.CCheckerDetector.html#save/1"},{"type":"function","title":"Evision.MCC.CCheckerDetector.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CCheckerDetector.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.MCC.CCheckerDetector.html#save/2"},{"type":"function","title":"Evision.MCC.CCheckerDetector.setNet/1","doc":"","ref":"Evision.MCC.CCheckerDetector.html#setNet/1"},{"type":"function","title":"Evision.MCC.CCheckerDetector.setNet/2","doc":"setNet\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CCheckerDetector.t()`\n- **net**: `Evision.DNN.Net.t()`\n\n##### Return\n- **retval**: `bool`\n\n\\brief Set the net which will be used to find the approximate\n         bounding boxes for the color charts.\n It is not necessary to use this, but this usually results in\n better detection rate.\n \\param net the neural network, if the network in empty, then\n            the function will return false.\n \\return true if it was able to set the detector's network,\n         false otherwise.\n\nPython prototype (for reference only):\n```python3\nsetNet(net) -> retval\n```","ref":"Evision.MCC.CCheckerDetector.html#setNet/2"},{"type":"function","title":"Evision.MCC.CCheckerDetector.write/1","doc":"","ref":"Evision.MCC.CCheckerDetector.html#write/1"},{"type":"function","title":"Evision.MCC.CCheckerDetector.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CCheckerDetector.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.MCC.CCheckerDetector.html#write/2"},{"type":"function","title":"Evision.MCC.CCheckerDetector.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CCheckerDetector.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.MCC.CCheckerDetector.html#write/3"},{"type":"type","title":"Evision.MCC.CCheckerDetector.t/0","doc":"Type that represents an `MCC.CCheckerDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.MCC.CCheckerDetector.html#t:t/0"},{"type":"module","title":"Evision.MCC.CCheckerDraw","doc":"","ref":"Evision.MCC.CCheckerDraw.html"},{"type":"function","title":"Evision.MCC.CCheckerDraw.create/1","doc":"create\n\n##### Positional Arguments\n- **pChecker**: `CChecker`\n\n##### Keyword Arguments\n- **color**: `Evision.scalar()`.\n- **thickness**: `integer()`.\n\n##### Return\n- **retval**: `CCheckerDraw`\n\n\\brief Create a new CCheckerDraw object.\n \\param pChecker The checker which will be drawn by this object.\n \\param color The color by with which the squares of the checker\n              will be drawn\n \\param thickness The thickness with which the sqaures will be\n                  drawn\n \\return A pointer to the implementation of the CCheckerDraw\n\nPython prototype (for reference only):\n```python3\ncreate(pChecker[, color[, thickness]]) -> retval\n```","ref":"Evision.MCC.CCheckerDraw.html#create/1"},{"type":"function","title":"Evision.MCC.CCheckerDraw.create/2","doc":"create\n\n##### Positional Arguments\n- **pChecker**: `CChecker`\n\n##### Keyword Arguments\n- **color**: `Evision.scalar()`.\n- **thickness**: `integer()`.\n\n##### Return\n- **retval**: `CCheckerDraw`\n\n\\brief Create a new CCheckerDraw object.\n \\param pChecker The checker which will be drawn by this object.\n \\param color The color by with which the squares of the checker\n              will be drawn\n \\param thickness The thickness with which the sqaures will be\n                  drawn\n \\return A pointer to the implementation of the CCheckerDraw\n\nPython prototype (for reference only):\n```python3\ncreate(pChecker[, color[, thickness]]) -> retval\n```","ref":"Evision.MCC.CCheckerDraw.html#create/2"},{"type":"function","title":"Evision.MCC.CCheckerDraw.draw/1","doc":"","ref":"Evision.MCC.CCheckerDraw.html#draw/1"},{"type":"function","title":"Evision.MCC.CCheckerDraw.draw/2","doc":"draw\n\n##### Positional Arguments\n- **self**: `Evision.MCC.CCheckerDraw.t()`\n\n##### Return\n- **img**: `Evision.Mat.t()`\n\n\\brief Draws the checker to the given image.\n \\param img image in color space BGR\n\nPython prototype (for reference only):\n```python3\ndraw(img) -> img\n```","ref":"Evision.MCC.CCheckerDraw.html#draw/2"},{"type":"type","title":"Evision.MCC.CCheckerDraw.t/0","doc":"Type that represents an `MCC.CCheckerDraw` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.MCC.CCheckerDraw.html#t:t/0"},{"type":"module","title":"Evision.MCC.DetectorParameters","doc":"","ref":"Evision.MCC.DetectorParameters.html"},{"type":"function","title":"Evision.MCC.DetectorParameters.create/0","doc":"create\n##### Return\n- **retval**: `DetectorParameters`\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.MCC.DetectorParameters.html#create/0"},{"type":"function","title":"Evision.MCC.DetectorParameters.create/1","doc":"","ref":"Evision.MCC.DetectorParameters.html#create/1"},{"type":"function","title":"Evision.MCC.DetectorParameters.get_adaptiveThreshConstant/1","doc":"","ref":"Evision.MCC.DetectorParameters.html#get_adaptiveThreshConstant/1"},{"type":"function","title":"Evision.MCC.DetectorParameters.get_adaptiveThreshWinSizeMax/1","doc":"","ref":"Evision.MCC.DetectorParameters.html#get_adaptiveThreshWinSizeMax/1"},{"type":"function","title":"Evision.MCC.DetectorParameters.get_adaptiveThreshWinSizeMin/1","doc":"","ref":"Evision.MCC.DetectorParameters.html#get_adaptiveThreshWinSizeMin/1"},{"type":"function","title":"Evision.MCC.DetectorParameters.get_adaptiveThreshWinSizeStep/1","doc":"","ref":"Evision.MCC.DetectorParameters.html#get_adaptiveThreshWinSizeStep/1"},{"type":"function","title":"Evision.MCC.DetectorParameters.get_B0factor/1","doc":"","ref":"Evision.MCC.DetectorParameters.html#get_B0factor/1"},{"type":"function","title":"Evision.MCC.DetectorParameters.get_borderWidth/1","doc":"","ref":"Evision.MCC.DetectorParameters.html#get_borderWidth/1"},{"type":"function","title":"Evision.MCC.DetectorParameters.get_confidenceThreshold/1","doc":"","ref":"Evision.MCC.DetectorParameters.html#get_confidenceThreshold/1"},{"type":"function","title":"Evision.MCC.DetectorParameters.get_findCandidatesApproxPolyDPEpsMultiplier/1","doc":"","ref":"Evision.MCC.DetectorParameters.html#get_findCandidatesApproxPolyDPEpsMultiplier/1"},{"type":"function","title":"Evision.MCC.DetectorParameters.get_maxError/1","doc":"","ref":"Evision.MCC.DetectorParameters.html#get_maxError/1"},{"type":"function","title":"Evision.MCC.DetectorParameters.get_minContourLengthAllowed/1","doc":"","ref":"Evision.MCC.DetectorParameters.html#get_minContourLengthAllowed/1"},{"type":"function","title":"Evision.MCC.DetectorParameters.get_minContourPointsAllowed/1","doc":"","ref":"Evision.MCC.DetectorParameters.html#get_minContourPointsAllowed/1"},{"type":"function","title":"Evision.MCC.DetectorParameters.get_minContourSolidity/1","doc":"","ref":"Evision.MCC.DetectorParameters.html#get_minContourSolidity/1"},{"type":"function","title":"Evision.MCC.DetectorParameters.get_minContoursArea/1","doc":"","ref":"Evision.MCC.DetectorParameters.html#get_minContoursArea/1"},{"type":"function","title":"Evision.MCC.DetectorParameters.get_minContoursAreaRate/1","doc":"","ref":"Evision.MCC.DetectorParameters.html#get_minContoursAreaRate/1"},{"type":"function","title":"Evision.MCC.DetectorParameters.get_minGroupSize/1","doc":"","ref":"Evision.MCC.DetectorParameters.html#get_minGroupSize/1"},{"type":"function","title":"Evision.MCC.DetectorParameters.get_minImageSize/1","doc":"","ref":"Evision.MCC.DetectorParameters.html#get_minImageSize/1"},{"type":"function","title":"Evision.MCC.DetectorParameters.get_minInterCheckerDistance/1","doc":"","ref":"Evision.MCC.DetectorParameters.html#get_minInterCheckerDistance/1"},{"type":"function","title":"Evision.MCC.DetectorParameters.get_minInterContourDistance/1","doc":"","ref":"Evision.MCC.DetectorParameters.html#get_minInterContourDistance/1"},{"type":"function","title":"Evision.MCC.DetectorParameters.set_adaptiveThreshConstant/2","doc":"","ref":"Evision.MCC.DetectorParameters.html#set_adaptiveThreshConstant/2"},{"type":"function","title":"Evision.MCC.DetectorParameters.set_adaptiveThreshWinSizeMax/2","doc":"","ref":"Evision.MCC.DetectorParameters.html#set_adaptiveThreshWinSizeMax/2"},{"type":"function","title":"Evision.MCC.DetectorParameters.set_adaptiveThreshWinSizeMin/2","doc":"","ref":"Evision.MCC.DetectorParameters.html#set_adaptiveThreshWinSizeMin/2"},{"type":"function","title":"Evision.MCC.DetectorParameters.set_adaptiveThreshWinSizeStep/2","doc":"","ref":"Evision.MCC.DetectorParameters.html#set_adaptiveThreshWinSizeStep/2"},{"type":"function","title":"Evision.MCC.DetectorParameters.set_B0factor/2","doc":"","ref":"Evision.MCC.DetectorParameters.html#set_B0factor/2"},{"type":"function","title":"Evision.MCC.DetectorParameters.set_borderWidth/2","doc":"","ref":"Evision.MCC.DetectorParameters.html#set_borderWidth/2"},{"type":"function","title":"Evision.MCC.DetectorParameters.set_confidenceThreshold/2","doc":"","ref":"Evision.MCC.DetectorParameters.html#set_confidenceThreshold/2"},{"type":"function","title":"Evision.MCC.DetectorParameters.set_findCandidatesApproxPolyDPEpsMultiplier/2","doc":"","ref":"Evision.MCC.DetectorParameters.html#set_findCandidatesApproxPolyDPEpsMultiplier/2"},{"type":"function","title":"Evision.MCC.DetectorParameters.set_maxError/2","doc":"","ref":"Evision.MCC.DetectorParameters.html#set_maxError/2"},{"type":"function","title":"Evision.MCC.DetectorParameters.set_minContourLengthAllowed/2","doc":"","ref":"Evision.MCC.DetectorParameters.html#set_minContourLengthAllowed/2"},{"type":"function","title":"Evision.MCC.DetectorParameters.set_minContourPointsAllowed/2","doc":"","ref":"Evision.MCC.DetectorParameters.html#set_minContourPointsAllowed/2"},{"type":"function","title":"Evision.MCC.DetectorParameters.set_minContourSolidity/2","doc":"","ref":"Evision.MCC.DetectorParameters.html#set_minContourSolidity/2"},{"type":"function","title":"Evision.MCC.DetectorParameters.set_minContoursArea/2","doc":"","ref":"Evision.MCC.DetectorParameters.html#set_minContoursArea/2"},{"type":"function","title":"Evision.MCC.DetectorParameters.set_minContoursAreaRate/2","doc":"","ref":"Evision.MCC.DetectorParameters.html#set_minContoursAreaRate/2"},{"type":"function","title":"Evision.MCC.DetectorParameters.set_minGroupSize/2","doc":"","ref":"Evision.MCC.DetectorParameters.html#set_minGroupSize/2"},{"type":"function","title":"Evision.MCC.DetectorParameters.set_minImageSize/2","doc":"","ref":"Evision.MCC.DetectorParameters.html#set_minImageSize/2"},{"type":"function","title":"Evision.MCC.DetectorParameters.set_minInterCheckerDistance/2","doc":"","ref":"Evision.MCC.DetectorParameters.html#set_minInterCheckerDistance/2"},{"type":"function","title":"Evision.MCC.DetectorParameters.set_minInterContourDistance/2","doc":"","ref":"Evision.MCC.DetectorParameters.html#set_minInterContourDistance/2"},{"type":"type","title":"Evision.MCC.DetectorParameters.t/0","doc":"Type that represents an `MCC.DetectorParameters` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.MCC.DetectorParameters.html#t:t/0"},{"type":"module","title":"Evision.MCC.TYPECHART","doc":"","ref":"Evision.MCC.TYPECHART.html"},{"type":"function","title":"Evision.MCC.TYPECHART.cv_MCC24/0","doc":"","ref":"Evision.MCC.TYPECHART.html#cv_MCC24/0"},{"type":"function","title":"Evision.MCC.TYPECHART.cv_SG140/0","doc":"","ref":"Evision.MCC.TYPECHART.html#cv_SG140/0"},{"type":"function","title":"Evision.MCC.TYPECHART.cv_VINYL18/0","doc":"","ref":"Evision.MCC.TYPECHART.html#cv_VINYL18/0"},{"type":"type","title":"Evision.MCC.TYPECHART.enum/0","doc":"","ref":"Evision.MCC.TYPECHART.html#t:enum/0"},{"type":"module","title":"Evision.ML","doc":"","ref":"Evision.ML.html"},{"type":"type","title":"Evision.ML.t/0","doc":"Type that represents an `ML` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ML.html#t:t/0"},{"type":"module","title":"Evision.ML.ANNMLP","doc":"","ref":"Evision.ML.ANNMLP.html"},{"type":"function","title":"Evision.ML.ANNMLP.calcError/1","doc":"","ref":"Evision.ML.ANNMLP.html#calcError/1"},{"type":"function","title":"Evision.ML.ANNMLP.calcError/3","doc":"Computes error on the training or test dataset\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **data**: `Evision.ML.TrainData.t()`.\n\n  the training data\n\n- **test**: `bool`.\n\n  if true, the error is computed over the test subset of the data, otherwise it's\n  computed over the training subset of the data. Please note that if you loaded a completely\n  different dataset to evaluate already trained classifier, you will probably want not to set\n  the test subset at all with TrainData::setTrainTestSplitRatio and specify test=false, so\n  that the error is computed for the whole new set. Yes, this sounds a bit confusing.\n\n##### Return\n- **retval**: `float`\n- **resp**: `Evision.Mat.t()`.\n\n  the optional output responses.\n\nThe method uses StatModel::predict to compute the error. For regression models the error is\ncomputed as RMS, for classifiers - as a percent of missclassified samples (0%-100%).\n\nPython prototype (for reference only):\n```python3\ncalcError(data, test[, resp]) -> retval, resp\n```","ref":"Evision.ML.ANNMLP.html#calcError/3"},{"type":"function","title":"Evision.ML.ANNMLP.calcError/4","doc":"Computes error on the training or test dataset\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **data**: `Evision.ML.TrainData.t()`.\n\n  the training data\n\n- **test**: `bool`.\n\n  if true, the error is computed over the test subset of the data, otherwise it's\n  computed over the training subset of the data. Please note that if you loaded a completely\n  different dataset to evaluate already trained classifier, you will probably want not to set\n  the test subset at all with TrainData::setTrainTestSplitRatio and specify test=false, so\n  that the error is computed for the whole new set. Yes, this sounds a bit confusing.\n\n##### Return\n- **retval**: `float`\n- **resp**: `Evision.Mat.t()`.\n\n  the optional output responses.\n\nThe method uses StatModel::predict to compute the error. For regression models the error is\ncomputed as RMS, for classifiers - as a percent of missclassified samples (0%-100%).\n\nPython prototype (for reference only):\n```python3\ncalcError(data, test[, resp]) -> retval, resp\n```","ref":"Evision.ML.ANNMLP.html#calcError/4"},{"type":"function","title":"Evision.ML.ANNMLP.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.ML.ANNMLP.html#clear/1"},{"type":"function","title":"Evision.ML.ANNMLP.create/0","doc":"Creates empty model\n##### Return\n- **retval**: `Evision.ML.ANNMLP.t()`\n\nUse StatModel::train to train the model, Algorithm::load\\ (filename) to load the pre-trained model.\nNote that the train method has optional flags: ANN_MLP::TrainFlags.\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.ML.ANNMLP.html#create/0"},{"type":"function","title":"Evision.ML.ANNMLP.create/1","doc":"","ref":"Evision.ML.ANNMLP.html#create/1"},{"type":"function","title":"Evision.ML.ANNMLP.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.ML.ANNMLP.html#empty/1"},{"type":"function","title":"Evision.ML.ANNMLP.getAnnealCoolingRatio/1","doc":"getAnnealCoolingRatio\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n\n##### Return\n- **retval**: `double`\n\n@see `setAnnealCoolingRatio/2`\n\nPython prototype (for reference only):\n```python3\ngetAnnealCoolingRatio() -> retval\n```","ref":"Evision.ML.ANNMLP.html#getAnnealCoolingRatio/1"},{"type":"function","title":"Evision.ML.ANNMLP.getAnnealFinalT/1","doc":"getAnnealFinalT\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n\n##### Return\n- **retval**: `double`\n\n@see `setAnnealFinalT/2`\n\nPython prototype (for reference only):\n```python3\ngetAnnealFinalT() -> retval\n```","ref":"Evision.ML.ANNMLP.html#getAnnealFinalT/1"},{"type":"function","title":"Evision.ML.ANNMLP.getAnnealInitialT/1","doc":"getAnnealInitialT\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n\n##### Return\n- **retval**: `double`\n\n@see `setAnnealInitialT/2`\n\nPython prototype (for reference only):\n```python3\ngetAnnealInitialT() -> retval\n```","ref":"Evision.ML.ANNMLP.html#getAnnealInitialT/1"},{"type":"function","title":"Evision.ML.ANNMLP.getAnnealItePerStep/1","doc":"getAnnealItePerStep\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setAnnealItePerStep/2`\n\nPython prototype (for reference only):\n```python3\ngetAnnealItePerStep() -> retval\n```","ref":"Evision.ML.ANNMLP.html#getAnnealItePerStep/1"},{"type":"function","title":"Evision.ML.ANNMLP.getBackpropMomentumScale/1","doc":"getBackpropMomentumScale\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n\n##### Return\n- **retval**: `double`\n\n@see `setBackpropMomentumScale/2`\n\nPython prototype (for reference only):\n```python3\ngetBackpropMomentumScale() -> retval\n```","ref":"Evision.ML.ANNMLP.html#getBackpropMomentumScale/1"},{"type":"function","title":"Evision.ML.ANNMLP.getBackpropWeightScale/1","doc":"getBackpropWeightScale\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n\n##### Return\n- **retval**: `double`\n\n@see `setBackpropWeightScale/2`\n\nPython prototype (for reference only):\n```python3\ngetBackpropWeightScale() -> retval\n```","ref":"Evision.ML.ANNMLP.html#getBackpropWeightScale/1"},{"type":"function","title":"Evision.ML.ANNMLP.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.ML.ANNMLP.html#getDefaultName/1"},{"type":"function","title":"Evision.ML.ANNMLP.getLayerSizes/1","doc":"getLayerSizes\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nInteger vector specifying the number of neurons in each layer including the input and output layers.\nThe very first element specifies the number of elements in the input layer.\nThe last element - number of elements in the output layer.\n@sa setLayerSizes\n\nPython prototype (for reference only):\n```python3\ngetLayerSizes() -> retval\n```","ref":"Evision.ML.ANNMLP.html#getLayerSizes/1"},{"type":"function","title":"Evision.ML.ANNMLP.getRpropDW0/1","doc":"getRpropDW0\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n\n##### Return\n- **retval**: `double`\n\n@see `setRpropDW0/2`\n\nPython prototype (for reference only):\n```python3\ngetRpropDW0() -> retval\n```","ref":"Evision.ML.ANNMLP.html#getRpropDW0/1"},{"type":"function","title":"Evision.ML.ANNMLP.getRpropDWMax/1","doc":"getRpropDWMax\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n\n##### Return\n- **retval**: `double`\n\n@see `setRpropDWMax/2`\n\nPython prototype (for reference only):\n```python3\ngetRpropDWMax() -> retval\n```","ref":"Evision.ML.ANNMLP.html#getRpropDWMax/1"},{"type":"function","title":"Evision.ML.ANNMLP.getRpropDWMin/1","doc":"getRpropDWMin\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n\n##### Return\n- **retval**: `double`\n\n@see `setRpropDWMin/2`\n\nPython prototype (for reference only):\n```python3\ngetRpropDWMin() -> retval\n```","ref":"Evision.ML.ANNMLP.html#getRpropDWMin/1"},{"type":"function","title":"Evision.ML.ANNMLP.getRpropDWMinus/1","doc":"getRpropDWMinus\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n\n##### Return\n- **retval**: `double`\n\n@see `setRpropDWMinus/2`\n\nPython prototype (for reference only):\n```python3\ngetRpropDWMinus() -> retval\n```","ref":"Evision.ML.ANNMLP.html#getRpropDWMinus/1"},{"type":"function","title":"Evision.ML.ANNMLP.getRpropDWPlus/1","doc":"getRpropDWPlus\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n\n##### Return\n- **retval**: `double`\n\n@see `setRpropDWPlus/2`\n\nPython prototype (for reference only):\n```python3\ngetRpropDWPlus() -> retval\n```","ref":"Evision.ML.ANNMLP.html#getRpropDWPlus/1"},{"type":"function","title":"Evision.ML.ANNMLP.getTermCriteria/1","doc":"getTermCriteria\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n\n##### Return\n- **retval**: `TermCriteria`\n\n@see `setTermCriteria/2`\n\nPython prototype (for reference only):\n```python3\ngetTermCriteria() -> retval\n```","ref":"Evision.ML.ANNMLP.html#getTermCriteria/1"},{"type":"function","title":"Evision.ML.ANNMLP.getTrainMethod/1","doc":"getTrainMethod\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n\n##### Return\n- **retval**: `integer()`\n\nReturns current training method\n\nPython prototype (for reference only):\n```python3\ngetTrainMethod() -> retval\n```","ref":"Evision.ML.ANNMLP.html#getTrainMethod/1"},{"type":"function","title":"Evision.ML.ANNMLP.getVarCount/1","doc":"Returns the number of variables in training samples\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetVarCount() -> retval\n```","ref":"Evision.ML.ANNMLP.html#getVarCount/1"},{"type":"function","title":"Evision.ML.ANNMLP.getWeights/1","doc":"","ref":"Evision.ML.ANNMLP.html#getWeights/1"},{"type":"function","title":"Evision.ML.ANNMLP.getWeights/2","doc":"getWeights\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **layerIdx**: `integer()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetWeights(layerIdx) -> retval\n```","ref":"Evision.ML.ANNMLP.html#getWeights/2"},{"type":"function","title":"Evision.ML.ANNMLP.isClassifier/1","doc":"Returns true if the model is classifier\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisClassifier() -> retval\n```","ref":"Evision.ML.ANNMLP.html#isClassifier/1"},{"type":"function","title":"Evision.ML.ANNMLP.isTrained/1","doc":"Returns true if the model is trained\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisTrained() -> retval\n```","ref":"Evision.ML.ANNMLP.html#isTrained/1"},{"type":"function","title":"Evision.ML.ANNMLP.load/1","doc":"Loads and creates a serialized ANN from a file\n\n##### Positional Arguments\n- **filepath**: `String`.\n\n  path to serialized ANN\n\n##### Return\n- **retval**: `Evision.ML.ANNMLP.t()`\n\n Use ANN::save to serialize and store an ANN to disk.\n Load the ANN from this file again, by calling this function with the path to the file.\n\nPython prototype (for reference only):\n```python3\nload(filepath) -> retval\n```","ref":"Evision.ML.ANNMLP.html#load/1"},{"type":"function","title":"Evision.ML.ANNMLP.predict/1","doc":"","ref":"Evision.ML.ANNMLP.html#predict/1"},{"type":"function","title":"Evision.ML.ANNMLP.predict/2","doc":"Predicts response(s) for the provided sample(s)\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **samples**: `Evision.Mat`.\n\n  The input samples, floating-point matrix\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  The optional flags, model-dependent. See cv::ml::StatModel::Flags.\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  The optional output matrix of results.\n\nPython prototype (for reference only):\n```python3\npredict(samples[, results[, flags]]) -> retval, results\n```","ref":"Evision.ML.ANNMLP.html#predict/2"},{"type":"function","title":"Evision.ML.ANNMLP.predict/3","doc":"Predicts response(s) for the provided sample(s)\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **samples**: `Evision.Mat`.\n\n  The input samples, floating-point matrix\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  The optional flags, model-dependent. See cv::ml::StatModel::Flags.\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  The optional output matrix of results.\n\nPython prototype (for reference only):\n```python3\npredict(samples[, results[, flags]]) -> retval, results\n```","ref":"Evision.ML.ANNMLP.html#predict/3"},{"type":"function","title":"Evision.ML.ANNMLP.read/1","doc":"","ref":"Evision.ML.ANNMLP.html#read/1"},{"type":"function","title":"Evision.ML.ANNMLP.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.ML.ANNMLP.html#read/2"},{"type":"function","title":"Evision.ML.ANNMLP.save/1","doc":"","ref":"Evision.ML.ANNMLP.html#save/1"},{"type":"function","title":"Evision.ML.ANNMLP.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.ML.ANNMLP.html#save/2"},{"type":"function","title":"Evision.ML.ANNMLP.setActivationFunction/1","doc":"","ref":"Evision.ML.ANNMLP.html#setActivationFunction/1"},{"type":"function","title":"Evision.ML.ANNMLP.setActivationFunction/2","doc":"setActivationFunction\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **type**: `integer()`.\n\n  The type of activation function. See ANN_MLP::ActivationFunctions.\n\n##### Keyword Arguments\n- **param1**: `double`.\n\n  The first parameter of the activation function, \\f$\\alpha\\f$. Default value is 0.\n\n- **param2**: `double`.\n\n  The second parameter of the activation function, \\f$\\beta\\f$. Default value is 0.\n\nInitialize the activation function for each neuron.\nCurrently the default and the only fully supported activation function is ANN_MLP::SIGMOID_SYM.\n\nPython prototype (for reference only):\n```python3\nsetActivationFunction(type[, param1[, param2]]) -> None\n```","ref":"Evision.ML.ANNMLP.html#setActivationFunction/2"},{"type":"function","title":"Evision.ML.ANNMLP.setActivationFunction/3","doc":"setActivationFunction\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **type**: `integer()`.\n\n  The type of activation function. See ANN_MLP::ActivationFunctions.\n\n##### Keyword Arguments\n- **param1**: `double`.\n\n  The first parameter of the activation function, \\f$\\alpha\\f$. Default value is 0.\n\n- **param2**: `double`.\n\n  The second parameter of the activation function, \\f$\\beta\\f$. Default value is 0.\n\nInitialize the activation function for each neuron.\nCurrently the default and the only fully supported activation function is ANN_MLP::SIGMOID_SYM.\n\nPython prototype (for reference only):\n```python3\nsetActivationFunction(type[, param1[, param2]]) -> None\n```","ref":"Evision.ML.ANNMLP.html#setActivationFunction/3"},{"type":"function","title":"Evision.ML.ANNMLP.setAnnealCoolingRatio/1","doc":"","ref":"Evision.ML.ANNMLP.html#setAnnealCoolingRatio/1"},{"type":"function","title":"Evision.ML.ANNMLP.setAnnealCoolingRatio/2","doc":"setAnnealCoolingRatio\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **val**: `double`\n\n@see `getAnnealCoolingRatio/1`\n\nPython prototype (for reference only):\n```python3\nsetAnnealCoolingRatio(val) -> None\n```","ref":"Evision.ML.ANNMLP.html#setAnnealCoolingRatio/2"},{"type":"function","title":"Evision.ML.ANNMLP.setAnnealFinalT/1","doc":"","ref":"Evision.ML.ANNMLP.html#setAnnealFinalT/1"},{"type":"function","title":"Evision.ML.ANNMLP.setAnnealFinalT/2","doc":"setAnnealFinalT\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **val**: `double`\n\n@see `getAnnealFinalT/1`\n\nPython prototype (for reference only):\n```python3\nsetAnnealFinalT(val) -> None\n```","ref":"Evision.ML.ANNMLP.html#setAnnealFinalT/2"},{"type":"function","title":"Evision.ML.ANNMLP.setAnnealInitialT/1","doc":"","ref":"Evision.ML.ANNMLP.html#setAnnealInitialT/1"},{"type":"function","title":"Evision.ML.ANNMLP.setAnnealInitialT/2","doc":"setAnnealInitialT\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **val**: `double`\n\n@see `getAnnealInitialT/1`\n\nPython prototype (for reference only):\n```python3\nsetAnnealInitialT(val) -> None\n```","ref":"Evision.ML.ANNMLP.html#setAnnealInitialT/2"},{"type":"function","title":"Evision.ML.ANNMLP.setAnnealItePerStep/1","doc":"","ref":"Evision.ML.ANNMLP.html#setAnnealItePerStep/1"},{"type":"function","title":"Evision.ML.ANNMLP.setAnnealItePerStep/2","doc":"setAnnealItePerStep\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **val**: `integer()`\n\n@see `getAnnealItePerStep/1`\n\nPython prototype (for reference only):\n```python3\nsetAnnealItePerStep(val) -> None\n```","ref":"Evision.ML.ANNMLP.html#setAnnealItePerStep/2"},{"type":"function","title":"Evision.ML.ANNMLP.setBackpropMomentumScale/1","doc":"","ref":"Evision.ML.ANNMLP.html#setBackpropMomentumScale/1"},{"type":"function","title":"Evision.ML.ANNMLP.setBackpropMomentumScale/2","doc":"setBackpropMomentumScale\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **val**: `double`\n\n@see `getBackpropMomentumScale/1`\n\nPython prototype (for reference only):\n```python3\nsetBackpropMomentumScale(val) -> None\n```","ref":"Evision.ML.ANNMLP.html#setBackpropMomentumScale/2"},{"type":"function","title":"Evision.ML.ANNMLP.setBackpropWeightScale/1","doc":"","ref":"Evision.ML.ANNMLP.html#setBackpropWeightScale/1"},{"type":"function","title":"Evision.ML.ANNMLP.setBackpropWeightScale/2","doc":"setBackpropWeightScale\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **val**: `double`\n\n@see `getBackpropWeightScale/1`\n\nPython prototype (for reference only):\n```python3\nsetBackpropWeightScale(val) -> None\n```","ref":"Evision.ML.ANNMLP.html#setBackpropWeightScale/2"},{"type":"function","title":"Evision.ML.ANNMLP.setLayerSizes/1","doc":"","ref":"Evision.ML.ANNMLP.html#setLayerSizes/1"},{"type":"function","title":"Evision.ML.ANNMLP.setLayerSizes/2","doc":"setLayerSizes\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **layer_sizes**: `Evision.Mat`\n\nInteger vector specifying the number of neurons in each layer including the input and output layers.\nThe very first element specifies the number of elements in the input layer.\nThe last element - number of elements in the output layer. Default value is empty Mat.\n@sa getLayerSizes\n\nPython prototype (for reference only):\n```python3\nsetLayerSizes(_layer_sizes) -> None\n```","ref":"Evision.ML.ANNMLP.html#setLayerSizes/2"},{"type":"function","title":"Evision.ML.ANNMLP.setRpropDW0/1","doc":"","ref":"Evision.ML.ANNMLP.html#setRpropDW0/1"},{"type":"function","title":"Evision.ML.ANNMLP.setRpropDW0/2","doc":"setRpropDW0\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **val**: `double`\n\n@see `getRpropDW0/1`\n\nPython prototype (for reference only):\n```python3\nsetRpropDW0(val) -> None\n```","ref":"Evision.ML.ANNMLP.html#setRpropDW0/2"},{"type":"function","title":"Evision.ML.ANNMLP.setRpropDWMax/1","doc":"","ref":"Evision.ML.ANNMLP.html#setRpropDWMax/1"},{"type":"function","title":"Evision.ML.ANNMLP.setRpropDWMax/2","doc":"setRpropDWMax\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **val**: `double`\n\n@see `getRpropDWMax/1`\n\nPython prototype (for reference only):\n```python3\nsetRpropDWMax(val) -> None\n```","ref":"Evision.ML.ANNMLP.html#setRpropDWMax/2"},{"type":"function","title":"Evision.ML.ANNMLP.setRpropDWMin/1","doc":"","ref":"Evision.ML.ANNMLP.html#setRpropDWMin/1"},{"type":"function","title":"Evision.ML.ANNMLP.setRpropDWMin/2","doc":"setRpropDWMin\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **val**: `double`\n\n@see `getRpropDWMin/1`\n\nPython prototype (for reference only):\n```python3\nsetRpropDWMin(val) -> None\n```","ref":"Evision.ML.ANNMLP.html#setRpropDWMin/2"},{"type":"function","title":"Evision.ML.ANNMLP.setRpropDWMinus/1","doc":"","ref":"Evision.ML.ANNMLP.html#setRpropDWMinus/1"},{"type":"function","title":"Evision.ML.ANNMLP.setRpropDWMinus/2","doc":"setRpropDWMinus\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **val**: `double`\n\n@see `getRpropDWMinus/1`\n\nPython prototype (for reference only):\n```python3\nsetRpropDWMinus(val) -> None\n```","ref":"Evision.ML.ANNMLP.html#setRpropDWMinus/2"},{"type":"function","title":"Evision.ML.ANNMLP.setRpropDWPlus/1","doc":"","ref":"Evision.ML.ANNMLP.html#setRpropDWPlus/1"},{"type":"function","title":"Evision.ML.ANNMLP.setRpropDWPlus/2","doc":"setRpropDWPlus\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **val**: `double`\n\n@see `getRpropDWPlus/1`\n\nPython prototype (for reference only):\n```python3\nsetRpropDWPlus(val) -> None\n```","ref":"Evision.ML.ANNMLP.html#setRpropDWPlus/2"},{"type":"function","title":"Evision.ML.ANNMLP.setTermCriteria/1","doc":"","ref":"Evision.ML.ANNMLP.html#setTermCriteria/1"},{"type":"function","title":"Evision.ML.ANNMLP.setTermCriteria/2","doc":"setTermCriteria\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **val**: `TermCriteria`\n\n@see `getTermCriteria/1`\n\nPython prototype (for reference only):\n```python3\nsetTermCriteria(val) -> None\n```","ref":"Evision.ML.ANNMLP.html#setTermCriteria/2"},{"type":"function","title":"Evision.ML.ANNMLP.setTrainMethod/1","doc":"","ref":"Evision.ML.ANNMLP.html#setTrainMethod/1"},{"type":"function","title":"Evision.ML.ANNMLP.setTrainMethod/2","doc":"setTrainMethod\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **method**: `integer()`.\n\n  Default value is ANN_MLP::RPROP. See ANN_MLP::TrainingMethods.\n\n##### Keyword Arguments\n- **param1**: `double`.\n\n  passed to setRpropDW0 for ANN_MLP::RPROP and to setBackpropWeightScale for ANN_MLP::BACKPROP and to initialT for ANN_MLP::ANNEAL.\n\n- **param2**: `double`.\n\n  passed to setRpropDWMin for ANN_MLP::RPROP and to setBackpropMomentumScale for ANN_MLP::BACKPROP and to finalT for ANN_MLP::ANNEAL.\n\nSets training method and common parameters.\n\nPython prototype (for reference only):\n```python3\nsetTrainMethod(method[, param1[, param2]]) -> None\n```","ref":"Evision.ML.ANNMLP.html#setTrainMethod/2"},{"type":"function","title":"Evision.ML.ANNMLP.setTrainMethod/3","doc":"setTrainMethod\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **method**: `integer()`.\n\n  Default value is ANN_MLP::RPROP. See ANN_MLP::TrainingMethods.\n\n##### Keyword Arguments\n- **param1**: `double`.\n\n  passed to setRpropDW0 for ANN_MLP::RPROP and to setBackpropWeightScale for ANN_MLP::BACKPROP and to initialT for ANN_MLP::ANNEAL.\n\n- **param2**: `double`.\n\n  passed to setRpropDWMin for ANN_MLP::RPROP and to setBackpropMomentumScale for ANN_MLP::BACKPROP and to finalT for ANN_MLP::ANNEAL.\n\nSets training method and common parameters.\n\nPython prototype (for reference only):\n```python3\nsetTrainMethod(method[, param1[, param2]]) -> None\n```","ref":"Evision.ML.ANNMLP.html#setTrainMethod/3"},{"type":"function","title":"Evision.ML.ANNMLP.train/1","doc":"","ref":"Evision.ML.ANNMLP.html#train/1"},{"type":"function","title":"Evision.ML.ANNMLP.train/2","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **trainData**: `Evision.ML.TrainData.t()`.\n\n  training data that can be loaded from file using TrainData::loadFromCSV or\n  created with TrainData::create.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  optional flags, depending on the model. Some of the models can be updated with the\n  new training samples, not completely overwritten (such as NormalBayesClassifier or ANN_MLP).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(trainData[, flags]) -> retval\n```","ref":"Evision.ML.ANNMLP.html#train/2"},{"type":"function","title":"Evision.ML.ANNMLP.train/3","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **trainData**: `Evision.ML.TrainData.t()`.\n\n  training data that can be loaded from file using TrainData::loadFromCSV or\n  created with TrainData::create.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  optional flags, depending on the model. Some of the models can be updated with the\n  new training samples, not completely overwritten (such as NormalBayesClassifier or ANN_MLP).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(trainData[, flags]) -> retval\n```","ref":"Evision.ML.ANNMLP.html#train/3"},{"type":"function","title":"Evision.ML.ANNMLP.train/4","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **samples**: `Evision.Mat`.\n\n  training samples\n\n- **layout**: `integer()`.\n\n  See ml::SampleTypes.\n\n- **responses**: `Evision.Mat`.\n\n  vector of responses associated with the training samples.\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(samples, layout, responses) -> retval\n```","ref":"Evision.ML.ANNMLP.html#train/4"},{"type":"function","title":"Evision.ML.ANNMLP.write/1","doc":"","ref":"Evision.ML.ANNMLP.html#write/1"},{"type":"function","title":"Evision.ML.ANNMLP.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.ML.ANNMLP.html#write/2"},{"type":"function","title":"Evision.ML.ANNMLP.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.ML.ANNMLP.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.ML.ANNMLP.html#write/3"},{"type":"type","title":"Evision.ML.ANNMLP.t/0","doc":"Type that represents an `ML.ANNMLP` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ML.ANNMLP.html#t:t/0"},{"type":"module","title":"Evision.ML.ANN_MLP.ActivationFunctions","doc":"","ref":"Evision.ML.ANN_MLP.ActivationFunctions.html"},{"type":"function","title":"Evision.ML.ANN_MLP.ActivationFunctions.cv_GAUSSIAN/0","doc":"","ref":"Evision.ML.ANN_MLP.ActivationFunctions.html#cv_GAUSSIAN/0"},{"type":"function","title":"Evision.ML.ANN_MLP.ActivationFunctions.cv_IDENTITY/0","doc":"","ref":"Evision.ML.ANN_MLP.ActivationFunctions.html#cv_IDENTITY/0"},{"type":"function","title":"Evision.ML.ANN_MLP.ActivationFunctions.cv_LEAKYRELU/0","doc":"","ref":"Evision.ML.ANN_MLP.ActivationFunctions.html#cv_LEAKYRELU/0"},{"type":"function","title":"Evision.ML.ANN_MLP.ActivationFunctions.cv_RELU/0","doc":"","ref":"Evision.ML.ANN_MLP.ActivationFunctions.html#cv_RELU/0"},{"type":"function","title":"Evision.ML.ANN_MLP.ActivationFunctions.cv_SIGMOID_SYM/0","doc":"","ref":"Evision.ML.ANN_MLP.ActivationFunctions.html#cv_SIGMOID_SYM/0"},{"type":"type","title":"Evision.ML.ANN_MLP.ActivationFunctions.enum/0","doc":"","ref":"Evision.ML.ANN_MLP.ActivationFunctions.html#t:enum/0"},{"type":"module","title":"Evision.ML.ANN_MLP.TrainFlags","doc":"","ref":"Evision.ML.ANN_MLP.TrainFlags.html"},{"type":"function","title":"Evision.ML.ANN_MLP.TrainFlags.cv_NO_INPUT_SCALE/0","doc":"","ref":"Evision.ML.ANN_MLP.TrainFlags.html#cv_NO_INPUT_SCALE/0"},{"type":"function","title":"Evision.ML.ANN_MLP.TrainFlags.cv_NO_OUTPUT_SCALE/0","doc":"","ref":"Evision.ML.ANN_MLP.TrainFlags.html#cv_NO_OUTPUT_SCALE/0"},{"type":"function","title":"Evision.ML.ANN_MLP.TrainFlags.cv_UPDATE_WEIGHTS/0","doc":"","ref":"Evision.ML.ANN_MLP.TrainFlags.html#cv_UPDATE_WEIGHTS/0"},{"type":"type","title":"Evision.ML.ANN_MLP.TrainFlags.enum/0","doc":"","ref":"Evision.ML.ANN_MLP.TrainFlags.html#t:enum/0"},{"type":"module","title":"Evision.ML.ANN_MLP.TrainingMethods","doc":"","ref":"Evision.ML.ANN_MLP.TrainingMethods.html"},{"type":"function","title":"Evision.ML.ANN_MLP.TrainingMethods.cv_ANNEAL/0","doc":"","ref":"Evision.ML.ANN_MLP.TrainingMethods.html#cv_ANNEAL/0"},{"type":"function","title":"Evision.ML.ANN_MLP.TrainingMethods.cv_BACKPROP/0","doc":"","ref":"Evision.ML.ANN_MLP.TrainingMethods.html#cv_BACKPROP/0"},{"type":"function","title":"Evision.ML.ANN_MLP.TrainingMethods.cv_RPROP/0","doc":"","ref":"Evision.ML.ANN_MLP.TrainingMethods.html#cv_RPROP/0"},{"type":"type","title":"Evision.ML.ANN_MLP.TrainingMethods.enum/0","doc":"","ref":"Evision.ML.ANN_MLP.TrainingMethods.html#t:enum/0"},{"type":"module","title":"Evision.ML.Boost","doc":"","ref":"Evision.ML.Boost.html"},{"type":"function","title":"Evision.ML.Boost.calcError/1","doc":"","ref":"Evision.ML.Boost.html#calcError/1"},{"type":"function","title":"Evision.ML.Boost.calcError/3","doc":"Computes error on the training or test dataset\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n- **data**: `Evision.ML.TrainData.t()`.\n\n  the training data\n\n- **test**: `bool`.\n\n  if true, the error is computed over the test subset of the data, otherwise it's\n  computed over the training subset of the data. Please note that if you loaded a completely\n  different dataset to evaluate already trained classifier, you will probably want not to set\n  the test subset at all with TrainData::setTrainTestSplitRatio and specify test=false, so\n  that the error is computed for the whole new set. Yes, this sounds a bit confusing.\n\n##### Return\n- **retval**: `float`\n- **resp**: `Evision.Mat.t()`.\n\n  the optional output responses.\n\nThe method uses StatModel::predict to compute the error. For regression models the error is\ncomputed as RMS, for classifiers - as a percent of missclassified samples (0%-100%).\n\nPython prototype (for reference only):\n```python3\ncalcError(data, test[, resp]) -> retval, resp\n```","ref":"Evision.ML.Boost.html#calcError/3"},{"type":"function","title":"Evision.ML.Boost.calcError/4","doc":"Computes error on the training or test dataset\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n- **data**: `Evision.ML.TrainData.t()`.\n\n  the training data\n\n- **test**: `bool`.\n\n  if true, the error is computed over the test subset of the data, otherwise it's\n  computed over the training subset of the data. Please note that if you loaded a completely\n  different dataset to evaluate already trained classifier, you will probably want not to set\n  the test subset at all with TrainData::setTrainTestSplitRatio and specify test=false, so\n  that the error is computed for the whole new set. Yes, this sounds a bit confusing.\n\n##### Return\n- **retval**: `float`\n- **resp**: `Evision.Mat.t()`.\n\n  the optional output responses.\n\nThe method uses StatModel::predict to compute the error. For regression models the error is\ncomputed as RMS, for classifiers - as a percent of missclassified samples (0%-100%).\n\nPython prototype (for reference only):\n```python3\ncalcError(data, test[, resp]) -> retval, resp\n```","ref":"Evision.ML.Boost.html#calcError/4"},{"type":"function","title":"Evision.ML.Boost.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.ML.Boost.html#clear/1"},{"type":"function","title":"Evision.ML.Boost.create/0","doc":"create\n##### Return\n- **retval**: `Evision.ML.Boost.t()`\n\nCreates the empty model.\nUse StatModel::train to train the model, Algorithm::load\\ (filename) to load the pre-trained model.\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.ML.Boost.html#create/0"},{"type":"function","title":"Evision.ML.Boost.create/1","doc":"","ref":"Evision.ML.Boost.html#create/1"},{"type":"function","title":"Evision.ML.Boost.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.ML.Boost.html#empty/1"},{"type":"function","title":"Evision.ML.Boost.getBoostType/1","doc":"getBoostType\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setBoostType/2`\n\nPython prototype (for reference only):\n```python3\ngetBoostType() -> retval\n```","ref":"Evision.ML.Boost.html#getBoostType/1"},{"type":"function","title":"Evision.ML.Boost.getCVFolds/1","doc":"getCVFolds\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setCVFolds/2`\n\nPython prototype (for reference only):\n```python3\ngetCVFolds() -> retval\n```","ref":"Evision.ML.Boost.html#getCVFolds/1"},{"type":"function","title":"Evision.ML.Boost.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.ML.Boost.html#getDefaultName/1"},{"type":"function","title":"Evision.ML.Boost.getMaxCategories/1","doc":"getMaxCategories\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setMaxCategories/2`\n\nPython prototype (for reference only):\n```python3\ngetMaxCategories() -> retval\n```","ref":"Evision.ML.Boost.html#getMaxCategories/1"},{"type":"function","title":"Evision.ML.Boost.getMaxDepth/1","doc":"getMaxDepth\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setMaxDepth/2`\n\nPython prototype (for reference only):\n```python3\ngetMaxDepth() -> retval\n```","ref":"Evision.ML.Boost.html#getMaxDepth/1"},{"type":"function","title":"Evision.ML.Boost.getMinSampleCount/1","doc":"getMinSampleCount\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setMinSampleCount/2`\n\nPython prototype (for reference only):\n```python3\ngetMinSampleCount() -> retval\n```","ref":"Evision.ML.Boost.html#getMinSampleCount/1"},{"type":"function","title":"Evision.ML.Boost.getPriors/1","doc":"getPriors\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n@see `setPriors/2`\n\nPython prototype (for reference only):\n```python3\ngetPriors() -> retval\n```","ref":"Evision.ML.Boost.html#getPriors/1"},{"type":"function","title":"Evision.ML.Boost.getRegressionAccuracy/1","doc":"getRegressionAccuracy\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setRegressionAccuracy/2`\n\nPython prototype (for reference only):\n```python3\ngetRegressionAccuracy() -> retval\n```","ref":"Evision.ML.Boost.html#getRegressionAccuracy/1"},{"type":"function","title":"Evision.ML.Boost.getTruncatePrunedTree/1","doc":"getTruncatePrunedTree\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n\n##### Return\n- **retval**: `bool`\n\n@see `setTruncatePrunedTree/2`\n\nPython prototype (for reference only):\n```python3\ngetTruncatePrunedTree() -> retval\n```","ref":"Evision.ML.Boost.html#getTruncatePrunedTree/1"},{"type":"function","title":"Evision.ML.Boost.getUse1SERule/1","doc":"getUse1SERule\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n\n##### Return\n- **retval**: `bool`\n\n@see `setUse1SERule/2`\n\nPython prototype (for reference only):\n```python3\ngetUse1SERule() -> retval\n```","ref":"Evision.ML.Boost.html#getUse1SERule/1"},{"type":"function","title":"Evision.ML.Boost.getUseSurrogates/1","doc":"getUseSurrogates\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n\n##### Return\n- **retval**: `bool`\n\n@see `setUseSurrogates/2`\n\nPython prototype (for reference only):\n```python3\ngetUseSurrogates() -> retval\n```","ref":"Evision.ML.Boost.html#getUseSurrogates/1"},{"type":"function","title":"Evision.ML.Boost.getVarCount/1","doc":"Returns the number of variables in training samples\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetVarCount() -> retval\n```","ref":"Evision.ML.Boost.html#getVarCount/1"},{"type":"function","title":"Evision.ML.Boost.getWeakCount/1","doc":"getWeakCount\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setWeakCount/2`\n\nPython prototype (for reference only):\n```python3\ngetWeakCount() -> retval\n```","ref":"Evision.ML.Boost.html#getWeakCount/1"},{"type":"function","title":"Evision.ML.Boost.getWeightTrimRate/1","doc":"getWeightTrimRate\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n\n##### Return\n- **retval**: `double`\n\n@see `setWeightTrimRate/2`\n\nPython prototype (for reference only):\n```python3\ngetWeightTrimRate() -> retval\n```","ref":"Evision.ML.Boost.html#getWeightTrimRate/1"},{"type":"function","title":"Evision.ML.Boost.isClassifier/1","doc":"Returns true if the model is classifier\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisClassifier() -> retval\n```","ref":"Evision.ML.Boost.html#isClassifier/1"},{"type":"function","title":"Evision.ML.Boost.isTrained/1","doc":"Returns true if the model is trained\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisTrained() -> retval\n```","ref":"Evision.ML.Boost.html#isTrained/1"},{"type":"function","title":"Evision.ML.Boost.load/1","doc":"Loads and creates a serialized Boost from a file\n\n##### Positional Arguments\n- **filepath**: `String`.\n\n  path to serialized Boost\n\n##### Keyword Arguments\n- **nodeName**: `String`.\n\n  name of node containing the classifier\n\n##### Return\n- **retval**: `Evision.ML.Boost.t()`\n\n Use Boost::save to serialize and store an RTree to disk.\n Load the Boost from this file again, by calling this function with the path to the file.\n Optionally specify the node for the file containing the classifier\n\nPython prototype (for reference only):\n```python3\nload(filepath[, nodeName]) -> retval\n```","ref":"Evision.ML.Boost.html#load/1"},{"type":"function","title":"Evision.ML.Boost.load/2","doc":"Loads and creates a serialized Boost from a file\n\n##### Positional Arguments\n- **filepath**: `String`.\n\n  path to serialized Boost\n\n##### Keyword Arguments\n- **nodeName**: `String`.\n\n  name of node containing the classifier\n\n##### Return\n- **retval**: `Evision.ML.Boost.t()`\n\n Use Boost::save to serialize and store an RTree to disk.\n Load the Boost from this file again, by calling this function with the path to the file.\n Optionally specify the node for the file containing the classifier\n\nPython prototype (for reference only):\n```python3\nload(filepath[, nodeName]) -> retval\n```","ref":"Evision.ML.Boost.html#load/2"},{"type":"function","title":"Evision.ML.Boost.predict/1","doc":"","ref":"Evision.ML.Boost.html#predict/1"},{"type":"function","title":"Evision.ML.Boost.predict/2","doc":"Predicts response(s) for the provided sample(s)\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n- **samples**: `Evision.Mat`.\n\n  The input samples, floating-point matrix\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  The optional flags, model-dependent. See cv::ml::StatModel::Flags.\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  The optional output matrix of results.\n\nPython prototype (for reference only):\n```python3\npredict(samples[, results[, flags]]) -> retval, results\n```","ref":"Evision.ML.Boost.html#predict/2"},{"type":"function","title":"Evision.ML.Boost.predict/3","doc":"Predicts response(s) for the provided sample(s)\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n- **samples**: `Evision.Mat`.\n\n  The input samples, floating-point matrix\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  The optional flags, model-dependent. See cv::ml::StatModel::Flags.\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  The optional output matrix of results.\n\nPython prototype (for reference only):\n```python3\npredict(samples[, results[, flags]]) -> retval, results\n```","ref":"Evision.ML.Boost.html#predict/3"},{"type":"function","title":"Evision.ML.Boost.read/1","doc":"","ref":"Evision.ML.Boost.html#read/1"},{"type":"function","title":"Evision.ML.Boost.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.ML.Boost.html#read/2"},{"type":"function","title":"Evision.ML.Boost.save/1","doc":"","ref":"Evision.ML.Boost.html#save/1"},{"type":"function","title":"Evision.ML.Boost.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.ML.Boost.html#save/2"},{"type":"function","title":"Evision.ML.Boost.setBoostType/1","doc":"","ref":"Evision.ML.Boost.html#setBoostType/1"},{"type":"function","title":"Evision.ML.Boost.setBoostType/2","doc":"setBoostType\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n- **val**: `integer()`\n\n@see `getBoostType/1`\n\nPython prototype (for reference only):\n```python3\nsetBoostType(val) -> None\n```","ref":"Evision.ML.Boost.html#setBoostType/2"},{"type":"function","title":"Evision.ML.Boost.setCVFolds/1","doc":"","ref":"Evision.ML.Boost.html#setCVFolds/1"},{"type":"function","title":"Evision.ML.Boost.setCVFolds/2","doc":"setCVFolds\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n- **val**: `integer()`\n\n@see `getCVFolds/1`\n\nPython prototype (for reference only):\n```python3\nsetCVFolds(val) -> None\n```","ref":"Evision.ML.Boost.html#setCVFolds/2"},{"type":"function","title":"Evision.ML.Boost.setMaxCategories/1","doc":"","ref":"Evision.ML.Boost.html#setMaxCategories/1"},{"type":"function","title":"Evision.ML.Boost.setMaxCategories/2","doc":"setMaxCategories\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n- **val**: `integer()`\n\n@see `getMaxCategories/1`\n\nPython prototype (for reference only):\n```python3\nsetMaxCategories(val) -> None\n```","ref":"Evision.ML.Boost.html#setMaxCategories/2"},{"type":"function","title":"Evision.ML.Boost.setMaxDepth/1","doc":"","ref":"Evision.ML.Boost.html#setMaxDepth/1"},{"type":"function","title":"Evision.ML.Boost.setMaxDepth/2","doc":"setMaxDepth\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n- **val**: `integer()`\n\n@see `getMaxDepth/1`\n\nPython prototype (for reference only):\n```python3\nsetMaxDepth(val) -> None\n```","ref":"Evision.ML.Boost.html#setMaxDepth/2"},{"type":"function","title":"Evision.ML.Boost.setMinSampleCount/1","doc":"","ref":"Evision.ML.Boost.html#setMinSampleCount/1"},{"type":"function","title":"Evision.ML.Boost.setMinSampleCount/2","doc":"setMinSampleCount\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n- **val**: `integer()`\n\n@see `getMinSampleCount/1`\n\nPython prototype (for reference only):\n```python3\nsetMinSampleCount(val) -> None\n```","ref":"Evision.ML.Boost.html#setMinSampleCount/2"},{"type":"function","title":"Evision.ML.Boost.setPriors/1","doc":"","ref":"Evision.ML.Boost.html#setPriors/1"},{"type":"function","title":"Evision.ML.Boost.setPriors/2","doc":"setPriors\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n- **val**: `Evision.Mat`\n\n@see `getPriors/1`\n\nPython prototype (for reference only):\n```python3\nsetPriors(val) -> None\n```","ref":"Evision.ML.Boost.html#setPriors/2"},{"type":"function","title":"Evision.ML.Boost.setRegressionAccuracy/1","doc":"","ref":"Evision.ML.Boost.html#setRegressionAccuracy/1"},{"type":"function","title":"Evision.ML.Boost.setRegressionAccuracy/2","doc":"setRegressionAccuracy\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n- **val**: `float`\n\n@see `getRegressionAccuracy/1`\n\nPython prototype (for reference only):\n```python3\nsetRegressionAccuracy(val) -> None\n```","ref":"Evision.ML.Boost.html#setRegressionAccuracy/2"},{"type":"function","title":"Evision.ML.Boost.setTruncatePrunedTree/1","doc":"","ref":"Evision.ML.Boost.html#setTruncatePrunedTree/1"},{"type":"function","title":"Evision.ML.Boost.setTruncatePrunedTree/2","doc":"setTruncatePrunedTree\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n- **val**: `bool`\n\n@see `getTruncatePrunedTree/1`\n\nPython prototype (for reference only):\n```python3\nsetTruncatePrunedTree(val) -> None\n```","ref":"Evision.ML.Boost.html#setTruncatePrunedTree/2"},{"type":"function","title":"Evision.ML.Boost.setUse1SERule/1","doc":"","ref":"Evision.ML.Boost.html#setUse1SERule/1"},{"type":"function","title":"Evision.ML.Boost.setUse1SERule/2","doc":"setUse1SERule\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n- **val**: `bool`\n\n@see `getUse1SERule/1`\n\nPython prototype (for reference only):\n```python3\nsetUse1SERule(val) -> None\n```","ref":"Evision.ML.Boost.html#setUse1SERule/2"},{"type":"function","title":"Evision.ML.Boost.setUseSurrogates/1","doc":"","ref":"Evision.ML.Boost.html#setUseSurrogates/1"},{"type":"function","title":"Evision.ML.Boost.setUseSurrogates/2","doc":"setUseSurrogates\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n- **val**: `bool`\n\n@see `getUseSurrogates/1`\n\nPython prototype (for reference only):\n```python3\nsetUseSurrogates(val) -> None\n```","ref":"Evision.ML.Boost.html#setUseSurrogates/2"},{"type":"function","title":"Evision.ML.Boost.setWeakCount/1","doc":"","ref":"Evision.ML.Boost.html#setWeakCount/1"},{"type":"function","title":"Evision.ML.Boost.setWeakCount/2","doc":"setWeakCount\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n- **val**: `integer()`\n\n@see `getWeakCount/1`\n\nPython prototype (for reference only):\n```python3\nsetWeakCount(val) -> None\n```","ref":"Evision.ML.Boost.html#setWeakCount/2"},{"type":"function","title":"Evision.ML.Boost.setWeightTrimRate/1","doc":"","ref":"Evision.ML.Boost.html#setWeightTrimRate/1"},{"type":"function","title":"Evision.ML.Boost.setWeightTrimRate/2","doc":"setWeightTrimRate\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n- **val**: `double`\n\n@see `getWeightTrimRate/1`\n\nPython prototype (for reference only):\n```python3\nsetWeightTrimRate(val) -> None\n```","ref":"Evision.ML.Boost.html#setWeightTrimRate/2"},{"type":"function","title":"Evision.ML.Boost.train/1","doc":"","ref":"Evision.ML.Boost.html#train/1"},{"type":"function","title":"Evision.ML.Boost.train/2","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n- **trainData**: `Evision.ML.TrainData.t()`.\n\n  training data that can be loaded from file using TrainData::loadFromCSV or\n  created with TrainData::create.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  optional flags, depending on the model. Some of the models can be updated with the\n  new training samples, not completely overwritten (such as NormalBayesClassifier or ANN_MLP).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(trainData[, flags]) -> retval\n```","ref":"Evision.ML.Boost.html#train/2"},{"type":"function","title":"Evision.ML.Boost.train/3","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n- **trainData**: `Evision.ML.TrainData.t()`.\n\n  training data that can be loaded from file using TrainData::loadFromCSV or\n  created with TrainData::create.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  optional flags, depending on the model. Some of the models can be updated with the\n  new training samples, not completely overwritten (such as NormalBayesClassifier or ANN_MLP).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(trainData[, flags]) -> retval\n```","ref":"Evision.ML.Boost.html#train/3"},{"type":"function","title":"Evision.ML.Boost.train/4","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n- **samples**: `Evision.Mat`.\n\n  training samples\n\n- **layout**: `integer()`.\n\n  See ml::SampleTypes.\n\n- **responses**: `Evision.Mat`.\n\n  vector of responses associated with the training samples.\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(samples, layout, responses) -> retval\n```","ref":"Evision.ML.Boost.html#train/4"},{"type":"function","title":"Evision.ML.Boost.write/1","doc":"","ref":"Evision.ML.Boost.html#write/1"},{"type":"function","title":"Evision.ML.Boost.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.ML.Boost.html#write/2"},{"type":"function","title":"Evision.ML.Boost.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.ML.Boost.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.ML.Boost.html#write/3"},{"type":"type","title":"Evision.ML.Boost.t/0","doc":"Type that represents an `ML.Boost` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ML.Boost.html#t:t/0"},{"type":"module","title":"Evision.ML.Boost.Types","doc":"","ref":"Evision.ML.Boost.Types.html"},{"type":"function","title":"Evision.ML.Boost.Types.cv_DISCRETE/0","doc":"","ref":"Evision.ML.Boost.Types.html#cv_DISCRETE/0"},{"type":"function","title":"Evision.ML.Boost.Types.cv_GENTLE/0","doc":"","ref":"Evision.ML.Boost.Types.html#cv_GENTLE/0"},{"type":"function","title":"Evision.ML.Boost.Types.cv_LOGIT/0","doc":"","ref":"Evision.ML.Boost.Types.html#cv_LOGIT/0"},{"type":"function","title":"Evision.ML.Boost.Types.cv_REAL/0","doc":"","ref":"Evision.ML.Boost.Types.html#cv_REAL/0"},{"type":"type","title":"Evision.ML.Boost.Types.enum/0","doc":"","ref":"Evision.ML.Boost.Types.html#t:enum/0"},{"type":"module","title":"Evision.ML.DTrees","doc":"","ref":"Evision.ML.DTrees.html"},{"type":"function","title":"Evision.ML.DTrees.calcError/1","doc":"","ref":"Evision.ML.DTrees.html#calcError/1"},{"type":"function","title":"Evision.ML.DTrees.calcError/3","doc":"Computes error on the training or test dataset\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n- **data**: `Evision.ML.TrainData.t()`.\n\n  the training data\n\n- **test**: `bool`.\n\n  if true, the error is computed over the test subset of the data, otherwise it's\n  computed over the training subset of the data. Please note that if you loaded a completely\n  different dataset to evaluate already trained classifier, you will probably want not to set\n  the test subset at all with TrainData::setTrainTestSplitRatio and specify test=false, so\n  that the error is computed for the whole new set. Yes, this sounds a bit confusing.\n\n##### Return\n- **retval**: `float`\n- **resp**: `Evision.Mat.t()`.\n\n  the optional output responses.\n\nThe method uses StatModel::predict to compute the error. For regression models the error is\ncomputed as RMS, for classifiers - as a percent of missclassified samples (0%-100%).\n\nPython prototype (for reference only):\n```python3\ncalcError(data, test[, resp]) -> retval, resp\n```","ref":"Evision.ML.DTrees.html#calcError/3"},{"type":"function","title":"Evision.ML.DTrees.calcError/4","doc":"Computes error on the training or test dataset\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n- **data**: `Evision.ML.TrainData.t()`.\n\n  the training data\n\n- **test**: `bool`.\n\n  if true, the error is computed over the test subset of the data, otherwise it's\n  computed over the training subset of the data. Please note that if you loaded a completely\n  different dataset to evaluate already trained classifier, you will probably want not to set\n  the test subset at all with TrainData::setTrainTestSplitRatio and specify test=false, so\n  that the error is computed for the whole new set. Yes, this sounds a bit confusing.\n\n##### Return\n- **retval**: `float`\n- **resp**: `Evision.Mat.t()`.\n\n  the optional output responses.\n\nThe method uses StatModel::predict to compute the error. For regression models the error is\ncomputed as RMS, for classifiers - as a percent of missclassified samples (0%-100%).\n\nPython prototype (for reference only):\n```python3\ncalcError(data, test[, resp]) -> retval, resp\n```","ref":"Evision.ML.DTrees.html#calcError/4"},{"type":"function","title":"Evision.ML.DTrees.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.ML.DTrees.html#clear/1"},{"type":"function","title":"Evision.ML.DTrees.create/0","doc":"Creates the empty model\n##### Return\n- **retval**: `Evision.ML.DTrees.t()`\n\nThe static method creates empty decision tree with the specified parameters. It should be then\ntrained using train method (see StatModel::train). Alternatively, you can load the model from\nfile using Algorithm::load\\ (filename).\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.ML.DTrees.html#create/0"},{"type":"function","title":"Evision.ML.DTrees.create/1","doc":"","ref":"Evision.ML.DTrees.html#create/1"},{"type":"function","title":"Evision.ML.DTrees.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.ML.DTrees.html#empty/1"},{"type":"function","title":"Evision.ML.DTrees.getCVFolds/1","doc":"getCVFolds\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setCVFolds/2`\n\nPython prototype (for reference only):\n```python3\ngetCVFolds() -> retval\n```","ref":"Evision.ML.DTrees.html#getCVFolds/1"},{"type":"function","title":"Evision.ML.DTrees.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.ML.DTrees.html#getDefaultName/1"},{"type":"function","title":"Evision.ML.DTrees.getMaxCategories/1","doc":"getMaxCategories\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setMaxCategories/2`\n\nPython prototype (for reference only):\n```python3\ngetMaxCategories() -> retval\n```","ref":"Evision.ML.DTrees.html#getMaxCategories/1"},{"type":"function","title":"Evision.ML.DTrees.getMaxDepth/1","doc":"getMaxDepth\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setMaxDepth/2`\n\nPython prototype (for reference only):\n```python3\ngetMaxDepth() -> retval\n```","ref":"Evision.ML.DTrees.html#getMaxDepth/1"},{"type":"function","title":"Evision.ML.DTrees.getMinSampleCount/1","doc":"getMinSampleCount\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setMinSampleCount/2`\n\nPython prototype (for reference only):\n```python3\ngetMinSampleCount() -> retval\n```","ref":"Evision.ML.DTrees.html#getMinSampleCount/1"},{"type":"function","title":"Evision.ML.DTrees.getPriors/1","doc":"getPriors\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n@see `setPriors/2`\n\nPython prototype (for reference only):\n```python3\ngetPriors() -> retval\n```","ref":"Evision.ML.DTrees.html#getPriors/1"},{"type":"function","title":"Evision.ML.DTrees.getRegressionAccuracy/1","doc":"getRegressionAccuracy\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setRegressionAccuracy/2`\n\nPython prototype (for reference only):\n```python3\ngetRegressionAccuracy() -> retval\n```","ref":"Evision.ML.DTrees.html#getRegressionAccuracy/1"},{"type":"function","title":"Evision.ML.DTrees.getTruncatePrunedTree/1","doc":"getTruncatePrunedTree\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n\n##### Return\n- **retval**: `bool`\n\n@see `setTruncatePrunedTree/2`\n\nPython prototype (for reference only):\n```python3\ngetTruncatePrunedTree() -> retval\n```","ref":"Evision.ML.DTrees.html#getTruncatePrunedTree/1"},{"type":"function","title":"Evision.ML.DTrees.getUse1SERule/1","doc":"getUse1SERule\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n\n##### Return\n- **retval**: `bool`\n\n@see `setUse1SERule/2`\n\nPython prototype (for reference only):\n```python3\ngetUse1SERule() -> retval\n```","ref":"Evision.ML.DTrees.html#getUse1SERule/1"},{"type":"function","title":"Evision.ML.DTrees.getUseSurrogates/1","doc":"getUseSurrogates\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n\n##### Return\n- **retval**: `bool`\n\n@see `setUseSurrogates/2`\n\nPython prototype (for reference only):\n```python3\ngetUseSurrogates() -> retval\n```","ref":"Evision.ML.DTrees.html#getUseSurrogates/1"},{"type":"function","title":"Evision.ML.DTrees.getVarCount/1","doc":"Returns the number of variables in training samples\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetVarCount() -> retval\n```","ref":"Evision.ML.DTrees.html#getVarCount/1"},{"type":"function","title":"Evision.ML.DTrees.isClassifier/1","doc":"Returns true if the model is classifier\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisClassifier() -> retval\n```","ref":"Evision.ML.DTrees.html#isClassifier/1"},{"type":"function","title":"Evision.ML.DTrees.isTrained/1","doc":"Returns true if the model is trained\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisTrained() -> retval\n```","ref":"Evision.ML.DTrees.html#isTrained/1"},{"type":"function","title":"Evision.ML.DTrees.load/1","doc":"Loads and creates a serialized DTrees from a file\n\n##### Positional Arguments\n- **filepath**: `String`.\n\n  path to serialized DTree\n\n##### Keyword Arguments\n- **nodeName**: `String`.\n\n  name of node containing the classifier\n\n##### Return\n- **retval**: `Evision.ML.DTrees.t()`\n\n Use DTree::save to serialize and store an DTree to disk.\n Load the DTree from this file again, by calling this function with the path to the file.\n Optionally specify the node for the file containing the classifier\n\nPython prototype (for reference only):\n```python3\nload(filepath[, nodeName]) -> retval\n```","ref":"Evision.ML.DTrees.html#load/1"},{"type":"function","title":"Evision.ML.DTrees.load/2","doc":"Loads and creates a serialized DTrees from a file\n\n##### Positional Arguments\n- **filepath**: `String`.\n\n  path to serialized DTree\n\n##### Keyword Arguments\n- **nodeName**: `String`.\n\n  name of node containing the classifier\n\n##### Return\n- **retval**: `Evision.ML.DTrees.t()`\n\n Use DTree::save to serialize and store an DTree to disk.\n Load the DTree from this file again, by calling this function with the path to the file.\n Optionally specify the node for the file containing the classifier\n\nPython prototype (for reference only):\n```python3\nload(filepath[, nodeName]) -> retval\n```","ref":"Evision.ML.DTrees.html#load/2"},{"type":"function","title":"Evision.ML.DTrees.predict/1","doc":"","ref":"Evision.ML.DTrees.html#predict/1"},{"type":"function","title":"Evision.ML.DTrees.predict/2","doc":"Predicts response(s) for the provided sample(s)\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n- **samples**: `Evision.Mat`.\n\n  The input samples, floating-point matrix\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  The optional flags, model-dependent. See cv::ml::StatModel::Flags.\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  The optional output matrix of results.\n\nPython prototype (for reference only):\n```python3\npredict(samples[, results[, flags]]) -> retval, results\n```","ref":"Evision.ML.DTrees.html#predict/2"},{"type":"function","title":"Evision.ML.DTrees.predict/3","doc":"Predicts response(s) for the provided sample(s)\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n- **samples**: `Evision.Mat`.\n\n  The input samples, floating-point matrix\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  The optional flags, model-dependent. See cv::ml::StatModel::Flags.\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  The optional output matrix of results.\n\nPython prototype (for reference only):\n```python3\npredict(samples[, results[, flags]]) -> retval, results\n```","ref":"Evision.ML.DTrees.html#predict/3"},{"type":"function","title":"Evision.ML.DTrees.read/1","doc":"","ref":"Evision.ML.DTrees.html#read/1"},{"type":"function","title":"Evision.ML.DTrees.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.ML.DTrees.html#read/2"},{"type":"function","title":"Evision.ML.DTrees.save/1","doc":"","ref":"Evision.ML.DTrees.html#save/1"},{"type":"function","title":"Evision.ML.DTrees.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.ML.DTrees.html#save/2"},{"type":"function","title":"Evision.ML.DTrees.setCVFolds/1","doc":"","ref":"Evision.ML.DTrees.html#setCVFolds/1"},{"type":"function","title":"Evision.ML.DTrees.setCVFolds/2","doc":"setCVFolds\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n- **val**: `integer()`\n\n@see `getCVFolds/1`\n\nPython prototype (for reference only):\n```python3\nsetCVFolds(val) -> None\n```","ref":"Evision.ML.DTrees.html#setCVFolds/2"},{"type":"function","title":"Evision.ML.DTrees.setMaxCategories/1","doc":"","ref":"Evision.ML.DTrees.html#setMaxCategories/1"},{"type":"function","title":"Evision.ML.DTrees.setMaxCategories/2","doc":"setMaxCategories\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n- **val**: `integer()`\n\n@see `getMaxCategories/1`\n\nPython prototype (for reference only):\n```python3\nsetMaxCategories(val) -> None\n```","ref":"Evision.ML.DTrees.html#setMaxCategories/2"},{"type":"function","title":"Evision.ML.DTrees.setMaxDepth/1","doc":"","ref":"Evision.ML.DTrees.html#setMaxDepth/1"},{"type":"function","title":"Evision.ML.DTrees.setMaxDepth/2","doc":"setMaxDepth\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n- **val**: `integer()`\n\n@see `getMaxDepth/1`\n\nPython prototype (for reference only):\n```python3\nsetMaxDepth(val) -> None\n```","ref":"Evision.ML.DTrees.html#setMaxDepth/2"},{"type":"function","title":"Evision.ML.DTrees.setMinSampleCount/1","doc":"","ref":"Evision.ML.DTrees.html#setMinSampleCount/1"},{"type":"function","title":"Evision.ML.DTrees.setMinSampleCount/2","doc":"setMinSampleCount\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n- **val**: `integer()`\n\n@see `getMinSampleCount/1`\n\nPython prototype (for reference only):\n```python3\nsetMinSampleCount(val) -> None\n```","ref":"Evision.ML.DTrees.html#setMinSampleCount/2"},{"type":"function","title":"Evision.ML.DTrees.setPriors/1","doc":"","ref":"Evision.ML.DTrees.html#setPriors/1"},{"type":"function","title":"Evision.ML.DTrees.setPriors/2","doc":"setPriors\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n- **val**: `Evision.Mat`\n\n@see `getPriors/1`\n\nPython prototype (for reference only):\n```python3\nsetPriors(val) -> None\n```","ref":"Evision.ML.DTrees.html#setPriors/2"},{"type":"function","title":"Evision.ML.DTrees.setRegressionAccuracy/1","doc":"","ref":"Evision.ML.DTrees.html#setRegressionAccuracy/1"},{"type":"function","title":"Evision.ML.DTrees.setRegressionAccuracy/2","doc":"setRegressionAccuracy\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n- **val**: `float`\n\n@see `getRegressionAccuracy/1`\n\nPython prototype (for reference only):\n```python3\nsetRegressionAccuracy(val) -> None\n```","ref":"Evision.ML.DTrees.html#setRegressionAccuracy/2"},{"type":"function","title":"Evision.ML.DTrees.setTruncatePrunedTree/1","doc":"","ref":"Evision.ML.DTrees.html#setTruncatePrunedTree/1"},{"type":"function","title":"Evision.ML.DTrees.setTruncatePrunedTree/2","doc":"setTruncatePrunedTree\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n- **val**: `bool`\n\n@see `getTruncatePrunedTree/1`\n\nPython prototype (for reference only):\n```python3\nsetTruncatePrunedTree(val) -> None\n```","ref":"Evision.ML.DTrees.html#setTruncatePrunedTree/2"},{"type":"function","title":"Evision.ML.DTrees.setUse1SERule/1","doc":"","ref":"Evision.ML.DTrees.html#setUse1SERule/1"},{"type":"function","title":"Evision.ML.DTrees.setUse1SERule/2","doc":"setUse1SERule\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n- **val**: `bool`\n\n@see `getUse1SERule/1`\n\nPython prototype (for reference only):\n```python3\nsetUse1SERule(val) -> None\n```","ref":"Evision.ML.DTrees.html#setUse1SERule/2"},{"type":"function","title":"Evision.ML.DTrees.setUseSurrogates/1","doc":"","ref":"Evision.ML.DTrees.html#setUseSurrogates/1"},{"type":"function","title":"Evision.ML.DTrees.setUseSurrogates/2","doc":"setUseSurrogates\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n- **val**: `bool`\n\n@see `getUseSurrogates/1`\n\nPython prototype (for reference only):\n```python3\nsetUseSurrogates(val) -> None\n```","ref":"Evision.ML.DTrees.html#setUseSurrogates/2"},{"type":"function","title":"Evision.ML.DTrees.train/1","doc":"","ref":"Evision.ML.DTrees.html#train/1"},{"type":"function","title":"Evision.ML.DTrees.train/2","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n- **trainData**: `Evision.ML.TrainData.t()`.\n\n  training data that can be loaded from file using TrainData::loadFromCSV or\n  created with TrainData::create.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  optional flags, depending on the model. Some of the models can be updated with the\n  new training samples, not completely overwritten (such as NormalBayesClassifier or ANN_MLP).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(trainData[, flags]) -> retval\n```","ref":"Evision.ML.DTrees.html#train/2"},{"type":"function","title":"Evision.ML.DTrees.train/3","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n- **trainData**: `Evision.ML.TrainData.t()`.\n\n  training data that can be loaded from file using TrainData::loadFromCSV or\n  created with TrainData::create.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  optional flags, depending on the model. Some of the models can be updated with the\n  new training samples, not completely overwritten (such as NormalBayesClassifier or ANN_MLP).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(trainData[, flags]) -> retval\n```","ref":"Evision.ML.DTrees.html#train/3"},{"type":"function","title":"Evision.ML.DTrees.train/4","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n- **samples**: `Evision.Mat`.\n\n  training samples\n\n- **layout**: `integer()`.\n\n  See ml::SampleTypes.\n\n- **responses**: `Evision.Mat`.\n\n  vector of responses associated with the training samples.\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(samples, layout, responses) -> retval\n```","ref":"Evision.ML.DTrees.html#train/4"},{"type":"function","title":"Evision.ML.DTrees.write/1","doc":"","ref":"Evision.ML.DTrees.html#write/1"},{"type":"function","title":"Evision.ML.DTrees.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.ML.DTrees.html#write/2"},{"type":"function","title":"Evision.ML.DTrees.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.ML.DTrees.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.ML.DTrees.html#write/3"},{"type":"type","title":"Evision.ML.DTrees.t/0","doc":"Type that represents an `ML.DTrees` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ML.DTrees.html#t:t/0"},{"type":"module","title":"Evision.ML.DTrees.Flags","doc":"","ref":"Evision.ML.DTrees.Flags.html"},{"type":"function","title":"Evision.ML.DTrees.Flags.cv_PREDICT_AUTO/0","doc":"","ref":"Evision.ML.DTrees.Flags.html#cv_PREDICT_AUTO/0"},{"type":"function","title":"Evision.ML.DTrees.Flags.cv_PREDICT_MASK/0","doc":"","ref":"Evision.ML.DTrees.Flags.html#cv_PREDICT_MASK/0"},{"type":"function","title":"Evision.ML.DTrees.Flags.cv_PREDICT_MAX_VOTE/0","doc":"","ref":"Evision.ML.DTrees.Flags.html#cv_PREDICT_MAX_VOTE/0"},{"type":"function","title":"Evision.ML.DTrees.Flags.cv_PREDICT_SUM/0","doc":"","ref":"Evision.ML.DTrees.Flags.html#cv_PREDICT_SUM/0"},{"type":"type","title":"Evision.ML.DTrees.Flags.enum/0","doc":"","ref":"Evision.ML.DTrees.Flags.html#t:enum/0"},{"type":"module","title":"Evision.ML.EM","doc":"","ref":"Evision.ML.EM.html"},{"type":"function","title":"Evision.ML.EM.calcError/1","doc":"","ref":"Evision.ML.EM.html#calcError/1"},{"type":"function","title":"Evision.ML.EM.calcError/3","doc":"Computes error on the training or test dataset\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n- **data**: `Evision.ML.TrainData.t()`.\n\n  the training data\n\n- **test**: `bool`.\n\n  if true, the error is computed over the test subset of the data, otherwise it's\n  computed over the training subset of the data. Please note that if you loaded a completely\n  different dataset to evaluate already trained classifier, you will probably want not to set\n  the test subset at all with TrainData::setTrainTestSplitRatio and specify test=false, so\n  that the error is computed for the whole new set. Yes, this sounds a bit confusing.\n\n##### Return\n- **retval**: `float`\n- **resp**: `Evision.Mat.t()`.\n\n  the optional output responses.\n\nThe method uses StatModel::predict to compute the error. For regression models the error is\ncomputed as RMS, for classifiers - as a percent of missclassified samples (0%-100%).\n\nPython prototype (for reference only):\n```python3\ncalcError(data, test[, resp]) -> retval, resp\n```","ref":"Evision.ML.EM.html#calcError/3"},{"type":"function","title":"Evision.ML.EM.calcError/4","doc":"Computes error on the training or test dataset\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n- **data**: `Evision.ML.TrainData.t()`.\n\n  the training data\n\n- **test**: `bool`.\n\n  if true, the error is computed over the test subset of the data, otherwise it's\n  computed over the training subset of the data. Please note that if you loaded a completely\n  different dataset to evaluate already trained classifier, you will probably want not to set\n  the test subset at all with TrainData::setTrainTestSplitRatio and specify test=false, so\n  that the error is computed for the whole new set. Yes, this sounds a bit confusing.\n\n##### Return\n- **retval**: `float`\n- **resp**: `Evision.Mat.t()`.\n\n  the optional output responses.\n\nThe method uses StatModel::predict to compute the error. For regression models the error is\ncomputed as RMS, for classifiers - as a percent of missclassified samples (0%-100%).\n\nPython prototype (for reference only):\n```python3\ncalcError(data, test[, resp]) -> retval, resp\n```","ref":"Evision.ML.EM.html#calcError/4"},{"type":"function","title":"Evision.ML.EM.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.ML.EM.html#clear/1"},{"type":"function","title":"Evision.ML.EM.create/0","doc":"create\n##### Return\n- **retval**: `Evision.ML.EM.t()`\n\nCreates empty %EM model.\nThe model should be trained then using StatModel::train(traindata, flags) method. Alternatively, you\ncan use one of the EM::train\\* methods or load it from file using Algorithm::load\\ (filename).\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.ML.EM.html#create/0"},{"type":"function","title":"Evision.ML.EM.create/1","doc":"","ref":"Evision.ML.EM.html#create/1"},{"type":"function","title":"Evision.ML.EM.cv_DEFAULT_MAX_ITERS/0","doc":"","ref":"Evision.ML.EM.html#cv_DEFAULT_MAX_ITERS/0"},{"type":"function","title":"Evision.ML.EM.cv_DEFAULT_NCLUSTERS/0","doc":"","ref":"Evision.ML.EM.html#cv_DEFAULT_NCLUSTERS/0"},{"type":"function","title":"Evision.ML.EM.cv_START_AUTO_STEP/0","doc":"","ref":"Evision.ML.EM.html#cv_START_AUTO_STEP/0"},{"type":"function","title":"Evision.ML.EM.cv_START_E_STEP/0","doc":"","ref":"Evision.ML.EM.html#cv_START_E_STEP/0"},{"type":"function","title":"Evision.ML.EM.cv_START_M_STEP/0","doc":"","ref":"Evision.ML.EM.html#cv_START_M_STEP/0"},{"type":"function","title":"Evision.ML.EM.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.ML.EM.html#empty/1"},{"type":"function","title":"Evision.ML.EM.getClustersNumber/1","doc":"getClustersNumber\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setClustersNumber/2`\n\nPython prototype (for reference only):\n```python3\ngetClustersNumber() -> retval\n```","ref":"Evision.ML.EM.html#getClustersNumber/1"},{"type":"function","title":"Evision.ML.EM.getCovarianceMatrixType/1","doc":"getCovarianceMatrixType\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setCovarianceMatrixType/2`\n\nPython prototype (for reference only):\n```python3\ngetCovarianceMatrixType() -> retval\n```","ref":"Evision.ML.EM.html#getCovarianceMatrixType/1"},{"type":"function","title":"Evision.ML.EM.getCovs/1","doc":"Returns covariation matrices\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n\n##### Return\n- **covs**: `[Evision.Mat]`.\n\nReturns vector of covariation matrices. Number of matrices is the number of gaussian mixtures,\neach matrix is a square floating-point matrix NxN, where N is the space dimensionality.\n\nPython prototype (for reference only):\n```python3\ngetCovs([, covs]) -> covs\n```","ref":"Evision.ML.EM.html#getCovs/1"},{"type":"function","title":"Evision.ML.EM.getCovs/2","doc":"Returns covariation matrices\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n\n##### Return\n- **covs**: `[Evision.Mat]`.\n\nReturns vector of covariation matrices. Number of matrices is the number of gaussian mixtures,\neach matrix is a square floating-point matrix NxN, where N is the space dimensionality.\n\nPython prototype (for reference only):\n```python3\ngetCovs([, covs]) -> covs\n```","ref":"Evision.ML.EM.html#getCovs/2"},{"type":"function","title":"Evision.ML.EM.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.ML.EM.html#getDefaultName/1"},{"type":"function","title":"Evision.ML.EM.getMeans/1","doc":"Returns the cluster centers (means of the Gaussian mixture)\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nReturns matrix with the number of rows equal to the number of mixtures and number of columns\nequal to the space dimensionality.\n\nPython prototype (for reference only):\n```python3\ngetMeans() -> retval\n```","ref":"Evision.ML.EM.html#getMeans/1"},{"type":"function","title":"Evision.ML.EM.getTermCriteria/1","doc":"getTermCriteria\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n\n##### Return\n- **retval**: `TermCriteria`\n\n@see `setTermCriteria/2`\n\nPython prototype (for reference only):\n```python3\ngetTermCriteria() -> retval\n```","ref":"Evision.ML.EM.html#getTermCriteria/1"},{"type":"function","title":"Evision.ML.EM.getVarCount/1","doc":"Returns the number of variables in training samples\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetVarCount() -> retval\n```","ref":"Evision.ML.EM.html#getVarCount/1"},{"type":"function","title":"Evision.ML.EM.getWeights/1","doc":"Returns weights of the mixtures\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nReturns vector with the number of elements equal to the number of mixtures.\n\nPython prototype (for reference only):\n```python3\ngetWeights() -> retval\n```","ref":"Evision.ML.EM.html#getWeights/1"},{"type":"function","title":"Evision.ML.EM.isClassifier/1","doc":"Returns true if the model is classifier\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisClassifier() -> retval\n```","ref":"Evision.ML.EM.html#isClassifier/1"},{"type":"function","title":"Evision.ML.EM.isTrained/1","doc":"Returns true if the model is trained\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisTrained() -> retval\n```","ref":"Evision.ML.EM.html#isTrained/1"},{"type":"function","title":"Evision.ML.EM.load/1","doc":"Loads and creates a serialized EM from a file\n\n##### Positional Arguments\n- **filepath**: `String`.\n\n  path to serialized EM\n\n##### Keyword Arguments\n- **nodeName**: `String`.\n\n  name of node containing the classifier\n\n##### Return\n- **retval**: `Evision.ML.EM.t()`\n\n Use EM::save to serialize and store an EM to disk.\n Load the EM from this file again, by calling this function with the path to the file.\n Optionally specify the node for the file containing the classifier\n\nPython prototype (for reference only):\n```python3\nload(filepath[, nodeName]) -> retval\n```","ref":"Evision.ML.EM.html#load/1"},{"type":"function","title":"Evision.ML.EM.load/2","doc":"Loads and creates a serialized EM from a file\n\n##### Positional Arguments\n- **filepath**: `String`.\n\n  path to serialized EM\n\n##### Keyword Arguments\n- **nodeName**: `String`.\n\n  name of node containing the classifier\n\n##### Return\n- **retval**: `Evision.ML.EM.t()`\n\n Use EM::save to serialize and store an EM to disk.\n Load the EM from this file again, by calling this function with the path to the file.\n Optionally specify the node for the file containing the classifier\n\nPython prototype (for reference only):\n```python3\nload(filepath[, nodeName]) -> retval\n```","ref":"Evision.ML.EM.html#load/2"},{"type":"function","title":"Evision.ML.EM.predict2/1","doc":"","ref":"Evision.ML.EM.html#predict2/1"},{"type":"function","title":"Evision.ML.EM.predict2/2","doc":"Returns a likelihood logarithm value and an index of the most probable mixture component\nfor the given sample.\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n- **sample**: `Evision.Mat`.\n\n  A sample for classification. It should be a one-channel matrix of\n  \\f$1 \\times dims\\f$ or \\f$dims \\times 1\\f$ size.\n\n##### Return\n- **retval**: `Vec2d`\n- **probs**: `Evision.Mat.t()`.\n\n  Optional output matrix that contains posterior probabilities of each component\n  given the sample. It has \\f$1 \\times nclusters\\f$ size and CV_64FC1 type.\n\nThe method returns a two-element double vector. Zero element is a likelihood logarithm value for\nthe sample. First element is an index of the most probable mixture component for the given\nsample.\n\nPython prototype (for reference only):\n```python3\npredict2(sample[, probs]) -> retval, probs\n```","ref":"Evision.ML.EM.html#predict2/2"},{"type":"function","title":"Evision.ML.EM.predict2/3","doc":"Returns a likelihood logarithm value and an index of the most probable mixture component\nfor the given sample.\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n- **sample**: `Evision.Mat`.\n\n  A sample for classification. It should be a one-channel matrix of\n  \\f$1 \\times dims\\f$ or \\f$dims \\times 1\\f$ size.\n\n##### Return\n- **retval**: `Vec2d`\n- **probs**: `Evision.Mat.t()`.\n\n  Optional output matrix that contains posterior probabilities of each component\n  given the sample. It has \\f$1 \\times nclusters\\f$ size and CV_64FC1 type.\n\nThe method returns a two-element double vector. Zero element is a likelihood logarithm value for\nthe sample. First element is an index of the most probable mixture component for the given\nsample.\n\nPython prototype (for reference only):\n```python3\npredict2(sample[, probs]) -> retval, probs\n```","ref":"Evision.ML.EM.html#predict2/3"},{"type":"function","title":"Evision.ML.EM.predict/1","doc":"","ref":"Evision.ML.EM.html#predict/1"},{"type":"function","title":"Evision.ML.EM.predict/2","doc":"Returns posterior probabilities for the provided samples\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n- **samples**: `Evision.Mat`.\n\n  The input samples, floating-point matrix\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  This parameter will be ignored\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  The optional output \\f$ nSamples \\times nClusters\\f$ matrix of results. It contains\n  posterior probabilities for each sample from the input\n\nPython prototype (for reference only):\n```python3\npredict(samples[, results[, flags]]) -> retval, results\n```","ref":"Evision.ML.EM.html#predict/2"},{"type":"function","title":"Evision.ML.EM.predict/3","doc":"Returns posterior probabilities for the provided samples\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n- **samples**: `Evision.Mat`.\n\n  The input samples, floating-point matrix\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  This parameter will be ignored\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  The optional output \\f$ nSamples \\times nClusters\\f$ matrix of results. It contains\n  posterior probabilities for each sample from the input\n\nPython prototype (for reference only):\n```python3\npredict(samples[, results[, flags]]) -> retval, results\n```","ref":"Evision.ML.EM.html#predict/3"},{"type":"function","title":"Evision.ML.EM.read/1","doc":"","ref":"Evision.ML.EM.html#read/1"},{"type":"function","title":"Evision.ML.EM.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.ML.EM.html#read/2"},{"type":"function","title":"Evision.ML.EM.save/1","doc":"","ref":"Evision.ML.EM.html#save/1"},{"type":"function","title":"Evision.ML.EM.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.ML.EM.html#save/2"},{"type":"function","title":"Evision.ML.EM.setClustersNumber/1","doc":"","ref":"Evision.ML.EM.html#setClustersNumber/1"},{"type":"function","title":"Evision.ML.EM.setClustersNumber/2","doc":"setClustersNumber\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n- **val**: `integer()`\n\n@see `getClustersNumber/1`\n\nPython prototype (for reference only):\n```python3\nsetClustersNumber(val) -> None\n```","ref":"Evision.ML.EM.html#setClustersNumber/2"},{"type":"function","title":"Evision.ML.EM.setCovarianceMatrixType/1","doc":"","ref":"Evision.ML.EM.html#setCovarianceMatrixType/1"},{"type":"function","title":"Evision.ML.EM.setCovarianceMatrixType/2","doc":"setCovarianceMatrixType\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n- **val**: `integer()`\n\n@see `getCovarianceMatrixType/1`\n\nPython prototype (for reference only):\n```python3\nsetCovarianceMatrixType(val) -> None\n```","ref":"Evision.ML.EM.html#setCovarianceMatrixType/2"},{"type":"function","title":"Evision.ML.EM.setTermCriteria/1","doc":"","ref":"Evision.ML.EM.html#setTermCriteria/1"},{"type":"function","title":"Evision.ML.EM.setTermCriteria/2","doc":"setTermCriteria\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n- **val**: `TermCriteria`\n\n@see `getTermCriteria/1`\n\nPython prototype (for reference only):\n```python3\nsetTermCriteria(val) -> None\n```","ref":"Evision.ML.EM.html#setTermCriteria/2"},{"type":"function","title":"Evision.ML.EM.train/1","doc":"","ref":"Evision.ML.EM.html#train/1"},{"type":"function","title":"Evision.ML.EM.train/2","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n- **trainData**: `Evision.ML.TrainData.t()`.\n\n  training data that can be loaded from file using TrainData::loadFromCSV or\n  created with TrainData::create.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  optional flags, depending on the model. Some of the models can be updated with the\n  new training samples, not completely overwritten (such as NormalBayesClassifier or ANN_MLP).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(trainData[, flags]) -> retval\n```","ref":"Evision.ML.EM.html#train/2"},{"type":"function","title":"Evision.ML.EM.train/3","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n- **trainData**: `Evision.ML.TrainData.t()`.\n\n  training data that can be loaded from file using TrainData::loadFromCSV or\n  created with TrainData::create.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  optional flags, depending on the model. Some of the models can be updated with the\n  new training samples, not completely overwritten (such as NormalBayesClassifier or ANN_MLP).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(trainData[, flags]) -> retval\n```","ref":"Evision.ML.EM.html#train/3"},{"type":"function","title":"Evision.ML.EM.train/4","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n- **samples**: `Evision.Mat`.\n\n  training samples\n\n- **layout**: `integer()`.\n\n  See ml::SampleTypes.\n\n- **responses**: `Evision.Mat`.\n\n  vector of responses associated with the training samples.\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(samples, layout, responses) -> retval\n```","ref":"Evision.ML.EM.html#train/4"},{"type":"function","title":"Evision.ML.EM.trainE/1","doc":"","ref":"Evision.ML.EM.html#trainE/1"},{"type":"function","title":"Evision.ML.EM.trainE/3","doc":"Estimate the Gaussian mixture parameters from a samples set.\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n- **samples**: `Evision.Mat`.\n\n  Samples from which the Gaussian mixture model will be estimated. It should be a\n  one-channel matrix, each row of which is a sample. If the matrix does not have CV_64F type\n  it will be converted to the inner matrix of such type for the further computing.\n\n- **means0**: `Evision.Mat`.\n\n  Initial means \\f$a_k\\f$ of mixture components. It is a one-channel matrix of\n  \\f$nclusters \\times dims\\f$ size. If the matrix does not have CV_64F type it will be\n  converted to the inner matrix of such type for the further computing.\n\n##### Keyword Arguments\n- **covs0**: `Evision.Mat`.\n\n  The vector of initial covariance matrices \\f$S_k\\f$ of mixture components. Each of\n  covariance matrices is a one-channel matrix of \\f$dims \\times dims\\f$ size. If the matrices\n  do not have CV_64F type they will be converted to the inner matrices of such type for the\n  further computing.\n\n- **weights0**: `Evision.Mat`.\n\n  Initial weights \\f$\\pi_k\\f$ of mixture components. It should be a one-channel\n  floating-point matrix with \\f$1 \\times nclusters\\f$ or \\f$nclusters \\times 1\\f$ size.\n\n##### Return\n- **retval**: `bool`\n- **logLikelihoods**: `Evision.Mat.t()`.\n\n  The optional output matrix that contains a likelihood logarithm value for\n  each sample. It has \\f$nsamples \\times 1\\f$ size and CV_64FC1 type.\n\n- **labels**: `Evision.Mat.t()`.\n\n  The optional output \"class label\" for each sample:\n  \\f$\\texttt{labels}_i=\\texttt{arg max}_k(p_{i,k}), i=1..N\\f$ (indices of the most probable\n  mixture component for each sample). It has \\f$nsamples \\times 1\\f$ size and CV_32SC1 type.\n\n- **probs**: `Evision.Mat.t()`.\n\n  The optional output matrix that contains posterior probabilities of each Gaussian\n  mixture component given the each sample. It has \\f$nsamples \\times nclusters\\f$ size and\n  CV_64FC1 type.\n\nThis variation starts with Expectation step. You need to provide initial means \\f$a\\_k\\f$ of\nmixture components. Optionally you can pass initial weights \\f$\\pi\\_k\\f$ and covariance matrices\n\\f$S\\_k\\f$ of mixture components.\n\nPython prototype (for reference only):\n```python3\ntrainE(samples, means0[, covs0[, weights0[, logLikelihoods[, labels[, probs]]]]]) -> retval, logLikelihoods, labels, probs\n```","ref":"Evision.ML.EM.html#trainE/3"},{"type":"function","title":"Evision.ML.EM.trainE/4","doc":"Estimate the Gaussian mixture parameters from a samples set.\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n- **samples**: `Evision.Mat`.\n\n  Samples from which the Gaussian mixture model will be estimated. It should be a\n  one-channel matrix, each row of which is a sample. If the matrix does not have CV_64F type\n  it will be converted to the inner matrix of such type for the further computing.\n\n- **means0**: `Evision.Mat`.\n\n  Initial means \\f$a_k\\f$ of mixture components. It is a one-channel matrix of\n  \\f$nclusters \\times dims\\f$ size. If the matrix does not have CV_64F type it will be\n  converted to the inner matrix of such type for the further computing.\n\n##### Keyword Arguments\n- **covs0**: `Evision.Mat`.\n\n  The vector of initial covariance matrices \\f$S_k\\f$ of mixture components. Each of\n  covariance matrices is a one-channel matrix of \\f$dims \\times dims\\f$ size. If the matrices\n  do not have CV_64F type they will be converted to the inner matrices of such type for the\n  further computing.\n\n- **weights0**: `Evision.Mat`.\n\n  Initial weights \\f$\\pi_k\\f$ of mixture components. It should be a one-channel\n  floating-point matrix with \\f$1 \\times nclusters\\f$ or \\f$nclusters \\times 1\\f$ size.\n\n##### Return\n- **retval**: `bool`\n- **logLikelihoods**: `Evision.Mat.t()`.\n\n  The optional output matrix that contains a likelihood logarithm value for\n  each sample. It has \\f$nsamples \\times 1\\f$ size and CV_64FC1 type.\n\n- **labels**: `Evision.Mat.t()`.\n\n  The optional output \"class label\" for each sample:\n  \\f$\\texttt{labels}_i=\\texttt{arg max}_k(p_{i,k}), i=1..N\\f$ (indices of the most probable\n  mixture component for each sample). It has \\f$nsamples \\times 1\\f$ size and CV_32SC1 type.\n\n- **probs**: `Evision.Mat.t()`.\n\n  The optional output matrix that contains posterior probabilities of each Gaussian\n  mixture component given the each sample. It has \\f$nsamples \\times nclusters\\f$ size and\n  CV_64FC1 type.\n\nThis variation starts with Expectation step. You need to provide initial means \\f$a\\_k\\f$ of\nmixture components. Optionally you can pass initial weights \\f$\\pi\\_k\\f$ and covariance matrices\n\\f$S\\_k\\f$ of mixture components.\n\nPython prototype (for reference only):\n```python3\ntrainE(samples, means0[, covs0[, weights0[, logLikelihoods[, labels[, probs]]]]]) -> retval, logLikelihoods, labels, probs\n```","ref":"Evision.ML.EM.html#trainE/4"},{"type":"function","title":"Evision.ML.EM.trainEM/1","doc":"","ref":"Evision.ML.EM.html#trainEM/1"},{"type":"function","title":"Evision.ML.EM.trainEM/2","doc":"Estimate the Gaussian mixture parameters from a samples set.\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n- **samples**: `Evision.Mat`.\n\n  Samples from which the Gaussian mixture model will be estimated. It should be a\n  one-channel matrix, each row of which is a sample. If the matrix does not have CV_64F type\n  it will be converted to the inner matrix of such type for the further computing.\n\n##### Return\n- **retval**: `bool`\n- **logLikelihoods**: `Evision.Mat.t()`.\n\n  The optional output matrix that contains a likelihood logarithm value for\n  each sample. It has \\f$nsamples \\times 1\\f$ size and CV_64FC1 type.\n\n- **labels**: `Evision.Mat.t()`.\n\n  The optional output \"class label\" for each sample:\n  \\f$\\texttt{labels}_i=\\texttt{arg max}_k(p_{i,k}), i=1..N\\f$ (indices of the most probable\n  mixture component for each sample). It has \\f$nsamples \\times 1\\f$ size and CV_32SC1 type.\n\n- **probs**: `Evision.Mat.t()`.\n\n  The optional output matrix that contains posterior probabilities of each Gaussian\n  mixture component given the each sample. It has \\f$nsamples \\times nclusters\\f$ size and\n  CV_64FC1 type.\n\nThis variation starts with Expectation step. Initial values of the model parameters will be\nestimated by the k-means algorithm.\nUnlike many of the ML models, %EM is an unsupervised learning algorithm and it does not take\nresponses (class labels or function values) as input. Instead, it computes the *Maximum\nLikelihood Estimate* of the Gaussian mixture parameters from an input sample set, stores all the\nparameters inside the structure: \\f$p\\_{i,k}\\f$ in probs, \\f$a\\_k\\f$ in means , \\f$S\\_k\\f$ in\ncovs[k], \\f$\\pi\\_k\\f$ in weights , and optionally computes the output \"class label\" for each\nsample: \\f$\\texttt{labels}\\_i=\\texttt{arg max}\\_k(p\\_{i,k}), i=1..N\\f$ (indices of the most\nprobable mixture component for each sample).\nThe trained model can be used further for prediction, just like any other classifier. The\ntrained model is similar to the NormalBayesClassifier.\n\nPython prototype (for reference only):\n```python3\ntrainEM(samples[, logLikelihoods[, labels[, probs]]]) -> retval, logLikelihoods, labels, probs\n```","ref":"Evision.ML.EM.html#trainEM/2"},{"type":"function","title":"Evision.ML.EM.trainEM/3","doc":"Estimate the Gaussian mixture parameters from a samples set.\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n- **samples**: `Evision.Mat`.\n\n  Samples from which the Gaussian mixture model will be estimated. It should be a\n  one-channel matrix, each row of which is a sample. If the matrix does not have CV_64F type\n  it will be converted to the inner matrix of such type for the further computing.\n\n##### Return\n- **retval**: `bool`\n- **logLikelihoods**: `Evision.Mat.t()`.\n\n  The optional output matrix that contains a likelihood logarithm value for\n  each sample. It has \\f$nsamples \\times 1\\f$ size and CV_64FC1 type.\n\n- **labels**: `Evision.Mat.t()`.\n\n  The optional output \"class label\" for each sample:\n  \\f$\\texttt{labels}_i=\\texttt{arg max}_k(p_{i,k}), i=1..N\\f$ (indices of the most probable\n  mixture component for each sample). It has \\f$nsamples \\times 1\\f$ size and CV_32SC1 type.\n\n- **probs**: `Evision.Mat.t()`.\n\n  The optional output matrix that contains posterior probabilities of each Gaussian\n  mixture component given the each sample. It has \\f$nsamples \\times nclusters\\f$ size and\n  CV_64FC1 type.\n\nThis variation starts with Expectation step. Initial values of the model parameters will be\nestimated by the k-means algorithm.\nUnlike many of the ML models, %EM is an unsupervised learning algorithm and it does not take\nresponses (class labels or function values) as input. Instead, it computes the *Maximum\nLikelihood Estimate* of the Gaussian mixture parameters from an input sample set, stores all the\nparameters inside the structure: \\f$p\\_{i,k}\\f$ in probs, \\f$a\\_k\\f$ in means , \\f$S\\_k\\f$ in\ncovs[k], \\f$\\pi\\_k\\f$ in weights , and optionally computes the output \"class label\" for each\nsample: \\f$\\texttt{labels}\\_i=\\texttt{arg max}\\_k(p\\_{i,k}), i=1..N\\f$ (indices of the most\nprobable mixture component for each sample).\nThe trained model can be used further for prediction, just like any other classifier. The\ntrained model is similar to the NormalBayesClassifier.\n\nPython prototype (for reference only):\n```python3\ntrainEM(samples[, logLikelihoods[, labels[, probs]]]) -> retval, logLikelihoods, labels, probs\n```","ref":"Evision.ML.EM.html#trainEM/3"},{"type":"function","title":"Evision.ML.EM.trainM/1","doc":"","ref":"Evision.ML.EM.html#trainM/1"},{"type":"function","title":"Evision.ML.EM.trainM/3","doc":"Estimate the Gaussian mixture parameters from a samples set.\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n- **samples**: `Evision.Mat`.\n\n  Samples from which the Gaussian mixture model will be estimated. It should be a\n  one-channel matrix, each row of which is a sample. If the matrix does not have CV_64F type\n  it will be converted to the inner matrix of such type for the further computing.\n\n- **probs0**: `Evision.Mat`.\n\n  the probabilities\n\n##### Return\n- **retval**: `bool`\n- **logLikelihoods**: `Evision.Mat.t()`.\n\n  The optional output matrix that contains a likelihood logarithm value for\n  each sample. It has \\f$nsamples \\times 1\\f$ size and CV_64FC1 type.\n\n- **labels**: `Evision.Mat.t()`.\n\n  The optional output \"class label\" for each sample:\n  \\f$\\texttt{labels}_i=\\texttt{arg max}_k(p_{i,k}), i=1..N\\f$ (indices of the most probable\n  mixture component for each sample). It has \\f$nsamples \\times 1\\f$ size and CV_32SC1 type.\n\n- **probs**: `Evision.Mat.t()`.\n\n  The optional output matrix that contains posterior probabilities of each Gaussian\n  mixture component given the each sample. It has \\f$nsamples \\times nclusters\\f$ size and\n  CV_64FC1 type.\n\nThis variation starts with Maximization step. You need to provide initial probabilities\n\\f$p\\_{i,k}\\f$ to use this option.\n\nPython prototype (for reference only):\n```python3\ntrainM(samples, probs0[, logLikelihoods[, labels[, probs]]]) -> retval, logLikelihoods, labels, probs\n```","ref":"Evision.ML.EM.html#trainM/3"},{"type":"function","title":"Evision.ML.EM.trainM/4","doc":"Estimate the Gaussian mixture parameters from a samples set.\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n- **samples**: `Evision.Mat`.\n\n  Samples from which the Gaussian mixture model will be estimated. It should be a\n  one-channel matrix, each row of which is a sample. If the matrix does not have CV_64F type\n  it will be converted to the inner matrix of such type for the further computing.\n\n- **probs0**: `Evision.Mat`.\n\n  the probabilities\n\n##### Return\n- **retval**: `bool`\n- **logLikelihoods**: `Evision.Mat.t()`.\n\n  The optional output matrix that contains a likelihood logarithm value for\n  each sample. It has \\f$nsamples \\times 1\\f$ size and CV_64FC1 type.\n\n- **labels**: `Evision.Mat.t()`.\n\n  The optional output \"class label\" for each sample:\n  \\f$\\texttt{labels}_i=\\texttt{arg max}_k(p_{i,k}), i=1..N\\f$ (indices of the most probable\n  mixture component for each sample). It has \\f$nsamples \\times 1\\f$ size and CV_32SC1 type.\n\n- **probs**: `Evision.Mat.t()`.\n\n  The optional output matrix that contains posterior probabilities of each Gaussian\n  mixture component given the each sample. It has \\f$nsamples \\times nclusters\\f$ size and\n  CV_64FC1 type.\n\nThis variation starts with Maximization step. You need to provide initial probabilities\n\\f$p\\_{i,k}\\f$ to use this option.\n\nPython prototype (for reference only):\n```python3\ntrainM(samples, probs0[, logLikelihoods[, labels[, probs]]]) -> retval, logLikelihoods, labels, probs\n```","ref":"Evision.ML.EM.html#trainM/4"},{"type":"function","title":"Evision.ML.EM.write/1","doc":"","ref":"Evision.ML.EM.html#write/1"},{"type":"function","title":"Evision.ML.EM.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.ML.EM.html#write/2"},{"type":"function","title":"Evision.ML.EM.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.ML.EM.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.ML.EM.html#write/3"},{"type":"type","title":"Evision.ML.EM.enum/0","doc":"","ref":"Evision.ML.EM.html#t:enum/0"},{"type":"type","title":"Evision.ML.EM.t/0","doc":"Type that represents an `ML.EM` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ML.EM.html#t:t/0"},{"type":"module","title":"Evision.ML.EM.Types","doc":"","ref":"Evision.ML.EM.Types.html"},{"type":"function","title":"Evision.ML.EM.Types.cv_COV_MAT_DEFAULT/0","doc":"","ref":"Evision.ML.EM.Types.html#cv_COV_MAT_DEFAULT/0"},{"type":"function","title":"Evision.ML.EM.Types.cv_COV_MAT_DIAGONAL/0","doc":"","ref":"Evision.ML.EM.Types.html#cv_COV_MAT_DIAGONAL/0"},{"type":"function","title":"Evision.ML.EM.Types.cv_COV_MAT_GENERIC/0","doc":"","ref":"Evision.ML.EM.Types.html#cv_COV_MAT_GENERIC/0"},{"type":"function","title":"Evision.ML.EM.Types.cv_COV_MAT_SPHERICAL/0","doc":"","ref":"Evision.ML.EM.Types.html#cv_COV_MAT_SPHERICAL/0"},{"type":"type","title":"Evision.ML.EM.Types.enum/0","doc":"","ref":"Evision.ML.EM.Types.html#t:enum/0"},{"type":"module","title":"Evision.ML.ErrorTypes","doc":"","ref":"Evision.ML.ErrorTypes.html"},{"type":"function","title":"Evision.ML.ErrorTypes.cv_TEST_ERROR/0","doc":"","ref":"Evision.ML.ErrorTypes.html#cv_TEST_ERROR/0"},{"type":"function","title":"Evision.ML.ErrorTypes.cv_TRAIN_ERROR/0","doc":"","ref":"Evision.ML.ErrorTypes.html#cv_TRAIN_ERROR/0"},{"type":"type","title":"Evision.ML.ErrorTypes.enum/0","doc":"","ref":"Evision.ML.ErrorTypes.html#t:enum/0"},{"type":"module","title":"Evision.ML.KNearest","doc":"","ref":"Evision.ML.KNearest.html"},{"type":"function","title":"Evision.ML.KNearest.calcError/1","doc":"","ref":"Evision.ML.KNearest.html#calcError/1"},{"type":"function","title":"Evision.ML.KNearest.calcError/3","doc":"Computes error on the training or test dataset\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n- **data**: `Evision.ML.TrainData.t()`.\n\n  the training data\n\n- **test**: `bool`.\n\n  if true, the error is computed over the test subset of the data, otherwise it's\n  computed over the training subset of the data. Please note that if you loaded a completely\n  different dataset to evaluate already trained classifier, you will probably want not to set\n  the test subset at all with TrainData::setTrainTestSplitRatio and specify test=false, so\n  that the error is computed for the whole new set. Yes, this sounds a bit confusing.\n\n##### Return\n- **retval**: `float`\n- **resp**: `Evision.Mat.t()`.\n\n  the optional output responses.\n\nThe method uses StatModel::predict to compute the error. For regression models the error is\ncomputed as RMS, for classifiers - as a percent of missclassified samples (0%-100%).\n\nPython prototype (for reference only):\n```python3\ncalcError(data, test[, resp]) -> retval, resp\n```","ref":"Evision.ML.KNearest.html#calcError/3"},{"type":"function","title":"Evision.ML.KNearest.calcError/4","doc":"Computes error on the training or test dataset\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n- **data**: `Evision.ML.TrainData.t()`.\n\n  the training data\n\n- **test**: `bool`.\n\n  if true, the error is computed over the test subset of the data, otherwise it's\n  computed over the training subset of the data. Please note that if you loaded a completely\n  different dataset to evaluate already trained classifier, you will probably want not to set\n  the test subset at all with TrainData::setTrainTestSplitRatio and specify test=false, so\n  that the error is computed for the whole new set. Yes, this sounds a bit confusing.\n\n##### Return\n- **retval**: `float`\n- **resp**: `Evision.Mat.t()`.\n\n  the optional output responses.\n\nThe method uses StatModel::predict to compute the error. For regression models the error is\ncomputed as RMS, for classifiers - as a percent of missclassified samples (0%-100%).\n\nPython prototype (for reference only):\n```python3\ncalcError(data, test[, resp]) -> retval, resp\n```","ref":"Evision.ML.KNearest.html#calcError/4"},{"type":"function","title":"Evision.ML.KNearest.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.ML.KNearest.html#clear/1"},{"type":"function","title":"Evision.ML.KNearest.create/0","doc":"Creates the empty model\n##### Return\n- **retval**: `Evision.ML.KNearest.t()`\n\nThe static method creates empty %KNearest classifier. It should be then trained using StatModel::train method.\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.ML.KNearest.html#create/0"},{"type":"function","title":"Evision.ML.KNearest.create/1","doc":"","ref":"Evision.ML.KNearest.html#create/1"},{"type":"function","title":"Evision.ML.KNearest.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.ML.KNearest.html#empty/1"},{"type":"function","title":"Evision.ML.KNearest.findNearest/1","doc":"","ref":"Evision.ML.KNearest.html#findNearest/1"},{"type":"function","title":"Evision.ML.KNearest.findNearest/3","doc":"Finds the neighbors and predicts responses for input vectors.\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n- **samples**: `Evision.Mat`.\n\n  Input samples stored by rows. It is a single-precision floating-point matrix of\n  `  * k` size.\n\n- **k**: `integer()`.\n\n  Number of used nearest neighbors. Should be greater than 1.\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  Vector with results of prediction (regression or classification) for each input\n  sample. It is a single-precision floating-point vector with ` ` elements.\n\n- **neighborResponses**: `Evision.Mat.t()`.\n\n  Optional output values for corresponding neighbors. It is a single-\n  precision floating-point matrix of `  * k` size.\n\n- **dist**: `Evision.Mat.t()`.\n\n  Optional output distances from the input vectors to the corresponding neighbors. It\n  is a single-precision floating-point matrix of `  * k` size.\n\nFor each input vector (a row of the matrix samples), the method finds the k nearest neighbors.\nIn case of regression, the predicted result is a mean value of the particular vector's neighbor\nresponses. In case of classification, the class is determined by voting.\nFor each input vector, the neighbors are sorted by their distances to the vector.\nIn case of C++ interface you can use output pointers to empty matrices and the function will\nallocate memory itself.\nIf only a single input vector is passed, all output matrices are optional and the predicted\nvalue is returned by the method.\nThe function is parallelized with the TBB library.\n\nPython prototype (for reference only):\n```python3\nfindNearest(samples, k[, results[, neighborResponses[, dist]]]) -> retval, results, neighborResponses, dist\n```","ref":"Evision.ML.KNearest.html#findNearest/3"},{"type":"function","title":"Evision.ML.KNearest.findNearest/4","doc":"Finds the neighbors and predicts responses for input vectors.\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n- **samples**: `Evision.Mat`.\n\n  Input samples stored by rows. It is a single-precision floating-point matrix of\n  `  * k` size.\n\n- **k**: `integer()`.\n\n  Number of used nearest neighbors. Should be greater than 1.\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  Vector with results of prediction (regression or classification) for each input\n  sample. It is a single-precision floating-point vector with ` ` elements.\n\n- **neighborResponses**: `Evision.Mat.t()`.\n\n  Optional output values for corresponding neighbors. It is a single-\n  precision floating-point matrix of `  * k` size.\n\n- **dist**: `Evision.Mat.t()`.\n\n  Optional output distances from the input vectors to the corresponding neighbors. It\n  is a single-precision floating-point matrix of `  * k` size.\n\nFor each input vector (a row of the matrix samples), the method finds the k nearest neighbors.\nIn case of regression, the predicted result is a mean value of the particular vector's neighbor\nresponses. In case of classification, the class is determined by voting.\nFor each input vector, the neighbors are sorted by their distances to the vector.\nIn case of C++ interface you can use output pointers to empty matrices and the function will\nallocate memory itself.\nIf only a single input vector is passed, all output matrices are optional and the predicted\nvalue is returned by the method.\nThe function is parallelized with the TBB library.\n\nPython prototype (for reference only):\n```python3\nfindNearest(samples, k[, results[, neighborResponses[, dist]]]) -> retval, results, neighborResponses, dist\n```","ref":"Evision.ML.KNearest.html#findNearest/4"},{"type":"function","title":"Evision.ML.KNearest.getAlgorithmType/1","doc":"getAlgorithmType\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setAlgorithmType/2`\n\nPython prototype (for reference only):\n```python3\ngetAlgorithmType() -> retval\n```","ref":"Evision.ML.KNearest.html#getAlgorithmType/1"},{"type":"function","title":"Evision.ML.KNearest.getDefaultK/1","doc":"getDefaultK\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setDefaultK/2`\n\nPython prototype (for reference only):\n```python3\ngetDefaultK() -> retval\n```","ref":"Evision.ML.KNearest.html#getDefaultK/1"},{"type":"function","title":"Evision.ML.KNearest.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.ML.KNearest.html#getDefaultName/1"},{"type":"function","title":"Evision.ML.KNearest.getEmax/1","doc":"getEmax\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setEmax/2`\n\nPython prototype (for reference only):\n```python3\ngetEmax() -> retval\n```","ref":"Evision.ML.KNearest.html#getEmax/1"},{"type":"function","title":"Evision.ML.KNearest.getIsClassifier/1","doc":"getIsClassifier\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n\n##### Return\n- **retval**: `bool`\n\n@see `setIsClassifier/2`\n\nPython prototype (for reference only):\n```python3\ngetIsClassifier() -> retval\n```","ref":"Evision.ML.KNearest.html#getIsClassifier/1"},{"type":"function","title":"Evision.ML.KNearest.getVarCount/1","doc":"Returns the number of variables in training samples\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetVarCount() -> retval\n```","ref":"Evision.ML.KNearest.html#getVarCount/1"},{"type":"function","title":"Evision.ML.KNearest.isClassifier/1","doc":"Returns true if the model is classifier\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisClassifier() -> retval\n```","ref":"Evision.ML.KNearest.html#isClassifier/1"},{"type":"function","title":"Evision.ML.KNearest.isTrained/1","doc":"Returns true if the model is trained\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisTrained() -> retval\n```","ref":"Evision.ML.KNearest.html#isTrained/1"},{"type":"function","title":"Evision.ML.KNearest.load/1","doc":"Loads and creates a serialized knearest from a file\n\n##### Positional Arguments\n- **filepath**: `String`.\n\n  path to serialized KNearest\n\n##### Return\n- **retval**: `Evision.ML.KNearest.t()`\n\n Use KNearest::save to serialize and store an KNearest to disk.\n Load the KNearest from this file again, by calling this function with the path to the file.\n\nPython prototype (for reference only):\n```python3\nload(filepath) -> retval\n```","ref":"Evision.ML.KNearest.html#load/1"},{"type":"function","title":"Evision.ML.KNearest.predict/1","doc":"","ref":"Evision.ML.KNearest.html#predict/1"},{"type":"function","title":"Evision.ML.KNearest.predict/2","doc":"Predicts response(s) for the provided sample(s)\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n- **samples**: `Evision.Mat`.\n\n  The input samples, floating-point matrix\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  The optional flags, model-dependent. See cv::ml::StatModel::Flags.\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  The optional output matrix of results.\n\nPython prototype (for reference only):\n```python3\npredict(samples[, results[, flags]]) -> retval, results\n```","ref":"Evision.ML.KNearest.html#predict/2"},{"type":"function","title":"Evision.ML.KNearest.predict/3","doc":"Predicts response(s) for the provided sample(s)\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n- **samples**: `Evision.Mat`.\n\n  The input samples, floating-point matrix\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  The optional flags, model-dependent. See cv::ml::StatModel::Flags.\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  The optional output matrix of results.\n\nPython prototype (for reference only):\n```python3\npredict(samples[, results[, flags]]) -> retval, results\n```","ref":"Evision.ML.KNearest.html#predict/3"},{"type":"function","title":"Evision.ML.KNearest.read/1","doc":"","ref":"Evision.ML.KNearest.html#read/1"},{"type":"function","title":"Evision.ML.KNearest.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.ML.KNearest.html#read/2"},{"type":"function","title":"Evision.ML.KNearest.save/1","doc":"","ref":"Evision.ML.KNearest.html#save/1"},{"type":"function","title":"Evision.ML.KNearest.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.ML.KNearest.html#save/2"},{"type":"function","title":"Evision.ML.KNearest.setAlgorithmType/1","doc":"","ref":"Evision.ML.KNearest.html#setAlgorithmType/1"},{"type":"function","title":"Evision.ML.KNearest.setAlgorithmType/2","doc":"setAlgorithmType\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n- **val**: `integer()`\n\n@see `getAlgorithmType/1`\n\nPython prototype (for reference only):\n```python3\nsetAlgorithmType(val) -> None\n```","ref":"Evision.ML.KNearest.html#setAlgorithmType/2"},{"type":"function","title":"Evision.ML.KNearest.setDefaultK/1","doc":"","ref":"Evision.ML.KNearest.html#setDefaultK/1"},{"type":"function","title":"Evision.ML.KNearest.setDefaultK/2","doc":"setDefaultK\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n- **val**: `integer()`\n\n@see `getDefaultK/1`\n\nPython prototype (for reference only):\n```python3\nsetDefaultK(val) -> None\n```","ref":"Evision.ML.KNearest.html#setDefaultK/2"},{"type":"function","title":"Evision.ML.KNearest.setEmax/1","doc":"","ref":"Evision.ML.KNearest.html#setEmax/1"},{"type":"function","title":"Evision.ML.KNearest.setEmax/2","doc":"setEmax\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n- **val**: `integer()`\n\n@see `getEmax/1`\n\nPython prototype (for reference only):\n```python3\nsetEmax(val) -> None\n```","ref":"Evision.ML.KNearest.html#setEmax/2"},{"type":"function","title":"Evision.ML.KNearest.setIsClassifier/1","doc":"","ref":"Evision.ML.KNearest.html#setIsClassifier/1"},{"type":"function","title":"Evision.ML.KNearest.setIsClassifier/2","doc":"setIsClassifier\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n- **val**: `bool`\n\n@see `getIsClassifier/1`\n\nPython prototype (for reference only):\n```python3\nsetIsClassifier(val) -> None\n```","ref":"Evision.ML.KNearest.html#setIsClassifier/2"},{"type":"function","title":"Evision.ML.KNearest.train/1","doc":"","ref":"Evision.ML.KNearest.html#train/1"},{"type":"function","title":"Evision.ML.KNearest.train/2","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n- **trainData**: `Evision.ML.TrainData.t()`.\n\n  training data that can be loaded from file using TrainData::loadFromCSV or\n  created with TrainData::create.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  optional flags, depending on the model. Some of the models can be updated with the\n  new training samples, not completely overwritten (such as NormalBayesClassifier or ANN_MLP).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(trainData[, flags]) -> retval\n```","ref":"Evision.ML.KNearest.html#train/2"},{"type":"function","title":"Evision.ML.KNearest.train/3","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n- **trainData**: `Evision.ML.TrainData.t()`.\n\n  training data that can be loaded from file using TrainData::loadFromCSV or\n  created with TrainData::create.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  optional flags, depending on the model. Some of the models can be updated with the\n  new training samples, not completely overwritten (such as NormalBayesClassifier or ANN_MLP).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(trainData[, flags]) -> retval\n```","ref":"Evision.ML.KNearest.html#train/3"},{"type":"function","title":"Evision.ML.KNearest.train/4","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n- **samples**: `Evision.Mat`.\n\n  training samples\n\n- **layout**: `integer()`.\n\n  See ml::SampleTypes.\n\n- **responses**: `Evision.Mat`.\n\n  vector of responses associated with the training samples.\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(samples, layout, responses) -> retval\n```","ref":"Evision.ML.KNearest.html#train/4"},{"type":"function","title":"Evision.ML.KNearest.write/1","doc":"","ref":"Evision.ML.KNearest.html#write/1"},{"type":"function","title":"Evision.ML.KNearest.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.ML.KNearest.html#write/2"},{"type":"function","title":"Evision.ML.KNearest.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.ML.KNearest.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.ML.KNearest.html#write/3"},{"type":"type","title":"Evision.ML.KNearest.t/0","doc":"Type that represents an `ML.KNearest` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ML.KNearest.html#t:t/0"},{"type":"module","title":"Evision.ML.KNearest.Types","doc":"","ref":"Evision.ML.KNearest.Types.html"},{"type":"function","title":"Evision.ML.KNearest.Types.cv_BRUTE_FORCE/0","doc":"","ref":"Evision.ML.KNearest.Types.html#cv_BRUTE_FORCE/0"},{"type":"function","title":"Evision.ML.KNearest.Types.cv_KDTREE/0","doc":"","ref":"Evision.ML.KNearest.Types.html#cv_KDTREE/0"},{"type":"type","title":"Evision.ML.KNearest.Types.enum/0","doc":"","ref":"Evision.ML.KNearest.Types.html#t:enum/0"},{"type":"module","title":"Evision.ML.LogisticRegression","doc":"","ref":"Evision.ML.LogisticRegression.html"},{"type":"function","title":"Evision.ML.LogisticRegression.calcError/1","doc":"","ref":"Evision.ML.LogisticRegression.html#calcError/1"},{"type":"function","title":"Evision.ML.LogisticRegression.calcError/3","doc":"Computes error on the training or test dataset\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n- **data**: `Evision.ML.TrainData.t()`.\n\n  the training data\n\n- **test**: `bool`.\n\n  if true, the error is computed over the test subset of the data, otherwise it's\n  computed over the training subset of the data. Please note that if you loaded a completely\n  different dataset to evaluate already trained classifier, you will probably want not to set\n  the test subset at all with TrainData::setTrainTestSplitRatio and specify test=false, so\n  that the error is computed for the whole new set. Yes, this sounds a bit confusing.\n\n##### Return\n- **retval**: `float`\n- **resp**: `Evision.Mat.t()`.\n\n  the optional output responses.\n\nThe method uses StatModel::predict to compute the error. For regression models the error is\ncomputed as RMS, for classifiers - as a percent of missclassified samples (0%-100%).\n\nPython prototype (for reference only):\n```python3\ncalcError(data, test[, resp]) -> retval, resp\n```","ref":"Evision.ML.LogisticRegression.html#calcError/3"},{"type":"function","title":"Evision.ML.LogisticRegression.calcError/4","doc":"Computes error on the training or test dataset\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n- **data**: `Evision.ML.TrainData.t()`.\n\n  the training data\n\n- **test**: `bool`.\n\n  if true, the error is computed over the test subset of the data, otherwise it's\n  computed over the training subset of the data. Please note that if you loaded a completely\n  different dataset to evaluate already trained classifier, you will probably want not to set\n  the test subset at all with TrainData::setTrainTestSplitRatio and specify test=false, so\n  that the error is computed for the whole new set. Yes, this sounds a bit confusing.\n\n##### Return\n- **retval**: `float`\n- **resp**: `Evision.Mat.t()`.\n\n  the optional output responses.\n\nThe method uses StatModel::predict to compute the error. For regression models the error is\ncomputed as RMS, for classifiers - as a percent of missclassified samples (0%-100%).\n\nPython prototype (for reference only):\n```python3\ncalcError(data, test[, resp]) -> retval, resp\n```","ref":"Evision.ML.LogisticRegression.html#calcError/4"},{"type":"function","title":"Evision.ML.LogisticRegression.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.ML.LogisticRegression.html#clear/1"},{"type":"function","title":"Evision.ML.LogisticRegression.create/0","doc":"Creates empty model.\n##### Return\n- **retval**: `Evision.ML.LogisticRegression.t()`\n\nCreates Logistic Regression model with parameters given.\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.ML.LogisticRegression.html#create/0"},{"type":"function","title":"Evision.ML.LogisticRegression.create/1","doc":"","ref":"Evision.ML.LogisticRegression.html#create/1"},{"type":"function","title":"Evision.ML.LogisticRegression.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.ML.LogisticRegression.html#empty/1"},{"type":"function","title":"Evision.ML.LogisticRegression.get_learnt_thetas/1","doc":"This function returns the trained parameters arranged across rows.\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nFor a two class classification problem, it returns a row matrix. It returns learnt parameters of\nthe Logistic Regression as a matrix of type CV_32F.\n\nPython prototype (for reference only):\n```python3\nget_learnt_thetas() -> retval\n```","ref":"Evision.ML.LogisticRegression.html#get_learnt_thetas/1"},{"type":"function","title":"Evision.ML.LogisticRegression.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.ML.LogisticRegression.html#getDefaultName/1"},{"type":"function","title":"Evision.ML.LogisticRegression.getIterations/1","doc":"getIterations\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setIterations/2`\n\nPython prototype (for reference only):\n```python3\ngetIterations() -> retval\n```","ref":"Evision.ML.LogisticRegression.html#getIterations/1"},{"type":"function","title":"Evision.ML.LogisticRegression.getLearningRate/1","doc":"getLearningRate\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n\n##### Return\n- **retval**: `double`\n\n@see `setLearningRate/2`\n\nPython prototype (for reference only):\n```python3\ngetLearningRate() -> retval\n```","ref":"Evision.ML.LogisticRegression.html#getLearningRate/1"},{"type":"function","title":"Evision.ML.LogisticRegression.getMiniBatchSize/1","doc":"getMiniBatchSize\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setMiniBatchSize/2`\n\nPython prototype (for reference only):\n```python3\ngetMiniBatchSize() -> retval\n```","ref":"Evision.ML.LogisticRegression.html#getMiniBatchSize/1"},{"type":"function","title":"Evision.ML.LogisticRegression.getRegularization/1","doc":"getRegularization\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setRegularization/2`\n\nPython prototype (for reference only):\n```python3\ngetRegularization() -> retval\n```","ref":"Evision.ML.LogisticRegression.html#getRegularization/1"},{"type":"function","title":"Evision.ML.LogisticRegression.getTermCriteria/1","doc":"getTermCriteria\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n\n##### Return\n- **retval**: `TermCriteria`\n\n@see `setTermCriteria/2`\n\nPython prototype (for reference only):\n```python3\ngetTermCriteria() -> retval\n```","ref":"Evision.ML.LogisticRegression.html#getTermCriteria/1"},{"type":"function","title":"Evision.ML.LogisticRegression.getTrainMethod/1","doc":"getTrainMethod\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setTrainMethod/2`\n\nPython prototype (for reference only):\n```python3\ngetTrainMethod() -> retval\n```","ref":"Evision.ML.LogisticRegression.html#getTrainMethod/1"},{"type":"function","title":"Evision.ML.LogisticRegression.getVarCount/1","doc":"Returns the number of variables in training samples\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetVarCount() -> retval\n```","ref":"Evision.ML.LogisticRegression.html#getVarCount/1"},{"type":"function","title":"Evision.ML.LogisticRegression.isClassifier/1","doc":"Returns true if the model is classifier\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisClassifier() -> retval\n```","ref":"Evision.ML.LogisticRegression.html#isClassifier/1"},{"type":"function","title":"Evision.ML.LogisticRegression.isTrained/1","doc":"Returns true if the model is trained\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisTrained() -> retval\n```","ref":"Evision.ML.LogisticRegression.html#isTrained/1"},{"type":"function","title":"Evision.ML.LogisticRegression.load/1","doc":"Loads and creates a serialized LogisticRegression from a file\n\n##### Positional Arguments\n- **filepath**: `String`.\n\n  path to serialized LogisticRegression\n\n##### Keyword Arguments\n- **nodeName**: `String`.\n\n  name of node containing the classifier\n\n##### Return\n- **retval**: `Evision.ML.LogisticRegression.t()`\n\n Use LogisticRegression::save to serialize and store an LogisticRegression to disk.\n Load the LogisticRegression from this file again, by calling this function with the path to the file.\n Optionally specify the node for the file containing the classifier\n\nPython prototype (for reference only):\n```python3\nload(filepath[, nodeName]) -> retval\n```","ref":"Evision.ML.LogisticRegression.html#load/1"},{"type":"function","title":"Evision.ML.LogisticRegression.load/2","doc":"Loads and creates a serialized LogisticRegression from a file\n\n##### Positional Arguments\n- **filepath**: `String`.\n\n  path to serialized LogisticRegression\n\n##### Keyword Arguments\n- **nodeName**: `String`.\n\n  name of node containing the classifier\n\n##### Return\n- **retval**: `Evision.ML.LogisticRegression.t()`\n\n Use LogisticRegression::save to serialize and store an LogisticRegression to disk.\n Load the LogisticRegression from this file again, by calling this function with the path to the file.\n Optionally specify the node for the file containing the classifier\n\nPython prototype (for reference only):\n```python3\nload(filepath[, nodeName]) -> retval\n```","ref":"Evision.ML.LogisticRegression.html#load/2"},{"type":"function","title":"Evision.ML.LogisticRegression.predict/1","doc":"","ref":"Evision.ML.LogisticRegression.html#predict/1"},{"type":"function","title":"Evision.ML.LogisticRegression.predict/2","doc":"Predicts responses for input samples and returns a float type.\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n- **samples**: `Evision.Mat`.\n\n  The input data for the prediction algorithm. Matrix [m x n], where each row\n  contains variables (features) of one object being classified. Should have data type CV_32F.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Not used.\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  Predicted labels as a column matrix of type CV_32S.\n\nPython prototype (for reference only):\n```python3\npredict(samples[, results[, flags]]) -> retval, results\n```","ref":"Evision.ML.LogisticRegression.html#predict/2"},{"type":"function","title":"Evision.ML.LogisticRegression.predict/3","doc":"Predicts responses for input samples and returns a float type.\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n- **samples**: `Evision.Mat`.\n\n  The input data for the prediction algorithm. Matrix [m x n], where each row\n  contains variables (features) of one object being classified. Should have data type CV_32F.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Not used.\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  Predicted labels as a column matrix of type CV_32S.\n\nPython prototype (for reference only):\n```python3\npredict(samples[, results[, flags]]) -> retval, results\n```","ref":"Evision.ML.LogisticRegression.html#predict/3"},{"type":"function","title":"Evision.ML.LogisticRegression.read/1","doc":"","ref":"Evision.ML.LogisticRegression.html#read/1"},{"type":"function","title":"Evision.ML.LogisticRegression.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.ML.LogisticRegression.html#read/2"},{"type":"function","title":"Evision.ML.LogisticRegression.save/1","doc":"","ref":"Evision.ML.LogisticRegression.html#save/1"},{"type":"function","title":"Evision.ML.LogisticRegression.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.ML.LogisticRegression.html#save/2"},{"type":"function","title":"Evision.ML.LogisticRegression.setIterations/1","doc":"","ref":"Evision.ML.LogisticRegression.html#setIterations/1"},{"type":"function","title":"Evision.ML.LogisticRegression.setIterations/2","doc":"setIterations\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n- **val**: `integer()`\n\n@see `getIterations/1`\n\nPython prototype (for reference only):\n```python3\nsetIterations(val) -> None\n```","ref":"Evision.ML.LogisticRegression.html#setIterations/2"},{"type":"function","title":"Evision.ML.LogisticRegression.setLearningRate/1","doc":"","ref":"Evision.ML.LogisticRegression.html#setLearningRate/1"},{"type":"function","title":"Evision.ML.LogisticRegression.setLearningRate/2","doc":"setLearningRate\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n- **val**: `double`\n\n@see `getLearningRate/1`\n\nPython prototype (for reference only):\n```python3\nsetLearningRate(val) -> None\n```","ref":"Evision.ML.LogisticRegression.html#setLearningRate/2"},{"type":"function","title":"Evision.ML.LogisticRegression.setMiniBatchSize/1","doc":"","ref":"Evision.ML.LogisticRegression.html#setMiniBatchSize/1"},{"type":"function","title":"Evision.ML.LogisticRegression.setMiniBatchSize/2","doc":"setMiniBatchSize\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n- **val**: `integer()`\n\n@see `getMiniBatchSize/1`\n\nPython prototype (for reference only):\n```python3\nsetMiniBatchSize(val) -> None\n```","ref":"Evision.ML.LogisticRegression.html#setMiniBatchSize/2"},{"type":"function","title":"Evision.ML.LogisticRegression.setRegularization/1","doc":"","ref":"Evision.ML.LogisticRegression.html#setRegularization/1"},{"type":"function","title":"Evision.ML.LogisticRegression.setRegularization/2","doc":"setRegularization\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n- **val**: `integer()`\n\n@see `getRegularization/1`\n\nPython prototype (for reference only):\n```python3\nsetRegularization(val) -> None\n```","ref":"Evision.ML.LogisticRegression.html#setRegularization/2"},{"type":"function","title":"Evision.ML.LogisticRegression.setTermCriteria/1","doc":"","ref":"Evision.ML.LogisticRegression.html#setTermCriteria/1"},{"type":"function","title":"Evision.ML.LogisticRegression.setTermCriteria/2","doc":"setTermCriteria\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n- **val**: `TermCriteria`\n\n@see `getTermCriteria/1`\n\nPython prototype (for reference only):\n```python3\nsetTermCriteria(val) -> None\n```","ref":"Evision.ML.LogisticRegression.html#setTermCriteria/2"},{"type":"function","title":"Evision.ML.LogisticRegression.setTrainMethod/1","doc":"","ref":"Evision.ML.LogisticRegression.html#setTrainMethod/1"},{"type":"function","title":"Evision.ML.LogisticRegression.setTrainMethod/2","doc":"setTrainMethod\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n- **val**: `integer()`\n\n@see `getTrainMethod/1`\n\nPython prototype (for reference only):\n```python3\nsetTrainMethod(val) -> None\n```","ref":"Evision.ML.LogisticRegression.html#setTrainMethod/2"},{"type":"function","title":"Evision.ML.LogisticRegression.train/1","doc":"","ref":"Evision.ML.LogisticRegression.html#train/1"},{"type":"function","title":"Evision.ML.LogisticRegression.train/2","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n- **trainData**: `Evision.ML.TrainData.t()`.\n\n  training data that can be loaded from file using TrainData::loadFromCSV or\n  created with TrainData::create.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  optional flags, depending on the model. Some of the models can be updated with the\n  new training samples, not completely overwritten (such as NormalBayesClassifier or ANN_MLP).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(trainData[, flags]) -> retval\n```","ref":"Evision.ML.LogisticRegression.html#train/2"},{"type":"function","title":"Evision.ML.LogisticRegression.train/3","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n- **trainData**: `Evision.ML.TrainData.t()`.\n\n  training data that can be loaded from file using TrainData::loadFromCSV or\n  created with TrainData::create.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  optional flags, depending on the model. Some of the models can be updated with the\n  new training samples, not completely overwritten (such as NormalBayesClassifier or ANN_MLP).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(trainData[, flags]) -> retval\n```","ref":"Evision.ML.LogisticRegression.html#train/3"},{"type":"function","title":"Evision.ML.LogisticRegression.train/4","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n- **samples**: `Evision.Mat`.\n\n  training samples\n\n- **layout**: `integer()`.\n\n  See ml::SampleTypes.\n\n- **responses**: `Evision.Mat`.\n\n  vector of responses associated with the training samples.\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(samples, layout, responses) -> retval\n```","ref":"Evision.ML.LogisticRegression.html#train/4"},{"type":"function","title":"Evision.ML.LogisticRegression.write/1","doc":"","ref":"Evision.ML.LogisticRegression.html#write/1"},{"type":"function","title":"Evision.ML.LogisticRegression.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.ML.LogisticRegression.html#write/2"},{"type":"function","title":"Evision.ML.LogisticRegression.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.ML.LogisticRegression.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.ML.LogisticRegression.html#write/3"},{"type":"type","title":"Evision.ML.LogisticRegression.t/0","doc":"Type that represents an `ML.LogisticRegression` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ML.LogisticRegression.html#t:t/0"},{"type":"module","title":"Evision.ML.LogisticRegression.Methods","doc":"","ref":"Evision.ML.LogisticRegression.Methods.html"},{"type":"function","title":"Evision.ML.LogisticRegression.Methods.cv_BATCH/0","doc":"","ref":"Evision.ML.LogisticRegression.Methods.html#cv_BATCH/0"},{"type":"function","title":"Evision.ML.LogisticRegression.Methods.cv_MINI_BATCH/0","doc":"","ref":"Evision.ML.LogisticRegression.Methods.html#cv_MINI_BATCH/0"},{"type":"type","title":"Evision.ML.LogisticRegression.Methods.enum/0","doc":"","ref":"Evision.ML.LogisticRegression.Methods.html#t:enum/0"},{"type":"module","title":"Evision.ML.LogisticRegression.RegKinds","doc":"","ref":"Evision.ML.LogisticRegression.RegKinds.html"},{"type":"function","title":"Evision.ML.LogisticRegression.RegKinds.cv_REG_DISABLE/0","doc":"","ref":"Evision.ML.LogisticRegression.RegKinds.html#cv_REG_DISABLE/0"},{"type":"function","title":"Evision.ML.LogisticRegression.RegKinds.cv_REG_L1/0","doc":"","ref":"Evision.ML.LogisticRegression.RegKinds.html#cv_REG_L1/0"},{"type":"function","title":"Evision.ML.LogisticRegression.RegKinds.cv_REG_L2/0","doc":"","ref":"Evision.ML.LogisticRegression.RegKinds.html#cv_REG_L2/0"},{"type":"type","title":"Evision.ML.LogisticRegression.RegKinds.enum/0","doc":"","ref":"Evision.ML.LogisticRegression.RegKinds.html#t:enum/0"},{"type":"module","title":"Evision.ML.NormalBayesClassifier","doc":"","ref":"Evision.ML.NormalBayesClassifier.html"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.calcError/1","doc":"","ref":"Evision.ML.NormalBayesClassifier.html#calcError/1"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.calcError/3","doc":"Computes error on the training or test dataset\n\n##### Positional Arguments\n- **self**: `Evision.ML.NormalBayesClassifier.t()`\n- **data**: `Evision.ML.TrainData.t()`.\n\n  the training data\n\n- **test**: `bool`.\n\n  if true, the error is computed over the test subset of the data, otherwise it's\n  computed over the training subset of the data. Please note that if you loaded a completely\n  different dataset to evaluate already trained classifier, you will probably want not to set\n  the test subset at all with TrainData::setTrainTestSplitRatio and specify test=false, so\n  that the error is computed for the whole new set. Yes, this sounds a bit confusing.\n\n##### Return\n- **retval**: `float`\n- **resp**: `Evision.Mat.t()`.\n\n  the optional output responses.\n\nThe method uses StatModel::predict to compute the error. For regression models the error is\ncomputed as RMS, for classifiers - as a percent of missclassified samples (0%-100%).\n\nPython prototype (for reference only):\n```python3\ncalcError(data, test[, resp]) -> retval, resp\n```","ref":"Evision.ML.NormalBayesClassifier.html#calcError/3"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.calcError/4","doc":"Computes error on the training or test dataset\n\n##### Positional Arguments\n- **self**: `Evision.ML.NormalBayesClassifier.t()`\n- **data**: `Evision.ML.TrainData.t()`.\n\n  the training data\n\n- **test**: `bool`.\n\n  if true, the error is computed over the test subset of the data, otherwise it's\n  computed over the training subset of the data. Please note that if you loaded a completely\n  different dataset to evaluate already trained classifier, you will probably want not to set\n  the test subset at all with TrainData::setTrainTestSplitRatio and specify test=false, so\n  that the error is computed for the whole new set. Yes, this sounds a bit confusing.\n\n##### Return\n- **retval**: `float`\n- **resp**: `Evision.Mat.t()`.\n\n  the optional output responses.\n\nThe method uses StatModel::predict to compute the error. For regression models the error is\ncomputed as RMS, for classifiers - as a percent of missclassified samples (0%-100%).\n\nPython prototype (for reference only):\n```python3\ncalcError(data, test[, resp]) -> retval, resp\n```","ref":"Evision.ML.NormalBayesClassifier.html#calcError/4"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.ML.NormalBayesClassifier.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.ML.NormalBayesClassifier.html#clear/1"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.create/0","doc":"create\n##### Return\n- **retval**: `Evision.ML.NormalBayesClassifier.t()`\n\nCreates empty model\nUse StatModel::train to train the model after creation.\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.ML.NormalBayesClassifier.html#create/0"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.create/1","doc":"","ref":"Evision.ML.NormalBayesClassifier.html#create/1"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.ML.NormalBayesClassifier.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.ML.NormalBayesClassifier.html#empty/1"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.ML.NormalBayesClassifier.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.ML.NormalBayesClassifier.html#getDefaultName/1"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.getVarCount/1","doc":"Returns the number of variables in training samples\n\n##### Positional Arguments\n- **self**: `Evision.ML.NormalBayesClassifier.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetVarCount() -> retval\n```","ref":"Evision.ML.NormalBayesClassifier.html#getVarCount/1"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.isClassifier/1","doc":"Returns true if the model is classifier\n\n##### Positional Arguments\n- **self**: `Evision.ML.NormalBayesClassifier.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisClassifier() -> retval\n```","ref":"Evision.ML.NormalBayesClassifier.html#isClassifier/1"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.isTrained/1","doc":"Returns true if the model is trained\n\n##### Positional Arguments\n- **self**: `Evision.ML.NormalBayesClassifier.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisTrained() -> retval\n```","ref":"Evision.ML.NormalBayesClassifier.html#isTrained/1"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.load/1","doc":"Loads and creates a serialized NormalBayesClassifier from a file\n\n##### Positional Arguments\n- **filepath**: `String`.\n\n  path to serialized NormalBayesClassifier\n\n##### Keyword Arguments\n- **nodeName**: `String`.\n\n  name of node containing the classifier\n\n##### Return\n- **retval**: `Evision.ML.NormalBayesClassifier.t()`\n\n Use NormalBayesClassifier::save to serialize and store an NormalBayesClassifier to disk.\n Load the NormalBayesClassifier from this file again, by calling this function with the path to the file.\n Optionally specify the node for the file containing the classifier\n\nPython prototype (for reference only):\n```python3\nload(filepath[, nodeName]) -> retval\n```","ref":"Evision.ML.NormalBayesClassifier.html#load/1"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.load/2","doc":"Loads and creates a serialized NormalBayesClassifier from a file\n\n##### Positional Arguments\n- **filepath**: `String`.\n\n  path to serialized NormalBayesClassifier\n\n##### Keyword Arguments\n- **nodeName**: `String`.\n\n  name of node containing the classifier\n\n##### Return\n- **retval**: `Evision.ML.NormalBayesClassifier.t()`\n\n Use NormalBayesClassifier::save to serialize and store an NormalBayesClassifier to disk.\n Load the NormalBayesClassifier from this file again, by calling this function with the path to the file.\n Optionally specify the node for the file containing the classifier\n\nPython prototype (for reference only):\n```python3\nload(filepath[, nodeName]) -> retval\n```","ref":"Evision.ML.NormalBayesClassifier.html#load/2"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.predict/1","doc":"","ref":"Evision.ML.NormalBayesClassifier.html#predict/1"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.predict/2","doc":"Predicts response(s) for the provided sample(s)\n\n##### Positional Arguments\n- **self**: `Evision.ML.NormalBayesClassifier.t()`\n- **samples**: `Evision.Mat`.\n\n  The input samples, floating-point matrix\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  The optional flags, model-dependent. See cv::ml::StatModel::Flags.\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  The optional output matrix of results.\n\nPython prototype (for reference only):\n```python3\npredict(samples[, results[, flags]]) -> retval, results\n```","ref":"Evision.ML.NormalBayesClassifier.html#predict/2"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.predict/3","doc":"Predicts response(s) for the provided sample(s)\n\n##### Positional Arguments\n- **self**: `Evision.ML.NormalBayesClassifier.t()`\n- **samples**: `Evision.Mat`.\n\n  The input samples, floating-point matrix\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  The optional flags, model-dependent. See cv::ml::StatModel::Flags.\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  The optional output matrix of results.\n\nPython prototype (for reference only):\n```python3\npredict(samples[, results[, flags]]) -> retval, results\n```","ref":"Evision.ML.NormalBayesClassifier.html#predict/3"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.predictProb/1","doc":"","ref":"Evision.ML.NormalBayesClassifier.html#predictProb/1"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.predictProb/2","doc":"Predicts the response for sample(s).\n\n##### Positional Arguments\n- **self**: `Evision.ML.NormalBayesClassifier.t()`\n- **inputs**: `Evision.Mat`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n##### Return\n- **retval**: `float`\n- **outputs**: `Evision.Mat.t()`.\n- **outputProbs**: `Evision.Mat.t()`.\n\nThe method estimates the most probable classes for input vectors. Input vectors (one or more)\nare stored as rows of the matrix inputs. In case of multiple input vectors, there should be one\noutput vector outputs. The predicted class for a single input vector is returned by the method.\nThe vector outputProbs contains the output probabilities corresponding to each element of\nresult.\n\nPython prototype (for reference only):\n```python3\npredictProb(inputs[, outputs[, outputProbs[, flags]]]) -> retval, outputs, outputProbs\n```","ref":"Evision.ML.NormalBayesClassifier.html#predictProb/2"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.predictProb/3","doc":"Predicts the response for sample(s).\n\n##### Positional Arguments\n- **self**: `Evision.ML.NormalBayesClassifier.t()`\n- **inputs**: `Evision.Mat`\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n##### Return\n- **retval**: `float`\n- **outputs**: `Evision.Mat.t()`.\n- **outputProbs**: `Evision.Mat.t()`.\n\nThe method estimates the most probable classes for input vectors. Input vectors (one or more)\nare stored as rows of the matrix inputs. In case of multiple input vectors, there should be one\noutput vector outputs. The predicted class for a single input vector is returned by the method.\nThe vector outputProbs contains the output probabilities corresponding to each element of\nresult.\n\nPython prototype (for reference only):\n```python3\npredictProb(inputs[, outputs[, outputProbs[, flags]]]) -> retval, outputs, outputProbs\n```","ref":"Evision.ML.NormalBayesClassifier.html#predictProb/3"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.read/1","doc":"","ref":"Evision.ML.NormalBayesClassifier.html#read/1"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ML.NormalBayesClassifier.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.ML.NormalBayesClassifier.html#read/2"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.save/1","doc":"","ref":"Evision.ML.NormalBayesClassifier.html#save/1"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.ML.NormalBayesClassifier.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.ML.NormalBayesClassifier.html#save/2"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.train/1","doc":"","ref":"Evision.ML.NormalBayesClassifier.html#train/1"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.train/2","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.NormalBayesClassifier.t()`\n- **trainData**: `Evision.ML.TrainData.t()`.\n\n  training data that can be loaded from file using TrainData::loadFromCSV or\n  created with TrainData::create.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  optional flags, depending on the model. Some of the models can be updated with the\n  new training samples, not completely overwritten (such as NormalBayesClassifier or ANN_MLP).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(trainData[, flags]) -> retval\n```","ref":"Evision.ML.NormalBayesClassifier.html#train/2"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.train/3","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.NormalBayesClassifier.t()`\n- **trainData**: `Evision.ML.TrainData.t()`.\n\n  training data that can be loaded from file using TrainData::loadFromCSV or\n  created with TrainData::create.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  optional flags, depending on the model. Some of the models can be updated with the\n  new training samples, not completely overwritten (such as NormalBayesClassifier or ANN_MLP).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(trainData[, flags]) -> retval\n```","ref":"Evision.ML.NormalBayesClassifier.html#train/3"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.train/4","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.NormalBayesClassifier.t()`\n- **samples**: `Evision.Mat`.\n\n  training samples\n\n- **layout**: `integer()`.\n\n  See ml::SampleTypes.\n\n- **responses**: `Evision.Mat`.\n\n  vector of responses associated with the training samples.\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(samples, layout, responses) -> retval\n```","ref":"Evision.ML.NormalBayesClassifier.html#train/4"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.write/1","doc":"","ref":"Evision.ML.NormalBayesClassifier.html#write/1"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ML.NormalBayesClassifier.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.ML.NormalBayesClassifier.html#write/2"},{"type":"function","title":"Evision.ML.NormalBayesClassifier.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.ML.NormalBayesClassifier.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.ML.NormalBayesClassifier.html#write/3"},{"type":"type","title":"Evision.ML.NormalBayesClassifier.t/0","doc":"Type that represents an `ML.NormalBayesClassifier` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ML.NormalBayesClassifier.html#t:t/0"},{"type":"module","title":"Evision.ML.ParamGrid","doc":"","ref":"Evision.ML.ParamGrid.html"},{"type":"function","title":"Evision.ML.ParamGrid.create/0","doc":"Creates a ParamGrid Ptr that can be given to the %SVM::trainAuto method\n##### Keyword Arguments\n- **minVal**: `double`.\n\n  minimum value of the parameter grid\n\n- **maxVal**: `double`.\n\n  maximum value of the parameter grid\n\n- **logstep**: `double`.\n\n  Logarithmic step for iterating the statmodel parameter\n\n##### Return\n- **retval**: `Evision.ML.ParamGrid.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, minVal[, maxVal[, logstep]]]) -> retval\n```","ref":"Evision.ML.ParamGrid.html#create/0"},{"type":"function","title":"Evision.ML.ParamGrid.create/1","doc":"Creates a ParamGrid Ptr that can be given to the %SVM::trainAuto method\n##### Keyword Arguments\n- **minVal**: `double`.\n\n  minimum value of the parameter grid\n\n- **maxVal**: `double`.\n\n  maximum value of the parameter grid\n\n- **logstep**: `double`.\n\n  Logarithmic step for iterating the statmodel parameter\n\n##### Return\n- **retval**: `Evision.ML.ParamGrid.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, minVal[, maxVal[, logstep]]]) -> retval\n```","ref":"Evision.ML.ParamGrid.html#create/1"},{"type":"function","title":"Evision.ML.ParamGrid.get_logStep/1","doc":"","ref":"Evision.ML.ParamGrid.html#get_logStep/1"},{"type":"function","title":"Evision.ML.ParamGrid.get_maxVal/1","doc":"","ref":"Evision.ML.ParamGrid.html#get_maxVal/1"},{"type":"function","title":"Evision.ML.ParamGrid.get_minVal/1","doc":"","ref":"Evision.ML.ParamGrid.html#get_minVal/1"},{"type":"function","title":"Evision.ML.ParamGrid.set_logStep/2","doc":"","ref":"Evision.ML.ParamGrid.html#set_logStep/2"},{"type":"function","title":"Evision.ML.ParamGrid.set_maxVal/2","doc":"","ref":"Evision.ML.ParamGrid.html#set_maxVal/2"},{"type":"function","title":"Evision.ML.ParamGrid.set_minVal/2","doc":"","ref":"Evision.ML.ParamGrid.html#set_minVal/2"},{"type":"type","title":"Evision.ML.ParamGrid.t/0","doc":"Type that represents an `ML.ParamGrid` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ML.ParamGrid.html#t:t/0"},{"type":"module","title":"Evision.ML.RTrees","doc":"","ref":"Evision.ML.RTrees.html"},{"type":"function","title":"Evision.ML.RTrees.calcError/1","doc":"","ref":"Evision.ML.RTrees.html#calcError/1"},{"type":"function","title":"Evision.ML.RTrees.calcError/3","doc":"Computes error on the training or test dataset\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **data**: `Evision.ML.TrainData.t()`.\n\n  the training data\n\n- **test**: `bool`.\n\n  if true, the error is computed over the test subset of the data, otherwise it's\n  computed over the training subset of the data. Please note that if you loaded a completely\n  different dataset to evaluate already trained classifier, you will probably want not to set\n  the test subset at all with TrainData::setTrainTestSplitRatio and specify test=false, so\n  that the error is computed for the whole new set. Yes, this sounds a bit confusing.\n\n##### Return\n- **retval**: `float`\n- **resp**: `Evision.Mat.t()`.\n\n  the optional output responses.\n\nThe method uses StatModel::predict to compute the error. For regression models the error is\ncomputed as RMS, for classifiers - as a percent of missclassified samples (0%-100%).\n\nPython prototype (for reference only):\n```python3\ncalcError(data, test[, resp]) -> retval, resp\n```","ref":"Evision.ML.RTrees.html#calcError/3"},{"type":"function","title":"Evision.ML.RTrees.calcError/4","doc":"Computes error on the training or test dataset\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **data**: `Evision.ML.TrainData.t()`.\n\n  the training data\n\n- **test**: `bool`.\n\n  if true, the error is computed over the test subset of the data, otherwise it's\n  computed over the training subset of the data. Please note that if you loaded a completely\n  different dataset to evaluate already trained classifier, you will probably want not to set\n  the test subset at all with TrainData::setTrainTestSplitRatio and specify test=false, so\n  that the error is computed for the whole new set. Yes, this sounds a bit confusing.\n\n##### Return\n- **retval**: `float`\n- **resp**: `Evision.Mat.t()`.\n\n  the optional output responses.\n\nThe method uses StatModel::predict to compute the error. For regression models the error is\ncomputed as RMS, for classifiers - as a percent of missclassified samples (0%-100%).\n\nPython prototype (for reference only):\n```python3\ncalcError(data, test[, resp]) -> retval, resp\n```","ref":"Evision.ML.RTrees.html#calcError/4"},{"type":"function","title":"Evision.ML.RTrees.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.ML.RTrees.html#clear/1"},{"type":"function","title":"Evision.ML.RTrees.create/0","doc":"create\n##### Return\n- **retval**: `Evision.ML.RTrees.t()`\n\nCreates the empty model.\nUse StatModel::train to train the model, StatModel::train to create and train the model,\nAlgorithm::load to load the pre-trained model.\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.ML.RTrees.html#create/0"},{"type":"function","title":"Evision.ML.RTrees.create/1","doc":"","ref":"Evision.ML.RTrees.html#create/1"},{"type":"function","title":"Evision.ML.RTrees.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.ML.RTrees.html#empty/1"},{"type":"function","title":"Evision.ML.RTrees.getActiveVarCount/1","doc":"getActiveVarCount\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setActiveVarCount/2`\n\nPython prototype (for reference only):\n```python3\ngetActiveVarCount() -> retval\n```","ref":"Evision.ML.RTrees.html#getActiveVarCount/1"},{"type":"function","title":"Evision.ML.RTrees.getCalculateVarImportance/1","doc":"getCalculateVarImportance\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n\n##### Return\n- **retval**: `bool`\n\n@see `setCalculateVarImportance/2`\n\nPython prototype (for reference only):\n```python3\ngetCalculateVarImportance() -> retval\n```","ref":"Evision.ML.RTrees.html#getCalculateVarImportance/1"},{"type":"function","title":"Evision.ML.RTrees.getCVFolds/1","doc":"getCVFolds\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setCVFolds/2`\n\nPython prototype (for reference only):\n```python3\ngetCVFolds() -> retval\n```","ref":"Evision.ML.RTrees.html#getCVFolds/1"},{"type":"function","title":"Evision.ML.RTrees.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.ML.RTrees.html#getDefaultName/1"},{"type":"function","title":"Evision.ML.RTrees.getMaxCategories/1","doc":"getMaxCategories\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setMaxCategories/2`\n\nPython prototype (for reference only):\n```python3\ngetMaxCategories() -> retval\n```","ref":"Evision.ML.RTrees.html#getMaxCategories/1"},{"type":"function","title":"Evision.ML.RTrees.getMaxDepth/1","doc":"getMaxDepth\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setMaxDepth/2`\n\nPython prototype (for reference only):\n```python3\ngetMaxDepth() -> retval\n```","ref":"Evision.ML.RTrees.html#getMaxDepth/1"},{"type":"function","title":"Evision.ML.RTrees.getMinSampleCount/1","doc":"getMinSampleCount\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setMinSampleCount/2`\n\nPython prototype (for reference only):\n```python3\ngetMinSampleCount() -> retval\n```","ref":"Evision.ML.RTrees.html#getMinSampleCount/1"},{"type":"function","title":"Evision.ML.RTrees.getOOBError/1","doc":"getOOBError\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n\n##### Return\n- **retval**: `double`\n\nReturns the OOB error value, computed at the training stage when calcOOBError is set to true.\n If this flag was set to false, 0 is returned. The OOB error is also scaled by sample weighting.\n\nPython prototype (for reference only):\n```python3\ngetOOBError() -> retval\n```","ref":"Evision.ML.RTrees.html#getOOBError/1"},{"type":"function","title":"Evision.ML.RTrees.getPriors/1","doc":"getPriors\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n@see `setPriors/2`\n\nPython prototype (for reference only):\n```python3\ngetPriors() -> retval\n```","ref":"Evision.ML.RTrees.html#getPriors/1"},{"type":"function","title":"Evision.ML.RTrees.getRegressionAccuracy/1","doc":"getRegressionAccuracy\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setRegressionAccuracy/2`\n\nPython prototype (for reference only):\n```python3\ngetRegressionAccuracy() -> retval\n```","ref":"Evision.ML.RTrees.html#getRegressionAccuracy/1"},{"type":"function","title":"Evision.ML.RTrees.getTermCriteria/1","doc":"getTermCriteria\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n\n##### Return\n- **retval**: `TermCriteria`\n\n@see `setTermCriteria/2`\n\nPython prototype (for reference only):\n```python3\ngetTermCriteria() -> retval\n```","ref":"Evision.ML.RTrees.html#getTermCriteria/1"},{"type":"function","title":"Evision.ML.RTrees.getTruncatePrunedTree/1","doc":"getTruncatePrunedTree\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n\n##### Return\n- **retval**: `bool`\n\n@see `setTruncatePrunedTree/2`\n\nPython prototype (for reference only):\n```python3\ngetTruncatePrunedTree() -> retval\n```","ref":"Evision.ML.RTrees.html#getTruncatePrunedTree/1"},{"type":"function","title":"Evision.ML.RTrees.getUse1SERule/1","doc":"getUse1SERule\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n\n##### Return\n- **retval**: `bool`\n\n@see `setUse1SERule/2`\n\nPython prototype (for reference only):\n```python3\ngetUse1SERule() -> retval\n```","ref":"Evision.ML.RTrees.html#getUse1SERule/1"},{"type":"function","title":"Evision.ML.RTrees.getUseSurrogates/1","doc":"getUseSurrogates\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n\n##### Return\n- **retval**: `bool`\n\n@see `setUseSurrogates/2`\n\nPython prototype (for reference only):\n```python3\ngetUseSurrogates() -> retval\n```","ref":"Evision.ML.RTrees.html#getUseSurrogates/1"},{"type":"function","title":"Evision.ML.RTrees.getVarCount/1","doc":"Returns the number of variables in training samples\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetVarCount() -> retval\n```","ref":"Evision.ML.RTrees.html#getVarCount/1"},{"type":"function","title":"Evision.ML.RTrees.getVarImportance/1","doc":"getVarImportance\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nReturns the variable importance array.\nThe method returns the variable importance vector, computed at the training stage when\nCalculateVarImportance is set to true. If this flag was set to false, the empty matrix is\nreturned.\n\nPython prototype (for reference only):\n```python3\ngetVarImportance() -> retval\n```","ref":"Evision.ML.RTrees.html#getVarImportance/1"},{"type":"function","title":"Evision.ML.RTrees.getVotes/1","doc":"","ref":"Evision.ML.RTrees.html#getVotes/1"},{"type":"function","title":"Evision.ML.RTrees.getVotes/3","doc":"getVotes\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **samples**: `Evision.Mat`.\n\n  Array containing the samples for which votes will be calculated.\n\n- **flags**: `integer()`.\n\n  Flags for defining the type of RTrees.\n\n##### Return\n- **results**: `Evision.Mat.t()`.\n\n  Array where the result of the calculation will be written.\n\nReturns the result of each individual tree in the forest.\nIn case the model is a regression problem, the method will return each of the trees'\nresults for each of the sample cases. If the model is a classifier, it will return\na Mat with samples + 1 rows, where the first row gives the class number and the\nfollowing rows return the votes each class had for each sample.\n\nPython prototype (for reference only):\n```python3\ngetVotes(samples, flags[, results]) -> results\n```","ref":"Evision.ML.RTrees.html#getVotes/3"},{"type":"function","title":"Evision.ML.RTrees.getVotes/4","doc":"getVotes\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **samples**: `Evision.Mat`.\n\n  Array containing the samples for which votes will be calculated.\n\n- **flags**: `integer()`.\n\n  Flags for defining the type of RTrees.\n\n##### Return\n- **results**: `Evision.Mat.t()`.\n\n  Array where the result of the calculation will be written.\n\nReturns the result of each individual tree in the forest.\nIn case the model is a regression problem, the method will return each of the trees'\nresults for each of the sample cases. If the model is a classifier, it will return\na Mat with samples + 1 rows, where the first row gives the class number and the\nfollowing rows return the votes each class had for each sample.\n\nPython prototype (for reference only):\n```python3\ngetVotes(samples, flags[, results]) -> results\n```","ref":"Evision.ML.RTrees.html#getVotes/4"},{"type":"function","title":"Evision.ML.RTrees.isClassifier/1","doc":"Returns true if the model is classifier\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisClassifier() -> retval\n```","ref":"Evision.ML.RTrees.html#isClassifier/1"},{"type":"function","title":"Evision.ML.RTrees.isTrained/1","doc":"Returns true if the model is trained\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisTrained() -> retval\n```","ref":"Evision.ML.RTrees.html#isTrained/1"},{"type":"function","title":"Evision.ML.RTrees.load/1","doc":"Loads and creates a serialized RTree from a file\n\n##### Positional Arguments\n- **filepath**: `String`.\n\n  path to serialized RTree\n\n##### Keyword Arguments\n- **nodeName**: `String`.\n\n  name of node containing the classifier\n\n##### Return\n- **retval**: `Evision.ML.RTrees.t()`\n\n Use RTree::save to serialize and store an RTree to disk.\n Load the RTree from this file again, by calling this function with the path to the file.\n Optionally specify the node for the file containing the classifier\n\nPython prototype (for reference only):\n```python3\nload(filepath[, nodeName]) -> retval\n```","ref":"Evision.ML.RTrees.html#load/1"},{"type":"function","title":"Evision.ML.RTrees.load/2","doc":"Loads and creates a serialized RTree from a file\n\n##### Positional Arguments\n- **filepath**: `String`.\n\n  path to serialized RTree\n\n##### Keyword Arguments\n- **nodeName**: `String`.\n\n  name of node containing the classifier\n\n##### Return\n- **retval**: `Evision.ML.RTrees.t()`\n\n Use RTree::save to serialize and store an RTree to disk.\n Load the RTree from this file again, by calling this function with the path to the file.\n Optionally specify the node for the file containing the classifier\n\nPython prototype (for reference only):\n```python3\nload(filepath[, nodeName]) -> retval\n```","ref":"Evision.ML.RTrees.html#load/2"},{"type":"function","title":"Evision.ML.RTrees.predict/1","doc":"","ref":"Evision.ML.RTrees.html#predict/1"},{"type":"function","title":"Evision.ML.RTrees.predict/2","doc":"Predicts response(s) for the provided sample(s)\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **samples**: `Evision.Mat`.\n\n  The input samples, floating-point matrix\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  The optional flags, model-dependent. See cv::ml::StatModel::Flags.\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  The optional output matrix of results.\n\nPython prototype (for reference only):\n```python3\npredict(samples[, results[, flags]]) -> retval, results\n```","ref":"Evision.ML.RTrees.html#predict/2"},{"type":"function","title":"Evision.ML.RTrees.predict/3","doc":"Predicts response(s) for the provided sample(s)\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **samples**: `Evision.Mat`.\n\n  The input samples, floating-point matrix\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  The optional flags, model-dependent. See cv::ml::StatModel::Flags.\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  The optional output matrix of results.\n\nPython prototype (for reference only):\n```python3\npredict(samples[, results[, flags]]) -> retval, results\n```","ref":"Evision.ML.RTrees.html#predict/3"},{"type":"function","title":"Evision.ML.RTrees.read/1","doc":"","ref":"Evision.ML.RTrees.html#read/1"},{"type":"function","title":"Evision.ML.RTrees.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.ML.RTrees.html#read/2"},{"type":"function","title":"Evision.ML.RTrees.save/1","doc":"","ref":"Evision.ML.RTrees.html#save/1"},{"type":"function","title":"Evision.ML.RTrees.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.ML.RTrees.html#save/2"},{"type":"function","title":"Evision.ML.RTrees.setActiveVarCount/1","doc":"","ref":"Evision.ML.RTrees.html#setActiveVarCount/1"},{"type":"function","title":"Evision.ML.RTrees.setActiveVarCount/2","doc":"setActiveVarCount\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **val**: `integer()`\n\n@see `getActiveVarCount/1`\n\nPython prototype (for reference only):\n```python3\nsetActiveVarCount(val) -> None\n```","ref":"Evision.ML.RTrees.html#setActiveVarCount/2"},{"type":"function","title":"Evision.ML.RTrees.setCalculateVarImportance/1","doc":"","ref":"Evision.ML.RTrees.html#setCalculateVarImportance/1"},{"type":"function","title":"Evision.ML.RTrees.setCalculateVarImportance/2","doc":"setCalculateVarImportance\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **val**: `bool`\n\n@see `getCalculateVarImportance/1`\n\nPython prototype (for reference only):\n```python3\nsetCalculateVarImportance(val) -> None\n```","ref":"Evision.ML.RTrees.html#setCalculateVarImportance/2"},{"type":"function","title":"Evision.ML.RTrees.setCVFolds/1","doc":"","ref":"Evision.ML.RTrees.html#setCVFolds/1"},{"type":"function","title":"Evision.ML.RTrees.setCVFolds/2","doc":"setCVFolds\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **val**: `integer()`\n\n@see `getCVFolds/1`\n\nPython prototype (for reference only):\n```python3\nsetCVFolds(val) -> None\n```","ref":"Evision.ML.RTrees.html#setCVFolds/2"},{"type":"function","title":"Evision.ML.RTrees.setMaxCategories/1","doc":"","ref":"Evision.ML.RTrees.html#setMaxCategories/1"},{"type":"function","title":"Evision.ML.RTrees.setMaxCategories/2","doc":"setMaxCategories\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **val**: `integer()`\n\n@see `getMaxCategories/1`\n\nPython prototype (for reference only):\n```python3\nsetMaxCategories(val) -> None\n```","ref":"Evision.ML.RTrees.html#setMaxCategories/2"},{"type":"function","title":"Evision.ML.RTrees.setMaxDepth/1","doc":"","ref":"Evision.ML.RTrees.html#setMaxDepth/1"},{"type":"function","title":"Evision.ML.RTrees.setMaxDepth/2","doc":"setMaxDepth\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **val**: `integer()`\n\n@see `getMaxDepth/1`\n\nPython prototype (for reference only):\n```python3\nsetMaxDepth(val) -> None\n```","ref":"Evision.ML.RTrees.html#setMaxDepth/2"},{"type":"function","title":"Evision.ML.RTrees.setMinSampleCount/1","doc":"","ref":"Evision.ML.RTrees.html#setMinSampleCount/1"},{"type":"function","title":"Evision.ML.RTrees.setMinSampleCount/2","doc":"setMinSampleCount\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **val**: `integer()`\n\n@see `getMinSampleCount/1`\n\nPython prototype (for reference only):\n```python3\nsetMinSampleCount(val) -> None\n```","ref":"Evision.ML.RTrees.html#setMinSampleCount/2"},{"type":"function","title":"Evision.ML.RTrees.setPriors/1","doc":"","ref":"Evision.ML.RTrees.html#setPriors/1"},{"type":"function","title":"Evision.ML.RTrees.setPriors/2","doc":"setPriors\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **val**: `Evision.Mat`\n\n@see `getPriors/1`\n\nPython prototype (for reference only):\n```python3\nsetPriors(val) -> None\n```","ref":"Evision.ML.RTrees.html#setPriors/2"},{"type":"function","title":"Evision.ML.RTrees.setRegressionAccuracy/1","doc":"","ref":"Evision.ML.RTrees.html#setRegressionAccuracy/1"},{"type":"function","title":"Evision.ML.RTrees.setRegressionAccuracy/2","doc":"setRegressionAccuracy\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **val**: `float`\n\n@see `getRegressionAccuracy/1`\n\nPython prototype (for reference only):\n```python3\nsetRegressionAccuracy(val) -> None\n```","ref":"Evision.ML.RTrees.html#setRegressionAccuracy/2"},{"type":"function","title":"Evision.ML.RTrees.setTermCriteria/1","doc":"","ref":"Evision.ML.RTrees.html#setTermCriteria/1"},{"type":"function","title":"Evision.ML.RTrees.setTermCriteria/2","doc":"setTermCriteria\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **val**: `TermCriteria`\n\n@see `getTermCriteria/1`\n\nPython prototype (for reference only):\n```python3\nsetTermCriteria(val) -> None\n```","ref":"Evision.ML.RTrees.html#setTermCriteria/2"},{"type":"function","title":"Evision.ML.RTrees.setTruncatePrunedTree/1","doc":"","ref":"Evision.ML.RTrees.html#setTruncatePrunedTree/1"},{"type":"function","title":"Evision.ML.RTrees.setTruncatePrunedTree/2","doc":"setTruncatePrunedTree\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **val**: `bool`\n\n@see `getTruncatePrunedTree/1`\n\nPython prototype (for reference only):\n```python3\nsetTruncatePrunedTree(val) -> None\n```","ref":"Evision.ML.RTrees.html#setTruncatePrunedTree/2"},{"type":"function","title":"Evision.ML.RTrees.setUse1SERule/1","doc":"","ref":"Evision.ML.RTrees.html#setUse1SERule/1"},{"type":"function","title":"Evision.ML.RTrees.setUse1SERule/2","doc":"setUse1SERule\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **val**: `bool`\n\n@see `getUse1SERule/1`\n\nPython prototype (for reference only):\n```python3\nsetUse1SERule(val) -> None\n```","ref":"Evision.ML.RTrees.html#setUse1SERule/2"},{"type":"function","title":"Evision.ML.RTrees.setUseSurrogates/1","doc":"","ref":"Evision.ML.RTrees.html#setUseSurrogates/1"},{"type":"function","title":"Evision.ML.RTrees.setUseSurrogates/2","doc":"setUseSurrogates\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **val**: `bool`\n\n@see `getUseSurrogates/1`\n\nPython prototype (for reference only):\n```python3\nsetUseSurrogates(val) -> None\n```","ref":"Evision.ML.RTrees.html#setUseSurrogates/2"},{"type":"function","title":"Evision.ML.RTrees.train/1","doc":"","ref":"Evision.ML.RTrees.html#train/1"},{"type":"function","title":"Evision.ML.RTrees.train/2","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **trainData**: `Evision.ML.TrainData.t()`.\n\n  training data that can be loaded from file using TrainData::loadFromCSV or\n  created with TrainData::create.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  optional flags, depending on the model. Some of the models can be updated with the\n  new training samples, not completely overwritten (such as NormalBayesClassifier or ANN_MLP).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(trainData[, flags]) -> retval\n```","ref":"Evision.ML.RTrees.html#train/2"},{"type":"function","title":"Evision.ML.RTrees.train/3","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **trainData**: `Evision.ML.TrainData.t()`.\n\n  training data that can be loaded from file using TrainData::loadFromCSV or\n  created with TrainData::create.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  optional flags, depending on the model. Some of the models can be updated with the\n  new training samples, not completely overwritten (such as NormalBayesClassifier or ANN_MLP).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(trainData[, flags]) -> retval\n```","ref":"Evision.ML.RTrees.html#train/3"},{"type":"function","title":"Evision.ML.RTrees.train/4","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **samples**: `Evision.Mat`.\n\n  training samples\n\n- **layout**: `integer()`.\n\n  See ml::SampleTypes.\n\n- **responses**: `Evision.Mat`.\n\n  vector of responses associated with the training samples.\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(samples, layout, responses) -> retval\n```","ref":"Evision.ML.RTrees.html#train/4"},{"type":"function","title":"Evision.ML.RTrees.write/1","doc":"","ref":"Evision.ML.RTrees.html#write/1"},{"type":"function","title":"Evision.ML.RTrees.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.ML.RTrees.html#write/2"},{"type":"function","title":"Evision.ML.RTrees.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.ML.RTrees.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.ML.RTrees.html#write/3"},{"type":"type","title":"Evision.ML.RTrees.t/0","doc":"Type that represents an `ML.RTrees` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ML.RTrees.html#t:t/0"},{"type":"module","title":"Evision.ML.SVM","doc":"","ref":"Evision.ML.SVM.html"},{"type":"function","title":"Evision.ML.SVM.calcError/1","doc":"","ref":"Evision.ML.SVM.html#calcError/1"},{"type":"function","title":"Evision.ML.SVM.calcError/3","doc":"Computes error on the training or test dataset\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **data**: `Evision.ML.TrainData.t()`.\n\n  the training data\n\n- **test**: `bool`.\n\n  if true, the error is computed over the test subset of the data, otherwise it's\n  computed over the training subset of the data. Please note that if you loaded a completely\n  different dataset to evaluate already trained classifier, you will probably want not to set\n  the test subset at all with TrainData::setTrainTestSplitRatio and specify test=false, so\n  that the error is computed for the whole new set. Yes, this sounds a bit confusing.\n\n##### Return\n- **retval**: `float`\n- **resp**: `Evision.Mat.t()`.\n\n  the optional output responses.\n\nThe method uses StatModel::predict to compute the error. For regression models the error is\ncomputed as RMS, for classifiers - as a percent of missclassified samples (0%-100%).\n\nPython prototype (for reference only):\n```python3\ncalcError(data, test[, resp]) -> retval, resp\n```","ref":"Evision.ML.SVM.html#calcError/3"},{"type":"function","title":"Evision.ML.SVM.calcError/4","doc":"Computes error on the training or test dataset\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **data**: `Evision.ML.TrainData.t()`.\n\n  the training data\n\n- **test**: `bool`.\n\n  if true, the error is computed over the test subset of the data, otherwise it's\n  computed over the training subset of the data. Please note that if you loaded a completely\n  different dataset to evaluate already trained classifier, you will probably want not to set\n  the test subset at all with TrainData::setTrainTestSplitRatio and specify test=false, so\n  that the error is computed for the whole new set. Yes, this sounds a bit confusing.\n\n##### Return\n- **retval**: `float`\n- **resp**: `Evision.Mat.t()`.\n\n  the optional output responses.\n\nThe method uses StatModel::predict to compute the error. For regression models the error is\ncomputed as RMS, for classifiers - as a percent of missclassified samples (0%-100%).\n\nPython prototype (for reference only):\n```python3\ncalcError(data, test[, resp]) -> retval, resp\n```","ref":"Evision.ML.SVM.html#calcError/4"},{"type":"function","title":"Evision.ML.SVM.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.ML.SVM.html#clear/1"},{"type":"function","title":"Evision.ML.SVM.create/0","doc":"create\n##### Return\n- **retval**: `Evision.ML.SVM.t()`\n\nCreates empty model.\nUse StatModel::train to train the model. Since %SVM has several parameters, you may want to\nfind the best parameters for your problem, it can be done with SVM::trainAuto.\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.ML.SVM.html#create/0"},{"type":"function","title":"Evision.ML.SVM.create/1","doc":"","ref":"Evision.ML.SVM.html#create/1"},{"type":"function","title":"Evision.ML.SVM.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.ML.SVM.html#empty/1"},{"type":"function","title":"Evision.ML.SVM.getC/1","doc":"getC\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n\n##### Return\n- **retval**: `double`\n\n@see `setC/2`\n\nPython prototype (for reference only):\n```python3\ngetC() -> retval\n```","ref":"Evision.ML.SVM.html#getC/1"},{"type":"function","title":"Evision.ML.SVM.getClassWeights/1","doc":"getClassWeights\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n@see `setClassWeights/2`\n\nPython prototype (for reference only):\n```python3\ngetClassWeights() -> retval\n```","ref":"Evision.ML.SVM.html#getClassWeights/1"},{"type":"function","title":"Evision.ML.SVM.getCoef0/1","doc":"getCoef0\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n\n##### Return\n- **retval**: `double`\n\n@see `setCoef0/2`\n\nPython prototype (for reference only):\n```python3\ngetCoef0() -> retval\n```","ref":"Evision.ML.SVM.html#getCoef0/1"},{"type":"function","title":"Evision.ML.SVM.getDecisionFunction/1","doc":"","ref":"Evision.ML.SVM.html#getDecisionFunction/1"},{"type":"function","title":"Evision.ML.SVM.getDecisionFunction/2","doc":"Retrieves the decision function\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **i**: `integer()`.\n\n  the index of the decision function. If the problem solved is regression, 1-class or\n  2-class classification, then there will be just one decision function and the index should\n  always be 0. Otherwise, in the case of N-class classification, there will be \\f$N(N-1)/2\\f$\n  decision functions.\n\n##### Return\n- **retval**: `double`\n- **alpha**: `Evision.Mat.t()`.\n\n  the optional output vector for weights, corresponding to different support vectors.\n  In the case of linear %SVM all the alpha's will be 1's.\n\n- **svidx**: `Evision.Mat.t()`.\n\n  the optional output vector of indices of support vectors within the matrix of\n  support vectors (which can be retrieved by SVM::getSupportVectors). In the case of linear\n  %SVM each decision function consists of a single \"compressed\" support vector.\n\nThe method returns rho parameter of the decision function, a scalar subtracted from the weighted\nsum of kernel responses.\n\nPython prototype (for reference only):\n```python3\ngetDecisionFunction(i[, alpha[, svidx]]) -> retval, alpha, svidx\n```","ref":"Evision.ML.SVM.html#getDecisionFunction/2"},{"type":"function","title":"Evision.ML.SVM.getDecisionFunction/3","doc":"Retrieves the decision function\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **i**: `integer()`.\n\n  the index of the decision function. If the problem solved is regression, 1-class or\n  2-class classification, then there will be just one decision function and the index should\n  always be 0. Otherwise, in the case of N-class classification, there will be \\f$N(N-1)/2\\f$\n  decision functions.\n\n##### Return\n- **retval**: `double`\n- **alpha**: `Evision.Mat.t()`.\n\n  the optional output vector for weights, corresponding to different support vectors.\n  In the case of linear %SVM all the alpha's will be 1's.\n\n- **svidx**: `Evision.Mat.t()`.\n\n  the optional output vector of indices of support vectors within the matrix of\n  support vectors (which can be retrieved by SVM::getSupportVectors). In the case of linear\n  %SVM each decision function consists of a single \"compressed\" support vector.\n\nThe method returns rho parameter of the decision function, a scalar subtracted from the weighted\nsum of kernel responses.\n\nPython prototype (for reference only):\n```python3\ngetDecisionFunction(i[, alpha[, svidx]]) -> retval, alpha, svidx\n```","ref":"Evision.ML.SVM.html#getDecisionFunction/3"},{"type":"function","title":"Evision.ML.SVM.getDefaultGridPtr/1","doc":"Generates a grid for %SVM parameters.\n\n##### Positional Arguments\n- **param_id**: `integer()`.\n\n  %SVM parameters IDs that must be one of the SVM::ParamTypes. The grid is\n  generated for the parameter with this ID.\n\n##### Return\n- **retval**: `Evision.ML.ParamGrid.t()`\n\nThe function generates a grid pointer for the specified parameter of the %SVM algorithm.\nThe grid may be passed to the function SVM::trainAuto.\n\nPython prototype (for reference only):\n```python3\ngetDefaultGridPtr(param_id) -> retval\n```","ref":"Evision.ML.SVM.html#getDefaultGridPtr/1"},{"type":"function","title":"Evision.ML.SVM.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.ML.SVM.html#getDefaultName/1"},{"type":"function","title":"Evision.ML.SVM.getDegree/1","doc":"getDegree\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n\n##### Return\n- **retval**: `double`\n\n@see `setDegree/2`\n\nPython prototype (for reference only):\n```python3\ngetDegree() -> retval\n```","ref":"Evision.ML.SVM.html#getDegree/1"},{"type":"function","title":"Evision.ML.SVM.getGamma/1","doc":"getGamma\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n\n##### Return\n- **retval**: `double`\n\n@see `setGamma/2`\n\nPython prototype (for reference only):\n```python3\ngetGamma() -> retval\n```","ref":"Evision.ML.SVM.html#getGamma/1"},{"type":"function","title":"Evision.ML.SVM.getKernelType/1","doc":"getKernelType\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nType of a %SVM kernel.\nSee SVM::KernelTypes. Default value is SVM::RBF.\n\nPython prototype (for reference only):\n```python3\ngetKernelType() -> retval\n```","ref":"Evision.ML.SVM.html#getKernelType/1"},{"type":"function","title":"Evision.ML.SVM.getNu/1","doc":"getNu\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n\n##### Return\n- **retval**: `double`\n\n@see `setNu/2`\n\nPython prototype (for reference only):\n```python3\ngetNu() -> retval\n```","ref":"Evision.ML.SVM.html#getNu/1"},{"type":"function","title":"Evision.ML.SVM.getP/1","doc":"getP\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n\n##### Return\n- **retval**: `double`\n\n@see `setP/2`\n\nPython prototype (for reference only):\n```python3\ngetP() -> retval\n```","ref":"Evision.ML.SVM.html#getP/1"},{"type":"function","title":"Evision.ML.SVM.getSupportVectors/1","doc":"Retrieves all the support vectors\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nThe method returns all the support vectors as a floating-point matrix, where support vectors are\nstored as matrix rows.\n\nPython prototype (for reference only):\n```python3\ngetSupportVectors() -> retval\n```","ref":"Evision.ML.SVM.html#getSupportVectors/1"},{"type":"function","title":"Evision.ML.SVM.getTermCriteria/1","doc":"getTermCriteria\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n\n##### Return\n- **retval**: `cv::TermCriteria`\n\n@see `setTermCriteria/2`\n\nPython prototype (for reference only):\n```python3\ngetTermCriteria() -> retval\n```","ref":"Evision.ML.SVM.html#getTermCriteria/1"},{"type":"function","title":"Evision.ML.SVM.getType/1","doc":"getType\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setType/2`\n\nPython prototype (for reference only):\n```python3\ngetType() -> retval\n```","ref":"Evision.ML.SVM.html#getType/1"},{"type":"function","title":"Evision.ML.SVM.getUncompressedSupportVectors/1","doc":"Retrieves all the uncompressed support vectors of a linear %SVM\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nThe method returns all the uncompressed support vectors of a linear %SVM that the compressed\nsupport vector, used for prediction, was derived from. They are returned in a floating-point\nmatrix, where the support vectors are stored as matrix rows.\n\nPython prototype (for reference only):\n```python3\ngetUncompressedSupportVectors() -> retval\n```","ref":"Evision.ML.SVM.html#getUncompressedSupportVectors/1"},{"type":"function","title":"Evision.ML.SVM.getVarCount/1","doc":"Returns the number of variables in training samples\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetVarCount() -> retval\n```","ref":"Evision.ML.SVM.html#getVarCount/1"},{"type":"function","title":"Evision.ML.SVM.isClassifier/1","doc":"Returns true if the model is classifier\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisClassifier() -> retval\n```","ref":"Evision.ML.SVM.html#isClassifier/1"},{"type":"function","title":"Evision.ML.SVM.isTrained/1","doc":"Returns true if the model is trained\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisTrained() -> retval\n```","ref":"Evision.ML.SVM.html#isTrained/1"},{"type":"function","title":"Evision.ML.SVM.load/1","doc":"Loads and creates a serialized svm from a file\n\n##### Positional Arguments\n- **filepath**: `String`.\n\n  path to serialized svm\n\n##### Return\n- **retval**: `Evision.ML.SVM.t()`\n\n Use SVM::save to serialize and store an SVM to disk.\n Load the SVM from this file again, by calling this function with the path to the file.\n\nPython prototype (for reference only):\n```python3\nload(filepath) -> retval\n```","ref":"Evision.ML.SVM.html#load/1"},{"type":"function","title":"Evision.ML.SVM.predict/1","doc":"","ref":"Evision.ML.SVM.html#predict/1"},{"type":"function","title":"Evision.ML.SVM.predict/2","doc":"Predicts response(s) for the provided sample(s)\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **samples**: `Evision.Mat`.\n\n  The input samples, floating-point matrix\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  The optional flags, model-dependent. See cv::ml::StatModel::Flags.\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  The optional output matrix of results.\n\nPython prototype (for reference only):\n```python3\npredict(samples[, results[, flags]]) -> retval, results\n```","ref":"Evision.ML.SVM.html#predict/2"},{"type":"function","title":"Evision.ML.SVM.predict/3","doc":"Predicts response(s) for the provided sample(s)\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **samples**: `Evision.Mat`.\n\n  The input samples, floating-point matrix\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  The optional flags, model-dependent. See cv::ml::StatModel::Flags.\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  The optional output matrix of results.\n\nPython prototype (for reference only):\n```python3\npredict(samples[, results[, flags]]) -> retval, results\n```","ref":"Evision.ML.SVM.html#predict/3"},{"type":"function","title":"Evision.ML.SVM.read/1","doc":"","ref":"Evision.ML.SVM.html#read/1"},{"type":"function","title":"Evision.ML.SVM.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.ML.SVM.html#read/2"},{"type":"function","title":"Evision.ML.SVM.save/1","doc":"","ref":"Evision.ML.SVM.html#save/1"},{"type":"function","title":"Evision.ML.SVM.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.ML.SVM.html#save/2"},{"type":"function","title":"Evision.ML.SVM.setC/1","doc":"","ref":"Evision.ML.SVM.html#setC/1"},{"type":"function","title":"Evision.ML.SVM.setC/2","doc":"setC\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **val**: `double`\n\n@see `getC/1`\n\nPython prototype (for reference only):\n```python3\nsetC(val) -> None\n```","ref":"Evision.ML.SVM.html#setC/2"},{"type":"function","title":"Evision.ML.SVM.setClassWeights/1","doc":"","ref":"Evision.ML.SVM.html#setClassWeights/1"},{"type":"function","title":"Evision.ML.SVM.setClassWeights/2","doc":"setClassWeights\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **val**: `Evision.Mat`\n\n@see `getClassWeights/1`\n\nPython prototype (for reference only):\n```python3\nsetClassWeights(val) -> None\n```","ref":"Evision.ML.SVM.html#setClassWeights/2"},{"type":"function","title":"Evision.ML.SVM.setCoef0/1","doc":"","ref":"Evision.ML.SVM.html#setCoef0/1"},{"type":"function","title":"Evision.ML.SVM.setCoef0/2","doc":"setCoef0\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **val**: `double`\n\n@see `getCoef0/1`\n\nPython prototype (for reference only):\n```python3\nsetCoef0(val) -> None\n```","ref":"Evision.ML.SVM.html#setCoef0/2"},{"type":"function","title":"Evision.ML.SVM.setDegree/1","doc":"","ref":"Evision.ML.SVM.html#setDegree/1"},{"type":"function","title":"Evision.ML.SVM.setDegree/2","doc":"setDegree\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **val**: `double`\n\n@see `getDegree/1`\n\nPython prototype (for reference only):\n```python3\nsetDegree(val) -> None\n```","ref":"Evision.ML.SVM.html#setDegree/2"},{"type":"function","title":"Evision.ML.SVM.setGamma/1","doc":"","ref":"Evision.ML.SVM.html#setGamma/1"},{"type":"function","title":"Evision.ML.SVM.setGamma/2","doc":"setGamma\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **val**: `double`\n\n@see `getGamma/1`\n\nPython prototype (for reference only):\n```python3\nsetGamma(val) -> None\n```","ref":"Evision.ML.SVM.html#setGamma/2"},{"type":"function","title":"Evision.ML.SVM.setKernel/1","doc":"","ref":"Evision.ML.SVM.html#setKernel/1"},{"type":"function","title":"Evision.ML.SVM.setKernel/2","doc":"setKernel\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **kernelType**: `integer()`\n\nInitialize with one of predefined kernels.\nSee SVM::KernelTypes.\n\nPython prototype (for reference only):\n```python3\nsetKernel(kernelType) -> None\n```","ref":"Evision.ML.SVM.html#setKernel/2"},{"type":"function","title":"Evision.ML.SVM.setNu/1","doc":"","ref":"Evision.ML.SVM.html#setNu/1"},{"type":"function","title":"Evision.ML.SVM.setNu/2","doc":"setNu\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **val**: `double`\n\n@see `getNu/1`\n\nPython prototype (for reference only):\n```python3\nsetNu(val) -> None\n```","ref":"Evision.ML.SVM.html#setNu/2"},{"type":"function","title":"Evision.ML.SVM.setP/1","doc":"","ref":"Evision.ML.SVM.html#setP/1"},{"type":"function","title":"Evision.ML.SVM.setP/2","doc":"setP\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **val**: `double`\n\n@see `getP/1`\n\nPython prototype (for reference only):\n```python3\nsetP(val) -> None\n```","ref":"Evision.ML.SVM.html#setP/2"},{"type":"function","title":"Evision.ML.SVM.setTermCriteria/1","doc":"","ref":"Evision.ML.SVM.html#setTermCriteria/1"},{"type":"function","title":"Evision.ML.SVM.setTermCriteria/2","doc":"setTermCriteria\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **val**: `TermCriteria`\n\n@see `getTermCriteria/1`\n\nPython prototype (for reference only):\n```python3\nsetTermCriteria(val) -> None\n```","ref":"Evision.ML.SVM.html#setTermCriteria/2"},{"type":"function","title":"Evision.ML.SVM.setType/1","doc":"","ref":"Evision.ML.SVM.html#setType/1"},{"type":"function","title":"Evision.ML.SVM.setType/2","doc":"setType\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **val**: `integer()`\n\n@see `getType/1`\n\nPython prototype (for reference only):\n```python3\nsetType(val) -> None\n```","ref":"Evision.ML.SVM.html#setType/2"},{"type":"function","title":"Evision.ML.SVM.train/1","doc":"","ref":"Evision.ML.SVM.html#train/1"},{"type":"function","title":"Evision.ML.SVM.train/2","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **trainData**: `Evision.ML.TrainData.t()`.\n\n  training data that can be loaded from file using TrainData::loadFromCSV or\n  created with TrainData::create.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  optional flags, depending on the model. Some of the models can be updated with the\n  new training samples, not completely overwritten (such as NormalBayesClassifier or ANN_MLP).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(trainData[, flags]) -> retval\n```","ref":"Evision.ML.SVM.html#train/2"},{"type":"function","title":"Evision.ML.SVM.train/3","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **trainData**: `Evision.ML.TrainData.t()`.\n\n  training data that can be loaded from file using TrainData::loadFromCSV or\n  created with TrainData::create.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  optional flags, depending on the model. Some of the models can be updated with the\n  new training samples, not completely overwritten (such as NormalBayesClassifier or ANN_MLP).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(trainData[, flags]) -> retval\n```","ref":"Evision.ML.SVM.html#train/3"},{"type":"function","title":"Evision.ML.SVM.train/4","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **samples**: `Evision.Mat`.\n\n  training samples\n\n- **layout**: `integer()`.\n\n  See ml::SampleTypes.\n\n- **responses**: `Evision.Mat`.\n\n  vector of responses associated with the training samples.\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(samples, layout, responses) -> retval\n```","ref":"Evision.ML.SVM.html#train/4"},{"type":"function","title":"Evision.ML.SVM.trainAuto/1","doc":"","ref":"Evision.ML.SVM.html#trainAuto/1"},{"type":"function","title":"Evision.ML.SVM.trainAuto/4","doc":"Trains an %SVM with optimal parameters\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **samples**: `Evision.Mat`.\n\n  training samples\n\n- **layout**: `integer()`.\n\n  See ml::SampleTypes.\n\n- **responses**: `Evision.Mat`.\n\n  vector of responses associated with the training samples.\n\n##### Keyword Arguments\n- **kFold**: `integer()`.\n\n  Cross-validation parameter. The training set is divided into kFold subsets. One\n  subset is used to test the model, the others form the train set. So, the %SVM algorithm is\n\n- **cgrid**: `Evision.ML.ParamGrid.t()`.\n- **gammaGrid**: `Evision.ML.ParamGrid.t()`.\n\n  grid for gamma\n\n- **pGrid**: `Evision.ML.ParamGrid.t()`.\n- **nuGrid**: `Evision.ML.ParamGrid.t()`.\n- **coeffGrid**: `Evision.ML.ParamGrid.t()`.\n\n  grid for coeff\n\n- **degreeGrid**: `Evision.ML.ParamGrid.t()`.\n\n  grid for degree\n\n- **balanced**: `bool`.\n\n  If true and the problem is 2-class classification then the method creates more\n  balanced cross-validation subsets that is proportions between classes in subsets are close\n  to such proportion in the whole train dataset.\n\n##### Return\n- **retval**: `bool`\n\nThe method trains the %SVM model automatically by choosing the optimal parameters C, gamma, p,\nnu, coef0, degree. Parameters are considered optimal when the cross-validation\nestimate of the test set error is minimal.\nThis function only makes use of SVM::getDefaultGrid for parameter optimization and thus only\noffers rudimentary parameter options.\nThis function works for the classification (SVM::C_SVC or SVM::NU_SVC) as well as for the\nregression (SVM::EPS_SVR or SVM::NU_SVR). If it is SVM::ONE_CLASS, no optimization is made and\nthe usual %SVM with parameters specified in params is executed.\n\nPython prototype (for reference only):\n```python3\ntrainAuto(samples, layout, responses[, kFold[, Cgrid[, gammaGrid[, pGrid[, nuGrid[, coeffGrid[, degreeGrid[, balanced]]]]]]]]) -> retval\n```","ref":"Evision.ML.SVM.html#trainAuto/4"},{"type":"function","title":"Evision.ML.SVM.trainAuto/5","doc":"Trains an %SVM with optimal parameters\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **samples**: `Evision.Mat`.\n\n  training samples\n\n- **layout**: `integer()`.\n\n  See ml::SampleTypes.\n\n- **responses**: `Evision.Mat`.\n\n  vector of responses associated with the training samples.\n\n##### Keyword Arguments\n- **kFold**: `integer()`.\n\n  Cross-validation parameter. The training set is divided into kFold subsets. One\n  subset is used to test the model, the others form the train set. So, the %SVM algorithm is\n\n- **cgrid**: `Evision.ML.ParamGrid.t()`.\n- **gammaGrid**: `Evision.ML.ParamGrid.t()`.\n\n  grid for gamma\n\n- **pGrid**: `Evision.ML.ParamGrid.t()`.\n- **nuGrid**: `Evision.ML.ParamGrid.t()`.\n- **coeffGrid**: `Evision.ML.ParamGrid.t()`.\n\n  grid for coeff\n\n- **degreeGrid**: `Evision.ML.ParamGrid.t()`.\n\n  grid for degree\n\n- **balanced**: `bool`.\n\n  If true and the problem is 2-class classification then the method creates more\n  balanced cross-validation subsets that is proportions between classes in subsets are close\n  to such proportion in the whole train dataset.\n\n##### Return\n- **retval**: `bool`\n\nThe method trains the %SVM model automatically by choosing the optimal parameters C, gamma, p,\nnu, coef0, degree. Parameters are considered optimal when the cross-validation\nestimate of the test set error is minimal.\nThis function only makes use of SVM::getDefaultGrid for parameter optimization and thus only\noffers rudimentary parameter options.\nThis function works for the classification (SVM::C_SVC or SVM::NU_SVC) as well as for the\nregression (SVM::EPS_SVR or SVM::NU_SVR). If it is SVM::ONE_CLASS, no optimization is made and\nthe usual %SVM with parameters specified in params is executed.\n\nPython prototype (for reference only):\n```python3\ntrainAuto(samples, layout, responses[, kFold[, Cgrid[, gammaGrid[, pGrid[, nuGrid[, coeffGrid[, degreeGrid[, balanced]]]]]]]]) -> retval\n```","ref":"Evision.ML.SVM.html#trainAuto/5"},{"type":"function","title":"Evision.ML.SVM.write/1","doc":"","ref":"Evision.ML.SVM.html#write/1"},{"type":"function","title":"Evision.ML.SVM.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.ML.SVM.html#write/2"},{"type":"function","title":"Evision.ML.SVM.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVM.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.ML.SVM.html#write/3"},{"type":"type","title":"Evision.ML.SVM.t/0","doc":"Type that represents an `ML.SVM` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ML.SVM.html#t:t/0"},{"type":"module","title":"Evision.ML.SVM.KernelTypes","doc":"","ref":"Evision.ML.SVM.KernelTypes.html"},{"type":"function","title":"Evision.ML.SVM.KernelTypes.cv_CHI2/0","doc":"","ref":"Evision.ML.SVM.KernelTypes.html#cv_CHI2/0"},{"type":"function","title":"Evision.ML.SVM.KernelTypes.cv_CUSTOM/0","doc":"","ref":"Evision.ML.SVM.KernelTypes.html#cv_CUSTOM/0"},{"type":"function","title":"Evision.ML.SVM.KernelTypes.cv_INTER/0","doc":"","ref":"Evision.ML.SVM.KernelTypes.html#cv_INTER/0"},{"type":"function","title":"Evision.ML.SVM.KernelTypes.cv_LINEAR/0","doc":"","ref":"Evision.ML.SVM.KernelTypes.html#cv_LINEAR/0"},{"type":"function","title":"Evision.ML.SVM.KernelTypes.cv_POLY/0","doc":"","ref":"Evision.ML.SVM.KernelTypes.html#cv_POLY/0"},{"type":"function","title":"Evision.ML.SVM.KernelTypes.cv_RBF/0","doc":"","ref":"Evision.ML.SVM.KernelTypes.html#cv_RBF/0"},{"type":"function","title":"Evision.ML.SVM.KernelTypes.cv_SIGMOID/0","doc":"","ref":"Evision.ML.SVM.KernelTypes.html#cv_SIGMOID/0"},{"type":"type","title":"Evision.ML.SVM.KernelTypes.enum/0","doc":"","ref":"Evision.ML.SVM.KernelTypes.html#t:enum/0"},{"type":"module","title":"Evision.ML.SVM.ParamTypes","doc":"","ref":"Evision.ML.SVM.ParamTypes.html"},{"type":"function","title":"Evision.ML.SVM.ParamTypes.cv_C/0","doc":"","ref":"Evision.ML.SVM.ParamTypes.html#cv_C/0"},{"type":"function","title":"Evision.ML.SVM.ParamTypes.cv_COEF/0","doc":"","ref":"Evision.ML.SVM.ParamTypes.html#cv_COEF/0"},{"type":"function","title":"Evision.ML.SVM.ParamTypes.cv_DEGREE/0","doc":"","ref":"Evision.ML.SVM.ParamTypes.html#cv_DEGREE/0"},{"type":"function","title":"Evision.ML.SVM.ParamTypes.cv_GAMMA/0","doc":"","ref":"Evision.ML.SVM.ParamTypes.html#cv_GAMMA/0"},{"type":"function","title":"Evision.ML.SVM.ParamTypes.cv_NU/0","doc":"","ref":"Evision.ML.SVM.ParamTypes.html#cv_NU/0"},{"type":"function","title":"Evision.ML.SVM.ParamTypes.cv_P/0","doc":"","ref":"Evision.ML.SVM.ParamTypes.html#cv_P/0"},{"type":"type","title":"Evision.ML.SVM.ParamTypes.enum/0","doc":"","ref":"Evision.ML.SVM.ParamTypes.html#t:enum/0"},{"type":"module","title":"Evision.ML.SVM.Types","doc":"","ref":"Evision.ML.SVM.Types.html"},{"type":"function","title":"Evision.ML.SVM.Types.cv_C_SVC/0","doc":"","ref":"Evision.ML.SVM.Types.html#cv_C_SVC/0"},{"type":"function","title":"Evision.ML.SVM.Types.cv_EPS_SVR/0","doc":"","ref":"Evision.ML.SVM.Types.html#cv_EPS_SVR/0"},{"type":"function","title":"Evision.ML.SVM.Types.cv_NU_SVC/0","doc":"","ref":"Evision.ML.SVM.Types.html#cv_NU_SVC/0"},{"type":"function","title":"Evision.ML.SVM.Types.cv_NU_SVR/0","doc":"","ref":"Evision.ML.SVM.Types.html#cv_NU_SVR/0"},{"type":"function","title":"Evision.ML.SVM.Types.cv_ONE_CLASS/0","doc":"","ref":"Evision.ML.SVM.Types.html#cv_ONE_CLASS/0"},{"type":"type","title":"Evision.ML.SVM.Types.enum/0","doc":"","ref":"Evision.ML.SVM.Types.html#t:enum/0"},{"type":"module","title":"Evision.ML.SVMSGD","doc":"","ref":"Evision.ML.SVMSGD.html"},{"type":"function","title":"Evision.ML.SVMSGD.calcError/1","doc":"","ref":"Evision.ML.SVMSGD.html#calcError/1"},{"type":"function","title":"Evision.ML.SVMSGD.calcError/3","doc":"Computes error on the training or test dataset\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n- **data**: `Evision.ML.TrainData.t()`.\n\n  the training data\n\n- **test**: `bool`.\n\n  if true, the error is computed over the test subset of the data, otherwise it's\n  computed over the training subset of the data. Please note that if you loaded a completely\n  different dataset to evaluate already trained classifier, you will probably want not to set\n  the test subset at all with TrainData::setTrainTestSplitRatio and specify test=false, so\n  that the error is computed for the whole new set. Yes, this sounds a bit confusing.\n\n##### Return\n- **retval**: `float`\n- **resp**: `Evision.Mat.t()`.\n\n  the optional output responses.\n\nThe method uses StatModel::predict to compute the error. For regression models the error is\ncomputed as RMS, for classifiers - as a percent of missclassified samples (0%-100%).\n\nPython prototype (for reference only):\n```python3\ncalcError(data, test[, resp]) -> retval, resp\n```","ref":"Evision.ML.SVMSGD.html#calcError/3"},{"type":"function","title":"Evision.ML.SVMSGD.calcError/4","doc":"Computes error on the training or test dataset\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n- **data**: `Evision.ML.TrainData.t()`.\n\n  the training data\n\n- **test**: `bool`.\n\n  if true, the error is computed over the test subset of the data, otherwise it's\n  computed over the training subset of the data. Please note that if you loaded a completely\n  different dataset to evaluate already trained classifier, you will probably want not to set\n  the test subset at all with TrainData::setTrainTestSplitRatio and specify test=false, so\n  that the error is computed for the whole new set. Yes, this sounds a bit confusing.\n\n##### Return\n- **retval**: `float`\n- **resp**: `Evision.Mat.t()`.\n\n  the optional output responses.\n\nThe method uses StatModel::predict to compute the error. For regression models the error is\ncomputed as RMS, for classifiers - as a percent of missclassified samples (0%-100%).\n\nPython prototype (for reference only):\n```python3\ncalcError(data, test[, resp]) -> retval, resp\n```","ref":"Evision.ML.SVMSGD.html#calcError/4"},{"type":"function","title":"Evision.ML.SVMSGD.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.ML.SVMSGD.html#clear/1"},{"type":"function","title":"Evision.ML.SVMSGD.create/0","doc":"Creates empty model.\nUse StatModel::train to train the model. Since %SVMSGD has several parameters, you may want to\nfind the best parameters for your problem or use setOptimalParameters() to set some default parameters.\n\n##### Return\n- **retval**: `Evision.ML.SVMSGD.t()`\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.ML.SVMSGD.html#create/0"},{"type":"function","title":"Evision.ML.SVMSGD.create/1","doc":"","ref":"Evision.ML.SVMSGD.html#create/1"},{"type":"function","title":"Evision.ML.SVMSGD.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.ML.SVMSGD.html#empty/1"},{"type":"function","title":"Evision.ML.SVMSGD.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.ML.SVMSGD.html#getDefaultName/1"},{"type":"function","title":"Evision.ML.SVMSGD.getInitialStepSize/1","doc":"getInitialStepSize\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setInitialStepSize/2`\n\nPython prototype (for reference only):\n```python3\ngetInitialStepSize() -> retval\n```","ref":"Evision.ML.SVMSGD.html#getInitialStepSize/1"},{"type":"function","title":"Evision.ML.SVMSGD.getMarginRegularization/1","doc":"getMarginRegularization\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setMarginRegularization/2`\n\nPython prototype (for reference only):\n```python3\ngetMarginRegularization() -> retval\n```","ref":"Evision.ML.SVMSGD.html#getMarginRegularization/1"},{"type":"function","title":"Evision.ML.SVMSGD.getMarginType/1","doc":"getMarginType\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setMarginType/2`\n\nPython prototype (for reference only):\n```python3\ngetMarginType() -> retval\n```","ref":"Evision.ML.SVMSGD.html#getMarginType/1"},{"type":"function","title":"Evision.ML.SVMSGD.getShift/1","doc":"getShift\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n\n##### Return\n- **retval**: `float`\n\n@return the shift of the trained model (decision function f(x) = weights * x + shift).\n\nPython prototype (for reference only):\n```python3\ngetShift() -> retval\n```","ref":"Evision.ML.SVMSGD.html#getShift/1"},{"type":"function","title":"Evision.ML.SVMSGD.getStepDecreasingPower/1","doc":"getStepDecreasingPower\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setStepDecreasingPower/2`\n\nPython prototype (for reference only):\n```python3\ngetStepDecreasingPower() -> retval\n```","ref":"Evision.ML.SVMSGD.html#getStepDecreasingPower/1"},{"type":"function","title":"Evision.ML.SVMSGD.getSvmsgdType/1","doc":"getSvmsgdType\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setSvmsgdType/2`\n\nPython prototype (for reference only):\n```python3\ngetSvmsgdType() -> retval\n```","ref":"Evision.ML.SVMSGD.html#getSvmsgdType/1"},{"type":"function","title":"Evision.ML.SVMSGD.getTermCriteria/1","doc":"getTermCriteria\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n\n##### Return\n- **retval**: `TermCriteria`\n\n@see `setTermCriteria/2`\n\nPython prototype (for reference only):\n```python3\ngetTermCriteria() -> retval\n```","ref":"Evision.ML.SVMSGD.html#getTermCriteria/1"},{"type":"function","title":"Evision.ML.SVMSGD.getVarCount/1","doc":"Returns the number of variables in training samples\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetVarCount() -> retval\n```","ref":"Evision.ML.SVMSGD.html#getVarCount/1"},{"type":"function","title":"Evision.ML.SVMSGD.getWeights/1","doc":"getWeights\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n@return the weights of the trained model (decision function f(x) = weights * x + shift).\n\nPython prototype (for reference only):\n```python3\ngetWeights() -> retval\n```","ref":"Evision.ML.SVMSGD.html#getWeights/1"},{"type":"function","title":"Evision.ML.SVMSGD.isClassifier/1","doc":"Returns true if the model is classifier\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisClassifier() -> retval\n```","ref":"Evision.ML.SVMSGD.html#isClassifier/1"},{"type":"function","title":"Evision.ML.SVMSGD.isTrained/1","doc":"Returns true if the model is trained\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisTrained() -> retval\n```","ref":"Evision.ML.SVMSGD.html#isTrained/1"},{"type":"function","title":"Evision.ML.SVMSGD.load/1","doc":"Loads and creates a serialized SVMSGD from a file\n\n##### Positional Arguments\n- **filepath**: `String`.\n\n  path to serialized SVMSGD\n\n##### Keyword Arguments\n- **nodeName**: `String`.\n\n  name of node containing the classifier\n\n##### Return\n- **retval**: `Evision.ML.SVMSGD.t()`\n\n Use SVMSGD::save to serialize and store an SVMSGD to disk.\n Load the SVMSGD from this file again, by calling this function with the path to the file.\n Optionally specify the node for the file containing the classifier\n\nPython prototype (for reference only):\n```python3\nload(filepath[, nodeName]) -> retval\n```","ref":"Evision.ML.SVMSGD.html#load/1"},{"type":"function","title":"Evision.ML.SVMSGD.load/2","doc":"Loads and creates a serialized SVMSGD from a file\n\n##### Positional Arguments\n- **filepath**: `String`.\n\n  path to serialized SVMSGD\n\n##### Keyword Arguments\n- **nodeName**: `String`.\n\n  name of node containing the classifier\n\n##### Return\n- **retval**: `Evision.ML.SVMSGD.t()`\n\n Use SVMSGD::save to serialize and store an SVMSGD to disk.\n Load the SVMSGD from this file again, by calling this function with the path to the file.\n Optionally specify the node for the file containing the classifier\n\nPython prototype (for reference only):\n```python3\nload(filepath[, nodeName]) -> retval\n```","ref":"Evision.ML.SVMSGD.html#load/2"},{"type":"function","title":"Evision.ML.SVMSGD.predict/1","doc":"","ref":"Evision.ML.SVMSGD.html#predict/1"},{"type":"function","title":"Evision.ML.SVMSGD.predict/2","doc":"Predicts response(s) for the provided sample(s)\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n- **samples**: `Evision.Mat`.\n\n  The input samples, floating-point matrix\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  The optional flags, model-dependent. See cv::ml::StatModel::Flags.\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  The optional output matrix of results.\n\nPython prototype (for reference only):\n```python3\npredict(samples[, results[, flags]]) -> retval, results\n```","ref":"Evision.ML.SVMSGD.html#predict/2"},{"type":"function","title":"Evision.ML.SVMSGD.predict/3","doc":"Predicts response(s) for the provided sample(s)\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n- **samples**: `Evision.Mat`.\n\n  The input samples, floating-point matrix\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  The optional flags, model-dependent. See cv::ml::StatModel::Flags.\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  The optional output matrix of results.\n\nPython prototype (for reference only):\n```python3\npredict(samples[, results[, flags]]) -> retval, results\n```","ref":"Evision.ML.SVMSGD.html#predict/3"},{"type":"function","title":"Evision.ML.SVMSGD.read/1","doc":"","ref":"Evision.ML.SVMSGD.html#read/1"},{"type":"function","title":"Evision.ML.SVMSGD.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.ML.SVMSGD.html#read/2"},{"type":"function","title":"Evision.ML.SVMSGD.save/1","doc":"","ref":"Evision.ML.SVMSGD.html#save/1"},{"type":"function","title":"Evision.ML.SVMSGD.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.ML.SVMSGD.html#save/2"},{"type":"function","title":"Evision.ML.SVMSGD.setInitialStepSize/1","doc":"","ref":"Evision.ML.SVMSGD.html#setInitialStepSize/1"},{"type":"function","title":"Evision.ML.SVMSGD.setInitialStepSize/2","doc":"setInitialStepSize\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n- **initialStepSize**: `float`\n\n@see `getInitialStepSize/1`\n\nPython prototype (for reference only):\n```python3\nsetInitialStepSize(InitialStepSize) -> None\n```","ref":"Evision.ML.SVMSGD.html#setInitialStepSize/2"},{"type":"function","title":"Evision.ML.SVMSGD.setMarginRegularization/1","doc":"","ref":"Evision.ML.SVMSGD.html#setMarginRegularization/1"},{"type":"function","title":"Evision.ML.SVMSGD.setMarginRegularization/2","doc":"setMarginRegularization\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n- **marginRegularization**: `float`\n\n@see `getMarginRegularization/1`\n\nPython prototype (for reference only):\n```python3\nsetMarginRegularization(marginRegularization) -> None\n```","ref":"Evision.ML.SVMSGD.html#setMarginRegularization/2"},{"type":"function","title":"Evision.ML.SVMSGD.setMarginType/1","doc":"","ref":"Evision.ML.SVMSGD.html#setMarginType/1"},{"type":"function","title":"Evision.ML.SVMSGD.setMarginType/2","doc":"setMarginType\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n- **marginType**: `integer()`\n\n@see `getMarginType/1`\n\nPython prototype (for reference only):\n```python3\nsetMarginType(marginType) -> None\n```","ref":"Evision.ML.SVMSGD.html#setMarginType/2"},{"type":"function","title":"Evision.ML.SVMSGD.setOptimalParameters/1","doc":"Function sets optimal parameters values for chosen SVM SGD model.\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n\n##### Keyword Arguments\n- **svmsgdType**: `integer()`.\n\n  is the type of SVMSGD classifier.\n\n- **marginType**: `integer()`.\n\n  is the type of margin constraint.\n\nPython prototype (for reference only):\n```python3\nsetOptimalParameters([, svmsgdType[, marginType]]) -> None\n```","ref":"Evision.ML.SVMSGD.html#setOptimalParameters/1"},{"type":"function","title":"Evision.ML.SVMSGD.setOptimalParameters/2","doc":"Function sets optimal parameters values for chosen SVM SGD model.\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n\n##### Keyword Arguments\n- **svmsgdType**: `integer()`.\n\n  is the type of SVMSGD classifier.\n\n- **marginType**: `integer()`.\n\n  is the type of margin constraint.\n\nPython prototype (for reference only):\n```python3\nsetOptimalParameters([, svmsgdType[, marginType]]) -> None\n```","ref":"Evision.ML.SVMSGD.html#setOptimalParameters/2"},{"type":"function","title":"Evision.ML.SVMSGD.setStepDecreasingPower/1","doc":"","ref":"Evision.ML.SVMSGD.html#setStepDecreasingPower/1"},{"type":"function","title":"Evision.ML.SVMSGD.setStepDecreasingPower/2","doc":"setStepDecreasingPower\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n- **stepDecreasingPower**: `float`\n\n@see `getStepDecreasingPower/1`\n\nPython prototype (for reference only):\n```python3\nsetStepDecreasingPower(stepDecreasingPower) -> None\n```","ref":"Evision.ML.SVMSGD.html#setStepDecreasingPower/2"},{"type":"function","title":"Evision.ML.SVMSGD.setSvmsgdType/1","doc":"","ref":"Evision.ML.SVMSGD.html#setSvmsgdType/1"},{"type":"function","title":"Evision.ML.SVMSGD.setSvmsgdType/2","doc":"setSvmsgdType\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n- **svmsgdType**: `integer()`\n\n@see `getSvmsgdType/1`\n\nPython prototype (for reference only):\n```python3\nsetSvmsgdType(svmsgdType) -> None\n```","ref":"Evision.ML.SVMSGD.html#setSvmsgdType/2"},{"type":"function","title":"Evision.ML.SVMSGD.setTermCriteria/1","doc":"","ref":"Evision.ML.SVMSGD.html#setTermCriteria/1"},{"type":"function","title":"Evision.ML.SVMSGD.setTermCriteria/2","doc":"setTermCriteria\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n- **val**: `TermCriteria`\n\n@see `getTermCriteria/1`\n\nPython prototype (for reference only):\n```python3\nsetTermCriteria(val) -> None\n```","ref":"Evision.ML.SVMSGD.html#setTermCriteria/2"},{"type":"function","title":"Evision.ML.SVMSGD.train/1","doc":"","ref":"Evision.ML.SVMSGD.html#train/1"},{"type":"function","title":"Evision.ML.SVMSGD.train/2","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n- **trainData**: `Evision.ML.TrainData.t()`.\n\n  training data that can be loaded from file using TrainData::loadFromCSV or\n  created with TrainData::create.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  optional flags, depending on the model. Some of the models can be updated with the\n  new training samples, not completely overwritten (such as NormalBayesClassifier or ANN_MLP).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(trainData[, flags]) -> retval\n```","ref":"Evision.ML.SVMSGD.html#train/2"},{"type":"function","title":"Evision.ML.SVMSGD.train/3","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n- **trainData**: `Evision.ML.TrainData.t()`.\n\n  training data that can be loaded from file using TrainData::loadFromCSV or\n  created with TrainData::create.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  optional flags, depending on the model. Some of the models can be updated with the\n  new training samples, not completely overwritten (such as NormalBayesClassifier or ANN_MLP).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(trainData[, flags]) -> retval\n```","ref":"Evision.ML.SVMSGD.html#train/3"},{"type":"function","title":"Evision.ML.SVMSGD.train/4","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n- **samples**: `Evision.Mat`.\n\n  training samples\n\n- **layout**: `integer()`.\n\n  See ml::SampleTypes.\n\n- **responses**: `Evision.Mat`.\n\n  vector of responses associated with the training samples.\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(samples, layout, responses) -> retval\n```","ref":"Evision.ML.SVMSGD.html#train/4"},{"type":"function","title":"Evision.ML.SVMSGD.write/1","doc":"","ref":"Evision.ML.SVMSGD.html#write/1"},{"type":"function","title":"Evision.ML.SVMSGD.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.ML.SVMSGD.html#write/2"},{"type":"function","title":"Evision.ML.SVMSGD.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.ML.SVMSGD.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.ML.SVMSGD.html#write/3"},{"type":"type","title":"Evision.ML.SVMSGD.t/0","doc":"Type that represents an `ML.SVMSGD` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ML.SVMSGD.html#t:t/0"},{"type":"module","title":"Evision.ML.SVMSGD.MarginType","doc":"","ref":"Evision.ML.SVMSGD.MarginType.html"},{"type":"function","title":"Evision.ML.SVMSGD.MarginType.cv_HARD_MARGIN/0","doc":"","ref":"Evision.ML.SVMSGD.MarginType.html#cv_HARD_MARGIN/0"},{"type":"function","title":"Evision.ML.SVMSGD.MarginType.cv_SOFT_MARGIN/0","doc":"","ref":"Evision.ML.SVMSGD.MarginType.html#cv_SOFT_MARGIN/0"},{"type":"type","title":"Evision.ML.SVMSGD.MarginType.enum/0","doc":"","ref":"Evision.ML.SVMSGD.MarginType.html#t:enum/0"},{"type":"module","title":"Evision.ML.SVMSGD.SvmsgdType","doc":"","ref":"Evision.ML.SVMSGD.SvmsgdType.html"},{"type":"function","title":"Evision.ML.SVMSGD.SvmsgdType.cv_ASGD/0","doc":"","ref":"Evision.ML.SVMSGD.SvmsgdType.html#cv_ASGD/0"},{"type":"function","title":"Evision.ML.SVMSGD.SvmsgdType.cv_SGD/0","doc":"","ref":"Evision.ML.SVMSGD.SvmsgdType.html#cv_SGD/0"},{"type":"type","title":"Evision.ML.SVMSGD.SvmsgdType.enum/0","doc":"","ref":"Evision.ML.SVMSGD.SvmsgdType.html#t:enum/0"},{"type":"module","title":"Evision.ML.SampleTypes","doc":"","ref":"Evision.ML.SampleTypes.html"},{"type":"function","title":"Evision.ML.SampleTypes.cv_COL_SAMPLE/0","doc":"","ref":"Evision.ML.SampleTypes.html#cv_COL_SAMPLE/0"},{"type":"function","title":"Evision.ML.SampleTypes.cv_ROW_SAMPLE/0","doc":"","ref":"Evision.ML.SampleTypes.html#cv_ROW_SAMPLE/0"},{"type":"type","title":"Evision.ML.SampleTypes.enum/0","doc":"","ref":"Evision.ML.SampleTypes.html#t:enum/0"},{"type":"module","title":"Evision.ML.StatModel","doc":"","ref":"Evision.ML.StatModel.html"},{"type":"function","title":"Evision.ML.StatModel.calcError/1","doc":"","ref":"Evision.ML.StatModel.html#calcError/1"},{"type":"function","title":"Evision.ML.StatModel.calcError/3","doc":"Computes error on the training or test dataset\n\n##### Positional Arguments\n- **self**: `Evision.ML.StatModel.t()`\n- **data**: `Evision.ML.TrainData.t()`.\n\n  the training data\n\n- **test**: `bool`.\n\n  if true, the error is computed over the test subset of the data, otherwise it's\n  computed over the training subset of the data. Please note that if you loaded a completely\n  different dataset to evaluate already trained classifier, you will probably want not to set\n  the test subset at all with TrainData::setTrainTestSplitRatio and specify test=false, so\n  that the error is computed for the whole new set. Yes, this sounds a bit confusing.\n\n##### Return\n- **retval**: `float`\n- **resp**: `Evision.Mat.t()`.\n\n  the optional output responses.\n\nThe method uses StatModel::predict to compute the error. For regression models the error is\ncomputed as RMS, for classifiers - as a percent of missclassified samples (0%-100%).\n\nPython prototype (for reference only):\n```python3\ncalcError(data, test[, resp]) -> retval, resp\n```","ref":"Evision.ML.StatModel.html#calcError/3"},{"type":"function","title":"Evision.ML.StatModel.calcError/4","doc":"Computes error on the training or test dataset\n\n##### Positional Arguments\n- **self**: `Evision.ML.StatModel.t()`\n- **data**: `Evision.ML.TrainData.t()`.\n\n  the training data\n\n- **test**: `bool`.\n\n  if true, the error is computed over the test subset of the data, otherwise it's\n  computed over the training subset of the data. Please note that if you loaded a completely\n  different dataset to evaluate already trained classifier, you will probably want not to set\n  the test subset at all with TrainData::setTrainTestSplitRatio and specify test=false, so\n  that the error is computed for the whole new set. Yes, this sounds a bit confusing.\n\n##### Return\n- **retval**: `float`\n- **resp**: `Evision.Mat.t()`.\n\n  the optional output responses.\n\nThe method uses StatModel::predict to compute the error. For regression models the error is\ncomputed as RMS, for classifiers - as a percent of missclassified samples (0%-100%).\n\nPython prototype (for reference only):\n```python3\ncalcError(data, test[, resp]) -> retval, resp\n```","ref":"Evision.ML.StatModel.html#calcError/4"},{"type":"function","title":"Evision.ML.StatModel.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.ML.StatModel.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.ML.StatModel.html#clear/1"},{"type":"function","title":"Evision.ML.StatModel.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.ML.StatModel.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.ML.StatModel.html#empty/1"},{"type":"function","title":"Evision.ML.StatModel.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.ML.StatModel.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.ML.StatModel.html#getDefaultName/1"},{"type":"function","title":"Evision.ML.StatModel.getVarCount/1","doc":"Returns the number of variables in training samples\n\n##### Positional Arguments\n- **self**: `Evision.ML.StatModel.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetVarCount() -> retval\n```","ref":"Evision.ML.StatModel.html#getVarCount/1"},{"type":"function","title":"Evision.ML.StatModel.isClassifier/1","doc":"Returns true if the model is classifier\n\n##### Positional Arguments\n- **self**: `Evision.ML.StatModel.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisClassifier() -> retval\n```","ref":"Evision.ML.StatModel.html#isClassifier/1"},{"type":"function","title":"Evision.ML.StatModel.isTrained/1","doc":"Returns true if the model is trained\n\n##### Positional Arguments\n- **self**: `Evision.ML.StatModel.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisTrained() -> retval\n```","ref":"Evision.ML.StatModel.html#isTrained/1"},{"type":"function","title":"Evision.ML.StatModel.predict/1","doc":"","ref":"Evision.ML.StatModel.html#predict/1"},{"type":"function","title":"Evision.ML.StatModel.predict/2","doc":"Predicts response(s) for the provided sample(s)\n\n##### Positional Arguments\n- **self**: `Evision.ML.StatModel.t()`\n- **samples**: `Evision.Mat`.\n\n  The input samples, floating-point matrix\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  The optional flags, model-dependent. See cv::ml::StatModel::Flags.\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  The optional output matrix of results.\n\nPython prototype (for reference only):\n```python3\npredict(samples[, results[, flags]]) -> retval, results\n```","ref":"Evision.ML.StatModel.html#predict/2"},{"type":"function","title":"Evision.ML.StatModel.predict/3","doc":"Predicts response(s) for the provided sample(s)\n\n##### Positional Arguments\n- **self**: `Evision.ML.StatModel.t()`\n- **samples**: `Evision.Mat`.\n\n  The input samples, floating-point matrix\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  The optional flags, model-dependent. See cv::ml::StatModel::Flags.\n\n##### Return\n- **retval**: `float`\n- **results**: `Evision.Mat.t()`.\n\n  The optional output matrix of results.\n\nPython prototype (for reference only):\n```python3\npredict(samples[, results[, flags]]) -> retval, results\n```","ref":"Evision.ML.StatModel.html#predict/3"},{"type":"function","title":"Evision.ML.StatModel.read/1","doc":"","ref":"Evision.ML.StatModel.html#read/1"},{"type":"function","title":"Evision.ML.StatModel.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ML.StatModel.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.ML.StatModel.html#read/2"},{"type":"function","title":"Evision.ML.StatModel.save/1","doc":"","ref":"Evision.ML.StatModel.html#save/1"},{"type":"function","title":"Evision.ML.StatModel.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.ML.StatModel.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.ML.StatModel.html#save/2"},{"type":"function","title":"Evision.ML.StatModel.train/1","doc":"","ref":"Evision.ML.StatModel.html#train/1"},{"type":"function","title":"Evision.ML.StatModel.train/2","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.StatModel.t()`\n- **trainData**: `Evision.ML.TrainData.t()`.\n\n  training data that can be loaded from file using TrainData::loadFromCSV or\n  created with TrainData::create.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  optional flags, depending on the model. Some of the models can be updated with the\n  new training samples, not completely overwritten (such as NormalBayesClassifier or ANN_MLP).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(trainData[, flags]) -> retval\n```","ref":"Evision.ML.StatModel.html#train/2"},{"type":"function","title":"Evision.ML.StatModel.train/3","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.StatModel.t()`\n- **trainData**: `Evision.ML.TrainData.t()`.\n\n  training data that can be loaded from file using TrainData::loadFromCSV or\n  created with TrainData::create.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  optional flags, depending on the model. Some of the models can be updated with the\n  new training samples, not completely overwritten (such as NormalBayesClassifier or ANN_MLP).\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(trainData[, flags]) -> retval\n```","ref":"Evision.ML.StatModel.html#train/3"},{"type":"function","title":"Evision.ML.StatModel.train/4","doc":"Trains the statistical model\n\n##### Positional Arguments\n- **self**: `Evision.ML.StatModel.t()`\n- **samples**: `Evision.Mat`.\n\n  training samples\n\n- **layout**: `integer()`.\n\n  See ml::SampleTypes.\n\n- **responses**: `Evision.Mat`.\n\n  vector of responses associated with the training samples.\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntrain(samples, layout, responses) -> retval\n```","ref":"Evision.ML.StatModel.html#train/4"},{"type":"function","title":"Evision.ML.StatModel.write/1","doc":"","ref":"Evision.ML.StatModel.html#write/1"},{"type":"function","title":"Evision.ML.StatModel.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ML.StatModel.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.ML.StatModel.html#write/2"},{"type":"function","title":"Evision.ML.StatModel.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.ML.StatModel.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.ML.StatModel.html#write/3"},{"type":"type","title":"Evision.ML.StatModel.t/0","doc":"Type that represents an `ML.StatModel` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ML.StatModel.html#t:t/0"},{"type":"module","title":"Evision.ML.StatModel.Flags","doc":"","ref":"Evision.ML.StatModel.Flags.html"},{"type":"function","title":"Evision.ML.StatModel.Flags.cv_COMPRESSED_INPUT/0","doc":"","ref":"Evision.ML.StatModel.Flags.html#cv_COMPRESSED_INPUT/0"},{"type":"function","title":"Evision.ML.StatModel.Flags.cv_PREPROCESSED_INPUT/0","doc":"","ref":"Evision.ML.StatModel.Flags.html#cv_PREPROCESSED_INPUT/0"},{"type":"function","title":"Evision.ML.StatModel.Flags.cv_RAW_OUTPUT/0","doc":"","ref":"Evision.ML.StatModel.Flags.html#cv_RAW_OUTPUT/0"},{"type":"function","title":"Evision.ML.StatModel.Flags.cv_UPDATE_MODEL/0","doc":"","ref":"Evision.ML.StatModel.Flags.html#cv_UPDATE_MODEL/0"},{"type":"type","title":"Evision.ML.StatModel.Flags.enum/0","doc":"","ref":"Evision.ML.StatModel.Flags.html#t:enum/0"},{"type":"module","title":"Evision.ML.TrainData","doc":"","ref":"Evision.ML.TrainData.html"},{"type":"function","title":"Evision.ML.TrainData.create/1","doc":"","ref":"Evision.ML.TrainData.html#create/1"},{"type":"function","title":"Evision.ML.TrainData.create/3","doc":"Creates training data from in-memory arrays.\n\n##### Positional Arguments\n- **samples**: `Evision.Mat`.\n\n  matrix of samples. It should have CV_32F type.\n\n- **layout**: `integer()`.\n\n  see ml::SampleTypes.\n\n- **responses**: `Evision.Mat`.\n\n  matrix of responses. If the responses are scalar, they should be stored as a\n  single row or as a single column. The matrix should have type CV_32F or CV_32S (in the\n  former case the responses are considered as ordered by default; in the latter case - as\n  categorical)\n\n##### Keyword Arguments\n- **varIdx**: `Evision.Mat`.\n\n  vector specifying which variables to use for training. It can be an integer vector\n  (CV_32S) containing 0-based variable indices or byte vector (CV_8U) containing a mask of\n  active variables.\n\n- **sampleIdx**: `Evision.Mat`.\n\n  vector specifying which samples to use for training. It can be an integer\n  vector (CV_32S) containing 0-based sample indices or byte vector (CV_8U) containing a mask\n  of training samples.\n\n- **sampleWeights**: `Evision.Mat`.\n\n  optional vector with weights for each sample. It should have CV_32F type.\n\n- **varType**: `Evision.Mat`.\n\n  optional vector of type CV_8U and size `  +\n   `, containing types of each input and output variable. See\n  ml::VariableTypes.\n\n##### Return\n- **retval**: `Evision.ML.TrainData.t()`\n\nPython prototype (for reference only):\n```python3\ncreate(samples, layout, responses[, varIdx[, sampleIdx[, sampleWeights[, varType]]]]) -> retval\n```","ref":"Evision.ML.TrainData.html#create/3"},{"type":"function","title":"Evision.ML.TrainData.create/4","doc":"Creates training data from in-memory arrays.\n\n##### Positional Arguments\n- **samples**: `Evision.Mat`.\n\n  matrix of samples. It should have CV_32F type.\n\n- **layout**: `integer()`.\n\n  see ml::SampleTypes.\n\n- **responses**: `Evision.Mat`.\n\n  matrix of responses. If the responses are scalar, they should be stored as a\n  single row or as a single column. The matrix should have type CV_32F or CV_32S (in the\n  former case the responses are considered as ordered by default; in the latter case - as\n  categorical)\n\n##### Keyword Arguments\n- **varIdx**: `Evision.Mat`.\n\n  vector specifying which variables to use for training. It can be an integer vector\n  (CV_32S) containing 0-based variable indices or byte vector (CV_8U) containing a mask of\n  active variables.\n\n- **sampleIdx**: `Evision.Mat`.\n\n  vector specifying which samples to use for training. It can be an integer\n  vector (CV_32S) containing 0-based sample indices or byte vector (CV_8U) containing a mask\n  of training samples.\n\n- **sampleWeights**: `Evision.Mat`.\n\n  optional vector with weights for each sample. It should have CV_32F type.\n\n- **varType**: `Evision.Mat`.\n\n  optional vector of type CV_8U and size `  +\n   `, containing types of each input and output variable. See\n  ml::VariableTypes.\n\n##### Return\n- **retval**: `Evision.ML.TrainData.t()`\n\nPython prototype (for reference only):\n```python3\ncreate(samples, layout, responses[, varIdx[, sampleIdx[, sampleWeights[, varType]]]]) -> retval\n```","ref":"Evision.ML.TrainData.html#create/4"},{"type":"function","title":"Evision.ML.TrainData.getCatCount/1","doc":"","ref":"Evision.ML.TrainData.html#getCatCount/1"},{"type":"function","title":"Evision.ML.TrainData.getCatCount/2","doc":"getCatCount\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n- **vi**: `integer()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetCatCount(vi) -> retval\n```","ref":"Evision.ML.TrainData.html#getCatCount/2"},{"type":"function","title":"Evision.ML.TrainData.getCatMap/1","doc":"getCatMap\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetCatMap() -> retval\n```","ref":"Evision.ML.TrainData.html#getCatMap/1"},{"type":"function","title":"Evision.ML.TrainData.getCatOfs/1","doc":"getCatOfs\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetCatOfs() -> retval\n```","ref":"Evision.ML.TrainData.html#getCatOfs/1"},{"type":"function","title":"Evision.ML.TrainData.getClassLabels/1","doc":"Returns the vector of class labels\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nThe function returns vector of unique labels occurred in the responses.\n\nPython prototype (for reference only):\n```python3\ngetClassLabels() -> retval\n```","ref":"Evision.ML.TrainData.html#getClassLabels/1"},{"type":"function","title":"Evision.ML.TrainData.getDefaultSubstValues/1","doc":"getDefaultSubstValues\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetDefaultSubstValues() -> retval\n```","ref":"Evision.ML.TrainData.html#getDefaultSubstValues/1"},{"type":"function","title":"Evision.ML.TrainData.getLayout/1","doc":"getLayout\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetLayout() -> retval\n```","ref":"Evision.ML.TrainData.html#getLayout/1"},{"type":"function","title":"Evision.ML.TrainData.getMissing/1","doc":"getMissing\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetMissing() -> retval\n```","ref":"Evision.ML.TrainData.html#getMissing/1"},{"type":"function","title":"Evision.ML.TrainData.getNAllVars/1","doc":"getNAllVars\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNAllVars() -> retval\n```","ref":"Evision.ML.TrainData.html#getNAllVars/1"},{"type":"function","title":"Evision.ML.TrainData.getNames/1","doc":"","ref":"Evision.ML.TrainData.html#getNames/1"},{"type":"function","title":"Evision.ML.TrainData.getNames/2","doc":"Returns vector of symbolic names captured in loadFromCSV()\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n- **names**: `[String]`\n\nPython prototype (for reference only):\n```python3\ngetNames(names) -> None\n```","ref":"Evision.ML.TrainData.html#getNames/2"},{"type":"function","title":"Evision.ML.TrainData.getNormCatResponses/1","doc":"getNormCatResponses\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetNormCatResponses() -> retval\n```","ref":"Evision.ML.TrainData.html#getNormCatResponses/1"},{"type":"function","title":"Evision.ML.TrainData.getNSamples/1","doc":"getNSamples\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNSamples() -> retval\n```","ref":"Evision.ML.TrainData.html#getNSamples/1"},{"type":"function","title":"Evision.ML.TrainData.getNTestSamples/1","doc":"getNTestSamples\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNTestSamples() -> retval\n```","ref":"Evision.ML.TrainData.html#getNTestSamples/1"},{"type":"function","title":"Evision.ML.TrainData.getNTrainSamples/1","doc":"getNTrainSamples\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNTrainSamples() -> retval\n```","ref":"Evision.ML.TrainData.html#getNTrainSamples/1"},{"type":"function","title":"Evision.ML.TrainData.getNVars/1","doc":"getNVars\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNVars() -> retval\n```","ref":"Evision.ML.TrainData.html#getNVars/1"},{"type":"function","title":"Evision.ML.TrainData.getResponses/1","doc":"getResponses\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetResponses() -> retval\n```","ref":"Evision.ML.TrainData.html#getResponses/1"},{"type":"function","title":"Evision.ML.TrainData.getResponseType/1","doc":"getResponseType\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetResponseType() -> retval\n```","ref":"Evision.ML.TrainData.html#getResponseType/1"},{"type":"function","title":"Evision.ML.TrainData.getSample/1","doc":"","ref":"Evision.ML.TrainData.html#getSample/1"},{"type":"function","title":"Evision.ML.TrainData.getSample/4","doc":"getSample\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n- **varIdx**: `Evision.Mat`\n- **sidx**: `integer()`\n- **buf**: `float*`\n\nPython prototype (for reference only):\n```python3\ngetSample(varIdx, sidx, buf) -> None\n```","ref":"Evision.ML.TrainData.html#getSample/4"},{"type":"function","title":"Evision.ML.TrainData.getSamples/1","doc":"getSamples\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetSamples() -> retval\n```","ref":"Evision.ML.TrainData.html#getSamples/1"},{"type":"function","title":"Evision.ML.TrainData.getSampleWeights/1","doc":"getSampleWeights\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetSampleWeights() -> retval\n```","ref":"Evision.ML.TrainData.html#getSampleWeights/1"},{"type":"function","title":"Evision.ML.TrainData.getSubMatrix/1","doc":"","ref":"Evision.ML.TrainData.html#getSubMatrix/1"},{"type":"function","title":"Evision.ML.TrainData.getSubMatrix/3","doc":"Extract from matrix rows/cols specified by passed indexes.\n\n##### Positional Arguments\n- **matrix**: `Evision.Mat`.\n\n  input matrix (supported types: CV_32S, CV_32F, CV_64F)\n\n- **idx**: `Evision.Mat`.\n\n  1D index vector\n\n- **layout**: `integer()`.\n\n  specifies to extract rows (cv::ml::ROW_SAMPLES) or to extract columns (cv::ml::COL_SAMPLES)\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetSubMatrix(matrix, idx, layout) -> retval\n```","ref":"Evision.ML.TrainData.html#getSubMatrix/3"},{"type":"function","title":"Evision.ML.TrainData.getSubVector/1","doc":"","ref":"Evision.ML.TrainData.html#getSubVector/1"},{"type":"function","title":"Evision.ML.TrainData.getSubVector/2","doc":"Extract from 1D vector elements specified by passed indexes.\n\n##### Positional Arguments\n- **vec**: `Evision.Mat`.\n\n  input vector (supported types: CV_32S, CV_32F, CV_64F)\n\n- **idx**: `Evision.Mat`.\n\n  1D index vector\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetSubVector(vec, idx) -> retval\n```","ref":"Evision.ML.TrainData.html#getSubVector/2"},{"type":"function","title":"Evision.ML.TrainData.getTestNormCatResponses/1","doc":"getTestNormCatResponses\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetTestNormCatResponses() -> retval\n```","ref":"Evision.ML.TrainData.html#getTestNormCatResponses/1"},{"type":"function","title":"Evision.ML.TrainData.getTestResponses/1","doc":"getTestResponses\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetTestResponses() -> retval\n```","ref":"Evision.ML.TrainData.html#getTestResponses/1"},{"type":"function","title":"Evision.ML.TrainData.getTestSampleIdx/1","doc":"getTestSampleIdx\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetTestSampleIdx() -> retval\n```","ref":"Evision.ML.TrainData.html#getTestSampleIdx/1"},{"type":"function","title":"Evision.ML.TrainData.getTestSamples/1","doc":"Returns matrix of test samples\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetTestSamples() -> retval\n```","ref":"Evision.ML.TrainData.html#getTestSamples/1"},{"type":"function","title":"Evision.ML.TrainData.getTestSampleWeights/1","doc":"getTestSampleWeights\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetTestSampleWeights() -> retval\n```","ref":"Evision.ML.TrainData.html#getTestSampleWeights/1"},{"type":"function","title":"Evision.ML.TrainData.getTrainNormCatResponses/1","doc":"Returns the vector of normalized categorical responses\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nThe function returns vector of responses. Each response is integer from `0` to ` -1`. The actual label value can be retrieved then from the class label vector, see\nTrainData::getClassLabels.\n\nPython prototype (for reference only):\n```python3\ngetTrainNormCatResponses() -> retval\n```","ref":"Evision.ML.TrainData.html#getTrainNormCatResponses/1"},{"type":"function","title":"Evision.ML.TrainData.getTrainResponses/1","doc":"Returns the vector of responses\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nThe function returns ordered or the original categorical responses. Usually it's used in\nregression algorithms.\n\nPython prototype (for reference only):\n```python3\ngetTrainResponses() -> retval\n```","ref":"Evision.ML.TrainData.html#getTrainResponses/1"},{"type":"function","title":"Evision.ML.TrainData.getTrainSampleIdx/1","doc":"getTrainSampleIdx\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetTrainSampleIdx() -> retval\n```","ref":"Evision.ML.TrainData.html#getTrainSampleIdx/1"},{"type":"function","title":"Evision.ML.TrainData.getTrainSamples/1","doc":"Returns matrix of train samples\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Keyword Arguments\n- **layout**: `integer()`.\n\n  The requested layout. If it's different from the initial one, the matrix is\n  transposed. See ml::SampleTypes.\n\n- **compressSamples**: `bool`.\n\n  if true, the function returns only the training samples (specified by\n  sampleIdx)\n\n- **compressVars**: `bool`.\n\n  if true, the function returns the shorter training samples, containing only\n  the active variables.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nIn current implementation the function tries to avoid physical data copying and returns the\nmatrix stored inside TrainData (unless the transposition or compression is needed).\n\nPython prototype (for reference only):\n```python3\ngetTrainSamples([, layout[, compressSamples[, compressVars]]]) -> retval\n```","ref":"Evision.ML.TrainData.html#getTrainSamples/1"},{"type":"function","title":"Evision.ML.TrainData.getTrainSamples/2","doc":"Returns matrix of train samples\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Keyword Arguments\n- **layout**: `integer()`.\n\n  The requested layout. If it's different from the initial one, the matrix is\n  transposed. See ml::SampleTypes.\n\n- **compressSamples**: `bool`.\n\n  if true, the function returns only the training samples (specified by\n  sampleIdx)\n\n- **compressVars**: `bool`.\n\n  if true, the function returns the shorter training samples, containing only\n  the active variables.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nIn current implementation the function tries to avoid physical data copying and returns the\nmatrix stored inside TrainData (unless the transposition or compression is needed).\n\nPython prototype (for reference only):\n```python3\ngetTrainSamples([, layout[, compressSamples[, compressVars]]]) -> retval\n```","ref":"Evision.ML.TrainData.html#getTrainSamples/2"},{"type":"function","title":"Evision.ML.TrainData.getTrainSampleWeights/1","doc":"getTrainSampleWeights\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetTrainSampleWeights() -> retval\n```","ref":"Evision.ML.TrainData.html#getTrainSampleWeights/1"},{"type":"function","title":"Evision.ML.TrainData.getValues/1","doc":"","ref":"Evision.ML.TrainData.html#getValues/1"},{"type":"function","title":"Evision.ML.TrainData.getValues/4","doc":"getValues\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n- **vi**: `integer()`\n- **sidx**: `Evision.Mat`\n- **values**: `float*`\n\nPython prototype (for reference only):\n```python3\ngetValues(vi, sidx, values) -> None\n```","ref":"Evision.ML.TrainData.html#getValues/4"},{"type":"function","title":"Evision.ML.TrainData.getVarIdx/1","doc":"getVarIdx\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetVarIdx() -> retval\n```","ref":"Evision.ML.TrainData.html#getVarIdx/1"},{"type":"function","title":"Evision.ML.TrainData.getVarSymbolFlags/1","doc":"getVarSymbolFlags\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetVarSymbolFlags() -> retval\n```","ref":"Evision.ML.TrainData.html#getVarSymbolFlags/1"},{"type":"function","title":"Evision.ML.TrainData.getVarType/1","doc":"getVarType\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetVarType() -> retval\n```","ref":"Evision.ML.TrainData.html#getVarType/1"},{"type":"function","title":"Evision.ML.TrainData.setTrainTestSplit/1","doc":"","ref":"Evision.ML.TrainData.html#setTrainTestSplit/1"},{"type":"function","title":"Evision.ML.TrainData.setTrainTestSplit/2","doc":"Splits the training data into the training and test parts\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n- **count**: `integer()`\n\n##### Keyword Arguments\n- **shuffle**: `bool`.\n\n@sa TrainData::setTrainTestSplitRatio\n\nPython prototype (for reference only):\n```python3\nsetTrainTestSplit(count[, shuffle]) -> None\n```","ref":"Evision.ML.TrainData.html#setTrainTestSplit/2"},{"type":"function","title":"Evision.ML.TrainData.setTrainTestSplit/3","doc":"Splits the training data into the training and test parts\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n- **count**: `integer()`\n\n##### Keyword Arguments\n- **shuffle**: `bool`.\n\n@sa TrainData::setTrainTestSplitRatio\n\nPython prototype (for reference only):\n```python3\nsetTrainTestSplit(count[, shuffle]) -> None\n```","ref":"Evision.ML.TrainData.html#setTrainTestSplit/3"},{"type":"function","title":"Evision.ML.TrainData.setTrainTestSplitRatio/1","doc":"","ref":"Evision.ML.TrainData.html#setTrainTestSplitRatio/1"},{"type":"function","title":"Evision.ML.TrainData.setTrainTestSplitRatio/2","doc":"Splits the training data into the training and test parts\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n- **ratio**: `double`\n\n##### Keyword Arguments\n- **shuffle**: `bool`.\n\nThe function selects a subset of specified relative size and then returns it as the training\nset. If the function is not called, all the data is used for training. Please, note that for\neach of TrainData::getTrain\\* there is corresponding TrainData::getTest\\*, so that the test\nsubset can be retrieved and processed as well.\n@sa TrainData::setTrainTestSplit\n\nPython prototype (for reference only):\n```python3\nsetTrainTestSplitRatio(ratio[, shuffle]) -> None\n```","ref":"Evision.ML.TrainData.html#setTrainTestSplitRatio/2"},{"type":"function","title":"Evision.ML.TrainData.setTrainTestSplitRatio/3","doc":"Splits the training data into the training and test parts\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n- **ratio**: `double`\n\n##### Keyword Arguments\n- **shuffle**: `bool`.\n\nThe function selects a subset of specified relative size and then returns it as the training\nset. If the function is not called, all the data is used for training. Please, note that for\neach of TrainData::getTrain\\* there is corresponding TrainData::getTest\\*, so that the test\nsubset can be retrieved and processed as well.\n@sa TrainData::setTrainTestSplit\n\nPython prototype (for reference only):\n```python3\nsetTrainTestSplitRatio(ratio[, shuffle]) -> None\n```","ref":"Evision.ML.TrainData.html#setTrainTestSplitRatio/3"},{"type":"function","title":"Evision.ML.TrainData.shuffleTrainTest/1","doc":"shuffleTrainTest\n\n##### Positional Arguments\n- **self**: `Evision.ML.TrainData.t()`\n\nPython prototype (for reference only):\n```python3\nshuffleTrainTest() -> None\n```","ref":"Evision.ML.TrainData.html#shuffleTrainTest/1"},{"type":"type","title":"Evision.ML.TrainData.t/0","doc":"Type that represents an `ML.TrainData` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ML.TrainData.html#t:t/0"},{"type":"module","title":"Evision.ML.VariableTypes","doc":"","ref":"Evision.ML.VariableTypes.html"},{"type":"function","title":"Evision.ML.VariableTypes.cv_VAR_CATEGORICAL/0","doc":"","ref":"Evision.ML.VariableTypes.html#cv_VAR_CATEGORICAL/0"},{"type":"function","title":"Evision.ML.VariableTypes.cv_VAR_NUMERICAL/0","doc":"","ref":"Evision.ML.VariableTypes.html#cv_VAR_NUMERICAL/0"},{"type":"function","title":"Evision.ML.VariableTypes.cv_VAR_ORDERED/0","doc":"","ref":"Evision.ML.VariableTypes.html#cv_VAR_ORDERED/0"},{"type":"type","title":"Evision.ML.VariableTypes.enum/0","doc":"","ref":"Evision.ML.VariableTypes.html#t:enum/0"},{"type":"module","title":"Evision.MSER","doc":"","ref":"Evision.MSER.html"},{"type":"function","title":"Evision.MSER.compute/1","doc":"","ref":"Evision.MSER.html#compute/1"},{"type":"function","title":"Evision.MSER.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.MSER.html#compute/3"},{"type":"function","title":"Evision.MSER.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.MSER.html#compute/4"},{"type":"function","title":"Evision.MSER.create/0","doc":"Full constructor for %MSER detector\n##### Keyword Arguments\n- **delta**: `integer()`.\n\n  it compares \\f$(size_{i}-size_{i-delta})/size_{i-delta}\\f$\n\n- **min_area**: `integer()`.\n\n  prune the area which smaller than minArea\n\n- **max_area**: `integer()`.\n\n  prune the area which bigger than maxArea\n\n- **max_variation**: `double`.\n\n  prune the area have similar size to its children\n\n- **min_diversity**: `double`.\n\n  for color image, trace back to cut off mser with diversity less than min_diversity\n\n- **max_evolution**: `integer()`.\n\n  for color image, the evolution steps\n\n- **area_threshold**: `double`.\n\n  for color image, the area threshold to cause re-initialize\n\n- **min_margin**: `double`.\n\n  for color image, ignore too small margin\n\n- **edge_blur_size**: `integer()`.\n\n  for color image, the aperture size for edge blur\n\n##### Return\n- **retval**: `Evision.MSER.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, delta[, min_area[, max_area[, max_variation[, min_diversity[, max_evolution[, area_threshold[, min_margin[, edge_blur_size]]]]]]]]]) -> retval\n```","ref":"Evision.MSER.html#create/0"},{"type":"function","title":"Evision.MSER.create/1","doc":"Full constructor for %MSER detector\n##### Keyword Arguments\n- **delta**: `integer()`.\n\n  it compares \\f$(size_{i}-size_{i-delta})/size_{i-delta}\\f$\n\n- **min_area**: `integer()`.\n\n  prune the area which smaller than minArea\n\n- **max_area**: `integer()`.\n\n  prune the area which bigger than maxArea\n\n- **max_variation**: `double`.\n\n  prune the area have similar size to its children\n\n- **min_diversity**: `double`.\n\n  for color image, trace back to cut off mser with diversity less than min_diversity\n\n- **max_evolution**: `integer()`.\n\n  for color image, the evolution steps\n\n- **area_threshold**: `double`.\n\n  for color image, the area threshold to cause re-initialize\n\n- **min_margin**: `double`.\n\n  for color image, ignore too small margin\n\n- **edge_blur_size**: `integer()`.\n\n  for color image, the aperture size for edge blur\n\n##### Return\n- **retval**: `Evision.MSER.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, delta[, min_area[, max_area[, max_variation[, min_diversity[, max_evolution[, area_threshold[, min_margin[, edge_blur_size]]]]]]]]]) -> retval\n```","ref":"Evision.MSER.html#create/1"},{"type":"function","title":"Evision.MSER.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.MSER.html#defaultNorm/1"},{"type":"function","title":"Evision.MSER.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.MSER.html#descriptorSize/1"},{"type":"function","title":"Evision.MSER.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.MSER.html#descriptorType/1"},{"type":"function","title":"Evision.MSER.detect/1","doc":"","ref":"Evision.MSER.html#detect/1"},{"type":"function","title":"Evision.MSER.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.MSER.html#detect/2"},{"type":"function","title":"Evision.MSER.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.MSER.html#detect/3"},{"type":"function","title":"Evision.MSER.detectAndCompute/1","doc":"","ref":"Evision.MSER.html#detectAndCompute/1"},{"type":"function","title":"Evision.MSER.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.MSER.html#detectAndCompute/3"},{"type":"function","title":"Evision.MSER.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.MSER.html#detectAndCompute/4"},{"type":"function","title":"Evision.MSER.detectRegions/1","doc":"","ref":"Evision.MSER.html#detectRegions/1"},{"type":"function","title":"Evision.MSER.detectRegions/2","doc":"Detect %MSER regions\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **image**: `Evision.Mat`.\n\n  input image (8UC1, 8UC3 or 8UC4, must be greater or equal than 3x3)\n\n##### Return\n- **msers**: `[[Point]]`.\n\n  resulting list of point sets\n\n- **bboxes**: `[Rect]`.\n\n  resulting bounding boxes\n\nPython prototype (for reference only):\n```python3\ndetectRegions(image) -> msers, bboxes\n```","ref":"Evision.MSER.html#detectRegions/2"},{"type":"function","title":"Evision.MSER.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.MSER.html#empty/1"},{"type":"function","title":"Evision.MSER.getAreaThreshold/1","doc":"getAreaThreshold\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetAreaThreshold() -> retval\n```","ref":"Evision.MSER.html#getAreaThreshold/1"},{"type":"function","title":"Evision.MSER.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.MSER.html#getDefaultName/1"},{"type":"function","title":"Evision.MSER.getDelta/1","doc":"getDelta\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetDelta() -> retval\n```","ref":"Evision.MSER.html#getDelta/1"},{"type":"function","title":"Evision.MSER.getEdgeBlurSize/1","doc":"getEdgeBlurSize\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetEdgeBlurSize() -> retval\n```","ref":"Evision.MSER.html#getEdgeBlurSize/1"},{"type":"function","title":"Evision.MSER.getMaxArea/1","doc":"getMaxArea\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxArea() -> retval\n```","ref":"Evision.MSER.html#getMaxArea/1"},{"type":"function","title":"Evision.MSER.getMaxEvolution/1","doc":"getMaxEvolution\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxEvolution() -> retval\n```","ref":"Evision.MSER.html#getMaxEvolution/1"},{"type":"function","title":"Evision.MSER.getMaxVariation/1","doc":"getMaxVariation\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxVariation() -> retval\n```","ref":"Evision.MSER.html#getMaxVariation/1"},{"type":"function","title":"Evision.MSER.getMinArea/1","doc":"getMinArea\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMinArea() -> retval\n```","ref":"Evision.MSER.html#getMinArea/1"},{"type":"function","title":"Evision.MSER.getMinDiversity/1","doc":"getMinDiversity\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMinDiversity() -> retval\n```","ref":"Evision.MSER.html#getMinDiversity/1"},{"type":"function","title":"Evision.MSER.getMinMargin/1","doc":"getMinMargin\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMinMargin() -> retval\n```","ref":"Evision.MSER.html#getMinMargin/1"},{"type":"function","title":"Evision.MSER.getPass2Only/1","doc":"getPass2Only\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetPass2Only() -> retval\n```","ref":"Evision.MSER.html#getPass2Only/1"},{"type":"function","title":"Evision.MSER.read/1","doc":"","ref":"Evision.MSER.html#read/1"},{"type":"function","title":"Evision.MSER.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.MSER.html#read/2"},{"type":"function","title":"Evision.MSER.setAreaThreshold/1","doc":"","ref":"Evision.MSER.html#setAreaThreshold/1"},{"type":"function","title":"Evision.MSER.setAreaThreshold/2","doc":"setAreaThreshold\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **areaThreshold**: `double`\n\nPython prototype (for reference only):\n```python3\nsetAreaThreshold(areaThreshold) -> None\n```","ref":"Evision.MSER.html#setAreaThreshold/2"},{"type":"function","title":"Evision.MSER.setDelta/1","doc":"","ref":"Evision.MSER.html#setDelta/1"},{"type":"function","title":"Evision.MSER.setDelta/2","doc":"setDelta\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **delta**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetDelta(delta) -> None\n```","ref":"Evision.MSER.html#setDelta/2"},{"type":"function","title":"Evision.MSER.setEdgeBlurSize/1","doc":"","ref":"Evision.MSER.html#setEdgeBlurSize/1"},{"type":"function","title":"Evision.MSER.setEdgeBlurSize/2","doc":"setEdgeBlurSize\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **edge_blur_size**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetEdgeBlurSize(edge_blur_size) -> None\n```","ref":"Evision.MSER.html#setEdgeBlurSize/2"},{"type":"function","title":"Evision.MSER.setMaxArea/1","doc":"","ref":"Evision.MSER.html#setMaxArea/1"},{"type":"function","title":"Evision.MSER.setMaxArea/2","doc":"setMaxArea\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **maxArea**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxArea(maxArea) -> None\n```","ref":"Evision.MSER.html#setMaxArea/2"},{"type":"function","title":"Evision.MSER.setMaxEvolution/1","doc":"","ref":"Evision.MSER.html#setMaxEvolution/1"},{"type":"function","title":"Evision.MSER.setMaxEvolution/2","doc":"setMaxEvolution\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **maxEvolution**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxEvolution(maxEvolution) -> None\n```","ref":"Evision.MSER.html#setMaxEvolution/2"},{"type":"function","title":"Evision.MSER.setMaxVariation/1","doc":"","ref":"Evision.MSER.html#setMaxVariation/1"},{"type":"function","title":"Evision.MSER.setMaxVariation/2","doc":"setMaxVariation\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **maxVariation**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxVariation(maxVariation) -> None\n```","ref":"Evision.MSER.html#setMaxVariation/2"},{"type":"function","title":"Evision.MSER.setMinArea/1","doc":"","ref":"Evision.MSER.html#setMinArea/1"},{"type":"function","title":"Evision.MSER.setMinArea/2","doc":"setMinArea\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **minArea**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMinArea(minArea) -> None\n```","ref":"Evision.MSER.html#setMinArea/2"},{"type":"function","title":"Evision.MSER.setMinDiversity/1","doc":"","ref":"Evision.MSER.html#setMinDiversity/1"},{"type":"function","title":"Evision.MSER.setMinDiversity/2","doc":"setMinDiversity\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **minDiversity**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMinDiversity(minDiversity) -> None\n```","ref":"Evision.MSER.html#setMinDiversity/2"},{"type":"function","title":"Evision.MSER.setMinMargin/1","doc":"","ref":"Evision.MSER.html#setMinMargin/1"},{"type":"function","title":"Evision.MSER.setMinMargin/2","doc":"setMinMargin\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **min_margin**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMinMargin(min_margin) -> None\n```","ref":"Evision.MSER.html#setMinMargin/2"},{"type":"function","title":"Evision.MSER.setPass2Only/1","doc":"","ref":"Evision.MSER.html#setPass2Only/1"},{"type":"function","title":"Evision.MSER.setPass2Only/2","doc":"setPass2Only\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **f**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetPass2Only(f) -> None\n```","ref":"Evision.MSER.html#setPass2Only/2"},{"type":"function","title":"Evision.MSER.write/1","doc":"","ref":"Evision.MSER.html#write/1"},{"type":"function","title":"Evision.MSER.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.MSER.html#write/2"},{"type":"function","title":"Evision.MSER.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.MSER.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.MSER.html#write/3"},{"type":"type","title":"Evision.MSER.t/0","doc":"Type that represents an `MSER` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.MSER.html#t:t/0"},{"type":"module","title":"Evision.MarkerTypes","doc":"","ref":"Evision.MarkerTypes.html"},{"type":"function","title":"Evision.MarkerTypes.cv_MARKER_CROSS/0","doc":"","ref":"Evision.MarkerTypes.html#cv_MARKER_CROSS/0"},{"type":"function","title":"Evision.MarkerTypes.cv_MARKER_DIAMOND/0","doc":"","ref":"Evision.MarkerTypes.html#cv_MARKER_DIAMOND/0"},{"type":"function","title":"Evision.MarkerTypes.cv_MARKER_SQUARE/0","doc":"","ref":"Evision.MarkerTypes.html#cv_MARKER_SQUARE/0"},{"type":"function","title":"Evision.MarkerTypes.cv_MARKER_STAR/0","doc":"","ref":"Evision.MarkerTypes.html#cv_MARKER_STAR/0"},{"type":"function","title":"Evision.MarkerTypes.cv_MARKER_TILTED_CROSS/0","doc":"","ref":"Evision.MarkerTypes.html#cv_MARKER_TILTED_CROSS/0"},{"type":"function","title":"Evision.MarkerTypes.cv_MARKER_TRIANGLE_DOWN/0","doc":"","ref":"Evision.MarkerTypes.html#cv_MARKER_TRIANGLE_DOWN/0"},{"type":"function","title":"Evision.MarkerTypes.cv_MARKER_TRIANGLE_UP/0","doc":"","ref":"Evision.MarkerTypes.html#cv_MARKER_TRIANGLE_UP/0"},{"type":"type","title":"Evision.MarkerTypes.enum/0","doc":"","ref":"Evision.MarkerTypes.html#t:enum/0"},{"type":"module","title":"Evision.Mat","doc":"Evision Mat","ref":"Evision.Mat.html"},{"type":"function","title":"Evision.Mat.abs/1","doc":"","ref":"Evision.Mat.html#abs/1"},{"type":"function","title":"Evision.Mat.add/2","doc":"","ref":"Evision.Mat.html#add/2"},{"type":"function","title":"Evision.Mat.add/3","doc":"","ref":"Evision.Mat.html#add/3"},{"type":"function","title":"Evision.Mat.arange/4","doc":"Generate a Mat with shape `{1, length}`, where `length` is the amount of\nnumbers starting from `from` to `to` with step size `step`","ref":"Evision.Mat.html#arange/4"},{"type":"function","title":"Evision.Mat.arange/5","doc":"Generate a Mat with a list of number starting from `from` to `to` with step size `step`.\nThe generated Mat will then be reshaped to the requested `shape` if applicable.","ref":"Evision.Mat.html#arange/5"},{"type":"function","title":"Evision.Mat.as_shape/2","doc":"This method does not change the underlying data. It only changes the steps when accessing the matrix.\n\nIf intended to change the underlying data to the new shape, please use `Evision.Mat.reshape/2`.","ref":"Evision.Mat.html#as_shape/2"},{"type":"function","title":"Evision.Mat.as_type/2","doc":"","ref":"Evision.Mat.html#as_type/2"},{"type":"function","title":"Evision.Mat.at/2","doc":"","ref":"Evision.Mat.html#at/2"},{"type":"function","title":"Evision.Mat.bitwise_and/2","doc":"","ref":"Evision.Mat.html#bitwise_and/2"},{"type":"function","title":"Evision.Mat.bitwise_not/1","doc":"","ref":"Evision.Mat.html#bitwise_not/1"},{"type":"function","title":"Evision.Mat.bitwise_or/2","doc":"","ref":"Evision.Mat.html#bitwise_or/2"},{"type":"function","title":"Evision.Mat.bitwise_xor/2","doc":"","ref":"Evision.Mat.html#bitwise_xor/2"},{"type":"function","title":"Evision.Mat.broadcast_to/2","doc":"","ref":"Evision.Mat.html#broadcast_to/2"},{"type":"function","title":"Evision.Mat.broadcast_to/3","doc":"","ref":"Evision.Mat.html#broadcast_to/3"},{"type":"function","title":"Evision.Mat.ceil/1","doc":"","ref":"Evision.Mat.html#ceil/1"},{"type":"function","title":"Evision.Mat.channel_as_last_dim/1","doc":"This function does the opposite as to `Evision.Mat.last_dim_as_channel/1`.\n\nIf the number of channels of the input Evision.Mat is greater than 1,\nthen this function would convert the input Evision.Mat with dims `dims=list(int())` to a `1`-channel Evision.Mat with dims `[dims | channels]`.\n\nIf the number of channels of the input Evision.Mat is equal to 1,\n- if dims == shape, then nothing happens\n- otherwise, a new Evision.Mat that has dims=`[dims | channels]` will be returned","ref":"Evision.Mat.html#channel_as_last_dim/1"},{"type":"function","title":"Evision.Mat.channels/1","doc":"The method returns the number of matrix channels.","ref":"Evision.Mat.html#channels/1"},{"type":"function","title":"Evision.Mat.clip/3","doc":"","ref":"Evision.Mat.html#clip/3"},{"type":"function","title":"Evision.Mat.clone/1","doc":"Get a clone an `Evision.Mat`.\nData will be copied to the resulting `Evision.Mat`.","ref":"Evision.Mat.html#clone/1"},{"type":"function","title":"Evision.Mat.cmp/3","doc":"","ref":"Evision.Mat.html#cmp/3"},{"type":"function","title":"Evision.Mat.cv_AUTO_STEP/0","doc":"","ref":"Evision.Mat.html#cv_AUTO_STEP/0"},{"type":"function","title":"Evision.Mat.cv_DEPTH_MASK/0","doc":"","ref":"Evision.Mat.html#cv_DEPTH_MASK/0"},{"type":"function","title":"Evision.Mat.cv_MAGIC_MASK/0","doc":"","ref":"Evision.Mat.html#cv_MAGIC_MASK/0"},{"type":"function","title":"Evision.Mat.cv_MAGIC_VAL/0","doc":"","ref":"Evision.Mat.html#cv_MAGIC_VAL/0"},{"type":"function","title":"Evision.Mat.cv_TYPE_MASK/0","doc":"","ref":"Evision.Mat.html#cv_TYPE_MASK/0"},{"type":"function","title":"Evision.Mat.depth/1","doc":"Returns the depth of a matrix element.\n\nThe method returns the identifier of the matrix element depth (the type of each individual channel).\nFor example, for a 16-bit signed element array, the method returns CV_16S. A complete list of\nmatrix types contains the following values:\n\n  -   CV_8U - 8-bit unsigned integers ( 0..255 )\n  -   CV_8S - 8-bit signed integers ( -128..127 )\n  -   CV_16U - 16-bit unsigned integers ( 0..65535 )\n  -   CV_16S - 16-bit signed integers ( -32768..32767 )\n  -   CV_32S - 32-bit signed integers ( -2147483648..2147483647 )\n  -   CV_32F - 32-bit floating-point numbers ( -FLT_MAX..FLT_MAX, INF, NAN )\n  -   CV_64F - 64-bit floating-point numbers ( -DBL_MAX..DBL_MAX, INF, NAN )","ref":"Evision.Mat.html#depth/1"},{"type":"function","title":"Evision.Mat.divide/2","doc":"","ref":"Evision.Mat.html#divide/2"},{"type":"function","title":"Evision.Mat.divide/3","doc":"","ref":"Evision.Mat.html#divide/3"},{"type":"function","title":"Evision.Mat.dot/2","doc":"","ref":"Evision.Mat.html#dot/2"},{"type":"function","title":"Evision.Mat.elemSize1/1","doc":"Returns the size of each matrix element channel in bytes.\n\nThe method returns the matrix element channel size in bytes, that is, it ignores the number of\nchannels. For example, if the matrix type is CV_16SC3 , the method returns sizeof(short) or 2.","ref":"Evision.Mat.html#elemSize1/1"},{"type":"function","title":"Evision.Mat.elemSize/1","doc":"Returns the matrix element size in bytes.\n\nThe method returns the matrix element size in bytes. For example, if the matrix type is CV_16SC3,\nthe method returns 3*sizeof(short) or 6.","ref":"Evision.Mat.html#elemSize/1"},{"type":"function","title":"Evision.Mat.empty/0","doc":"Create an empty `Evision.Mat`.\nThis function is the Elixir equvilent of calling `cv::Mat()` in C++.","ref":"Evision.Mat.html#empty/0"},{"type":"function","title":"Evision.Mat.expm1/1","doc":"","ref":"Evision.Mat.html#expm1/1"},{"type":"function","title":"Evision.Mat.eye/2","doc":"","ref":"Evision.Mat.html#eye/2"},{"type":"function","title":"Evision.Mat.fetch/2","doc":"Access.fetch implementation for Evision.Mat.\n\n```elixir\niex> img = Evision.imread(\"test/qr_detector_test.png\")\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {300, 300, 3},\n  ref: #Reference<0.809884129.802291734.78316>\n}\n\n# Same behaviour as Nx.\n# Also, img[0] gives the same result as img[[0]]\n# For this example, they are both equvilent of img[[0, :all, :all]]\niex> img[[0]]\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {1, 300, 3},\n  ref: #Reference<0.809884129.802291731.77296>\n}\n\n# same as img[[0..100, 50..200, :all]]\n# however, currently we only support ranges with step size 1\n#\n# **IMPORTANT NOTE**\n#\n# also, please note that we are using Elixir.Range here\n# and Elixir.Range is **inclusive**, i.e, [start, end]\n# while cv::Range `{integer(), integer()}` is `[start, end)`\n# the difference can be observed in the `shape` field\niex> img[[0..100, 50..200]]\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {101, 151, 3},\n  ref: #Reference<0.809884129.802291731.77297>\n}\niex> img[[{0, 100}, {50, 200}]]\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {100, 150, 3},\n  ref: #Reference<0.809884129.802291731.77297>\n}\n\n# for this example, the result is the same as `Evision.extractChannel(img, 0)`\niex> img[[:all, :all, 0]]\n%Evision.Mat{\n  channels: 1,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 0,\n  shape: {300, 300},\n  ref: #Reference<0.809884129.802291731.77298>\n}\niex> img[[:all, :all, 0..1]]\n%Evision.Mat{\n  channels: 2,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 8,\n  shape: {300, 300, 2},\n  ref: #Reference<0.809884129.802291731.77299>\n}\n\n# when index is out of bounds\niex> img[[:all, :all, 42]]\n{:error, \"index 42 is out of bounds for axis 2 with size 3\"}\n\n# it works the same way for any dimensional Evision.Mat\niex> mat = Evision.Mat.ones({10, 10, 10, 10, 10}, :u8)\niex> mat[[1..7, :all, 2..6, 3..9, :all]]\n%Evision.Mat{\n  channels: 1,\n  dims: 5,\n  type: {:u, 8},\n  raw_type: 0,\n  shape: {7, 10, 5, 7, 10},\n  ref: #Reference<0.3015448455.3766878228.259075>\n}\n```","ref":"Evision.Mat.html#fetch/2"},{"type":"function","title":"Evision.Mat.floor/1","doc":"","ref":"Evision.Mat.html#floor/1"},{"type":"function","title":"Evision.Mat.from_binary/5","doc":"Create Mat from binary (pixel) data\n\n- **binary**.\n\n  The binary pixel data\n\n- **type**.\n\n  one of `[{:u, 8}, {:s, 8}, {:u, 16}, {:s, 16}, {:s, 32}, {:f, 32}, {:f, 64}]` and their corresponding shorthands.\n\n- **rows**. `int`\n\n  Number of rows (i.e., the height of the image)\n\n- **cols**. `int`\n\n  Number of cols (i.e., the width of the image)\n\n- **channels**. `int`\n\n  Number of channels.","ref":"Evision.Mat.html#from_binary/5"},{"type":"function","title":"Evision.Mat.from_binary_by_shape/3","doc":"","ref":"Evision.Mat.html#from_binary_by_shape/3"},{"type":"function","title":"Evision.Mat.from_nx/1","doc":"Converts a tensor from `Nx.Tensor` to `Evision.Mat`.\n\n##### Positional Arguments\n\n- **t**. `Nx.Tensor`\n\n##### Return\nAn `Evision.Mat` that has the same shape and type.\n(except for `:s64`, `:u32` and `:u64`, please see more details at https://github.com/cocoa-xu/evision/issues/48).","ref":"Evision.Mat.html#from_nx/1"},{"type":"function","title":"Evision.Mat.from_nx/2","doc":"Converts a tensor from `Nx.Tensor` to `Evision.Mat`.\n\n##### Positional Arguments\n\n- **t**. `Nx.Tensor`\n- **as_shape**. `tuple`.\n\n##### Return\nAn `Evision.Mat` that has the specified shape (if the number of elements matches) and the same type as the given tensor.\n(except for `:s64`, `:u32` and `:u64`, please see more details at https://github.com/cocoa-xu/evision/issues/48).","ref":"Evision.Mat.html#from_nx/2"},{"type":"function","title":"Evision.Mat.from_nx_2d/1","doc":"Converts a tensor from `Nx.Tensor` to a 2D `Evision.Mat`.\n\nIf the tuple size of the shape is 3, the resulting `Evision.Mat` will be a `c`-channel 2D image,\nwhere `c` is the last number in the shape tuple.\n\nIf the tuple size of the shape is 2, the resulting `Evision.Mat` will be a 1-channel 2D image.\n\nOtherwise, it's not possible to convert the tensor to a 2D image.","ref":"Evision.Mat.html#from_nx_2d/1"},{"type":"function","title":"Evision.Mat.full/3","doc":"Generate a Mat with all of its elements equal to `number`.\n\n##### Positional Arguments\n\n- **shape**. `tuple`\n\n  The expected shape of the resulting `Evision.Mat`\n\n- **number**. `number`\n\n  Element value.\n\n- **type**.\n\n  Value type.","ref":"Evision.Mat.html#full/3"},{"type":"function","title":"Evision.Mat.get_and_update/3","doc":"Access.get_and_update/3 implementation for Evision.Mat\n\n```elixir\niex> mat = Evision.Mat.zeros({5, 5}, :u8)\niex> Evision.Mat.to_nx(mat)\n#Nx.Tensor \niex> {old, new} = Evision.Mat.get_and_update(mat, [1..3, 1..3], fn roi ->\n    {roi, Nx.broadcast(Nx.tensor(255, type: roi.type), roi.shape)}\nend)\niex> Evision.Mat.to_nx(new)\n#Nx.Tensor \n```","ref":"Evision.Mat.html#get_and_update/3"},{"type":"function","title":"Evision.Mat.isContinuous/1","doc":"","ref":"Evision.Mat.html#isContinuous/1"},{"type":"function","title":"Evision.Mat.isSubmatrix/1","doc":"","ref":"Evision.Mat.html#isSubmatrix/1"},{"type":"function","title":"Evision.Mat.kino_render_image_encoding/0","doc":"Get preferred image encoding when rendering in Kino.\n\nDefault value is `Application.compile_env(:evision, :kino_render_image_encoding, :png)`.","ref":"Evision.Mat.html#kino_render_image_encoding/0"},{"type":"function","title":"Evision.Mat.kino_render_image_max_size/0","doc":"Get the maximum allowed image size to render in Kino.\n\nDefault value is `Application.compile_env(:evision, :kino_render_image_max_size, {8192, 8192})`.","ref":"Evision.Mat.html#kino_render_image_max_size/0"},{"type":"function","title":"Evision.Mat.kino_render_tab_order/0","doc":"Get preferred order of Kino.Layout tabs for `Evision.Mat` in Livebook.\n\nDefault value is `Enum.uniq(Application.compile_env(:evision, :kino_render_tab_order, [:image, :raw, :numerical]))`.","ref":"Evision.Mat.html#kino_render_tab_order/0"},{"type":"function","title":"Evision.Mat.last_dim_as_channel/1","doc":"This function would convert the input tensor with dims `[height, width, dims]` to a `dims`-channel image with dims `[height, width]`.\n\nNote that OpenCV has limitation on the number of channels. Currently the maximum number of channels is `512`.","ref":"Evision.Mat.html#last_dim_as_channel/1"},{"type":"function","title":"Evision.Mat.literal/1","doc":"Create an `Evision.Mat` from list literals.","ref":"Evision.Mat.html#literal/1"},{"type":"function","title":"Example - Evision.Mat.literal/1","doc":"Creating `Evision.Mat` from empty list literal (`[]`) is the same as calling `Evision.Mat.empty()`.\n\n```elixir\niex> Evision.Mat.literal!([])\n%Evision.Mat{\n  channels: 1,\n  dims: 0,\n  type: {:u, 8},\n  raw_type: 0,\n  shape: {},\n  ref: #Reference<0.1204050731.2031747092.46781>\n}\n```\n\nBy default, the shape of the Mat will stay as is.\n```elixir\niex> Evision.Mat.literal!([[[1,1,1],[2,2,2],[3,3,3]]], :u8)\n%Evision.Mat{\n  channels: 1,\n  dims: 3,\n  type: {:u, 8},\n  raw_type: 0,\n  shape: {1, 3, 3},\n  ref: #Reference<0.512519210.691404819.106300>\n}\n```\n\n`Evision.Mat.literal/3` will return a valid 2D image\nif the keyword argument, `as_2d`, is set to `true`\nand if the list literal can be represented as a 2D image.\n```elixir\niex> Evision.Mat.literal!([[[1,1,1],[2,2,2],[3,3,3]]], :u8, as_2d: true)\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {1, 3, 3},\n  ref: #Reference<0.512519210.691404820.106293>\n}\n```","ref":"Evision.Mat.html#literal/1-example"},{"type":"function","title":"Evision.Mat.literal/3","doc":"","ref":"Evision.Mat.html#literal/3"},{"type":"function","title":"Evision.Mat.logical_and/2","doc":"","ref":"Evision.Mat.html#logical_and/2"},{"type":"function","title":"Evision.Mat.logical_or/2","doc":"","ref":"Evision.Mat.html#logical_or/2"},{"type":"function","title":"Evision.Mat.logical_xor/2","doc":"","ref":"Evision.Mat.html#logical_xor/2"},{"type":"function","title":"Evision.Mat.matrix_multiply/3","doc":"","ref":"Evision.Mat.html#matrix_multiply/3"},{"type":"function","title":"Evision.Mat.multiply/2","doc":"","ref":"Evision.Mat.html#multiply/2"},{"type":"function","title":"Evision.Mat.multiply/3","doc":"","ref":"Evision.Mat.html#multiply/3"},{"type":"function","title":"Evision.Mat.negate/1","doc":"","ref":"Evision.Mat.html#negate/1"},{"type":"function","title":"Evision.Mat.number/2","doc":"","ref":"Evision.Mat.html#number/2"},{"type":"function","title":"Evision.Mat.ones/2","doc":"","ref":"Evision.Mat.html#ones/2"},{"type":"function","title":"Evision.Mat.pop/2","doc":"Access.pop/2 is not implemented yet","ref":"Evision.Mat.html#pop/2"},{"type":"function","title":"Evision.Mat.quicklook/1","doc":"Display inline image in terminal for iTerm2 users.\n\nThis function will check the value of `:display_inline_image_iterm2` in the application config.\n\nIf is `true`, then it will detect if current session is running in `iTerm2` (by checking the environment variable `LC_TERMINAL`).\n\nIf both are `true`, we next check if the image is a 2D image, also if its size is within the limits.\n\nThe maximum size can be set in the application config, for example,\n\n```elixir\nconfig :evision, display_inline_image_iterm2: true\nconfig :evision, display_inline_image_max_size: {8192, 8192}\n```\n\nIf it passes all the checks, then it will be displayed as an inline image in iTerm2.","ref":"Evision.Mat.html#quicklook/1"},{"type":"function","title":"Evision.Mat.raw_type/1","doc":"Returns the type of a matrix.\n\nAs `Evision.Mat.type/1` returns the type used by Nx, this method gives the raw value of\n`cv::Mat.type()`","ref":"Evision.Mat.html#raw_type/1"},{"type":"function","title":"Evision.Mat.reshape/2","doc":"","ref":"Evision.Mat.html#reshape/2"},{"type":"function","title":"Evision.Mat.roi/2","doc":"Extracts a rectangular submatrix.\n\n#### Variant 1\n##### Positional Arguments\n\n- **mat**. `maybe_mat_in()`\n\n  The matrix.\n\n- **rect**. `{int, int, int, int}`\n\n  The rect that specifies `{x, y, width, height}`.\n\n##### Return\n\nExtracted submatrix specified as a rectangle. (data is copied)\n\n#### Variant 2\n##### Positional Arguments\n\n- **mat**. `maybe_mat_in()`\n\n  The matrix.\n\n- **ranges**. `[{int, int} | :all]`\n\n  Array of selected ranges along each array dimension.\n\n##### Return\n\nExtracted submatrix. (data is copied)","ref":"Evision.Mat.html#roi/2"},{"type":"function","title":"Evision.Mat.roi/3","doc":"Extracts a rectangular submatrix.\n\nThe submatrix data is copied.\n\n#### Variant 1\n##### Positional Arguments\n\n- **mat**. `maybe_mat_in()`\n\n  The matrix.\n\n- **rowRange**. `{int, int} | :all`.\n\n  Start and end row of the extracted submatrix. The upper boundary is not included.\n\n- **colRange**. `{int, int} | :all`.\n\n  Start and end column of the extracted submatrix. The upper boundary is not included.\n\n##### Return\n\nExtracted submatrix (data is copied).\n\n#### Variant 2\n##### Positional Arguments\n\n- **mat**. `maybe_mat_in()`\n\n  The matrix.\n\n- **rowRange**. `Range.t(step: 1)`.\n\n  Start and end row of the extracted submatrix. The upper boundary is not included.\n\n- **colRange**. `Range.t(step: 1)`.\n\n  Start and end column of the extracted submatrix. The upper boundary is not included.\n\n##### Return\n\nExtracted submatrix (data is copied).","ref":"Evision.Mat.html#roi/3"},{"type":"function","title":"Evision.Mat.round/1","doc":"","ref":"Evision.Mat.html#round/1"},{"type":"function","title":"Evision.Mat.set_kino_render_image_encoding/1","doc":"Set preferred image encoding when rendering in Kino.\n\nOnly valid when `:kino` >= 0.7 and using in livebook\n\n##### Positional Arguments\n- **encoding**. `:png | :jpeg`.\n\n  When rendering a 2D image with Kino in Livebook\n  the image will first be encoded into either :png or :jpeg\n\n  - `:png` usually has better quality because it is lossless compression,\n    however, it uses more bandwidth to transfer\n\n  - `:jpeg` require less bandwidth to pass from the backend to the livebook frontend,\n    but it is lossy compression","ref":"Evision.Mat.html#set_kino_render_image_encoding/1"},{"type":"function","title":"Evision.Mat.set_kino_render_image_max_size/1","doc":"Set the maximum allowed image size to render in Kino.\n\nOnly valid when `:kino` >= 0.7 and using in livebook\n\n##### Positional Arguments\n- **size**. `{height, width}`.","ref":"Evision.Mat.html#set_kino_render_image_max_size/1"},{"type":"function","title":"Evision.Mat.set_kino_render_tab_order/1","doc":"Set preferred order of Kino.Layout tabs for `Evision.Mat` in Livebook.\n\nOnly valid when `:kino` >= 0.7 and using in Livebook.\n\n##### Positional Arguments\n- **order**: `[atom()]`\n\n  Default order is `[:image, :raw, :numerical]`, and the corresponding tabs will be:\n\n    Image | Raw | Numerical\n\n  Note that the `:image` tab will not show if the `Evision.Mat` is not a 2D image.\n\n  Also, it's possible to specify any combination (any subset) of these tabs,\n  including the empty one, `[]`, and in that case, the output content in the livebook\n  cell will be the same as `:raw` but without any tabs.\n\n  Simply put, `[]` means to only do the basic inspect and not use Kino.Layout.tabs\n\n  **It's worth noting that `[] != nil`, because `nil` is default return value when `kino_render_tab_order`**\n  **is not configured -- hence evision will use the default order, `[:image, :raw, :numerical]` in such case**\n\n  When only specifying one type, i.e., `[:image]`, `[:raw]` or `[:numerical]`, only one tab will be shown.\n\n  Furthermore, when `kino_render_tab_order` is configured to `[:image]` and when the `Evision.Mat` is not a 2D image,\n  it will automatically fallback to `:raw`.\n\n  Simply put, `[:image]` in this case (when only specifying one type) means:\n\n  displaying the `Evision.Mat` as an image whenever possible, and fallback to `:raw`\n  if it's not a 2D image","ref":"Evision.Mat.html#set_kino_render_tab_order/1"},{"type":"function","title":"Evision.Mat.setTo/3","doc":"","ref":"Evision.Mat.html#setTo/3"},{"type":"function","title":"Evision.Mat.shape/1","doc":"","ref":"Evision.Mat.html#shape/1"},{"type":"function","title":"Evision.Mat.sign/1","doc":"","ref":"Evision.Mat.html#sign/1"},{"type":"function","title":"Evision.Mat.size/1","doc":"Returns the `cv::MatSize` of the matrix.\n\nThe method returns a tuple `{dims, p}` where `dims` is the number of dimensions, and `p` is a list with `dims` elements.","ref":"Evision.Mat.html#size/1"},{"type":"function","title":"Evision.Mat.squeeze/1","doc":"","ref":"Evision.Mat.html#squeeze/1"},{"type":"function","title":"Evision.Mat.subtract/2","doc":"","ref":"Evision.Mat.html#subtract/2"},{"type":"function","title":"Evision.Mat.subtract/3","doc":"","ref":"Evision.Mat.html#subtract/3"},{"type":"function","title":"Evision.Mat.to_batched/3","doc":"","ref":"Evision.Mat.html#to_batched/3"},{"type":"function","title":"Evision.Mat.to_batched/4","doc":"","ref":"Evision.Mat.html#to_batched/4"},{"type":"function","title":"Evision.Mat.to_binary/2","doc":"","ref":"Evision.Mat.html#to_binary/2"},{"type":"function","title":"Evision.Mat.to_nx/2","doc":"Transform an `Evision.Mat` to `Nx.tensor`.\n\n##### Positional Arguments\n- **mat**: `maybe_mat_in()`\n\n  Evision.Mat\n\n- **backend**: `module()`\n\n  Nx backend.\n\n##### Return\nIf the input `Evision.Mat` represents a 2D image, the resulting tensor\nwill have shape `{height, width, channels}`.","ref":"Evision.Mat.html#to_nx/2"},{"type":"function","title":"Example - Evision.Mat.to_nx/2","doc":"```elixir\niex> %Evision.Mat{} = mat = Evision.imread(\"/path/to/exist/img.png\")\niex> nx_tensor = Evision.Mat.to_nx(mat)\n#Nx.Tensor \n```","ref":"Evision.Mat.html#to_nx/2-example"},{"type":"function","title":"Evision.Mat.to_pointer/1","doc":"Get raw pointers","ref":"Evision.Mat.html#to_pointer/1"},{"type":"function","title":"Evision.Mat.to_pointer/2","doc":"","ref":"Evision.Mat.html#to_pointer/2"},{"type":"function","title":"Evision.Mat.total/1","doc":"Returns the total number of array elements.\n\nThe method returns the number of array elements (a number of pixels if the array represents an image).","ref":"Evision.Mat.html#total/1"},{"type":"function","title":"Evision.Mat.total/3","doc":"Returns the total number of array elements.\n\nThe method returns the number of elements within a certain sub-array slice with start_dim <= dim < end_dim","ref":"Evision.Mat.html#total/3"},{"type":"function","title":"Evision.Mat.transpose/1","doc":"Transpose a matrix","ref":"Evision.Mat.html#transpose/1"},{"type":"function","title":"Parameters - Evision.Mat.transpose/1","doc":"- `mat`. The matrix.\n\n    by default it reverses the order of the axes.","ref":"Evision.Mat.html#transpose/1-parameters"},{"type":"function","title":"Evision.Mat.transpose/3","doc":"Transpose a matrix","ref":"Evision.Mat.html#transpose/3"},{"type":"function","title":"Parameters - Evision.Mat.transpose/3","doc":"- **mat**. `Evision.Mat`\n  - **axes**. `[int]`\n\n      It must be a list which contains a permutation of [0,1,..,N-1]\n      where N is the number of axes of `mat`. The i’th axis of the returned array will correspond to the\n      axis numbered axes[i] of the input.\n\n  - **opts**. Keyword options.\n\n      - `as_shape`. A tuple or list which overwrites the shape of the matrix (the total number of elements\n        must be equal to the one as in its original shape). For example, a 4x4 matrix can be treated as a\n        2x2x2x2 matrix and transposed with `axes=[2,1,3,0]` in a single call.\n\n        When specified, it combines the reshape and transpose operation in a single NIF call.","ref":"Evision.Mat.html#transpose/3-parameters"},{"type":"function","title":"Evision.Mat.type/1","doc":"This method returns the type-tuple used by Nx. To get the raw value of `cv::Mat.type()`, please use\n`Evision.Mat.raw_type/1`.","ref":"Evision.Mat.html#type/1"},{"type":"function","title":"Evision.Mat.update_roi/3","doc":"","ref":"Evision.Mat.html#update_roi/3"},{"type":"function","title":"Evision.Mat.zeros/2","doc":"","ref":"Evision.Mat.html#zeros/2"},{"type":"type","title":"Evision.Mat.enum/0","doc":"","ref":"Evision.Mat.html#t:enum/0"},{"type":"type","title":"Evision.Mat.mat_type/0","doc":"Types for `Evision.Mat`\n\n#### Shorthand\n\n- `:u8`\n- `:u16`\n- `:s16`\n- `:s32`\n- `:f32`\n- `:f64`\n- `:f16`\n\n#### Tuple Form\n\n- `{:u, 8}`\n- `{:u, 16}`\n- `{:s, 8}`\n- `{:s, 16}`\n- `{:s, 32}`\n- `{:f, 32}`\n- `{:f, 64}`\n- `{:f, 16}`","ref":"Evision.Mat.html#t:mat_type/0"},{"type":"type","title":"Evision.Mat.mat_type_tuple_form/0","doc":"","ref":"Evision.Mat.html#t:mat_type_tuple_form/0"},{"type":"type","title":"Evision.Mat.maybe_mat_in/0","doc":"Input argument, `Evision.Mat`, `Nx.Tensor`, `#reference`, or a single number, or a n-tuple of n numbers.\n\n- `Evision.Mat`, recommended to use.\n- `Nx.Tensor`, recommended to use.\n\n  Accepting this type so that it's easier to interact with a `Nx.Tensor`.\n\n- `number()`.\n- `tuple()`, should be a n-tuple of n numbers.\n\n- `reference()`, not recommended.\n\n  Only some internal functions will pass the raw reference variables around.","ref":"Evision.Mat.html#t:maybe_mat_in/0"},{"type":"type","title":"Evision.Mat.maybe_mat_out/0","doc":"The resulting ok-error tuple when a NIF function can return `Evision.Mat`.","ref":"Evision.Mat.html#t:maybe_mat_out/0"},{"type":"type","title":"Evision.Mat.t/0","doc":"Type that represents an `Evision.Mat` struct.\n\n- **channels**: `int`.\n\n  The number of matrix channels.\n\n- **dims**: `int`.\n\n  Matrix dimensionality.\n\n- **type**: `mat_type`.\n\n  Type of the matrix elements, following `:nx`'s convention.\n\n- **raw_type**: `int`.\n\n  The raw value returned from `int cv::Mat::type()`.\n\n- **shape**: `tuple`.\n\n  The shape of the matrix.\n\n- **ref**: `reference`.\n\n  The underlying erlang resource variable.","ref":"Evision.Mat.html#t:t/0"},{"type":"module","title":"Evision.Mat.DepthMask","doc":"","ref":"Evision.Mat.DepthMask.html"},{"type":"function","title":"Evision.Mat.DepthMask.cv_DEPTH_MASK_8S/0","doc":"","ref":"Evision.Mat.DepthMask.html#cv_DEPTH_MASK_8S/0"},{"type":"function","title":"Evision.Mat.DepthMask.cv_DEPTH_MASK_8U/0","doc":"","ref":"Evision.Mat.DepthMask.html#cv_DEPTH_MASK_8U/0"},{"type":"function","title":"Evision.Mat.DepthMask.cv_DEPTH_MASK_16F/0","doc":"","ref":"Evision.Mat.DepthMask.html#cv_DEPTH_MASK_16F/0"},{"type":"function","title":"Evision.Mat.DepthMask.cv_DEPTH_MASK_16S/0","doc":"","ref":"Evision.Mat.DepthMask.html#cv_DEPTH_MASK_16S/0"},{"type":"function","title":"Evision.Mat.DepthMask.cv_DEPTH_MASK_16U/0","doc":"","ref":"Evision.Mat.DepthMask.html#cv_DEPTH_MASK_16U/0"},{"type":"function","title":"Evision.Mat.DepthMask.cv_DEPTH_MASK_32F/0","doc":"","ref":"Evision.Mat.DepthMask.html#cv_DEPTH_MASK_32F/0"},{"type":"function","title":"Evision.Mat.DepthMask.cv_DEPTH_MASK_32S/0","doc":"","ref":"Evision.Mat.DepthMask.html#cv_DEPTH_MASK_32S/0"},{"type":"function","title":"Evision.Mat.DepthMask.cv_DEPTH_MASK_64F/0","doc":"","ref":"Evision.Mat.DepthMask.html#cv_DEPTH_MASK_64F/0"},{"type":"function","title":"Evision.Mat.DepthMask.cv_DEPTH_MASK_ALL/0","doc":"","ref":"Evision.Mat.DepthMask.html#cv_DEPTH_MASK_ALL/0"},{"type":"function","title":"Evision.Mat.DepthMask.cv_DEPTH_MASK_ALL_16F/0","doc":"","ref":"Evision.Mat.DepthMask.html#cv_DEPTH_MASK_ALL_16F/0"},{"type":"function","title":"Evision.Mat.DepthMask.cv_DEPTH_MASK_ALL_BUT_8S/0","doc":"","ref":"Evision.Mat.DepthMask.html#cv_DEPTH_MASK_ALL_BUT_8S/0"},{"type":"function","title":"Evision.Mat.DepthMask.cv_DEPTH_MASK_FLT/0","doc":"","ref":"Evision.Mat.DepthMask.html#cv_DEPTH_MASK_FLT/0"},{"type":"type","title":"Evision.Mat.DepthMask.enum/0","doc":"","ref":"Evision.Mat.DepthMask.html#t:enum/0"},{"type":"module","title":"Evision.Mat.KindFlag","doc":"","ref":"Evision.Mat.KindFlag.html"},{"type":"function","title":"Evision.Mat.KindFlag.cv_CUDA_GPU_MAT/0","doc":"","ref":"Evision.Mat.KindFlag.html#cv_CUDA_GPU_MAT/0"},{"type":"function","title":"Evision.Mat.KindFlag.cv_CUDA_HOST_MEM/0","doc":"","ref":"Evision.Mat.KindFlag.html#cv_CUDA_HOST_MEM/0"},{"type":"function","title":"Evision.Mat.KindFlag.cv_EXPR/0","doc":"","ref":"Evision.Mat.KindFlag.html#cv_EXPR/0"},{"type":"function","title":"Evision.Mat.KindFlag.cv_FIXED_SIZE/0","doc":"","ref":"Evision.Mat.KindFlag.html#cv_FIXED_SIZE/0"},{"type":"function","title":"Evision.Mat.KindFlag.cv_FIXED_TYPE/0","doc":"","ref":"Evision.Mat.KindFlag.html#cv_FIXED_TYPE/0"},{"type":"function","title":"Evision.Mat.KindFlag.cv_KIND_MASK/0","doc":"","ref":"Evision.Mat.KindFlag.html#cv_KIND_MASK/0"},{"type":"function","title":"Evision.Mat.KindFlag.cv_KIND_SHIFT/0","doc":"","ref":"Evision.Mat.KindFlag.html#cv_KIND_SHIFT/0"},{"type":"function","title":"Evision.Mat.KindFlag.cv_MAT/0","doc":"","ref":"Evision.Mat.KindFlag.html#cv_MAT/0"},{"type":"function","title":"Evision.Mat.KindFlag.cv_MATX/0","doc":"","ref":"Evision.Mat.KindFlag.html#cv_MATX/0"},{"type":"function","title":"Evision.Mat.KindFlag.cv_NONE/0","doc":"","ref":"Evision.Mat.KindFlag.html#cv_NONE/0"},{"type":"function","title":"Evision.Mat.KindFlag.cv_OPENGL_BUFFER/0","doc":"","ref":"Evision.Mat.KindFlag.html#cv_OPENGL_BUFFER/0"},{"type":"function","title":"Evision.Mat.KindFlag.cv_STD_ARRAY/0","doc":"","ref":"Evision.Mat.KindFlag.html#cv_STD_ARRAY/0"},{"type":"function","title":"Evision.Mat.KindFlag.cv_STD_ARRAY_MAT/0","doc":"","ref":"Evision.Mat.KindFlag.html#cv_STD_ARRAY_MAT/0"},{"type":"function","title":"Evision.Mat.KindFlag.cv_STD_BOOL_VECTOR/0","doc":"","ref":"Evision.Mat.KindFlag.html#cv_STD_BOOL_VECTOR/0"},{"type":"function","title":"Evision.Mat.KindFlag.cv_STD_VECTOR/0","doc":"","ref":"Evision.Mat.KindFlag.html#cv_STD_VECTOR/0"},{"type":"function","title":"Evision.Mat.KindFlag.cv_STD_VECTOR_CUDA_GPU_MAT/0","doc":"","ref":"Evision.Mat.KindFlag.html#cv_STD_VECTOR_CUDA_GPU_MAT/0"},{"type":"function","title":"Evision.Mat.KindFlag.cv_STD_VECTOR_MAT/0","doc":"","ref":"Evision.Mat.KindFlag.html#cv_STD_VECTOR_MAT/0"},{"type":"function","title":"Evision.Mat.KindFlag.cv_STD_VECTOR_UMAT/0","doc":"","ref":"Evision.Mat.KindFlag.html#cv_STD_VECTOR_UMAT/0"},{"type":"function","title":"Evision.Mat.KindFlag.cv_STD_VECTOR_VECTOR/0","doc":"","ref":"Evision.Mat.KindFlag.html#cv_STD_VECTOR_VECTOR/0"},{"type":"function","title":"Evision.Mat.KindFlag.cv_UMAT/0","doc":"","ref":"Evision.Mat.KindFlag.html#cv_UMAT/0"},{"type":"type","title":"Evision.Mat.KindFlag.enum/0","doc":"","ref":"Evision.Mat.KindFlag.html#t:enum/0"},{"type":"module","title":"Evision.MergeDebevec","doc":"","ref":"Evision.MergeDebevec.html"},{"type":"function","title":"Evision.MergeDebevec.process/1","doc":"","ref":"Evision.MergeDebevec.html#process/1"},{"type":"function","title":"Evision.MergeDebevec.process/3","doc":"process\n\n##### Positional Arguments\n- **self**: `Evision.MergeDebevec.t()`\n- **src**: `[Evision.Mat]`\n- **times**: `Evision.Mat`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nprocess(src, times[, dst]) -> dst\n```","ref":"Evision.MergeDebevec.html#process/3"},{"type":"function","title":"Evision.MergeDebevec.process/4","doc":"#### Variant 1:\nprocess\n\n##### Positional Arguments\n- **self**: `Evision.MergeDebevec.t()`\n- **src**: `[Evision.Mat]`\n- **times**: `Evision.Mat`\n- **response**: `Evision.Mat`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nprocess(src, times, response[, dst]) -> dst\n```\n#### Variant 2:\nprocess\n\n##### Positional Arguments\n- **self**: `Evision.MergeDebevec.t()`\n- **src**: `[Evision.Mat]`\n- **times**: `Evision.Mat`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nprocess(src, times[, dst]) -> dst\n```","ref":"Evision.MergeDebevec.html#process/4"},{"type":"function","title":"Evision.MergeDebevec.process/5","doc":"process\n\n##### Positional Arguments\n- **self**: `Evision.MergeDebevec.t()`\n- **src**: `[Evision.Mat]`\n- **times**: `Evision.Mat`\n- **response**: `Evision.Mat`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nprocess(src, times, response[, dst]) -> dst\n```","ref":"Evision.MergeDebevec.html#process/5"},{"type":"type","title":"Evision.MergeDebevec.t/0","doc":"Type that represents an `MergeDebevec` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.MergeDebevec.html#t:t/0"},{"type":"module","title":"Evision.MergeExposures","doc":"","ref":"Evision.MergeExposures.html"},{"type":"function","title":"Evision.MergeExposures.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.MergeExposures.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.MergeExposures.html#clear/1"},{"type":"function","title":"Evision.MergeExposures.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.MergeExposures.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.MergeExposures.html#empty/1"},{"type":"function","title":"Evision.MergeExposures.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.MergeExposures.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.MergeExposures.html#getDefaultName/1"},{"type":"function","title":"Evision.MergeExposures.process/1","doc":"","ref":"Evision.MergeExposures.html#process/1"},{"type":"function","title":"Evision.MergeExposures.process/4","doc":"Merges images.\n\n##### Positional Arguments\n- **self**: `Evision.MergeExposures.t()`\n- **src**: `[Evision.Mat]`.\n\n  vector of input images\n\n- **times**: `Evision.Mat`.\n\n  vector of exposure time values for each image\n\n- **response**: `Evision.Mat`.\n\n  256x1 matrix with inverse camera response function for each pixel value, it should\n  have the same number of channels as images.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  result image\n\nPython prototype (for reference only):\n```python3\nprocess(src, times, response[, dst]) -> dst\n```","ref":"Evision.MergeExposures.html#process/4"},{"type":"function","title":"Evision.MergeExposures.process/5","doc":"Merges images.\n\n##### Positional Arguments\n- **self**: `Evision.MergeExposures.t()`\n- **src**: `[Evision.Mat]`.\n\n  vector of input images\n\n- **times**: `Evision.Mat`.\n\n  vector of exposure time values for each image\n\n- **response**: `Evision.Mat`.\n\n  256x1 matrix with inverse camera response function for each pixel value, it should\n  have the same number of channels as images.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  result image\n\nPython prototype (for reference only):\n```python3\nprocess(src, times, response[, dst]) -> dst\n```","ref":"Evision.MergeExposures.html#process/5"},{"type":"function","title":"Evision.MergeExposures.read/1","doc":"","ref":"Evision.MergeExposures.html#read/1"},{"type":"function","title":"Evision.MergeExposures.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.MergeExposures.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.MergeExposures.html#read/2"},{"type":"function","title":"Evision.MergeExposures.save/1","doc":"","ref":"Evision.MergeExposures.html#save/1"},{"type":"function","title":"Evision.MergeExposures.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.MergeExposures.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.MergeExposures.html#save/2"},{"type":"function","title":"Evision.MergeExposures.write/1","doc":"","ref":"Evision.MergeExposures.html#write/1"},{"type":"function","title":"Evision.MergeExposures.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.MergeExposures.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.MergeExposures.html#write/2"},{"type":"function","title":"Evision.MergeExposures.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.MergeExposures.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.MergeExposures.html#write/3"},{"type":"type","title":"Evision.MergeExposures.t/0","doc":"Type that represents an `MergeExposures` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.MergeExposures.html#t:t/0"},{"type":"module","title":"Evision.MergeMertens","doc":"","ref":"Evision.MergeMertens.html"},{"type":"function","title":"Evision.MergeMertens.getContrastWeight/1","doc":"getContrastWeight\n\n##### Positional Arguments\n- **self**: `Evision.MergeMertens.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetContrastWeight() -> retval\n```","ref":"Evision.MergeMertens.html#getContrastWeight/1"},{"type":"function","title":"Evision.MergeMertens.getExposureWeight/1","doc":"getExposureWeight\n\n##### Positional Arguments\n- **self**: `Evision.MergeMertens.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetExposureWeight() -> retval\n```","ref":"Evision.MergeMertens.html#getExposureWeight/1"},{"type":"function","title":"Evision.MergeMertens.getSaturationWeight/1","doc":"getSaturationWeight\n\n##### Positional Arguments\n- **self**: `Evision.MergeMertens.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetSaturationWeight() -> retval\n```","ref":"Evision.MergeMertens.html#getSaturationWeight/1"},{"type":"function","title":"Evision.MergeMertens.process/1","doc":"","ref":"Evision.MergeMertens.html#process/1"},{"type":"function","title":"Evision.MergeMertens.process/2","doc":"Short version of process, that doesn't take extra arguments.\n\n##### Positional Arguments\n- **self**: `Evision.MergeMertens.t()`\n- **src**: `[Evision.Mat]`.\n\n  vector of input images\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  result image\n\nPython prototype (for reference only):\n```python3\nprocess(src[, dst]) -> dst\n```","ref":"Evision.MergeMertens.html#process/2"},{"type":"function","title":"Evision.MergeMertens.process/3","doc":"Short version of process, that doesn't take extra arguments.\n\n##### Positional Arguments\n- **self**: `Evision.MergeMertens.t()`\n- **src**: `[Evision.Mat]`.\n\n  vector of input images\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  result image\n\nPython prototype (for reference only):\n```python3\nprocess(src[, dst]) -> dst\n```","ref":"Evision.MergeMertens.html#process/3"},{"type":"function","title":"Evision.MergeMertens.process/4","doc":"process\n\n##### Positional Arguments\n- **self**: `Evision.MergeMertens.t()`\n- **src**: `[Evision.Mat]`\n- **times**: `Evision.Mat`\n- **response**: `Evision.Mat`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nprocess(src, times, response[, dst]) -> dst\n```","ref":"Evision.MergeMertens.html#process/4"},{"type":"function","title":"Evision.MergeMertens.process/5","doc":"process\n\n##### Positional Arguments\n- **self**: `Evision.MergeMertens.t()`\n- **src**: `[Evision.Mat]`\n- **times**: `Evision.Mat`\n- **response**: `Evision.Mat`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nprocess(src, times, response[, dst]) -> dst\n```","ref":"Evision.MergeMertens.html#process/5"},{"type":"function","title":"Evision.MergeMertens.setContrastWeight/1","doc":"","ref":"Evision.MergeMertens.html#setContrastWeight/1"},{"type":"function","title":"Evision.MergeMertens.setContrastWeight/2","doc":"setContrastWeight\n\n##### Positional Arguments\n- **self**: `Evision.MergeMertens.t()`\n- **contrast_weiht**: `float`\n\nPython prototype (for reference only):\n```python3\nsetContrastWeight(contrast_weiht) -> None\n```","ref":"Evision.MergeMertens.html#setContrastWeight/2"},{"type":"function","title":"Evision.MergeMertens.setExposureWeight/1","doc":"","ref":"Evision.MergeMertens.html#setExposureWeight/1"},{"type":"function","title":"Evision.MergeMertens.setExposureWeight/2","doc":"setExposureWeight\n\n##### Positional Arguments\n- **self**: `Evision.MergeMertens.t()`\n- **exposure_weight**: `float`\n\nPython prototype (for reference only):\n```python3\nsetExposureWeight(exposure_weight) -> None\n```","ref":"Evision.MergeMertens.html#setExposureWeight/2"},{"type":"function","title":"Evision.MergeMertens.setSaturationWeight/1","doc":"","ref":"Evision.MergeMertens.html#setSaturationWeight/1"},{"type":"function","title":"Evision.MergeMertens.setSaturationWeight/2","doc":"setSaturationWeight\n\n##### Positional Arguments\n- **self**: `Evision.MergeMertens.t()`\n- **saturation_weight**: `float`\n\nPython prototype (for reference only):\n```python3\nsetSaturationWeight(saturation_weight) -> None\n```","ref":"Evision.MergeMertens.html#setSaturationWeight/2"},{"type":"type","title":"Evision.MergeMertens.t/0","doc":"Type that represents an `MergeMertens` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.MergeMertens.html#t:t/0"},{"type":"module","title":"Evision.MergeRobertson","doc":"","ref":"Evision.MergeRobertson.html"},{"type":"function","title":"Evision.MergeRobertson.process/1","doc":"","ref":"Evision.MergeRobertson.html#process/1"},{"type":"function","title":"Evision.MergeRobertson.process/3","doc":"process\n\n##### Positional Arguments\n- **self**: `Evision.MergeRobertson.t()`\n- **src**: `[Evision.Mat]`\n- **times**: `Evision.Mat`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nprocess(src, times[, dst]) -> dst\n```","ref":"Evision.MergeRobertson.html#process/3"},{"type":"function","title":"Evision.MergeRobertson.process/4","doc":"#### Variant 1:\nprocess\n\n##### Positional Arguments\n- **self**: `Evision.MergeRobertson.t()`\n- **src**: `[Evision.Mat]`\n- **times**: `Evision.Mat`\n- **response**: `Evision.Mat`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nprocess(src, times, response[, dst]) -> dst\n```\n#### Variant 2:\nprocess\n\n##### Positional Arguments\n- **self**: `Evision.MergeRobertson.t()`\n- **src**: `[Evision.Mat]`\n- **times**: `Evision.Mat`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nprocess(src, times[, dst]) -> dst\n```","ref":"Evision.MergeRobertson.html#process/4"},{"type":"function","title":"Evision.MergeRobertson.process/5","doc":"process\n\n##### Positional Arguments\n- **self**: `Evision.MergeRobertson.t()`\n- **src**: `[Evision.Mat]`\n- **times**: `Evision.Mat`\n- **response**: `Evision.Mat`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nprocess(src, times, response[, dst]) -> dst\n```","ref":"Evision.MergeRobertson.html#process/5"},{"type":"type","title":"Evision.MergeRobertson.t/0","doc":"Type that represents an `MergeRobertson` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.MergeRobertson.html#t:t/0"},{"type":"module","title":"Evision.MorphShapes","doc":"","ref":"Evision.MorphShapes.html"},{"type":"function","title":"Evision.MorphShapes.cv_MORPH_CROSS/0","doc":"","ref":"Evision.MorphShapes.html#cv_MORPH_CROSS/0"},{"type":"function","title":"Evision.MorphShapes.cv_MORPH_ELLIPSE/0","doc":"","ref":"Evision.MorphShapes.html#cv_MORPH_ELLIPSE/0"},{"type":"function","title":"Evision.MorphShapes.cv_MORPH_RECT/0","doc":"","ref":"Evision.MorphShapes.html#cv_MORPH_RECT/0"},{"type":"type","title":"Evision.MorphShapes.enum/0","doc":"","ref":"Evision.MorphShapes.html#t:enum/0"},{"type":"module","title":"Evision.MorphTypes","doc":"","ref":"Evision.MorphTypes.html"},{"type":"function","title":"Evision.MorphTypes.cv_MORPH_BLACKHAT/0","doc":"","ref":"Evision.MorphTypes.html#cv_MORPH_BLACKHAT/0"},{"type":"function","title":"Evision.MorphTypes.cv_MORPH_CLOSE/0","doc":"","ref":"Evision.MorphTypes.html#cv_MORPH_CLOSE/0"},{"type":"function","title":"Evision.MorphTypes.cv_MORPH_DILATE/0","doc":"","ref":"Evision.MorphTypes.html#cv_MORPH_DILATE/0"},{"type":"function","title":"Evision.MorphTypes.cv_MORPH_ERODE/0","doc":"","ref":"Evision.MorphTypes.html#cv_MORPH_ERODE/0"},{"type":"function","title":"Evision.MorphTypes.cv_MORPH_GRADIENT/0","doc":"","ref":"Evision.MorphTypes.html#cv_MORPH_GRADIENT/0"},{"type":"function","title":"Evision.MorphTypes.cv_MORPH_HITMISS/0","doc":"","ref":"Evision.MorphTypes.html#cv_MORPH_HITMISS/0"},{"type":"function","title":"Evision.MorphTypes.cv_MORPH_OPEN/0","doc":"","ref":"Evision.MorphTypes.html#cv_MORPH_OPEN/0"},{"type":"function","title":"Evision.MorphTypes.cv_MORPH_TOPHAT/0","doc":"","ref":"Evision.MorphTypes.html#cv_MORPH_TOPHAT/0"},{"type":"type","title":"Evision.MorphTypes.enum/0","doc":"","ref":"Evision.MorphTypes.html#t:enum/0"},{"type":"module","title":"Evision.MouseEventFlags","doc":"","ref":"Evision.MouseEventFlags.html"},{"type":"function","title":"Evision.MouseEventFlags.cv_EVENT_FLAG_ALTKEY/0","doc":"","ref":"Evision.MouseEventFlags.html#cv_EVENT_FLAG_ALTKEY/0"},{"type":"function","title":"Evision.MouseEventFlags.cv_EVENT_FLAG_CTRLKEY/0","doc":"","ref":"Evision.MouseEventFlags.html#cv_EVENT_FLAG_CTRLKEY/0"},{"type":"function","title":"Evision.MouseEventFlags.cv_EVENT_FLAG_LBUTTON/0","doc":"","ref":"Evision.MouseEventFlags.html#cv_EVENT_FLAG_LBUTTON/0"},{"type":"function","title":"Evision.MouseEventFlags.cv_EVENT_FLAG_MBUTTON/0","doc":"","ref":"Evision.MouseEventFlags.html#cv_EVENT_FLAG_MBUTTON/0"},{"type":"function","title":"Evision.MouseEventFlags.cv_EVENT_FLAG_RBUTTON/0","doc":"","ref":"Evision.MouseEventFlags.html#cv_EVENT_FLAG_RBUTTON/0"},{"type":"function","title":"Evision.MouseEventFlags.cv_EVENT_FLAG_SHIFTKEY/0","doc":"","ref":"Evision.MouseEventFlags.html#cv_EVENT_FLAG_SHIFTKEY/0"},{"type":"type","title":"Evision.MouseEventFlags.enum/0","doc":"","ref":"Evision.MouseEventFlags.html#t:enum/0"},{"type":"module","title":"Evision.MouseEventTypes","doc":"","ref":"Evision.MouseEventTypes.html"},{"type":"function","title":"Evision.MouseEventTypes.cv_EVENT_LBUTTONDBLCLK/0","doc":"","ref":"Evision.MouseEventTypes.html#cv_EVENT_LBUTTONDBLCLK/0"},{"type":"function","title":"Evision.MouseEventTypes.cv_EVENT_LBUTTONDOWN/0","doc":"","ref":"Evision.MouseEventTypes.html#cv_EVENT_LBUTTONDOWN/0"},{"type":"function","title":"Evision.MouseEventTypes.cv_EVENT_LBUTTONUP/0","doc":"","ref":"Evision.MouseEventTypes.html#cv_EVENT_LBUTTONUP/0"},{"type":"function","title":"Evision.MouseEventTypes.cv_EVENT_MBUTTONDBLCLK/0","doc":"","ref":"Evision.MouseEventTypes.html#cv_EVENT_MBUTTONDBLCLK/0"},{"type":"function","title":"Evision.MouseEventTypes.cv_EVENT_MBUTTONDOWN/0","doc":"","ref":"Evision.MouseEventTypes.html#cv_EVENT_MBUTTONDOWN/0"},{"type":"function","title":"Evision.MouseEventTypes.cv_EVENT_MBUTTONUP/0","doc":"","ref":"Evision.MouseEventTypes.html#cv_EVENT_MBUTTONUP/0"},{"type":"function","title":"Evision.MouseEventTypes.cv_EVENT_MOUSEHWHEEL/0","doc":"","ref":"Evision.MouseEventTypes.html#cv_EVENT_MOUSEHWHEEL/0"},{"type":"function","title":"Evision.MouseEventTypes.cv_EVENT_MOUSEMOVE/0","doc":"","ref":"Evision.MouseEventTypes.html#cv_EVENT_MOUSEMOVE/0"},{"type":"function","title":"Evision.MouseEventTypes.cv_EVENT_MOUSEWHEEL/0","doc":"","ref":"Evision.MouseEventTypes.html#cv_EVENT_MOUSEWHEEL/0"},{"type":"function","title":"Evision.MouseEventTypes.cv_EVENT_RBUTTONDBLCLK/0","doc":"","ref":"Evision.MouseEventTypes.html#cv_EVENT_RBUTTONDBLCLK/0"},{"type":"function","title":"Evision.MouseEventTypes.cv_EVENT_RBUTTONDOWN/0","doc":"","ref":"Evision.MouseEventTypes.html#cv_EVENT_RBUTTONDOWN/0"},{"type":"function","title":"Evision.MouseEventTypes.cv_EVENT_RBUTTONUP/0","doc":"","ref":"Evision.MouseEventTypes.html#cv_EVENT_RBUTTONUP/0"},{"type":"type","title":"Evision.MouseEventTypes.enum/0","doc":"","ref":"Evision.MouseEventTypes.html#t:enum/0"},{"type":"module","title":"Evision.MultiCalib.MultiCameraCalibration","doc":"","ref":"Evision.MultiCalib.MultiCameraCalibration.html"},{"type":"function","title":"Evision.MultiCalib.MultiCameraCalibration.cv_OMNIDIRECTIONAL/0","doc":"","ref":"Evision.MultiCalib.MultiCameraCalibration.html#cv_OMNIDIRECTIONAL/0"},{"type":"function","title":"Evision.MultiCalib.MultiCameraCalibration.cv_PINHOLE/0","doc":"","ref":"Evision.MultiCalib.MultiCameraCalibration.html#cv_PINHOLE/0"},{"type":"type","title":"Evision.MultiCalib.MultiCameraCalibration.enum/0","doc":"","ref":"Evision.MultiCalib.MultiCameraCalibration.html#t:enum/0"},{"type":"module","title":"Evision.NeighborSearchMethod","doc":"","ref":"Evision.NeighborSearchMethod.html"},{"type":"function","title":"Evision.NeighborSearchMethod.cv_NEIGH_FLANN_KNN/0","doc":"","ref":"Evision.NeighborSearchMethod.html#cv_NEIGH_FLANN_KNN/0"},{"type":"function","title":"Evision.NeighborSearchMethod.cv_NEIGH_FLANN_RADIUS/0","doc":"","ref":"Evision.NeighborSearchMethod.html#cv_NEIGH_FLANN_RADIUS/0"},{"type":"function","title":"Evision.NeighborSearchMethod.cv_NEIGH_GRID/0","doc":"","ref":"Evision.NeighborSearchMethod.html#cv_NEIGH_GRID/0"},{"type":"type","title":"Evision.NeighborSearchMethod.enum/0","doc":"","ref":"Evision.NeighborSearchMethod.html#t:enum/0"},{"type":"module","title":"Evision.NormHistogramCostExtractor","doc":"","ref":"Evision.NormHistogramCostExtractor.html"},{"type":"function","title":"Evision.NormHistogramCostExtractor.getNormFlag/1","doc":"getNormFlag\n\n##### Positional Arguments\n- **self**: `Evision.NormHistogramCostExtractor.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNormFlag() -> retval\n```","ref":"Evision.NormHistogramCostExtractor.html#getNormFlag/1"},{"type":"function","title":"Evision.NormHistogramCostExtractor.setNormFlag/1","doc":"","ref":"Evision.NormHistogramCostExtractor.html#setNormFlag/1"},{"type":"function","title":"Evision.NormHistogramCostExtractor.setNormFlag/2","doc":"setNormFlag\n\n##### Positional Arguments\n- **self**: `Evision.NormHistogramCostExtractor.t()`\n- **flag**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNormFlag(flag) -> None\n```","ref":"Evision.NormHistogramCostExtractor.html#setNormFlag/2"},{"type":"type","title":"Evision.NormHistogramCostExtractor.t/0","doc":"Type that represents an `NormHistogramCostExtractor` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.NormHistogramCostExtractor.html#t:t/0"},{"type":"module","title":"Evision.NormTypes","doc":"","ref":"Evision.NormTypes.html"},{"type":"function","title":"Evision.NormTypes.cv_NORM_HAMMING2/0","doc":"","ref":"Evision.NormTypes.html#cv_NORM_HAMMING2/0"},{"type":"function","title":"Evision.NormTypes.cv_NORM_HAMMING/0","doc":"","ref":"Evision.NormTypes.html#cv_NORM_HAMMING/0"},{"type":"function","title":"Evision.NormTypes.cv_NORM_INF/0","doc":"","ref":"Evision.NormTypes.html#cv_NORM_INF/0"},{"type":"function","title":"Evision.NormTypes.cv_NORM_L1/0","doc":"","ref":"Evision.NormTypes.html#cv_NORM_L1/0"},{"type":"function","title":"Evision.NormTypes.cv_NORM_L2/0","doc":"","ref":"Evision.NormTypes.html#cv_NORM_L2/0"},{"type":"function","title":"Evision.NormTypes.cv_NORM_L2SQR/0","doc":"","ref":"Evision.NormTypes.html#cv_NORM_L2SQR/0"},{"type":"function","title":"Evision.NormTypes.cv_NORM_MINMAX/0","doc":"","ref":"Evision.NormTypes.html#cv_NORM_MINMAX/0"},{"type":"function","title":"Evision.NormTypes.cv_NORM_RELATIVE/0","doc":"","ref":"Evision.NormTypes.html#cv_NORM_RELATIVE/0"},{"type":"function","title":"Evision.NormTypes.cv_NORM_TYPE_MASK/0","doc":"","ref":"Evision.NormTypes.html#cv_NORM_TYPE_MASK/0"},{"type":"type","title":"Evision.NormTypes.enum/0","doc":"","ref":"Evision.NormTypes.html#t:enum/0"},{"type":"module","title":"Evision.OCL","doc":"","ref":"Evision.OCL.html"},{"type":"function","title":"Evision.OCL.finish/0","doc":"finish\n\nPython prototype (for reference only):\n```python3\nfinish() -> None\n```","ref":"Evision.OCL.html#finish/0"},{"type":"function","title":"Evision.OCL.finish/1","doc":"","ref":"Evision.OCL.html#finish/1"},{"type":"function","title":"Evision.OCL.haveAmdBlas/0","doc":"haveAmdBlas\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nhaveAmdBlas() -> retval\n```","ref":"Evision.OCL.html#haveAmdBlas/0"},{"type":"function","title":"Evision.OCL.haveAmdBlas/1","doc":"","ref":"Evision.OCL.html#haveAmdBlas/1"},{"type":"function","title":"Evision.OCL.haveAmdFft/0","doc":"haveAmdFft\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nhaveAmdFft() -> retval\n```","ref":"Evision.OCL.html#haveAmdFft/0"},{"type":"function","title":"Evision.OCL.haveAmdFft/1","doc":"","ref":"Evision.OCL.html#haveAmdFft/1"},{"type":"function","title":"Evision.OCL.haveOpenCL/0","doc":"haveOpenCL\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nhaveOpenCL() -> retval\n```","ref":"Evision.OCL.html#haveOpenCL/0"},{"type":"function","title":"Evision.OCL.haveOpenCL/1","doc":"","ref":"Evision.OCL.html#haveOpenCL/1"},{"type":"function","title":"Evision.OCL.setUseOpenCL/1","doc":"setUseOpenCL\n\n##### Positional Arguments\n- **flag**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetUseOpenCL(flag) -> None\n```","ref":"Evision.OCL.html#setUseOpenCL/1"},{"type":"function","title":"Evision.OCL.useOpenCL/0","doc":"useOpenCL\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nuseOpenCL() -> retval\n```","ref":"Evision.OCL.html#useOpenCL/0"},{"type":"function","title":"Evision.OCL.useOpenCL/1","doc":"","ref":"Evision.OCL.html#useOpenCL/1"},{"type":"type","title":"Evision.OCL.t/0","doc":"Type that represents an `OCL` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.OCL.html#t:t/0"},{"type":"module","title":"Evision.OCL.Device","doc":"","ref":"Evision.OCL.Device.html"},{"type":"function","title":"Evision.OCL.Device.addressBits/1","doc":"addressBits\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\naddressBits() -> retval\n```","ref":"Evision.OCL.Device.html#addressBits/1"},{"type":"function","title":"Evision.OCL.Device.available/1","doc":"available\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\navailable() -> retval\n```","ref":"Evision.OCL.Device.html#available/1"},{"type":"function","title":"Evision.OCL.Device.compilerAvailable/1","doc":"compilerAvailable\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ncompilerAvailable() -> retval\n```","ref":"Evision.OCL.Device.html#compilerAvailable/1"},{"type":"function","title":"Evision.OCL.Device.cv_EXEC_KERNEL/0","doc":"","ref":"Evision.OCL.Device.html#cv_EXEC_KERNEL/0"},{"type":"function","title":"Evision.OCL.Device.cv_EXEC_NATIVE_KERNEL/0","doc":"","ref":"Evision.OCL.Device.html#cv_EXEC_NATIVE_KERNEL/0"},{"type":"function","title":"Evision.OCL.Device.cv_FP_CORRECTLY_ROUNDED_DIVIDE_SQRT/0","doc":"","ref":"Evision.OCL.Device.html#cv_FP_CORRECTLY_ROUNDED_DIVIDE_SQRT/0"},{"type":"function","title":"Evision.OCL.Device.cv_FP_DENORM/0","doc":"","ref":"Evision.OCL.Device.html#cv_FP_DENORM/0"},{"type":"function","title":"Evision.OCL.Device.cv_FP_FMA/0","doc":"","ref":"Evision.OCL.Device.html#cv_FP_FMA/0"},{"type":"function","title":"Evision.OCL.Device.cv_FP_INF_NAN/0","doc":"","ref":"Evision.OCL.Device.html#cv_FP_INF_NAN/0"},{"type":"function","title":"Evision.OCL.Device.cv_FP_ROUND_TO_INF/0","doc":"","ref":"Evision.OCL.Device.html#cv_FP_ROUND_TO_INF/0"},{"type":"function","title":"Evision.OCL.Device.cv_FP_ROUND_TO_NEAREST/0","doc":"","ref":"Evision.OCL.Device.html#cv_FP_ROUND_TO_NEAREST/0"},{"type":"function","title":"Evision.OCL.Device.cv_FP_ROUND_TO_ZERO/0","doc":"","ref":"Evision.OCL.Device.html#cv_FP_ROUND_TO_ZERO/0"},{"type":"function","title":"Evision.OCL.Device.cv_FP_SOFT_FLOAT/0","doc":"","ref":"Evision.OCL.Device.html#cv_FP_SOFT_FLOAT/0"},{"type":"function","title":"Evision.OCL.Device.cv_LOCAL_IS_GLOBAL/0","doc":"","ref":"Evision.OCL.Device.html#cv_LOCAL_IS_GLOBAL/0"},{"type":"function","title":"Evision.OCL.Device.cv_LOCAL_IS_LOCAL/0","doc":"","ref":"Evision.OCL.Device.html#cv_LOCAL_IS_LOCAL/0"},{"type":"function","title":"Evision.OCL.Device.cv_NO_CACHE/0","doc":"","ref":"Evision.OCL.Device.html#cv_NO_CACHE/0"},{"type":"function","title":"Evision.OCL.Device.cv_NO_LOCAL_MEM/0","doc":"","ref":"Evision.OCL.Device.html#cv_NO_LOCAL_MEM/0"},{"type":"function","title":"Evision.OCL.Device.cv_READ_ONLY_CACHE/0","doc":"","ref":"Evision.OCL.Device.html#cv_READ_ONLY_CACHE/0"},{"type":"function","title":"Evision.OCL.Device.cv_READ_WRITE_CACHE/0","doc":"","ref":"Evision.OCL.Device.html#cv_READ_WRITE_CACHE/0"},{"type":"function","title":"Evision.OCL.Device.cv_TYPE_ACCELERATOR/0","doc":"","ref":"Evision.OCL.Device.html#cv_TYPE_ACCELERATOR/0"},{"type":"function","title":"Evision.OCL.Device.cv_TYPE_ALL/0","doc":"","ref":"Evision.OCL.Device.html#cv_TYPE_ALL/0"},{"type":"function","title":"Evision.OCL.Device.cv_TYPE_CPU/0","doc":"","ref":"Evision.OCL.Device.html#cv_TYPE_CPU/0"},{"type":"function","title":"Evision.OCL.Device.cv_TYPE_DEFAULT/0","doc":"","ref":"Evision.OCL.Device.html#cv_TYPE_DEFAULT/0"},{"type":"function","title":"Evision.OCL.Device.cv_TYPE_DGPU/0","doc":"","ref":"Evision.OCL.Device.html#cv_TYPE_DGPU/0"},{"type":"function","title":"Evision.OCL.Device.cv_TYPE_GPU/0","doc":"","ref":"Evision.OCL.Device.html#cv_TYPE_GPU/0"},{"type":"function","title":"Evision.OCL.Device.cv_TYPE_IGPU/0","doc":"","ref":"Evision.OCL.Device.html#cv_TYPE_IGPU/0"},{"type":"function","title":"Evision.OCL.Device.cv_UNKNOWN_VENDOR/0","doc":"","ref":"Evision.OCL.Device.html#cv_UNKNOWN_VENDOR/0"},{"type":"function","title":"Evision.OCL.Device.cv_VENDOR_AMD/0","doc":"","ref":"Evision.OCL.Device.html#cv_VENDOR_AMD/0"},{"type":"function","title":"Evision.OCL.Device.cv_VENDOR_INTEL/0","doc":"","ref":"Evision.OCL.Device.html#cv_VENDOR_INTEL/0"},{"type":"function","title":"Evision.OCL.Device.cv_VENDOR_NVIDIA/0","doc":"","ref":"Evision.OCL.Device.html#cv_VENDOR_NVIDIA/0"},{"type":"function","title":"Evision.OCL.Device.device/0","doc":"Device\n##### Return\n- **self**: `Evision.OCL.Device.t()`\n\nPython prototype (for reference only):\n```python3\nDevice() ->  \n```","ref":"Evision.OCL.Device.html#device/0"},{"type":"function","title":"Evision.OCL.Device.device/1","doc":"","ref":"Evision.OCL.Device.html#device/1"},{"type":"function","title":"Evision.OCL.Device.deviceVersionMajor/1","doc":"deviceVersionMajor\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndeviceVersionMajor() -> retval\n```","ref":"Evision.OCL.Device.html#deviceVersionMajor/1"},{"type":"function","title":"Evision.OCL.Device.deviceVersionMinor/1","doc":"deviceVersionMinor\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndeviceVersionMinor() -> retval\n```","ref":"Evision.OCL.Device.html#deviceVersionMinor/1"},{"type":"function","title":"Evision.OCL.Device.doubleFPConfig/1","doc":"doubleFPConfig\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndoubleFPConfig() -> retval\n```","ref":"Evision.OCL.Device.html#doubleFPConfig/1"},{"type":"function","title":"Evision.OCL.Device.driverVersion/1","doc":"driverVersion\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ndriverVersion() -> retval\n```","ref":"Evision.OCL.Device.html#driverVersion/1"},{"type":"function","title":"Evision.OCL.Device.endianLittle/1","doc":"endianLittle\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nendianLittle() -> retval\n```","ref":"Evision.OCL.Device.html#endianLittle/1"},{"type":"function","title":"Evision.OCL.Device.errorCorrectionSupport/1","doc":"errorCorrectionSupport\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nerrorCorrectionSupport() -> retval\n```","ref":"Evision.OCL.Device.html#errorCorrectionSupport/1"},{"type":"function","title":"Evision.OCL.Device.executionCapabilities/1","doc":"executionCapabilities\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nexecutionCapabilities() -> retval\n```","ref":"Evision.OCL.Device.html#executionCapabilities/1"},{"type":"function","title":"Evision.OCL.Device.extensions/1","doc":"extensions\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\nextensions() -> retval\n```","ref":"Evision.OCL.Device.html#extensions/1"},{"type":"function","title":"Evision.OCL.Device.getDefault/0","doc":"getDefault\n##### Return\n- **retval**: `Evision.OCL.Device.t()`\n\nPython prototype (for reference only):\n```python3\ngetDefault() -> retval\n```","ref":"Evision.OCL.Device.html#getDefault/0"},{"type":"function","title":"Evision.OCL.Device.getDefault/1","doc":"","ref":"Evision.OCL.Device.html#getDefault/1"},{"type":"function","title":"Evision.OCL.Device.globalMemCacheLineSize/1","doc":"globalMemCacheLineSize\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nglobalMemCacheLineSize() -> retval\n```","ref":"Evision.OCL.Device.html#globalMemCacheLineSize/1"},{"type":"function","title":"Evision.OCL.Device.globalMemCacheSize/1","doc":"globalMemCacheSize\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nglobalMemCacheSize() -> retval\n```","ref":"Evision.OCL.Device.html#globalMemCacheSize/1"},{"type":"function","title":"Evision.OCL.Device.globalMemCacheType/1","doc":"globalMemCacheType\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nglobalMemCacheType() -> retval\n```","ref":"Evision.OCL.Device.html#globalMemCacheType/1"},{"type":"function","title":"Evision.OCL.Device.globalMemSize/1","doc":"globalMemSize\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nglobalMemSize() -> retval\n```","ref":"Evision.OCL.Device.html#globalMemSize/1"},{"type":"function","title":"Evision.OCL.Device.halfFPConfig/1","doc":"halfFPConfig\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nhalfFPConfig() -> retval\n```","ref":"Evision.OCL.Device.html#halfFPConfig/1"},{"type":"function","title":"Evision.OCL.Device.hasFP16/1","doc":"hasFP16\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nhasFP16() -> retval\n```","ref":"Evision.OCL.Device.html#hasFP16/1"},{"type":"function","title":"Evision.OCL.Device.hasFP64/1","doc":"hasFP64\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nhasFP64() -> retval\n```","ref":"Evision.OCL.Device.html#hasFP64/1"},{"type":"function","title":"Evision.OCL.Device.hostUnifiedMemory/1","doc":"hostUnifiedMemory\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nhostUnifiedMemory() -> retval\n```","ref":"Evision.OCL.Device.html#hostUnifiedMemory/1"},{"type":"function","title":"Evision.OCL.Device.image2DMaxHeight/1","doc":"image2DMaxHeight\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nimage2DMaxHeight() -> retval\n```","ref":"Evision.OCL.Device.html#image2DMaxHeight/1"},{"type":"function","title":"Evision.OCL.Device.image2DMaxWidth/1","doc":"image2DMaxWidth\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nimage2DMaxWidth() -> retval\n```","ref":"Evision.OCL.Device.html#image2DMaxWidth/1"},{"type":"function","title":"Evision.OCL.Device.image3DMaxDepth/1","doc":"image3DMaxDepth\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nimage3DMaxDepth() -> retval\n```","ref":"Evision.OCL.Device.html#image3DMaxDepth/1"},{"type":"function","title":"Evision.OCL.Device.image3DMaxHeight/1","doc":"image3DMaxHeight\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nimage3DMaxHeight() -> retval\n```","ref":"Evision.OCL.Device.html#image3DMaxHeight/1"},{"type":"function","title":"Evision.OCL.Device.image3DMaxWidth/1","doc":"image3DMaxWidth\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nimage3DMaxWidth() -> retval\n```","ref":"Evision.OCL.Device.html#image3DMaxWidth/1"},{"type":"function","title":"Evision.OCL.Device.imageFromBufferSupport/1","doc":"imageFromBufferSupport\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nimageFromBufferSupport() -> retval\n```","ref":"Evision.OCL.Device.html#imageFromBufferSupport/1"},{"type":"function","title":"Evision.OCL.Device.imageMaxArraySize/1","doc":"imageMaxArraySize\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nimageMaxArraySize() -> retval\n```","ref":"Evision.OCL.Device.html#imageMaxArraySize/1"},{"type":"function","title":"Evision.OCL.Device.imageMaxBufferSize/1","doc":"imageMaxBufferSize\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nimageMaxBufferSize() -> retval\n```","ref":"Evision.OCL.Device.html#imageMaxBufferSize/1"},{"type":"function","title":"Evision.OCL.Device.imageSupport/1","doc":"imageSupport\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nimageSupport() -> retval\n```","ref":"Evision.OCL.Device.html#imageSupport/1"},{"type":"function","title":"Evision.OCL.Device.intelSubgroupsSupport/1","doc":"intelSubgroupsSupport\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nintelSubgroupsSupport() -> retval\n```","ref":"Evision.OCL.Device.html#intelSubgroupsSupport/1"},{"type":"function","title":"Evision.OCL.Device.isAMD/1","doc":"isAMD\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisAMD() -> retval\n```","ref":"Evision.OCL.Device.html#isAMD/1"},{"type":"function","title":"Evision.OCL.Device.isExtensionSupported/1","doc":"","ref":"Evision.OCL.Device.html#isExtensionSupported/1"},{"type":"function","title":"Evision.OCL.Device.isExtensionSupported/2","doc":"isExtensionSupported\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n- **extensionName**: `String`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisExtensionSupported(extensionName) -> retval\n```","ref":"Evision.OCL.Device.html#isExtensionSupported/2"},{"type":"function","title":"Evision.OCL.Device.isIntel/1","doc":"isIntel\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisIntel() -> retval\n```","ref":"Evision.OCL.Device.html#isIntel/1"},{"type":"function","title":"Evision.OCL.Device.isNVidia/1","doc":"isNVidia\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisNVidia() -> retval\n```","ref":"Evision.OCL.Device.html#isNVidia/1"},{"type":"function","title":"Evision.OCL.Device.linkerAvailable/1","doc":"linkerAvailable\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nlinkerAvailable() -> retval\n```","ref":"Evision.OCL.Device.html#linkerAvailable/1"},{"type":"function","title":"Evision.OCL.Device.localMemSize/1","doc":"localMemSize\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nlocalMemSize() -> retval\n```","ref":"Evision.OCL.Device.html#localMemSize/1"},{"type":"function","title":"Evision.OCL.Device.localMemType/1","doc":"localMemType\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nlocalMemType() -> retval\n```","ref":"Evision.OCL.Device.html#localMemType/1"},{"type":"function","title":"Evision.OCL.Device.maxClockFrequency/1","doc":"maxClockFrequency\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nmaxClockFrequency() -> retval\n```","ref":"Evision.OCL.Device.html#maxClockFrequency/1"},{"type":"function","title":"Evision.OCL.Device.maxComputeUnits/1","doc":"maxComputeUnits\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nmaxComputeUnits() -> retval\n```","ref":"Evision.OCL.Device.html#maxComputeUnits/1"},{"type":"function","title":"Evision.OCL.Device.maxConstantArgs/1","doc":"maxConstantArgs\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nmaxConstantArgs() -> retval\n```","ref":"Evision.OCL.Device.html#maxConstantArgs/1"},{"type":"function","title":"Evision.OCL.Device.maxConstantBufferSize/1","doc":"maxConstantBufferSize\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nmaxConstantBufferSize() -> retval\n```","ref":"Evision.OCL.Device.html#maxConstantBufferSize/1"},{"type":"function","title":"Evision.OCL.Device.maxMemAllocSize/1","doc":"maxMemAllocSize\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nmaxMemAllocSize() -> retval\n```","ref":"Evision.OCL.Device.html#maxMemAllocSize/1"},{"type":"function","title":"Evision.OCL.Device.maxParameterSize/1","doc":"maxParameterSize\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nmaxParameterSize() -> retval\n```","ref":"Evision.OCL.Device.html#maxParameterSize/1"},{"type":"function","title":"Evision.OCL.Device.maxReadImageArgs/1","doc":"maxReadImageArgs\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nmaxReadImageArgs() -> retval\n```","ref":"Evision.OCL.Device.html#maxReadImageArgs/1"},{"type":"function","title":"Evision.OCL.Device.maxSamplers/1","doc":"maxSamplers\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nmaxSamplers() -> retval\n```","ref":"Evision.OCL.Device.html#maxSamplers/1"},{"type":"function","title":"Evision.OCL.Device.maxWorkGroupSize/1","doc":"maxWorkGroupSize\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nmaxWorkGroupSize() -> retval\n```","ref":"Evision.OCL.Device.html#maxWorkGroupSize/1"},{"type":"function","title":"Evision.OCL.Device.maxWorkItemDims/1","doc":"maxWorkItemDims\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nmaxWorkItemDims() -> retval\n```","ref":"Evision.OCL.Device.html#maxWorkItemDims/1"},{"type":"function","title":"Evision.OCL.Device.maxWriteImageArgs/1","doc":"maxWriteImageArgs\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nmaxWriteImageArgs() -> retval\n```","ref":"Evision.OCL.Device.html#maxWriteImageArgs/1"},{"type":"function","title":"Evision.OCL.Device.memBaseAddrAlign/1","doc":"memBaseAddrAlign\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nmemBaseAddrAlign() -> retval\n```","ref":"Evision.OCL.Device.html#memBaseAddrAlign/1"},{"type":"function","title":"Evision.OCL.Device.name/1","doc":"name\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\nname() -> retval\n```","ref":"Evision.OCL.Device.html#name/1"},{"type":"function","title":"Evision.OCL.Device.nativeVectorWidthChar/1","doc":"nativeVectorWidthChar\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nnativeVectorWidthChar() -> retval\n```","ref":"Evision.OCL.Device.html#nativeVectorWidthChar/1"},{"type":"function","title":"Evision.OCL.Device.nativeVectorWidthDouble/1","doc":"nativeVectorWidthDouble\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nnativeVectorWidthDouble() -> retval\n```","ref":"Evision.OCL.Device.html#nativeVectorWidthDouble/1"},{"type":"function","title":"Evision.OCL.Device.nativeVectorWidthFloat/1","doc":"nativeVectorWidthFloat\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nnativeVectorWidthFloat() -> retval\n```","ref":"Evision.OCL.Device.html#nativeVectorWidthFloat/1"},{"type":"function","title":"Evision.OCL.Device.nativeVectorWidthHalf/1","doc":"nativeVectorWidthHalf\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nnativeVectorWidthHalf() -> retval\n```","ref":"Evision.OCL.Device.html#nativeVectorWidthHalf/1"},{"type":"function","title":"Evision.OCL.Device.nativeVectorWidthInt/1","doc":"nativeVectorWidthInt\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nnativeVectorWidthInt() -> retval\n```","ref":"Evision.OCL.Device.html#nativeVectorWidthInt/1"},{"type":"function","title":"Evision.OCL.Device.nativeVectorWidthLong/1","doc":"nativeVectorWidthLong\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nnativeVectorWidthLong() -> retval\n```","ref":"Evision.OCL.Device.html#nativeVectorWidthLong/1"},{"type":"function","title":"Evision.OCL.Device.nativeVectorWidthShort/1","doc":"nativeVectorWidthShort\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nnativeVectorWidthShort() -> retval\n```","ref":"Evision.OCL.Device.html#nativeVectorWidthShort/1"},{"type":"function","title":"Evision.OCL.Device.openCL_C_Version/1","doc":"OpenCL_C_Version\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\nOpenCL_C_Version() -> retval\n```","ref":"Evision.OCL.Device.html#openCL_C_Version/1"},{"type":"function","title":"Evision.OCL.Device.openCLVersion/1","doc":"OpenCLVersion\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\nOpenCLVersion() -> retval\n```","ref":"Evision.OCL.Device.html#openCLVersion/1"},{"type":"function","title":"Evision.OCL.Device.preferredVectorWidthChar/1","doc":"preferredVectorWidthChar\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\npreferredVectorWidthChar() -> retval\n```","ref":"Evision.OCL.Device.html#preferredVectorWidthChar/1"},{"type":"function","title":"Evision.OCL.Device.preferredVectorWidthDouble/1","doc":"preferredVectorWidthDouble\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\npreferredVectorWidthDouble() -> retval\n```","ref":"Evision.OCL.Device.html#preferredVectorWidthDouble/1"},{"type":"function","title":"Evision.OCL.Device.preferredVectorWidthFloat/1","doc":"preferredVectorWidthFloat\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\npreferredVectorWidthFloat() -> retval\n```","ref":"Evision.OCL.Device.html#preferredVectorWidthFloat/1"},{"type":"function","title":"Evision.OCL.Device.preferredVectorWidthHalf/1","doc":"preferredVectorWidthHalf\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\npreferredVectorWidthHalf() -> retval\n```","ref":"Evision.OCL.Device.html#preferredVectorWidthHalf/1"},{"type":"function","title":"Evision.OCL.Device.preferredVectorWidthInt/1","doc":"preferredVectorWidthInt\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\npreferredVectorWidthInt() -> retval\n```","ref":"Evision.OCL.Device.html#preferredVectorWidthInt/1"},{"type":"function","title":"Evision.OCL.Device.preferredVectorWidthLong/1","doc":"preferredVectorWidthLong\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\npreferredVectorWidthLong() -> retval\n```","ref":"Evision.OCL.Device.html#preferredVectorWidthLong/1"},{"type":"function","title":"Evision.OCL.Device.preferredVectorWidthShort/1","doc":"preferredVectorWidthShort\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\npreferredVectorWidthShort() -> retval\n```","ref":"Evision.OCL.Device.html#preferredVectorWidthShort/1"},{"type":"function","title":"Evision.OCL.Device.printfBufferSize/1","doc":"printfBufferSize\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nprintfBufferSize() -> retval\n```","ref":"Evision.OCL.Device.html#printfBufferSize/1"},{"type":"function","title":"Evision.OCL.Device.profilingTimerResolution/1","doc":"profilingTimerResolution\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `size_t`\n\nPython prototype (for reference only):\n```python3\nprofilingTimerResolution() -> retval\n```","ref":"Evision.OCL.Device.html#profilingTimerResolution/1"},{"type":"function","title":"Evision.OCL.Device.singleFPConfig/1","doc":"singleFPConfig\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsingleFPConfig() -> retval\n```","ref":"Evision.OCL.Device.html#singleFPConfig/1"},{"type":"function","title":"Evision.OCL.Device.type/1","doc":"type\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ntype() -> retval\n```","ref":"Evision.OCL.Device.html#type/1"},{"type":"function","title":"Evision.OCL.Device.vendorID/1","doc":"vendorID\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nvendorID() -> retval\n```","ref":"Evision.OCL.Device.html#vendorID/1"},{"type":"function","title":"Evision.OCL.Device.vendorName/1","doc":"vendorName\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\nvendorName() -> retval\n```","ref":"Evision.OCL.Device.html#vendorName/1"},{"type":"function","title":"Evision.OCL.Device.version/1","doc":"version\n\n##### Positional Arguments\n- **self**: `Evision.OCL.Device.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\nversion() -> retval\n```","ref":"Evision.OCL.Device.html#version/1"},{"type":"type","title":"Evision.OCL.Device.enum/0","doc":"","ref":"Evision.OCL.Device.html#t:enum/0"},{"type":"type","title":"Evision.OCL.Device.t/0","doc":"Type that represents an `OCL.Device` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.OCL.Device.html#t:t/0"},{"type":"module","title":"Evision.OCL.KernelArg","doc":"","ref":"Evision.OCL.KernelArg.html"},{"type":"function","title":"Evision.OCL.KernelArg.cv_CONSTANT/0","doc":"","ref":"Evision.OCL.KernelArg.html#cv_CONSTANT/0"},{"type":"function","title":"Evision.OCL.KernelArg.cv_LOCAL/0","doc":"","ref":"Evision.OCL.KernelArg.html#cv_LOCAL/0"},{"type":"function","title":"Evision.OCL.KernelArg.cv_NO_SIZE/0","doc":"","ref":"Evision.OCL.KernelArg.html#cv_NO_SIZE/0"},{"type":"function","title":"Evision.OCL.KernelArg.cv_PTR_ONLY/0","doc":"","ref":"Evision.OCL.KernelArg.html#cv_PTR_ONLY/0"},{"type":"function","title":"Evision.OCL.KernelArg.cv_READ_ONLY/0","doc":"","ref":"Evision.OCL.KernelArg.html#cv_READ_ONLY/0"},{"type":"function","title":"Evision.OCL.KernelArg.cv_READ_WRITE/0","doc":"","ref":"Evision.OCL.KernelArg.html#cv_READ_WRITE/0"},{"type":"function","title":"Evision.OCL.KernelArg.cv_WRITE_ONLY/0","doc":"","ref":"Evision.OCL.KernelArg.html#cv_WRITE_ONLY/0"},{"type":"type","title":"Evision.OCL.KernelArg.enum/0","doc":"","ref":"Evision.OCL.KernelArg.html#t:enum/0"},{"type":"module","title":"Evision.OCL.OclVectorStrategy","doc":"","ref":"Evision.OCL.OclVectorStrategy.html"},{"type":"function","title":"Evision.OCL.OclVectorStrategy.cv_OCL_VECTOR_DEFAULT/0","doc":"","ref":"Evision.OCL.OclVectorStrategy.html#cv_OCL_VECTOR_DEFAULT/0"},{"type":"function","title":"Evision.OCL.OclVectorStrategy.cv_OCL_VECTOR_MAX/0","doc":"","ref":"Evision.OCL.OclVectorStrategy.html#cv_OCL_VECTOR_MAX/0"},{"type":"function","title":"Evision.OCL.OclVectorStrategy.cv_OCL_VECTOR_OWN/0","doc":"","ref":"Evision.OCL.OclVectorStrategy.html#cv_OCL_VECTOR_OWN/0"},{"type":"type","title":"Evision.OCL.OclVectorStrategy.enum/0","doc":"","ref":"Evision.OCL.OclVectorStrategy.html#t:enum/0"},{"type":"module","title":"Evision.OCL.OpenCLExecutionContext","doc":"","ref":"Evision.OCL.OpenCLExecutionContext.html"},{"type":"type","title":"Evision.OCL.OpenCLExecutionContext.t/0","doc":"Type that represents an `OCL.OpenCLExecutionContext` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.OCL.OpenCLExecutionContext.html#t:t/0"},{"type":"module","title":"Evision.OGL.Buffer.Access","doc":"","ref":"Evision.OGL.Buffer.Access.html"},{"type":"function","title":"Evision.OGL.Buffer.Access.cv_READ_ONLY/0","doc":"","ref":"Evision.OGL.Buffer.Access.html#cv_READ_ONLY/0"},{"type":"function","title":"Evision.OGL.Buffer.Access.cv_READ_WRITE/0","doc":"","ref":"Evision.OGL.Buffer.Access.html#cv_READ_WRITE/0"},{"type":"function","title":"Evision.OGL.Buffer.Access.cv_WRITE_ONLY/0","doc":"","ref":"Evision.OGL.Buffer.Access.html#cv_WRITE_ONLY/0"},{"type":"type","title":"Evision.OGL.Buffer.Access.enum/0","doc":"","ref":"Evision.OGL.Buffer.Access.html#t:enum/0"},{"type":"module","title":"Evision.OGL.Buffer.Target","doc":"","ref":"Evision.OGL.Buffer.Target.html"},{"type":"function","title":"Evision.OGL.Buffer.Target.cv_ARRAY_BUFFER/0","doc":"","ref":"Evision.OGL.Buffer.Target.html#cv_ARRAY_BUFFER/0"},{"type":"function","title":"Evision.OGL.Buffer.Target.cv_ELEMENT_ARRAY_BUFFER/0","doc":"","ref":"Evision.OGL.Buffer.Target.html#cv_ELEMENT_ARRAY_BUFFER/0"},{"type":"function","title":"Evision.OGL.Buffer.Target.cv_PIXEL_PACK_BUFFER/0","doc":"","ref":"Evision.OGL.Buffer.Target.html#cv_PIXEL_PACK_BUFFER/0"},{"type":"function","title":"Evision.OGL.Buffer.Target.cv_PIXEL_UNPACK_BUFFER/0","doc":"","ref":"Evision.OGL.Buffer.Target.html#cv_PIXEL_UNPACK_BUFFER/0"},{"type":"type","title":"Evision.OGL.Buffer.Target.enum/0","doc":"","ref":"Evision.OGL.Buffer.Target.html#t:enum/0"},{"type":"module","title":"Evision.OGL.RenderModes","doc":"","ref":"Evision.OGL.RenderModes.html"},{"type":"function","title":"Evision.OGL.RenderModes.cv_LINE_LOOP/0","doc":"","ref":"Evision.OGL.RenderModes.html#cv_LINE_LOOP/0"},{"type":"function","title":"Evision.OGL.RenderModes.cv_LINE_STRIP/0","doc":"","ref":"Evision.OGL.RenderModes.html#cv_LINE_STRIP/0"},{"type":"function","title":"Evision.OGL.RenderModes.cv_LINES/0","doc":"","ref":"Evision.OGL.RenderModes.html#cv_LINES/0"},{"type":"function","title":"Evision.OGL.RenderModes.cv_POINTS/0","doc":"","ref":"Evision.OGL.RenderModes.html#cv_POINTS/0"},{"type":"function","title":"Evision.OGL.RenderModes.cv_POLYGON/0","doc":"","ref":"Evision.OGL.RenderModes.html#cv_POLYGON/0"},{"type":"function","title":"Evision.OGL.RenderModes.cv_QUAD_STRIP/0","doc":"","ref":"Evision.OGL.RenderModes.html#cv_QUAD_STRIP/0"},{"type":"function","title":"Evision.OGL.RenderModes.cv_QUADS/0","doc":"","ref":"Evision.OGL.RenderModes.html#cv_QUADS/0"},{"type":"function","title":"Evision.OGL.RenderModes.cv_TRIANGLE_FAN/0","doc":"","ref":"Evision.OGL.RenderModes.html#cv_TRIANGLE_FAN/0"},{"type":"function","title":"Evision.OGL.RenderModes.cv_TRIANGLE_STRIP/0","doc":"","ref":"Evision.OGL.RenderModes.html#cv_TRIANGLE_STRIP/0"},{"type":"function","title":"Evision.OGL.RenderModes.cv_TRIANGLES/0","doc":"","ref":"Evision.OGL.RenderModes.html#cv_TRIANGLES/0"},{"type":"type","title":"Evision.OGL.RenderModes.enum/0","doc":"","ref":"Evision.OGL.RenderModes.html#t:enum/0"},{"type":"module","title":"Evision.OGL.Texture2D.Format","doc":"","ref":"Evision.OGL.Texture2D.Format.html"},{"type":"function","title":"Evision.OGL.Texture2D.Format.cv_DEPTH_COMPONENT/0","doc":"","ref":"Evision.OGL.Texture2D.Format.html#cv_DEPTH_COMPONENT/0"},{"type":"function","title":"Evision.OGL.Texture2D.Format.cv_NONE/0","doc":"","ref":"Evision.OGL.Texture2D.Format.html#cv_NONE/0"},{"type":"function","title":"Evision.OGL.Texture2D.Format.cv_RGB/0","doc":"","ref":"Evision.OGL.Texture2D.Format.html#cv_RGB/0"},{"type":"function","title":"Evision.OGL.Texture2D.Format.cv_RGBA/0","doc":"","ref":"Evision.OGL.Texture2D.Format.html#cv_RGBA/0"},{"type":"type","title":"Evision.OGL.Texture2D.Format.enum/0","doc":"","ref":"Evision.OGL.Texture2D.Format.html#t:enum/0"},{"type":"module","title":"Evision.ORB","doc":"","ref":"Evision.ORB.html"},{"type":"function","title":"Evision.ORB.compute/1","doc":"","ref":"Evision.ORB.html#compute/1"},{"type":"function","title":"Evision.ORB.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.ORB.html#compute/3"},{"type":"function","title":"Evision.ORB.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.ORB.html#compute/4"},{"type":"function","title":"Evision.ORB.create/0","doc":"The ORB constructor\n##### Keyword Arguments\n- **nfeatures**: `integer()`.\n\n  The maximum number of features to retain.\n\n- **scaleFactor**: `float`.\n\n  Pyramid decimation ratio, greater than 1. scaleFactor==2 means the classical\n  pyramid, where each next level has 4x less pixels than the previous, but such a big scale factor\n  will degrade feature matching scores dramatically. On the other hand, too close to 1 scale factor\n  will mean that to cover certain scale range you will need more pyramid levels and so the speed\n  will suffer.\n\n- **nlevels**: `integer()`.\n\n  The number of pyramid levels. The smallest level will have linear size equal to\n  input_image_linear_size/pow(scaleFactor, nlevels - firstLevel).\n\n- **edgeThreshold**: `integer()`.\n\n  This is size of the border where the features are not detected. It should\n  roughly match the patchSize parameter.\n\n- **firstLevel**: `integer()`.\n\n  The level of pyramid to put source image to. Previous layers are filled\n  with upscaled source image.\n\n- **wTA_K**: `integer()`.\n\n  The number of points that produce each element of the oriented BRIEF descriptor. The\n  default value 2 means the BRIEF where we take a random point pair and compare their brightnesses,\n  so we get 0/1 response. Other possible values are 3 and 4. For example, 3 means that we take 3\n  random points (of course, those point coordinates are random, but they are generated from the\n  pre-defined seed, so each element of BRIEF descriptor is computed deterministically from the pixel\n  rectangle), find point of maximum brightness and output index of the winner (0, 1 or 2). Such\n  output will occupy 2 bits, and therefore it will need a special variant of Hamming distance,\n  denoted as NORM_HAMMING2 (2 bits per bin). When WTA_K=4, we take 4 random points to compute each\n  bin (that will also occupy 2 bits with possible values 0, 1, 2 or 3).\n\n- **scoreType**: `ORB_ScoreType`.\n\n  The default HARRIS_SCORE means that Harris algorithm is used to rank features\n  (the score is written to KeyPoint::score and is used to retain best nfeatures features);\n  FAST_SCORE is alternative value of the parameter that produces slightly less stable keypoints,\n  but it is a little faster to compute.\n\n- **patchSize**: `integer()`.\n\n  size of the patch used by the oriented BRIEF descriptor. Of course, on smaller\n  pyramid layers the perceived image area covered by a feature will be larger.\n\n- **fastThreshold**: `integer()`.\n\n  the fast threshold\n\n##### Return\n- **retval**: `Evision.ORB.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, nfeatures[, scaleFactor[, nlevels[, edgeThreshold[, firstLevel[, WTA_K[, scoreType[, patchSize[, fastThreshold]]]]]]]]]) -> retval\n```","ref":"Evision.ORB.html#create/0"},{"type":"function","title":"Evision.ORB.create/1","doc":"The ORB constructor\n##### Keyword Arguments\n- **nfeatures**: `integer()`.\n\n  The maximum number of features to retain.\n\n- **scaleFactor**: `float`.\n\n  Pyramid decimation ratio, greater than 1. scaleFactor==2 means the classical\n  pyramid, where each next level has 4x less pixels than the previous, but such a big scale factor\n  will degrade feature matching scores dramatically. On the other hand, too close to 1 scale factor\n  will mean that to cover certain scale range you will need more pyramid levels and so the speed\n  will suffer.\n\n- **nlevels**: `integer()`.\n\n  The number of pyramid levels. The smallest level will have linear size equal to\n  input_image_linear_size/pow(scaleFactor, nlevels - firstLevel).\n\n- **edgeThreshold**: `integer()`.\n\n  This is size of the border where the features are not detected. It should\n  roughly match the patchSize parameter.\n\n- **firstLevel**: `integer()`.\n\n  The level of pyramid to put source image to. Previous layers are filled\n  with upscaled source image.\n\n- **wTA_K**: `integer()`.\n\n  The number of points that produce each element of the oriented BRIEF descriptor. The\n  default value 2 means the BRIEF where we take a random point pair and compare their brightnesses,\n  so we get 0/1 response. Other possible values are 3 and 4. For example, 3 means that we take 3\n  random points (of course, those point coordinates are random, but they are generated from the\n  pre-defined seed, so each element of BRIEF descriptor is computed deterministically from the pixel\n  rectangle), find point of maximum brightness and output index of the winner (0, 1 or 2). Such\n  output will occupy 2 bits, and therefore it will need a special variant of Hamming distance,\n  denoted as NORM_HAMMING2 (2 bits per bin). When WTA_K=4, we take 4 random points to compute each\n  bin (that will also occupy 2 bits with possible values 0, 1, 2 or 3).\n\n- **scoreType**: `ORB_ScoreType`.\n\n  The default HARRIS_SCORE means that Harris algorithm is used to rank features\n  (the score is written to KeyPoint::score and is used to retain best nfeatures features);\n  FAST_SCORE is alternative value of the parameter that produces slightly less stable keypoints,\n  but it is a little faster to compute.\n\n- **patchSize**: `integer()`.\n\n  size of the patch used by the oriented BRIEF descriptor. Of course, on smaller\n  pyramid layers the perceived image area covered by a feature will be larger.\n\n- **fastThreshold**: `integer()`.\n\n  the fast threshold\n\n##### Return\n- **retval**: `Evision.ORB.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, nfeatures[, scaleFactor[, nlevels[, edgeThreshold[, firstLevel[, WTA_K[, scoreType[, patchSize[, fastThreshold]]]]]]]]]) -> retval\n```","ref":"Evision.ORB.html#create/1"},{"type":"function","title":"Evision.ORB.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.ORB.html#defaultNorm/1"},{"type":"function","title":"Evision.ORB.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.ORB.html#descriptorSize/1"},{"type":"function","title":"Evision.ORB.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.ORB.html#descriptorType/1"},{"type":"function","title":"Evision.ORB.detect/1","doc":"","ref":"Evision.ORB.html#detect/1"},{"type":"function","title":"Evision.ORB.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.ORB.html#detect/2"},{"type":"function","title":"Evision.ORB.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.ORB.html#detect/3"},{"type":"function","title":"Evision.ORB.detectAndCompute/1","doc":"","ref":"Evision.ORB.html#detectAndCompute/1"},{"type":"function","title":"Evision.ORB.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.ORB.html#detectAndCompute/3"},{"type":"function","title":"Evision.ORB.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.ORB.html#detectAndCompute/4"},{"type":"function","title":"Evision.ORB.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.ORB.html#empty/1"},{"type":"function","title":"Evision.ORB.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.ORB.html#getDefaultName/1"},{"type":"function","title":"Evision.ORB.getEdgeThreshold/1","doc":"getEdgeThreshold\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetEdgeThreshold() -> retval\n```","ref":"Evision.ORB.html#getEdgeThreshold/1"},{"type":"function","title":"Evision.ORB.getFastThreshold/1","doc":"getFastThreshold\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetFastThreshold() -> retval\n```","ref":"Evision.ORB.html#getFastThreshold/1"},{"type":"function","title":"Evision.ORB.getFirstLevel/1","doc":"getFirstLevel\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetFirstLevel() -> retval\n```","ref":"Evision.ORB.html#getFirstLevel/1"},{"type":"function","title":"Evision.ORB.getMaxFeatures/1","doc":"getMaxFeatures\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxFeatures() -> retval\n```","ref":"Evision.ORB.html#getMaxFeatures/1"},{"type":"function","title":"Evision.ORB.getNLevels/1","doc":"getNLevels\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNLevels() -> retval\n```","ref":"Evision.ORB.html#getNLevels/1"},{"type":"function","title":"Evision.ORB.getPatchSize/1","doc":"getPatchSize\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetPatchSize() -> retval\n```","ref":"Evision.ORB.html#getPatchSize/1"},{"type":"function","title":"Evision.ORB.getScaleFactor/1","doc":"getScaleFactor\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetScaleFactor() -> retval\n```","ref":"Evision.ORB.html#getScaleFactor/1"},{"type":"function","title":"Evision.ORB.getScoreType/1","doc":"getScoreType\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n\n##### Return\n- **retval**: `ORB::ScoreType`\n\nPython prototype (for reference only):\n```python3\ngetScoreType() -> retval\n```","ref":"Evision.ORB.html#getScoreType/1"},{"type":"function","title":"Evision.ORB.getWTA_K/1","doc":"getWTA_K\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetWTA_K() -> retval\n```","ref":"Evision.ORB.html#getWTA_K/1"},{"type":"function","title":"Evision.ORB.read/1","doc":"","ref":"Evision.ORB.html#read/1"},{"type":"function","title":"Evision.ORB.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.ORB.html#read/2"},{"type":"function","title":"Evision.ORB.setEdgeThreshold/1","doc":"","ref":"Evision.ORB.html#setEdgeThreshold/1"},{"type":"function","title":"Evision.ORB.setEdgeThreshold/2","doc":"setEdgeThreshold\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n- **edgeThreshold**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetEdgeThreshold(edgeThreshold) -> None\n```","ref":"Evision.ORB.html#setEdgeThreshold/2"},{"type":"function","title":"Evision.ORB.setFastThreshold/1","doc":"","ref":"Evision.ORB.html#setFastThreshold/1"},{"type":"function","title":"Evision.ORB.setFastThreshold/2","doc":"setFastThreshold\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n- **fastThreshold**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetFastThreshold(fastThreshold) -> None\n```","ref":"Evision.ORB.html#setFastThreshold/2"},{"type":"function","title":"Evision.ORB.setFirstLevel/1","doc":"","ref":"Evision.ORB.html#setFirstLevel/1"},{"type":"function","title":"Evision.ORB.setFirstLevel/2","doc":"setFirstLevel\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n- **firstLevel**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetFirstLevel(firstLevel) -> None\n```","ref":"Evision.ORB.html#setFirstLevel/2"},{"type":"function","title":"Evision.ORB.setMaxFeatures/1","doc":"","ref":"Evision.ORB.html#setMaxFeatures/1"},{"type":"function","title":"Evision.ORB.setMaxFeatures/2","doc":"setMaxFeatures\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n- **maxFeatures**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxFeatures(maxFeatures) -> None\n```","ref":"Evision.ORB.html#setMaxFeatures/2"},{"type":"function","title":"Evision.ORB.setNLevels/1","doc":"","ref":"Evision.ORB.html#setNLevels/1"},{"type":"function","title":"Evision.ORB.setNLevels/2","doc":"setNLevels\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n- **nlevels**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNLevels(nlevels) -> None\n```","ref":"Evision.ORB.html#setNLevels/2"},{"type":"function","title":"Evision.ORB.setPatchSize/1","doc":"","ref":"Evision.ORB.html#setPatchSize/1"},{"type":"function","title":"Evision.ORB.setPatchSize/2","doc":"setPatchSize\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n- **patchSize**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetPatchSize(patchSize) -> None\n```","ref":"Evision.ORB.html#setPatchSize/2"},{"type":"function","title":"Evision.ORB.setScaleFactor/1","doc":"","ref":"Evision.ORB.html#setScaleFactor/1"},{"type":"function","title":"Evision.ORB.setScaleFactor/2","doc":"setScaleFactor\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n- **scaleFactor**: `double`\n\nPython prototype (for reference only):\n```python3\nsetScaleFactor(scaleFactor) -> None\n```","ref":"Evision.ORB.html#setScaleFactor/2"},{"type":"function","title":"Evision.ORB.setScoreType/1","doc":"","ref":"Evision.ORB.html#setScoreType/1"},{"type":"function","title":"Evision.ORB.setScoreType/2","doc":"setScoreType\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n- **scoreType**: `ORB_ScoreType`\n\nPython prototype (for reference only):\n```python3\nsetScoreType(scoreType) -> None\n```","ref":"Evision.ORB.html#setScoreType/2"},{"type":"function","title":"Evision.ORB.setWTA_K/1","doc":"","ref":"Evision.ORB.html#setWTA_K/1"},{"type":"function","title":"Evision.ORB.setWTA_K/2","doc":"setWTA_K\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n- **wta_k**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetWTA_K(wta_k) -> None\n```","ref":"Evision.ORB.html#setWTA_K/2"},{"type":"function","title":"Evision.ORB.write/1","doc":"","ref":"Evision.ORB.html#write/1"},{"type":"function","title":"Evision.ORB.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.ORB.html#write/2"},{"type":"function","title":"Evision.ORB.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.ORB.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.ORB.html#write/3"},{"type":"type","title":"Evision.ORB.t/0","doc":"Type that represents an `ORB` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ORB.html#t:t/0"},{"type":"module","title":"Evision.ORB.ScoreType","doc":"","ref":"Evision.ORB.ScoreType.html"},{"type":"function","title":"Evision.ORB.ScoreType.cv_FAST_SCORE/0","doc":"","ref":"Evision.ORB.ScoreType.html#cv_FAST_SCORE/0"},{"type":"function","title":"Evision.ORB.ScoreType.cv_HARRIS_SCORE/0","doc":"","ref":"Evision.ORB.ScoreType.html#cv_HARRIS_SCORE/0"},{"type":"type","title":"Evision.ORB.ScoreType.enum/0","doc":"","ref":"Evision.ORB.ScoreType.html#t:enum/0"},{"type":"module","title":"Evision.Omnidir","doc":"","ref":"Evision.Omnidir.html"},{"type":"function","title":"Evision.Omnidir.calibrate/1","doc":"","ref":"Evision.Omnidir.html#calibrate/1"},{"type":"function","title":"Evision.Omnidir.calibrate/8","doc":"Perform omnidirectional camera calibration, the default depth of outputs is CV_64F.\n\n##### Positional Arguments\n- **objectPoints**: `[Evision.Mat]`.\n\n  Vector of vector of Vec3f object points in world (pattern) coordinate.\n  It also can be vector of Mat with size 1xN/Nx1 and type CV_32FC3. Data with depth of 64_F is also acceptable.\n\n- **imagePoints**: `[Evision.Mat]`.\n\n  Vector of vector of Vec2f corresponding image points of objectPoints. It must be the same\n  size and the same type with objectPoints.\n\n- **size**: `Size`.\n\n  Image size of calibration images.\n\n- **flags**: `integer()`.\n\n  The flags that control calibrate\n\n- **criteria**: `TermCriteria`.\n\n  Termination criteria for optimization\n\n##### Return\n- **retval**: `double`\n- **k**: `Evision.Mat.t()`.\n\n  Output calibrated camera matrix.\n\n- **xi**: `Evision.Mat.t()`.\n\n  Output parameter xi for CMei's model\n\n- **d**: `Evision.Mat.t()`.\n\n  Output distortion parameters \\f$(k_1, k_2, p_1, p_2)\\f$\n\n- **rvecs**: `[Evision.Mat]`.\n\n  Output rotations for each calibration images\n\n- **tvecs**: `[Evision.Mat]`.\n\n  Output translation for each calibration images\n\n- **idx**: `Evision.Mat.t()`.\n\n  Indices of images that pass initialization, which are really used in calibration. So the size of rvecs is the\n  same as idx.total().\n\nPython prototype (for reference only):\n```python3\ncalibrate(objectPoints, imagePoints, size, K, xi, D, flags, criteria[, rvecs[, tvecs[, idx]]]) -> retval, K, xi, D, rvecs, tvecs, idx\n```","ref":"Evision.Omnidir.html#calibrate/8"},{"type":"function","title":"Evision.Omnidir.calibrate/9","doc":"Perform omnidirectional camera calibration, the default depth of outputs is CV_64F.\n\n##### Positional Arguments\n- **objectPoints**: `[Evision.Mat]`.\n\n  Vector of vector of Vec3f object points in world (pattern) coordinate.\n  It also can be vector of Mat with size 1xN/Nx1 and type CV_32FC3. Data with depth of 64_F is also acceptable.\n\n- **imagePoints**: `[Evision.Mat]`.\n\n  Vector of vector of Vec2f corresponding image points of objectPoints. It must be the same\n  size and the same type with objectPoints.\n\n- **size**: `Size`.\n\n  Image size of calibration images.\n\n- **flags**: `integer()`.\n\n  The flags that control calibrate\n\n- **criteria**: `TermCriteria`.\n\n  Termination criteria for optimization\n\n##### Return\n- **retval**: `double`\n- **k**: `Evision.Mat.t()`.\n\n  Output calibrated camera matrix.\n\n- **xi**: `Evision.Mat.t()`.\n\n  Output parameter xi for CMei's model\n\n- **d**: `Evision.Mat.t()`.\n\n  Output distortion parameters \\f$(k_1, k_2, p_1, p_2)\\f$\n\n- **rvecs**: `[Evision.Mat]`.\n\n  Output rotations for each calibration images\n\n- **tvecs**: `[Evision.Mat]`.\n\n  Output translation for each calibration images\n\n- **idx**: `Evision.Mat.t()`.\n\n  Indices of images that pass initialization, which are really used in calibration. So the size of rvecs is the\n  same as idx.total().\n\nPython prototype (for reference only):\n```python3\ncalibrate(objectPoints, imagePoints, size, K, xi, D, flags, criteria[, rvecs[, tvecs[, idx]]]) -> retval, K, xi, D, rvecs, tvecs, idx\n```","ref":"Evision.Omnidir.html#calibrate/9"},{"type":"function","title":"Evision.Omnidir.cv_CALIB_FIX_CENTER/0","doc":"","ref":"Evision.Omnidir.html#cv_CALIB_FIX_CENTER/0"},{"type":"function","title":"Evision.Omnidir.cv_CALIB_FIX_GAMMA/0","doc":"","ref":"Evision.Omnidir.html#cv_CALIB_FIX_GAMMA/0"},{"type":"function","title":"Evision.Omnidir.cv_CALIB_FIX_K1/0","doc":"","ref":"Evision.Omnidir.html#cv_CALIB_FIX_K1/0"},{"type":"function","title":"Evision.Omnidir.cv_CALIB_FIX_K2/0","doc":"","ref":"Evision.Omnidir.html#cv_CALIB_FIX_K2/0"},{"type":"function","title":"Evision.Omnidir.cv_CALIB_FIX_P1/0","doc":"","ref":"Evision.Omnidir.html#cv_CALIB_FIX_P1/0"},{"type":"function","title":"Evision.Omnidir.cv_CALIB_FIX_P2/0","doc":"","ref":"Evision.Omnidir.html#cv_CALIB_FIX_P2/0"},{"type":"function","title":"Evision.Omnidir.cv_CALIB_FIX_SKEW/0","doc":"","ref":"Evision.Omnidir.html#cv_CALIB_FIX_SKEW/0"},{"type":"function","title":"Evision.Omnidir.cv_CALIB_FIX_XI/0","doc":"","ref":"Evision.Omnidir.html#cv_CALIB_FIX_XI/0"},{"type":"function","title":"Evision.Omnidir.cv_CALIB_USE_GUESS/0","doc":"","ref":"Evision.Omnidir.html#cv_CALIB_USE_GUESS/0"},{"type":"function","title":"Evision.Omnidir.cv_RECTIFY_CYLINDRICAL/0","doc":"","ref":"Evision.Omnidir.html#cv_RECTIFY_CYLINDRICAL/0"},{"type":"function","title":"Evision.Omnidir.cv_RECTIFY_LONGLATI/0","doc":"","ref":"Evision.Omnidir.html#cv_RECTIFY_LONGLATI/0"},{"type":"function","title":"Evision.Omnidir.cv_RECTIFY_PERSPECTIVE/0","doc":"","ref":"Evision.Omnidir.html#cv_RECTIFY_PERSPECTIVE/0"},{"type":"function","title":"Evision.Omnidir.cv_RECTIFY_STEREOGRAPHIC/0","doc":"","ref":"Evision.Omnidir.html#cv_RECTIFY_STEREOGRAPHIC/0"},{"type":"function","title":"Evision.Omnidir.cv_XYZ/0","doc":"","ref":"Evision.Omnidir.html#cv_XYZ/0"},{"type":"function","title":"Evision.Omnidir.cv_XYZRGB/0","doc":"","ref":"Evision.Omnidir.html#cv_XYZRGB/0"},{"type":"function","title":"Evision.Omnidir.initUndistortRectifyMap/1","doc":"","ref":"Evision.Omnidir.html#initUndistortRectifyMap/1"},{"type":"function","title":"Evision.Omnidir.initUndistortRectifyMap/8","doc":"Computes undistortion and rectification maps for omnidirectional camera image transform by a rotation R.\nIt output two maps that are used for cv::remap(). If D is empty then zero distortion is used,\nif R or P is empty then identity matrices are used.\n\n##### Positional Arguments\n- **k**: `Evision.Mat`.\n\n  Camera matrix \\f$K = \\vecthreethree{f_x}{s}{c_x}{0}{f_y}{c_y}{0}{0}{_1}\\f$, with depth CV_32F or CV_64F\n\n- **d**: `Evision.Mat`.\n\n  Input vector of distortion coefficients \\f$(k_1, k_2, p_1, p_2)\\f$, with depth CV_32F or CV_64F\n\n- **xi**: `Evision.Mat`.\n\n  The parameter xi for CMei's model\n\n- **r**: `Evision.Mat`.\n\n  Rotation transform between the original and object space : 3x3 1-channel, or vector: 3x1/1x3, with depth CV_32F or CV_64F\n\n- **p**: `Evision.Mat`.\n\n  New camera matrix (3x3) or new projection matrix (3x4)\n\n- **size**: `Size`.\n\n  Undistorted image size.\n\n- **m1type**: `integer()`.\n\n  Type of the first output map that can be CV_32FC1 or CV_16SC2 . See convertMaps()\n  for details.\n\n- **flags**: `integer()`.\n\n  Flags indicates the rectification type,  RECTIFY_PERSPECTIVE, RECTIFY_CYLINDRICAL, RECTIFY_LONGLATI and RECTIFY_STEREOGRAPHIC\n  are supported.\n\n##### Return\n- **map1**: `Evision.Mat.t()`.\n\n  The first output map.\n\n- **map2**: `Evision.Mat.t()`.\n\n  The second output map.\n\nPython prototype (for reference only):\n```python3\ninitUndistortRectifyMap(K, D, xi, R, P, size, m1type, flags[, map1[, map2]]) -> map1, map2\n```","ref":"Evision.Omnidir.html#initUndistortRectifyMap/8"},{"type":"function","title":"Evision.Omnidir.initUndistortRectifyMap/9","doc":"Computes undistortion and rectification maps for omnidirectional camera image transform by a rotation R.\nIt output two maps that are used for cv::remap(). If D is empty then zero distortion is used,\nif R or P is empty then identity matrices are used.\n\n##### Positional Arguments\n- **k**: `Evision.Mat`.\n\n  Camera matrix \\f$K = \\vecthreethree{f_x}{s}{c_x}{0}{f_y}{c_y}{0}{0}{_1}\\f$, with depth CV_32F or CV_64F\n\n- **d**: `Evision.Mat`.\n\n  Input vector of distortion coefficients \\f$(k_1, k_2, p_1, p_2)\\f$, with depth CV_32F or CV_64F\n\n- **xi**: `Evision.Mat`.\n\n  The parameter xi for CMei's model\n\n- **r**: `Evision.Mat`.\n\n  Rotation transform between the original and object space : 3x3 1-channel, or vector: 3x1/1x3, with depth CV_32F or CV_64F\n\n- **p**: `Evision.Mat`.\n\n  New camera matrix (3x3) or new projection matrix (3x4)\n\n- **size**: `Size`.\n\n  Undistorted image size.\n\n- **m1type**: `integer()`.\n\n  Type of the first output map that can be CV_32FC1 or CV_16SC2 . See convertMaps()\n  for details.\n\n- **flags**: `integer()`.\n\n  Flags indicates the rectification type,  RECTIFY_PERSPECTIVE, RECTIFY_CYLINDRICAL, RECTIFY_LONGLATI and RECTIFY_STEREOGRAPHIC\n  are supported.\n\n##### Return\n- **map1**: `Evision.Mat.t()`.\n\n  The first output map.\n\n- **map2**: `Evision.Mat.t()`.\n\n  The second output map.\n\nPython prototype (for reference only):\n```python3\ninitUndistortRectifyMap(K, D, xi, R, P, size, m1type, flags[, map1[, map2]]) -> map1, map2\n```","ref":"Evision.Omnidir.html#initUndistortRectifyMap/9"},{"type":"function","title":"Evision.Omnidir.projectPoints/1","doc":"","ref":"Evision.Omnidir.html#projectPoints/1"},{"type":"function","title":"Evision.Omnidir.projectPoints/6","doc":"Projects points for omnidirectional camera using CMei's model\n\n##### Positional Arguments\n- **objectPoints**: `Evision.Mat`.\n\n  Object points in world coordinate, vector of vector of Vec3f or Mat of\n  1xN/Nx1 3-channel of type CV_32F and N is the number of points. 64F is also acceptable.\n\n- **rvec**: `Evision.Mat`.\n\n  vector of rotation between world coordinate and camera coordinate, i.e., om\n\n- **tvec**: `Evision.Mat`.\n\n  vector of translation between pattern coordinate and camera coordinate\n\n- **k**: `Evision.Mat`.\n\n  Camera matrix \\f$K = \\vecthreethree{f_x}{s}{c_x}{0}{f_y}{c_y}{0}{0}{_1}\\f$.\n\n- **xi**: `double`.\n\n  The parameter xi for CMei's model\n\n- **d**: `Evision.Mat`.\n\n  Input vector of distortion coefficients \\f$(k_1, k_2, p_1, p_2)\\f$.\n\n##### Return\n- **imagePoints**: `Evision.Mat.t()`.\n\n  Output array of image points, vector of vector of Vec2f or\n  1xN/Nx1 2-channel of type CV_32F. 64F is also acceptable.\n\n- **jacobian**: `Evision.Mat.t()`.\n\n  Optional output 2Nx16 of type CV_64F jacobian matrix, contains the derivatives of\n  image pixel points wrt parameters including \\f$om, T, f_x, f_y, s, c_x, c_y, xi, k_1, k_2, p_1, p_2\\f$.\n  This matrix will be used in calibration by optimization.\n\nThe function projects object 3D points of world coordinate to image pixels, parameter by intrinsic\nand extrinsic parameters. Also, it optionally compute a by-product: the jacobian matrix containing\ncontains the derivatives of image pixel points wrt intrinsic and extrinsic parameters.\n\nPython prototype (for reference only):\n```python3\nprojectPoints(objectPoints, rvec, tvec, K, xi, D[, imagePoints[, jacobian]]) -> imagePoints, jacobian\n```","ref":"Evision.Omnidir.html#projectPoints/6"},{"type":"function","title":"Evision.Omnidir.projectPoints/7","doc":"Projects points for omnidirectional camera using CMei's model\n\n##### Positional Arguments\n- **objectPoints**: `Evision.Mat`.\n\n  Object points in world coordinate, vector of vector of Vec3f or Mat of\n  1xN/Nx1 3-channel of type CV_32F and N is the number of points. 64F is also acceptable.\n\n- **rvec**: `Evision.Mat`.\n\n  vector of rotation between world coordinate and camera coordinate, i.e., om\n\n- **tvec**: `Evision.Mat`.\n\n  vector of translation between pattern coordinate and camera coordinate\n\n- **k**: `Evision.Mat`.\n\n  Camera matrix \\f$K = \\vecthreethree{f_x}{s}{c_x}{0}{f_y}{c_y}{0}{0}{_1}\\f$.\n\n- **xi**: `double`.\n\n  The parameter xi for CMei's model\n\n- **d**: `Evision.Mat`.\n\n  Input vector of distortion coefficients \\f$(k_1, k_2, p_1, p_2)\\f$.\n\n##### Return\n- **imagePoints**: `Evision.Mat.t()`.\n\n  Output array of image points, vector of vector of Vec2f or\n  1xN/Nx1 2-channel of type CV_32F. 64F is also acceptable.\n\n- **jacobian**: `Evision.Mat.t()`.\n\n  Optional output 2Nx16 of type CV_64F jacobian matrix, contains the derivatives of\n  image pixel points wrt parameters including \\f$om, T, f_x, f_y, s, c_x, c_y, xi, k_1, k_2, p_1, p_2\\f$.\n  This matrix will be used in calibration by optimization.\n\nThe function projects object 3D points of world coordinate to image pixels, parameter by intrinsic\nand extrinsic parameters. Also, it optionally compute a by-product: the jacobian matrix containing\ncontains the derivatives of image pixel points wrt intrinsic and extrinsic parameters.\n\nPython prototype (for reference only):\n```python3\nprojectPoints(objectPoints, rvec, tvec, K, xi, D[, imagePoints[, jacobian]]) -> imagePoints, jacobian\n```","ref":"Evision.Omnidir.html#projectPoints/7"},{"type":"function","title":"Evision.Omnidir.stereoCalibrate/1","doc":"","ref":"Evision.Omnidir.html#stereoCalibrate/1"},{"type":"function","title":"Evision.Omnidir.stereoCalibrate/13","doc":"Stereo calibration for omnidirectional camera model. It computes the intrinsic parameters for two\ncameras and the extrinsic parameters between two cameras. The default depth of outputs is CV_64F.\n\n##### Positional Arguments\n- **imageSize1**: `Size`.\n\n  Image size of calibration images of the first camera.\n\n- **imageSize2**: `Size`.\n\n  Image size of calibration images of the second camera.\n\n- **flags**: `integer()`.\n\n  The flags that control stereoCalibrate\n\n- **criteria**: `TermCriteria`.\n\n  Termination criteria for optimization\n\n##### Return\n- **retval**: `double`\n- **objectPoints**: `[Evision.Mat]`.\n\n  Object points in world (pattern) coordinate. Its type is vector  >.\n  It also can be vector of Mat with size 1xN/Nx1 and type CV_32FC3. Data with depth of 64_F is also acceptable.\n\n- **imagePoints1**: `[Evision.Mat]`.\n\n  The corresponding image points of the first camera, with type vector  >.\n  It must be the same size and the same type as objectPoints.\n\n- **imagePoints2**: `[Evision.Mat]`.\n\n  The corresponding image points of the second camera, with type vector  >.\n  It must be the same size and the same type as objectPoints.\n\n- **k1**: `Evision.Mat.t()`.\n\n  Output camera matrix for the first camera.\n\n- **xi1**: `Evision.Mat.t()`.\n\n  Output parameter xi of Mei's model for the first camera\n\n- **d1**: `Evision.Mat.t()`.\n\n  Output distortion parameters \\f$(k_1, k_2, p_1, p_2)\\f$ for the first camera\n\n- **k2**: `Evision.Mat.t()`.\n\n  Output camera matrix for the first camera.\n\n- **xi2**: `Evision.Mat.t()`.\n\n  Output parameter xi of CMei's model for the second camera\n\n- **d2**: `Evision.Mat.t()`.\n\n  Output distortion parameters \\f$(k_1, k_2, p_1, p_2)\\f$ for the second camera\n\n- **rvec**: `Evision.Mat.t()`.\n\n  Output rotation between the first and second camera\n\n- **tvec**: `Evision.Mat.t()`.\n\n  Output translation between the first and second camera\n\n- **rvecsL**: `[Evision.Mat]`.\n\n  Output rotation for each image of the first camera\n\n- **tvecsL**: `[Evision.Mat]`.\n\n  Output translation for each image of the first camera\n\n- **idx**: `Evision.Mat.t()`.\n\n  Indices of image pairs that pass initialization, which are really used in calibration. So the size of rvecs is the\n  same as idx.total().\n\n@\n\nPython prototype (for reference only):\n```python3\nstereoCalibrate(objectPoints, imagePoints1, imagePoints2, imageSize1, imageSize2, K1, xi1, D1, K2, xi2, D2, flags, criteria[, rvec[, tvec[, rvecsL[, tvecsL[, idx]]]]]) -> retval, objectPoints, imagePoints1, imagePoints2, K1, xi1, D1, K2, xi2, D2, rvec, tvec, rvecsL, tvecsL, idx\n```","ref":"Evision.Omnidir.html#stereoCalibrate/13"},{"type":"function","title":"Evision.Omnidir.stereoCalibrate/14","doc":"Stereo calibration for omnidirectional camera model. It computes the intrinsic parameters for two\ncameras and the extrinsic parameters between two cameras. The default depth of outputs is CV_64F.\n\n##### Positional Arguments\n- **imageSize1**: `Size`.\n\n  Image size of calibration images of the first camera.\n\n- **imageSize2**: `Size`.\n\n  Image size of calibration images of the second camera.\n\n- **flags**: `integer()`.\n\n  The flags that control stereoCalibrate\n\n- **criteria**: `TermCriteria`.\n\n  Termination criteria for optimization\n\n##### Return\n- **retval**: `double`\n- **objectPoints**: `[Evision.Mat]`.\n\n  Object points in world (pattern) coordinate. Its type is vector  >.\n  It also can be vector of Mat with size 1xN/Nx1 and type CV_32FC3. Data with depth of 64_F is also acceptable.\n\n- **imagePoints1**: `[Evision.Mat]`.\n\n  The corresponding image points of the first camera, with type vector  >.\n  It must be the same size and the same type as objectPoints.\n\n- **imagePoints2**: `[Evision.Mat]`.\n\n  The corresponding image points of the second camera, with type vector  >.\n  It must be the same size and the same type as objectPoints.\n\n- **k1**: `Evision.Mat.t()`.\n\n  Output camera matrix for the first camera.\n\n- **xi1**: `Evision.Mat.t()`.\n\n  Output parameter xi of Mei's model for the first camera\n\n- **d1**: `Evision.Mat.t()`.\n\n  Output distortion parameters \\f$(k_1, k_2, p_1, p_2)\\f$ for the first camera\n\n- **k2**: `Evision.Mat.t()`.\n\n  Output camera matrix for the first camera.\n\n- **xi2**: `Evision.Mat.t()`.\n\n  Output parameter xi of CMei's model for the second camera\n\n- **d2**: `Evision.Mat.t()`.\n\n  Output distortion parameters \\f$(k_1, k_2, p_1, p_2)\\f$ for the second camera\n\n- **rvec**: `Evision.Mat.t()`.\n\n  Output rotation between the first and second camera\n\n- **tvec**: `Evision.Mat.t()`.\n\n  Output translation between the first and second camera\n\n- **rvecsL**: `[Evision.Mat]`.\n\n  Output rotation for each image of the first camera\n\n- **tvecsL**: `[Evision.Mat]`.\n\n  Output translation for each image of the first camera\n\n- **idx**: `Evision.Mat.t()`.\n\n  Indices of image pairs that pass initialization, which are really used in calibration. So the size of rvecs is the\n  same as idx.total().\n\n@\n\nPython prototype (for reference only):\n```python3\nstereoCalibrate(objectPoints, imagePoints1, imagePoints2, imageSize1, imageSize2, K1, xi1, D1, K2, xi2, D2, flags, criteria[, rvec[, tvec[, rvecsL[, tvecsL[, idx]]]]]) -> retval, objectPoints, imagePoints1, imagePoints2, K1, xi1, D1, K2, xi2, D2, rvec, tvec, rvecsL, tvecsL, idx\n```","ref":"Evision.Omnidir.html#stereoCalibrate/14"},{"type":"function","title":"Evision.Omnidir.stereoReconstruct/1","doc":"","ref":"Evision.Omnidir.html#stereoReconstruct/1"},{"type":"function","title":"Evision.Omnidir.stereoReconstruct/13","doc":"Stereo 3D reconstruction from a pair of images\n\n##### Positional Arguments\n- **image1**: `Evision.Mat`.\n\n  The first input image\n\n- **image2**: `Evision.Mat`.\n\n  The second input image\n\n- **k1**: `Evision.Mat`.\n\n  Input camera matrix of the first camera\n\n- **d1**: `Evision.Mat`.\n\n  Input distortion parameters \\f$(k_1, k_2, p_1, p_2)\\f$ for the first camera\n\n- **xi1**: `Evision.Mat`.\n\n  Input parameter xi for the first camera for CMei's model\n\n- **k2**: `Evision.Mat`.\n\n  Input camera matrix of the second camera\n\n- **d2**: `Evision.Mat`.\n\n  Input distortion parameters \\f$(k_1, k_2, p_1, p_2)\\f$ for the second camera\n\n- **xi2**: `Evision.Mat`.\n\n  Input parameter xi for the second camera for CMei's model\n\n- **r**: `Evision.Mat`.\n\n  Rotation between the first and second camera\n\n- **t**: `Evision.Mat`.\n\n  Translation between the first and second camera\n\n- **flag**: `integer()`.\n\n  Flag of rectification type, RECTIFY_PERSPECTIVE or RECTIFY_LONGLATI\n\n- **numDisparities**: `integer()`.\n\n  The parameter 'numDisparities' in StereoSGBM, see StereoSGBM for details.\n\n- **sADWindowSize**: `integer()`.\n\n  The parameter 'SADWindowSize' in StereoSGBM, see StereoSGBM for details.\n\n##### Keyword Arguments\n- **newSize**: `Size`.\n\n  Image size of rectified image, see omnidir::undistortImage\n\n- **knew**: `Evision.Mat`.\n\n  New camera matrix of rectified image, see omnidir::undistortImage\n\n- **pointType**: `integer()`.\n\n  Point cloud type, it can be XYZRGB or XYZ\n\n##### Return\n- **disparity**: `Evision.Mat.t()`.\n\n  Disparity map generated by stereo matching\n\n- **image1Rec**: `Evision.Mat.t()`.\n\n  Rectified image of the first image\n\n- **image2Rec**: `Evision.Mat.t()`.\n\n  rectified image of the second image\n\n- **pointCloud**: `Evision.Mat.t()`.\n\n  Point cloud of 3D reconstruction, with type CV_64FC3\n\nPython prototype (for reference only):\n```python3\nstereoReconstruct(image1, image2, K1, D1, xi1, K2, D2, xi2, R, T, flag, numDisparities, SADWindowSize[, disparity[, image1Rec[, image2Rec[, newSize[, Knew[, pointCloud[, pointType]]]]]]]) -> disparity, image1Rec, image2Rec, pointCloud\n```","ref":"Evision.Omnidir.html#stereoReconstruct/13"},{"type":"function","title":"Evision.Omnidir.stereoReconstruct/14","doc":"Stereo 3D reconstruction from a pair of images\n\n##### Positional Arguments\n- **image1**: `Evision.Mat`.\n\n  The first input image\n\n- **image2**: `Evision.Mat`.\n\n  The second input image\n\n- **k1**: `Evision.Mat`.\n\n  Input camera matrix of the first camera\n\n- **d1**: `Evision.Mat`.\n\n  Input distortion parameters \\f$(k_1, k_2, p_1, p_2)\\f$ for the first camera\n\n- **xi1**: `Evision.Mat`.\n\n  Input parameter xi for the first camera for CMei's model\n\n- **k2**: `Evision.Mat`.\n\n  Input camera matrix of the second camera\n\n- **d2**: `Evision.Mat`.\n\n  Input distortion parameters \\f$(k_1, k_2, p_1, p_2)\\f$ for the second camera\n\n- **xi2**: `Evision.Mat`.\n\n  Input parameter xi for the second camera for CMei's model\n\n- **r**: `Evision.Mat`.\n\n  Rotation between the first and second camera\n\n- **t**: `Evision.Mat`.\n\n  Translation between the first and second camera\n\n- **flag**: `integer()`.\n\n  Flag of rectification type, RECTIFY_PERSPECTIVE or RECTIFY_LONGLATI\n\n- **numDisparities**: `integer()`.\n\n  The parameter 'numDisparities' in StereoSGBM, see StereoSGBM for details.\n\n- **sADWindowSize**: `integer()`.\n\n  The parameter 'SADWindowSize' in StereoSGBM, see StereoSGBM for details.\n\n##### Keyword Arguments\n- **newSize**: `Size`.\n\n  Image size of rectified image, see omnidir::undistortImage\n\n- **knew**: `Evision.Mat`.\n\n  New camera matrix of rectified image, see omnidir::undistortImage\n\n- **pointType**: `integer()`.\n\n  Point cloud type, it can be XYZRGB or XYZ\n\n##### Return\n- **disparity**: `Evision.Mat.t()`.\n\n  Disparity map generated by stereo matching\n\n- **image1Rec**: `Evision.Mat.t()`.\n\n  Rectified image of the first image\n\n- **image2Rec**: `Evision.Mat.t()`.\n\n  rectified image of the second image\n\n- **pointCloud**: `Evision.Mat.t()`.\n\n  Point cloud of 3D reconstruction, with type CV_64FC3\n\nPython prototype (for reference only):\n```python3\nstereoReconstruct(image1, image2, K1, D1, xi1, K2, D2, xi2, R, T, flag, numDisparities, SADWindowSize[, disparity[, image1Rec[, image2Rec[, newSize[, Knew[, pointCloud[, pointType]]]]]]]) -> disparity, image1Rec, image2Rec, pointCloud\n```","ref":"Evision.Omnidir.html#stereoReconstruct/14"},{"type":"function","title":"Evision.Omnidir.stereoRectify/1","doc":"","ref":"Evision.Omnidir.html#stereoRectify/1"},{"type":"function","title":"Evision.Omnidir.stereoRectify/2","doc":"Stereo rectification for omnidirectional camera model. It computes the rectification rotations for two cameras\n\n##### Positional Arguments\n- **r**: `Evision.Mat`.\n\n  Rotation between the first and second camera\n\n- **t**: `Evision.Mat`.\n\n  Translation between the first and second camera\n\n##### Return\n- **r1**: `Evision.Mat.t()`.\n\n  Output 3x3 rotation matrix for the first camera\n\n- **r2**: `Evision.Mat.t()`.\n\n  Output 3x3 rotation matrix for the second camera\n\nPython prototype (for reference only):\n```python3\nstereoRectify(R, T[, R1[, R2]]) -> R1, R2\n```","ref":"Evision.Omnidir.html#stereoRectify/2"},{"type":"function","title":"Evision.Omnidir.stereoRectify/3","doc":"Stereo rectification for omnidirectional camera model. It computes the rectification rotations for two cameras\n\n##### Positional Arguments\n- **r**: `Evision.Mat`.\n\n  Rotation between the first and second camera\n\n- **t**: `Evision.Mat`.\n\n  Translation between the first and second camera\n\n##### Return\n- **r1**: `Evision.Mat.t()`.\n\n  Output 3x3 rotation matrix for the first camera\n\n- **r2**: `Evision.Mat.t()`.\n\n  Output 3x3 rotation matrix for the second camera\n\nPython prototype (for reference only):\n```python3\nstereoRectify(R, T[, R1[, R2]]) -> R1, R2\n```","ref":"Evision.Omnidir.html#stereoRectify/3"},{"type":"function","title":"Evision.Omnidir.undistortImage/1","doc":"","ref":"Evision.Omnidir.html#undistortImage/1"},{"type":"function","title":"Evision.Omnidir.undistortImage/5","doc":"Undistort omnidirectional images to perspective images\n\n##### Positional Arguments\n- **distorted**: `Evision.Mat`.\n\n  The input omnidirectional image.\n\n- **k**: `Evision.Mat`.\n\n  Camera matrix \\f$K = \\vecthreethree{f_x}{s}{c_x}{0}{f_y}{c_y}{0}{0}{_1}\\f$.\n\n- **d**: `Evision.Mat`.\n\n  Input vector of distortion coefficients \\f$(k_1, k_2, p_1, p_2)\\f$.\n\n- **xi**: `Evision.Mat`.\n\n  The parameter xi for CMei's model.\n\n- **flags**: `integer()`.\n\n  Flags indicates the rectification type,  RECTIFY_PERSPECTIVE, RECTIFY_CYLINDRICAL, RECTIFY_LONGLATI and RECTIFY_STEREOGRAPHIC\n\n##### Keyword Arguments\n- **knew**: `Evision.Mat`.\n\n  Camera matrix of the distorted image. If it is not assigned, it is just K.\n\n- **new_size**: `Size`.\n\n  The new image size. By default, it is the size of distorted.\n\n- **r**: `Evision.Mat`.\n\n  Rotation matrix between the input and output images. By default, it is identity matrix.\n\n##### Return\n- **undistorted**: `Evision.Mat.t()`.\n\n  The output undistorted image.\n\nPython prototype (for reference only):\n```python3\nundistortImage(distorted, K, D, xi, flags[, undistorted[, Knew[, new_size[, R]]]]) -> undistorted\n```","ref":"Evision.Omnidir.html#undistortImage/5"},{"type":"function","title":"Evision.Omnidir.undistortImage/6","doc":"Undistort omnidirectional images to perspective images\n\n##### Positional Arguments\n- **distorted**: `Evision.Mat`.\n\n  The input omnidirectional image.\n\n- **k**: `Evision.Mat`.\n\n  Camera matrix \\f$K = \\vecthreethree{f_x}{s}{c_x}{0}{f_y}{c_y}{0}{0}{_1}\\f$.\n\n- **d**: `Evision.Mat`.\n\n  Input vector of distortion coefficients \\f$(k_1, k_2, p_1, p_2)\\f$.\n\n- **xi**: `Evision.Mat`.\n\n  The parameter xi for CMei's model.\n\n- **flags**: `integer()`.\n\n  Flags indicates the rectification type,  RECTIFY_PERSPECTIVE, RECTIFY_CYLINDRICAL, RECTIFY_LONGLATI and RECTIFY_STEREOGRAPHIC\n\n##### Keyword Arguments\n- **knew**: `Evision.Mat`.\n\n  Camera matrix of the distorted image. If it is not assigned, it is just K.\n\n- **new_size**: `Size`.\n\n  The new image size. By default, it is the size of distorted.\n\n- **r**: `Evision.Mat`.\n\n  Rotation matrix between the input and output images. By default, it is identity matrix.\n\n##### Return\n- **undistorted**: `Evision.Mat.t()`.\n\n  The output undistorted image.\n\nPython prototype (for reference only):\n```python3\nundistortImage(distorted, K, D, xi, flags[, undistorted[, Knew[, new_size[, R]]]]) -> undistorted\n```","ref":"Evision.Omnidir.html#undistortImage/6"},{"type":"function","title":"Evision.Omnidir.undistortPoints/1","doc":"","ref":"Evision.Omnidir.html#undistortPoints/1"},{"type":"function","title":"Evision.Omnidir.undistortPoints/5","doc":"Undistort 2D image points for omnidirectional camera using CMei's model\n\n##### Positional Arguments\n- **distorted**: `Evision.Mat`.\n\n  Array of distorted image points, vector of Vec2f\n  or 1xN/Nx1 2-channel Mat of type CV_32F, 64F depth is also acceptable\n\n- **k**: `Evision.Mat`.\n\n  Camera matrix \\f$K = \\vecthreethree{f_x}{s}{c_x}{0}{f_y}{c_y}{0}{0}{_1}\\f$.\n\n- **d**: `Evision.Mat`.\n\n  Distortion coefficients \\f$(k_1, k_2, p_1, p_2)\\f$.\n\n- **xi**: `Evision.Mat`.\n\n  The parameter xi for CMei's model\n\n- **r**: `Evision.Mat`.\n\n  Rotation trainsform between the original and object space : 3x3 1-channel, or vector: 3x1/1x3\n  1-channel or 1x1 3-channel\n\n##### Return\n- **undistorted**: `Evision.Mat.t()`.\n\n  array of normalized object points, vector of Vec2f/Vec2d or 1xN/Nx1 2-channel Mat with the same\n  depth of distorted points.\n\nPython prototype (for reference only):\n```python3\nundistortPoints(distorted, K, D, xi, R[, undistorted]) -> undistorted\n```","ref":"Evision.Omnidir.html#undistortPoints/5"},{"type":"function","title":"Evision.Omnidir.undistortPoints/6","doc":"Undistort 2D image points for omnidirectional camera using CMei's model\n\n##### Positional Arguments\n- **distorted**: `Evision.Mat`.\n\n  Array of distorted image points, vector of Vec2f\n  or 1xN/Nx1 2-channel Mat of type CV_32F, 64F depth is also acceptable\n\n- **k**: `Evision.Mat`.\n\n  Camera matrix \\f$K = \\vecthreethree{f_x}{s}{c_x}{0}{f_y}{c_y}{0}{0}{_1}\\f$.\n\n- **d**: `Evision.Mat`.\n\n  Distortion coefficients \\f$(k_1, k_2, p_1, p_2)\\f$.\n\n- **xi**: `Evision.Mat`.\n\n  The parameter xi for CMei's model\n\n- **r**: `Evision.Mat`.\n\n  Rotation trainsform between the original and object space : 3x3 1-channel, or vector: 3x1/1x3\n  1-channel or 1x1 3-channel\n\n##### Return\n- **undistorted**: `Evision.Mat.t()`.\n\n  array of normalized object points, vector of Vec2f/Vec2d or 1xN/Nx1 2-channel Mat with the same\n  depth of distorted points.\n\nPython prototype (for reference only):\n```python3\nundistortPoints(distorted, K, D, xi, R[, undistorted]) -> undistorted\n```","ref":"Evision.Omnidir.html#undistortPoints/6"},{"type":"type","title":"Evision.Omnidir.enum/0","doc":"","ref":"Evision.Omnidir.html#t:enum/0"},{"type":"type","title":"Evision.Omnidir.t/0","doc":"Type that represents an `Omnidir` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Omnidir.html#t:t/0"},{"type":"module","title":"Evision.PCA.Flags","doc":"","ref":"Evision.PCA.Flags.html"},{"type":"function","title":"Evision.PCA.Flags.cv_DATA_AS_COL/0","doc":"","ref":"Evision.PCA.Flags.html#cv_DATA_AS_COL/0"},{"type":"function","title":"Evision.PCA.Flags.cv_DATA_AS_ROW/0","doc":"","ref":"Evision.PCA.Flags.html#cv_DATA_AS_ROW/0"},{"type":"function","title":"Evision.PCA.Flags.cv_USE_AVG/0","doc":"","ref":"Evision.PCA.Flags.html#cv_USE_AVG/0"},{"type":"type","title":"Evision.PCA.Flags.enum/0","doc":"","ref":"Evision.PCA.Flags.html#t:enum/0"},{"type":"module","title":"Evision.PPFMatch3D","doc":"","ref":"Evision.PPFMatch3D.html"},{"type":"function","title":"Evision.PPFMatch3D.addNoisePC/1","doc":"","ref":"Evision.PPFMatch3D.html#addNoisePC/1"},{"type":"function","title":"Evision.PPFMatch3D.addNoisePC/2","doc":"addNoisePC\n\n##### Positional Arguments\n- **pc**: `Evision.Mat`\n- **scale**: `double`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n  Adds a uniform noise in the given scale to the input point cloud\n\nPython prototype (for reference only):\n```python3\naddNoisePC(pc, scale) -> retval\n```","ref":"Evision.PPFMatch3D.html#addNoisePC/2"},{"type":"function","title":"Evision.PPFMatch3D.computeNormalsPC3d/1","doc":"","ref":"Evision.PPFMatch3D.html#computeNormalsPC3d/1"},{"type":"function","title":"Evision.PPFMatch3D.computeNormalsPC3d/4","doc":"Compute the normals of an arbitrary point cloud\ncomputeNormalsPC3d uses a plane fitting approach to smoothly compute\nlocal normals. Normals are obtained through the eigenvector of the covariance\nmatrix, corresponding to the smallest eigen value.\nIf PCNormals is provided to be an Nx6 matrix, then no new allocation\nis made, instead the existing memory is overwritten.\n\n##### Positional Arguments\n- **pC**: `Evision.Mat`\n- **numNeighbors**: `integer()`\n- **flipViewpoint**: `bool`\n- **viewpoint**: `Vec3f`\n\n##### Return\n- **retval**: `integer()`\n- **pCNormals**: `Evision.Mat.t()`.\n\n@return Returns 0 on success\n\nPython prototype (for reference only):\n```python3\ncomputeNormalsPC3d(PC, NumNeighbors, FlipViewpoint, viewpoint[, PCNormals]) -> retval, PCNormals\n```","ref":"Evision.PPFMatch3D.html#computeNormalsPC3d/4"},{"type":"function","title":"Evision.PPFMatch3D.computeNormalsPC3d/5","doc":"Compute the normals of an arbitrary point cloud\ncomputeNormalsPC3d uses a plane fitting approach to smoothly compute\nlocal normals. Normals are obtained through the eigenvector of the covariance\nmatrix, corresponding to the smallest eigen value.\nIf PCNormals is provided to be an Nx6 matrix, then no new allocation\nis made, instead the existing memory is overwritten.\n\n##### Positional Arguments\n- **pC**: `Evision.Mat`\n- **numNeighbors**: `integer()`\n- **flipViewpoint**: `bool`\n- **viewpoint**: `Vec3f`\n\n##### Return\n- **retval**: `integer()`\n- **pCNormals**: `Evision.Mat.t()`.\n\n@return Returns 0 on success\n\nPython prototype (for reference only):\n```python3\ncomputeNormalsPC3d(PC, NumNeighbors, FlipViewpoint, viewpoint[, PCNormals]) -> retval, PCNormals\n```","ref":"Evision.PPFMatch3D.html#computeNormalsPC3d/5"},{"type":"function","title":"Evision.PPFMatch3D.getRandomPose/1","doc":"getRandomPose\n\n##### Positional Arguments\n- **pose**: `Evision.Mat`\n\n  Generate a random 4x4 pose matrix\n\nPython prototype (for reference only):\n```python3\ngetRandomPose(Pose) -> None\n```","ref":"Evision.PPFMatch3D.html#getRandomPose/1"},{"type":"function","title":"Evision.PPFMatch3D.loadPLYSimple/1","doc":"Load a PLY file\n\n##### Positional Arguments\n- **fileName**: `c_string`\n\n##### Keyword Arguments\n- **withNormals**: `integer()`.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n@return Returns the matrix on successful load\n\nPython prototype (for reference only):\n```python3\nloadPLYSimple(fileName[, withNormals]) -> retval\n```","ref":"Evision.PPFMatch3D.html#loadPLYSimple/1"},{"type":"function","title":"Evision.PPFMatch3D.loadPLYSimple/2","doc":"Load a PLY file\n\n##### Positional Arguments\n- **fileName**: `c_string`\n\n##### Keyword Arguments\n- **withNormals**: `integer()`.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n@return Returns the matrix on successful load\n\nPython prototype (for reference only):\n```python3\nloadPLYSimple(fileName[, withNormals]) -> retval\n```","ref":"Evision.PPFMatch3D.html#loadPLYSimple/2"},{"type":"function","title":"Evision.PPFMatch3D.samplePCByQuantization/1","doc":"","ref":"Evision.PPFMatch3D.html#samplePCByQuantization/1"},{"type":"function","title":"Evision.PPFMatch3D.samplePCByQuantization/5","doc":"samplePCByQuantization\n\n##### Positional Arguments\n- **pc**: `Evision.Mat`\n- **xrange**: `Vec2f`\n- **yrange**: `Vec2f`\n- **zrange**: `Vec2f`\n- **sample_step_relative**: `float`\n\n##### Keyword Arguments\n- **weightByCenter**: `integer()`.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n  Sample a point cloud using uniform steps\n@return Sampled point cloud\n\nPython prototype (for reference only):\n```python3\nsamplePCByQuantization(pc, xrange, yrange, zrange, sample_step_relative[, weightByCenter]) -> retval\n```","ref":"Evision.PPFMatch3D.html#samplePCByQuantization/5"},{"type":"function","title":"Evision.PPFMatch3D.samplePCByQuantization/6","doc":"samplePCByQuantization\n\n##### Positional Arguments\n- **pc**: `Evision.Mat`\n- **xrange**: `Vec2f`\n- **yrange**: `Vec2f`\n- **zrange**: `Vec2f`\n- **sample_step_relative**: `float`\n\n##### Keyword Arguments\n- **weightByCenter**: `integer()`.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n  Sample a point cloud using uniform steps\n@return Sampled point cloud\n\nPython prototype (for reference only):\n```python3\nsamplePCByQuantization(pc, xrange, yrange, zrange, sample_step_relative[, weightByCenter]) -> retval\n```","ref":"Evision.PPFMatch3D.html#samplePCByQuantization/6"},{"type":"function","title":"Evision.PPFMatch3D.transformPCPose/1","doc":"","ref":"Evision.PPFMatch3D.html#transformPCPose/1"},{"type":"function","title":"Evision.PPFMatch3D.transformPCPose/2","doc":"transformPCPose\n\n##### Positional Arguments\n- **pc**: `Evision.Mat`\n- **pose**: `Evision.Mat`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n  Transforms the point cloud with a given a homogeneous 4x4 pose matrix (in double precision)\n@return Transformed point cloud\n\nPython prototype (for reference only):\n```python3\ntransformPCPose(pc, Pose) -> retval\n```","ref":"Evision.PPFMatch3D.html#transformPCPose/2"},{"type":"function","title":"Evision.PPFMatch3D.writePLY/1","doc":"","ref":"Evision.PPFMatch3D.html#writePLY/1"},{"type":"function","title":"Evision.PPFMatch3D.writePLY/2","doc":"Write a point cloud to PLY file\n\n##### Positional Arguments\n- **pC**: `Evision.Mat`\n- **fileName**: `c_string`\n\nPython prototype (for reference only):\n```python3\nwritePLY(PC, fileName) -> None\n```","ref":"Evision.PPFMatch3D.html#writePLY/2"},{"type":"function","title":"Evision.PPFMatch3D.writePLYVisibleNormals/1","doc":"","ref":"Evision.PPFMatch3D.html#writePLYVisibleNormals/1"},{"type":"function","title":"Evision.PPFMatch3D.writePLYVisibleNormals/2","doc":"Used for debbuging pruposes, writes a point cloud to a PLY file with the tip\nof the normal vectors as visible red points\n\n##### Positional Arguments\n- **pC**: `Evision.Mat`\n- **fileName**: `c_string`\n\nPython prototype (for reference only):\n```python3\nwritePLYVisibleNormals(PC, fileName) -> None\n```","ref":"Evision.PPFMatch3D.html#writePLYVisibleNormals/2"},{"type":"type","title":"Evision.PPFMatch3D.t/0","doc":"Type that represents an `PPFMatch3D` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.PPFMatch3D.html#t:t/0"},{"type":"module","title":"Evision.PPFMatch3D.ICP","doc":"","ref":"Evision.PPFMatch3D.ICP.html"},{"type":"function","title":"Evision.PPFMatch3D.ICP.iCP/0","doc":"ICP\n##### Return\n- **self**: `ICP`\n\nPython prototype (for reference only):\n```python3\nICP() ->  \n```","ref":"Evision.PPFMatch3D.ICP.html#iCP/0"},{"type":"function","title":"Evision.PPFMatch3D.ICP.iCP/1","doc":"ICP\n\n##### Positional Arguments\n- **iterations**: `integer()`\n\n##### Keyword Arguments\n- **tolerence**: `float`.\n- **rejectionScale**: `float`.\n- **numLevels**: `integer()`.\n- **sampleType**: `integer()`.\n- **numMaxCorr**: `integer()`.\n\n##### Return\n- **self**: `ICP`\n\n  \\brief ICP constructor with default arguments.\n\nPython prototype (for reference only):\n```python3\nICP(iterations[, tolerence[, rejectionScale[, numLevels[, sampleType[, numMaxCorr]]]]]) ->  \n```","ref":"Evision.PPFMatch3D.ICP.html#iCP/1"},{"type":"function","title":"Evision.PPFMatch3D.ICP.iCP/2","doc":"ICP\n\n##### Positional Arguments\n- **iterations**: `integer()`\n\n##### Keyword Arguments\n- **tolerence**: `float`.\n- **rejectionScale**: `float`.\n- **numLevels**: `integer()`.\n- **sampleType**: `integer()`.\n- **numMaxCorr**: `integer()`.\n\n##### Return\n- **self**: `ICP`\n\n  \\brief ICP constructor with default arguments.\n\nPython prototype (for reference only):\n```python3\nICP(iterations[, tolerence[, rejectionScale[, numLevels[, sampleType[, numMaxCorr]]]]]) ->  \n```","ref":"Evision.PPFMatch3D.ICP.html#iCP/2"},{"type":"function","title":"Evision.PPFMatch3D.ICP.registerModelToScene/1","doc":"","ref":"Evision.PPFMatch3D.ICP.html#registerModelToScene/1"},{"type":"function","title":"Evision.PPFMatch3D.ICP.registerModelToScene/3","doc":"registerModelToScene\n\n##### Positional Arguments\n- **self**: `Evision.PPFMatch3D.ICP.t()`\n- **srcPC**: `Evision.Mat`\n- **dstPC**: `Evision.Mat`\n\n##### Return\n- **retval**: `integer()`\n- **residual**: `double`\n- **pose**: `Evision.Mat.t()`\n\n  \\brief Perform registration\n\n  \\details It is assumed that the model is registered on the scene. Scene remains static, while the model transforms. The output poses transform the models onto the scene. Because of the point to plane minimization, the scene is expected to have the normals available. Expected to have the normals (Nx6).\n\nPython prototype (for reference only):\n```python3\nregisterModelToScene(srcPC, dstPC) -> retval, residual, pose\n```","ref":"Evision.PPFMatch3D.ICP.html#registerModelToScene/3"},{"type":"function","title":"Evision.PPFMatch3D.ICP.registerModelToScene/4","doc":"registerModelToScene\n\n##### Positional Arguments\n- **self**: `Evision.PPFMatch3D.ICP.t()`\n- **srcPC**: `Evision.Mat`\n- **dstPC**: `Evision.Mat`\n\n##### Return\n- **retval**: `integer()`\n- **poses**: `[Evision.PPFMatch3D.Pose3D]`\n\n  \\brief Perform registration with multiple initial poses\n\n  \\details It is assumed that the model is registered on the scene. Scene remains static, while the model transforms. The output poses transform the models onto the scene. Because of the point to plane minimization, the scene is expected to have the normals available. Expected to have the normals (Nx6).\n\nPython prototype (for reference only):\n```python3\nregisterModelToScene(srcPC, dstPC, poses) -> retval, poses\n```","ref":"Evision.PPFMatch3D.ICP.html#registerModelToScene/4"},{"type":"type","title":"Evision.PPFMatch3D.ICP.t/0","doc":"Type that represents an `PPFMatch3D.ICP` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.PPFMatch3D.ICP.html#t:t/0"},{"type":"module","title":"Evision.PPFMatch3D.PPF3DDetector","doc":"","ref":"Evision.PPFMatch3D.PPF3DDetector.html"},{"type":"function","title":"Evision.PPFMatch3D.PPF3DDetector.match/1","doc":"","ref":"Evision.PPFMatch3D.PPF3DDetector.html#match/1"},{"type":"function","title":"Evision.PPFMatch3D.PPF3DDetector.match/2","doc":"match\n\n##### Positional Arguments\n- **self**: `Evision.PPFMatch3D.PPF3DDetector.t()`\n- **scene**: `Evision.Mat`\n\n##### Keyword Arguments\n- **relativeSceneSampleStep**: `double`.\n- **relativeSceneDistance**: `double`.\n\n##### Return\n- **results**: `[Evision.PPFMatch3D.Pose3D]`\n\n  \\brief Matches a trained model across a provided scene.\n\nPython prototype (for reference only):\n```python3\nmatch(scene[, relativeSceneSampleStep[, relativeSceneDistance]]) -> results\n```","ref":"Evision.PPFMatch3D.PPF3DDetector.html#match/2"},{"type":"function","title":"Evision.PPFMatch3D.PPF3DDetector.match/3","doc":"match\n\n##### Positional Arguments\n- **self**: `Evision.PPFMatch3D.PPF3DDetector.t()`\n- **scene**: `Evision.Mat`\n\n##### Keyword Arguments\n- **relativeSceneSampleStep**: `double`.\n- **relativeSceneDistance**: `double`.\n\n##### Return\n- **results**: `[Evision.PPFMatch3D.Pose3D]`\n\n  \\brief Matches a trained model across a provided scene.\n\nPython prototype (for reference only):\n```python3\nmatch(scene[, relativeSceneSampleStep[, relativeSceneDistance]]) -> results\n```","ref":"Evision.PPFMatch3D.PPF3DDetector.html#match/3"},{"type":"function","title":"Evision.PPFMatch3D.PPF3DDetector.pPF3DDetector/0","doc":"PPF3DDetector\n##### Return\n- **self**: `Evision.PPFMatch3D.PPF3DDetector.t()`\n\n \\brief Empty constructor. Sets default arguments\n\nPython prototype (for reference only):\n```python3\nPPF3DDetector() ->  \n```","ref":"Evision.PPFMatch3D.PPF3DDetector.html#pPF3DDetector/0"},{"type":"function","title":"Evision.PPFMatch3D.PPF3DDetector.pPF3DDetector/1","doc":"PPF3DDetector\n\n##### Positional Arguments\n- **relativeSamplingStep**: `double`\n\n##### Keyword Arguments\n- **relativeDistanceStep**: `double`.\n- **numAngles**: `double`.\n\n##### Return\n- **self**: `Evision.PPFMatch3D.PPF3DDetector.t()`\n\n Constructor with arguments\n\nPython prototype (for reference only):\n```python3\nPPF3DDetector(relativeSamplingStep[, relativeDistanceStep[, numAngles]]) ->  \n```","ref":"Evision.PPFMatch3D.PPF3DDetector.html#pPF3DDetector/1"},{"type":"function","title":"Evision.PPFMatch3D.PPF3DDetector.pPF3DDetector/2","doc":"PPF3DDetector\n\n##### Positional Arguments\n- **relativeSamplingStep**: `double`\n\n##### Keyword Arguments\n- **relativeDistanceStep**: `double`.\n- **numAngles**: `double`.\n\n##### Return\n- **self**: `Evision.PPFMatch3D.PPF3DDetector.t()`\n\n Constructor with arguments\n\nPython prototype (for reference only):\n```python3\nPPF3DDetector(relativeSamplingStep[, relativeDistanceStep[, numAngles]]) ->  \n```","ref":"Evision.PPFMatch3D.PPF3DDetector.html#pPF3DDetector/2"},{"type":"function","title":"Evision.PPFMatch3D.PPF3DDetector.trainModel/1","doc":"","ref":"Evision.PPFMatch3D.PPF3DDetector.html#trainModel/1"},{"type":"function","title":"Evision.PPFMatch3D.PPF3DDetector.trainModel/2","doc":"trainModel\n\n##### Positional Arguments\n- **self**: `Evision.PPFMatch3D.PPF3DDetector.t()`\n- **model**: `Evision.Mat`\n\n  \\brief Trains a new model.\n\n  \\details Uses the parameters set in the constructor to downsample and learn a new model. When the model is learnt, the instance gets ready for calling \"match\".\n\nPython prototype (for reference only):\n```python3\ntrainModel(Model) -> None\n```","ref":"Evision.PPFMatch3D.PPF3DDetector.html#trainModel/2"},{"type":"type","title":"Evision.PPFMatch3D.PPF3DDetector.t/0","doc":"Type that represents an `PPFMatch3D.PPF3DDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.PPFMatch3D.PPF3DDetector.html#t:t/0"},{"type":"module","title":"Evision.PPFMatch3D.Pose3D","doc":"","ref":"Evision.PPFMatch3D.Pose3D.html"},{"type":"function","title":"Evision.PPFMatch3D.Pose3D.appendPose/1","doc":"","ref":"Evision.PPFMatch3D.Pose3D.html#appendPose/1"},{"type":"function","title":"Evision.PPFMatch3D.Pose3D.appendPose/2","doc":"appendPose\n\n##### Positional Arguments\n- **self**: `Evision.PPFMatch3D.Pose3D.t()`\n- **incrementalPose**: `Evision.Mat`\n\n  \\brief Left multiplies the existing pose in order to update the transformation\n  \\param [in] IncrementalPose New pose to apply\n\nPython prototype (for reference only):\n```python3\nappendPose(IncrementalPose) -> None\n```","ref":"Evision.PPFMatch3D.Pose3D.html#appendPose/2"},{"type":"function","title":"Evision.PPFMatch3D.Pose3D.get_alpha/1","doc":"","ref":"Evision.PPFMatch3D.Pose3D.html#get_alpha/1"},{"type":"function","title":"Evision.PPFMatch3D.Pose3D.get_angle/1","doc":"","ref":"Evision.PPFMatch3D.Pose3D.html#get_angle/1"},{"type":"function","title":"Evision.PPFMatch3D.Pose3D.get_modelIndex/1","doc":"","ref":"Evision.PPFMatch3D.Pose3D.html#get_modelIndex/1"},{"type":"function","title":"Evision.PPFMatch3D.Pose3D.get_numVotes/1","doc":"","ref":"Evision.PPFMatch3D.Pose3D.html#get_numVotes/1"},{"type":"function","title":"Evision.PPFMatch3D.Pose3D.get_pose/1","doc":"","ref":"Evision.PPFMatch3D.Pose3D.html#get_pose/1"},{"type":"function","title":"Evision.PPFMatch3D.Pose3D.get_q/1","doc":"","ref":"Evision.PPFMatch3D.Pose3D.html#get_q/1"},{"type":"function","title":"Evision.PPFMatch3D.Pose3D.get_residual/1","doc":"","ref":"Evision.PPFMatch3D.Pose3D.html#get_residual/1"},{"type":"function","title":"Evision.PPFMatch3D.Pose3D.get_t/1","doc":"","ref":"Evision.PPFMatch3D.Pose3D.html#get_t/1"},{"type":"function","title":"Evision.PPFMatch3D.Pose3D.pose3D/0","doc":"Pose3D\n##### Return\n- **self**: `Evision.PPFMatch3D.Pose3D.t()`\n\nPython prototype (for reference only):\n```python3\nPose3D() ->  \n```","ref":"Evision.PPFMatch3D.Pose3D.html#pose3D/0"},{"type":"function","title":"Evision.PPFMatch3D.Pose3D.pose3D/1","doc":"Pose3D\n\n##### Positional Arguments\n- **alpha**: `double`\n\n##### Keyword Arguments\n- **modelIndex**: `size_t`.\n- **numVotes**: `size_t`.\n\n##### Return\n- **self**: `Evision.PPFMatch3D.Pose3D.t()`\n\nPython prototype (for reference only):\n```python3\nPose3D(Alpha[, ModelIndex[, NumVotes]]) ->  \n```","ref":"Evision.PPFMatch3D.Pose3D.html#pose3D/1"},{"type":"function","title":"Evision.PPFMatch3D.Pose3D.pose3D/2","doc":"Pose3D\n\n##### Positional Arguments\n- **alpha**: `double`\n\n##### Keyword Arguments\n- **modelIndex**: `size_t`.\n- **numVotes**: `size_t`.\n\n##### Return\n- **self**: `Evision.PPFMatch3D.Pose3D.t()`\n\nPython prototype (for reference only):\n```python3\nPose3D(Alpha[, ModelIndex[, NumVotes]]) ->  \n```","ref":"Evision.PPFMatch3D.Pose3D.html#pose3D/2"},{"type":"function","title":"Evision.PPFMatch3D.Pose3D.printPose/1","doc":"printPose\n\n##### Positional Arguments\n- **self**: `Evision.PPFMatch3D.Pose3D.t()`\n\nPython prototype (for reference only):\n```python3\nprintPose() -> None\n```","ref":"Evision.PPFMatch3D.Pose3D.html#printPose/1"},{"type":"function","title":"Evision.PPFMatch3D.Pose3D.updatePose/1","doc":"","ref":"Evision.PPFMatch3D.Pose3D.html#updatePose/1"},{"type":"function","title":"Evision.PPFMatch3D.Pose3D.updatePose/2","doc":"updatePose\n\n##### Positional Arguments\n- **self**: `Evision.PPFMatch3D.Pose3D.t()`\n- **newPose**: `Evision.Mat`\n\n  \\brief Updates the pose with the new one\n  \\param [in] NewPose New pose to overwrite\n\nPython prototype (for reference only):\n```python3\nupdatePose(NewPose) -> None\n```","ref":"Evision.PPFMatch3D.Pose3D.html#updatePose/2"},{"type":"function","title":"Evision.PPFMatch3D.Pose3D.updatePose/3","doc":"updatePose\n\n##### Positional Arguments\n- **self**: `Evision.PPFMatch3D.Pose3D.t()`\n- **newR**: `Evision.Mat`\n- **newT**: `Vec3d`\n\n  \\brief Updates the pose with the new one\n\nPython prototype (for reference only):\n```python3\nupdatePose(NewR, NewT) -> None\n```","ref":"Evision.PPFMatch3D.Pose3D.html#updatePose/3"},{"type":"function","title":"Evision.PPFMatch3D.Pose3D.updatePoseQuat/1","doc":"","ref":"Evision.PPFMatch3D.Pose3D.html#updatePoseQuat/1"},{"type":"function","title":"Evision.PPFMatch3D.Pose3D.updatePoseQuat/3","doc":"updatePoseQuat\n\n##### Positional Arguments\n- **self**: `Evision.PPFMatch3D.Pose3D.t()`\n- **q**: `Vec4d`\n- **newT**: `Vec3d`\n\n  \\brief Updates the pose with the new one, but this time using quaternions to represent rotation\n\nPython prototype (for reference only):\n```python3\nupdatePoseQuat(Q, NewT) -> None\n```","ref":"Evision.PPFMatch3D.Pose3D.html#updatePoseQuat/3"},{"type":"type","title":"Evision.PPFMatch3D.Pose3D.t/0","doc":"Type that represents an `PPFMatch3D.Pose3D` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.PPFMatch3D.Pose3D.html#t:t/0"},{"type":"module","title":"Evision.PPFMatch3D.PoseCluster3D","doc":"","ref":"Evision.PPFMatch3D.PoseCluster3D.html"},{"type":"type","title":"Evision.PPFMatch3D.PoseCluster3D.t/0","doc":"Type that represents an `PPFMatch3D.PoseCluster3D` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.PPFMatch3D.PoseCluster3D.html#t:t/0"},{"type":"module","title":"Evision.Parallel","doc":"","ref":"Evision.Parallel.html"},{"type":"function","title":"Evision.Parallel.setParallelForBackend/1","doc":"Change OpenCV parallel_for backend\n\n##### Positional Arguments\n- **backendName**: `string`\n\n##### Keyword Arguments\n- **propagateNumThreads**: `bool`.\n\n##### Return\n- **retval**: `bool`\n\n**Note**: This call is not thread-safe. Consider calling this function from the `main()` before any other OpenCV processing functions (and without any other created threads).\n\nPython prototype (for reference only):\n```python3\nsetParallelForBackend(backendName[, propagateNumThreads]) -> retval\n```","ref":"Evision.Parallel.html#setParallelForBackend/1"},{"type":"function","title":"Evision.Parallel.setParallelForBackend/2","doc":"Change OpenCV parallel_for backend\n\n##### Positional Arguments\n- **backendName**: `string`\n\n##### Keyword Arguments\n- **propagateNumThreads**: `bool`.\n\n##### Return\n- **retval**: `bool`\n\n**Note**: This call is not thread-safe. Consider calling this function from the `main()` before any other OpenCV processing functions (and without any other created threads).\n\nPython prototype (for reference only):\n```python3\nsetParallelForBackend(backendName[, propagateNumThreads]) -> retval\n```","ref":"Evision.Parallel.html#setParallelForBackend/2"},{"type":"type","title":"Evision.Parallel.t/0","doc":"Type that represents an `Parallel` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Parallel.html#t:t/0"},{"type":"module","title":"Evision.Param","doc":"","ref":"Evision.Param.html"},{"type":"function","title":"Evision.Param.cv_ALGORITHM/0","doc":"","ref":"Evision.Param.html#cv_ALGORITHM/0"},{"type":"function","title":"Evision.Param.cv_BOOLEAN/0","doc":"","ref":"Evision.Param.html#cv_BOOLEAN/0"},{"type":"function","title":"Evision.Param.cv_FLOAT/0","doc":"","ref":"Evision.Param.html#cv_FLOAT/0"},{"type":"function","title":"Evision.Param.cv_INT/0","doc":"","ref":"Evision.Param.html#cv_INT/0"},{"type":"function","title":"Evision.Param.cv_MAT/0","doc":"","ref":"Evision.Param.html#cv_MAT/0"},{"type":"function","title":"Evision.Param.cv_MAT_VECTOR/0","doc":"","ref":"Evision.Param.html#cv_MAT_VECTOR/0"},{"type":"function","title":"Evision.Param.cv_REAL/0","doc":"","ref":"Evision.Param.html#cv_REAL/0"},{"type":"function","title":"Evision.Param.cv_SCALAR/0","doc":"","ref":"Evision.Param.html#cv_SCALAR/0"},{"type":"function","title":"Evision.Param.cv_STRING/0","doc":"","ref":"Evision.Param.html#cv_STRING/0"},{"type":"function","title":"Evision.Param.cv_UCHAR/0","doc":"","ref":"Evision.Param.html#cv_UCHAR/0"},{"type":"function","title":"Evision.Param.cv_UINT64/0","doc":"","ref":"Evision.Param.html#cv_UINT64/0"},{"type":"function","title":"Evision.Param.cv_UNSIGNED_INT/0","doc":"","ref":"Evision.Param.html#cv_UNSIGNED_INT/0"},{"type":"type","title":"Evision.Param.enum/0","doc":"","ref":"Evision.Param.html#t:enum/0"},{"type":"module","title":"Evision.PhaseUnwrapping","doc":"","ref":"Evision.PhaseUnwrapping.html"},{"type":"type","title":"Evision.PhaseUnwrapping.t/0","doc":"Type that represents an `PhaseUnwrapping` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.PhaseUnwrapping.html#t:t/0"},{"type":"module","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping","doc":"","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.html"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.html#clear/1"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.create/0","doc":"Constructor\n##### Keyword Arguments\n- **parameters**: `Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params`.\n\n  HistogramPhaseUnwrapping parameters HistogramPhaseUnwrapping::Params: width,height of the phase map and histogram characteristics.\n\n##### Return\n- **retval**: `Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, parameters]) -> retval\n```","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.html#create/0"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.create/1","doc":"Constructor\n##### Keyword Arguments\n- **parameters**: `Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params`.\n\n  HistogramPhaseUnwrapping parameters HistogramPhaseUnwrapping::Params: width,height of the phase map and histogram characteristics.\n\n##### Return\n- **retval**: `Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, parameters]) -> retval\n```","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.html#create/1"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.html#empty/1"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.html#getDefaultName/1"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.getInverseReliabilityMap/1","doc":"Get the reliability map computed from the wrapped phase map.\n\n##### Positional Arguments\n- **self**: `Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.t()`\n\n##### Return\n- **reliabilityMap**: `Evision.Mat.t()`.\n\n  Image where the reliability map is stored.\n\nPython prototype (for reference only):\n```python3\ngetInverseReliabilityMap([, reliabilityMap]) -> reliabilityMap\n```","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.html#getInverseReliabilityMap/1"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.getInverseReliabilityMap/2","doc":"Get the reliability map computed from the wrapped phase map.\n\n##### Positional Arguments\n- **self**: `Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.t()`\n\n##### Return\n- **reliabilityMap**: `Evision.Mat.t()`.\n\n  Image where the reliability map is stored.\n\nPython prototype (for reference only):\n```python3\ngetInverseReliabilityMap([, reliabilityMap]) -> reliabilityMap\n```","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.html#getInverseReliabilityMap/2"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.read/1","doc":"","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.html#read/1"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.html#read/2"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.save/1","doc":"","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.html#save/1"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.html#save/2"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.unwrapPhaseMap/1","doc":"","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.html#unwrapPhaseMap/1"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.unwrapPhaseMap/2","doc":"Unwraps a 2D phase map.\n\n##### Positional Arguments\n- **self**: `Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.t()`\n- **wrappedPhaseMap**: `Evision.Mat`.\n\n  The wrapped phase map of type CV_32FC1 that needs to be unwrapped.\n\n##### Keyword Arguments\n- **shadowMask**: `Evision.Mat`.\n\n  Optional CV_8UC1 mask image used when some pixels do not hold any phase information in the wrapped phase map.\n\n##### Return\n- **unwrappedPhaseMap**: `Evision.Mat.t()`.\n\n  The unwrapped phase map.\n\nPython prototype (for reference only):\n```python3\nunwrapPhaseMap(wrappedPhaseMap[, unwrappedPhaseMap[, shadowMask]]) -> unwrappedPhaseMap\n```","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.html#unwrapPhaseMap/2"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.unwrapPhaseMap/3","doc":"Unwraps a 2D phase map.\n\n##### Positional Arguments\n- **self**: `Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.t()`\n- **wrappedPhaseMap**: `Evision.Mat`.\n\n  The wrapped phase map of type CV_32FC1 that needs to be unwrapped.\n\n##### Keyword Arguments\n- **shadowMask**: `Evision.Mat`.\n\n  Optional CV_8UC1 mask image used when some pixels do not hold any phase information in the wrapped phase map.\n\n##### Return\n- **unwrappedPhaseMap**: `Evision.Mat.t()`.\n\n  The unwrapped phase map.\n\nPython prototype (for reference only):\n```python3\nunwrapPhaseMap(wrappedPhaseMap[, unwrappedPhaseMap[, shadowMask]]) -> unwrappedPhaseMap\n```","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.html#unwrapPhaseMap/3"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.write/1","doc":"","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.html#write/1"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.html#write/2"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.html#write/3"},{"type":"type","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.t/0","doc":"Type that represents an `PhaseUnwrapping.HistogramPhaseUnwrapping` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.html#t:t/0"},{"type":"module","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params","doc":"","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.html"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.get_height/1","doc":"","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.html#get_height/1"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.get_histThresh/1","doc":"","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.html#get_histThresh/1"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.get_nbrOfLargeBins/1","doc":"","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.html#get_nbrOfLargeBins/1"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.get_nbrOfSmallBins/1","doc":"","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.html#get_nbrOfSmallBins/1"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.get_width/1","doc":"","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.html#get_width/1"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.phase_unwrapping_HistogramPhaseUnwrapping_Params/0","doc":"HistogramPhaseUnwrapping_Params\n##### Return\n- **self**: `Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.t()`\n\nPython prototype (for reference only):\n```python3\nHistogramPhaseUnwrapping_Params() ->  \n```","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.html#phase_unwrapping_HistogramPhaseUnwrapping_Params/0"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.phase_unwrapping_HistogramPhaseUnwrapping_Params/1","doc":"","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.html#phase_unwrapping_HistogramPhaseUnwrapping_Params/1"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.set_height/2","doc":"","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.html#set_height/2"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.set_histThresh/2","doc":"","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.html#set_histThresh/2"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.set_nbrOfLargeBins/2","doc":"","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.html#set_nbrOfLargeBins/2"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.set_nbrOfSmallBins/2","doc":"","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.html#set_nbrOfSmallBins/2"},{"type":"function","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.set_width/2","doc":"","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.html#set_width/2"},{"type":"type","title":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.t/0","doc":"Type that represents an `PhaseUnwrapping.HistogramPhaseUnwrapping.Params` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.PhaseUnwrapping.HistogramPhaseUnwrapping.Params.html#t:t/0"},{"type":"module","title":"Evision.PhaseUnwrapping.PhaseUnwrapping","doc":"","ref":"Evision.PhaseUnwrapping.PhaseUnwrapping.html"},{"type":"function","title":"Evision.PhaseUnwrapping.PhaseUnwrapping.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.PhaseUnwrapping.PhaseUnwrapping.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.PhaseUnwrapping.PhaseUnwrapping.html#clear/1"},{"type":"function","title":"Evision.PhaseUnwrapping.PhaseUnwrapping.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.PhaseUnwrapping.PhaseUnwrapping.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.PhaseUnwrapping.PhaseUnwrapping.html#empty/1"},{"type":"function","title":"Evision.PhaseUnwrapping.PhaseUnwrapping.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.PhaseUnwrapping.PhaseUnwrapping.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.PhaseUnwrapping.PhaseUnwrapping.html#getDefaultName/1"},{"type":"function","title":"Evision.PhaseUnwrapping.PhaseUnwrapping.read/1","doc":"","ref":"Evision.PhaseUnwrapping.PhaseUnwrapping.html#read/1"},{"type":"function","title":"Evision.PhaseUnwrapping.PhaseUnwrapping.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.PhaseUnwrapping.PhaseUnwrapping.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.PhaseUnwrapping.PhaseUnwrapping.html#read/2"},{"type":"function","title":"Evision.PhaseUnwrapping.PhaseUnwrapping.save/1","doc":"","ref":"Evision.PhaseUnwrapping.PhaseUnwrapping.html#save/1"},{"type":"function","title":"Evision.PhaseUnwrapping.PhaseUnwrapping.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.PhaseUnwrapping.PhaseUnwrapping.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.PhaseUnwrapping.PhaseUnwrapping.html#save/2"},{"type":"function","title":"Evision.PhaseUnwrapping.PhaseUnwrapping.unwrapPhaseMap/1","doc":"","ref":"Evision.PhaseUnwrapping.PhaseUnwrapping.html#unwrapPhaseMap/1"},{"type":"function","title":"Evision.PhaseUnwrapping.PhaseUnwrapping.unwrapPhaseMap/2","doc":"Unwraps a 2D phase map.\n\n##### Positional Arguments\n- **self**: `Evision.PhaseUnwrapping.PhaseUnwrapping.t()`\n- **wrappedPhaseMap**: `Evision.Mat`.\n\n  The wrapped phase map of type CV_32FC1 that needs to be unwrapped.\n\n##### Keyword Arguments\n- **shadowMask**: `Evision.Mat`.\n\n  Optional CV_8UC1 mask image used when some pixels do not hold any phase information in the wrapped phase map.\n\n##### Return\n- **unwrappedPhaseMap**: `Evision.Mat.t()`.\n\n  The unwrapped phase map.\n\nPython prototype (for reference only):\n```python3\nunwrapPhaseMap(wrappedPhaseMap[, unwrappedPhaseMap[, shadowMask]]) -> unwrappedPhaseMap\n```","ref":"Evision.PhaseUnwrapping.PhaseUnwrapping.html#unwrapPhaseMap/2"},{"type":"function","title":"Evision.PhaseUnwrapping.PhaseUnwrapping.unwrapPhaseMap/3","doc":"Unwraps a 2D phase map.\n\n##### Positional Arguments\n- **self**: `Evision.PhaseUnwrapping.PhaseUnwrapping.t()`\n- **wrappedPhaseMap**: `Evision.Mat`.\n\n  The wrapped phase map of type CV_32FC1 that needs to be unwrapped.\n\n##### Keyword Arguments\n- **shadowMask**: `Evision.Mat`.\n\n  Optional CV_8UC1 mask image used when some pixels do not hold any phase information in the wrapped phase map.\n\n##### Return\n- **unwrappedPhaseMap**: `Evision.Mat.t()`.\n\n  The unwrapped phase map.\n\nPython prototype (for reference only):\n```python3\nunwrapPhaseMap(wrappedPhaseMap[, unwrappedPhaseMap[, shadowMask]]) -> unwrappedPhaseMap\n```","ref":"Evision.PhaseUnwrapping.PhaseUnwrapping.html#unwrapPhaseMap/3"},{"type":"function","title":"Evision.PhaseUnwrapping.PhaseUnwrapping.write/1","doc":"","ref":"Evision.PhaseUnwrapping.PhaseUnwrapping.html#write/1"},{"type":"function","title":"Evision.PhaseUnwrapping.PhaseUnwrapping.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.PhaseUnwrapping.PhaseUnwrapping.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.PhaseUnwrapping.PhaseUnwrapping.html#write/2"},{"type":"function","title":"Evision.PhaseUnwrapping.PhaseUnwrapping.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.PhaseUnwrapping.PhaseUnwrapping.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.PhaseUnwrapping.PhaseUnwrapping.html#write/3"},{"type":"type","title":"Evision.PhaseUnwrapping.PhaseUnwrapping.t/0","doc":"Type that represents an `PhaseUnwrapping.PhaseUnwrapping` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.PhaseUnwrapping.PhaseUnwrapping.html#t:t/0"},{"type":"module","title":"Evision.Plot","doc":"","ref":"Evision.Plot.html"},{"type":"type","title":"Evision.Plot.t/0","doc":"Type that represents an `Plot` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Plot.html#t:t/0"},{"type":"module","title":"Evision.Plot.Plot2d","doc":"","ref":"Evision.Plot.Plot2d.html"},{"type":"function","title":"Evision.Plot.Plot2d.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Plot.Plot2d.html#clear/1"},{"type":"function","title":"Evision.Plot.Plot2d.create/1","doc":"Creates Plot2d object\n\n##### Positional Arguments\n- **data**: `Evision.Mat`.\n\n  \\f$1xN\\f$ or \\f$Nx1\\f$ matrix containing \\f$Y\\f$ values of points to plot. \\f$X\\f$ values\n  will be equal to indexes of correspondind elements in data matrix.\n\n##### Return\n- **retval**: `Plot2d`\n\nPython prototype (for reference only):\n```python3\ncreate(data) -> retval\n```","ref":"Evision.Plot.Plot2d.html#create/1"},{"type":"function","title":"Evision.Plot.Plot2d.create/2","doc":"Creates Plot2d object\n\n##### Positional Arguments\n- **dataX**: `Evision.Mat`.\n\n  \\f$1xN\\f$ or \\f$Nx1\\f$ matrix \\f$X\\f$ values of points to plot.\n\n- **dataY**: `Evision.Mat`.\n\n  \\f$1xN\\f$ or \\f$Nx1\\f$ matrix containing \\f$Y\\f$ values of points to plot.\n\n##### Return\n- **retval**: `Plot2d`\n\nPython prototype (for reference only):\n```python3\ncreate(dataX, dataY) -> retval\n```","ref":"Evision.Plot.Plot2d.html#create/2"},{"type":"function","title":"Evision.Plot.Plot2d.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Plot.Plot2d.html#empty/1"},{"type":"function","title":"Evision.Plot.Plot2d.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Plot.Plot2d.html#getDefaultName/1"},{"type":"function","title":"Evision.Plot.Plot2d.read/1","doc":"","ref":"Evision.Plot.Plot2d.html#read/1"},{"type":"function","title":"Evision.Plot.Plot2d.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Plot.Plot2d.html#read/2"},{"type":"function","title":"Evision.Plot.Plot2d.render/1","doc":"render\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n\n##### Return\n- **plotResult**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nrender([, _plotResult]) -> _plotResult\n```","ref":"Evision.Plot.Plot2d.html#render/1"},{"type":"function","title":"Evision.Plot.Plot2d.render/2","doc":"render\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n\n##### Return\n- **plotResult**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nrender([, _plotResult]) -> _plotResult\n```","ref":"Evision.Plot.Plot2d.html#render/2"},{"type":"function","title":"Evision.Plot.Plot2d.save/1","doc":"","ref":"Evision.Plot.Plot2d.html#save/1"},{"type":"function","title":"Evision.Plot.Plot2d.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Plot.Plot2d.html#save/2"},{"type":"function","title":"Evision.Plot.Plot2d.setGridLinesNumber/1","doc":"","ref":"Evision.Plot.Plot2d.html#setGridLinesNumber/1"},{"type":"function","title":"Evision.Plot.Plot2d.setGridLinesNumber/2","doc":"setGridLinesNumber\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n- **gridLinesNumber**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetGridLinesNumber(gridLinesNumber) -> None\n```","ref":"Evision.Plot.Plot2d.html#setGridLinesNumber/2"},{"type":"function","title":"Evision.Plot.Plot2d.setInvertOrientation/1","doc":"","ref":"Evision.Plot.Plot2d.html#setInvertOrientation/1"},{"type":"function","title":"Evision.Plot.Plot2d.setInvertOrientation/2","doc":"setInvertOrientation\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n- **invertOrientation**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetInvertOrientation(_invertOrientation) -> None\n```","ref":"Evision.Plot.Plot2d.html#setInvertOrientation/2"},{"type":"function","title":"Evision.Plot.Plot2d.setMaxX/1","doc":"","ref":"Evision.Plot.Plot2d.html#setMaxX/1"},{"type":"function","title":"Evision.Plot.Plot2d.setMaxX/2","doc":"setMaxX\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n- **plotMaxX**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxX(_plotMaxX) -> None\n```","ref":"Evision.Plot.Plot2d.html#setMaxX/2"},{"type":"function","title":"Evision.Plot.Plot2d.setMaxY/1","doc":"","ref":"Evision.Plot.Plot2d.html#setMaxY/1"},{"type":"function","title":"Evision.Plot.Plot2d.setMaxY/2","doc":"setMaxY\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n- **plotMaxY**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxY(_plotMaxY) -> None\n```","ref":"Evision.Plot.Plot2d.html#setMaxY/2"},{"type":"function","title":"Evision.Plot.Plot2d.setMinX/1","doc":"","ref":"Evision.Plot.Plot2d.html#setMinX/1"},{"type":"function","title":"Evision.Plot.Plot2d.setMinX/2","doc":"setMinX\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n- **plotMinX**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMinX(_plotMinX) -> None\n```","ref":"Evision.Plot.Plot2d.html#setMinX/2"},{"type":"function","title":"Evision.Plot.Plot2d.setMinY/1","doc":"","ref":"Evision.Plot.Plot2d.html#setMinY/1"},{"type":"function","title":"Evision.Plot.Plot2d.setMinY/2","doc":"setMinY\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n- **plotMinY**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMinY(_plotMinY) -> None\n```","ref":"Evision.Plot.Plot2d.html#setMinY/2"},{"type":"function","title":"Evision.Plot.Plot2d.setNeedPlotLine/1","doc":"","ref":"Evision.Plot.Plot2d.html#setNeedPlotLine/1"},{"type":"function","title":"Evision.Plot.Plot2d.setNeedPlotLine/2","doc":"Switches data visualization mode\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n- **needPlotLine**: `bool`.\n\n  if true then neighbour plot points will be connected by lines.\n  In other case data will be plotted as a set of standalone points.\n\nPython prototype (for reference only):\n```python3\nsetNeedPlotLine(_needPlotLine) -> None\n```","ref":"Evision.Plot.Plot2d.html#setNeedPlotLine/2"},{"type":"function","title":"Evision.Plot.Plot2d.setPlotAxisColor/1","doc":"","ref":"Evision.Plot.Plot2d.html#setPlotAxisColor/1"},{"type":"function","title":"Evision.Plot.Plot2d.setPlotAxisColor/2","doc":"setPlotAxisColor\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n- **plotAxisColor**: `Evision.scalar()`\n\nPython prototype (for reference only):\n```python3\nsetPlotAxisColor(_plotAxisColor) -> None\n```","ref":"Evision.Plot.Plot2d.html#setPlotAxisColor/2"},{"type":"function","title":"Evision.Plot.Plot2d.setPlotBackgroundColor/1","doc":"","ref":"Evision.Plot.Plot2d.html#setPlotBackgroundColor/1"},{"type":"function","title":"Evision.Plot.Plot2d.setPlotBackgroundColor/2","doc":"setPlotBackgroundColor\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n- **plotBackgroundColor**: `Evision.scalar()`\n\nPython prototype (for reference only):\n```python3\nsetPlotBackgroundColor(_plotBackgroundColor) -> None\n```","ref":"Evision.Plot.Plot2d.html#setPlotBackgroundColor/2"},{"type":"function","title":"Evision.Plot.Plot2d.setPlotGridColor/1","doc":"","ref":"Evision.Plot.Plot2d.html#setPlotGridColor/1"},{"type":"function","title":"Evision.Plot.Plot2d.setPlotGridColor/2","doc":"setPlotGridColor\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n- **plotGridColor**: `Evision.scalar()`\n\nPython prototype (for reference only):\n```python3\nsetPlotGridColor(_plotGridColor) -> None\n```","ref":"Evision.Plot.Plot2d.html#setPlotGridColor/2"},{"type":"function","title":"Evision.Plot.Plot2d.setPlotLineColor/1","doc":"","ref":"Evision.Plot.Plot2d.html#setPlotLineColor/1"},{"type":"function","title":"Evision.Plot.Plot2d.setPlotLineColor/2","doc":"setPlotLineColor\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n- **plotLineColor**: `Evision.scalar()`\n\nPython prototype (for reference only):\n```python3\nsetPlotLineColor(_plotLineColor) -> None\n```","ref":"Evision.Plot.Plot2d.html#setPlotLineColor/2"},{"type":"function","title":"Evision.Plot.Plot2d.setPlotLineWidth/1","doc":"","ref":"Evision.Plot.Plot2d.html#setPlotLineWidth/1"},{"type":"function","title":"Evision.Plot.Plot2d.setPlotLineWidth/2","doc":"setPlotLineWidth\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n- **plotLineWidth**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetPlotLineWidth(_plotLineWidth) -> None\n```","ref":"Evision.Plot.Plot2d.html#setPlotLineWidth/2"},{"type":"function","title":"Evision.Plot.Plot2d.setPlotSize/1","doc":"","ref":"Evision.Plot.Plot2d.html#setPlotSize/1"},{"type":"function","title":"Evision.Plot.Plot2d.setPlotSize/3","doc":"setPlotSize\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n- **plotSizeWidth**: `integer()`\n- **plotSizeHeight**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetPlotSize(_plotSizeWidth, _plotSizeHeight) -> None\n```","ref":"Evision.Plot.Plot2d.html#setPlotSize/3"},{"type":"function","title":"Evision.Plot.Plot2d.setPlotTextColor/1","doc":"","ref":"Evision.Plot.Plot2d.html#setPlotTextColor/1"},{"type":"function","title":"Evision.Plot.Plot2d.setPlotTextColor/2","doc":"setPlotTextColor\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n- **plotTextColor**: `Evision.scalar()`\n\nPython prototype (for reference only):\n```python3\nsetPlotTextColor(_plotTextColor) -> None\n```","ref":"Evision.Plot.Plot2d.html#setPlotTextColor/2"},{"type":"function","title":"Evision.Plot.Plot2d.setPointIdxToPrint/1","doc":"","ref":"Evision.Plot.Plot2d.html#setPointIdxToPrint/1"},{"type":"function","title":"Evision.Plot.Plot2d.setPointIdxToPrint/2","doc":"Sets the index of a point which coordinates will be printed on the top left corner of the plot (if ShowText flag is true).\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n- **pointIdx**: `integer()`.\n\n  index of the required point in data array.\n\nPython prototype (for reference only):\n```python3\nsetPointIdxToPrint(pointIdx) -> None\n```","ref":"Evision.Plot.Plot2d.html#setPointIdxToPrint/2"},{"type":"function","title":"Evision.Plot.Plot2d.setShowGrid/1","doc":"","ref":"Evision.Plot.Plot2d.html#setShowGrid/1"},{"type":"function","title":"Evision.Plot.Plot2d.setShowGrid/2","doc":"setShowGrid\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n- **needShowGrid**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetShowGrid(needShowGrid) -> None\n```","ref":"Evision.Plot.Plot2d.html#setShowGrid/2"},{"type":"function","title":"Evision.Plot.Plot2d.setShowText/1","doc":"","ref":"Evision.Plot.Plot2d.html#setShowText/1"},{"type":"function","title":"Evision.Plot.Plot2d.setShowText/2","doc":"setShowText\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n- **needShowText**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetShowText(needShowText) -> None\n```","ref":"Evision.Plot.Plot2d.html#setShowText/2"},{"type":"function","title":"Evision.Plot.Plot2d.write/1","doc":"","ref":"Evision.Plot.Plot2d.html#write/1"},{"type":"function","title":"Evision.Plot.Plot2d.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Plot.Plot2d.html#write/2"},{"type":"function","title":"Evision.Plot.Plot2d.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Plot.Plot2d.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Plot.Plot2d.html#write/3"},{"type":"type","title":"Evision.Plot.Plot2d.t/0","doc":"Type that represents an `Plot.Plot2d` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Plot.Plot2d.html#t:t/0"},{"type":"module","title":"Evision.PolishingMethod","doc":"","ref":"Evision.PolishingMethod.html"},{"type":"function","title":"Evision.PolishingMethod.cv_COV_POLISHER/0","doc":"","ref":"Evision.PolishingMethod.html#cv_COV_POLISHER/0"},{"type":"function","title":"Evision.PolishingMethod.cv_LSQ_POLISHER/0","doc":"","ref":"Evision.PolishingMethod.html#cv_LSQ_POLISHER/0"},{"type":"function","title":"Evision.PolishingMethod.cv_MAGSAC/0","doc":"","ref":"Evision.PolishingMethod.html#cv_MAGSAC/0"},{"type":"function","title":"Evision.PolishingMethod.cv_NONE_POLISHER/0","doc":"","ref":"Evision.PolishingMethod.html#cv_NONE_POLISHER/0"},{"type":"type","title":"Evision.PolishingMethod.enum/0","doc":"","ref":"Evision.PolishingMethod.html#t:enum/0"},{"type":"module","title":"Evision.PyRotationWarper","doc":"","ref":"Evision.PyRotationWarper.html"},{"type":"function","title":"Evision.PyRotationWarper.buildMaps/1","doc":"","ref":"Evision.PyRotationWarper.html#buildMaps/1"},{"type":"function","title":"Evision.PyRotationWarper.buildMaps/4","doc":"Builds the projection maps according to the given camera data.\n\n##### Positional Arguments\n- **self**: `Evision.PyRotationWarper.t()`\n- **src_size**: `Size`.\n\n  Source image size\n\n- **k**: `Evision.Mat`.\n\n  Camera intrinsic parameters\n\n- **r**: `Evision.Mat`.\n\n  Camera rotation matrix\n\n##### Return\n- **retval**: `Rect`\n- **xmap**: `Evision.Mat.t()`.\n\n  Projection map for the x axis\n\n- **ymap**: `Evision.Mat.t()`.\n\n  Projection map for the y axis\n\n@return Projected image minimum bounding box\n\nPython prototype (for reference only):\n```python3\nbuildMaps(src_size, K, R[, xmap[, ymap]]) -> retval, xmap, ymap\n```","ref":"Evision.PyRotationWarper.html#buildMaps/4"},{"type":"function","title":"Evision.PyRotationWarper.buildMaps/5","doc":"Builds the projection maps according to the given camera data.\n\n##### Positional Arguments\n- **self**: `Evision.PyRotationWarper.t()`\n- **src_size**: `Size`.\n\n  Source image size\n\n- **k**: `Evision.Mat`.\n\n  Camera intrinsic parameters\n\n- **r**: `Evision.Mat`.\n\n  Camera rotation matrix\n\n##### Return\n- **retval**: `Rect`\n- **xmap**: `Evision.Mat.t()`.\n\n  Projection map for the x axis\n\n- **ymap**: `Evision.Mat.t()`.\n\n  Projection map for the y axis\n\n@return Projected image minimum bounding box\n\nPython prototype (for reference only):\n```python3\nbuildMaps(src_size, K, R[, xmap[, ymap]]) -> retval, xmap, ymap\n```","ref":"Evision.PyRotationWarper.html#buildMaps/5"},{"type":"function","title":"Evision.PyRotationWarper.getScale/1","doc":"getScale\n\n##### Positional Arguments\n- **self**: `Evision.PyRotationWarper.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetScale() -> retval\n```","ref":"Evision.PyRotationWarper.html#getScale/1"},{"type":"function","title":"Evision.PyRotationWarper.pyRotationWarper/0","doc":"PyRotationWarper\n##### Return\n- **self**: `Evision.PyRotationWarper.t()`\n\nPython prototype (for reference only):\n```python3\nPyRotationWarper() ->  \n```","ref":"Evision.PyRotationWarper.html#pyRotationWarper/0"},{"type":"function","title":"Evision.PyRotationWarper.pyRotationWarper/1","doc":"","ref":"Evision.PyRotationWarper.html#pyRotationWarper/1"},{"type":"function","title":"Evision.PyRotationWarper.pyRotationWarper/2","doc":"PyRotationWarper\n\n##### Positional Arguments\n- **type**: `String`\n- **scale**: `float`\n\n##### Return\n- **self**: `Evision.PyRotationWarper.t()`\n\nPython prototype (for reference only):\n```python3\nPyRotationWarper(type, scale) ->  \n```","ref":"Evision.PyRotationWarper.html#pyRotationWarper/2"},{"type":"function","title":"Evision.PyRotationWarper.setScale/1","doc":"","ref":"Evision.PyRotationWarper.html#setScale/1"},{"type":"function","title":"Evision.PyRotationWarper.setScale/2","doc":"setScale\n\n##### Positional Arguments\n- **self**: `Evision.PyRotationWarper.t()`\n- **arg1**: `float`\n\nPython prototype (for reference only):\n```python3\nsetScale(arg1) -> None\n```","ref":"Evision.PyRotationWarper.html#setScale/2"},{"type":"function","title":"Evision.PyRotationWarper.warp/1","doc":"","ref":"Evision.PyRotationWarper.html#warp/1"},{"type":"function","title":"Evision.PyRotationWarper.warp/6","doc":"Projects the image.\n\n##### Positional Arguments\n- **self**: `Evision.PyRotationWarper.t()`\n- **src**: `Evision.Mat`.\n\n  Source image\n\n- **k**: `Evision.Mat`.\n\n  Camera intrinsic parameters\n\n- **r**: `Evision.Mat`.\n\n  Camera rotation matrix\n\n- **interp_mode**: `integer()`.\n\n  Interpolation mode\n\n- **border_mode**: `integer()`.\n\n  Border extrapolation mode\n\n##### Return\n- **retval**: `Point`\n- **dst**: `Evision.Mat.t()`.\n\n  Projected image\n\n@return Project image top-left corner\n\nPython prototype (for reference only):\n```python3\nwarp(src, K, R, interp_mode, border_mode[, dst]) -> retval, dst\n```","ref":"Evision.PyRotationWarper.html#warp/6"},{"type":"function","title":"Evision.PyRotationWarper.warp/7","doc":"Projects the image.\n\n##### Positional Arguments\n- **self**: `Evision.PyRotationWarper.t()`\n- **src**: `Evision.Mat`.\n\n  Source image\n\n- **k**: `Evision.Mat`.\n\n  Camera intrinsic parameters\n\n- **r**: `Evision.Mat`.\n\n  Camera rotation matrix\n\n- **interp_mode**: `integer()`.\n\n  Interpolation mode\n\n- **border_mode**: `integer()`.\n\n  Border extrapolation mode\n\n##### Return\n- **retval**: `Point`\n- **dst**: `Evision.Mat.t()`.\n\n  Projected image\n\n@return Project image top-left corner\n\nPython prototype (for reference only):\n```python3\nwarp(src, K, R, interp_mode, border_mode[, dst]) -> retval, dst\n```","ref":"Evision.PyRotationWarper.html#warp/7"},{"type":"function","title":"Evision.PyRotationWarper.warpBackward/1","doc":"","ref":"Evision.PyRotationWarper.html#warpBackward/1"},{"type":"function","title":"Evision.PyRotationWarper.warpBackward/7","doc":"Projects the image backward.\n\n##### Positional Arguments\n- **self**: `Evision.PyRotationWarper.t()`\n- **src**: `Evision.Mat`.\n\n  Projected image\n\n- **k**: `Evision.Mat`.\n\n  Camera intrinsic parameters\n\n- **r**: `Evision.Mat`.\n\n  Camera rotation matrix\n\n- **interp_mode**: `integer()`.\n\n  Interpolation mode\n\n- **border_mode**: `integer()`.\n\n  Border extrapolation mode\n\n- **dst_size**: `Size`.\n\n  Backward-projected image size\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Backward-projected image\n\nPython prototype (for reference only):\n```python3\nwarpBackward(src, K, R, interp_mode, border_mode, dst_size[, dst]) -> dst\n```","ref":"Evision.PyRotationWarper.html#warpBackward/7"},{"type":"function","title":"Evision.PyRotationWarper.warpBackward/8","doc":"Projects the image backward.\n\n##### Positional Arguments\n- **self**: `Evision.PyRotationWarper.t()`\n- **src**: `Evision.Mat`.\n\n  Projected image\n\n- **k**: `Evision.Mat`.\n\n  Camera intrinsic parameters\n\n- **r**: `Evision.Mat`.\n\n  Camera rotation matrix\n\n- **interp_mode**: `integer()`.\n\n  Interpolation mode\n\n- **border_mode**: `integer()`.\n\n  Border extrapolation mode\n\n- **dst_size**: `Size`.\n\n  Backward-projected image size\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Backward-projected image\n\nPython prototype (for reference only):\n```python3\nwarpBackward(src, K, R, interp_mode, border_mode, dst_size[, dst]) -> dst\n```","ref":"Evision.PyRotationWarper.html#warpBackward/8"},{"type":"function","title":"Evision.PyRotationWarper.warpPoint/1","doc":"","ref":"Evision.PyRotationWarper.html#warpPoint/1"},{"type":"function","title":"Evision.PyRotationWarper.warpPoint/4","doc":"Projects the image point.\n\n##### Positional Arguments\n- **self**: `Evision.PyRotationWarper.t()`\n- **pt**: `Point2f`.\n\n  Source point\n\n- **k**: `Evision.Mat`.\n\n  Camera intrinsic parameters\n\n- **r**: `Evision.Mat`.\n\n  Camera rotation matrix\n\n##### Return\n- **retval**: `Point2f`\n\n@return Projected point\n\nPython prototype (for reference only):\n```python3\nwarpPoint(pt, K, R) -> retval\n```","ref":"Evision.PyRotationWarper.html#warpPoint/4"},{"type":"function","title":"Evision.PyRotationWarper.warpPointBackward/1","doc":"","ref":"Evision.PyRotationWarper.html#warpPointBackward/1"},{"type":"function","title":"Evision.PyRotationWarper.warpPointBackward/4","doc":"warpPointBackward\n\n##### Positional Arguments\n- **self**: `Evision.PyRotationWarper.t()`\n- **pt**: `Point2f`\n- **k**: `Evision.Mat`\n- **r**: `Evision.Mat`\n\n##### Return\n- **retval**: `Point2f`\n\nPython prototype (for reference only):\n```python3\nwarpPointBackward(pt, K, R) -> retval\n```","ref":"Evision.PyRotationWarper.html#warpPointBackward/4"},{"type":"function","title":"Evision.PyRotationWarper.warpRoi/1","doc":"","ref":"Evision.PyRotationWarper.html#warpRoi/1"},{"type":"function","title":"Evision.PyRotationWarper.warpRoi/4","doc":"warpRoi\n\n##### Positional Arguments\n- **self**: `Evision.PyRotationWarper.t()`\n- **src_size**: `Size`.\n\n  Source image bounding box\n\n- **k**: `Evision.Mat`.\n\n  Camera intrinsic parameters\n\n- **r**: `Evision.Mat`.\n\n  Camera rotation matrix\n\n##### Return\n- **retval**: `Rect`\n\n@return Projected image minimum bounding box\n\nPython prototype (for reference only):\n```python3\nwarpRoi(src_size, K, R) -> retval\n```","ref":"Evision.PyRotationWarper.html#warpRoi/4"},{"type":"type","title":"Evision.PyRotationWarper.t/0","doc":"Type that represents an `PyRotationWarper` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.PyRotationWarper.html#t:t/0"},{"type":"module","title":"Evision.QRCodeDetector","doc":"","ref":"Evision.QRCodeDetector.html"},{"type":"function","title":"Evision.QRCodeDetector.decode/1","doc":"","ref":"Evision.QRCodeDetector.html#decode/1"},{"type":"function","title":"Evision.QRCodeDetector.decode/3","doc":"Decodes graphical code in image once it's found by the detect() method.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical code.\n\n- **points**: `Evision.Mat`.\n\n  Quadrangle vertices found by detect() method (or some other algorithm).\n\n##### Return\n- **retval**: `string`\n- **straight_code**: `Evision.Mat.t()`.\n\n  The optional output image containing binarized code, will be empty if not found.\n\nReturns UTF8-encoded output string or empty string if the code cannot be decoded.\n\nPython prototype (for reference only):\n```python3\ndecode(img, points[, straight_code]) -> retval, straight_code\n```","ref":"Evision.QRCodeDetector.html#decode/3"},{"type":"function","title":"Evision.QRCodeDetector.decode/4","doc":"Decodes graphical code in image once it's found by the detect() method.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical code.\n\n- **points**: `Evision.Mat`.\n\n  Quadrangle vertices found by detect() method (or some other algorithm).\n\n##### Return\n- **retval**: `string`\n- **straight_code**: `Evision.Mat.t()`.\n\n  The optional output image containing binarized code, will be empty if not found.\n\nReturns UTF8-encoded output string or empty string if the code cannot be decoded.\n\nPython prototype (for reference only):\n```python3\ndecode(img, points[, straight_code]) -> retval, straight_code\n```","ref":"Evision.QRCodeDetector.html#decode/4"},{"type":"function","title":"Evision.QRCodeDetector.decodeCurved/1","doc":"","ref":"Evision.QRCodeDetector.html#decodeCurved/1"},{"type":"function","title":"Evision.QRCodeDetector.decodeCurved/3","doc":"Decodes QR code on a curved surface in image once it's found by the detect() method.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing QR code.\n\n- **points**: `Evision.Mat`.\n\n  Quadrangle vertices found by detect() method (or some other algorithm).\n\n##### Return\n- **retval**: `String`\n- **straight_qrcode**: `Evision.Mat.t()`.\n\n  The optional output image containing rectified and binarized QR code\n\nReturns UTF8-encoded output string or empty string if the code cannot be decoded.\n\nPython prototype (for reference only):\n```python3\ndecodeCurved(img, points[, straight_qrcode]) -> retval, straight_qrcode\n```","ref":"Evision.QRCodeDetector.html#decodeCurved/3"},{"type":"function","title":"Evision.QRCodeDetector.decodeCurved/4","doc":"Decodes QR code on a curved surface in image once it's found by the detect() method.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing QR code.\n\n- **points**: `Evision.Mat`.\n\n  Quadrangle vertices found by detect() method (or some other algorithm).\n\n##### Return\n- **retval**: `String`\n- **straight_qrcode**: `Evision.Mat.t()`.\n\n  The optional output image containing rectified and binarized QR code\n\nReturns UTF8-encoded output string or empty string if the code cannot be decoded.\n\nPython prototype (for reference only):\n```python3\ndecodeCurved(img, points[, straight_qrcode]) -> retval, straight_qrcode\n```","ref":"Evision.QRCodeDetector.html#decodeCurved/4"},{"type":"function","title":"Evision.QRCodeDetector.decodeMulti/1","doc":"","ref":"Evision.QRCodeDetector.html#decodeMulti/1"},{"type":"function","title":"Evision.QRCodeDetector.decodeMulti/3","doc":"Decodes graphical codes in image once it's found by the detect() method.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical codes.\n\n- **points**: `Evision.Mat`.\n\n  vector of Quadrangle vertices found by detect() method (or some other algorithm).\n\n##### Return\n- **retval**: `bool`\n- **decoded_info**: `[string]`.\n\n  UTF8-encoded output vector of string or empty vector of string if the codes cannot be decoded.\n\n- **straight_code**: `[Evision.Mat]`.\n\n  The optional output vector of images containing binarized codes\n\nPython prototype (for reference only):\n```python3\ndecodeMulti(img, points[, straight_code]) -> retval, decoded_info, straight_code\n```","ref":"Evision.QRCodeDetector.html#decodeMulti/3"},{"type":"function","title":"Evision.QRCodeDetector.decodeMulti/4","doc":"Decodes graphical codes in image once it's found by the detect() method.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical codes.\n\n- **points**: `Evision.Mat`.\n\n  vector of Quadrangle vertices found by detect() method (or some other algorithm).\n\n##### Return\n- **retval**: `bool`\n- **decoded_info**: `[string]`.\n\n  UTF8-encoded output vector of string or empty vector of string if the codes cannot be decoded.\n\n- **straight_code**: `[Evision.Mat]`.\n\n  The optional output vector of images containing binarized codes\n\nPython prototype (for reference only):\n```python3\ndecodeMulti(img, points[, straight_code]) -> retval, decoded_info, straight_code\n```","ref":"Evision.QRCodeDetector.html#decodeMulti/4"},{"type":"function","title":"Evision.QRCodeDetector.detect/1","doc":"","ref":"Evision.QRCodeDetector.html#detect/1"},{"type":"function","title":"Evision.QRCodeDetector.detect/2","doc":"Detects graphical code in image and returns the quadrangle containing the code.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing (or not) graphical code.\n\n##### Return\n- **retval**: `bool`\n- **points**: `Evision.Mat.t()`.\n\n  Output vector of vertices of the minimum-area quadrangle containing the code.\n\nPython prototype (for reference only):\n```python3\ndetect(img[, points]) -> retval, points\n```","ref":"Evision.QRCodeDetector.html#detect/2"},{"type":"function","title":"Evision.QRCodeDetector.detect/3","doc":"Detects graphical code in image and returns the quadrangle containing the code.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing (or not) graphical code.\n\n##### Return\n- **retval**: `bool`\n- **points**: `Evision.Mat.t()`.\n\n  Output vector of vertices of the minimum-area quadrangle containing the code.\n\nPython prototype (for reference only):\n```python3\ndetect(img[, points]) -> retval, points\n```","ref":"Evision.QRCodeDetector.html#detect/3"},{"type":"function","title":"Evision.QRCodeDetector.detectAndDecode/1","doc":"","ref":"Evision.QRCodeDetector.html#detectAndDecode/1"},{"type":"function","title":"Evision.QRCodeDetector.detectAndDecode/2","doc":"Both detects and decodes graphical code\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical code.\n\n##### Return\n- **retval**: `string`\n- **points**: `Evision.Mat.t()`.\n\n  optional output array of vertices of the found graphical code quadrangle, will be empty if not found.\n\n- **straight_code**: `Evision.Mat.t()`.\n\n  The optional output image containing binarized code\n\nPython prototype (for reference only):\n```python3\ndetectAndDecode(img[, points[, straight_code]]) -> retval, points, straight_code\n```","ref":"Evision.QRCodeDetector.html#detectAndDecode/2"},{"type":"function","title":"Evision.QRCodeDetector.detectAndDecode/3","doc":"Both detects and decodes graphical code\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical code.\n\n##### Return\n- **retval**: `string`\n- **points**: `Evision.Mat.t()`.\n\n  optional output array of vertices of the found graphical code quadrangle, will be empty if not found.\n\n- **straight_code**: `Evision.Mat.t()`.\n\n  The optional output image containing binarized code\n\nPython prototype (for reference only):\n```python3\ndetectAndDecode(img[, points[, straight_code]]) -> retval, points, straight_code\n```","ref":"Evision.QRCodeDetector.html#detectAndDecode/3"},{"type":"function","title":"Evision.QRCodeDetector.detectAndDecodeCurved/1","doc":"","ref":"Evision.QRCodeDetector.html#detectAndDecodeCurved/1"},{"type":"function","title":"Evision.QRCodeDetector.detectAndDecodeCurved/2","doc":"Both detects and decodes QR code on a curved surface\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing QR code.\n\n##### Return\n- **retval**: `string`\n- **points**: `Evision.Mat.t()`.\n\n  optional output array of vertices of the found QR code quadrangle. Will be empty if not found.\n\n- **straight_qrcode**: `Evision.Mat.t()`.\n\n  The optional output image containing rectified and binarized QR code\n\nPython prototype (for reference only):\n```python3\ndetectAndDecodeCurved(img[, points[, straight_qrcode]]) -> retval, points, straight_qrcode\n```","ref":"Evision.QRCodeDetector.html#detectAndDecodeCurved/2"},{"type":"function","title":"Evision.QRCodeDetector.detectAndDecodeCurved/3","doc":"Both detects and decodes QR code on a curved surface\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing QR code.\n\n##### Return\n- **retval**: `string`\n- **points**: `Evision.Mat.t()`.\n\n  optional output array of vertices of the found QR code quadrangle. Will be empty if not found.\n\n- **straight_qrcode**: `Evision.Mat.t()`.\n\n  The optional output image containing rectified and binarized QR code\n\nPython prototype (for reference only):\n```python3\ndetectAndDecodeCurved(img[, points[, straight_qrcode]]) -> retval, points, straight_qrcode\n```","ref":"Evision.QRCodeDetector.html#detectAndDecodeCurved/3"},{"type":"function","title":"Evision.QRCodeDetector.detectAndDecodeMulti/1","doc":"","ref":"Evision.QRCodeDetector.html#detectAndDecodeMulti/1"},{"type":"function","title":"Evision.QRCodeDetector.detectAndDecodeMulti/2","doc":"Both detects and decodes graphical codes\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical codes.\n\n##### Return\n- **retval**: `bool`\n- **decoded_info**: `[string]`.\n\n  UTF8-encoded output vector of string or empty vector of string if the codes cannot be decoded.\n\n- **points**: `Evision.Mat.t()`.\n\n  optional output vector of vertices of the found graphical code quadrangles. Will be empty if not found.\n\n- **straight_code**: `[Evision.Mat]`.\n\n  The optional vector of images containing binarized codes\n\n- If there are QR codes encoded with a Structured Append mode on the image and all of them detected and decoded correctly,\n  method writes a full message to position corresponds to 0-th code in a sequence. The rest of QR codes from the same sequence\n  have empty string.\n\nPython prototype (for reference only):\n```python3\ndetectAndDecodeMulti(img[, points[, straight_code]]) -> retval, decoded_info, points, straight_code\n```","ref":"Evision.QRCodeDetector.html#detectAndDecodeMulti/2"},{"type":"function","title":"Evision.QRCodeDetector.detectAndDecodeMulti/3","doc":"Both detects and decodes graphical codes\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical codes.\n\n##### Return\n- **retval**: `bool`\n- **decoded_info**: `[string]`.\n\n  UTF8-encoded output vector of string or empty vector of string if the codes cannot be decoded.\n\n- **points**: `Evision.Mat.t()`.\n\n  optional output vector of vertices of the found graphical code quadrangles. Will be empty if not found.\n\n- **straight_code**: `[Evision.Mat]`.\n\n  The optional vector of images containing binarized codes\n\n- If there are QR codes encoded with a Structured Append mode on the image and all of them detected and decoded correctly,\n  method writes a full message to position corresponds to 0-th code in a sequence. The rest of QR codes from the same sequence\n  have empty string.\n\nPython prototype (for reference only):\n```python3\ndetectAndDecodeMulti(img[, points[, straight_code]]) -> retval, decoded_info, points, straight_code\n```","ref":"Evision.QRCodeDetector.html#detectAndDecodeMulti/3"},{"type":"function","title":"Evision.QRCodeDetector.detectMulti/1","doc":"","ref":"Evision.QRCodeDetector.html#detectMulti/1"},{"type":"function","title":"Evision.QRCodeDetector.detectMulti/2","doc":"Detects graphical codes in image and returns the vector of the quadrangles containing the codes.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing (or not) graphical codes.\n\n##### Return\n- **retval**: `bool`\n- **points**: `Evision.Mat.t()`.\n\n  Output vector of vector of vertices of the minimum-area quadrangle containing the codes.\n\nPython prototype (for reference only):\n```python3\ndetectMulti(img[, points]) -> retval, points\n```","ref":"Evision.QRCodeDetector.html#detectMulti/2"},{"type":"function","title":"Evision.QRCodeDetector.detectMulti/3","doc":"Detects graphical codes in image and returns the vector of the quadrangles containing the codes.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetector.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing (or not) graphical codes.\n\n##### Return\n- **retval**: `bool`\n- **points**: `Evision.Mat.t()`.\n\n  Output vector of vector of vertices of the minimum-area quadrangle containing the codes.\n\nPython prototype (for reference only):\n```python3\ndetectMulti(img[, points]) -> retval, points\n```","ref":"Evision.QRCodeDetector.html#detectMulti/3"},{"type":"function","title":"Evision.QRCodeDetector.qrCodeDetector/0","doc":"QRCodeDetector\n##### Return\n- **self**: `Evision.QRCodeDetector.t()`\n\nPython prototype (for reference only):\n```python3\nQRCodeDetector() ->  \n```","ref":"Evision.QRCodeDetector.html#qrCodeDetector/0"},{"type":"function","title":"Evision.QRCodeDetector.qrCodeDetector/1","doc":"","ref":"Evision.QRCodeDetector.html#qrCodeDetector/1"},{"type":"function","title":"Evision.QRCodeDetector.setEpsX/1","doc":"","ref":"Evision.QRCodeDetector.html#setEpsX/1"},{"type":"function","title":"Evision.QRCodeDetector.setEpsX/2","doc":"sets the epsilon used during the horizontal scan of QR code stop marker detection.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetector.t()`\n- **epsX**: `double`.\n\n  Epsilon neighborhood, which allows you to determine the horizontal pattern\n  of the scheme 1:1:3:1:1 according to QR code standard.\n\n##### Return\n- **retval**: `Evision.QRCodeDetector.t()`\n\nPython prototype (for reference only):\n```python3\nsetEpsX(epsX) -> retval\n```","ref":"Evision.QRCodeDetector.html#setEpsX/2"},{"type":"function","title":"Evision.QRCodeDetector.setEpsY/1","doc":"","ref":"Evision.QRCodeDetector.html#setEpsY/1"},{"type":"function","title":"Evision.QRCodeDetector.setEpsY/2","doc":"sets the epsilon used during the vertical scan of QR code stop marker detection.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetector.t()`\n- **epsY**: `double`.\n\n  Epsilon neighborhood, which allows you to determine the vertical pattern\n  of the scheme 1:1:3:1:1 according to QR code standard.\n\n##### Return\n- **retval**: `Evision.QRCodeDetector.t()`\n\nPython prototype (for reference only):\n```python3\nsetEpsY(epsY) -> retval\n```","ref":"Evision.QRCodeDetector.html#setEpsY/2"},{"type":"function","title":"Evision.QRCodeDetector.setUseAlignmentMarkers/1","doc":"","ref":"Evision.QRCodeDetector.html#setUseAlignmentMarkers/1"},{"type":"function","title":"Evision.QRCodeDetector.setUseAlignmentMarkers/2","doc":"use markers to improve the position of the corners of the QR code\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetector.t()`\n- **useAlignmentMarkers**: `bool`\n\n##### Return\n- **retval**: `Evision.QRCodeDetector.t()`\n\n alignmentMarkers using by default\n\nPython prototype (for reference only):\n```python3\nsetUseAlignmentMarkers(useAlignmentMarkers) -> retval\n```","ref":"Evision.QRCodeDetector.html#setUseAlignmentMarkers/2"},{"type":"type","title":"Evision.QRCodeDetector.t/0","doc":"Type that represents an `QRCodeDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.QRCodeDetector.html#t:t/0"},{"type":"module","title":"Evision.QRCodeDetectorAruco","doc":"","ref":"Evision.QRCodeDetectorAruco.html"},{"type":"function","title":"Evision.QRCodeDetectorAruco.decode/1","doc":"","ref":"Evision.QRCodeDetectorAruco.html#decode/1"},{"type":"function","title":"Evision.QRCodeDetectorAruco.decode/3","doc":"Decodes graphical code in image once it's found by the detect() method.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetectorAruco.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical code.\n\n- **points**: `Evision.Mat`.\n\n  Quadrangle vertices found by detect() method (or some other algorithm).\n\n##### Return\n- **retval**: `string`\n- **straight_code**: `Evision.Mat.t()`.\n\n  The optional output image containing binarized code, will be empty if not found.\n\nReturns UTF8-encoded output string or empty string if the code cannot be decoded.\n\nPython prototype (for reference only):\n```python3\ndecode(img, points[, straight_code]) -> retval, straight_code\n```","ref":"Evision.QRCodeDetectorAruco.html#decode/3"},{"type":"function","title":"Evision.QRCodeDetectorAruco.decode/4","doc":"Decodes graphical code in image once it's found by the detect() method.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetectorAruco.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical code.\n\n- **points**: `Evision.Mat`.\n\n  Quadrangle vertices found by detect() method (or some other algorithm).\n\n##### Return\n- **retval**: `string`\n- **straight_code**: `Evision.Mat.t()`.\n\n  The optional output image containing binarized code, will be empty if not found.\n\nReturns UTF8-encoded output string or empty string if the code cannot be decoded.\n\nPython prototype (for reference only):\n```python3\ndecode(img, points[, straight_code]) -> retval, straight_code\n```","ref":"Evision.QRCodeDetectorAruco.html#decode/4"},{"type":"function","title":"Evision.QRCodeDetectorAruco.decodeMulti/1","doc":"","ref":"Evision.QRCodeDetectorAruco.html#decodeMulti/1"},{"type":"function","title":"Evision.QRCodeDetectorAruco.decodeMulti/3","doc":"Decodes graphical codes in image once it's found by the detect() method.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetectorAruco.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical codes.\n\n- **points**: `Evision.Mat`.\n\n  vector of Quadrangle vertices found by detect() method (or some other algorithm).\n\n##### Return\n- **retval**: `bool`\n- **decoded_info**: `[string]`.\n\n  UTF8-encoded output vector of string or empty vector of string if the codes cannot be decoded.\n\n- **straight_code**: `[Evision.Mat]`.\n\n  The optional output vector of images containing binarized codes\n\nPython prototype (for reference only):\n```python3\ndecodeMulti(img, points[, straight_code]) -> retval, decoded_info, straight_code\n```","ref":"Evision.QRCodeDetectorAruco.html#decodeMulti/3"},{"type":"function","title":"Evision.QRCodeDetectorAruco.decodeMulti/4","doc":"Decodes graphical codes in image once it's found by the detect() method.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetectorAruco.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical codes.\n\n- **points**: `Evision.Mat`.\n\n  vector of Quadrangle vertices found by detect() method (or some other algorithm).\n\n##### Return\n- **retval**: `bool`\n- **decoded_info**: `[string]`.\n\n  UTF8-encoded output vector of string or empty vector of string if the codes cannot be decoded.\n\n- **straight_code**: `[Evision.Mat]`.\n\n  The optional output vector of images containing binarized codes\n\nPython prototype (for reference only):\n```python3\ndecodeMulti(img, points[, straight_code]) -> retval, decoded_info, straight_code\n```","ref":"Evision.QRCodeDetectorAruco.html#decodeMulti/4"},{"type":"function","title":"Evision.QRCodeDetectorAruco.detect/1","doc":"","ref":"Evision.QRCodeDetectorAruco.html#detect/1"},{"type":"function","title":"Evision.QRCodeDetectorAruco.detect/2","doc":"Detects graphical code in image and returns the quadrangle containing the code.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetectorAruco.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing (or not) graphical code.\n\n##### Return\n- **retval**: `bool`\n- **points**: `Evision.Mat.t()`.\n\n  Output vector of vertices of the minimum-area quadrangle containing the code.\n\nPython prototype (for reference only):\n```python3\ndetect(img[, points]) -> retval, points\n```","ref":"Evision.QRCodeDetectorAruco.html#detect/2"},{"type":"function","title":"Evision.QRCodeDetectorAruco.detect/3","doc":"Detects graphical code in image and returns the quadrangle containing the code.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetectorAruco.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing (or not) graphical code.\n\n##### Return\n- **retval**: `bool`\n- **points**: `Evision.Mat.t()`.\n\n  Output vector of vertices of the minimum-area quadrangle containing the code.\n\nPython prototype (for reference only):\n```python3\ndetect(img[, points]) -> retval, points\n```","ref":"Evision.QRCodeDetectorAruco.html#detect/3"},{"type":"function","title":"Evision.QRCodeDetectorAruco.detectAndDecode/1","doc":"","ref":"Evision.QRCodeDetectorAruco.html#detectAndDecode/1"},{"type":"function","title":"Evision.QRCodeDetectorAruco.detectAndDecode/2","doc":"Both detects and decodes graphical code\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetectorAruco.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical code.\n\n##### Return\n- **retval**: `string`\n- **points**: `Evision.Mat.t()`.\n\n  optional output array of vertices of the found graphical code quadrangle, will be empty if not found.\n\n- **straight_code**: `Evision.Mat.t()`.\n\n  The optional output image containing binarized code\n\nPython prototype (for reference only):\n```python3\ndetectAndDecode(img[, points[, straight_code]]) -> retval, points, straight_code\n```","ref":"Evision.QRCodeDetectorAruco.html#detectAndDecode/2"},{"type":"function","title":"Evision.QRCodeDetectorAruco.detectAndDecode/3","doc":"Both detects and decodes graphical code\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetectorAruco.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical code.\n\n##### Return\n- **retval**: `string`\n- **points**: `Evision.Mat.t()`.\n\n  optional output array of vertices of the found graphical code quadrangle, will be empty if not found.\n\n- **straight_code**: `Evision.Mat.t()`.\n\n  The optional output image containing binarized code\n\nPython prototype (for reference only):\n```python3\ndetectAndDecode(img[, points[, straight_code]]) -> retval, points, straight_code\n```","ref":"Evision.QRCodeDetectorAruco.html#detectAndDecode/3"},{"type":"function","title":"Evision.QRCodeDetectorAruco.detectAndDecodeMulti/1","doc":"","ref":"Evision.QRCodeDetectorAruco.html#detectAndDecodeMulti/1"},{"type":"function","title":"Evision.QRCodeDetectorAruco.detectAndDecodeMulti/2","doc":"Both detects and decodes graphical codes\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetectorAruco.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical codes.\n\n##### Return\n- **retval**: `bool`\n- **decoded_info**: `[string]`.\n\n  UTF8-encoded output vector of string or empty vector of string if the codes cannot be decoded.\n\n- **points**: `Evision.Mat.t()`.\n\n  optional output vector of vertices of the found graphical code quadrangles. Will be empty if not found.\n\n- **straight_code**: `[Evision.Mat]`.\n\n  The optional vector of images containing binarized codes\n\n- If there are QR codes encoded with a Structured Append mode on the image and all of them detected and decoded correctly,\n  method writes a full message to position corresponds to 0-th code in a sequence. The rest of QR codes from the same sequence\n  have empty string.\n\nPython prototype (for reference only):\n```python3\ndetectAndDecodeMulti(img[, points[, straight_code]]) -> retval, decoded_info, points, straight_code\n```","ref":"Evision.QRCodeDetectorAruco.html#detectAndDecodeMulti/2"},{"type":"function","title":"Evision.QRCodeDetectorAruco.detectAndDecodeMulti/3","doc":"Both detects and decodes graphical codes\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetectorAruco.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing graphical codes.\n\n##### Return\n- **retval**: `bool`\n- **decoded_info**: `[string]`.\n\n  UTF8-encoded output vector of string or empty vector of string if the codes cannot be decoded.\n\n- **points**: `Evision.Mat.t()`.\n\n  optional output vector of vertices of the found graphical code quadrangles. Will be empty if not found.\n\n- **straight_code**: `[Evision.Mat]`.\n\n  The optional vector of images containing binarized codes\n\n- If there are QR codes encoded with a Structured Append mode on the image and all of them detected and decoded correctly,\n  method writes a full message to position corresponds to 0-th code in a sequence. The rest of QR codes from the same sequence\n  have empty string.\n\nPython prototype (for reference only):\n```python3\ndetectAndDecodeMulti(img[, points[, straight_code]]) -> retval, decoded_info, points, straight_code\n```","ref":"Evision.QRCodeDetectorAruco.html#detectAndDecodeMulti/3"},{"type":"function","title":"Evision.QRCodeDetectorAruco.detectMulti/1","doc":"","ref":"Evision.QRCodeDetectorAruco.html#detectMulti/1"},{"type":"function","title":"Evision.QRCodeDetectorAruco.detectMulti/2","doc":"Detects graphical codes in image and returns the vector of the quadrangles containing the codes.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetectorAruco.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing (or not) graphical codes.\n\n##### Return\n- **retval**: `bool`\n- **points**: `Evision.Mat.t()`.\n\n  Output vector of vector of vertices of the minimum-area quadrangle containing the codes.\n\nPython prototype (for reference only):\n```python3\ndetectMulti(img[, points]) -> retval, points\n```","ref":"Evision.QRCodeDetectorAruco.html#detectMulti/2"},{"type":"function","title":"Evision.QRCodeDetectorAruco.detectMulti/3","doc":"Detects graphical codes in image and returns the vector of the quadrangles containing the codes.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetectorAruco.t()`\n- **img**: `Evision.Mat`.\n\n  grayscale or color (BGR) image containing (or not) graphical codes.\n\n##### Return\n- **retval**: `bool`\n- **points**: `Evision.Mat.t()`.\n\n  Output vector of vector of vertices of the minimum-area quadrangle containing the codes.\n\nPython prototype (for reference only):\n```python3\ndetectMulti(img[, points]) -> retval, points\n```","ref":"Evision.QRCodeDetectorAruco.html#detectMulti/3"},{"type":"function","title":"Evision.QRCodeDetectorAruco.getArucoParameters/1","doc":"Aruco detector parameters are used to search for the finder patterns.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetectorAruco.t()`\n\n##### Return\n- **retval**: `aruco::DetectorParameters`\n\nPython prototype (for reference only):\n```python3\ngetArucoParameters() -> retval\n```","ref":"Evision.QRCodeDetectorAruco.html#getArucoParameters/1"},{"type":"function","title":"Evision.QRCodeDetectorAruco.getDetectorParameters/1","doc":"Detector parameters getter. See cv::QRCodeDetectorAruco::Params\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetectorAruco.t()`\n\n##### Return\n- **retval**: `QRCodeDetectorAruco::Params`\n\nPython prototype (for reference only):\n```python3\ngetDetectorParameters() -> retval\n```","ref":"Evision.QRCodeDetectorAruco.html#getDetectorParameters/1"},{"type":"function","title":"Evision.QRCodeDetectorAruco.qrcodedetectoraruco/0","doc":"QRCodeDetectorAruco\n##### Return\n- **self**: `Evision.QRCodeDetectorAruco.t()`\n\nPython prototype (for reference only):\n```python3\nQRCodeDetectorAruco() ->  \n```","ref":"Evision.QRCodeDetectorAruco.html#qrcodedetectoraruco/0"},{"type":"function","title":"Evision.QRCodeDetectorAruco.qrcodedetectoraruco/1","doc":"QR code detector constructor for Aruco-based algorithm. See cv::QRCodeDetectorAruco::Params\n\n##### Positional Arguments\n- **params**: `QRCodeDetectorAruco_Params`\n\n##### Return\n- **self**: `Evision.QRCodeDetectorAruco.t()`\n\nPython prototype (for reference only):\n```python3\nQRCodeDetectorAruco(params) ->  \n```","ref":"Evision.QRCodeDetectorAruco.html#qrcodedetectoraruco/1"},{"type":"function","title":"Evision.QRCodeDetectorAruco.setArucoParameters/1","doc":"","ref":"Evision.QRCodeDetectorAruco.html#setArucoParameters/1"},{"type":"function","title":"Evision.QRCodeDetectorAruco.setArucoParameters/2","doc":"Aruco detector parameters are used to search for the finder patterns.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetectorAruco.t()`\n- **params**: `aruco_DetectorParameters`\n\nPython prototype (for reference only):\n```python3\nsetArucoParameters(params) -> None\n```","ref":"Evision.QRCodeDetectorAruco.html#setArucoParameters/2"},{"type":"function","title":"Evision.QRCodeDetectorAruco.setDetectorParameters/1","doc":"","ref":"Evision.QRCodeDetectorAruco.html#setDetectorParameters/1"},{"type":"function","title":"Evision.QRCodeDetectorAruco.setDetectorParameters/2","doc":"Detector parameters setter. See cv::QRCodeDetectorAruco::Params\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeDetectorAruco.t()`\n- **params**: `QRCodeDetectorAruco_Params`\n\n##### Return\n- **retval**: `Evision.QRCodeDetectorAruco.t()`\n\nPython prototype (for reference only):\n```python3\nsetDetectorParameters(params) -> retval\n```","ref":"Evision.QRCodeDetectorAruco.html#setDetectorParameters/2"},{"type":"type","title":"Evision.QRCodeDetectorAruco.t/0","doc":"Type that represents an `QRCodeDetectorAruco` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.QRCodeDetectorAruco.html#t:t/0"},{"type":"module","title":"Evision.QRCodeDetectorAruco.Params","doc":"","ref":"Evision.QRCodeDetectorAruco.Params.html"},{"type":"function","title":"Evision.QRCodeDetectorAruco.Params.get_maxColorsMismatch/1","doc":"","ref":"Evision.QRCodeDetectorAruco.Params.html#get_maxColorsMismatch/1"},{"type":"function","title":"Evision.QRCodeDetectorAruco.Params.get_maxModuleSizeMismatch/1","doc":"","ref":"Evision.QRCodeDetectorAruco.Params.html#get_maxModuleSizeMismatch/1"},{"type":"function","title":"Evision.QRCodeDetectorAruco.Params.get_maxPenalties/1","doc":"","ref":"Evision.QRCodeDetectorAruco.Params.html#get_maxPenalties/1"},{"type":"function","title":"Evision.QRCodeDetectorAruco.Params.get_maxRotation/1","doc":"","ref":"Evision.QRCodeDetectorAruco.Params.html#get_maxRotation/1"},{"type":"function","title":"Evision.QRCodeDetectorAruco.Params.get_maxTimingPatternMismatch/1","doc":"","ref":"Evision.QRCodeDetectorAruco.Params.html#get_maxTimingPatternMismatch/1"},{"type":"function","title":"Evision.QRCodeDetectorAruco.Params.get_minModuleSizeInPyramid/1","doc":"","ref":"Evision.QRCodeDetectorAruco.Params.html#get_minModuleSizeInPyramid/1"},{"type":"function","title":"Evision.QRCodeDetectorAruco.Params.get_scaleTimingPatternScore/1","doc":"","ref":"Evision.QRCodeDetectorAruco.Params.html#get_scaleTimingPatternScore/1"},{"type":"function","title":"Evision.QRCodeDetectorAruco.Params.qrcodedetectoraruco_params/0","doc":"QRCodeDetectorAruco_Params\n##### Return\n- **self**: `QRCodeDetectorAruco_Params`\n\nPython prototype (for reference only):\n```python3\nQRCodeDetectorAruco_Params() ->  \n```","ref":"Evision.QRCodeDetectorAruco.Params.html#qrcodedetectoraruco_params/0"},{"type":"function","title":"Evision.QRCodeDetectorAruco.Params.qrcodedetectoraruco_params/1","doc":"","ref":"Evision.QRCodeDetectorAruco.Params.html#qrcodedetectoraruco_params/1"},{"type":"function","title":"Evision.QRCodeDetectorAruco.Params.set_maxColorsMismatch/2","doc":"","ref":"Evision.QRCodeDetectorAruco.Params.html#set_maxColorsMismatch/2"},{"type":"function","title":"Evision.QRCodeDetectorAruco.Params.set_maxModuleSizeMismatch/2","doc":"","ref":"Evision.QRCodeDetectorAruco.Params.html#set_maxModuleSizeMismatch/2"},{"type":"function","title":"Evision.QRCodeDetectorAruco.Params.set_maxPenalties/2","doc":"","ref":"Evision.QRCodeDetectorAruco.Params.html#set_maxPenalties/2"},{"type":"function","title":"Evision.QRCodeDetectorAruco.Params.set_maxRotation/2","doc":"","ref":"Evision.QRCodeDetectorAruco.Params.html#set_maxRotation/2"},{"type":"function","title":"Evision.QRCodeDetectorAruco.Params.set_maxTimingPatternMismatch/2","doc":"","ref":"Evision.QRCodeDetectorAruco.Params.html#set_maxTimingPatternMismatch/2"},{"type":"function","title":"Evision.QRCodeDetectorAruco.Params.set_minModuleSizeInPyramid/2","doc":"","ref":"Evision.QRCodeDetectorAruco.Params.html#set_minModuleSizeInPyramid/2"},{"type":"function","title":"Evision.QRCodeDetectorAruco.Params.set_scaleTimingPatternScore/2","doc":"","ref":"Evision.QRCodeDetectorAruco.Params.html#set_scaleTimingPatternScore/2"},{"type":"type","title":"Evision.QRCodeDetectorAruco.Params.t/0","doc":"Type that represents an `QRCodeDetectorAruco.Params` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.QRCodeDetectorAruco.Params.html#t:t/0"},{"type":"module","title":"Evision.QRCodeEncoder","doc":"","ref":"Evision.QRCodeEncoder.html"},{"type":"function","title":"Evision.QRCodeEncoder.create/0","doc":"Constructor\n##### Keyword Arguments\n- **parameters**: `Evision.QRCodeEncoder.Params.t()`.\n\n  QR code encoder parameters QRCodeEncoder::Params\n\n##### Return\n- **retval**: `Evision.QRCodeEncoder.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, parameters]) -> retval\n```","ref":"Evision.QRCodeEncoder.html#create/0"},{"type":"function","title":"Evision.QRCodeEncoder.create/1","doc":"Constructor\n##### Keyword Arguments\n- **parameters**: `Evision.QRCodeEncoder.Params.t()`.\n\n  QR code encoder parameters QRCodeEncoder::Params\n\n##### Return\n- **retval**: `Evision.QRCodeEncoder.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, parameters]) -> retval\n```","ref":"Evision.QRCodeEncoder.html#create/1"},{"type":"function","title":"Evision.QRCodeEncoder.encode/1","doc":"","ref":"Evision.QRCodeEncoder.html#encode/1"},{"type":"function","title":"Evision.QRCodeEncoder.encode/2","doc":"Generates QR code from input string.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeEncoder.t()`\n- **encoded_info**: `String`.\n\n  Input string to encode.\n\n##### Return\n- **qrcode**: `Evision.Mat.t()`.\n\n  Generated QR code.\n\nPython prototype (for reference only):\n```python3\nencode(encoded_info[, qrcode]) -> qrcode\n```","ref":"Evision.QRCodeEncoder.html#encode/2"},{"type":"function","title":"Evision.QRCodeEncoder.encode/3","doc":"Generates QR code from input string.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeEncoder.t()`\n- **encoded_info**: `String`.\n\n  Input string to encode.\n\n##### Return\n- **qrcode**: `Evision.Mat.t()`.\n\n  Generated QR code.\n\nPython prototype (for reference only):\n```python3\nencode(encoded_info[, qrcode]) -> qrcode\n```","ref":"Evision.QRCodeEncoder.html#encode/3"},{"type":"function","title":"Evision.QRCodeEncoder.encodeStructuredAppend/1","doc":"","ref":"Evision.QRCodeEncoder.html#encodeStructuredAppend/1"},{"type":"function","title":"Evision.QRCodeEncoder.encodeStructuredAppend/2","doc":"Generates QR code from input string in Structured Append mode. The encoded message is splitting over a number of QR codes.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeEncoder.t()`\n- **encoded_info**: `String`.\n\n  Input string to encode.\n\n##### Return\n- **qrcodes**: `[Evision.Mat]`.\n\n  Vector of generated QR codes.\n\nPython prototype (for reference only):\n```python3\nencodeStructuredAppend(encoded_info[, qrcodes]) -> qrcodes\n```","ref":"Evision.QRCodeEncoder.html#encodeStructuredAppend/2"},{"type":"function","title":"Evision.QRCodeEncoder.encodeStructuredAppend/3","doc":"Generates QR code from input string in Structured Append mode. The encoded message is splitting over a number of QR codes.\n\n##### Positional Arguments\n- **self**: `Evision.QRCodeEncoder.t()`\n- **encoded_info**: `String`.\n\n  Input string to encode.\n\n##### Return\n- **qrcodes**: `[Evision.Mat]`.\n\n  Vector of generated QR codes.\n\nPython prototype (for reference only):\n```python3\nencodeStructuredAppend(encoded_info[, qrcodes]) -> qrcodes\n```","ref":"Evision.QRCodeEncoder.html#encodeStructuredAppend/3"},{"type":"type","title":"Evision.QRCodeEncoder.t/0","doc":"Type that represents an `QRCodeEncoder` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.QRCodeEncoder.html#t:t/0"},{"type":"module","title":"Evision.QRCodeEncoder.CorrectionLevel","doc":"","ref":"Evision.QRCodeEncoder.CorrectionLevel.html"},{"type":"function","title":"Evision.QRCodeEncoder.CorrectionLevel.cv_CORRECT_LEVEL_H/0","doc":"","ref":"Evision.QRCodeEncoder.CorrectionLevel.html#cv_CORRECT_LEVEL_H/0"},{"type":"function","title":"Evision.QRCodeEncoder.CorrectionLevel.cv_CORRECT_LEVEL_L/0","doc":"","ref":"Evision.QRCodeEncoder.CorrectionLevel.html#cv_CORRECT_LEVEL_L/0"},{"type":"function","title":"Evision.QRCodeEncoder.CorrectionLevel.cv_CORRECT_LEVEL_M/0","doc":"","ref":"Evision.QRCodeEncoder.CorrectionLevel.html#cv_CORRECT_LEVEL_M/0"},{"type":"function","title":"Evision.QRCodeEncoder.CorrectionLevel.cv_CORRECT_LEVEL_Q/0","doc":"","ref":"Evision.QRCodeEncoder.CorrectionLevel.html#cv_CORRECT_LEVEL_Q/0"},{"type":"type","title":"Evision.QRCodeEncoder.CorrectionLevel.enum/0","doc":"","ref":"Evision.QRCodeEncoder.CorrectionLevel.html#t:enum/0"},{"type":"module","title":"Evision.QRCodeEncoder.ECIEncodings","doc":"","ref":"Evision.QRCodeEncoder.ECIEncodings.html"},{"type":"function","title":"Evision.QRCodeEncoder.ECIEncodings.cv_ECI_UTF8/0","doc":"","ref":"Evision.QRCodeEncoder.ECIEncodings.html#cv_ECI_UTF8/0"},{"type":"type","title":"Evision.QRCodeEncoder.ECIEncodings.enum/0","doc":"","ref":"Evision.QRCodeEncoder.ECIEncodings.html#t:enum/0"},{"type":"module","title":"Evision.QRCodeEncoder.EncodeMode","doc":"","ref":"Evision.QRCodeEncoder.EncodeMode.html"},{"type":"function","title":"Evision.QRCodeEncoder.EncodeMode.cv_MODE_ALPHANUMERIC/0","doc":"","ref":"Evision.QRCodeEncoder.EncodeMode.html#cv_MODE_ALPHANUMERIC/0"},{"type":"function","title":"Evision.QRCodeEncoder.EncodeMode.cv_MODE_AUTO/0","doc":"","ref":"Evision.QRCodeEncoder.EncodeMode.html#cv_MODE_AUTO/0"},{"type":"function","title":"Evision.QRCodeEncoder.EncodeMode.cv_MODE_BYTE/0","doc":"","ref":"Evision.QRCodeEncoder.EncodeMode.html#cv_MODE_BYTE/0"},{"type":"function","title":"Evision.QRCodeEncoder.EncodeMode.cv_MODE_ECI/0","doc":"","ref":"Evision.QRCodeEncoder.EncodeMode.html#cv_MODE_ECI/0"},{"type":"function","title":"Evision.QRCodeEncoder.EncodeMode.cv_MODE_KANJI/0","doc":"","ref":"Evision.QRCodeEncoder.EncodeMode.html#cv_MODE_KANJI/0"},{"type":"function","title":"Evision.QRCodeEncoder.EncodeMode.cv_MODE_NUMERIC/0","doc":"","ref":"Evision.QRCodeEncoder.EncodeMode.html#cv_MODE_NUMERIC/0"},{"type":"function","title":"Evision.QRCodeEncoder.EncodeMode.cv_MODE_STRUCTURED_APPEND/0","doc":"","ref":"Evision.QRCodeEncoder.EncodeMode.html#cv_MODE_STRUCTURED_APPEND/0"},{"type":"type","title":"Evision.QRCodeEncoder.EncodeMode.enum/0","doc":"","ref":"Evision.QRCodeEncoder.EncodeMode.html#t:enum/0"},{"type":"module","title":"Evision.QRCodeEncoder.Params","doc":"","ref":"Evision.QRCodeEncoder.Params.html"},{"type":"function","title":"Evision.QRCodeEncoder.Params.get_correction_level/1","doc":"","ref":"Evision.QRCodeEncoder.Params.html#get_correction_level/1"},{"type":"function","title":"Evision.QRCodeEncoder.Params.get_mode/1","doc":"","ref":"Evision.QRCodeEncoder.Params.html#get_mode/1"},{"type":"function","title":"Evision.QRCodeEncoder.Params.get_structure_number/1","doc":"","ref":"Evision.QRCodeEncoder.Params.html#get_structure_number/1"},{"type":"function","title":"Evision.QRCodeEncoder.Params.get_version/1","doc":"","ref":"Evision.QRCodeEncoder.Params.html#get_version/1"},{"type":"function","title":"Evision.QRCodeEncoder.Params.params/0","doc":"QRCodeEncoder_Params\n##### Return\n- **self**: `Evision.QRCodeEncoder.Params.t()`\n\nPython prototype (for reference only):\n```python3\nQRCodeEncoder_Params() ->  \n```","ref":"Evision.QRCodeEncoder.Params.html#params/0"},{"type":"function","title":"Evision.QRCodeEncoder.Params.params/1","doc":"","ref":"Evision.QRCodeEncoder.Params.html#params/1"},{"type":"function","title":"Evision.QRCodeEncoder.Params.set_correction_level/2","doc":"","ref":"Evision.QRCodeEncoder.Params.html#set_correction_level/2"},{"type":"function","title":"Evision.QRCodeEncoder.Params.set_mode/2","doc":"","ref":"Evision.QRCodeEncoder.Params.html#set_mode/2"},{"type":"function","title":"Evision.QRCodeEncoder.Params.set_structure_number/2","doc":"","ref":"Evision.QRCodeEncoder.Params.html#set_structure_number/2"},{"type":"function","title":"Evision.QRCodeEncoder.Params.set_version/2","doc":"","ref":"Evision.QRCodeEncoder.Params.html#set_version/2"},{"type":"type","title":"Evision.QRCodeEncoder.Params.t/0","doc":"Type that represents an `QRCodeEncoder.Params` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.QRCodeEncoder.Params.html#t:t/0"},{"type":"module","title":"Evision.QtButtonTypes","doc":"","ref":"Evision.QtButtonTypes.html"},{"type":"function","title":"Evision.QtButtonTypes.cv_QT_CHECKBOX/0","doc":"","ref":"Evision.QtButtonTypes.html#cv_QT_CHECKBOX/0"},{"type":"function","title":"Evision.QtButtonTypes.cv_QT_NEW_BUTTONBAR/0","doc":"","ref":"Evision.QtButtonTypes.html#cv_QT_NEW_BUTTONBAR/0"},{"type":"function","title":"Evision.QtButtonTypes.cv_QT_PUSH_BUTTON/0","doc":"","ref":"Evision.QtButtonTypes.html#cv_QT_PUSH_BUTTON/0"},{"type":"function","title":"Evision.QtButtonTypes.cv_QT_RADIOBOX/0","doc":"","ref":"Evision.QtButtonTypes.html#cv_QT_RADIOBOX/0"},{"type":"type","title":"Evision.QtButtonTypes.enum/0","doc":"","ref":"Evision.QtButtonTypes.html#t:enum/0"},{"type":"module","title":"Evision.QtFontStyles","doc":"","ref":"Evision.QtFontStyles.html"},{"type":"function","title":"Evision.QtFontStyles.cv_QT_STYLE_ITALIC/0","doc":"","ref":"Evision.QtFontStyles.html#cv_QT_STYLE_ITALIC/0"},{"type":"function","title":"Evision.QtFontStyles.cv_QT_STYLE_NORMAL/0","doc":"","ref":"Evision.QtFontStyles.html#cv_QT_STYLE_NORMAL/0"},{"type":"function","title":"Evision.QtFontStyles.cv_QT_STYLE_OBLIQUE/0","doc":"","ref":"Evision.QtFontStyles.html#cv_QT_STYLE_OBLIQUE/0"},{"type":"type","title":"Evision.QtFontStyles.enum/0","doc":"","ref":"Evision.QtFontStyles.html#t:enum/0"},{"type":"module","title":"Evision.QtFontWeights","doc":"","ref":"Evision.QtFontWeights.html"},{"type":"function","title":"Evision.QtFontWeights.cv_QT_FONT_BLACK/0","doc":"","ref":"Evision.QtFontWeights.html#cv_QT_FONT_BLACK/0"},{"type":"function","title":"Evision.QtFontWeights.cv_QT_FONT_BOLD/0","doc":"","ref":"Evision.QtFontWeights.html#cv_QT_FONT_BOLD/0"},{"type":"function","title":"Evision.QtFontWeights.cv_QT_FONT_DEMIBOLD/0","doc":"","ref":"Evision.QtFontWeights.html#cv_QT_FONT_DEMIBOLD/0"},{"type":"function","title":"Evision.QtFontWeights.cv_QT_FONT_LIGHT/0","doc":"","ref":"Evision.QtFontWeights.html#cv_QT_FONT_LIGHT/0"},{"type":"function","title":"Evision.QtFontWeights.cv_QT_FONT_NORMAL/0","doc":"","ref":"Evision.QtFontWeights.html#cv_QT_FONT_NORMAL/0"},{"type":"type","title":"Evision.QtFontWeights.enum/0","doc":"","ref":"Evision.QtFontWeights.html#t:enum/0"},{"type":"module","title":"Evision.Quality","doc":"","ref":"Evision.Quality.html"},{"type":"type","title":"Evision.Quality.t/0","doc":"Type that represents an `Quality` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Quality.html#t:t/0"},{"type":"module","title":"Evision.Quality.QualityBRISQUE","doc":"","ref":"Evision.Quality.QualityBRISQUE.html"},{"type":"function","title":"Evision.Quality.QualityBRISQUE.compute/1","doc":"","ref":"Evision.Quality.QualityBRISQUE.html#compute/1"},{"type":"function","title":"Evision.Quality.QualityBRISQUE.compute/2","doc":"Computes BRISQUE quality score for input image\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityBRISQUE.t()`\n- **img**: `Evision.Mat`.\n\n  Image for which to compute quality\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n\n@returns cv::Scalar with the score in the first element.  The score ranges from 0 (best quality) to 100 (worst quality)\n\nPython prototype (for reference only):\n```python3\ncompute(img) -> retval\n```","ref":"Evision.Quality.QualityBRISQUE.html#compute/2"},{"type":"function","title":"Evision.Quality.QualityBRISQUE.compute/4","doc":"static method for computing quality\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityBRISQUE.t()`\n- **img**: `Evision.Mat`.\n\n  image for which to compute quality\n\n- **model_file_path**: `String`.\n\n  cv::String which contains a path to the BRISQUE model data, eg. /path/to/brisque_model_live.yml\n\n- **range_file_path**: `String`.\n\n  cv::String which contains a path to the BRISQUE range data, eg. /path/to/brisque_range_live.yml\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n\n@returns cv::Scalar with the score in the first element.  The score ranges from 0 (best quality) to 100 (worst quality)\n\nPython prototype (for reference only):\n```python3\ncompute(img, model_file_path, range_file_path) -> retval\n```","ref":"Evision.Quality.QualityBRISQUE.html#compute/4"},{"type":"function","title":"Evision.Quality.QualityBRISQUE.computeFeatures/1","doc":"static method for computing image features used by the BRISQUE algorithm\n\n##### Positional Arguments\n- **img**: `Evision.Mat`.\n\n  image (BGR(A) or grayscale) for which to compute features\n\n##### Return\n- **features**: `Evision.Mat.t()`.\n\n  output row vector of features to cv::Mat or cv::UMat\n\nPython prototype (for reference only):\n```python3\ncomputeFeatures(img[, features]) -> features\n```","ref":"Evision.Quality.QualityBRISQUE.html#computeFeatures/1"},{"type":"function","title":"Evision.Quality.QualityBRISQUE.computeFeatures/2","doc":"static method for computing image features used by the BRISQUE algorithm\n\n##### Positional Arguments\n- **img**: `Evision.Mat`.\n\n  image (BGR(A) or grayscale) for which to compute features\n\n##### Return\n- **features**: `Evision.Mat.t()`.\n\n  output row vector of features to cv::Mat or cv::UMat\n\nPython prototype (for reference only):\n```python3\ncomputeFeatures(img[, features]) -> features\n```","ref":"Evision.Quality.QualityBRISQUE.html#computeFeatures/2"},{"type":"function","title":"Evision.Quality.QualityBRISQUE.create/1","doc":"","ref":"Evision.Quality.QualityBRISQUE.html#create/1"},{"type":"function","title":"Evision.Quality.QualityBRISQUE.create/2","doc":"#### Variant 1:\nCreate an object which calculates quality\n\n##### Positional Arguments\n- **model**: `ml::SVM`.\n\n  cv::Ptr  which contains a loaded BRISQUE model\n\n- **range**: `Evision.Mat`.\n\n  cv::Mat which contains BRISQUE range data\n\n##### Return\n- **retval**: `QualityBRISQUE`\n\nPython prototype (for reference only):\n```python3\ncreate(model, range) -> retval\n```\n#### Variant 2:\nCreate an object which calculates quality\n\n##### Positional Arguments\n- **model_file_path**: `String`.\n\n  cv::String which contains a path to the BRISQUE model data, eg. /path/to/brisque_model_live.yml\n\n- **range_file_path**: `String`.\n\n  cv::String which contains a path to the BRISQUE range data, eg. /path/to/brisque_range_live.yml\n\n##### Return\n- **retval**: `QualityBRISQUE`\n\nPython prototype (for reference only):\n```python3\ncreate(model_file_path, range_file_path) -> retval\n```","ref":"Evision.Quality.QualityBRISQUE.html#create/2"},{"type":"type","title":"Evision.Quality.QualityBRISQUE.t/0","doc":"Type that represents an `Quality.QualityBRISQUE` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Quality.QualityBRISQUE.html#t:t/0"},{"type":"module","title":"Evision.Quality.QualityBase","doc":"","ref":"Evision.Quality.QualityBase.html"},{"type":"function","title":"Evision.Quality.QualityBase.clear/1","doc":"Implements Algorithm::clear()\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityBase.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Quality.QualityBase.html#clear/1"},{"type":"function","title":"Evision.Quality.QualityBase.compute/1","doc":"","ref":"Evision.Quality.QualityBase.html#compute/1"},{"type":"function","title":"Evision.Quality.QualityBase.compute/2","doc":"Compute quality score per channel with the per-channel score in each element of the resulting cv::Scalar.  See specific algorithm for interpreting result scores\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityBase.t()`\n- **img**: `Evision.Mat`.\n\n  comparison image, or image to evalute for no-reference quality algorithms\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n\nPython prototype (for reference only):\n```python3\ncompute(img) -> retval\n```","ref":"Evision.Quality.QualityBase.html#compute/2"},{"type":"function","title":"Evision.Quality.QualityBase.empty/1","doc":"Implements Algorithm::empty()\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityBase.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Quality.QualityBase.html#empty/1"},{"type":"function","title":"Evision.Quality.QualityBase.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityBase.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Quality.QualityBase.html#getDefaultName/1"},{"type":"function","title":"Evision.Quality.QualityBase.getQualityMap/1","doc":"Returns output quality map that was generated during computation, if supported by the algorithm\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityBase.t()`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetQualityMap([, dst]) -> dst\n```","ref":"Evision.Quality.QualityBase.html#getQualityMap/1"},{"type":"function","title":"Evision.Quality.QualityBase.getQualityMap/2","doc":"Returns output quality map that was generated during computation, if supported by the algorithm\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityBase.t()`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetQualityMap([, dst]) -> dst\n```","ref":"Evision.Quality.QualityBase.html#getQualityMap/2"},{"type":"function","title":"Evision.Quality.QualityBase.read/1","doc":"","ref":"Evision.Quality.QualityBase.html#read/1"},{"type":"function","title":"Evision.Quality.QualityBase.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityBase.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Quality.QualityBase.html#read/2"},{"type":"function","title":"Evision.Quality.QualityBase.save/1","doc":"","ref":"Evision.Quality.QualityBase.html#save/1"},{"type":"function","title":"Evision.Quality.QualityBase.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityBase.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Quality.QualityBase.html#save/2"},{"type":"function","title":"Evision.Quality.QualityBase.write/1","doc":"","ref":"Evision.Quality.QualityBase.html#write/1"},{"type":"function","title":"Evision.Quality.QualityBase.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityBase.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Quality.QualityBase.html#write/2"},{"type":"function","title":"Evision.Quality.QualityBase.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityBase.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Quality.QualityBase.html#write/3"},{"type":"type","title":"Evision.Quality.QualityBase.t/0","doc":"Type that represents an `Quality.QualityBase` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Quality.QualityBase.html#t:t/0"},{"type":"module","title":"Evision.Quality.QualityGMSD","doc":"","ref":"Evision.Quality.QualityGMSD.html"},{"type":"function","title":"Evision.Quality.QualityGMSD.clear/1","doc":"Implements Algorithm::clear()\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityGMSD.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Quality.QualityGMSD.html#clear/1"},{"type":"function","title":"Evision.Quality.QualityGMSD.compute/1","doc":"","ref":"Evision.Quality.QualityGMSD.html#compute/1"},{"type":"function","title":"Evision.Quality.QualityGMSD.compute/2","doc":"Compute GMSD\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityGMSD.t()`\n- **cmp**: `Evision.Mat`.\n\n  comparison image\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n\n@returns cv::Scalar with per-channel quality value.  Values range from 0 (worst) to 1 (best)\n\nPython prototype (for reference only):\n```python3\ncompute(cmp) -> retval\n```","ref":"Evision.Quality.QualityGMSD.html#compute/2"},{"type":"function","title":"Evision.Quality.QualityGMSD.compute/3","doc":"static method for computing quality\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityGMSD.t()`\n- **ref**: `Evision.Mat`.\n\n  reference image\n\n- **cmp**: `Evision.Mat`.\n\n  comparison image\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n- **qualityMap**: `Evision.Mat.t()`.\n\n  output quality map, or cv::noArray()\n\n@returns cv::Scalar with per-channel quality value.  Values range from 0 (worst) to 1 (best)\n\nPython prototype (for reference only):\n```python3\ncompute(ref, cmp[, qualityMap]) -> retval, qualityMap\n```","ref":"Evision.Quality.QualityGMSD.html#compute/3"},{"type":"function","title":"Evision.Quality.QualityGMSD.compute/4","doc":"static method for computing quality\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityGMSD.t()`\n- **ref**: `Evision.Mat`.\n\n  reference image\n\n- **cmp**: `Evision.Mat`.\n\n  comparison image\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n- **qualityMap**: `Evision.Mat.t()`.\n\n  output quality map, or cv::noArray()\n\n@returns cv::Scalar with per-channel quality value.  Values range from 0 (worst) to 1 (best)\n\nPython prototype (for reference only):\n```python3\ncompute(ref, cmp[, qualityMap]) -> retval, qualityMap\n```","ref":"Evision.Quality.QualityGMSD.html#compute/4"},{"type":"function","title":"Evision.Quality.QualityGMSD.create/1","doc":"Create an object which calculates image quality\n\n##### Positional Arguments\n- **ref**: `Evision.Mat`.\n\n  reference image\n\n##### Return\n- **retval**: `QualityGMSD`\n\nPython prototype (for reference only):\n```python3\ncreate(ref) -> retval\n```","ref":"Evision.Quality.QualityGMSD.html#create/1"},{"type":"function","title":"Evision.Quality.QualityGMSD.empty/1","doc":"Implements Algorithm::empty()\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityGMSD.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Quality.QualityGMSD.html#empty/1"},{"type":"type","title":"Evision.Quality.QualityGMSD.t/0","doc":"Type that represents an `Quality.QualityGMSD` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Quality.QualityGMSD.html#t:t/0"},{"type":"module","title":"Evision.Quality.QualityMSE","doc":"","ref":"Evision.Quality.QualityMSE.html"},{"type":"function","title":"Evision.Quality.QualityMSE.clear/1","doc":"Implements Algorithm::clear()\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityMSE.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Quality.QualityMSE.html#clear/1"},{"type":"function","title":"Evision.Quality.QualityMSE.compute/1","doc":"","ref":"Evision.Quality.QualityMSE.html#compute/1"},{"type":"function","title":"Evision.Quality.QualityMSE.compute/2","doc":"Computes MSE for reference images supplied in class constructor and provided comparison images\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityMSE.t()`\n- **cmpImgs**: `[Evision.Mat]`.\n\n  Comparison image(s)\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n\n@returns cv::Scalar with per-channel quality values.  Values range from 0 (best) to potentially max float (worst)\n\nPython prototype (for reference only):\n```python3\ncompute(cmpImgs) -> retval\n```","ref":"Evision.Quality.QualityMSE.html#compute/2"},{"type":"function","title":"Evision.Quality.QualityMSE.compute/3","doc":"static method for computing quality\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityMSE.t()`\n- **ref**: `Evision.Mat`.\n\n  reference image\n\n- **cmp**: `Evision.Mat`.\n\n  comparison image=\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n- **qualityMap**: `Evision.Mat.t()`.\n\n  output quality map, or cv::noArray()\n\n@returns cv::Scalar with per-channel quality values.  Values range from 0 (best) to max float (worst)\n\nPython prototype (for reference only):\n```python3\ncompute(ref, cmp[, qualityMap]) -> retval, qualityMap\n```","ref":"Evision.Quality.QualityMSE.html#compute/3"},{"type":"function","title":"Evision.Quality.QualityMSE.compute/4","doc":"static method for computing quality\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityMSE.t()`\n- **ref**: `Evision.Mat`.\n\n  reference image\n\n- **cmp**: `Evision.Mat`.\n\n  comparison image=\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n- **qualityMap**: `Evision.Mat.t()`.\n\n  output quality map, or cv::noArray()\n\n@returns cv::Scalar with per-channel quality values.  Values range from 0 (best) to max float (worst)\n\nPython prototype (for reference only):\n```python3\ncompute(ref, cmp[, qualityMap]) -> retval, qualityMap\n```","ref":"Evision.Quality.QualityMSE.html#compute/4"},{"type":"function","title":"Evision.Quality.QualityMSE.create/1","doc":"Create an object which calculates quality\n\n##### Positional Arguments\n- **ref**: `Evision.Mat`.\n\n  input image to use as the reference for comparison\n\n##### Return\n- **retval**: `QualityMSE`\n\nPython prototype (for reference only):\n```python3\ncreate(ref) -> retval\n```","ref":"Evision.Quality.QualityMSE.html#create/1"},{"type":"function","title":"Evision.Quality.QualityMSE.empty/1","doc":"Implements Algorithm::empty()\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityMSE.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Quality.QualityMSE.html#empty/1"},{"type":"type","title":"Evision.Quality.QualityMSE.t/0","doc":"Type that represents an `Quality.QualityMSE` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Quality.QualityMSE.html#t:t/0"},{"type":"module","title":"Evision.Quality.QualityPSNR","doc":"","ref":"Evision.Quality.QualityPSNR.html"},{"type":"function","title":"Evision.Quality.QualityPSNR.clear/1","doc":"Implements Algorithm::clear()\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityPSNR.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Quality.QualityPSNR.html#clear/1"},{"type":"function","title":"Evision.Quality.QualityPSNR.compute/1","doc":"","ref":"Evision.Quality.QualityPSNR.html#compute/1"},{"type":"function","title":"Evision.Quality.QualityPSNR.compute/2","doc":"Compute the PSNR\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityPSNR.t()`\n- **cmp**: `Evision.Mat`.\n\n  Comparison image\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n\n@returns Per-channel PSNR value, or std::numeric_limits ::infinity() if the MSE between the two images == 0\n\nPython prototype (for reference only):\n```python3\ncompute(cmp) -> retval\n```","ref":"Evision.Quality.QualityPSNR.html#compute/2"},{"type":"function","title":"Evision.Quality.QualityPSNR.compute/3","doc":"static method for computing quality\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityPSNR.t()`\n- **ref**: `Evision.Mat`.\n\n  reference image\n\n- **cmp**: `Evision.Mat`.\n\n  comparison image\n\n##### Keyword Arguments\n- **maxPixelValue**: `double`.\n\n  maximum per-channel value for any individual pixel; eg 255 for uint8 image\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n- **qualityMap**: `Evision.Mat.t()`.\n\n  output quality map, or cv::noArray()\n\n@returns PSNR value, or std::numeric_limits ::infinity() if the MSE between the two images == 0\n\nPython prototype (for reference only):\n```python3\ncompute(ref, cmp[, qualityMap[, maxPixelValue]]) -> retval, qualityMap\n```","ref":"Evision.Quality.QualityPSNR.html#compute/3"},{"type":"function","title":"Evision.Quality.QualityPSNR.compute/4","doc":"static method for computing quality\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityPSNR.t()`\n- **ref**: `Evision.Mat`.\n\n  reference image\n\n- **cmp**: `Evision.Mat`.\n\n  comparison image\n\n##### Keyword Arguments\n- **maxPixelValue**: `double`.\n\n  maximum per-channel value for any individual pixel; eg 255 for uint8 image\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n- **qualityMap**: `Evision.Mat.t()`.\n\n  output quality map, or cv::noArray()\n\n@returns PSNR value, or std::numeric_limits ::infinity() if the MSE between the two images == 0\n\nPython prototype (for reference only):\n```python3\ncompute(ref, cmp[, qualityMap[, maxPixelValue]]) -> retval, qualityMap\n```","ref":"Evision.Quality.QualityPSNR.html#compute/4"},{"type":"function","title":"Evision.Quality.QualityPSNR.create/1","doc":"Create an object which calculates quality\n\n##### Positional Arguments\n- **ref**: `Evision.Mat`.\n\n  input image to use as the source for comparison\n\n##### Keyword Arguments\n- **maxPixelValue**: `double`.\n\n  maximum per-channel value for any individual pixel; eg 255 for uint8 image\n\n##### Return\n- **retval**: `QualityPSNR`\n\nPython prototype (for reference only):\n```python3\ncreate(ref[, maxPixelValue]) -> retval\n```","ref":"Evision.Quality.QualityPSNR.html#create/1"},{"type":"function","title":"Evision.Quality.QualityPSNR.create/2","doc":"Create an object which calculates quality\n\n##### Positional Arguments\n- **ref**: `Evision.Mat`.\n\n  input image to use as the source for comparison\n\n##### Keyword Arguments\n- **maxPixelValue**: `double`.\n\n  maximum per-channel value for any individual pixel; eg 255 for uint8 image\n\n##### Return\n- **retval**: `QualityPSNR`\n\nPython prototype (for reference only):\n```python3\ncreate(ref[, maxPixelValue]) -> retval\n```","ref":"Evision.Quality.QualityPSNR.html#create/2"},{"type":"function","title":"Evision.Quality.QualityPSNR.empty/1","doc":"Implements Algorithm::empty()\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityPSNR.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Quality.QualityPSNR.html#empty/1"},{"type":"function","title":"Evision.Quality.QualityPSNR.getMaxPixelValue/1","doc":"return the maximum pixel value used for PSNR computation\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityPSNR.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxPixelValue() -> retval\n```","ref":"Evision.Quality.QualityPSNR.html#getMaxPixelValue/1"},{"type":"function","title":"Evision.Quality.QualityPSNR.setMaxPixelValue/1","doc":"","ref":"Evision.Quality.QualityPSNR.html#setMaxPixelValue/1"},{"type":"function","title":"Evision.Quality.QualityPSNR.setMaxPixelValue/2","doc":"sets the maximum pixel value used for PSNR computation\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualityPSNR.t()`\n- **val**: `double`.\n\n  Maximum pixel value\n\nPython prototype (for reference only):\n```python3\nsetMaxPixelValue(val) -> None\n```","ref":"Evision.Quality.QualityPSNR.html#setMaxPixelValue/2"},{"type":"type","title":"Evision.Quality.QualityPSNR.t/0","doc":"Type that represents an `Quality.QualityPSNR` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Quality.QualityPSNR.html#t:t/0"},{"type":"module","title":"Evision.Quality.QualitySSIM","doc":"","ref":"Evision.Quality.QualitySSIM.html"},{"type":"function","title":"Evision.Quality.QualitySSIM.clear/1","doc":"Implements Algorithm::clear()\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualitySSIM.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Quality.QualitySSIM.html#clear/1"},{"type":"function","title":"Evision.Quality.QualitySSIM.compute/1","doc":"","ref":"Evision.Quality.QualitySSIM.html#compute/1"},{"type":"function","title":"Evision.Quality.QualitySSIM.compute/2","doc":"Computes SSIM\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualitySSIM.t()`\n- **cmp**: `Evision.Mat`.\n\n  Comparison image\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n\n@returns cv::Scalar with per-channel quality values.  Values range from 0 (worst) to 1 (best)\n\nPython prototype (for reference only):\n```python3\ncompute(cmp) -> retval\n```","ref":"Evision.Quality.QualitySSIM.html#compute/2"},{"type":"function","title":"Evision.Quality.QualitySSIM.compute/3","doc":"static method for computing quality\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualitySSIM.t()`\n- **ref**: `Evision.Mat`.\n\n  reference image\n\n- **cmp**: `Evision.Mat`.\n\n  comparison image\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n- **qualityMap**: `Evision.Mat.t()`.\n\n  output quality map, or cv::noArray()\n\n@returns cv::Scalar with per-channel quality values.  Values range from 0 (worst) to 1 (best)\n\nPython prototype (for reference only):\n```python3\ncompute(ref, cmp[, qualityMap]) -> retval, qualityMap\n```","ref":"Evision.Quality.QualitySSIM.html#compute/3"},{"type":"function","title":"Evision.Quality.QualitySSIM.compute/4","doc":"static method for computing quality\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualitySSIM.t()`\n- **ref**: `Evision.Mat`.\n\n  reference image\n\n- **cmp**: `Evision.Mat`.\n\n  comparison image\n\n##### Return\n- **retval**: `Evision.scalar().t()`\n- **qualityMap**: `Evision.Mat.t()`.\n\n  output quality map, or cv::noArray()\n\n@returns cv::Scalar with per-channel quality values.  Values range from 0 (worst) to 1 (best)\n\nPython prototype (for reference only):\n```python3\ncompute(ref, cmp[, qualityMap]) -> retval, qualityMap\n```","ref":"Evision.Quality.QualitySSIM.html#compute/4"},{"type":"function","title":"Evision.Quality.QualitySSIM.create/1","doc":"Create an object which calculates quality\n\n##### Positional Arguments\n- **ref**: `Evision.Mat`.\n\n  input image to use as the reference image for comparison\n\n##### Return\n- **retval**: `QualitySSIM`\n\nPython prototype (for reference only):\n```python3\ncreate(ref) -> retval\n```","ref":"Evision.Quality.QualitySSIM.html#create/1"},{"type":"function","title":"Evision.Quality.QualitySSIM.empty/1","doc":"Implements Algorithm::empty()\n\n##### Positional Arguments\n- **self**: `Evision.Quality.QualitySSIM.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Quality.QualitySSIM.html#empty/1"},{"type":"type","title":"Evision.Quality.QualitySSIM.t/0","doc":"Type that represents an `Quality.QualitySSIM` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Quality.QualitySSIM.html#t:t/0"},{"type":"module","title":"Evision.QuatAssumeType","doc":"","ref":"Evision.QuatAssumeType.html"},{"type":"function","title":"Evision.QuatAssumeType.cv_QUAT_ASSUME_NOT_UNIT/0","doc":"","ref":"Evision.QuatAssumeType.html#cv_QUAT_ASSUME_NOT_UNIT/0"},{"type":"function","title":"Evision.QuatAssumeType.cv_QUAT_ASSUME_UNIT/0","doc":"","ref":"Evision.QuatAssumeType.html#cv_QUAT_ASSUME_UNIT/0"},{"type":"type","title":"Evision.QuatAssumeType.enum/0","doc":"","ref":"Evision.QuatAssumeType.html#t:enum/0"},{"type":"module","title":"Evision.QuatEnum.EulerAnglesType","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_EULER_ANGLES_MAX_VALUE/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_EULER_ANGLES_MAX_VALUE/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_EXT_XYX/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_EXT_XYX/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_EXT_XYZ/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_EXT_XYZ/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_EXT_XZX/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_EXT_XZX/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_EXT_XZY/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_EXT_XZY/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_EXT_YXY/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_EXT_YXY/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_EXT_YXZ/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_EXT_YXZ/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_EXT_YZX/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_EXT_YZX/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_EXT_YZY/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_EXT_YZY/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_EXT_ZXY/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_EXT_ZXY/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_EXT_ZXZ/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_EXT_ZXZ/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_EXT_ZYX/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_EXT_ZYX/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_EXT_ZYZ/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_EXT_ZYZ/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_INT_XYX/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_INT_XYX/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_INT_XYZ/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_INT_XYZ/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_INT_XZX/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_INT_XZX/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_INT_XZY/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_INT_XZY/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_INT_YXY/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_INT_YXY/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_INT_YXZ/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_INT_YXZ/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_INT_YZX/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_INT_YZX/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_INT_YZY/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_INT_YZY/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_INT_ZXY/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_INT_ZXY/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_INT_ZXZ/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_INT_ZXZ/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_INT_ZYX/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_INT_ZYX/0"},{"type":"function","title":"Evision.QuatEnum.EulerAnglesType.cv_INT_ZYZ/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#cv_INT_ZYZ/0"},{"type":"type","title":"Evision.QuatEnum.EulerAnglesType.enum/0","doc":"","ref":"Evision.QuatEnum.EulerAnglesType.html#t:enum/0"},{"type":"module","title":"Evision.RGBD","doc":"","ref":"Evision.RGBD.html"},{"type":"function","title":"Evision.RGBD.depthTo3d/1","doc":"","ref":"Evision.RGBD.html#depthTo3d/1"},{"type":"function","title":"Evision.RGBD.depthTo3d/2","doc":"depthTo3d\n\n##### Positional Arguments\n- **depth**: `Evision.Mat`.\n\n  the depth image (if given as short int CV_U, it is assumed to be the depth in millimeters\n  (as done with the Microsoft Kinect), otherwise, if given as CV_32F or CV_64F, it is assumed in meters)\n\n- **k**: `Evision.Mat`.\n\n  The calibration matrix\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  the mask of the points to consider (can be empty)\n\n##### Return\n- **points3d**: `Evision.Mat.t()`.\n\n  the resulting 3d points. They are of depth the same as `depth` if it is CV_32F or CV_64F, and the\n  depth of `K` if `depth` is of depth CV_U\n\nConverts a depth image to an organized set of 3d points.\n The coordinate system is x pointing left, y down and z away from the camera\n\nPython prototype (for reference only):\n```python3\ndepthTo3d(depth, K[, points3d[, mask]]) -> points3d\n```","ref":"Evision.RGBD.html#depthTo3d/2"},{"type":"function","title":"Evision.RGBD.depthTo3d/3","doc":"depthTo3d\n\n##### Positional Arguments\n- **depth**: `Evision.Mat`.\n\n  the depth image (if given as short int CV_U, it is assumed to be the depth in millimeters\n  (as done with the Microsoft Kinect), otherwise, if given as CV_32F or CV_64F, it is assumed in meters)\n\n- **k**: `Evision.Mat`.\n\n  The calibration matrix\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  the mask of the points to consider (can be empty)\n\n##### Return\n- **points3d**: `Evision.Mat.t()`.\n\n  the resulting 3d points. They are of depth the same as `depth` if it is CV_32F or CV_64F, and the\n  depth of `K` if `depth` is of depth CV_U\n\nConverts a depth image to an organized set of 3d points.\n The coordinate system is x pointing left, y down and z away from the camera\n\nPython prototype (for reference only):\n```python3\ndepthTo3d(depth, K[, points3d[, mask]]) -> points3d\n```","ref":"Evision.RGBD.html#depthTo3d/3"},{"type":"function","title":"Evision.RGBD.depthTo3dSparse/1","doc":"","ref":"Evision.RGBD.html#depthTo3dSparse/1"},{"type":"function","title":"Evision.RGBD.depthTo3dSparse/3","doc":"depthTo3dSparse\n\n##### Positional Arguments\n- **depth**: `Evision.Mat`.\n\n  the depth image\n\n- **in_K**: `Evision.Mat`.\n\n- **in_points**: `Evision.Mat`.\n\n  the list of xy coordinates\n\n##### Return\n- **points3d**: `Evision.Mat.t()`.\n\n  the resulting 3d points\n\nPython prototype (for reference only):\n```python3\ndepthTo3dSparse(depth, in_K, in_points[, points3d]) -> points3d\n```","ref":"Evision.RGBD.html#depthTo3dSparse/3"},{"type":"function","title":"Evision.RGBD.depthTo3dSparse/4","doc":"depthTo3dSparse\n\n##### Positional Arguments\n- **depth**: `Evision.Mat`.\n\n  the depth image\n\n- **in_K**: `Evision.Mat`.\n\n- **in_points**: `Evision.Mat`.\n\n  the list of xy coordinates\n\n##### Return\n- **points3d**: `Evision.Mat.t()`.\n\n  the resulting 3d points\n\nPython prototype (for reference only):\n```python3\ndepthTo3dSparse(depth, in_K, in_points[, points3d]) -> points3d\n```","ref":"Evision.RGBD.html#depthTo3dSparse/4"},{"type":"function","title":"Evision.RGBD.registerDepth/1","doc":"","ref":"Evision.RGBD.html#registerDepth/1"},{"type":"function","title":"Evision.RGBD.registerDepth/6","doc":"registerDepth\n\n##### Positional Arguments\n- **unregisteredCameraMatrix**: `Evision.Mat`.\n\n  the camera matrix of the depth camera\n\n- **registeredCameraMatrix**: `Evision.Mat`.\n\n  the camera matrix of the external camera\n\n- **registeredDistCoeffs**: `Evision.Mat`.\n\n  the distortion coefficients of the external camera\n\n- **rt**: `Evision.Mat`.\n\n  the rigid body transform between the cameras. Transforms points from depth camera frame to external camera frame.\n\n- **unregisteredDepth**: `Evision.Mat`.\n\n  the input depth data\n\n- **outputImagePlaneSize**: `Size`.\n\n  the image plane dimensions of the external camera (width, height)\n\n##### Keyword Arguments\n- **depthDilation**: `bool`.\n\n  whether or not the depth is dilated to avoid holes and occlusion errors (optional)\n\n##### Return\n- **registeredDepth**: `Evision.Mat.t()`.\n\n  the result of transforming the depth into the external camera\n\nRegisters depth data to an external camera\n Registration is performed by creating a depth cloud, transforming the cloud by\n the rigid body transformation between the cameras, and then projecting the\n transformed points into the RGB camera.\n uv_rgb = K_rgb * [R | t] * z * inv(K_ir) * uv_ir\n Currently does not check for negative depth values.\n\nPython prototype (for reference only):\n```python3\nregisterDepth(unregisteredCameraMatrix, registeredCameraMatrix, registeredDistCoeffs, Rt, unregisteredDepth, outputImagePlaneSize[, registeredDepth[, depthDilation]]) -> registeredDepth\n```","ref":"Evision.RGBD.html#registerDepth/6"},{"type":"function","title":"Evision.RGBD.registerDepth/7","doc":"registerDepth\n\n##### Positional Arguments\n- **unregisteredCameraMatrix**: `Evision.Mat`.\n\n  the camera matrix of the depth camera\n\n- **registeredCameraMatrix**: `Evision.Mat`.\n\n  the camera matrix of the external camera\n\n- **registeredDistCoeffs**: `Evision.Mat`.\n\n  the distortion coefficients of the external camera\n\n- **rt**: `Evision.Mat`.\n\n  the rigid body transform between the cameras. Transforms points from depth camera frame to external camera frame.\n\n- **unregisteredDepth**: `Evision.Mat`.\n\n  the input depth data\n\n- **outputImagePlaneSize**: `Size`.\n\n  the image plane dimensions of the external camera (width, height)\n\n##### Keyword Arguments\n- **depthDilation**: `bool`.\n\n  whether or not the depth is dilated to avoid holes and occlusion errors (optional)\n\n##### Return\n- **registeredDepth**: `Evision.Mat.t()`.\n\n  the result of transforming the depth into the external camera\n\nRegisters depth data to an external camera\n Registration is performed by creating a depth cloud, transforming the cloud by\n the rigid body transformation between the cameras, and then projecting the\n transformed points into the RGB camera.\n uv_rgb = K_rgb * [R | t] * z * inv(K_ir) * uv_ir\n Currently does not check for negative depth values.\n\nPython prototype (for reference only):\n```python3\nregisterDepth(unregisteredCameraMatrix, registeredCameraMatrix, registeredDistCoeffs, Rt, unregisteredDepth, outputImagePlaneSize[, registeredDepth[, depthDilation]]) -> registeredDepth\n```","ref":"Evision.RGBD.html#registerDepth/7"},{"type":"function","title":"Evision.RGBD.rescaleDepth/1","doc":"","ref":"Evision.RGBD.html#rescaleDepth/1"},{"type":"function","title":"Evision.RGBD.rescaleDepth/2","doc":"rescaleDepth\n\n##### Positional Arguments\n- **arg_in**: `Evision.Mat`.\n\n  the depth image (if given as short int CV_U, it is assumed to be the depth in millimeters\n  (as done with the Microsoft Kinect), it is assumed in meters)\n\n- **depth**: `integer()`.\n\n  the desired output depth (floats or double)\n\n##### Keyword Arguments\n- **depth_factor**: `double`.\n\n  (optional) factor by which depth is converted to distance (by default = 1000.0 for Kinect sensor)\n\n##### Return\n- **out**: `Evision.Mat.t()`.\n\n  The rescaled float depth image\n\nIf the input image is of type CV_16UC1 (like the Kinect one), the image is converted to floats, divided\n by depth_factor to get a depth in meters, and the values 0 are converted to std::numeric_limits ::quiet_NaN()\n Otherwise, the image is simply converted to floats\n\nPython prototype (for reference only):\n```python3\nrescaleDepth(in, depth[, out[, depth_factor]]) -> out\n```","ref":"Evision.RGBD.html#rescaleDepth/2"},{"type":"function","title":"Evision.RGBD.rescaleDepth/3","doc":"rescaleDepth\n\n##### Positional Arguments\n- **arg_in**: `Evision.Mat`.\n\n  the depth image (if given as short int CV_U, it is assumed to be the depth in millimeters\n  (as done with the Microsoft Kinect), it is assumed in meters)\n\n- **depth**: `integer()`.\n\n  the desired output depth (floats or double)\n\n##### Keyword Arguments\n- **depth_factor**: `double`.\n\n  (optional) factor by which depth is converted to distance (by default = 1000.0 for Kinect sensor)\n\n##### Return\n- **out**: `Evision.Mat.t()`.\n\n  The rescaled float depth image\n\nIf the input image is of type CV_16UC1 (like the Kinect one), the image is converted to floats, divided\n by depth_factor to get a depth in meters, and the values 0 are converted to std::numeric_limits ::quiet_NaN()\n Otherwise, the image is simply converted to floats\n\nPython prototype (for reference only):\n```python3\nrescaleDepth(in, depth[, out[, depth_factor]]) -> out\n```","ref":"Evision.RGBD.html#rescaleDepth/3"},{"type":"function","title":"Evision.RGBD.warpFrame/1","doc":"","ref":"Evision.RGBD.html#warpFrame/1"},{"type":"function","title":"Evision.RGBD.warpFrame/6","doc":"warpFrame\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  The image (of CV_8UC1 or CV_8UC3 type)\n\n- **depth**: `Evision.Mat`.\n\n  The depth (of type used in depthTo3d fuction)\n\n- **mask**: `Evision.Mat`.\n\n  The mask of used pixels (of CV_8UC1), it can be empty\n\n- **rt**: `Evision.Mat`.\n\n  The transformation that will be applied to the 3d points computed from the depth\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Camera matrix\n\n- **distCoeff**: `Evision.Mat`.\n\n  Distortion coefficients\n\n##### Return\n- **warpedImage**: `Evision.Mat.t()`.\n\n  The warped image.\n\n- **warpedDepth**: `Evision.Mat.t()`.\n\n  The warped depth.\n\n- **warpedMask**: `Evision.Mat.t()`.\n\n  The warped mask.\n\nWarp the image: compute 3d points from the depth, transform them using given transformation,\n then project color point cloud to an image plane.\n This function can be used to visualize results of the Odometry algorithm.\n\nPython prototype (for reference only):\n```python3\nwarpFrame(image, depth, mask, Rt, cameraMatrix, distCoeff[, warpedImage[, warpedDepth[, warpedMask]]]) -> warpedImage, warpedDepth, warpedMask\n```","ref":"Evision.RGBD.html#warpFrame/6"},{"type":"function","title":"Evision.RGBD.warpFrame/7","doc":"warpFrame\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  The image (of CV_8UC1 or CV_8UC3 type)\n\n- **depth**: `Evision.Mat`.\n\n  The depth (of type used in depthTo3d fuction)\n\n- **mask**: `Evision.Mat`.\n\n  The mask of used pixels (of CV_8UC1), it can be empty\n\n- **rt**: `Evision.Mat`.\n\n  The transformation that will be applied to the 3d points computed from the depth\n\n- **cameraMatrix**: `Evision.Mat`.\n\n  Camera matrix\n\n- **distCoeff**: `Evision.Mat`.\n\n  Distortion coefficients\n\n##### Return\n- **warpedImage**: `Evision.Mat.t()`.\n\n  The warped image.\n\n- **warpedDepth**: `Evision.Mat.t()`.\n\n  The warped depth.\n\n- **warpedMask**: `Evision.Mat.t()`.\n\n  The warped mask.\n\nWarp the image: compute 3d points from the depth, transform them using given transformation,\n then project color point cloud to an image plane.\n This function can be used to visualize results of the Odometry algorithm.\n\nPython prototype (for reference only):\n```python3\nwarpFrame(image, depth, mask, Rt, cameraMatrix, distCoeff[, warpedImage[, warpedDepth[, warpedMask]]]) -> warpedImage, warpedDepth, warpedMask\n```","ref":"Evision.RGBD.html#warpFrame/7"},{"type":"type","title":"Evision.RGBD.t/0","doc":"Type that represents an `RGBD` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.RGBD.html#t:t/0"},{"type":"module","title":"Evision.RGBD.DepthCleaner","doc":"","ref":"Evision.RGBD.DepthCleaner.html"},{"type":"function","title":"Evision.RGBD.DepthCleaner.apply/1","doc":"","ref":"Evision.RGBD.DepthCleaner.html#apply/1"},{"type":"function","title":"Evision.RGBD.DepthCleaner.apply/2","doc":"apply\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.DepthCleaner.t()`\n- **points**: `Evision.Mat`.\n\n  a rows x cols x 3 matrix of CV_32F/CV64F or a rows x cols x 1 CV_U16S\n\n##### Return\n- **depth**: `Evision.Mat.t()`.\n\n  a rows x cols matrix of the cleaned up depth\n\nGiven a set of 3d points in a depth image, compute the normals at each point.\n\nPython prototype (for reference only):\n```python3\napply(points[, depth]) -> depth\n```","ref":"Evision.RGBD.DepthCleaner.html#apply/2"},{"type":"function","title":"Evision.RGBD.DepthCleaner.apply/3","doc":"apply\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.DepthCleaner.t()`\n- **points**: `Evision.Mat`.\n\n  a rows x cols x 3 matrix of CV_32F/CV64F or a rows x cols x 1 CV_U16S\n\n##### Return\n- **depth**: `Evision.Mat.t()`.\n\n  a rows x cols matrix of the cleaned up depth\n\nGiven a set of 3d points in a depth image, compute the normals at each point.\n\nPython prototype (for reference only):\n```python3\napply(points[, depth]) -> depth\n```","ref":"Evision.RGBD.DepthCleaner.html#apply/3"},{"type":"function","title":"Evision.RGBD.DepthCleaner.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.DepthCleaner.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.RGBD.DepthCleaner.html#clear/1"},{"type":"function","title":"Evision.RGBD.DepthCleaner.create/1","doc":"create\n\n##### Positional Arguments\n- **depth**: `integer()`.\n\n  the depth of the normals (only CV_32F or CV_64F)\n\n##### Keyword Arguments\n- **window_size**: `integer()`.\n\n  the window size to compute the normals: can only be 1,3,5 or 7\n\n- **method**: `integer()`.\n\n  one of the methods to use: RGBD_NORMALS_METHOD_SRI, RGBD_NORMALS_METHOD_FALS\n\n##### Return\n- **retval**: `DepthCleaner`\n\nConstructor\n\nPython prototype (for reference only):\n```python3\ncreate(depth[, window_size[, method]]) -> retval\n```","ref":"Evision.RGBD.DepthCleaner.html#create/1"},{"type":"function","title":"Evision.RGBD.DepthCleaner.create/2","doc":"create\n\n##### Positional Arguments\n- **depth**: `integer()`.\n\n  the depth of the normals (only CV_32F or CV_64F)\n\n##### Keyword Arguments\n- **window_size**: `integer()`.\n\n  the window size to compute the normals: can only be 1,3,5 or 7\n\n- **method**: `integer()`.\n\n  one of the methods to use: RGBD_NORMALS_METHOD_SRI, RGBD_NORMALS_METHOD_FALS\n\n##### Return\n- **retval**: `DepthCleaner`\n\nConstructor\n\nPython prototype (for reference only):\n```python3\ncreate(depth[, window_size[, method]]) -> retval\n```","ref":"Evision.RGBD.DepthCleaner.html#create/2"},{"type":"function","title":"Evision.RGBD.DepthCleaner.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.DepthCleaner.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.RGBD.DepthCleaner.html#empty/1"},{"type":"function","title":"Evision.RGBD.DepthCleaner.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.DepthCleaner.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.RGBD.DepthCleaner.html#getDefaultName/1"},{"type":"function","title":"Evision.RGBD.DepthCleaner.getDepth/1","doc":"getDepth\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.DepthCleaner.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetDepth() -> retval\n```","ref":"Evision.RGBD.DepthCleaner.html#getDepth/1"},{"type":"function","title":"Evision.RGBD.DepthCleaner.getMethod/1","doc":"getMethod\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.DepthCleaner.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMethod() -> retval\n```","ref":"Evision.RGBD.DepthCleaner.html#getMethod/1"},{"type":"function","title":"Evision.RGBD.DepthCleaner.getWindowSize/1","doc":"getWindowSize\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.DepthCleaner.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetWindowSize() -> retval\n```","ref":"Evision.RGBD.DepthCleaner.html#getWindowSize/1"},{"type":"function","title":"Evision.RGBD.DepthCleaner.initialize/1","doc":"initialize\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.DepthCleaner.t()`\n\nInitializes some data that is cached for later computation\n If that function is not called, it will be called the first time normals are computed\n\nPython prototype (for reference only):\n```python3\ninitialize() -> None\n```","ref":"Evision.RGBD.DepthCleaner.html#initialize/1"},{"type":"function","title":"Evision.RGBD.DepthCleaner.read/1","doc":"","ref":"Evision.RGBD.DepthCleaner.html#read/1"},{"type":"function","title":"Evision.RGBD.DepthCleaner.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.DepthCleaner.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.RGBD.DepthCleaner.html#read/2"},{"type":"function","title":"Evision.RGBD.DepthCleaner.save/1","doc":"","ref":"Evision.RGBD.DepthCleaner.html#save/1"},{"type":"function","title":"Evision.RGBD.DepthCleaner.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.DepthCleaner.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.RGBD.DepthCleaner.html#save/2"},{"type":"function","title":"Evision.RGBD.DepthCleaner.setDepth/1","doc":"","ref":"Evision.RGBD.DepthCleaner.html#setDepth/1"},{"type":"function","title":"Evision.RGBD.DepthCleaner.setDepth/2","doc":"setDepth\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.DepthCleaner.t()`\n- **val**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetDepth(val) -> None\n```","ref":"Evision.RGBD.DepthCleaner.html#setDepth/2"},{"type":"function","title":"Evision.RGBD.DepthCleaner.setMethod/1","doc":"","ref":"Evision.RGBD.DepthCleaner.html#setMethod/1"},{"type":"function","title":"Evision.RGBD.DepthCleaner.setMethod/2","doc":"setMethod\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.DepthCleaner.t()`\n- **val**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMethod(val) -> None\n```","ref":"Evision.RGBD.DepthCleaner.html#setMethod/2"},{"type":"function","title":"Evision.RGBD.DepthCleaner.setWindowSize/1","doc":"","ref":"Evision.RGBD.DepthCleaner.html#setWindowSize/1"},{"type":"function","title":"Evision.RGBD.DepthCleaner.setWindowSize/2","doc":"setWindowSize\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.DepthCleaner.t()`\n- **val**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetWindowSize(val) -> None\n```","ref":"Evision.RGBD.DepthCleaner.html#setWindowSize/2"},{"type":"function","title":"Evision.RGBD.DepthCleaner.write/1","doc":"","ref":"Evision.RGBD.DepthCleaner.html#write/1"},{"type":"function","title":"Evision.RGBD.DepthCleaner.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.DepthCleaner.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.RGBD.DepthCleaner.html#write/2"},{"type":"function","title":"Evision.RGBD.DepthCleaner.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.DepthCleaner.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.RGBD.DepthCleaner.html#write/3"},{"type":"type","title":"Evision.RGBD.DepthCleaner.t/0","doc":"Type that represents an `RGBD.DepthCleaner` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.RGBD.DepthCleaner.html#t:t/0"},{"type":"module","title":"Evision.RGBD.DepthCleaner.DEPTH_CLEANER_METHOD","doc":"","ref":"Evision.RGBD.DepthCleaner.DEPTH_CLEANER_METHOD.html"},{"type":"function","title":"Evision.RGBD.DepthCleaner.DEPTH_CLEANER_METHOD.cv_DEPTH_CLEANER_NIL/0","doc":"","ref":"Evision.RGBD.DepthCleaner.DEPTH_CLEANER_METHOD.html#cv_DEPTH_CLEANER_NIL/0"},{"type":"type","title":"Evision.RGBD.DepthCleaner.DEPTH_CLEANER_METHOD.enum/0","doc":"","ref":"Evision.RGBD.DepthCleaner.DEPTH_CLEANER_METHOD.html#t:enum/0"},{"type":"module","title":"Evision.RGBD.FastICPOdometry","doc":"","ref":"Evision.RGBD.FastICPOdometry.html"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.create/1","doc":"create\n\n##### Positional Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  Camera matrix\n\n##### Keyword Arguments\n- **maxDistDiff**: `float`.\n\n  Correspondences between pixels of two given frames will be filtered out\n  if their depth difference is larger than maxDepthDiff\n\n- **angleThreshold**: `float`.\n\n  Correspondence will be filtered out\n  if an angle between their normals is bigger than threshold\n\n- **sigmaDepth**: `float`.\n\n  Depth sigma in meters for bilateral smooth\n\n- **sigmaSpatial**: `float`.\n\n  Spatial sigma in pixels for bilateral smooth\n\n- **kernelSize**: `integer()`.\n\n  Kernel size in pixels for bilateral smooth\n\n- **iterCounts**: `[integer()]`.\n\n  Count of iterations on each pyramid level\n\n##### Return\n- **retval**: `FastICPOdometry`\n\nConstructor.\n\nPython prototype (for reference only):\n```python3\ncreate(cameraMatrix[, maxDistDiff[, angleThreshold[, sigmaDepth[, sigmaSpatial[, kernelSize[, iterCounts]]]]]]) -> retval\n```","ref":"Evision.RGBD.FastICPOdometry.html#create/1"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.create/2","doc":"create\n\n##### Positional Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  Camera matrix\n\n##### Keyword Arguments\n- **maxDistDiff**: `float`.\n\n  Correspondences between pixels of two given frames will be filtered out\n  if their depth difference is larger than maxDepthDiff\n\n- **angleThreshold**: `float`.\n\n  Correspondence will be filtered out\n  if an angle between their normals is bigger than threshold\n\n- **sigmaDepth**: `float`.\n\n  Depth sigma in meters for bilateral smooth\n\n- **sigmaSpatial**: `float`.\n\n  Spatial sigma in pixels for bilateral smooth\n\n- **kernelSize**: `integer()`.\n\n  Kernel size in pixels for bilateral smooth\n\n- **iterCounts**: `[integer()]`.\n\n  Count of iterations on each pyramid level\n\n##### Return\n- **retval**: `FastICPOdometry`\n\nConstructor.\n\nPython prototype (for reference only):\n```python3\ncreate(cameraMatrix[, maxDistDiff[, angleThreshold[, sigmaDepth[, sigmaSpatial[, kernelSize[, iterCounts]]]]]]) -> retval\n```","ref":"Evision.RGBD.FastICPOdometry.html#create/2"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.getAngleThreshold/1","doc":"getAngleThreshold\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.FastICPOdometry.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetAngleThreshold() -> retval\n```","ref":"Evision.RGBD.FastICPOdometry.html#getAngleThreshold/1"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.getCameraMatrix/1","doc":"getCameraMatrix\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.FastICPOdometry.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetCameraMatrix() -> retval\n```","ref":"Evision.RGBD.FastICPOdometry.html#getCameraMatrix/1"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.getIterationCounts/1","doc":"getIterationCounts\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.FastICPOdometry.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetIterationCounts() -> retval\n```","ref":"Evision.RGBD.FastICPOdometry.html#getIterationCounts/1"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.getKernelSize/1","doc":"getKernelSize\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.FastICPOdometry.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetKernelSize() -> retval\n```","ref":"Evision.RGBD.FastICPOdometry.html#getKernelSize/1"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.getMaxDistDiff/1","doc":"getMaxDistDiff\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.FastICPOdometry.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxDistDiff() -> retval\n```","ref":"Evision.RGBD.FastICPOdometry.html#getMaxDistDiff/1"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.getSigmaDepth/1","doc":"getSigmaDepth\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.FastICPOdometry.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetSigmaDepth() -> retval\n```","ref":"Evision.RGBD.FastICPOdometry.html#getSigmaDepth/1"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.getSigmaSpatial/1","doc":"getSigmaSpatial\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.FastICPOdometry.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetSigmaSpatial() -> retval\n```","ref":"Evision.RGBD.FastICPOdometry.html#getSigmaSpatial/1"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.getTransformType/1","doc":"getTransformType\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.FastICPOdometry.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetTransformType() -> retval\n```","ref":"Evision.RGBD.FastICPOdometry.html#getTransformType/1"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.prepareFrameCache/1","doc":"","ref":"Evision.RGBD.FastICPOdometry.html#prepareFrameCache/1"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.prepareFrameCache/3","doc":"prepareFrameCache\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.FastICPOdometry.t()`\n- **frame**: `OdometryFrame`\n- **cacheType**: `integer()`\n\n##### Return\n- **retval**: `Size`\n\nPython prototype (for reference only):\n```python3\nprepareFrameCache(frame, cacheType) -> retval\n```","ref":"Evision.RGBD.FastICPOdometry.html#prepareFrameCache/3"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.setAngleThreshold/1","doc":"","ref":"Evision.RGBD.FastICPOdometry.html#setAngleThreshold/1"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.setAngleThreshold/2","doc":"setAngleThreshold\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.FastICPOdometry.t()`\n- **f**: `float`\n\nPython prototype (for reference only):\n```python3\nsetAngleThreshold(f) -> None\n```","ref":"Evision.RGBD.FastICPOdometry.html#setAngleThreshold/2"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.setCameraMatrix/1","doc":"","ref":"Evision.RGBD.FastICPOdometry.html#setCameraMatrix/1"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.setCameraMatrix/2","doc":"setCameraMatrix\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.FastICPOdometry.t()`\n- **val**: `Evision.Mat`\n\nPython prototype (for reference only):\n```python3\nsetCameraMatrix(val) -> None\n```","ref":"Evision.RGBD.FastICPOdometry.html#setCameraMatrix/2"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.setIterationCounts/1","doc":"","ref":"Evision.RGBD.FastICPOdometry.html#setIterationCounts/1"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.setIterationCounts/2","doc":"setIterationCounts\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.FastICPOdometry.t()`\n- **val**: `Evision.Mat`\n\nPython prototype (for reference only):\n```python3\nsetIterationCounts(val) -> None\n```","ref":"Evision.RGBD.FastICPOdometry.html#setIterationCounts/2"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.setKernelSize/1","doc":"","ref":"Evision.RGBD.FastICPOdometry.html#setKernelSize/1"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.setKernelSize/2","doc":"setKernelSize\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.FastICPOdometry.t()`\n- **f**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetKernelSize(f) -> None\n```","ref":"Evision.RGBD.FastICPOdometry.html#setKernelSize/2"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.setMaxDistDiff/1","doc":"","ref":"Evision.RGBD.FastICPOdometry.html#setMaxDistDiff/1"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.setMaxDistDiff/2","doc":"setMaxDistDiff\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.FastICPOdometry.t()`\n- **val**: `float`\n\nPython prototype (for reference only):\n```python3\nsetMaxDistDiff(val) -> None\n```","ref":"Evision.RGBD.FastICPOdometry.html#setMaxDistDiff/2"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.setSigmaDepth/1","doc":"","ref":"Evision.RGBD.FastICPOdometry.html#setSigmaDepth/1"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.setSigmaDepth/2","doc":"setSigmaDepth\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.FastICPOdometry.t()`\n- **f**: `float`\n\nPython prototype (for reference only):\n```python3\nsetSigmaDepth(f) -> None\n```","ref":"Evision.RGBD.FastICPOdometry.html#setSigmaDepth/2"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.setSigmaSpatial/1","doc":"","ref":"Evision.RGBD.FastICPOdometry.html#setSigmaSpatial/1"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.setSigmaSpatial/2","doc":"setSigmaSpatial\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.FastICPOdometry.t()`\n- **f**: `float`\n\nPython prototype (for reference only):\n```python3\nsetSigmaSpatial(f) -> None\n```","ref":"Evision.RGBD.FastICPOdometry.html#setSigmaSpatial/2"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.setTransformType/1","doc":"","ref":"Evision.RGBD.FastICPOdometry.html#setTransformType/1"},{"type":"function","title":"Evision.RGBD.FastICPOdometry.setTransformType/2","doc":"setTransformType\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.FastICPOdometry.t()`\n- **val**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetTransformType(val) -> None\n```","ref":"Evision.RGBD.FastICPOdometry.html#setTransformType/2"},{"type":"type","title":"Evision.RGBD.FastICPOdometry.t/0","doc":"Type that represents an `RGBD.FastICPOdometry` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.RGBD.FastICPOdometry.html#t:t/0"},{"type":"module","title":"Evision.RGBD.ICPOdometry","doc":"","ref":"Evision.RGBD.ICPOdometry.html"},{"type":"function","title":"Evision.RGBD.ICPOdometry.create/0","doc":"create\n##### Keyword Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  Camera matrix\n\n- **minDepth**: `float`.\n\n  Pixels with depth less than minDepth will not be used\n\n- **maxDepth**: `float`.\n\n  Pixels with depth larger than maxDepth will not be used\n\n- **maxDepthDiff**: `float`.\n\n  Correspondences between pixels of two given frames will be filtered out\n  if their depth difference is larger than maxDepthDiff\n\n- **maxPointsPart**: `float`.\n\n  The method uses a random pixels subset of size frameWidth x frameHeight x pointsPart\n\n- **iterCounts**: `[integer()]`.\n\n  Count of iterations on each pyramid level.\n\n- **transformType**: `integer()`.\n\n  Class of trasformation\n\n##### Return\n- **retval**: `ICPOdometry`\n\nConstructor.\n\nPython prototype (for reference only):\n```python3\ncreate([, cameraMatrix[, minDepth[, maxDepth[, maxDepthDiff[, maxPointsPart[, iterCounts[, transformType]]]]]]]) -> retval\n```","ref":"Evision.RGBD.ICPOdometry.html#create/0"},{"type":"function","title":"Evision.RGBD.ICPOdometry.create/1","doc":"create\n##### Keyword Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  Camera matrix\n\n- **minDepth**: `float`.\n\n  Pixels with depth less than minDepth will not be used\n\n- **maxDepth**: `float`.\n\n  Pixels with depth larger than maxDepth will not be used\n\n- **maxDepthDiff**: `float`.\n\n  Correspondences between pixels of two given frames will be filtered out\n  if their depth difference is larger than maxDepthDiff\n\n- **maxPointsPart**: `float`.\n\n  The method uses a random pixels subset of size frameWidth x frameHeight x pointsPart\n\n- **iterCounts**: `[integer()]`.\n\n  Count of iterations on each pyramid level.\n\n- **transformType**: `integer()`.\n\n  Class of trasformation\n\n##### Return\n- **retval**: `ICPOdometry`\n\nConstructor.\n\nPython prototype (for reference only):\n```python3\ncreate([, cameraMatrix[, minDepth[, maxDepth[, maxDepthDiff[, maxPointsPart[, iterCounts[, transformType]]]]]]]) -> retval\n```","ref":"Evision.RGBD.ICPOdometry.html#create/1"},{"type":"function","title":"Evision.RGBD.ICPOdometry.getCameraMatrix/1","doc":"getCameraMatrix\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.ICPOdometry.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetCameraMatrix() -> retval\n```","ref":"Evision.RGBD.ICPOdometry.html#getCameraMatrix/1"},{"type":"function","title":"Evision.RGBD.ICPOdometry.getIterationCounts/1","doc":"getIterationCounts\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.ICPOdometry.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetIterationCounts() -> retval\n```","ref":"Evision.RGBD.ICPOdometry.html#getIterationCounts/1"},{"type":"function","title":"Evision.RGBD.ICPOdometry.getMaxDepth/1","doc":"getMaxDepth\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.ICPOdometry.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxDepth() -> retval\n```","ref":"Evision.RGBD.ICPOdometry.html#getMaxDepth/1"},{"type":"function","title":"Evision.RGBD.ICPOdometry.getMaxDepthDiff/1","doc":"getMaxDepthDiff\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.ICPOdometry.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxDepthDiff() -> retval\n```","ref":"Evision.RGBD.ICPOdometry.html#getMaxDepthDiff/1"},{"type":"function","title":"Evision.RGBD.ICPOdometry.getMaxPointsPart/1","doc":"getMaxPointsPart\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.ICPOdometry.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxPointsPart() -> retval\n```","ref":"Evision.RGBD.ICPOdometry.html#getMaxPointsPart/1"},{"type":"function","title":"Evision.RGBD.ICPOdometry.getMaxRotation/1","doc":"getMaxRotation\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.ICPOdometry.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxRotation() -> retval\n```","ref":"Evision.RGBD.ICPOdometry.html#getMaxRotation/1"},{"type":"function","title":"Evision.RGBD.ICPOdometry.getMaxTranslation/1","doc":"getMaxTranslation\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.ICPOdometry.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxTranslation() -> retval\n```","ref":"Evision.RGBD.ICPOdometry.html#getMaxTranslation/1"},{"type":"function","title":"Evision.RGBD.ICPOdometry.getMinDepth/1","doc":"getMinDepth\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.ICPOdometry.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMinDepth() -> retval\n```","ref":"Evision.RGBD.ICPOdometry.html#getMinDepth/1"},{"type":"function","title":"Evision.RGBD.ICPOdometry.getNormalsComputer/1","doc":"getNormalsComputer\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.ICPOdometry.t()`\n\n##### Return\n- **retval**: `RgbdNormals`\n\nPython prototype (for reference only):\n```python3\ngetNormalsComputer() -> retval\n```","ref":"Evision.RGBD.ICPOdometry.html#getNormalsComputer/1"},{"type":"function","title":"Evision.RGBD.ICPOdometry.getTransformType/1","doc":"getTransformType\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.ICPOdometry.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetTransformType() -> retval\n```","ref":"Evision.RGBD.ICPOdometry.html#getTransformType/1"},{"type":"function","title":"Evision.RGBD.ICPOdometry.prepareFrameCache/1","doc":"","ref":"Evision.RGBD.ICPOdometry.html#prepareFrameCache/1"},{"type":"function","title":"Evision.RGBD.ICPOdometry.prepareFrameCache/3","doc":"prepareFrameCache\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.ICPOdometry.t()`\n- **frame**: `OdometryFrame`\n- **cacheType**: `integer()`\n\n##### Return\n- **retval**: `Size`\n\nPython prototype (for reference only):\n```python3\nprepareFrameCache(frame, cacheType) -> retval\n```","ref":"Evision.RGBD.ICPOdometry.html#prepareFrameCache/3"},{"type":"function","title":"Evision.RGBD.ICPOdometry.setCameraMatrix/1","doc":"","ref":"Evision.RGBD.ICPOdometry.html#setCameraMatrix/1"},{"type":"function","title":"Evision.RGBD.ICPOdometry.setCameraMatrix/2","doc":"setCameraMatrix\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.ICPOdometry.t()`\n- **val**: `Evision.Mat`\n\nPython prototype (for reference only):\n```python3\nsetCameraMatrix(val) -> None\n```","ref":"Evision.RGBD.ICPOdometry.html#setCameraMatrix/2"},{"type":"function","title":"Evision.RGBD.ICPOdometry.setIterationCounts/1","doc":"","ref":"Evision.RGBD.ICPOdometry.html#setIterationCounts/1"},{"type":"function","title":"Evision.RGBD.ICPOdometry.setIterationCounts/2","doc":"setIterationCounts\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.ICPOdometry.t()`\n- **val**: `Evision.Mat`\n\nPython prototype (for reference only):\n```python3\nsetIterationCounts(val) -> None\n```","ref":"Evision.RGBD.ICPOdometry.html#setIterationCounts/2"},{"type":"function","title":"Evision.RGBD.ICPOdometry.setMaxDepth/1","doc":"","ref":"Evision.RGBD.ICPOdometry.html#setMaxDepth/1"},{"type":"function","title":"Evision.RGBD.ICPOdometry.setMaxDepth/2","doc":"setMaxDepth\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.ICPOdometry.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxDepth(val) -> None\n```","ref":"Evision.RGBD.ICPOdometry.html#setMaxDepth/2"},{"type":"function","title":"Evision.RGBD.ICPOdometry.setMaxDepthDiff/1","doc":"","ref":"Evision.RGBD.ICPOdometry.html#setMaxDepthDiff/1"},{"type":"function","title":"Evision.RGBD.ICPOdometry.setMaxDepthDiff/2","doc":"setMaxDepthDiff\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.ICPOdometry.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxDepthDiff(val) -> None\n```","ref":"Evision.RGBD.ICPOdometry.html#setMaxDepthDiff/2"},{"type":"function","title":"Evision.RGBD.ICPOdometry.setMaxPointsPart/1","doc":"","ref":"Evision.RGBD.ICPOdometry.html#setMaxPointsPart/1"},{"type":"function","title":"Evision.RGBD.ICPOdometry.setMaxPointsPart/2","doc":"setMaxPointsPart\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.ICPOdometry.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxPointsPart(val) -> None\n```","ref":"Evision.RGBD.ICPOdometry.html#setMaxPointsPart/2"},{"type":"function","title":"Evision.RGBD.ICPOdometry.setMaxRotation/1","doc":"","ref":"Evision.RGBD.ICPOdometry.html#setMaxRotation/1"},{"type":"function","title":"Evision.RGBD.ICPOdometry.setMaxRotation/2","doc":"setMaxRotation\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.ICPOdometry.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxRotation(val) -> None\n```","ref":"Evision.RGBD.ICPOdometry.html#setMaxRotation/2"},{"type":"function","title":"Evision.RGBD.ICPOdometry.setMaxTranslation/1","doc":"","ref":"Evision.RGBD.ICPOdometry.html#setMaxTranslation/1"},{"type":"function","title":"Evision.RGBD.ICPOdometry.setMaxTranslation/2","doc":"setMaxTranslation\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.ICPOdometry.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxTranslation(val) -> None\n```","ref":"Evision.RGBD.ICPOdometry.html#setMaxTranslation/2"},{"type":"function","title":"Evision.RGBD.ICPOdometry.setMinDepth/1","doc":"","ref":"Evision.RGBD.ICPOdometry.html#setMinDepth/1"},{"type":"function","title":"Evision.RGBD.ICPOdometry.setMinDepth/2","doc":"setMinDepth\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.ICPOdometry.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMinDepth(val) -> None\n```","ref":"Evision.RGBD.ICPOdometry.html#setMinDepth/2"},{"type":"function","title":"Evision.RGBD.ICPOdometry.setTransformType/1","doc":"","ref":"Evision.RGBD.ICPOdometry.html#setTransformType/1"},{"type":"function","title":"Evision.RGBD.ICPOdometry.setTransformType/2","doc":"setTransformType\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.ICPOdometry.t()`\n- **val**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetTransformType(val) -> None\n```","ref":"Evision.RGBD.ICPOdometry.html#setTransformType/2"},{"type":"type","title":"Evision.RGBD.ICPOdometry.t/0","doc":"Type that represents an `RGBD.ICPOdometry` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.RGBD.ICPOdometry.html#t:t/0"},{"type":"module","title":"Evision.RGBD.Odometry","doc":"","ref":"Evision.RGBD.Odometry.html"},{"type":"function","title":"Evision.RGBD.Odometry.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.Odometry.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.RGBD.Odometry.html#clear/1"},{"type":"function","title":"Evision.RGBD.Odometry.compute2/1","doc":"","ref":"Evision.RGBD.Odometry.html#compute2/1"},{"type":"function","title":"Evision.RGBD.Odometry.compute2/3","doc":"compute2\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.Odometry.t()`\n- **srcFrame**: `OdometryFrame`\n- **dstFrame**: `OdometryFrame`\n\n##### Keyword Arguments\n- **initRt**: `Evision.Mat`.\n\n##### Return\n- **retval**: `bool`\n- **rt**: `Evision.Mat.t()`.\n\nOne more method to compute a transformation from the source frame to the destination one.\n It is designed to save on computing the frame data (image pyramids, normals, etc.).\n\nPython prototype (for reference only):\n```python3\ncompute2(srcFrame, dstFrame[, Rt[, initRt]]) -> retval, Rt\n```","ref":"Evision.RGBD.Odometry.html#compute2/3"},{"type":"function","title":"Evision.RGBD.Odometry.compute2/4","doc":"compute2\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.Odometry.t()`\n- **srcFrame**: `OdometryFrame`\n- **dstFrame**: `OdometryFrame`\n\n##### Keyword Arguments\n- **initRt**: `Evision.Mat`.\n\n##### Return\n- **retval**: `bool`\n- **rt**: `Evision.Mat.t()`.\n\nOne more method to compute a transformation from the source frame to the destination one.\n It is designed to save on computing the frame data (image pyramids, normals, etc.).\n\nPython prototype (for reference only):\n```python3\ncompute2(srcFrame, dstFrame[, Rt[, initRt]]) -> retval, Rt\n```","ref":"Evision.RGBD.Odometry.html#compute2/4"},{"type":"function","title":"Evision.RGBD.Odometry.compute/1","doc":"","ref":"Evision.RGBD.Odometry.html#compute/1"},{"type":"function","title":"Evision.RGBD.Odometry.compute/7","doc":"compute\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.Odometry.t()`\n- **srcImage**: `Evision.Mat`.\n\n  Image data of the source frame (CV_8UC1)\n\n- **srcDepth**: `Evision.Mat`.\n\n  Depth data of the source frame (CV_32FC1, in meters)\n\n- **srcMask**: `Evision.Mat`.\n\n  Mask that sets which pixels have to be used from the source frame (CV_8UC1)\n\n- **dstImage**: `Evision.Mat`.\n\n  Image data of the destination frame (CV_8UC1)\n\n- **dstDepth**: `Evision.Mat`.\n\n  Depth data of the destination frame (CV_32FC1, in meters)\n\n- **dstMask**: `Evision.Mat`.\n\n  Mask that sets which pixels have to be used from the destination frame (CV_8UC1)\n\n##### Keyword Arguments\n- **initRt**: `Evision.Mat`.\n\n  Initial transformation from the source frame to the destination one (optional)\n\n##### Return\n- **retval**: `bool`\n- **rt**: `Evision.Mat.t()`.\n\n  Resulting transformation from the source frame to the destination one (rigid body motion):\n  dst_p = Rt * src_p, where dst_p is a homogeneous point in the destination frame and src_p is\n  homogeneous point in the source frame,\n  Rt is 4x4 matrix of CV_64FC1 type.\n\nMethod to compute a transformation from the source frame to the destination one.\n Some odometry algorithms do not used some data of frames (eg. ICP does not use images).\n In such case corresponding arguments can be set as empty Mat.\n The method returns true if all internal computations were possible (e.g. there were enough correspondences,\n system of equations has a solution, etc) and resulting transformation satisfies some test if it's provided\n by the Odometry inheritor implementation (e.g. thresholds for maximum translation and rotation).\n\nPython prototype (for reference only):\n```python3\ncompute(srcImage, srcDepth, srcMask, dstImage, dstDepth, dstMask[, Rt[, initRt]]) -> retval, Rt\n```","ref":"Evision.RGBD.Odometry.html#compute/7"},{"type":"function","title":"Evision.RGBD.Odometry.compute/8","doc":"compute\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.Odometry.t()`\n- **srcImage**: `Evision.Mat`.\n\n  Image data of the source frame (CV_8UC1)\n\n- **srcDepth**: `Evision.Mat`.\n\n  Depth data of the source frame (CV_32FC1, in meters)\n\n- **srcMask**: `Evision.Mat`.\n\n  Mask that sets which pixels have to be used from the source frame (CV_8UC1)\n\n- **dstImage**: `Evision.Mat`.\n\n  Image data of the destination frame (CV_8UC1)\n\n- **dstDepth**: `Evision.Mat`.\n\n  Depth data of the destination frame (CV_32FC1, in meters)\n\n- **dstMask**: `Evision.Mat`.\n\n  Mask that sets which pixels have to be used from the destination frame (CV_8UC1)\n\n##### Keyword Arguments\n- **initRt**: `Evision.Mat`.\n\n  Initial transformation from the source frame to the destination one (optional)\n\n##### Return\n- **retval**: `bool`\n- **rt**: `Evision.Mat.t()`.\n\n  Resulting transformation from the source frame to the destination one (rigid body motion):\n  dst_p = Rt * src_p, where dst_p is a homogeneous point in the destination frame and src_p is\n  homogeneous point in the source frame,\n  Rt is 4x4 matrix of CV_64FC1 type.\n\nMethod to compute a transformation from the source frame to the destination one.\n Some odometry algorithms do not used some data of frames (eg. ICP does not use images).\n In such case corresponding arguments can be set as empty Mat.\n The method returns true if all internal computations were possible (e.g. there were enough correspondences,\n system of equations has a solution, etc) and resulting transformation satisfies some test if it's provided\n by the Odometry inheritor implementation (e.g. thresholds for maximum translation and rotation).\n\nPython prototype (for reference only):\n```python3\ncompute(srcImage, srcDepth, srcMask, dstImage, dstDepth, dstMask[, Rt[, initRt]]) -> retval, Rt\n```","ref":"Evision.RGBD.Odometry.html#compute/8"},{"type":"function","title":"Evision.RGBD.Odometry.create/1","doc":"create\n\n##### Positional Arguments\n- **odometryType**: `String`\n\n##### Return\n- **retval**: `Odometry`\n\nPython prototype (for reference only):\n```python3\ncreate(odometryType) -> retval\n```","ref":"Evision.RGBD.Odometry.html#create/1"},{"type":"function","title":"Evision.RGBD.Odometry.cv_RIGID_BODY_MOTION/0","doc":"","ref":"Evision.RGBD.Odometry.html#cv_RIGID_BODY_MOTION/0"},{"type":"function","title":"Evision.RGBD.Odometry.cv_ROTATION/0","doc":"","ref":"Evision.RGBD.Odometry.html#cv_ROTATION/0"},{"type":"function","title":"Evision.RGBD.Odometry.cv_TRANSLATION/0","doc":"","ref":"Evision.RGBD.Odometry.html#cv_TRANSLATION/0"},{"type":"function","title":"Evision.RGBD.Odometry.default_max_depth/1","doc":"DEFAULT_MAX_DEPTH\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.Odometry.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\nDEFAULT_MAX_DEPTH() -> retval\n```","ref":"Evision.RGBD.Odometry.html#default_max_depth/1"},{"type":"function","title":"Evision.RGBD.Odometry.default_max_depth_diff/1","doc":"DEFAULT_MAX_DEPTH_DIFF\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.Odometry.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\nDEFAULT_MAX_DEPTH_DIFF() -> retval\n```","ref":"Evision.RGBD.Odometry.html#default_max_depth_diff/1"},{"type":"function","title":"Evision.RGBD.Odometry.default_max_points_part/1","doc":"DEFAULT_MAX_POINTS_PART\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.Odometry.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\nDEFAULT_MAX_POINTS_PART() -> retval\n```","ref":"Evision.RGBD.Odometry.html#default_max_points_part/1"},{"type":"function","title":"Evision.RGBD.Odometry.default_max_rotation/1","doc":"DEFAULT_MAX_ROTATION\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.Odometry.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\nDEFAULT_MAX_ROTATION() -> retval\n```","ref":"Evision.RGBD.Odometry.html#default_max_rotation/1"},{"type":"function","title":"Evision.RGBD.Odometry.default_max_translation/1","doc":"DEFAULT_MAX_TRANSLATION\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.Odometry.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\nDEFAULT_MAX_TRANSLATION() -> retval\n```","ref":"Evision.RGBD.Odometry.html#default_max_translation/1"},{"type":"function","title":"Evision.RGBD.Odometry.default_min_depth/1","doc":"DEFAULT_MIN_DEPTH\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.Odometry.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\nDEFAULT_MIN_DEPTH() -> retval\n```","ref":"Evision.RGBD.Odometry.html#default_min_depth/1"},{"type":"function","title":"Evision.RGBD.Odometry.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.Odometry.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.RGBD.Odometry.html#empty/1"},{"type":"function","title":"Evision.RGBD.Odometry.getCameraMatrix/1","doc":"getCameraMatrix\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.Odometry.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n@see `setCameraMatrix/2`\n\nPython prototype (for reference only):\n```python3\ngetCameraMatrix() -> retval\n```","ref":"Evision.RGBD.Odometry.html#getCameraMatrix/1"},{"type":"function","title":"Evision.RGBD.Odometry.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.Odometry.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.RGBD.Odometry.html#getDefaultName/1"},{"type":"function","title":"Evision.RGBD.Odometry.getTransformType/1","doc":"getTransformType\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.Odometry.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setTransformType/2`\n\nPython prototype (for reference only):\n```python3\ngetTransformType() -> retval\n```","ref":"Evision.RGBD.Odometry.html#getTransformType/1"},{"type":"function","title":"Evision.RGBD.Odometry.prepareFrameCache/1","doc":"","ref":"Evision.RGBD.Odometry.html#prepareFrameCache/1"},{"type":"function","title":"Evision.RGBD.Odometry.prepareFrameCache/3","doc":"prepareFrameCache\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.Odometry.t()`\n- **frame**: `OdometryFrame`.\n\n  The odometry which will process the frame.\n\n- **cacheType**: `integer()`.\n\n  The cache type: CACHE_SRC, CACHE_DST or CACHE_ALL.\n\n##### Return\n- **retval**: `Size`\n\nPrepare a cache for the frame. The function checks the precomputed/passed data (throws the error if this data\n does not satisfy) and computes all remaining cache data needed for the frame. Returned size is a resolution\n of the prepared frame.\n\nPython prototype (for reference only):\n```python3\nprepareFrameCache(frame, cacheType) -> retval\n```","ref":"Evision.RGBD.Odometry.html#prepareFrameCache/3"},{"type":"function","title":"Evision.RGBD.Odometry.read/1","doc":"","ref":"Evision.RGBD.Odometry.html#read/1"},{"type":"function","title":"Evision.RGBD.Odometry.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.Odometry.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.RGBD.Odometry.html#read/2"},{"type":"function","title":"Evision.RGBD.Odometry.save/1","doc":"","ref":"Evision.RGBD.Odometry.html#save/1"},{"type":"function","title":"Evision.RGBD.Odometry.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.Odometry.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.RGBD.Odometry.html#save/2"},{"type":"function","title":"Evision.RGBD.Odometry.setCameraMatrix/1","doc":"","ref":"Evision.RGBD.Odometry.html#setCameraMatrix/1"},{"type":"function","title":"Evision.RGBD.Odometry.setCameraMatrix/2","doc":"setCameraMatrix\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.Odometry.t()`\n- **val**: `Evision.Mat`\n\n@see `getCameraMatrix/1`\n\nPython prototype (for reference only):\n```python3\nsetCameraMatrix(val) -> None\n```","ref":"Evision.RGBD.Odometry.html#setCameraMatrix/2"},{"type":"function","title":"Evision.RGBD.Odometry.setTransformType/1","doc":"","ref":"Evision.RGBD.Odometry.html#setTransformType/1"},{"type":"function","title":"Evision.RGBD.Odometry.setTransformType/2","doc":"setTransformType\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.Odometry.t()`\n- **val**: `integer()`\n\n@see `getTransformType/1`\n\nPython prototype (for reference only):\n```python3\nsetTransformType(val) -> None\n```","ref":"Evision.RGBD.Odometry.html#setTransformType/2"},{"type":"function","title":"Evision.RGBD.Odometry.write/1","doc":"","ref":"Evision.RGBD.Odometry.html#write/1"},{"type":"function","title":"Evision.RGBD.Odometry.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.Odometry.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.RGBD.Odometry.html#write/2"},{"type":"function","title":"Evision.RGBD.Odometry.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.Odometry.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.RGBD.Odometry.html#write/3"},{"type":"type","title":"Evision.RGBD.Odometry.enum/0","doc":"","ref":"Evision.RGBD.Odometry.html#t:enum/0"},{"type":"type","title":"Evision.RGBD.Odometry.t/0","doc":"Type that represents an `RGBD.Odometry` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.RGBD.Odometry.html#t:t/0"},{"type":"module","title":"Evision.RGBD.OdometryFrame","doc":"","ref":"Evision.RGBD.OdometryFrame.html"},{"type":"function","title":"Evision.RGBD.OdometryFrame.create/0","doc":"create\n##### Keyword Arguments\n- **image**: `Evision.Mat`.\n- **depth**: `Evision.Mat`.\n- **mask**: `Evision.Mat`.\n- **normals**: `Evision.Mat`.\n- **iD**: `integer()`.\n\n##### Return\n- **retval**: `OdometryFrame`\n\nPython prototype (for reference only):\n```python3\ncreate([, image[, depth[, mask[, normals[, ID]]]]]) -> retval\n```","ref":"Evision.RGBD.OdometryFrame.html#create/0"},{"type":"function","title":"Evision.RGBD.OdometryFrame.create/1","doc":"create\n##### Keyword Arguments\n- **image**: `Evision.Mat`.\n- **depth**: `Evision.Mat`.\n- **mask**: `Evision.Mat`.\n- **normals**: `Evision.Mat`.\n- **iD**: `integer()`.\n\n##### Return\n- **retval**: `OdometryFrame`\n\nPython prototype (for reference only):\n```python3\ncreate([, image[, depth[, mask[, normals[, ID]]]]]) -> retval\n```","ref":"Evision.RGBD.OdometryFrame.html#create/1"},{"type":"function","title":"Evision.RGBD.OdometryFrame.cv_CACHE_ALL/0","doc":"","ref":"Evision.RGBD.OdometryFrame.html#cv_CACHE_ALL/0"},{"type":"function","title":"Evision.RGBD.OdometryFrame.cv_CACHE_DST/0","doc":"","ref":"Evision.RGBD.OdometryFrame.html#cv_CACHE_DST/0"},{"type":"function","title":"Evision.RGBD.OdometryFrame.cv_CACHE_SRC/0","doc":"","ref":"Evision.RGBD.OdometryFrame.html#cv_CACHE_SRC/0"},{"type":"function","title":"Evision.RGBD.OdometryFrame.get_pyramid_dI_dx/1","doc":"","ref":"Evision.RGBD.OdometryFrame.html#get_pyramid_dI_dx/1"},{"type":"function","title":"Evision.RGBD.OdometryFrame.get_pyramid_dI_dy/1","doc":"","ref":"Evision.RGBD.OdometryFrame.html#get_pyramid_dI_dy/1"},{"type":"function","title":"Evision.RGBD.OdometryFrame.get_pyramidCloud/1","doc":"","ref":"Evision.RGBD.OdometryFrame.html#get_pyramidCloud/1"},{"type":"function","title":"Evision.RGBD.OdometryFrame.get_pyramidDepth/1","doc":"","ref":"Evision.RGBD.OdometryFrame.html#get_pyramidDepth/1"},{"type":"function","title":"Evision.RGBD.OdometryFrame.get_pyramidImage/1","doc":"","ref":"Evision.RGBD.OdometryFrame.html#get_pyramidImage/1"},{"type":"function","title":"Evision.RGBD.OdometryFrame.get_pyramidMask/1","doc":"","ref":"Evision.RGBD.OdometryFrame.html#get_pyramidMask/1"},{"type":"function","title":"Evision.RGBD.OdometryFrame.get_pyramidNormals/1","doc":"","ref":"Evision.RGBD.OdometryFrame.html#get_pyramidNormals/1"},{"type":"function","title":"Evision.RGBD.OdometryFrame.get_pyramidNormalsMask/1","doc":"","ref":"Evision.RGBD.OdometryFrame.html#get_pyramidNormalsMask/1"},{"type":"function","title":"Evision.RGBD.OdometryFrame.get_pyramidTexturedMask/1","doc":"","ref":"Evision.RGBD.OdometryFrame.html#get_pyramidTexturedMask/1"},{"type":"function","title":"Evision.RGBD.OdometryFrame.release/1","doc":"release\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.OdometryFrame.t()`\n\nPython prototype (for reference only):\n```python3\nrelease() -> None\n```","ref":"Evision.RGBD.OdometryFrame.html#release/1"},{"type":"function","title":"Evision.RGBD.OdometryFrame.releasePyramids/1","doc":"releasePyramids\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.OdometryFrame.t()`\n\nPython prototype (for reference only):\n```python3\nreleasePyramids() -> None\n```","ref":"Evision.RGBD.OdometryFrame.html#releasePyramids/1"},{"type":"type","title":"Evision.RGBD.OdometryFrame.enum/0","doc":"","ref":"Evision.RGBD.OdometryFrame.html#t:enum/0"},{"type":"type","title":"Evision.RGBD.OdometryFrame.t/0","doc":"Type that represents an `RGBD.OdometryFrame` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.RGBD.OdometryFrame.html#t:t/0"},{"type":"module","title":"Evision.RGBD.RgbdFrame","doc":"","ref":"Evision.RGBD.RgbdFrame.html"},{"type":"function","title":"Evision.RGBD.RgbdFrame.create/0","doc":"create\n##### Keyword Arguments\n- **image**: `Evision.Mat`.\n- **depth**: `Evision.Mat`.\n- **mask**: `Evision.Mat`.\n- **normals**: `Evision.Mat`.\n- **iD**: `integer()`.\n\n##### Return\n- **retval**: `RgbdFrame`\n\nPython prototype (for reference only):\n```python3\ncreate([, image[, depth[, mask[, normals[, ID]]]]]) -> retval\n```","ref":"Evision.RGBD.RgbdFrame.html#create/0"},{"type":"function","title":"Evision.RGBD.RgbdFrame.create/1","doc":"create\n##### Keyword Arguments\n- **image**: `Evision.Mat`.\n- **depth**: `Evision.Mat`.\n- **mask**: `Evision.Mat`.\n- **normals**: `Evision.Mat`.\n- **iD**: `integer()`.\n\n##### Return\n- **retval**: `RgbdFrame`\n\nPython prototype (for reference only):\n```python3\ncreate([, image[, depth[, mask[, normals[, ID]]]]]) -> retval\n```","ref":"Evision.RGBD.RgbdFrame.html#create/1"},{"type":"function","title":"Evision.RGBD.RgbdFrame.get_depth/1","doc":"","ref":"Evision.RGBD.RgbdFrame.html#get_depth/1"},{"type":"function","title":"Evision.RGBD.RgbdFrame.get_ID/1","doc":"","ref":"Evision.RGBD.RgbdFrame.html#get_ID/1"},{"type":"function","title":"Evision.RGBD.RgbdFrame.get_image/1","doc":"","ref":"Evision.RGBD.RgbdFrame.html#get_image/1"},{"type":"function","title":"Evision.RGBD.RgbdFrame.get_mask/1","doc":"","ref":"Evision.RGBD.RgbdFrame.html#get_mask/1"},{"type":"function","title":"Evision.RGBD.RgbdFrame.get_normals/1","doc":"","ref":"Evision.RGBD.RgbdFrame.html#get_normals/1"},{"type":"function","title":"Evision.RGBD.RgbdFrame.release/1","doc":"release\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdFrame.t()`\n\nPython prototype (for reference only):\n```python3\nrelease() -> None\n```","ref":"Evision.RGBD.RgbdFrame.html#release/1"},{"type":"type","title":"Evision.RGBD.RgbdFrame.t/0","doc":"Type that represents an `RGBD.RgbdFrame` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.RGBD.RgbdFrame.html#t:t/0"},{"type":"module","title":"Evision.RGBD.RgbdICPOdometry","doc":"","ref":"Evision.RGBD.RgbdICPOdometry.html"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.create/0","doc":"create\n##### Keyword Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  Camera matrix\n\n- **minDepth**: `float`.\n\n  Pixels with depth less than minDepth will not be used\n\n- **maxDepth**: `float`.\n\n  Pixels with depth larger than maxDepth will not be used\n\n- **maxDepthDiff**: `float`.\n\n  Correspondences between pixels of two given frames will be filtered out\n  if their depth difference is larger than maxDepthDiff\n\n- **maxPointsPart**: `float`.\n\n  The method uses a random pixels subset of size frameWidth x frameHeight x pointsPart\n\n- **iterCounts**: `[integer()]`.\n\n  Count of iterations on each pyramid level.\n\n- **minGradientMagnitudes**: `[float]`.\n\n  For each pyramid level the pixels will be filtered out\n  if they have gradient magnitude less than minGradientMagnitudes[level].\n\n- **transformType**: `integer()`.\n\n  Class of trasformation\n\n##### Return\n- **retval**: `RgbdICPOdometry`\n\nConstructor.\n\nPython prototype (for reference only):\n```python3\ncreate([, cameraMatrix[, minDepth[, maxDepth[, maxDepthDiff[, maxPointsPart[, iterCounts[, minGradientMagnitudes[, transformType]]]]]]]]) -> retval\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#create/0"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.create/1","doc":"create\n##### Keyword Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  Camera matrix\n\n- **minDepth**: `float`.\n\n  Pixels with depth less than minDepth will not be used\n\n- **maxDepth**: `float`.\n\n  Pixels with depth larger than maxDepth will not be used\n\n- **maxDepthDiff**: `float`.\n\n  Correspondences between pixels of two given frames will be filtered out\n  if their depth difference is larger than maxDepthDiff\n\n- **maxPointsPart**: `float`.\n\n  The method uses a random pixels subset of size frameWidth x frameHeight x pointsPart\n\n- **iterCounts**: `[integer()]`.\n\n  Count of iterations on each pyramid level.\n\n- **minGradientMagnitudes**: `[float]`.\n\n  For each pyramid level the pixels will be filtered out\n  if they have gradient magnitude less than minGradientMagnitudes[level].\n\n- **transformType**: `integer()`.\n\n  Class of trasformation\n\n##### Return\n- **retval**: `RgbdICPOdometry`\n\nConstructor.\n\nPython prototype (for reference only):\n```python3\ncreate([, cameraMatrix[, minDepth[, maxDepth[, maxDepthDiff[, maxPointsPart[, iterCounts[, minGradientMagnitudes[, transformType]]]]]]]]) -> retval\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#create/1"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.getCameraMatrix/1","doc":"getCameraMatrix\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdICPOdometry.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetCameraMatrix() -> retval\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#getCameraMatrix/1"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.getIterationCounts/1","doc":"getIterationCounts\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdICPOdometry.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetIterationCounts() -> retval\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#getIterationCounts/1"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.getMaxDepth/1","doc":"getMaxDepth\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdICPOdometry.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxDepth() -> retval\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#getMaxDepth/1"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.getMaxDepthDiff/1","doc":"getMaxDepthDiff\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdICPOdometry.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxDepthDiff() -> retval\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#getMaxDepthDiff/1"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.getMaxPointsPart/1","doc":"getMaxPointsPart\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdICPOdometry.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxPointsPart() -> retval\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#getMaxPointsPart/1"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.getMaxRotation/1","doc":"getMaxRotation\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdICPOdometry.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxRotation() -> retval\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#getMaxRotation/1"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.getMaxTranslation/1","doc":"getMaxTranslation\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdICPOdometry.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxTranslation() -> retval\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#getMaxTranslation/1"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.getMinDepth/1","doc":"getMinDepth\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdICPOdometry.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMinDepth() -> retval\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#getMinDepth/1"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.getMinGradientMagnitudes/1","doc":"getMinGradientMagnitudes\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdICPOdometry.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetMinGradientMagnitudes() -> retval\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#getMinGradientMagnitudes/1"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.getNormalsComputer/1","doc":"getNormalsComputer\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdICPOdometry.t()`\n\n##### Return\n- **retval**: `RgbdNormals`\n\nPython prototype (for reference only):\n```python3\ngetNormalsComputer() -> retval\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#getNormalsComputer/1"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.getTransformType/1","doc":"getTransformType\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdICPOdometry.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetTransformType() -> retval\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#getTransformType/1"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.prepareFrameCache/1","doc":"","ref":"Evision.RGBD.RgbdICPOdometry.html#prepareFrameCache/1"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.prepareFrameCache/3","doc":"prepareFrameCache\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdICPOdometry.t()`\n- **frame**: `OdometryFrame`\n- **cacheType**: `integer()`\n\n##### Return\n- **retval**: `Size`\n\nPython prototype (for reference only):\n```python3\nprepareFrameCache(frame, cacheType) -> retval\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#prepareFrameCache/3"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.setCameraMatrix/1","doc":"","ref":"Evision.RGBD.RgbdICPOdometry.html#setCameraMatrix/1"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.setCameraMatrix/2","doc":"setCameraMatrix\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdICPOdometry.t()`\n- **val**: `Evision.Mat`\n\nPython prototype (for reference only):\n```python3\nsetCameraMatrix(val) -> None\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#setCameraMatrix/2"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.setIterationCounts/1","doc":"","ref":"Evision.RGBD.RgbdICPOdometry.html#setIterationCounts/1"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.setIterationCounts/2","doc":"setIterationCounts\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdICPOdometry.t()`\n- **val**: `Evision.Mat`\n\nPython prototype (for reference only):\n```python3\nsetIterationCounts(val) -> None\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#setIterationCounts/2"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.setMaxDepth/1","doc":"","ref":"Evision.RGBD.RgbdICPOdometry.html#setMaxDepth/1"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.setMaxDepth/2","doc":"setMaxDepth\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdICPOdometry.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxDepth(val) -> None\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#setMaxDepth/2"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.setMaxDepthDiff/1","doc":"","ref":"Evision.RGBD.RgbdICPOdometry.html#setMaxDepthDiff/1"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.setMaxDepthDiff/2","doc":"setMaxDepthDiff\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdICPOdometry.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxDepthDiff(val) -> None\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#setMaxDepthDiff/2"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.setMaxPointsPart/1","doc":"","ref":"Evision.RGBD.RgbdICPOdometry.html#setMaxPointsPart/1"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.setMaxPointsPart/2","doc":"setMaxPointsPart\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdICPOdometry.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxPointsPart(val) -> None\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#setMaxPointsPart/2"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.setMaxRotation/1","doc":"","ref":"Evision.RGBD.RgbdICPOdometry.html#setMaxRotation/1"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.setMaxRotation/2","doc":"setMaxRotation\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdICPOdometry.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxRotation(val) -> None\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#setMaxRotation/2"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.setMaxTranslation/1","doc":"","ref":"Evision.RGBD.RgbdICPOdometry.html#setMaxTranslation/1"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.setMaxTranslation/2","doc":"setMaxTranslation\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdICPOdometry.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxTranslation(val) -> None\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#setMaxTranslation/2"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.setMinDepth/1","doc":"","ref":"Evision.RGBD.RgbdICPOdometry.html#setMinDepth/1"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.setMinDepth/2","doc":"setMinDepth\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdICPOdometry.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMinDepth(val) -> None\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#setMinDepth/2"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.setMinGradientMagnitudes/1","doc":"","ref":"Evision.RGBD.RgbdICPOdometry.html#setMinGradientMagnitudes/1"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.setMinGradientMagnitudes/2","doc":"setMinGradientMagnitudes\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdICPOdometry.t()`\n- **val**: `Evision.Mat`\n\nPython prototype (for reference only):\n```python3\nsetMinGradientMagnitudes(val) -> None\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#setMinGradientMagnitudes/2"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.setTransformType/1","doc":"","ref":"Evision.RGBD.RgbdICPOdometry.html#setTransformType/1"},{"type":"function","title":"Evision.RGBD.RgbdICPOdometry.setTransformType/2","doc":"setTransformType\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdICPOdometry.t()`\n- **val**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetTransformType(val) -> None\n```","ref":"Evision.RGBD.RgbdICPOdometry.html#setTransformType/2"},{"type":"type","title":"Evision.RGBD.RgbdICPOdometry.t/0","doc":"Type that represents an `RGBD.RgbdICPOdometry` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.RGBD.RgbdICPOdometry.html#t:t/0"},{"type":"module","title":"Evision.RGBD.RgbdNormals","doc":"","ref":"Evision.RGBD.RgbdNormals.html"},{"type":"function","title":"Evision.RGBD.RgbdNormals.apply/1","doc":"","ref":"Evision.RGBD.RgbdNormals.html#apply/1"},{"type":"function","title":"Evision.RGBD.RgbdNormals.apply/2","doc":"apply\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdNormals.t()`\n- **points**: `Evision.Mat`.\n\n  a rows x cols x 3 matrix of CV_32F/CV64F or a rows x cols x 1 CV_U16S\n\n##### Return\n- **normals**: `Evision.Mat.t()`.\n\n  a rows x cols x 3 matrix\n\nGiven a set of 3d points in a depth image, compute the normals at each point.\n\nPython prototype (for reference only):\n```python3\napply(points[, normals]) -> normals\n```","ref":"Evision.RGBD.RgbdNormals.html#apply/2"},{"type":"function","title":"Evision.RGBD.RgbdNormals.apply/3","doc":"apply\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdNormals.t()`\n- **points**: `Evision.Mat`.\n\n  a rows x cols x 3 matrix of CV_32F/CV64F or a rows x cols x 1 CV_U16S\n\n##### Return\n- **normals**: `Evision.Mat.t()`.\n\n  a rows x cols x 3 matrix\n\nGiven a set of 3d points in a depth image, compute the normals at each point.\n\nPython prototype (for reference only):\n```python3\napply(points[, normals]) -> normals\n```","ref":"Evision.RGBD.RgbdNormals.html#apply/3"},{"type":"function","title":"Evision.RGBD.RgbdNormals.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdNormals.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.RGBD.RgbdNormals.html#clear/1"},{"type":"function","title":"Evision.RGBD.RgbdNormals.create/1","doc":"","ref":"Evision.RGBD.RgbdNormals.html#create/1"},{"type":"function","title":"Evision.RGBD.RgbdNormals.create/4","doc":"create\n\n##### Positional Arguments\n- **rows**: `integer()`.\n\n  the number of rows of the depth image normals will be computed on\n\n- **cols**: `integer()`.\n\n  the number of cols of the depth image normals will be computed on\n\n- **depth**: `integer()`.\n\n  the depth of the normals (only CV_32F or CV_64F)\n\n- **k**: `Evision.Mat`.\n\n  the calibration matrix to use\n\n##### Keyword Arguments\n- **window_size**: `integer()`.\n\n  the window size to compute the normals: can only be 1,3,5 or 7\n\n- **method**: `integer()`.\n\n  one of the methods to use: RGBD_NORMALS_METHOD_SRI, RGBD_NORMALS_METHOD_FALS\n\n##### Return\n- **retval**: `RgbdNormals`\n\nConstructor\n\nPython prototype (for reference only):\n```python3\ncreate(rows, cols, depth, K[, window_size[, method]]) -> retval\n```","ref":"Evision.RGBD.RgbdNormals.html#create/4"},{"type":"function","title":"Evision.RGBD.RgbdNormals.create/5","doc":"create\n\n##### Positional Arguments\n- **rows**: `integer()`.\n\n  the number of rows of the depth image normals will be computed on\n\n- **cols**: `integer()`.\n\n  the number of cols of the depth image normals will be computed on\n\n- **depth**: `integer()`.\n\n  the depth of the normals (only CV_32F or CV_64F)\n\n- **k**: `Evision.Mat`.\n\n  the calibration matrix to use\n\n##### Keyword Arguments\n- **window_size**: `integer()`.\n\n  the window size to compute the normals: can only be 1,3,5 or 7\n\n- **method**: `integer()`.\n\n  one of the methods to use: RGBD_NORMALS_METHOD_SRI, RGBD_NORMALS_METHOD_FALS\n\n##### Return\n- **retval**: `RgbdNormals`\n\nConstructor\n\nPython prototype (for reference only):\n```python3\ncreate(rows, cols, depth, K[, window_size[, method]]) -> retval\n```","ref":"Evision.RGBD.RgbdNormals.html#create/5"},{"type":"function","title":"Evision.RGBD.RgbdNormals.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdNormals.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.RGBD.RgbdNormals.html#empty/1"},{"type":"function","title":"Evision.RGBD.RgbdNormals.getCols/1","doc":"getCols\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdNormals.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetCols() -> retval\n```","ref":"Evision.RGBD.RgbdNormals.html#getCols/1"},{"type":"function","title":"Evision.RGBD.RgbdNormals.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdNormals.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.RGBD.RgbdNormals.html#getDefaultName/1"},{"type":"function","title":"Evision.RGBD.RgbdNormals.getDepth/1","doc":"getDepth\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdNormals.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetDepth() -> retval\n```","ref":"Evision.RGBD.RgbdNormals.html#getDepth/1"},{"type":"function","title":"Evision.RGBD.RgbdNormals.getK/1","doc":"getK\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdNormals.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetK() -> retval\n```","ref":"Evision.RGBD.RgbdNormals.html#getK/1"},{"type":"function","title":"Evision.RGBD.RgbdNormals.getMethod/1","doc":"getMethod\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdNormals.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMethod() -> retval\n```","ref":"Evision.RGBD.RgbdNormals.html#getMethod/1"},{"type":"function","title":"Evision.RGBD.RgbdNormals.getRows/1","doc":"getRows\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdNormals.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetRows() -> retval\n```","ref":"Evision.RGBD.RgbdNormals.html#getRows/1"},{"type":"function","title":"Evision.RGBD.RgbdNormals.getWindowSize/1","doc":"getWindowSize\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdNormals.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetWindowSize() -> retval\n```","ref":"Evision.RGBD.RgbdNormals.html#getWindowSize/1"},{"type":"function","title":"Evision.RGBD.RgbdNormals.initialize/1","doc":"initialize\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdNormals.t()`\n\nInitializes some data that is cached for later computation\n If that function is not called, it will be called the first time normals are computed\n\nPython prototype (for reference only):\n```python3\ninitialize() -> None\n```","ref":"Evision.RGBD.RgbdNormals.html#initialize/1"},{"type":"function","title":"Evision.RGBD.RgbdNormals.read/1","doc":"","ref":"Evision.RGBD.RgbdNormals.html#read/1"},{"type":"function","title":"Evision.RGBD.RgbdNormals.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdNormals.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.RGBD.RgbdNormals.html#read/2"},{"type":"function","title":"Evision.RGBD.RgbdNormals.save/1","doc":"","ref":"Evision.RGBD.RgbdNormals.html#save/1"},{"type":"function","title":"Evision.RGBD.RgbdNormals.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdNormals.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.RGBD.RgbdNormals.html#save/2"},{"type":"function","title":"Evision.RGBD.RgbdNormals.setCols/1","doc":"","ref":"Evision.RGBD.RgbdNormals.html#setCols/1"},{"type":"function","title":"Evision.RGBD.RgbdNormals.setCols/2","doc":"setCols\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdNormals.t()`\n- **val**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetCols(val) -> None\n```","ref":"Evision.RGBD.RgbdNormals.html#setCols/2"},{"type":"function","title":"Evision.RGBD.RgbdNormals.setDepth/1","doc":"","ref":"Evision.RGBD.RgbdNormals.html#setDepth/1"},{"type":"function","title":"Evision.RGBD.RgbdNormals.setDepth/2","doc":"setDepth\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdNormals.t()`\n- **val**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetDepth(val) -> None\n```","ref":"Evision.RGBD.RgbdNormals.html#setDepth/2"},{"type":"function","title":"Evision.RGBD.RgbdNormals.setK/1","doc":"","ref":"Evision.RGBD.RgbdNormals.html#setK/1"},{"type":"function","title":"Evision.RGBD.RgbdNormals.setK/2","doc":"setK\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdNormals.t()`\n- **val**: `Evision.Mat`\n\nPython prototype (for reference only):\n```python3\nsetK(val) -> None\n```","ref":"Evision.RGBD.RgbdNormals.html#setK/2"},{"type":"function","title":"Evision.RGBD.RgbdNormals.setMethod/1","doc":"","ref":"Evision.RGBD.RgbdNormals.html#setMethod/1"},{"type":"function","title":"Evision.RGBD.RgbdNormals.setMethod/2","doc":"setMethod\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdNormals.t()`\n- **val**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMethod(val) -> None\n```","ref":"Evision.RGBD.RgbdNormals.html#setMethod/2"},{"type":"function","title":"Evision.RGBD.RgbdNormals.setRows/1","doc":"","ref":"Evision.RGBD.RgbdNormals.html#setRows/1"},{"type":"function","title":"Evision.RGBD.RgbdNormals.setRows/2","doc":"setRows\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdNormals.t()`\n- **val**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetRows(val) -> None\n```","ref":"Evision.RGBD.RgbdNormals.html#setRows/2"},{"type":"function","title":"Evision.RGBD.RgbdNormals.setWindowSize/1","doc":"","ref":"Evision.RGBD.RgbdNormals.html#setWindowSize/1"},{"type":"function","title":"Evision.RGBD.RgbdNormals.setWindowSize/2","doc":"setWindowSize\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdNormals.t()`\n- **val**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetWindowSize(val) -> None\n```","ref":"Evision.RGBD.RgbdNormals.html#setWindowSize/2"},{"type":"function","title":"Evision.RGBD.RgbdNormals.write/1","doc":"","ref":"Evision.RGBD.RgbdNormals.html#write/1"},{"type":"function","title":"Evision.RGBD.RgbdNormals.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdNormals.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.RGBD.RgbdNormals.html#write/2"},{"type":"function","title":"Evision.RGBD.RgbdNormals.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdNormals.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.RGBD.RgbdNormals.html#write/3"},{"type":"type","title":"Evision.RGBD.RgbdNormals.t/0","doc":"Type that represents an `RGBD.RgbdNormals` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.RGBD.RgbdNormals.html#t:t/0"},{"type":"module","title":"Evision.RGBD.RgbdNormals.RGBD_NORMALS_METHOD","doc":"","ref":"Evision.RGBD.RgbdNormals.RGBD_NORMALS_METHOD.html"},{"type":"function","title":"Evision.RGBD.RgbdNormals.RGBD_NORMALS_METHOD.cv_RGBD_NORMALS_METHOD_FALS/0","doc":"","ref":"Evision.RGBD.RgbdNormals.RGBD_NORMALS_METHOD.html#cv_RGBD_NORMALS_METHOD_FALS/0"},{"type":"function","title":"Evision.RGBD.RgbdNormals.RGBD_NORMALS_METHOD.cv_RGBD_NORMALS_METHOD_LINEMOD/0","doc":"","ref":"Evision.RGBD.RgbdNormals.RGBD_NORMALS_METHOD.html#cv_RGBD_NORMALS_METHOD_LINEMOD/0"},{"type":"function","title":"Evision.RGBD.RgbdNormals.RGBD_NORMALS_METHOD.cv_RGBD_NORMALS_METHOD_SRI/0","doc":"","ref":"Evision.RGBD.RgbdNormals.RGBD_NORMALS_METHOD.html#cv_RGBD_NORMALS_METHOD_SRI/0"},{"type":"type","title":"Evision.RGBD.RgbdNormals.RGBD_NORMALS_METHOD.enum/0","doc":"","ref":"Evision.RGBD.RgbdNormals.RGBD_NORMALS_METHOD.html#t:enum/0"},{"type":"module","title":"Evision.RGBD.RgbdOdometry","doc":"","ref":"Evision.RGBD.RgbdOdometry.html"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.create/0","doc":"create\n##### Keyword Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  Camera matrix\n\n- **minDepth**: `float`.\n\n  Pixels with depth less than minDepth will not be used (in meters)\n\n- **maxDepth**: `float`.\n\n  Pixels with depth larger than maxDepth will not be used (in meters)\n\n- **maxDepthDiff**: `float`.\n\n  Correspondences between pixels of two given frames will be filtered out\n  if their depth difference is larger than maxDepthDiff (in meters)\n\n- **iterCounts**: `[integer()]`.\n\n  Count of iterations on each pyramid level.\n\n- **minGradientMagnitudes**: `[float]`.\n\n  For each pyramid level the pixels will be filtered out\n  if they have gradient magnitude less than minGradientMagnitudes[level].\n\n- **maxPointsPart**: `float`.\n\n  The method uses a random pixels subset of size frameWidth x frameHeight x pointsPart\n\n- **transformType**: `integer()`.\n\n  Class of transformation\n\n##### Return\n- **retval**: `RgbdOdometry`\n\nConstructor.\n\nPython prototype (for reference only):\n```python3\ncreate([, cameraMatrix[, minDepth[, maxDepth[, maxDepthDiff[, iterCounts[, minGradientMagnitudes[, maxPointsPart[, transformType]]]]]]]]) -> retval\n```","ref":"Evision.RGBD.RgbdOdometry.html#create/0"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.create/1","doc":"create\n##### Keyword Arguments\n- **cameraMatrix**: `Evision.Mat`.\n\n  Camera matrix\n\n- **minDepth**: `float`.\n\n  Pixels with depth less than minDepth will not be used (in meters)\n\n- **maxDepth**: `float`.\n\n  Pixels with depth larger than maxDepth will not be used (in meters)\n\n- **maxDepthDiff**: `float`.\n\n  Correspondences between pixels of two given frames will be filtered out\n  if their depth difference is larger than maxDepthDiff (in meters)\n\n- **iterCounts**: `[integer()]`.\n\n  Count of iterations on each pyramid level.\n\n- **minGradientMagnitudes**: `[float]`.\n\n  For each pyramid level the pixels will be filtered out\n  if they have gradient magnitude less than minGradientMagnitudes[level].\n\n- **maxPointsPart**: `float`.\n\n  The method uses a random pixels subset of size frameWidth x frameHeight x pointsPart\n\n- **transformType**: `integer()`.\n\n  Class of transformation\n\n##### Return\n- **retval**: `RgbdOdometry`\n\nConstructor.\n\nPython prototype (for reference only):\n```python3\ncreate([, cameraMatrix[, minDepth[, maxDepth[, maxDepthDiff[, iterCounts[, minGradientMagnitudes[, maxPointsPart[, transformType]]]]]]]]) -> retval\n```","ref":"Evision.RGBD.RgbdOdometry.html#create/1"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.getCameraMatrix/1","doc":"getCameraMatrix\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdOdometry.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetCameraMatrix() -> retval\n```","ref":"Evision.RGBD.RgbdOdometry.html#getCameraMatrix/1"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.getIterationCounts/1","doc":"getIterationCounts\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdOdometry.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetIterationCounts() -> retval\n```","ref":"Evision.RGBD.RgbdOdometry.html#getIterationCounts/1"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.getMaxDepth/1","doc":"getMaxDepth\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdOdometry.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxDepth() -> retval\n```","ref":"Evision.RGBD.RgbdOdometry.html#getMaxDepth/1"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.getMaxDepthDiff/1","doc":"getMaxDepthDiff\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdOdometry.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxDepthDiff() -> retval\n```","ref":"Evision.RGBD.RgbdOdometry.html#getMaxDepthDiff/1"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.getMaxPointsPart/1","doc":"getMaxPointsPart\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdOdometry.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxPointsPart() -> retval\n```","ref":"Evision.RGBD.RgbdOdometry.html#getMaxPointsPart/1"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.getMaxRotation/1","doc":"getMaxRotation\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdOdometry.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxRotation() -> retval\n```","ref":"Evision.RGBD.RgbdOdometry.html#getMaxRotation/1"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.getMaxTranslation/1","doc":"getMaxTranslation\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdOdometry.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMaxTranslation() -> retval\n```","ref":"Evision.RGBD.RgbdOdometry.html#getMaxTranslation/1"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.getMinDepth/1","doc":"getMinDepth\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdOdometry.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMinDepth() -> retval\n```","ref":"Evision.RGBD.RgbdOdometry.html#getMinDepth/1"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.getMinGradientMagnitudes/1","doc":"getMinGradientMagnitudes\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdOdometry.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetMinGradientMagnitudes() -> retval\n```","ref":"Evision.RGBD.RgbdOdometry.html#getMinGradientMagnitudes/1"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.getTransformType/1","doc":"getTransformType\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdOdometry.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetTransformType() -> retval\n```","ref":"Evision.RGBD.RgbdOdometry.html#getTransformType/1"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.prepareFrameCache/1","doc":"","ref":"Evision.RGBD.RgbdOdometry.html#prepareFrameCache/1"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.prepareFrameCache/3","doc":"prepareFrameCache\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdOdometry.t()`\n- **frame**: `OdometryFrame`\n- **cacheType**: `integer()`\n\n##### Return\n- **retval**: `Size`\n\nPython prototype (for reference only):\n```python3\nprepareFrameCache(frame, cacheType) -> retval\n```","ref":"Evision.RGBD.RgbdOdometry.html#prepareFrameCache/3"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.setCameraMatrix/1","doc":"","ref":"Evision.RGBD.RgbdOdometry.html#setCameraMatrix/1"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.setCameraMatrix/2","doc":"setCameraMatrix\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdOdometry.t()`\n- **val**: `Evision.Mat`\n\nPython prototype (for reference only):\n```python3\nsetCameraMatrix(val) -> None\n```","ref":"Evision.RGBD.RgbdOdometry.html#setCameraMatrix/2"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.setIterationCounts/1","doc":"","ref":"Evision.RGBD.RgbdOdometry.html#setIterationCounts/1"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.setIterationCounts/2","doc":"setIterationCounts\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdOdometry.t()`\n- **val**: `Evision.Mat`\n\nPython prototype (for reference only):\n```python3\nsetIterationCounts(val) -> None\n```","ref":"Evision.RGBD.RgbdOdometry.html#setIterationCounts/2"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.setMaxDepth/1","doc":"","ref":"Evision.RGBD.RgbdOdometry.html#setMaxDepth/1"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.setMaxDepth/2","doc":"setMaxDepth\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdOdometry.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxDepth(val) -> None\n```","ref":"Evision.RGBD.RgbdOdometry.html#setMaxDepth/2"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.setMaxDepthDiff/1","doc":"","ref":"Evision.RGBD.RgbdOdometry.html#setMaxDepthDiff/1"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.setMaxDepthDiff/2","doc":"setMaxDepthDiff\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdOdometry.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxDepthDiff(val) -> None\n```","ref":"Evision.RGBD.RgbdOdometry.html#setMaxDepthDiff/2"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.setMaxPointsPart/1","doc":"","ref":"Evision.RGBD.RgbdOdometry.html#setMaxPointsPart/1"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.setMaxPointsPart/2","doc":"setMaxPointsPart\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdOdometry.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxPointsPart(val) -> None\n```","ref":"Evision.RGBD.RgbdOdometry.html#setMaxPointsPart/2"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.setMaxRotation/1","doc":"","ref":"Evision.RGBD.RgbdOdometry.html#setMaxRotation/1"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.setMaxRotation/2","doc":"setMaxRotation\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdOdometry.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxRotation(val) -> None\n```","ref":"Evision.RGBD.RgbdOdometry.html#setMaxRotation/2"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.setMaxTranslation/1","doc":"","ref":"Evision.RGBD.RgbdOdometry.html#setMaxTranslation/1"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.setMaxTranslation/2","doc":"setMaxTranslation\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdOdometry.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMaxTranslation(val) -> None\n```","ref":"Evision.RGBD.RgbdOdometry.html#setMaxTranslation/2"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.setMinDepth/1","doc":"","ref":"Evision.RGBD.RgbdOdometry.html#setMinDepth/1"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.setMinDepth/2","doc":"setMinDepth\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdOdometry.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMinDepth(val) -> None\n```","ref":"Evision.RGBD.RgbdOdometry.html#setMinDepth/2"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.setMinGradientMagnitudes/1","doc":"","ref":"Evision.RGBD.RgbdOdometry.html#setMinGradientMagnitudes/1"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.setMinGradientMagnitudes/2","doc":"setMinGradientMagnitudes\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdOdometry.t()`\n- **val**: `Evision.Mat`\n\nPython prototype (for reference only):\n```python3\nsetMinGradientMagnitudes(val) -> None\n```","ref":"Evision.RGBD.RgbdOdometry.html#setMinGradientMagnitudes/2"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.setTransformType/1","doc":"","ref":"Evision.RGBD.RgbdOdometry.html#setTransformType/1"},{"type":"function","title":"Evision.RGBD.RgbdOdometry.setTransformType/2","doc":"setTransformType\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdOdometry.t()`\n- **val**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetTransformType(val) -> None\n```","ref":"Evision.RGBD.RgbdOdometry.html#setTransformType/2"},{"type":"type","title":"Evision.RGBD.RgbdOdometry.t/0","doc":"Type that represents an `RGBD.RgbdOdometry` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.RGBD.RgbdOdometry.html#t:t/0"},{"type":"module","title":"Evision.RGBD.RgbdPlane","doc":"","ref":"Evision.RGBD.RgbdPlane.html"},{"type":"function","title":"Evision.RGBD.RgbdPlane.apply/1","doc":"","ref":"Evision.RGBD.RgbdPlane.html#apply/1"},{"type":"function","title":"Evision.RGBD.RgbdPlane.apply/2","doc":"apply\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n- **points3d**: `Evision.Mat`.\n\n  the 3d points organized like the depth image: rows x cols with 3 channels\n\n##### Return\n- **mask**: `Evision.Mat.t()`.\n\n  An image where each pixel is labeled with the plane it belongs to\n  and 255 if it does not belong to any plane\n\n- **plane_coefficients**: `Evision.Mat.t()`.\n\n  the coefficients of the corresponding planes (a,b,c,d) such that ax+by+cz+d=0\n\nFind The planes in a depth image but without doing a normal check, which is faster but less accurate\n\nPython prototype (for reference only):\n```python3\napply(points3d[, mask[, plane_coefficients]]) -> mask, plane_coefficients\n```","ref":"Evision.RGBD.RgbdPlane.html#apply/2"},{"type":"function","title":"Evision.RGBD.RgbdPlane.apply/3","doc":"#### Variant 1:\napply\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n- **points3d**: `Evision.Mat`.\n\n  the 3d points organized like the depth image: rows x cols with 3 channels\n\n- **normals**: `Evision.Mat`.\n\n  the normals for every point in the depth image\n\n##### Return\n- **mask**: `Evision.Mat.t()`.\n\n  An image where each pixel is labeled with the plane it belongs to\n  and 255 if it does not belong to any plane\n\n- **plane_coefficients**: `Evision.Mat.t()`.\n\n  the coefficients of the corresponding planes (a,b,c,d) such that ax+by+cz+d=0, norm(a,b,c)=1\n  and c < 0 (so that the normal points towards the camera)\n\nFind The planes in a depth image\n\nPython prototype (for reference only):\n```python3\napply(points3d, normals[, mask[, plane_coefficients]]) -> mask, plane_coefficients\n```\n#### Variant 2:\napply\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n- **points3d**: `Evision.Mat`.\n\n  the 3d points organized like the depth image: rows x cols with 3 channels\n\n##### Return\n- **mask**: `Evision.Mat.t()`.\n\n  An image where each pixel is labeled with the plane it belongs to\n  and 255 if it does not belong to any plane\n\n- **plane_coefficients**: `Evision.Mat.t()`.\n\n  the coefficients of the corresponding planes (a,b,c,d) such that ax+by+cz+d=0\n\nFind The planes in a depth image but without doing a normal check, which is faster but less accurate\n\nPython prototype (for reference only):\n```python3\napply(points3d[, mask[, plane_coefficients]]) -> mask, plane_coefficients\n```","ref":"Evision.RGBD.RgbdPlane.html#apply/3"},{"type":"function","title":"Evision.RGBD.RgbdPlane.apply/4","doc":"apply\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n- **points3d**: `Evision.Mat`.\n\n  the 3d points organized like the depth image: rows x cols with 3 channels\n\n- **normals**: `Evision.Mat`.\n\n  the normals for every point in the depth image\n\n##### Return\n- **mask**: `Evision.Mat.t()`.\n\n  An image where each pixel is labeled with the plane it belongs to\n  and 255 if it does not belong to any plane\n\n- **plane_coefficients**: `Evision.Mat.t()`.\n\n  the coefficients of the corresponding planes (a,b,c,d) such that ax+by+cz+d=0, norm(a,b,c)=1\n  and c < 0 (so that the normal points towards the camera)\n\nFind The planes in a depth image\n\nPython prototype (for reference only):\n```python3\napply(points3d, normals[, mask[, plane_coefficients]]) -> mask, plane_coefficients\n```","ref":"Evision.RGBD.RgbdPlane.html#apply/4"},{"type":"function","title":"Evision.RGBD.RgbdPlane.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.RGBD.RgbdPlane.html#clear/1"},{"type":"function","title":"Evision.RGBD.RgbdPlane.create/1","doc":"","ref":"Evision.RGBD.RgbdPlane.html#create/1"},{"type":"function","title":"Evision.RGBD.RgbdPlane.create/4","doc":"create\n\n##### Positional Arguments\n- **method**: `integer()`.\n\n  The method to use to compute the planes.\n\n- **block_size**: `integer()`.\n\n  The size of the blocks to look at for a stable MSE\n\n- **min_size**: `integer()`.\n\n  The minimum size of a cluster to be considered a plane\n\n- **threshold**: `double`.\n\n  The maximum distance of a point from a plane to belong to it (in meters)\n\n##### Keyword Arguments\n- **sensor_error_a**: `double`.\n\n  coefficient of the sensor error. 0 by default, 0.0075 for a Kinect\n\n- **sensor_error_b**: `double`.\n\n  coefficient of the sensor error. 0 by default\n\n- **sensor_error_c**: `double`.\n\n  coefficient of the sensor error. 0 by default\n\n##### Return\n- **retval**: `RgbdPlane`\n\nConstructor\n\nPython prototype (for reference only):\n```python3\ncreate(method, block_size, min_size, threshold[, sensor_error_a[, sensor_error_b[, sensor_error_c]]]) -> retval\n```","ref":"Evision.RGBD.RgbdPlane.html#create/4"},{"type":"function","title":"Evision.RGBD.RgbdPlane.create/5","doc":"create\n\n##### Positional Arguments\n- **method**: `integer()`.\n\n  The method to use to compute the planes.\n\n- **block_size**: `integer()`.\n\n  The size of the blocks to look at for a stable MSE\n\n- **min_size**: `integer()`.\n\n  The minimum size of a cluster to be considered a plane\n\n- **threshold**: `double`.\n\n  The maximum distance of a point from a plane to belong to it (in meters)\n\n##### Keyword Arguments\n- **sensor_error_a**: `double`.\n\n  coefficient of the sensor error. 0 by default, 0.0075 for a Kinect\n\n- **sensor_error_b**: `double`.\n\n  coefficient of the sensor error. 0 by default\n\n- **sensor_error_c**: `double`.\n\n  coefficient of the sensor error. 0 by default\n\n##### Return\n- **retval**: `RgbdPlane`\n\nConstructor\n\nPython prototype (for reference only):\n```python3\ncreate(method, block_size, min_size, threshold[, sensor_error_a[, sensor_error_b[, sensor_error_c]]]) -> retval\n```","ref":"Evision.RGBD.RgbdPlane.html#create/5"},{"type":"function","title":"Evision.RGBD.RgbdPlane.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.RGBD.RgbdPlane.html#empty/1"},{"type":"function","title":"Evision.RGBD.RgbdPlane.getBlockSize/1","doc":"getBlockSize\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetBlockSize() -> retval\n```","ref":"Evision.RGBD.RgbdPlane.html#getBlockSize/1"},{"type":"function","title":"Evision.RGBD.RgbdPlane.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.RGBD.RgbdPlane.html#getDefaultName/1"},{"type":"function","title":"Evision.RGBD.RgbdPlane.getMethod/1","doc":"getMethod\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMethod() -> retval\n```","ref":"Evision.RGBD.RgbdPlane.html#getMethod/1"},{"type":"function","title":"Evision.RGBD.RgbdPlane.getMinSize/1","doc":"getMinSize\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMinSize() -> retval\n```","ref":"Evision.RGBD.RgbdPlane.html#getMinSize/1"},{"type":"function","title":"Evision.RGBD.RgbdPlane.getSensorErrorA/1","doc":"getSensorErrorA\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetSensorErrorA() -> retval\n```","ref":"Evision.RGBD.RgbdPlane.html#getSensorErrorA/1"},{"type":"function","title":"Evision.RGBD.RgbdPlane.getSensorErrorB/1","doc":"getSensorErrorB\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetSensorErrorB() -> retval\n```","ref":"Evision.RGBD.RgbdPlane.html#getSensorErrorB/1"},{"type":"function","title":"Evision.RGBD.RgbdPlane.getSensorErrorC/1","doc":"getSensorErrorC\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetSensorErrorC() -> retval\n```","ref":"Evision.RGBD.RgbdPlane.html#getSensorErrorC/1"},{"type":"function","title":"Evision.RGBD.RgbdPlane.getThreshold/1","doc":"getThreshold\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetThreshold() -> retval\n```","ref":"Evision.RGBD.RgbdPlane.html#getThreshold/1"},{"type":"function","title":"Evision.RGBD.RgbdPlane.read/1","doc":"","ref":"Evision.RGBD.RgbdPlane.html#read/1"},{"type":"function","title":"Evision.RGBD.RgbdPlane.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.RGBD.RgbdPlane.html#read/2"},{"type":"function","title":"Evision.RGBD.RgbdPlane.save/1","doc":"","ref":"Evision.RGBD.RgbdPlane.html#save/1"},{"type":"function","title":"Evision.RGBD.RgbdPlane.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.RGBD.RgbdPlane.html#save/2"},{"type":"function","title":"Evision.RGBD.RgbdPlane.setBlockSize/1","doc":"","ref":"Evision.RGBD.RgbdPlane.html#setBlockSize/1"},{"type":"function","title":"Evision.RGBD.RgbdPlane.setBlockSize/2","doc":"setBlockSize\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n- **val**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetBlockSize(val) -> None\n```","ref":"Evision.RGBD.RgbdPlane.html#setBlockSize/2"},{"type":"function","title":"Evision.RGBD.RgbdPlane.setMethod/1","doc":"","ref":"Evision.RGBD.RgbdPlane.html#setMethod/1"},{"type":"function","title":"Evision.RGBD.RgbdPlane.setMethod/2","doc":"setMethod\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n- **val**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMethod(val) -> None\n```","ref":"Evision.RGBD.RgbdPlane.html#setMethod/2"},{"type":"function","title":"Evision.RGBD.RgbdPlane.setMinSize/1","doc":"","ref":"Evision.RGBD.RgbdPlane.html#setMinSize/1"},{"type":"function","title":"Evision.RGBD.RgbdPlane.setMinSize/2","doc":"setMinSize\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n- **val**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMinSize(val) -> None\n```","ref":"Evision.RGBD.RgbdPlane.html#setMinSize/2"},{"type":"function","title":"Evision.RGBD.RgbdPlane.setSensorErrorA/1","doc":"","ref":"Evision.RGBD.RgbdPlane.html#setSensorErrorA/1"},{"type":"function","title":"Evision.RGBD.RgbdPlane.setSensorErrorA/2","doc":"setSensorErrorA\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetSensorErrorA(val) -> None\n```","ref":"Evision.RGBD.RgbdPlane.html#setSensorErrorA/2"},{"type":"function","title":"Evision.RGBD.RgbdPlane.setSensorErrorB/1","doc":"","ref":"Evision.RGBD.RgbdPlane.html#setSensorErrorB/1"},{"type":"function","title":"Evision.RGBD.RgbdPlane.setSensorErrorB/2","doc":"setSensorErrorB\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetSensorErrorB(val) -> None\n```","ref":"Evision.RGBD.RgbdPlane.html#setSensorErrorB/2"},{"type":"function","title":"Evision.RGBD.RgbdPlane.setSensorErrorC/1","doc":"","ref":"Evision.RGBD.RgbdPlane.html#setSensorErrorC/1"},{"type":"function","title":"Evision.RGBD.RgbdPlane.setSensorErrorC/2","doc":"setSensorErrorC\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetSensorErrorC(val) -> None\n```","ref":"Evision.RGBD.RgbdPlane.html#setSensorErrorC/2"},{"type":"function","title":"Evision.RGBD.RgbdPlane.setThreshold/1","doc":"","ref":"Evision.RGBD.RgbdPlane.html#setThreshold/1"},{"type":"function","title":"Evision.RGBD.RgbdPlane.setThreshold/2","doc":"setThreshold\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetThreshold(val) -> None\n```","ref":"Evision.RGBD.RgbdPlane.html#setThreshold/2"},{"type":"function","title":"Evision.RGBD.RgbdPlane.write/1","doc":"","ref":"Evision.RGBD.RgbdPlane.html#write/1"},{"type":"function","title":"Evision.RGBD.RgbdPlane.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.RGBD.RgbdPlane.html#write/2"},{"type":"function","title":"Evision.RGBD.RgbdPlane.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.RGBD.RgbdPlane.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.RGBD.RgbdPlane.html#write/3"},{"type":"type","title":"Evision.RGBD.RgbdPlane.t/0","doc":"Type that represents an `RGBD.RgbdPlane` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.RGBD.RgbdPlane.html#t:t/0"},{"type":"module","title":"Evision.RGBD.RgbdPlane.RGBD_PLANE_METHOD","doc":"","ref":"Evision.RGBD.RgbdPlane.RGBD_PLANE_METHOD.html"},{"type":"function","title":"Evision.RGBD.RgbdPlane.RGBD_PLANE_METHOD.cv_RGBD_PLANE_METHOD_DEFAULT/0","doc":"","ref":"Evision.RGBD.RgbdPlane.RGBD_PLANE_METHOD.html#cv_RGBD_PLANE_METHOD_DEFAULT/0"},{"type":"type","title":"Evision.RGBD.RgbdPlane.RGBD_PLANE_METHOD.enum/0","doc":"","ref":"Evision.RGBD.RgbdPlane.RGBD_PLANE_METHOD.html#t:enum/0"},{"type":"module","title":"Evision.RNG","doc":"","ref":"Evision.RNG.html"},{"type":"function","title":"Evision.RNG.cv_NORMAL/0","doc":"","ref":"Evision.RNG.html#cv_NORMAL/0"},{"type":"function","title":"Evision.RNG.cv_UNIFORM/0","doc":"","ref":"Evision.RNG.html#cv_UNIFORM/0"},{"type":"type","title":"Evision.RNG.enum/0","doc":"","ref":"Evision.RNG.html#t:enum/0"},{"type":"module","title":"Evision.Rapid","doc":"","ref":"Evision.Rapid.html"},{"type":"function","title":"Evision.Rapid.convertCorrespondencies/1","doc":"","ref":"Evision.Rapid.html#convertCorrespondencies/1"},{"type":"function","title":"Evision.Rapid.convertCorrespondencies/2","doc":"convertCorrespondencies\n\n##### Positional Arguments\n- **cols**: `Evision.Mat`.\n\n  correspondence-position per line in line-bundle-space\n\n- **srcLocations**: `Evision.Mat`.\n\n  the source image location\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  mask containing non-zero values for the elements to be retained\n\n##### Return\n- **pts2d**: `Evision.Mat.t()`.\n\n  2d points\n\n- **pts3d**: `Evision.Mat.t()`.\n\n  3d points\n\n Collect corresponding 2d and 3d points based on correspondencies and mask\n\nPython prototype (for reference only):\n```python3\nconvertCorrespondencies(cols, srcLocations[, pts2d[, pts3d[, mask]]]) -> pts2d, pts3d\n```","ref":"Evision.Rapid.html#convertCorrespondencies/2"},{"type":"function","title":"Evision.Rapid.convertCorrespondencies/3","doc":"convertCorrespondencies\n\n##### Positional Arguments\n- **cols**: `Evision.Mat`.\n\n  correspondence-position per line in line-bundle-space\n\n- **srcLocations**: `Evision.Mat`.\n\n  the source image location\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  mask containing non-zero values for the elements to be retained\n\n##### Return\n- **pts2d**: `Evision.Mat.t()`.\n\n  2d points\n\n- **pts3d**: `Evision.Mat.t()`.\n\n  3d points\n\n Collect corresponding 2d and 3d points based on correspondencies and mask\n\nPython prototype (for reference only):\n```python3\nconvertCorrespondencies(cols, srcLocations[, pts2d[, pts3d[, mask]]]) -> pts2d, pts3d\n```","ref":"Evision.Rapid.html#convertCorrespondencies/3"},{"type":"function","title":"Evision.Rapid.drawCorrespondencies/1","doc":"","ref":"Evision.Rapid.html#drawCorrespondencies/1"},{"type":"function","title":"Evision.Rapid.drawCorrespondencies/2","doc":"drawCorrespondencies\n\n##### Positional Arguments\n- **cols**: `Evision.Mat`.\n\n  column coordinates in the line bundle\n\n##### Keyword Arguments\n- **colors**: `Evision.Mat`.\n\n  colors for the markers. Defaults to white.\n\n##### Return\n- **bundle**: `Evision.Mat.t()`.\n\n  the lineBundle\n\n Debug draw markers of matched correspondences onto a lineBundle\n\nPython prototype (for reference only):\n```python3\ndrawCorrespondencies(bundle, cols[, colors]) -> bundle\n```","ref":"Evision.Rapid.html#drawCorrespondencies/2"},{"type":"function","title":"Evision.Rapid.drawCorrespondencies/3","doc":"drawCorrespondencies\n\n##### Positional Arguments\n- **cols**: `Evision.Mat`.\n\n  column coordinates in the line bundle\n\n##### Keyword Arguments\n- **colors**: `Evision.Mat`.\n\n  colors for the markers. Defaults to white.\n\n##### Return\n- **bundle**: `Evision.Mat.t()`.\n\n  the lineBundle\n\n Debug draw markers of matched correspondences onto a lineBundle\n\nPython prototype (for reference only):\n```python3\ndrawCorrespondencies(bundle, cols[, colors]) -> bundle\n```","ref":"Evision.Rapid.html#drawCorrespondencies/3"},{"type":"function","title":"Evision.Rapid.drawSearchLines/1","doc":"","ref":"Evision.Rapid.html#drawSearchLines/1"},{"type":"function","title":"Evision.Rapid.drawSearchLines/3","doc":"drawSearchLines\n\n##### Positional Arguments\n- **locations**: `Evision.Mat`.\n\n  the source locations of a line bundle\n\n- **color**: `Evision.scalar()`.\n\n  the line color\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  the output image\n\n Debug draw search lines onto an image\n\nPython prototype (for reference only):\n```python3\ndrawSearchLines(img, locations, color) -> img\n```","ref":"Evision.Rapid.html#drawSearchLines/3"},{"type":"function","title":"Evision.Rapid.drawWireframe/1","doc":"","ref":"Evision.Rapid.html#drawWireframe/1"},{"type":"function","title":"Evision.Rapid.drawWireframe/4","doc":"drawWireframe\n\n##### Positional Arguments\n- **pts2d**: `Evision.Mat`.\n\n  the 2d points obtained by @ref projectPoints\n\n- **tris**: `Evision.Mat`.\n\n  triangle face connectivity\n\n- **color**: `Evision.scalar()`.\n\n  line color\n\n##### Keyword Arguments\n- **type**: `integer()`.\n\n  line type. See @ref LineTypes.\n\n- **cullBackface**: `bool`.\n\n  enable back-face culling based on CCW order\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  the output image\n\n Draw a wireframe of a triangle mesh\n\nPython prototype (for reference only):\n```python3\ndrawWireframe(img, pts2d, tris, color[, type[, cullBackface]]) -> img\n```","ref":"Evision.Rapid.html#drawWireframe/4"},{"type":"function","title":"Evision.Rapid.drawWireframe/5","doc":"drawWireframe\n\n##### Positional Arguments\n- **pts2d**: `Evision.Mat`.\n\n  the 2d points obtained by @ref projectPoints\n\n- **tris**: `Evision.Mat`.\n\n  triangle face connectivity\n\n- **color**: `Evision.scalar()`.\n\n  line color\n\n##### Keyword Arguments\n- **type**: `integer()`.\n\n  line type. See @ref LineTypes.\n\n- **cullBackface**: `bool`.\n\n  enable back-face culling based on CCW order\n\n##### Return\n- **img**: `Evision.Mat.t()`.\n\n  the output image\n\n Draw a wireframe of a triangle mesh\n\nPython prototype (for reference only):\n```python3\ndrawWireframe(img, pts2d, tris, color[, type[, cullBackface]]) -> img\n```","ref":"Evision.Rapid.html#drawWireframe/5"},{"type":"function","title":"Evision.Rapid.extractControlPoints/1","doc":"","ref":"Evision.Rapid.html#extractControlPoints/1"},{"type":"function","title":"Evision.Rapid.extractControlPoints/8","doc":"extractControlPoints\n\n##### Positional Arguments\n- **num**: `integer()`.\n\n  number of control points\n\n- **len**: `integer()`.\n\n  search radius (used to restrict the ROI)\n\n- **pts3d**: `Evision.Mat`.\n\n  the 3D points of the mesh\n\n- **rvec**: `Evision.Mat`.\n\n  rotation between mesh and camera\n\n- **tvec**: `Evision.Mat`.\n\n  translation between mesh and camera\n\n- **k**: `Evision.Mat`.\n\n  camera intrinsic\n\n- **imsize**: `Size`.\n\n  size of the video frame\n\n- **tris**: `Evision.Mat`.\n\n  triangle face connectivity\n\n##### Return\n- **ctl2d**: `Evision.Mat.t()`.\n\n  the 2D locations of the control points\n\n- **ctl3d**: `Evision.Mat.t()`.\n\n  matching 3D points of the mesh\n\n Extract control points from the projected silhouette of a mesh\n see @cite drummond2002real Sec 2.1, Step b\n\nPython prototype (for reference only):\n```python3\nextractControlPoints(num, len, pts3d, rvec, tvec, K, imsize, tris[, ctl2d[, ctl3d]]) -> ctl2d, ctl3d\n```","ref":"Evision.Rapid.html#extractControlPoints/8"},{"type":"function","title":"Evision.Rapid.extractControlPoints/9","doc":"extractControlPoints\n\n##### Positional Arguments\n- **num**: `integer()`.\n\n  number of control points\n\n- **len**: `integer()`.\n\n  search radius (used to restrict the ROI)\n\n- **pts3d**: `Evision.Mat`.\n\n  the 3D points of the mesh\n\n- **rvec**: `Evision.Mat`.\n\n  rotation between mesh and camera\n\n- **tvec**: `Evision.Mat`.\n\n  translation between mesh and camera\n\n- **k**: `Evision.Mat`.\n\n  camera intrinsic\n\n- **imsize**: `Size`.\n\n  size of the video frame\n\n- **tris**: `Evision.Mat`.\n\n  triangle face connectivity\n\n##### Return\n- **ctl2d**: `Evision.Mat.t()`.\n\n  the 2D locations of the control points\n\n- **ctl3d**: `Evision.Mat.t()`.\n\n  matching 3D points of the mesh\n\n Extract control points from the projected silhouette of a mesh\n see @cite drummond2002real Sec 2.1, Step b\n\nPython prototype (for reference only):\n```python3\nextractControlPoints(num, len, pts3d, rvec, tvec, K, imsize, tris[, ctl2d[, ctl3d]]) -> ctl2d, ctl3d\n```","ref":"Evision.Rapid.html#extractControlPoints/9"},{"type":"function","title":"Evision.Rapid.extractLineBundle/1","doc":"","ref":"Evision.Rapid.html#extractLineBundle/1"},{"type":"function","title":"Evision.Rapid.extractLineBundle/3","doc":"extractLineBundle\n\n##### Positional Arguments\n- **len**: `integer()`.\n\n  the search radius. The bundle will have `2*len + 1` columns.\n\n- **ctl2d**: `Evision.Mat`.\n\n  the search lines will be centered at this points and orthogonal to the contour defined by\n  them. The bundle will have as many rows.\n\n- **img**: `Evision.Mat`.\n\n  the image to read the pixel intensities values from\n\n##### Return\n- **bundle**: `Evision.Mat.t()`.\n\n  line bundle image with size `ctl2d.rows() x (2 * len + 1)` and the same type as @p img\n\n- **srcLocations**: `Evision.Mat.t()`.\n\n  the source pixel locations of @p bundle in @p img as CV_16SC2\n\n Extract the line bundle from an image\n\nPython prototype (for reference only):\n```python3\nextractLineBundle(len, ctl2d, img[, bundle[, srcLocations]]) -> bundle, srcLocations\n```","ref":"Evision.Rapid.html#extractLineBundle/3"},{"type":"function","title":"Evision.Rapid.extractLineBundle/4","doc":"extractLineBundle\n\n##### Positional Arguments\n- **len**: `integer()`.\n\n  the search radius. The bundle will have `2*len + 1` columns.\n\n- **ctl2d**: `Evision.Mat`.\n\n  the search lines will be centered at this points and orthogonal to the contour defined by\n  them. The bundle will have as many rows.\n\n- **img**: `Evision.Mat`.\n\n  the image to read the pixel intensities values from\n\n##### Return\n- **bundle**: `Evision.Mat.t()`.\n\n  line bundle image with size `ctl2d.rows() x (2 * len + 1)` and the same type as @p img\n\n- **srcLocations**: `Evision.Mat.t()`.\n\n  the source pixel locations of @p bundle in @p img as CV_16SC2\n\n Extract the line bundle from an image\n\nPython prototype (for reference only):\n```python3\nextractLineBundle(len, ctl2d, img[, bundle[, srcLocations]]) -> bundle, srcLocations\n```","ref":"Evision.Rapid.html#extractLineBundle/4"},{"type":"function","title":"Evision.Rapid.findCorrespondencies/1","doc":"findCorrespondencies\n\n##### Positional Arguments\n- **bundle**: `Evision.Mat`.\n\n  the line bundle\n\n##### Return\n- **cols**: `Evision.Mat.t()`.\n\n  correspondence-position per line in line-bundle-space\n\n- **response**: `Evision.Mat.t()`.\n\n  the sobel response for the selected point\n\n Find corresponding image locations by searching for a maximal sobel edge along the search line (a single\n row in the bundle)\n\nPython prototype (for reference only):\n```python3\nfindCorrespondencies(bundle[, cols[, response]]) -> cols, response\n```","ref":"Evision.Rapid.html#findCorrespondencies/1"},{"type":"function","title":"Evision.Rapid.findCorrespondencies/2","doc":"findCorrespondencies\n\n##### Positional Arguments\n- **bundle**: `Evision.Mat`.\n\n  the line bundle\n\n##### Return\n- **cols**: `Evision.Mat.t()`.\n\n  correspondence-position per line in line-bundle-space\n\n- **response**: `Evision.Mat.t()`.\n\n  the sobel response for the selected point\n\n Find corresponding image locations by searching for a maximal sobel edge along the search line (a single\n row in the bundle)\n\nPython prototype (for reference only):\n```python3\nfindCorrespondencies(bundle[, cols[, response]]) -> cols, response\n```","ref":"Evision.Rapid.html#findCorrespondencies/2"},{"type":"function","title":"Evision.Rapid.rapid/1","doc":"","ref":"Evision.Rapid.html#rapid/1"},{"type":"function","title":"Evision.Rapid.rapid/8","doc":"rapid\n\n##### Positional Arguments\n- **img**: `Evision.Mat`.\n\n  the video frame\n\n- **num**: `integer()`.\n\n  number of search lines\n\n- **len**: `integer()`.\n\n  search line radius\n\n- **pts3d**: `Evision.Mat`.\n\n  the 3D points of the mesh\n\n- **tris**: `Evision.Mat`.\n\n  triangle face connectivity\n\n- **k**: `Evision.Mat`.\n\n  camera matrix\n\n##### Return\n- **retval**: `float`\n- **rvec**: `Evision.Mat.t()`.\n\n  rotation between mesh and camera. Input values are used as an initial solution.\n\n- **tvec**: `Evision.Mat.t()`.\n\n  translation between mesh and camera. Input values are used as an initial solution.\n\n- **rmsd**: `double*`.\n\n  the 2d reprojection difference\n\n High level function to execute a single rapid @cite harris1990rapid iteration\n 1. @ref extractControlPoints\n 2. @ref extractLineBundle\n 3. @ref findCorrespondencies\n 4. @ref convertCorrespondencies\n 5. @ref solvePnPRefineLM\n@return ratio of search lines that could be extracted and matched\n\nPython prototype (for reference only):\n```python3\nrapid(img, num, len, pts3d, tris, K, rvec, tvec) -> retval, rvec, tvec, rmsd\n```","ref":"Evision.Rapid.html#rapid/8"},{"type":"type","title":"Evision.Rapid.t/0","doc":"Type that represents an `Rapid` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Rapid.html#t:t/0"},{"type":"module","title":"Evision.Rapid.GOSTracker","doc":"","ref":"Evision.Rapid.GOSTracker.html"},{"type":"function","title":"Evision.Rapid.GOSTracker.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.GOSTracker.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Rapid.GOSTracker.html#clear/1"},{"type":"function","title":"Evision.Rapid.GOSTracker.clearState/1","doc":"clearState\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.GOSTracker.t()`\n\nPython prototype (for reference only):\n```python3\nclearState() -> None\n```","ref":"Evision.Rapid.GOSTracker.html#clearState/1"},{"type":"function","title":"Evision.Rapid.GOSTracker.compute/1","doc":"","ref":"Evision.Rapid.GOSTracker.html#compute/1"},{"type":"function","title":"Evision.Rapid.GOSTracker.compute/7","doc":"compute\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.GOSTracker.t()`\n- **img**: `Evision.Mat`\n- **num**: `integer()`\n- **len**: `integer()`\n- **k**: `Evision.Mat`\n\n##### Keyword Arguments\n- **termcrit**: `TermCriteria`.\n\n##### Return\n- **retval**: `float`\n- **rvec**: `Evision.Mat.t()`\n- **tvec**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ncompute(img, num, len, K, rvec, tvec[, termcrit]) -> retval, rvec, tvec\n```","ref":"Evision.Rapid.GOSTracker.html#compute/7"},{"type":"function","title":"Evision.Rapid.GOSTracker.compute/8","doc":"compute\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.GOSTracker.t()`\n- **img**: `Evision.Mat`\n- **num**: `integer()`\n- **len**: `integer()`\n- **k**: `Evision.Mat`\n\n##### Keyword Arguments\n- **termcrit**: `TermCriteria`.\n\n##### Return\n- **retval**: `float`\n- **rvec**: `Evision.Mat.t()`\n- **tvec**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ncompute(img, num, len, K, rvec, tvec[, termcrit]) -> retval, rvec, tvec\n```","ref":"Evision.Rapid.GOSTracker.html#compute/8"},{"type":"function","title":"Evision.Rapid.GOSTracker.create/1","doc":"","ref":"Evision.Rapid.GOSTracker.html#create/1"},{"type":"function","title":"Evision.Rapid.GOSTracker.create/2","doc":"create\n\n##### Positional Arguments\n- **pts3d**: `Evision.Mat`\n- **tris**: `Evision.Mat`\n\n##### Keyword Arguments\n- **histBins**: `integer()`.\n- **sobelThesh**: `uchar`.\n\n##### Return\n- **retval**: `OLSTracker`\n\nPython prototype (for reference only):\n```python3\ncreate(pts3d, tris[, histBins[, sobelThesh]]) -> retval\n```","ref":"Evision.Rapid.GOSTracker.html#create/2"},{"type":"function","title":"Evision.Rapid.GOSTracker.create/3","doc":"create\n\n##### Positional Arguments\n- **pts3d**: `Evision.Mat`\n- **tris**: `Evision.Mat`\n\n##### Keyword Arguments\n- **histBins**: `integer()`.\n- **sobelThesh**: `uchar`.\n\n##### Return\n- **retval**: `OLSTracker`\n\nPython prototype (for reference only):\n```python3\ncreate(pts3d, tris[, histBins[, sobelThesh]]) -> retval\n```","ref":"Evision.Rapid.GOSTracker.html#create/3"},{"type":"function","title":"Evision.Rapid.GOSTracker.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.GOSTracker.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Rapid.GOSTracker.html#empty/1"},{"type":"function","title":"Evision.Rapid.GOSTracker.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.GOSTracker.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Rapid.GOSTracker.html#getDefaultName/1"},{"type":"function","title":"Evision.Rapid.GOSTracker.read/1","doc":"","ref":"Evision.Rapid.GOSTracker.html#read/1"},{"type":"function","title":"Evision.Rapid.GOSTracker.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.GOSTracker.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Rapid.GOSTracker.html#read/2"},{"type":"function","title":"Evision.Rapid.GOSTracker.save/1","doc":"","ref":"Evision.Rapid.GOSTracker.html#save/1"},{"type":"function","title":"Evision.Rapid.GOSTracker.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.GOSTracker.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Rapid.GOSTracker.html#save/2"},{"type":"function","title":"Evision.Rapid.GOSTracker.write/1","doc":"","ref":"Evision.Rapid.GOSTracker.html#write/1"},{"type":"function","title":"Evision.Rapid.GOSTracker.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.GOSTracker.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Rapid.GOSTracker.html#write/2"},{"type":"function","title":"Evision.Rapid.GOSTracker.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.GOSTracker.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Rapid.GOSTracker.html#write/3"},{"type":"type","title":"Evision.Rapid.GOSTracker.t/0","doc":"Type that represents an `Rapid.GOSTracker` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Rapid.GOSTracker.html#t:t/0"},{"type":"module","title":"Evision.Rapid.OLSTracker","doc":"","ref":"Evision.Rapid.OLSTracker.html"},{"type":"function","title":"Evision.Rapid.OLSTracker.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.OLSTracker.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Rapid.OLSTracker.html#clear/1"},{"type":"function","title":"Evision.Rapid.OLSTracker.clearState/1","doc":"clearState\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.OLSTracker.t()`\n\nPython prototype (for reference only):\n```python3\nclearState() -> None\n```","ref":"Evision.Rapid.OLSTracker.html#clearState/1"},{"type":"function","title":"Evision.Rapid.OLSTracker.compute/1","doc":"","ref":"Evision.Rapid.OLSTracker.html#compute/1"},{"type":"function","title":"Evision.Rapid.OLSTracker.compute/7","doc":"compute\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.OLSTracker.t()`\n- **img**: `Evision.Mat`\n- **num**: `integer()`\n- **len**: `integer()`\n- **k**: `Evision.Mat`\n\n##### Keyword Arguments\n- **termcrit**: `TermCriteria`.\n\n##### Return\n- **retval**: `float`\n- **rvec**: `Evision.Mat.t()`\n- **tvec**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ncompute(img, num, len, K, rvec, tvec[, termcrit]) -> retval, rvec, tvec\n```","ref":"Evision.Rapid.OLSTracker.html#compute/7"},{"type":"function","title":"Evision.Rapid.OLSTracker.compute/8","doc":"compute\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.OLSTracker.t()`\n- **img**: `Evision.Mat`\n- **num**: `integer()`\n- **len**: `integer()`\n- **k**: `Evision.Mat`\n\n##### Keyword Arguments\n- **termcrit**: `TermCriteria`.\n\n##### Return\n- **retval**: `float`\n- **rvec**: `Evision.Mat.t()`\n- **tvec**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ncompute(img, num, len, K, rvec, tvec[, termcrit]) -> retval, rvec, tvec\n```","ref":"Evision.Rapid.OLSTracker.html#compute/8"},{"type":"function","title":"Evision.Rapid.OLSTracker.create/1","doc":"","ref":"Evision.Rapid.OLSTracker.html#create/1"},{"type":"function","title":"Evision.Rapid.OLSTracker.create/2","doc":"create\n\n##### Positional Arguments\n- **pts3d**: `Evision.Mat`\n- **tris**: `Evision.Mat`\n\n##### Keyword Arguments\n- **histBins**: `integer()`.\n- **sobelThesh**: `uchar`.\n\n##### Return\n- **retval**: `OLSTracker`\n\nPython prototype (for reference only):\n```python3\ncreate(pts3d, tris[, histBins[, sobelThesh]]) -> retval\n```","ref":"Evision.Rapid.OLSTracker.html#create/2"},{"type":"function","title":"Evision.Rapid.OLSTracker.create/3","doc":"create\n\n##### Positional Arguments\n- **pts3d**: `Evision.Mat`\n- **tris**: `Evision.Mat`\n\n##### Keyword Arguments\n- **histBins**: `integer()`.\n- **sobelThesh**: `uchar`.\n\n##### Return\n- **retval**: `OLSTracker`\n\nPython prototype (for reference only):\n```python3\ncreate(pts3d, tris[, histBins[, sobelThesh]]) -> retval\n```","ref":"Evision.Rapid.OLSTracker.html#create/3"},{"type":"function","title":"Evision.Rapid.OLSTracker.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.OLSTracker.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Rapid.OLSTracker.html#empty/1"},{"type":"function","title":"Evision.Rapid.OLSTracker.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.OLSTracker.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Rapid.OLSTracker.html#getDefaultName/1"},{"type":"function","title":"Evision.Rapid.OLSTracker.read/1","doc":"","ref":"Evision.Rapid.OLSTracker.html#read/1"},{"type":"function","title":"Evision.Rapid.OLSTracker.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.OLSTracker.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Rapid.OLSTracker.html#read/2"},{"type":"function","title":"Evision.Rapid.OLSTracker.save/1","doc":"","ref":"Evision.Rapid.OLSTracker.html#save/1"},{"type":"function","title":"Evision.Rapid.OLSTracker.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.OLSTracker.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Rapid.OLSTracker.html#save/2"},{"type":"function","title":"Evision.Rapid.OLSTracker.write/1","doc":"","ref":"Evision.Rapid.OLSTracker.html#write/1"},{"type":"function","title":"Evision.Rapid.OLSTracker.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.OLSTracker.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Rapid.OLSTracker.html#write/2"},{"type":"function","title":"Evision.Rapid.OLSTracker.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.OLSTracker.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Rapid.OLSTracker.html#write/3"},{"type":"type","title":"Evision.Rapid.OLSTracker.t/0","doc":"Type that represents an `Rapid.OLSTracker` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Rapid.OLSTracker.html#t:t/0"},{"type":"module","title":"Evision.Rapid.Rapid","doc":"","ref":"Evision.Rapid.Rapid.html"},{"type":"function","title":"Evision.Rapid.Rapid.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.Rapid.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Rapid.Rapid.html#clear/1"},{"type":"function","title":"Evision.Rapid.Rapid.clearState/1","doc":"clearState\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.Rapid.t()`\n\nPython prototype (for reference only):\n```python3\nclearState() -> None\n```","ref":"Evision.Rapid.Rapid.html#clearState/1"},{"type":"function","title":"Evision.Rapid.Rapid.compute/1","doc":"","ref":"Evision.Rapid.Rapid.html#compute/1"},{"type":"function","title":"Evision.Rapid.Rapid.compute/7","doc":"compute\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.Rapid.t()`\n- **img**: `Evision.Mat`\n- **num**: `integer()`\n- **len**: `integer()`\n- **k**: `Evision.Mat`\n\n##### Keyword Arguments\n- **termcrit**: `TermCriteria`.\n\n##### Return\n- **retval**: `float`\n- **rvec**: `Evision.Mat.t()`\n- **tvec**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ncompute(img, num, len, K, rvec, tvec[, termcrit]) -> retval, rvec, tvec\n```","ref":"Evision.Rapid.Rapid.html#compute/7"},{"type":"function","title":"Evision.Rapid.Rapid.compute/8","doc":"compute\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.Rapid.t()`\n- **img**: `Evision.Mat`\n- **num**: `integer()`\n- **len**: `integer()`\n- **k**: `Evision.Mat`\n\n##### Keyword Arguments\n- **termcrit**: `TermCriteria`.\n\n##### Return\n- **retval**: `float`\n- **rvec**: `Evision.Mat.t()`\n- **tvec**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ncompute(img, num, len, K, rvec, tvec[, termcrit]) -> retval, rvec, tvec\n```","ref":"Evision.Rapid.Rapid.html#compute/8"},{"type":"function","title":"Evision.Rapid.Rapid.create/1","doc":"","ref":"Evision.Rapid.Rapid.html#create/1"},{"type":"function","title":"Evision.Rapid.Rapid.create/2","doc":"create\n\n##### Positional Arguments\n- **pts3d**: `Evision.Mat`\n- **tris**: `Evision.Mat`\n\n##### Return\n- **retval**: `Rapid`\n\nPython prototype (for reference only):\n```python3\ncreate(pts3d, tris) -> retval\n```","ref":"Evision.Rapid.Rapid.html#create/2"},{"type":"function","title":"Evision.Rapid.Rapid.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.Rapid.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Rapid.Rapid.html#empty/1"},{"type":"function","title":"Evision.Rapid.Rapid.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.Rapid.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Rapid.Rapid.html#getDefaultName/1"},{"type":"function","title":"Evision.Rapid.Rapid.read/1","doc":"","ref":"Evision.Rapid.Rapid.html#read/1"},{"type":"function","title":"Evision.Rapid.Rapid.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.Rapid.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Rapid.Rapid.html#read/2"},{"type":"function","title":"Evision.Rapid.Rapid.save/1","doc":"","ref":"Evision.Rapid.Rapid.html#save/1"},{"type":"function","title":"Evision.Rapid.Rapid.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.Rapid.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Rapid.Rapid.html#save/2"},{"type":"function","title":"Evision.Rapid.Rapid.write/1","doc":"","ref":"Evision.Rapid.Rapid.html#write/1"},{"type":"function","title":"Evision.Rapid.Rapid.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.Rapid.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Rapid.Rapid.html#write/2"},{"type":"function","title":"Evision.Rapid.Rapid.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.Rapid.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Rapid.Rapid.html#write/3"},{"type":"type","title":"Evision.Rapid.Rapid.t/0","doc":"Type that represents an `Rapid.Rapid` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Rapid.Rapid.html#t:t/0"},{"type":"module","title":"Evision.Rapid.Tracker","doc":"","ref":"Evision.Rapid.Tracker.html"},{"type":"function","title":"Evision.Rapid.Tracker.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.Tracker.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Rapid.Tracker.html#clear/1"},{"type":"function","title":"Evision.Rapid.Tracker.clearState/1","doc":"clearState\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.Tracker.t()`\n\nPython prototype (for reference only):\n```python3\nclearState() -> None\n```","ref":"Evision.Rapid.Tracker.html#clearState/1"},{"type":"function","title":"Evision.Rapid.Tracker.compute/1","doc":"","ref":"Evision.Rapid.Tracker.html#compute/1"},{"type":"function","title":"Evision.Rapid.Tracker.compute/7","doc":"compute\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.Tracker.t()`\n- **img**: `Evision.Mat`\n- **num**: `integer()`\n- **len**: `integer()`\n- **k**: `Evision.Mat`\n\n##### Keyword Arguments\n- **termcrit**: `TermCriteria`.\n\n##### Return\n- **retval**: `float`\n- **rvec**: `Evision.Mat.t()`\n- **tvec**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ncompute(img, num, len, K, rvec, tvec[, termcrit]) -> retval, rvec, tvec\n```","ref":"Evision.Rapid.Tracker.html#compute/7"},{"type":"function","title":"Evision.Rapid.Tracker.compute/8","doc":"compute\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.Tracker.t()`\n- **img**: `Evision.Mat`\n- **num**: `integer()`\n- **len**: `integer()`\n- **k**: `Evision.Mat`\n\n##### Keyword Arguments\n- **termcrit**: `TermCriteria`.\n\n##### Return\n- **retval**: `float`\n- **rvec**: `Evision.Mat.t()`\n- **tvec**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ncompute(img, num, len, K, rvec, tvec[, termcrit]) -> retval, rvec, tvec\n```","ref":"Evision.Rapid.Tracker.html#compute/8"},{"type":"function","title":"Evision.Rapid.Tracker.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.Tracker.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Rapid.Tracker.html#empty/1"},{"type":"function","title":"Evision.Rapid.Tracker.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.Tracker.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Rapid.Tracker.html#getDefaultName/1"},{"type":"function","title":"Evision.Rapid.Tracker.read/1","doc":"","ref":"Evision.Rapid.Tracker.html#read/1"},{"type":"function","title":"Evision.Rapid.Tracker.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.Tracker.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Rapid.Tracker.html#read/2"},{"type":"function","title":"Evision.Rapid.Tracker.save/1","doc":"","ref":"Evision.Rapid.Tracker.html#save/1"},{"type":"function","title":"Evision.Rapid.Tracker.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.Tracker.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Rapid.Tracker.html#save/2"},{"type":"function","title":"Evision.Rapid.Tracker.write/1","doc":"","ref":"Evision.Rapid.Tracker.html#write/1"},{"type":"function","title":"Evision.Rapid.Tracker.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.Tracker.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Rapid.Tracker.html#write/2"},{"type":"function","title":"Evision.Rapid.Tracker.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Rapid.Tracker.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Rapid.Tracker.html#write/3"},{"type":"type","title":"Evision.Rapid.Tracker.t/0","doc":"Type that represents an `Rapid.Tracker` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Rapid.Tracker.html#t:t/0"},{"type":"module","title":"Evision.RectanglesIntersectTypes","doc":"","ref":"Evision.RectanglesIntersectTypes.html"},{"type":"function","title":"Evision.RectanglesIntersectTypes.cv_INTERSECT_FULL/0","doc":"","ref":"Evision.RectanglesIntersectTypes.html#cv_INTERSECT_FULL/0"},{"type":"function","title":"Evision.RectanglesIntersectTypes.cv_INTERSECT_NONE/0","doc":"","ref":"Evision.RectanglesIntersectTypes.html#cv_INTERSECT_NONE/0"},{"type":"function","title":"Evision.RectanglesIntersectTypes.cv_INTERSECT_PARTIAL/0","doc":"","ref":"Evision.RectanglesIntersectTypes.html#cv_INTERSECT_PARTIAL/0"},{"type":"type","title":"Evision.RectanglesIntersectTypes.enum/0","doc":"","ref":"Evision.RectanglesIntersectTypes.html#t:enum/0"},{"type":"module","title":"Evision.ReduceTypes","doc":"","ref":"Evision.ReduceTypes.html"},{"type":"function","title":"Evision.ReduceTypes.cv_REDUCE_AVG/0","doc":"","ref":"Evision.ReduceTypes.html#cv_REDUCE_AVG/0"},{"type":"function","title":"Evision.ReduceTypes.cv_REDUCE_MAX/0","doc":"","ref":"Evision.ReduceTypes.html#cv_REDUCE_MAX/0"},{"type":"function","title":"Evision.ReduceTypes.cv_REDUCE_MIN/0","doc":"","ref":"Evision.ReduceTypes.html#cv_REDUCE_MIN/0"},{"type":"function","title":"Evision.ReduceTypes.cv_REDUCE_SUM2/0","doc":"","ref":"Evision.ReduceTypes.html#cv_REDUCE_SUM2/0"},{"type":"function","title":"Evision.ReduceTypes.cv_REDUCE_SUM/0","doc":"","ref":"Evision.ReduceTypes.html#cv_REDUCE_SUM/0"},{"type":"type","title":"Evision.ReduceTypes.enum/0","doc":"","ref":"Evision.ReduceTypes.html#t:enum/0"},{"type":"module","title":"Evision.Reg","doc":"","ref":"Evision.Reg.html"},{"type":"type","title":"Evision.Reg.t/0","doc":"Type that represents an `Reg` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Reg.html#t:t/0"},{"type":"module","title":"Evision.Reg.Map","doc":"","ref":"Evision.Reg.Map.html"},{"type":"function","title":"Evision.Reg.Map.compose/1","doc":"","ref":"Evision.Reg.Map.html#compose/1"},{"type":"function","title":"Evision.Reg.Map.compose/2","doc":"compose\n\n##### Positional Arguments\n- **self**: `Evision.Reg.Map.t()`\n- **map**: `Map`\n\nPython prototype (for reference only):\n```python3\ncompose(map) -> None\n```","ref":"Evision.Reg.Map.html#compose/2"},{"type":"function","title":"Evision.Reg.Map.inverseMap/1","doc":"inverseMap\n\n##### Positional Arguments\n- **self**: `Evision.Reg.Map.t()`\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ninverseMap() -> retval\n```","ref":"Evision.Reg.Map.html#inverseMap/1"},{"type":"function","title":"Evision.Reg.Map.inverseWarp/1","doc":"","ref":"Evision.Reg.Map.html#inverseWarp/1"},{"type":"function","title":"Evision.Reg.Map.inverseWarp/2","doc":"inverseWarp\n\n##### Positional Arguments\n- **self**: `Evision.Reg.Map.t()`\n- **img1**: `Evision.Mat`\n\n##### Return\n- **img2**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ninverseWarp(img1[, img2]) -> img2\n```","ref":"Evision.Reg.Map.html#inverseWarp/2"},{"type":"function","title":"Evision.Reg.Map.inverseWarp/3","doc":"inverseWarp\n\n##### Positional Arguments\n- **self**: `Evision.Reg.Map.t()`\n- **img1**: `Evision.Mat`\n\n##### Return\n- **img2**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ninverseWarp(img1[, img2]) -> img2\n```","ref":"Evision.Reg.Map.html#inverseWarp/3"},{"type":"function","title":"Evision.Reg.Map.scale/1","doc":"","ref":"Evision.Reg.Map.html#scale/1"},{"type":"function","title":"Evision.Reg.Map.scale/2","doc":"scale\n\n##### Positional Arguments\n- **self**: `Evision.Reg.Map.t()`\n- **factor**: `double`\n\nPython prototype (for reference only):\n```python3\nscale(factor) -> None\n```","ref":"Evision.Reg.Map.html#scale/2"},{"type":"function","title":"Evision.Reg.Map.warp/1","doc":"","ref":"Evision.Reg.Map.html#warp/1"},{"type":"function","title":"Evision.Reg.Map.warp/2","doc":"warp\n\n##### Positional Arguments\n- **self**: `Evision.Reg.Map.t()`\n- **img1**: `Evision.Mat`\n\n##### Return\n- **img2**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nwarp(img1[, img2]) -> img2\n```","ref":"Evision.Reg.Map.html#warp/2"},{"type":"function","title":"Evision.Reg.Map.warp/3","doc":"warp\n\n##### Positional Arguments\n- **self**: `Evision.Reg.Map.t()`\n- **img1**: `Evision.Mat`\n\n##### Return\n- **img2**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nwarp(img1[, img2]) -> img2\n```","ref":"Evision.Reg.Map.html#warp/3"},{"type":"type","title":"Evision.Reg.Map.t/0","doc":"Type that represents an `Reg.Map` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Reg.Map.html#t:t/0"},{"type":"module","title":"Evision.Reg.MapAffine","doc":"","ref":"Evision.Reg.MapAffine.html"},{"type":"function","title":"Evision.Reg.MapAffine.compose/1","doc":"","ref":"Evision.Reg.MapAffine.html#compose/1"},{"type":"function","title":"Evision.Reg.MapAffine.compose/2","doc":"compose\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapAffine.t()`\n- **map**: `Map`\n\nPython prototype (for reference only):\n```python3\ncompose(map) -> None\n```","ref":"Evision.Reg.MapAffine.html#compose/2"},{"type":"function","title":"Evision.Reg.MapAffine.getLinTr/1","doc":"getLinTr\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapAffine.t()`\n\n##### Return\n- **linTr**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetLinTr([, linTr]) -> linTr\n```","ref":"Evision.Reg.MapAffine.html#getLinTr/1"},{"type":"function","title":"Evision.Reg.MapAffine.getLinTr/2","doc":"getLinTr\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapAffine.t()`\n\n##### Return\n- **linTr**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetLinTr([, linTr]) -> linTr\n```","ref":"Evision.Reg.MapAffine.html#getLinTr/2"},{"type":"function","title":"Evision.Reg.MapAffine.getShift/1","doc":"getShift\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapAffine.t()`\n\n##### Return\n- **shift**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetShift([, shift]) -> shift\n```","ref":"Evision.Reg.MapAffine.html#getShift/1"},{"type":"function","title":"Evision.Reg.MapAffine.getShift/2","doc":"getShift\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapAffine.t()`\n\n##### Return\n- **shift**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetShift([, shift]) -> shift\n```","ref":"Evision.Reg.MapAffine.html#getShift/2"},{"type":"function","title":"Evision.Reg.MapAffine.inverseMap/1","doc":"inverseMap\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapAffine.t()`\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ninverseMap() -> retval\n```","ref":"Evision.Reg.MapAffine.html#inverseMap/1"},{"type":"function","title":"Evision.Reg.MapAffine.inverseWarp/1","doc":"","ref":"Evision.Reg.MapAffine.html#inverseWarp/1"},{"type":"function","title":"Evision.Reg.MapAffine.inverseWarp/2","doc":"inverseWarp\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapAffine.t()`\n- **img1**: `Evision.Mat`\n\n##### Return\n- **img2**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ninverseWarp(img1[, img2]) -> img2\n```","ref":"Evision.Reg.MapAffine.html#inverseWarp/2"},{"type":"function","title":"Evision.Reg.MapAffine.inverseWarp/3","doc":"inverseWarp\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapAffine.t()`\n- **img1**: `Evision.Mat`\n\n##### Return\n- **img2**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ninverseWarp(img1[, img2]) -> img2\n```","ref":"Evision.Reg.MapAffine.html#inverseWarp/3"},{"type":"function","title":"Evision.Reg.MapAffine.mapAffine/0","doc":"MapAffine\n##### Return\n- **self**: `MapAffine`\n\nPython prototype (for reference only):\n```python3\nMapAffine() ->  \n```","ref":"Evision.Reg.MapAffine.html#mapAffine/0"},{"type":"function","title":"Evision.Reg.MapAffine.mapAffine/1","doc":"","ref":"Evision.Reg.MapAffine.html#mapAffine/1"},{"type":"function","title":"Evision.Reg.MapAffine.mapAffine/2","doc":"MapAffine\n\n##### Positional Arguments\n- **linTr**: `Evision.Mat`\n- **shift**: `Evision.Mat`\n\n##### Return\n- **self**: `MapAffine`\n\nPython prototype (for reference only):\n```python3\nMapAffine(linTr, shift) ->  \n```","ref":"Evision.Reg.MapAffine.html#mapAffine/2"},{"type":"function","title":"Evision.Reg.MapAffine.scale/1","doc":"","ref":"Evision.Reg.MapAffine.html#scale/1"},{"type":"function","title":"Evision.Reg.MapAffine.scale/2","doc":"scale\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapAffine.t()`\n- **factor**: `double`\n\nPython prototype (for reference only):\n```python3\nscale(factor) -> None\n```","ref":"Evision.Reg.MapAffine.html#scale/2"},{"type":"function","title":"Evision.Reg.MapAffine.warp/1","doc":"","ref":"Evision.Reg.MapAffine.html#warp/1"},{"type":"function","title":"Evision.Reg.MapAffine.warp/2","doc":"warp\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapAffine.t()`\n- **img1**: `Evision.Mat`\n\n##### Return\n- **img2**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nwarp(img1[, img2]) -> img2\n```","ref":"Evision.Reg.MapAffine.html#warp/2"},{"type":"function","title":"Evision.Reg.MapAffine.warp/3","doc":"warp\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapAffine.t()`\n- **img1**: `Evision.Mat`\n\n##### Return\n- **img2**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nwarp(img1[, img2]) -> img2\n```","ref":"Evision.Reg.MapAffine.html#warp/3"},{"type":"type","title":"Evision.Reg.MapAffine.t/0","doc":"Type that represents an `Reg.MapAffine` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Reg.MapAffine.html#t:t/0"},{"type":"module","title":"Evision.Reg.MapProjec","doc":"","ref":"Evision.Reg.MapProjec.html"},{"type":"function","title":"Evision.Reg.MapProjec.compose/1","doc":"","ref":"Evision.Reg.MapProjec.html#compose/1"},{"type":"function","title":"Evision.Reg.MapProjec.compose/2","doc":"compose\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapProjec.t()`\n- **map**: `Map`\n\nPython prototype (for reference only):\n```python3\ncompose(map) -> None\n```","ref":"Evision.Reg.MapProjec.html#compose/2"},{"type":"function","title":"Evision.Reg.MapProjec.getProjTr/1","doc":"getProjTr\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapProjec.t()`\n\n##### Return\n- **projTr**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetProjTr([, projTr]) -> projTr\n```","ref":"Evision.Reg.MapProjec.html#getProjTr/1"},{"type":"function","title":"Evision.Reg.MapProjec.getProjTr/2","doc":"getProjTr\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapProjec.t()`\n\n##### Return\n- **projTr**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetProjTr([, projTr]) -> projTr\n```","ref":"Evision.Reg.MapProjec.html#getProjTr/2"},{"type":"function","title":"Evision.Reg.MapProjec.inverseMap/1","doc":"inverseMap\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapProjec.t()`\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ninverseMap() -> retval\n```","ref":"Evision.Reg.MapProjec.html#inverseMap/1"},{"type":"function","title":"Evision.Reg.MapProjec.inverseWarp/1","doc":"","ref":"Evision.Reg.MapProjec.html#inverseWarp/1"},{"type":"function","title":"Evision.Reg.MapProjec.inverseWarp/2","doc":"inverseWarp\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapProjec.t()`\n- **img1**: `Evision.Mat`\n\n##### Return\n- **img2**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ninverseWarp(img1[, img2]) -> img2\n```","ref":"Evision.Reg.MapProjec.html#inverseWarp/2"},{"type":"function","title":"Evision.Reg.MapProjec.inverseWarp/3","doc":"inverseWarp\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapProjec.t()`\n- **img1**: `Evision.Mat`\n\n##### Return\n- **img2**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ninverseWarp(img1[, img2]) -> img2\n```","ref":"Evision.Reg.MapProjec.html#inverseWarp/3"},{"type":"function","title":"Evision.Reg.MapProjec.mapProjec/0","doc":"MapProjec\n##### Return\n- **self**: `MapProjec`\n\nPython prototype (for reference only):\n```python3\nMapProjec() ->  \n```","ref":"Evision.Reg.MapProjec.html#mapProjec/0"},{"type":"function","title":"Evision.Reg.MapProjec.mapProjec/1","doc":"MapProjec\n\n##### Positional Arguments\n- **projTr**: `Evision.Mat`\n\n##### Return\n- **self**: `MapProjec`\n\nPython prototype (for reference only):\n```python3\nMapProjec(projTr) ->  \n```","ref":"Evision.Reg.MapProjec.html#mapProjec/1"},{"type":"function","title":"Evision.Reg.MapProjec.normalize/1","doc":"normalize\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapProjec.t()`\n\nPython prototype (for reference only):\n```python3\nnormalize() -> None\n```","ref":"Evision.Reg.MapProjec.html#normalize/1"},{"type":"function","title":"Evision.Reg.MapProjec.scale/1","doc":"","ref":"Evision.Reg.MapProjec.html#scale/1"},{"type":"function","title":"Evision.Reg.MapProjec.scale/2","doc":"scale\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapProjec.t()`\n- **factor**: `double`\n\nPython prototype (for reference only):\n```python3\nscale(factor) -> None\n```","ref":"Evision.Reg.MapProjec.html#scale/2"},{"type":"function","title":"Evision.Reg.MapProjec.warp/1","doc":"","ref":"Evision.Reg.MapProjec.html#warp/1"},{"type":"function","title":"Evision.Reg.MapProjec.warp/2","doc":"warp\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapProjec.t()`\n- **img1**: `Evision.Mat`\n\n##### Return\n- **img2**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nwarp(img1[, img2]) -> img2\n```","ref":"Evision.Reg.MapProjec.html#warp/2"},{"type":"function","title":"Evision.Reg.MapProjec.warp/3","doc":"warp\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapProjec.t()`\n- **img1**: `Evision.Mat`\n\n##### Return\n- **img2**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nwarp(img1[, img2]) -> img2\n```","ref":"Evision.Reg.MapProjec.html#warp/3"},{"type":"type","title":"Evision.Reg.MapProjec.t/0","doc":"Type that represents an `Reg.MapProjec` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Reg.MapProjec.html#t:t/0"},{"type":"module","title":"Evision.Reg.MapShift","doc":"","ref":"Evision.Reg.MapShift.html"},{"type":"function","title":"Evision.Reg.MapShift.compose/1","doc":"","ref":"Evision.Reg.MapShift.html#compose/1"},{"type":"function","title":"Evision.Reg.MapShift.compose/2","doc":"compose\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapShift.t()`\n- **map**: `Map`\n\nPython prototype (for reference only):\n```python3\ncompose(map) -> None\n```","ref":"Evision.Reg.MapShift.html#compose/2"},{"type":"function","title":"Evision.Reg.MapShift.getShift/1","doc":"getShift\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapShift.t()`\n\n##### Return\n- **shift**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetShift([, shift]) -> shift\n```","ref":"Evision.Reg.MapShift.html#getShift/1"},{"type":"function","title":"Evision.Reg.MapShift.getShift/2","doc":"getShift\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapShift.t()`\n\n##### Return\n- **shift**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetShift([, shift]) -> shift\n```","ref":"Evision.Reg.MapShift.html#getShift/2"},{"type":"function","title":"Evision.Reg.MapShift.inverseMap/1","doc":"inverseMap\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapShift.t()`\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ninverseMap() -> retval\n```","ref":"Evision.Reg.MapShift.html#inverseMap/1"},{"type":"function","title":"Evision.Reg.MapShift.inverseWarp/1","doc":"","ref":"Evision.Reg.MapShift.html#inverseWarp/1"},{"type":"function","title":"Evision.Reg.MapShift.inverseWarp/2","doc":"inverseWarp\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapShift.t()`\n- **img1**: `Evision.Mat`\n\n##### Return\n- **img2**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ninverseWarp(img1[, img2]) -> img2\n```","ref":"Evision.Reg.MapShift.html#inverseWarp/2"},{"type":"function","title":"Evision.Reg.MapShift.inverseWarp/3","doc":"inverseWarp\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapShift.t()`\n- **img1**: `Evision.Mat`\n\n##### Return\n- **img2**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ninverseWarp(img1[, img2]) -> img2\n```","ref":"Evision.Reg.MapShift.html#inverseWarp/3"},{"type":"function","title":"Evision.Reg.MapShift.mapShift/0","doc":"MapShift\n##### Return\n- **self**: `MapShift`\n\nPython prototype (for reference only):\n```python3\nMapShift() ->  \n```","ref":"Evision.Reg.MapShift.html#mapShift/0"},{"type":"function","title":"Evision.Reg.MapShift.mapShift/1","doc":"MapShift\n\n##### Positional Arguments\n- **shift**: `Evision.Mat`\n\n##### Return\n- **self**: `MapShift`\n\nPython prototype (for reference only):\n```python3\nMapShift(shift) ->  \n```","ref":"Evision.Reg.MapShift.html#mapShift/1"},{"type":"function","title":"Evision.Reg.MapShift.scale/1","doc":"","ref":"Evision.Reg.MapShift.html#scale/1"},{"type":"function","title":"Evision.Reg.MapShift.scale/2","doc":"scale\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapShift.t()`\n- **factor**: `double`\n\nPython prototype (for reference only):\n```python3\nscale(factor) -> None\n```","ref":"Evision.Reg.MapShift.html#scale/2"},{"type":"function","title":"Evision.Reg.MapShift.warp/1","doc":"","ref":"Evision.Reg.MapShift.html#warp/1"},{"type":"function","title":"Evision.Reg.MapShift.warp/2","doc":"warp\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapShift.t()`\n- **img1**: `Evision.Mat`\n\n##### Return\n- **img2**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nwarp(img1[, img2]) -> img2\n```","ref":"Evision.Reg.MapShift.html#warp/2"},{"type":"function","title":"Evision.Reg.MapShift.warp/3","doc":"warp\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapShift.t()`\n- **img1**: `Evision.Mat`\n\n##### Return\n- **img2**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nwarp(img1[, img2]) -> img2\n```","ref":"Evision.Reg.MapShift.html#warp/3"},{"type":"type","title":"Evision.Reg.MapShift.t/0","doc":"Type that represents an `Reg.MapShift` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Reg.MapShift.html#t:t/0"},{"type":"module","title":"Evision.Reg.MapTypeCaster","doc":"","ref":"Evision.Reg.MapTypeCaster.html"},{"type":"function","title":"Evision.Reg.MapTypeCaster.toAffine/1","doc":"toAffine\n\n##### Positional Arguments\n- **sourceMap**: `Map`\n\n##### Return\n- **retval**: `MapAffine`\n\nPython prototype (for reference only):\n```python3\ntoAffine(sourceMap) -> retval\n```","ref":"Evision.Reg.MapTypeCaster.html#toAffine/1"},{"type":"function","title":"Evision.Reg.MapTypeCaster.toProjec/1","doc":"toProjec\n\n##### Positional Arguments\n- **sourceMap**: `Map`\n\n##### Return\n- **retval**: `MapProjec`\n\nPython prototype (for reference only):\n```python3\ntoProjec(sourceMap) -> retval\n```","ref":"Evision.Reg.MapTypeCaster.html#toProjec/1"},{"type":"function","title":"Evision.Reg.MapTypeCaster.toShift/1","doc":"toShift\n\n##### Positional Arguments\n- **sourceMap**: `Map`\n\n##### Return\n- **retval**: `MapShift`\n\nPython prototype (for reference only):\n```python3\ntoShift(sourceMap) -> retval\n```","ref":"Evision.Reg.MapTypeCaster.html#toShift/1"},{"type":"type","title":"Evision.Reg.MapTypeCaster.t/0","doc":"Type that represents an `Reg.MapTypeCaster` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Reg.MapTypeCaster.html#t:t/0"},{"type":"module","title":"Evision.Reg.Mapper","doc":"","ref":"Evision.Reg.Mapper.html"},{"type":"function","title":"Evision.Reg.Mapper.calculate/1","doc":"","ref":"Evision.Reg.Mapper.html#calculate/1"},{"type":"function","title":"Evision.Reg.Mapper.calculate/3","doc":"calculate\n\n##### Positional Arguments\n- **self**: `Evision.Reg.Mapper.t()`\n- **img1**: `Evision.Mat`\n- **img2**: `Evision.Mat`\n\n##### Keyword Arguments\n- **init**: `Map`.\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ncalculate(img1, img2[, init]) -> retval\n```","ref":"Evision.Reg.Mapper.html#calculate/3"},{"type":"function","title":"Evision.Reg.Mapper.calculate/4","doc":"calculate\n\n##### Positional Arguments\n- **self**: `Evision.Reg.Mapper.t()`\n- **img1**: `Evision.Mat`\n- **img2**: `Evision.Mat`\n\n##### Keyword Arguments\n- **init**: `Map`.\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ncalculate(img1, img2[, init]) -> retval\n```","ref":"Evision.Reg.Mapper.html#calculate/4"},{"type":"function","title":"Evision.Reg.Mapper.getMap/1","doc":"getMap\n\n##### Positional Arguments\n- **self**: `Evision.Reg.Mapper.t()`\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ngetMap() -> retval\n```","ref":"Evision.Reg.Mapper.html#getMap/1"},{"type":"type","title":"Evision.Reg.Mapper.t/0","doc":"Type that represents an `Reg.Mapper` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Reg.Mapper.html#t:t/0"},{"type":"module","title":"Evision.Reg.MapperGradAffine","doc":"","ref":"Evision.Reg.MapperGradAffine.html"},{"type":"function","title":"Evision.Reg.MapperGradAffine.calculate/1","doc":"","ref":"Evision.Reg.MapperGradAffine.html#calculate/1"},{"type":"function","title":"Evision.Reg.MapperGradAffine.calculate/3","doc":"calculate\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapperGradAffine.t()`\n- **img1**: `Evision.Mat`\n- **img2**: `Evision.Mat`\n\n##### Keyword Arguments\n- **init**: `Map`.\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ncalculate(img1, img2[, init]) -> retval\n```","ref":"Evision.Reg.MapperGradAffine.html#calculate/3"},{"type":"function","title":"Evision.Reg.MapperGradAffine.calculate/4","doc":"calculate\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapperGradAffine.t()`\n- **img1**: `Evision.Mat`\n- **img2**: `Evision.Mat`\n\n##### Keyword Arguments\n- **init**: `Map`.\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ncalculate(img1, img2[, init]) -> retval\n```","ref":"Evision.Reg.MapperGradAffine.html#calculate/4"},{"type":"function","title":"Evision.Reg.MapperGradAffine.getMap/1","doc":"getMap\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapperGradAffine.t()`\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ngetMap() -> retval\n```","ref":"Evision.Reg.MapperGradAffine.html#getMap/1"},{"type":"function","title":"Evision.Reg.MapperGradAffine.mapperGradAffine/0","doc":"MapperGradAffine\n##### Return\n- **self**: `MapperGradAffine`\n\nPython prototype (for reference only):\n```python3\nMapperGradAffine() ->  \n```","ref":"Evision.Reg.MapperGradAffine.html#mapperGradAffine/0"},{"type":"function","title":"Evision.Reg.MapperGradAffine.mapperGradAffine/1","doc":"","ref":"Evision.Reg.MapperGradAffine.html#mapperGradAffine/1"},{"type":"type","title":"Evision.Reg.MapperGradAffine.t/0","doc":"Type that represents an `Reg.MapperGradAffine` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Reg.MapperGradAffine.html#t:t/0"},{"type":"module","title":"Evision.Reg.MapperGradEuclid","doc":"","ref":"Evision.Reg.MapperGradEuclid.html"},{"type":"function","title":"Evision.Reg.MapperGradEuclid.calculate/1","doc":"","ref":"Evision.Reg.MapperGradEuclid.html#calculate/1"},{"type":"function","title":"Evision.Reg.MapperGradEuclid.calculate/3","doc":"calculate\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapperGradEuclid.t()`\n- **img1**: `Evision.Mat`\n- **img2**: `Evision.Mat`\n\n##### Keyword Arguments\n- **init**: `Map`.\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ncalculate(img1, img2[, init]) -> retval\n```","ref":"Evision.Reg.MapperGradEuclid.html#calculate/3"},{"type":"function","title":"Evision.Reg.MapperGradEuclid.calculate/4","doc":"calculate\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapperGradEuclid.t()`\n- **img1**: `Evision.Mat`\n- **img2**: `Evision.Mat`\n\n##### Keyword Arguments\n- **init**: `Map`.\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ncalculate(img1, img2[, init]) -> retval\n```","ref":"Evision.Reg.MapperGradEuclid.html#calculate/4"},{"type":"function","title":"Evision.Reg.MapperGradEuclid.getMap/1","doc":"getMap\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapperGradEuclid.t()`\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ngetMap() -> retval\n```","ref":"Evision.Reg.MapperGradEuclid.html#getMap/1"},{"type":"function","title":"Evision.Reg.MapperGradEuclid.mapperGradEuclid/0","doc":"MapperGradEuclid\n##### Return\n- **self**: `MapperGradEuclid`\n\nPython prototype (for reference only):\n```python3\nMapperGradEuclid() ->  \n```","ref":"Evision.Reg.MapperGradEuclid.html#mapperGradEuclid/0"},{"type":"function","title":"Evision.Reg.MapperGradEuclid.mapperGradEuclid/1","doc":"","ref":"Evision.Reg.MapperGradEuclid.html#mapperGradEuclid/1"},{"type":"type","title":"Evision.Reg.MapperGradEuclid.t/0","doc":"Type that represents an `Reg.MapperGradEuclid` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Reg.MapperGradEuclid.html#t:t/0"},{"type":"module","title":"Evision.Reg.MapperGradProj","doc":"","ref":"Evision.Reg.MapperGradProj.html"},{"type":"function","title":"Evision.Reg.MapperGradProj.calculate/1","doc":"","ref":"Evision.Reg.MapperGradProj.html#calculate/1"},{"type":"function","title":"Evision.Reg.MapperGradProj.calculate/3","doc":"calculate\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapperGradProj.t()`\n- **img1**: `Evision.Mat`\n- **img2**: `Evision.Mat`\n\n##### Keyword Arguments\n- **init**: `Map`.\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ncalculate(img1, img2[, init]) -> retval\n```","ref":"Evision.Reg.MapperGradProj.html#calculate/3"},{"type":"function","title":"Evision.Reg.MapperGradProj.calculate/4","doc":"calculate\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapperGradProj.t()`\n- **img1**: `Evision.Mat`\n- **img2**: `Evision.Mat`\n\n##### Keyword Arguments\n- **init**: `Map`.\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ncalculate(img1, img2[, init]) -> retval\n```","ref":"Evision.Reg.MapperGradProj.html#calculate/4"},{"type":"function","title":"Evision.Reg.MapperGradProj.getMap/1","doc":"getMap\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapperGradProj.t()`\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ngetMap() -> retval\n```","ref":"Evision.Reg.MapperGradProj.html#getMap/1"},{"type":"function","title":"Evision.Reg.MapperGradProj.mapperGradProj/0","doc":"MapperGradProj\n##### Return\n- **self**: `MapperGradProj`\n\nPython prototype (for reference only):\n```python3\nMapperGradProj() ->  \n```","ref":"Evision.Reg.MapperGradProj.html#mapperGradProj/0"},{"type":"function","title":"Evision.Reg.MapperGradProj.mapperGradProj/1","doc":"","ref":"Evision.Reg.MapperGradProj.html#mapperGradProj/1"},{"type":"type","title":"Evision.Reg.MapperGradProj.t/0","doc":"Type that represents an `Reg.MapperGradProj` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Reg.MapperGradProj.html#t:t/0"},{"type":"module","title":"Evision.Reg.MapperGradShift","doc":"","ref":"Evision.Reg.MapperGradShift.html"},{"type":"function","title":"Evision.Reg.MapperGradShift.calculate/1","doc":"","ref":"Evision.Reg.MapperGradShift.html#calculate/1"},{"type":"function","title":"Evision.Reg.MapperGradShift.calculate/3","doc":"calculate\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapperGradShift.t()`\n- **img1**: `Evision.Mat`\n- **img2**: `Evision.Mat`\n\n##### Keyword Arguments\n- **init**: `Map`.\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ncalculate(img1, img2[, init]) -> retval\n```","ref":"Evision.Reg.MapperGradShift.html#calculate/3"},{"type":"function","title":"Evision.Reg.MapperGradShift.calculate/4","doc":"calculate\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapperGradShift.t()`\n- **img1**: `Evision.Mat`\n- **img2**: `Evision.Mat`\n\n##### Keyword Arguments\n- **init**: `Map`.\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ncalculate(img1, img2[, init]) -> retval\n```","ref":"Evision.Reg.MapperGradShift.html#calculate/4"},{"type":"function","title":"Evision.Reg.MapperGradShift.getMap/1","doc":"getMap\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapperGradShift.t()`\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ngetMap() -> retval\n```","ref":"Evision.Reg.MapperGradShift.html#getMap/1"},{"type":"function","title":"Evision.Reg.MapperGradShift.mapperGradShift/0","doc":"MapperGradShift\n##### Return\n- **self**: `MapperGradShift`\n\nPython prototype (for reference only):\n```python3\nMapperGradShift() ->  \n```","ref":"Evision.Reg.MapperGradShift.html#mapperGradShift/0"},{"type":"function","title":"Evision.Reg.MapperGradShift.mapperGradShift/1","doc":"","ref":"Evision.Reg.MapperGradShift.html#mapperGradShift/1"},{"type":"type","title":"Evision.Reg.MapperGradShift.t/0","doc":"Type that represents an `Reg.MapperGradShift` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Reg.MapperGradShift.html#t:t/0"},{"type":"module","title":"Evision.Reg.MapperGradSimilar","doc":"","ref":"Evision.Reg.MapperGradSimilar.html"},{"type":"function","title":"Evision.Reg.MapperGradSimilar.calculate/1","doc":"","ref":"Evision.Reg.MapperGradSimilar.html#calculate/1"},{"type":"function","title":"Evision.Reg.MapperGradSimilar.calculate/3","doc":"calculate\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapperGradSimilar.t()`\n- **img1**: `Evision.Mat`\n- **img2**: `Evision.Mat`\n\n##### Keyword Arguments\n- **init**: `Map`.\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ncalculate(img1, img2[, init]) -> retval\n```","ref":"Evision.Reg.MapperGradSimilar.html#calculate/3"},{"type":"function","title":"Evision.Reg.MapperGradSimilar.calculate/4","doc":"calculate\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapperGradSimilar.t()`\n- **img1**: `Evision.Mat`\n- **img2**: `Evision.Mat`\n\n##### Keyword Arguments\n- **init**: `Map`.\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ncalculate(img1, img2[, init]) -> retval\n```","ref":"Evision.Reg.MapperGradSimilar.html#calculate/4"},{"type":"function","title":"Evision.Reg.MapperGradSimilar.getMap/1","doc":"getMap\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapperGradSimilar.t()`\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ngetMap() -> retval\n```","ref":"Evision.Reg.MapperGradSimilar.html#getMap/1"},{"type":"function","title":"Evision.Reg.MapperGradSimilar.mapperGradSimilar/0","doc":"MapperGradSimilar\n##### Return\n- **self**: `MapperGradSimilar`\n\nPython prototype (for reference only):\n```python3\nMapperGradSimilar() ->  \n```","ref":"Evision.Reg.MapperGradSimilar.html#mapperGradSimilar/0"},{"type":"function","title":"Evision.Reg.MapperGradSimilar.mapperGradSimilar/1","doc":"","ref":"Evision.Reg.MapperGradSimilar.html#mapperGradSimilar/1"},{"type":"type","title":"Evision.Reg.MapperGradSimilar.t/0","doc":"Type that represents an `Reg.MapperGradSimilar` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Reg.MapperGradSimilar.html#t:t/0"},{"type":"module","title":"Evision.Reg.MapperPyramid","doc":"","ref":"Evision.Reg.MapperPyramid.html"},{"type":"function","title":"Evision.Reg.MapperPyramid.calculate/1","doc":"","ref":"Evision.Reg.MapperPyramid.html#calculate/1"},{"type":"function","title":"Evision.Reg.MapperPyramid.calculate/3","doc":"calculate\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapperPyramid.t()`\n- **img1**: `Evision.Mat`\n- **img2**: `Evision.Mat`\n\n##### Keyword Arguments\n- **init**: `Map`.\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ncalculate(img1, img2[, init]) -> retval\n```","ref":"Evision.Reg.MapperPyramid.html#calculate/3"},{"type":"function","title":"Evision.Reg.MapperPyramid.calculate/4","doc":"calculate\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapperPyramid.t()`\n- **img1**: `Evision.Mat`\n- **img2**: `Evision.Mat`\n\n##### Keyword Arguments\n- **init**: `Map`.\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ncalculate(img1, img2[, init]) -> retval\n```","ref":"Evision.Reg.MapperPyramid.html#calculate/4"},{"type":"function","title":"Evision.Reg.MapperPyramid.get_numIterPerScale_/1","doc":"","ref":"Evision.Reg.MapperPyramid.html#get_numIterPerScale_/1"},{"type":"function","title":"Evision.Reg.MapperPyramid.get_numLev_/1","doc":"","ref":"Evision.Reg.MapperPyramid.html#get_numLev_/1"},{"type":"function","title":"Evision.Reg.MapperPyramid.getMap/1","doc":"getMap\n\n##### Positional Arguments\n- **self**: `Evision.Reg.MapperPyramid.t()`\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ngetMap() -> retval\n```","ref":"Evision.Reg.MapperPyramid.html#getMap/1"},{"type":"function","title":"Evision.Reg.MapperPyramid.mapperPyramid/1","doc":"MapperPyramid\n\n##### Positional Arguments\n- **baseMapper**: `Mapper`\n\n##### Return\n- **self**: `MapperPyramid`\n\nPython prototype (for reference only):\n```python3\nMapperPyramid(baseMapper) ->  \n```","ref":"Evision.Reg.MapperPyramid.html#mapperPyramid/1"},{"type":"function","title":"Evision.Reg.MapperPyramid.set_numIterPerScale_/2","doc":"","ref":"Evision.Reg.MapperPyramid.html#set_numIterPerScale_/2"},{"type":"function","title":"Evision.Reg.MapperPyramid.set_numLev_/2","doc":"","ref":"Evision.Reg.MapperPyramid.html#set_numLev_/2"},{"type":"type","title":"Evision.Reg.MapperPyramid.t/0","doc":"Type that represents an `Reg.MapperPyramid` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Reg.MapperPyramid.html#t:t/0"},{"type":"module","title":"Evision.RetrievalModes","doc":"","ref":"Evision.RetrievalModes.html"},{"type":"function","title":"Evision.RetrievalModes.cv_RETR_CCOMP/0","doc":"","ref":"Evision.RetrievalModes.html#cv_RETR_CCOMP/0"},{"type":"function","title":"Evision.RetrievalModes.cv_RETR_EXTERNAL/0","doc":"","ref":"Evision.RetrievalModes.html#cv_RETR_EXTERNAL/0"},{"type":"function","title":"Evision.RetrievalModes.cv_RETR_FLOODFILL/0","doc":"","ref":"Evision.RetrievalModes.html#cv_RETR_FLOODFILL/0"},{"type":"function","title":"Evision.RetrievalModes.cv_RETR_LIST/0","doc":"","ref":"Evision.RetrievalModes.html#cv_RETR_LIST/0"},{"type":"function","title":"Evision.RetrievalModes.cv_RETR_TREE/0","doc":"","ref":"Evision.RetrievalModes.html#cv_RETR_TREE/0"},{"type":"type","title":"Evision.RetrievalModes.enum/0","doc":"","ref":"Evision.RetrievalModes.html#t:enum/0"},{"type":"module","title":"Evision.RobotWorldHandEyeCalibrationMethod","doc":"","ref":"Evision.RobotWorldHandEyeCalibrationMethod.html"},{"type":"function","title":"Evision.RobotWorldHandEyeCalibrationMethod.cv_CALIB_ROBOT_WORLD_HAND_EYE_LI/0","doc":"","ref":"Evision.RobotWorldHandEyeCalibrationMethod.html#cv_CALIB_ROBOT_WORLD_HAND_EYE_LI/0"},{"type":"function","title":"Evision.RobotWorldHandEyeCalibrationMethod.cv_CALIB_ROBOT_WORLD_HAND_EYE_SHAH/0","doc":"","ref":"Evision.RobotWorldHandEyeCalibrationMethod.html#cv_CALIB_ROBOT_WORLD_HAND_EYE_SHAH/0"},{"type":"type","title":"Evision.RobotWorldHandEyeCalibrationMethod.enum/0","doc":"","ref":"Evision.RobotWorldHandEyeCalibrationMethod.html#t:enum/0"},{"type":"module","title":"Evision.RotateFlags","doc":"","ref":"Evision.RotateFlags.html"},{"type":"function","title":"Evision.RotateFlags.cv_ROTATE_90_CLOCKWISE/0","doc":"","ref":"Evision.RotateFlags.html#cv_ROTATE_90_CLOCKWISE/0"},{"type":"function","title":"Evision.RotateFlags.cv_ROTATE_90_COUNTERCLOCKWISE/0","doc":"","ref":"Evision.RotateFlags.html#cv_ROTATE_90_COUNTERCLOCKWISE/0"},{"type":"function","title":"Evision.RotateFlags.cv_ROTATE_180/0","doc":"","ref":"Evision.RotateFlags.html#cv_ROTATE_180/0"},{"type":"type","title":"Evision.RotateFlags.enum/0","doc":"","ref":"Evision.RotateFlags.html#t:enum/0"},{"type":"module","title":"Evision.RotatedRect","doc":"","ref":"Evision.RotatedRect.html"},{"type":"function","title":"Evision.RotatedRect.boundingRect2f/1","doc":"boundingRect2f\n\n##### Positional Arguments\n- **self**: `Evision.RotatedRect.t()`\n\n##### Return\n- **retval**: `Rect2f`\n\nPython prototype (for reference only):\n```python3\nboundingRect2f() -> retval\n```","ref":"Evision.RotatedRect.html#boundingRect2f/1"},{"type":"function","title":"Evision.RotatedRect.boundingRect/1","doc":"boundingRect\n\n##### Positional Arguments\n- **self**: `Evision.RotatedRect.t()`\n\n##### Return\n- **retval**: `Rect`\n\nPython prototype (for reference only):\n```python3\nboundingRect() -> retval\n```","ref":"Evision.RotatedRect.html#boundingRect/1"},{"type":"function","title":"Evision.RotatedRect.get_angle/1","doc":"","ref":"Evision.RotatedRect.html#get_angle/1"},{"type":"function","title":"Evision.RotatedRect.get_center/1","doc":"","ref":"Evision.RotatedRect.html#get_center/1"},{"type":"function","title":"Evision.RotatedRect.get_size/1","doc":"","ref":"Evision.RotatedRect.html#get_size/1"},{"type":"function","title":"Evision.RotatedRect.points/1","doc":"points\n\n##### Positional Arguments\n- **self**: `Evision.RotatedRect.t()`\n\n##### Return\n- **pts**: `[Point2f]`.\n\n  The points array for storing rectangle vertices. The order is _bottomLeft_, _topLeft_, topRight, bottomRight.\n\nreturns 4 vertices of the rotated rectangle\n**Note**: _Bottom_, _Top_, _Left_ and _Right_ sides refer to the original rectangle (angle is 0),\nso after 180 degree rotation _bottomLeft_ point will be located at the top right corner of the\nrectangle.\n\nPython prototype (for reference only):\n```python3\npoints() -> pts\n```","ref":"Evision.RotatedRect.html#points/1"},{"type":"function","title":"Evision.RotatedRect.rotatedRect/0","doc":"RotatedRect\n##### Return\n- **self**: `{centre={x, y}, size={s1, s2}, angle}`\n\nPython prototype (for reference only):\n```python3\nRotatedRect() ->  \n```","ref":"Evision.RotatedRect.html#rotatedRect/0"},{"type":"function","title":"Evision.RotatedRect.rotatedRect/1","doc":"","ref":"Evision.RotatedRect.html#rotatedRect/1"},{"type":"function","title":"Evision.RotatedRect.rotatedRect/3","doc":"#### Variant 1:\nRotatedRect\n\n##### Positional Arguments\n- **point1**: `Point2f`\n- **point2**: `Point2f`\n- **point3**: `Point2f`\n\n##### Return\n- **self**: `{centre={x, y}, size={s1, s2}, angle}`\n\nAny 3 end points of the RotatedRect. They must be given in order (either clockwise or\nanticlockwise).\n\nPython prototype (for reference only):\n```python3\nRotatedRect(point1, point2, point3) ->  \n```\n#### Variant 2:\nRotatedRect\n\n##### Positional Arguments\n- **center**: `Point2f`.\n\n  The rectangle mass center.\n\n- **size**: `Size2f`.\n\n  Width and height of the rectangle.\n\n- **angle**: `float`.\n\n  The rotation angle in a clockwise direction. When the angle is 0, 90, 180, 270 etc.,\n  the rectangle becomes an up-right rectangle.\n\n##### Return\n- **self**: `{centre={x, y}, size={s1, s2}, angle}`\n\nfull constructor\n\nPython prototype (for reference only):\n```python3\nRotatedRect(center, size, angle) ->  \n```","ref":"Evision.RotatedRect.html#rotatedRect/3"},{"type":"function","title":"Evision.RotatedRect.set_angle/2","doc":"","ref":"Evision.RotatedRect.html#set_angle/2"},{"type":"function","title":"Evision.RotatedRect.set_center/2","doc":"","ref":"Evision.RotatedRect.html#set_center/2"},{"type":"function","title":"Evision.RotatedRect.set_size/2","doc":"","ref":"Evision.RotatedRect.html#set_size/2"},{"type":"type","title":"Evision.RotatedRect.t/0","doc":"Type that represents an `RotatedRect` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.RotatedRect.html#t:t/0"},{"type":"module","title":"Evision.SIFT","doc":"","ref":"Evision.SIFT.html"},{"type":"function","title":"Evision.SIFT.compute/1","doc":"","ref":"Evision.SIFT.html#compute/1"},{"type":"function","title":"Evision.SIFT.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.SIFT.html#compute/3"},{"type":"function","title":"Evision.SIFT.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.SIFT.html#compute/4"},{"type":"function","title":"Evision.SIFT.create/0","doc":"create\n##### Keyword Arguments\n- **nfeatures**: `integer()`.\n\n  The number of best features to retain. The features are ranked by their scores\n  (measured in SIFT algorithm as the local contrast)\n\n- **nOctaveLayers**: `integer()`.\n\n  The number of layers in each octave. 3 is the value used in D. Lowe paper. The\n  number of octaves is computed automatically from the image resolution.\n\n- **contrastThreshold**: `double`.\n\n  The contrast threshold used to filter out weak features in semi-uniform\n  (low-contrast) regions. The larger the threshold, the less features are produced by the detector.\n\n- **edgeThreshold**: `double`.\n\n  The threshold used to filter out edge-like features. Note that the its meaning\n  is different from the contrastThreshold, i.e. the larger the edgeThreshold, the less features are\n  filtered out (more features are retained).\n\n- **sigma**: `double`.\n\n  The sigma of the Gaussian applied to the input image at the octave \\#0. If your image\n  is captured with a weak camera with soft lenses, you might want to reduce the number.\n\n- **enable_precise_upscale**: `bool`.\n\n  Whether to enable precise upscaling in the scale pyramid, which maps\n  index \\f$\\texttt{x}\\f$ to \\f$\\texttt{2x}\\f$. This prevents localization bias. The option\n  is disabled by default.\n\n##### Return\n- **retval**: `Evision.SIFT.t()`\n\n**Note**: The contrast threshold will be divided by nOctaveLayers when the filtering is applied. When\nnOctaveLayers is set to default and if you want to use the value used in D. Lowe paper, 0.03, set\nthis argument to 0.09.\n\nPython prototype (for reference only):\n```python3\ncreate([, nfeatures[, nOctaveLayers[, contrastThreshold[, edgeThreshold[, sigma[, enable_precise_upscale]]]]]]) -> retval\n```","ref":"Evision.SIFT.html#create/0"},{"type":"function","title":"Evision.SIFT.create/1","doc":"create\n##### Keyword Arguments\n- **nfeatures**: `integer()`.\n\n  The number of best features to retain. The features are ranked by their scores\n  (measured in SIFT algorithm as the local contrast)\n\n- **nOctaveLayers**: `integer()`.\n\n  The number of layers in each octave. 3 is the value used in D. Lowe paper. The\n  number of octaves is computed automatically from the image resolution.\n\n- **contrastThreshold**: `double`.\n\n  The contrast threshold used to filter out weak features in semi-uniform\n  (low-contrast) regions. The larger the threshold, the less features are produced by the detector.\n\n- **edgeThreshold**: `double`.\n\n  The threshold used to filter out edge-like features. Note that the its meaning\n  is different from the contrastThreshold, i.e. the larger the edgeThreshold, the less features are\n  filtered out (more features are retained).\n\n- **sigma**: `double`.\n\n  The sigma of the Gaussian applied to the input image at the octave \\#0. If your image\n  is captured with a weak camera with soft lenses, you might want to reduce the number.\n\n- **enable_precise_upscale**: `bool`.\n\n  Whether to enable precise upscaling in the scale pyramid, which maps\n  index \\f$\\texttt{x}\\f$ to \\f$\\texttt{2x}\\f$. This prevents localization bias. The option\n  is disabled by default.\n\n##### Return\n- **retval**: `Evision.SIFT.t()`\n\n**Note**: The contrast threshold will be divided by nOctaveLayers when the filtering is applied. When\nnOctaveLayers is set to default and if you want to use the value used in D. Lowe paper, 0.03, set\nthis argument to 0.09.\n\nPython prototype (for reference only):\n```python3\ncreate([, nfeatures[, nOctaveLayers[, contrastThreshold[, edgeThreshold[, sigma[, enable_precise_upscale]]]]]]) -> retval\n```","ref":"Evision.SIFT.html#create/1"},{"type":"function","title":"Evision.SIFT.create/6","doc":"Create SIFT with specified descriptorType.\n\n##### Positional Arguments\n- **nfeatures**: `integer()`.\n\n  The number of best features to retain. The features are ranked by their scores\n  (measured in SIFT algorithm as the local contrast)\n\n- **nOctaveLayers**: `integer()`.\n\n  The number of layers in each octave. 3 is the value used in D. Lowe paper. The\n  number of octaves is computed automatically from the image resolution.\n\n- **contrastThreshold**: `double`.\n\n  The contrast threshold used to filter out weak features in semi-uniform\n  (low-contrast) regions. The larger the threshold, the less features are produced by the detector.\n\n- **edgeThreshold**: `double`.\n\n  The threshold used to filter out edge-like features. Note that the its meaning\n  is different from the contrastThreshold, i.e. the larger the edgeThreshold, the less features are\n  filtered out (more features are retained).\n\n- **sigma**: `double`.\n\n  The sigma of the Gaussian applied to the input image at the octave \\#0. If your image\n  is captured with a weak camera with soft lenses, you might want to reduce the number.\n\n- **descriptorType**: `integer()`.\n\n  The type of descriptors. Only CV_32F and CV_8U are supported.\n\n##### Keyword Arguments\n- **enable_precise_upscale**: `bool`.\n\n  Whether to enable precise upscaling in the scale pyramid, which maps\n  index \\f$\\texttt{x}\\f$ to \\f$\\texttt{2x}\\f$. This prevents localization bias. The option\n  is disabled by default.\n\n##### Return\n- **retval**: `Evision.SIFT.t()`\n\n**Note**: The contrast threshold will be divided by nOctaveLayers when the filtering is applied. When\nnOctaveLayers is set to default and if you want to use the value used in D. Lowe paper, 0.03, set\nthis argument to 0.09.\n\nPython prototype (for reference only):\n```python3\ncreate(nfeatures, nOctaveLayers, contrastThreshold, edgeThreshold, sigma, descriptorType[, enable_precise_upscale]) -> retval\n```","ref":"Evision.SIFT.html#create/6"},{"type":"function","title":"Evision.SIFT.create/7","doc":"Create SIFT with specified descriptorType.\n\n##### Positional Arguments\n- **nfeatures**: `integer()`.\n\n  The number of best features to retain. The features are ranked by their scores\n  (measured in SIFT algorithm as the local contrast)\n\n- **nOctaveLayers**: `integer()`.\n\n  The number of layers in each octave. 3 is the value used in D. Lowe paper. The\n  number of octaves is computed automatically from the image resolution.\n\n- **contrastThreshold**: `double`.\n\n  The contrast threshold used to filter out weak features in semi-uniform\n  (low-contrast) regions. The larger the threshold, the less features are produced by the detector.\n\n- **edgeThreshold**: `double`.\n\n  The threshold used to filter out edge-like features. Note that the its meaning\n  is different from the contrastThreshold, i.e. the larger the edgeThreshold, the less features are\n  filtered out (more features are retained).\n\n- **sigma**: `double`.\n\n  The sigma of the Gaussian applied to the input image at the octave \\#0. If your image\n  is captured with a weak camera with soft lenses, you might want to reduce the number.\n\n- **descriptorType**: `integer()`.\n\n  The type of descriptors. Only CV_32F and CV_8U are supported.\n\n##### Keyword Arguments\n- **enable_precise_upscale**: `bool`.\n\n  Whether to enable precise upscaling in the scale pyramid, which maps\n  index \\f$\\texttt{x}\\f$ to \\f$\\texttt{2x}\\f$. This prevents localization bias. The option\n  is disabled by default.\n\n##### Return\n- **retval**: `Evision.SIFT.t()`\n\n**Note**: The contrast threshold will be divided by nOctaveLayers when the filtering is applied. When\nnOctaveLayers is set to default and if you want to use the value used in D. Lowe paper, 0.03, set\nthis argument to 0.09.\n\nPython prototype (for reference only):\n```python3\ncreate(nfeatures, nOctaveLayers, contrastThreshold, edgeThreshold, sigma, descriptorType[, enable_precise_upscale]) -> retval\n```","ref":"Evision.SIFT.html#create/7"},{"type":"function","title":"Evision.SIFT.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.SIFT.html#defaultNorm/1"},{"type":"function","title":"Evision.SIFT.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.SIFT.html#descriptorSize/1"},{"type":"function","title":"Evision.SIFT.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.SIFT.html#descriptorType/1"},{"type":"function","title":"Evision.SIFT.detect/1","doc":"","ref":"Evision.SIFT.html#detect/1"},{"type":"function","title":"Evision.SIFT.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.SIFT.html#detect/2"},{"type":"function","title":"Evision.SIFT.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.SIFT.html#detect/3"},{"type":"function","title":"Evision.SIFT.detectAndCompute/1","doc":"","ref":"Evision.SIFT.html#detectAndCompute/1"},{"type":"function","title":"Evision.SIFT.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.SIFT.html#detectAndCompute/3"},{"type":"function","title":"Evision.SIFT.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.SIFT.html#detectAndCompute/4"},{"type":"function","title":"Evision.SIFT.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.SIFT.html#empty/1"},{"type":"function","title":"Evision.SIFT.getContrastThreshold/1","doc":"getContrastThreshold\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetContrastThreshold() -> retval\n```","ref":"Evision.SIFT.html#getContrastThreshold/1"},{"type":"function","title":"Evision.SIFT.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.SIFT.html#getDefaultName/1"},{"type":"function","title":"Evision.SIFT.getEdgeThreshold/1","doc":"getEdgeThreshold\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetEdgeThreshold() -> retval\n```","ref":"Evision.SIFT.html#getEdgeThreshold/1"},{"type":"function","title":"Evision.SIFT.getNFeatures/1","doc":"getNFeatures\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNFeatures() -> retval\n```","ref":"Evision.SIFT.html#getNFeatures/1"},{"type":"function","title":"Evision.SIFT.getNOctaveLayers/1","doc":"getNOctaveLayers\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNOctaveLayers() -> retval\n```","ref":"Evision.SIFT.html#getNOctaveLayers/1"},{"type":"function","title":"Evision.SIFT.getSigma/1","doc":"getSigma\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetSigma() -> retval\n```","ref":"Evision.SIFT.html#getSigma/1"},{"type":"function","title":"Evision.SIFT.read/1","doc":"","ref":"Evision.SIFT.html#read/1"},{"type":"function","title":"Evision.SIFT.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.SIFT.html#read/2"},{"type":"function","title":"Evision.SIFT.setContrastThreshold/1","doc":"","ref":"Evision.SIFT.html#setContrastThreshold/1"},{"type":"function","title":"Evision.SIFT.setContrastThreshold/2","doc":"setContrastThreshold\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n- **contrastThreshold**: `double`\n\nPython prototype (for reference only):\n```python3\nsetContrastThreshold(contrastThreshold) -> None\n```","ref":"Evision.SIFT.html#setContrastThreshold/2"},{"type":"function","title":"Evision.SIFT.setEdgeThreshold/1","doc":"","ref":"Evision.SIFT.html#setEdgeThreshold/1"},{"type":"function","title":"Evision.SIFT.setEdgeThreshold/2","doc":"setEdgeThreshold\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n- **edgeThreshold**: `double`\n\nPython prototype (for reference only):\n```python3\nsetEdgeThreshold(edgeThreshold) -> None\n```","ref":"Evision.SIFT.html#setEdgeThreshold/2"},{"type":"function","title":"Evision.SIFT.setNFeatures/1","doc":"","ref":"Evision.SIFT.html#setNFeatures/1"},{"type":"function","title":"Evision.SIFT.setNFeatures/2","doc":"setNFeatures\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n- **maxFeatures**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNFeatures(maxFeatures) -> None\n```","ref":"Evision.SIFT.html#setNFeatures/2"},{"type":"function","title":"Evision.SIFT.setNOctaveLayers/1","doc":"","ref":"Evision.SIFT.html#setNOctaveLayers/1"},{"type":"function","title":"Evision.SIFT.setNOctaveLayers/2","doc":"setNOctaveLayers\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n- **nOctaveLayers**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNOctaveLayers(nOctaveLayers) -> None\n```","ref":"Evision.SIFT.html#setNOctaveLayers/2"},{"type":"function","title":"Evision.SIFT.setSigma/1","doc":"","ref":"Evision.SIFT.html#setSigma/1"},{"type":"function","title":"Evision.SIFT.setSigma/2","doc":"setSigma\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n- **sigma**: `double`\n\nPython prototype (for reference only):\n```python3\nsetSigma(sigma) -> None\n```","ref":"Evision.SIFT.html#setSigma/2"},{"type":"function","title":"Evision.SIFT.write/1","doc":"","ref":"Evision.SIFT.html#write/1"},{"type":"function","title":"Evision.SIFT.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.SIFT.html#write/2"},{"type":"function","title":"Evision.SIFT.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.SIFT.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.SIFT.html#write/3"},{"type":"type","title":"Evision.SIFT.t/0","doc":"Type that represents an `SIFT` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.SIFT.html#t:t/0"},{"type":"module","title":"Evision.SVD.Flags","doc":"","ref":"Evision.SVD.Flags.html"},{"type":"function","title":"Evision.SVD.Flags.cv_FULL_UV/0","doc":"","ref":"Evision.SVD.Flags.html#cv_FULL_UV/0"},{"type":"function","title":"Evision.SVD.Flags.cv_MODIFY_A/0","doc":"","ref":"Evision.SVD.Flags.html#cv_MODIFY_A/0"},{"type":"function","title":"Evision.SVD.Flags.cv_NO_UV/0","doc":"","ref":"Evision.SVD.Flags.html#cv_NO_UV/0"},{"type":"type","title":"Evision.SVD.Flags.enum/0","doc":"","ref":"Evision.SVD.Flags.html#t:enum/0"},{"type":"module","title":"Evision.Saliency","doc":"","ref":"Evision.Saliency.html"},{"type":"type","title":"Evision.Saliency.t/0","doc":"Type that represents an `Saliency` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Saliency.html#t:t/0"},{"type":"module","title":"Evision.Saliency.MotionSaliency","doc":"","ref":"Evision.Saliency.MotionSaliency.html"},{"type":"type","title":"Evision.Saliency.MotionSaliency.t/0","doc":"Type that represents an `Saliency.MotionSaliency` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Saliency.MotionSaliency.html#t:t/0"},{"type":"module","title":"Evision.Saliency.MotionSaliencyBinWangApr2014","doc":"","ref":"Evision.Saliency.MotionSaliencyBinWangApr2014.html"},{"type":"function","title":"Evision.Saliency.MotionSaliencyBinWangApr2014.computeSaliency/1","doc":"","ref":"Evision.Saliency.MotionSaliencyBinWangApr2014.html#computeSaliency/1"},{"type":"function","title":"Evision.Saliency.MotionSaliencyBinWangApr2014.computeSaliency/2","doc":"computeSaliency\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.MotionSaliencyBinWangApr2014.t()`\n- **image**: `Evision.Mat`\n\n##### Return\n- **retval**: `bool`\n- **saliencyMap**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ncomputeSaliency(image[, saliencyMap]) -> retval, saliencyMap\n```","ref":"Evision.Saliency.MotionSaliencyBinWangApr2014.html#computeSaliency/2"},{"type":"function","title":"Evision.Saliency.MotionSaliencyBinWangApr2014.computeSaliency/3","doc":"computeSaliency\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.MotionSaliencyBinWangApr2014.t()`\n- **image**: `Evision.Mat`\n\n##### Return\n- **retval**: `bool`\n- **saliencyMap**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ncomputeSaliency(image[, saliencyMap]) -> retval, saliencyMap\n```","ref":"Evision.Saliency.MotionSaliencyBinWangApr2014.html#computeSaliency/3"},{"type":"function","title":"Evision.Saliency.MotionSaliencyBinWangApr2014.create/0","doc":"create\n##### Return\n- **retval**: `MotionSaliencyBinWangApr2014`\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.Saliency.MotionSaliencyBinWangApr2014.html#create/0"},{"type":"function","title":"Evision.Saliency.MotionSaliencyBinWangApr2014.create/1","doc":"","ref":"Evision.Saliency.MotionSaliencyBinWangApr2014.html#create/1"},{"type":"function","title":"Evision.Saliency.MotionSaliencyBinWangApr2014.getImageHeight/1","doc":"getImageHeight\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.MotionSaliencyBinWangApr2014.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetImageHeight() -> retval\n```","ref":"Evision.Saliency.MotionSaliencyBinWangApr2014.html#getImageHeight/1"},{"type":"function","title":"Evision.Saliency.MotionSaliencyBinWangApr2014.getImageWidth/1","doc":"getImageWidth\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.MotionSaliencyBinWangApr2014.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetImageWidth() -> retval\n```","ref":"Evision.Saliency.MotionSaliencyBinWangApr2014.html#getImageWidth/1"},{"type":"function","title":"Evision.Saliency.MotionSaliencyBinWangApr2014.init/1","doc":"This function allows the correct initialization of all data structures that will be used by the\nalgorithm.\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.MotionSaliencyBinWangApr2014.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ninit() -> retval\n```","ref":"Evision.Saliency.MotionSaliencyBinWangApr2014.html#init/1"},{"type":"function","title":"Evision.Saliency.MotionSaliencyBinWangApr2014.setImageHeight/1","doc":"","ref":"Evision.Saliency.MotionSaliencyBinWangApr2014.html#setImageHeight/1"},{"type":"function","title":"Evision.Saliency.MotionSaliencyBinWangApr2014.setImageHeight/2","doc":"setImageHeight\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.MotionSaliencyBinWangApr2014.t()`\n- **val**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetImageHeight(val) -> None\n```","ref":"Evision.Saliency.MotionSaliencyBinWangApr2014.html#setImageHeight/2"},{"type":"function","title":"Evision.Saliency.MotionSaliencyBinWangApr2014.setImagesize/1","doc":"","ref":"Evision.Saliency.MotionSaliencyBinWangApr2014.html#setImagesize/1"},{"type":"function","title":"Evision.Saliency.MotionSaliencyBinWangApr2014.setImagesize/3","doc":"This is a utility function that allows to set the correct size (taken from the input image) in the\ncorresponding variables that will be used to size the data structures of the algorithm.\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.MotionSaliencyBinWangApr2014.t()`\n- **w**: `integer()`.\n\n  width of input image\n\n- **h**: `integer()`.\n\n  height of input image\n\nPython prototype (for reference only):\n```python3\nsetImagesize(W, H) -> None\n```","ref":"Evision.Saliency.MotionSaliencyBinWangApr2014.html#setImagesize/3"},{"type":"function","title":"Evision.Saliency.MotionSaliencyBinWangApr2014.setImageWidth/1","doc":"","ref":"Evision.Saliency.MotionSaliencyBinWangApr2014.html#setImageWidth/1"},{"type":"function","title":"Evision.Saliency.MotionSaliencyBinWangApr2014.setImageWidth/2","doc":"setImageWidth\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.MotionSaliencyBinWangApr2014.t()`\n- **val**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetImageWidth(val) -> None\n```","ref":"Evision.Saliency.MotionSaliencyBinWangApr2014.html#setImageWidth/2"},{"type":"type","title":"Evision.Saliency.MotionSaliencyBinWangApr2014.t/0","doc":"Type that represents an `Saliency.MotionSaliencyBinWangApr2014` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Saliency.MotionSaliencyBinWangApr2014.html#t:t/0"},{"type":"module","title":"Evision.Saliency.Objectness","doc":"","ref":"Evision.Saliency.Objectness.html"},{"type":"type","title":"Evision.Saliency.Objectness.t/0","doc":"Type that represents an `Saliency.Objectness` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Saliency.Objectness.html#t:t/0"},{"type":"module","title":"Evision.Saliency.ObjectnessBING","doc":"","ref":"Evision.Saliency.ObjectnessBING.html"},{"type":"function","title":"Evision.Saliency.ObjectnessBING.computeSaliency/1","doc":"","ref":"Evision.Saliency.ObjectnessBING.html#computeSaliency/1"},{"type":"function","title":"Evision.Saliency.ObjectnessBING.computeSaliency/2","doc":"computeSaliency\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.ObjectnessBING.t()`\n- **image**: `Evision.Mat`\n\n##### Return\n- **retval**: `bool`\n- **saliencyMap**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ncomputeSaliency(image[, saliencyMap]) -> retval, saliencyMap\n```","ref":"Evision.Saliency.ObjectnessBING.html#computeSaliency/2"},{"type":"function","title":"Evision.Saliency.ObjectnessBING.computeSaliency/3","doc":"computeSaliency\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.ObjectnessBING.t()`\n- **image**: `Evision.Mat`\n\n##### Return\n- **retval**: `bool`\n- **saliencyMap**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ncomputeSaliency(image[, saliencyMap]) -> retval, saliencyMap\n```","ref":"Evision.Saliency.ObjectnessBING.html#computeSaliency/3"},{"type":"function","title":"Evision.Saliency.ObjectnessBING.create/0","doc":"create\n##### Return\n- **retval**: `ObjectnessBING`\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.Saliency.ObjectnessBING.html#create/0"},{"type":"function","title":"Evision.Saliency.ObjectnessBING.create/1","doc":"","ref":"Evision.Saliency.ObjectnessBING.html#create/1"},{"type":"function","title":"Evision.Saliency.ObjectnessBING.getBase/1","doc":"getBase\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.ObjectnessBING.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetBase() -> retval\n```","ref":"Evision.Saliency.ObjectnessBING.html#getBase/1"},{"type":"function","title":"Evision.Saliency.ObjectnessBING.getNSS/1","doc":"getNSS\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.ObjectnessBING.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNSS() -> retval\n```","ref":"Evision.Saliency.ObjectnessBING.html#getNSS/1"},{"type":"function","title":"Evision.Saliency.ObjectnessBING.getobjectnessValues/1","doc":"Return the list of the rectangles' objectness value,\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.ObjectnessBING.t()`\n\n##### Return\n- **retval**: `[float]`\n\nin the same order as the *vector\\  objectnessBoundingBox* returned by the algorithm (in\ncomputeSaliencyImpl function). The bigger value these scores are, it is more likely to be an\nobject window.\n\nPython prototype (for reference only):\n```python3\ngetobjectnessValues() -> retval\n```","ref":"Evision.Saliency.ObjectnessBING.html#getobjectnessValues/1"},{"type":"function","title":"Evision.Saliency.ObjectnessBING.getW/1","doc":"getW\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.ObjectnessBING.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetW() -> retval\n```","ref":"Evision.Saliency.ObjectnessBING.html#getW/1"},{"type":"function","title":"Evision.Saliency.ObjectnessBING.read/1","doc":"read\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.ObjectnessBING.t()`\n\nPython prototype (for reference only):\n```python3\nread() -> None\n```","ref":"Evision.Saliency.ObjectnessBING.html#read/1"},{"type":"function","title":"Evision.Saliency.ObjectnessBING.setBase/1","doc":"","ref":"Evision.Saliency.ObjectnessBING.html#setBase/1"},{"type":"function","title":"Evision.Saliency.ObjectnessBING.setBase/2","doc":"setBase\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.ObjectnessBING.t()`\n- **val**: `double`\n\nPython prototype (for reference only):\n```python3\nsetBase(val) -> None\n```","ref":"Evision.Saliency.ObjectnessBING.html#setBase/2"},{"type":"function","title":"Evision.Saliency.ObjectnessBING.setBBResDir/1","doc":"","ref":"Evision.Saliency.ObjectnessBING.html#setBBResDir/1"},{"type":"function","title":"Evision.Saliency.ObjectnessBING.setBBResDir/2","doc":"This is a utility function that allows to set an arbitrary path in which the algorithm will save the\noptional results\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.ObjectnessBING.t()`\n- **resultsDir**: `String`.\n\n  results' folder path\n\n(ie writing on file the total number and the list of rectangles returned by objectess, one for\neach row).\n\nPython prototype (for reference only):\n```python3\nsetBBResDir(resultsDir) -> None\n```","ref":"Evision.Saliency.ObjectnessBING.html#setBBResDir/2"},{"type":"function","title":"Evision.Saliency.ObjectnessBING.setNSS/1","doc":"","ref":"Evision.Saliency.ObjectnessBING.html#setNSS/1"},{"type":"function","title":"Evision.Saliency.ObjectnessBING.setNSS/2","doc":"setNSS\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.ObjectnessBING.t()`\n- **val**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNSS(val) -> None\n```","ref":"Evision.Saliency.ObjectnessBING.html#setNSS/2"},{"type":"function","title":"Evision.Saliency.ObjectnessBING.setTrainingPath/1","doc":"","ref":"Evision.Saliency.ObjectnessBING.html#setTrainingPath/1"},{"type":"function","title":"Evision.Saliency.ObjectnessBING.setTrainingPath/2","doc":"This is a utility function that allows to set the correct path from which the algorithm will load\nthe trained model.\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.ObjectnessBING.t()`\n- **trainingPath**: `String`.\n\n  trained model path\n\nPython prototype (for reference only):\n```python3\nsetTrainingPath(trainingPath) -> None\n```","ref":"Evision.Saliency.ObjectnessBING.html#setTrainingPath/2"},{"type":"function","title":"Evision.Saliency.ObjectnessBING.setW/1","doc":"","ref":"Evision.Saliency.ObjectnessBING.html#setW/1"},{"type":"function","title":"Evision.Saliency.ObjectnessBING.setW/2","doc":"setW\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.ObjectnessBING.t()`\n- **val**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetW(val) -> None\n```","ref":"Evision.Saliency.ObjectnessBING.html#setW/2"},{"type":"function","title":"Evision.Saliency.ObjectnessBING.write/1","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.ObjectnessBING.t()`\n\nPython prototype (for reference only):\n```python3\nwrite() -> None\n```","ref":"Evision.Saliency.ObjectnessBING.html#write/1"},{"type":"type","title":"Evision.Saliency.ObjectnessBING.t/0","doc":"Type that represents an `Saliency.ObjectnessBING` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Saliency.ObjectnessBING.html#t:t/0"},{"type":"module","title":"Evision.Saliency.Saliency","doc":"","ref":"Evision.Saliency.Saliency.html"},{"type":"function","title":"Evision.Saliency.Saliency.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.Saliency.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Saliency.Saliency.html#clear/1"},{"type":"function","title":"Evision.Saliency.Saliency.computeSaliency/1","doc":"","ref":"Evision.Saliency.Saliency.html#computeSaliency/1"},{"type":"function","title":"Evision.Saliency.Saliency.computeSaliency/2","doc":"computeSaliency\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.Saliency.t()`\n- **image**: `Evision.Mat`\n\n##### Return\n- **retval**: `bool`\n- **saliencyMap**: `Evision.Mat.t()`.\n\n \\brief Compute the saliency\n \\param image        The image.\n \\param saliencyMap      The computed saliency map.\n \\return true if the saliency map is computed, false otherwise\n\nPython prototype (for reference only):\n```python3\ncomputeSaliency(image[, saliencyMap]) -> retval, saliencyMap\n```","ref":"Evision.Saliency.Saliency.html#computeSaliency/2"},{"type":"function","title":"Evision.Saliency.Saliency.computeSaliency/3","doc":"computeSaliency\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.Saliency.t()`\n- **image**: `Evision.Mat`\n\n##### Return\n- **retval**: `bool`\n- **saliencyMap**: `Evision.Mat.t()`.\n\n \\brief Compute the saliency\n \\param image        The image.\n \\param saliencyMap      The computed saliency map.\n \\return true if the saliency map is computed, false otherwise\n\nPython prototype (for reference only):\n```python3\ncomputeSaliency(image[, saliencyMap]) -> retval, saliencyMap\n```","ref":"Evision.Saliency.Saliency.html#computeSaliency/3"},{"type":"function","title":"Evision.Saliency.Saliency.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.Saliency.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Saliency.Saliency.html#empty/1"},{"type":"function","title":"Evision.Saliency.Saliency.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.Saliency.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Saliency.Saliency.html#getDefaultName/1"},{"type":"function","title":"Evision.Saliency.Saliency.read/1","doc":"","ref":"Evision.Saliency.Saliency.html#read/1"},{"type":"function","title":"Evision.Saliency.Saliency.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.Saliency.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Saliency.Saliency.html#read/2"},{"type":"function","title":"Evision.Saliency.Saliency.save/1","doc":"","ref":"Evision.Saliency.Saliency.html#save/1"},{"type":"function","title":"Evision.Saliency.Saliency.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.Saliency.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Saliency.Saliency.html#save/2"},{"type":"function","title":"Evision.Saliency.Saliency.write/1","doc":"","ref":"Evision.Saliency.Saliency.html#write/1"},{"type":"function","title":"Evision.Saliency.Saliency.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.Saliency.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Saliency.Saliency.html#write/2"},{"type":"function","title":"Evision.Saliency.Saliency.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.Saliency.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Saliency.Saliency.html#write/3"},{"type":"type","title":"Evision.Saliency.Saliency.t/0","doc":"Type that represents an `Saliency.Saliency` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Saliency.Saliency.html#t:t/0"},{"type":"module","title":"Evision.Saliency.StaticSaliency","doc":"","ref":"Evision.Saliency.StaticSaliency.html"},{"type":"function","title":"Evision.Saliency.StaticSaliency.computeBinaryMap/1","doc":"","ref":"Evision.Saliency.StaticSaliency.html#computeBinaryMap/1"},{"type":"function","title":"Evision.Saliency.StaticSaliency.computeBinaryMap/2","doc":"This function perform a binary map of given saliency map. This is obtained in this\nway:\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.StaticSaliency.t()`\n- **saliencyMap**: `Evision.Mat`.\n\n  the saliency map obtained through one of the specialized algorithms\n\n##### Return\n- **retval**: `bool`\n- **binaryMap**: `Evision.Mat.t()`.\n\n  the binary map\n\nIn a first step, to improve the definition of interest areas and facilitate identification of\ntargets, a segmentation by clustering is performed, using *K-means algorithm*. Then, to gain a\nbinary representation of clustered saliency map, since values of the map can vary according to\nthe characteristics of frame under analysis, it is not convenient to use a fixed threshold. So,\nOtsu's algorithm* is used, which assumes that the image to be thresholded contains two classes\nof pixels or bi-modal histograms (e.g. foreground and back-ground pixels); later on, the\nalgorithm calculates the optimal threshold separating those two classes, so that their\nintra-class variance is minimal.\n\nPython prototype (for reference only):\n```python3\ncomputeBinaryMap(_saliencyMap[, _binaryMap]) -> retval, _binaryMap\n```","ref":"Evision.Saliency.StaticSaliency.html#computeBinaryMap/2"},{"type":"function","title":"Evision.Saliency.StaticSaliency.computeBinaryMap/3","doc":"This function perform a binary map of given saliency map. This is obtained in this\nway:\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.StaticSaliency.t()`\n- **saliencyMap**: `Evision.Mat`.\n\n  the saliency map obtained through one of the specialized algorithms\n\n##### Return\n- **retval**: `bool`\n- **binaryMap**: `Evision.Mat.t()`.\n\n  the binary map\n\nIn a first step, to improve the definition of interest areas and facilitate identification of\ntargets, a segmentation by clustering is performed, using *K-means algorithm*. Then, to gain a\nbinary representation of clustered saliency map, since values of the map can vary according to\nthe characteristics of frame under analysis, it is not convenient to use a fixed threshold. So,\nOtsu's algorithm* is used, which assumes that the image to be thresholded contains two classes\nof pixels or bi-modal histograms (e.g. foreground and back-ground pixels); later on, the\nalgorithm calculates the optimal threshold separating those two classes, so that their\nintra-class variance is minimal.\n\nPython prototype (for reference only):\n```python3\ncomputeBinaryMap(_saliencyMap[, _binaryMap]) -> retval, _binaryMap\n```","ref":"Evision.Saliency.StaticSaliency.html#computeBinaryMap/3"},{"type":"type","title":"Evision.Saliency.StaticSaliency.t/0","doc":"Type that represents an `Saliency.StaticSaliency` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Saliency.StaticSaliency.html#t:t/0"},{"type":"module","title":"Evision.Saliency.StaticSaliencyFineGrained","doc":"","ref":"Evision.Saliency.StaticSaliencyFineGrained.html"},{"type":"function","title":"Evision.Saliency.StaticSaliencyFineGrained.computeSaliency/1","doc":"","ref":"Evision.Saliency.StaticSaliencyFineGrained.html#computeSaliency/1"},{"type":"function","title":"Evision.Saliency.StaticSaliencyFineGrained.computeSaliency/2","doc":"computeSaliency\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.StaticSaliencyFineGrained.t()`\n- **image**: `Evision.Mat`\n\n##### Return\n- **retval**: `bool`\n- **saliencyMap**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ncomputeSaliency(image[, saliencyMap]) -> retval, saliencyMap\n```","ref":"Evision.Saliency.StaticSaliencyFineGrained.html#computeSaliency/2"},{"type":"function","title":"Evision.Saliency.StaticSaliencyFineGrained.computeSaliency/3","doc":"computeSaliency\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.StaticSaliencyFineGrained.t()`\n- **image**: `Evision.Mat`\n\n##### Return\n- **retval**: `bool`\n- **saliencyMap**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ncomputeSaliency(image[, saliencyMap]) -> retval, saliencyMap\n```","ref":"Evision.Saliency.StaticSaliencyFineGrained.html#computeSaliency/3"},{"type":"function","title":"Evision.Saliency.StaticSaliencyFineGrained.create/0","doc":"create\n##### Return\n- **retval**: `StaticSaliencyFineGrained`\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.Saliency.StaticSaliencyFineGrained.html#create/0"},{"type":"function","title":"Evision.Saliency.StaticSaliencyFineGrained.create/1","doc":"","ref":"Evision.Saliency.StaticSaliencyFineGrained.html#create/1"},{"type":"type","title":"Evision.Saliency.StaticSaliencyFineGrained.t/0","doc":"Type that represents an `Saliency.StaticSaliencyFineGrained` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Saliency.StaticSaliencyFineGrained.html#t:t/0"},{"type":"module","title":"Evision.Saliency.StaticSaliencySpectralResidual","doc":"","ref":"Evision.Saliency.StaticSaliencySpectralResidual.html"},{"type":"function","title":"Evision.Saliency.StaticSaliencySpectralResidual.computeSaliency/1","doc":"","ref":"Evision.Saliency.StaticSaliencySpectralResidual.html#computeSaliency/1"},{"type":"function","title":"Evision.Saliency.StaticSaliencySpectralResidual.computeSaliency/2","doc":"computeSaliency\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.StaticSaliencySpectralResidual.t()`\n- **image**: `Evision.Mat`\n\n##### Return\n- **retval**: `bool`\n- **saliencyMap**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ncomputeSaliency(image[, saliencyMap]) -> retval, saliencyMap\n```","ref":"Evision.Saliency.StaticSaliencySpectralResidual.html#computeSaliency/2"},{"type":"function","title":"Evision.Saliency.StaticSaliencySpectralResidual.computeSaliency/3","doc":"computeSaliency\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.StaticSaliencySpectralResidual.t()`\n- **image**: `Evision.Mat`\n\n##### Return\n- **retval**: `bool`\n- **saliencyMap**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ncomputeSaliency(image[, saliencyMap]) -> retval, saliencyMap\n```","ref":"Evision.Saliency.StaticSaliencySpectralResidual.html#computeSaliency/3"},{"type":"function","title":"Evision.Saliency.StaticSaliencySpectralResidual.create/0","doc":"create\n##### Return\n- **retval**: `StaticSaliencySpectralResidual`\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.Saliency.StaticSaliencySpectralResidual.html#create/0"},{"type":"function","title":"Evision.Saliency.StaticSaliencySpectralResidual.create/1","doc":"","ref":"Evision.Saliency.StaticSaliencySpectralResidual.html#create/1"},{"type":"function","title":"Evision.Saliency.StaticSaliencySpectralResidual.getImageHeight/1","doc":"getImageHeight\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.StaticSaliencySpectralResidual.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetImageHeight() -> retval\n```","ref":"Evision.Saliency.StaticSaliencySpectralResidual.html#getImageHeight/1"},{"type":"function","title":"Evision.Saliency.StaticSaliencySpectralResidual.getImageWidth/1","doc":"getImageWidth\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.StaticSaliencySpectralResidual.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetImageWidth() -> retval\n```","ref":"Evision.Saliency.StaticSaliencySpectralResidual.html#getImageWidth/1"},{"type":"function","title":"Evision.Saliency.StaticSaliencySpectralResidual.read/1","doc":"","ref":"Evision.Saliency.StaticSaliencySpectralResidual.html#read/1"},{"type":"function","title":"Evision.Saliency.StaticSaliencySpectralResidual.read/2","doc":"read\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.StaticSaliencySpectralResidual.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Saliency.StaticSaliencySpectralResidual.html#read/2"},{"type":"function","title":"Evision.Saliency.StaticSaliencySpectralResidual.setImageHeight/1","doc":"","ref":"Evision.Saliency.StaticSaliencySpectralResidual.html#setImageHeight/1"},{"type":"function","title":"Evision.Saliency.StaticSaliencySpectralResidual.setImageHeight/2","doc":"setImageHeight\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.StaticSaliencySpectralResidual.t()`\n- **val**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetImageHeight(val) -> None\n```","ref":"Evision.Saliency.StaticSaliencySpectralResidual.html#setImageHeight/2"},{"type":"function","title":"Evision.Saliency.StaticSaliencySpectralResidual.setImageWidth/1","doc":"","ref":"Evision.Saliency.StaticSaliencySpectralResidual.html#setImageWidth/1"},{"type":"function","title":"Evision.Saliency.StaticSaliencySpectralResidual.setImageWidth/2","doc":"setImageWidth\n\n##### Positional Arguments\n- **self**: `Evision.Saliency.StaticSaliencySpectralResidual.t()`\n- **val**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetImageWidth(val) -> None\n```","ref":"Evision.Saliency.StaticSaliencySpectralResidual.html#setImageWidth/2"},{"type":"type","title":"Evision.Saliency.StaticSaliencySpectralResidual.t/0","doc":"Type that represents an `Saliency.StaticSaliencySpectralResidual` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Saliency.StaticSaliencySpectralResidual.html#t:t/0"},{"type":"module","title":"Evision.Samples","doc":"","ref":"Evision.Samples.html"},{"type":"function","title":"Evision.Samples.addSamplesDataSearchPath/1","doc":"Override search data path by adding new search location\n\n##### Positional Arguments\n- **path**: `String`.\n\n  Path to used samples data\n\nUse this only to override default behavior\nPassed paths are used in LIFO order.\n\nPython prototype (for reference only):\n```python3\naddSamplesDataSearchPath(path) -> None\n```","ref":"Evision.Samples.html#addSamplesDataSearchPath/1"},{"type":"function","title":"Evision.Samples.addSamplesDataSearchSubDirectory/1","doc":"Append samples search data sub directory\n\n##### Positional Arguments\n- **subdir**: `String`.\n\n  samples data sub directory\n\nGeneral usage is to add OpenCV modules name (` /modules/ /samples/data` -> ` /samples/data` + `modules/ /samples/data`).\nPassed subdirectories are used in LIFO order.\n\nPython prototype (for reference only):\n```python3\naddSamplesDataSearchSubDirectory(subdir) -> None\n```","ref":"Evision.Samples.html#addSamplesDataSearchSubDirectory/1"},{"type":"function","title":"Evision.Samples.findFile/1","doc":"Try to find requested data file\n\n##### Positional Arguments\n- **relative_path**: `String`.\n\n  Relative path to data file\n\n##### Keyword Arguments\n- **required**: `bool`.\n\n  Specify \"file not found\" handling.\n  If true, function prints information message and raises cv::Exception.\n  If false, function returns empty result\n\n- **silentMode**: `bool`.\n\n  Disables messages\n\n##### Return\n- **retval**: `String`\n\nSearch directories:\n1. Directories passed via `addSamplesDataSearchPath()`\n2. OPENCV_SAMPLES_DATA_PATH_HINT environment variable\n3. OPENCV_SAMPLES_DATA_PATH environment variable\nIf parameter value is not empty and nothing is found then stop searching.\n4. Detects build/install path based on:\na. current working directory (CWD)\nb. and/or binary module location (opencv_core/opencv_world, doesn't work with static linkage)\n5. Scan ` /{,data,samples/data}` directories if build directory is detected or the current directory is in source tree.\n6. Scan ` /share/OpenCV` directory if install directory is detected.\n@see cv::utils::findDataFile\n@return Returns path (absolute or relative to the current directory) or empty string if file is not found\n\nPython prototype (for reference only):\n```python3\nfindFile(relative_path[, required[, silentMode]]) -> retval\n```","ref":"Evision.Samples.html#findFile/1"},{"type":"function","title":"Evision.Samples.findFile/2","doc":"Try to find requested data file\n\n##### Positional Arguments\n- **relative_path**: `String`.\n\n  Relative path to data file\n\n##### Keyword Arguments\n- **required**: `bool`.\n\n  Specify \"file not found\" handling.\n  If true, function prints information message and raises cv::Exception.\n  If false, function returns empty result\n\n- **silentMode**: `bool`.\n\n  Disables messages\n\n##### Return\n- **retval**: `String`\n\nSearch directories:\n1. Directories passed via `addSamplesDataSearchPath()`\n2. OPENCV_SAMPLES_DATA_PATH_HINT environment variable\n3. OPENCV_SAMPLES_DATA_PATH environment variable\nIf parameter value is not empty and nothing is found then stop searching.\n4. Detects build/install path based on:\na. current working directory (CWD)\nb. and/or binary module location (opencv_core/opencv_world, doesn't work with static linkage)\n5. Scan ` /{,data,samples/data}` directories if build directory is detected or the current directory is in source tree.\n6. Scan ` /share/OpenCV` directory if install directory is detected.\n@see cv::utils::findDataFile\n@return Returns path (absolute or relative to the current directory) or empty string if file is not found\n\nPython prototype (for reference only):\n```python3\nfindFile(relative_path[, required[, silentMode]]) -> retval\n```","ref":"Evision.Samples.html#findFile/2"},{"type":"function","title":"Evision.Samples.findFileOrKeep/1","doc":"findFileOrKeep\n\n##### Positional Arguments\n- **relative_path**: `String`\n\n##### Keyword Arguments\n- **silentMode**: `bool`.\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\nfindFileOrKeep(relative_path[, silentMode]) -> retval\n```","ref":"Evision.Samples.html#findFileOrKeep/1"},{"type":"function","title":"Evision.Samples.findFileOrKeep/2","doc":"findFileOrKeep\n\n##### Positional Arguments\n- **relative_path**: `String`\n\n##### Keyword Arguments\n- **silentMode**: `bool`.\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\nfindFileOrKeep(relative_path[, silentMode]) -> retval\n```","ref":"Evision.Samples.html#findFileOrKeep/2"},{"type":"type","title":"Evision.Samples.t/0","doc":"Type that represents an `Samples` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Samples.html#t:t/0"},{"type":"module","title":"Evision.SamplingMethod","doc":"","ref":"Evision.SamplingMethod.html"},{"type":"function","title":"Evision.SamplingMethod.cv_SAMPLING_NAPSAC/0","doc":"","ref":"Evision.SamplingMethod.html#cv_SAMPLING_NAPSAC/0"},{"type":"function","title":"Evision.SamplingMethod.cv_SAMPLING_PROGRESSIVE_NAPSAC/0","doc":"","ref":"Evision.SamplingMethod.html#cv_SAMPLING_PROGRESSIVE_NAPSAC/0"},{"type":"function","title":"Evision.SamplingMethod.cv_SAMPLING_PROSAC/0","doc":"","ref":"Evision.SamplingMethod.html#cv_SAMPLING_PROSAC/0"},{"type":"function","title":"Evision.SamplingMethod.cv_SAMPLING_UNIFORM/0","doc":"","ref":"Evision.SamplingMethod.html#cv_SAMPLING_UNIFORM/0"},{"type":"type","title":"Evision.SamplingMethod.enum/0","doc":"","ref":"Evision.SamplingMethod.html#t:enum/0"},{"type":"module","title":"Evision.ScoreMethod","doc":"","ref":"Evision.ScoreMethod.html"},{"type":"function","title":"Evision.ScoreMethod.cv_SCORE_METHOD_LMEDS/0","doc":"","ref":"Evision.ScoreMethod.html#cv_SCORE_METHOD_LMEDS/0"},{"type":"function","title":"Evision.ScoreMethod.cv_SCORE_METHOD_MAGSAC/0","doc":"","ref":"Evision.ScoreMethod.html#cv_SCORE_METHOD_MAGSAC/0"},{"type":"function","title":"Evision.ScoreMethod.cv_SCORE_METHOD_MSAC/0","doc":"","ref":"Evision.ScoreMethod.html#cv_SCORE_METHOD_MSAC/0"},{"type":"function","title":"Evision.ScoreMethod.cv_SCORE_METHOD_RANSAC/0","doc":"","ref":"Evision.ScoreMethod.html#cv_SCORE_METHOD_RANSAC/0"},{"type":"type","title":"Evision.ScoreMethod.enum/0","doc":"","ref":"Evision.ScoreMethod.html#t:enum/0"},{"type":"module","title":"Evision.Segmentation","doc":"","ref":"Evision.Segmentation.html"},{"type":"type","title":"Evision.Segmentation.t/0","doc":"Type that represents an `Segmentation` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Segmentation.html#t:t/0"},{"type":"module","title":"Evision.Segmentation.IntelligentScissorsMB","doc":"","ref":"Evision.Segmentation.IntelligentScissorsMB.html"},{"type":"function","title":"Evision.Segmentation.IntelligentScissorsMB.applyImage/1","doc":"","ref":"Evision.Segmentation.IntelligentScissorsMB.html#applyImage/1"},{"type":"function","title":"Evision.Segmentation.IntelligentScissorsMB.applyImage/2","doc":"Specify input image and extract image features\n\n##### Positional Arguments\n- **self**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n- **image**: `Evision.Mat`.\n\n  input image. Type is #CV_8UC1 / #CV_8UC3\n\n##### Return\n- **retval**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n\nPython prototype (for reference only):\n```python3\napplyImage(image) -> retval\n```","ref":"Evision.Segmentation.IntelligentScissorsMB.html#applyImage/2"},{"type":"function","title":"Evision.Segmentation.IntelligentScissorsMB.applyImageFeatures/1","doc":"","ref":"Evision.Segmentation.IntelligentScissorsMB.html#applyImageFeatures/1"},{"type":"function","title":"Evision.Segmentation.IntelligentScissorsMB.applyImageFeatures/4","doc":"Specify custom features of input image\n\n##### Positional Arguments\n- **self**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n- **non_edge**: `Evision.Mat`.\n\n  Specify cost of non-edge pixels. Type is CV_8UC1. Expected values are `{0, 1}`.\n\n- **gradient_direction**: `Evision.Mat`.\n\n  Specify gradient direction feature. Type is CV_32FC2. Values are expected to be normalized: `x^2 + y^2 == 1`\n\n- **gradient_magnitude**: `Evision.Mat`.\n\n  Specify cost of gradient magnitude function: Type is CV_32FC1. Values should be in range `[0, 1]`.\n\n##### Keyword Arguments\n- **image**: `Evision.Mat`.\n\n  **Optional parameter**. Must be specified if subset of features is specified (non-specified features are calculated internally)\n\n##### Return\n- **retval**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n\n Customized advanced variant of applyImage() call.\n\nPython prototype (for reference only):\n```python3\napplyImageFeatures(non_edge, gradient_direction, gradient_magnitude[, image]) -> retval\n```","ref":"Evision.Segmentation.IntelligentScissorsMB.html#applyImageFeatures/4"},{"type":"function","title":"Evision.Segmentation.IntelligentScissorsMB.applyImageFeatures/5","doc":"Specify custom features of input image\n\n##### Positional Arguments\n- **self**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n- **non_edge**: `Evision.Mat`.\n\n  Specify cost of non-edge pixels. Type is CV_8UC1. Expected values are `{0, 1}`.\n\n- **gradient_direction**: `Evision.Mat`.\n\n  Specify gradient direction feature. Type is CV_32FC2. Values are expected to be normalized: `x^2 + y^2 == 1`\n\n- **gradient_magnitude**: `Evision.Mat`.\n\n  Specify cost of gradient magnitude function: Type is CV_32FC1. Values should be in range `[0, 1]`.\n\n##### Keyword Arguments\n- **image**: `Evision.Mat`.\n\n  **Optional parameter**. Must be specified if subset of features is specified (non-specified features are calculated internally)\n\n##### Return\n- **retval**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n\n Customized advanced variant of applyImage() call.\n\nPython prototype (for reference only):\n```python3\napplyImageFeatures(non_edge, gradient_direction, gradient_magnitude[, image]) -> retval\n```","ref":"Evision.Segmentation.IntelligentScissorsMB.html#applyImageFeatures/5"},{"type":"function","title":"Evision.Segmentation.IntelligentScissorsMB.buildMap/1","doc":"","ref":"Evision.Segmentation.IntelligentScissorsMB.html#buildMap/1"},{"type":"function","title":"Evision.Segmentation.IntelligentScissorsMB.buildMap/2","doc":"Prepares a map of optimal paths for the given source point on the image\n\n##### Positional Arguments\n- **self**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n- **sourcePt**: `Point`.\n\n  The source point used to find the paths\n\n**Note**: applyImage() / applyImageFeatures() must be called before this call\n\nPython prototype (for reference only):\n```python3\nbuildMap(sourcePt) -> None\n```","ref":"Evision.Segmentation.IntelligentScissorsMB.html#buildMap/2"},{"type":"function","title":"Evision.Segmentation.IntelligentScissorsMB.getContour/1","doc":"","ref":"Evision.Segmentation.IntelligentScissorsMB.html#getContour/1"},{"type":"function","title":"Evision.Segmentation.IntelligentScissorsMB.getContour/2","doc":"Extracts optimal contour for the given target point on the image\n\n##### Positional Arguments\n- **self**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n- **targetPt**: `Point`.\n\n  The target point\n\n##### Keyword Arguments\n- **backward**: `bool`.\n\n  Flag to indicate reverse order of retrived pixels (use \"true\" value to fetch points from the target to the source point)\n\n##### Return\n- **contour**: `Evision.Mat.t()`.\n\n  The list of pixels which contains optimal path between the source and the target points of the image. Type is CV_32SC2 (compatible with `std::vector `)\n\n**Note**: buildMap() must be called before this call\n\nPython prototype (for reference only):\n```python3\ngetContour(targetPt[, contour[, backward]]) -> contour\n```","ref":"Evision.Segmentation.IntelligentScissorsMB.html#getContour/2"},{"type":"function","title":"Evision.Segmentation.IntelligentScissorsMB.getContour/3","doc":"Extracts optimal contour for the given target point on the image\n\n##### Positional Arguments\n- **self**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n- **targetPt**: `Point`.\n\n  The target point\n\n##### Keyword Arguments\n- **backward**: `bool`.\n\n  Flag to indicate reverse order of retrived pixels (use \"true\" value to fetch points from the target to the source point)\n\n##### Return\n- **contour**: `Evision.Mat.t()`.\n\n  The list of pixels which contains optimal path between the source and the target points of the image. Type is CV_32SC2 (compatible with `std::vector `)\n\n**Note**: buildMap() must be called before this call\n\nPython prototype (for reference only):\n```python3\ngetContour(targetPt[, contour[, backward]]) -> contour\n```","ref":"Evision.Segmentation.IntelligentScissorsMB.html#getContour/3"},{"type":"function","title":"Evision.Segmentation.IntelligentScissorsMB.intelligentScissorsMB/0","doc":"IntelligentScissorsMB\n##### Return\n- **self**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n\nPython prototype (for reference only):\n```python3\nIntelligentScissorsMB() ->  \n```","ref":"Evision.Segmentation.IntelligentScissorsMB.html#intelligentScissorsMB/0"},{"type":"function","title":"Evision.Segmentation.IntelligentScissorsMB.intelligentScissorsMB/1","doc":"","ref":"Evision.Segmentation.IntelligentScissorsMB.html#intelligentScissorsMB/1"},{"type":"function","title":"Evision.Segmentation.IntelligentScissorsMB.setEdgeFeatureCannyParameters/1","doc":"","ref":"Evision.Segmentation.IntelligentScissorsMB.html#setEdgeFeatureCannyParameters/1"},{"type":"function","title":"Evision.Segmentation.IntelligentScissorsMB.setEdgeFeatureCannyParameters/3","doc":"Switch edge feature extractor to use Canny edge detector\n\n##### Positional Arguments\n- **self**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n- **threshold1**: `double`\n- **threshold2**: `double`\n\n##### Keyword Arguments\n- **apertureSize**: `integer()`.\n- **l2gradient**: `bool`.\n\n##### Return\n- **retval**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n\n**Note**: \"Laplacian Zero-Crossing\" feature extractor is used by default (following to original article)\n@sa Canny\n\nPython prototype (for reference only):\n```python3\nsetEdgeFeatureCannyParameters(threshold1, threshold2[, apertureSize[, L2gradient]]) -> retval\n```","ref":"Evision.Segmentation.IntelligentScissorsMB.html#setEdgeFeatureCannyParameters/3"},{"type":"function","title":"Evision.Segmentation.IntelligentScissorsMB.setEdgeFeatureCannyParameters/4","doc":"Switch edge feature extractor to use Canny edge detector\n\n##### Positional Arguments\n- **self**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n- **threshold1**: `double`\n- **threshold2**: `double`\n\n##### Keyword Arguments\n- **apertureSize**: `integer()`.\n- **l2gradient**: `bool`.\n\n##### Return\n- **retval**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n\n**Note**: \"Laplacian Zero-Crossing\" feature extractor is used by default (following to original article)\n@sa Canny\n\nPython prototype (for reference only):\n```python3\nsetEdgeFeatureCannyParameters(threshold1, threshold2[, apertureSize[, L2gradient]]) -> retval\n```","ref":"Evision.Segmentation.IntelligentScissorsMB.html#setEdgeFeatureCannyParameters/4"},{"type":"function","title":"Evision.Segmentation.IntelligentScissorsMB.setEdgeFeatureZeroCrossingParameters/1","doc":"Switch to \"Laplacian Zero-Crossing\" edge feature extractor and specify its parameters\n\n##### Positional Arguments\n- **self**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n\n##### Keyword Arguments\n- **gradient_magnitude_min_value**: `float`.\n\n  Minimal gradient magnitude value for edge pixels (default: 0, check is disabled)\n\n##### Return\n- **retval**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n\n This feature extractor is used by default according to article.\n Implementation has additional filtering for regions with low-amplitude noise.\n This filtering is enabled through parameter of minimal gradient amplitude (use some small value 4, 8, 16).\n**Note**: Current implementation of this feature extractor is based on processing of grayscale images (color image is converted to grayscale image first).\n**Note**: Canny edge detector is a bit slower, but provides better results (especially on color images): use setEdgeFeatureCannyParameters().\n\nPython prototype (for reference only):\n```python3\nsetEdgeFeatureZeroCrossingParameters([, gradient_magnitude_min_value]) -> retval\n```","ref":"Evision.Segmentation.IntelligentScissorsMB.html#setEdgeFeatureZeroCrossingParameters/1"},{"type":"function","title":"Evision.Segmentation.IntelligentScissorsMB.setEdgeFeatureZeroCrossingParameters/2","doc":"Switch to \"Laplacian Zero-Crossing\" edge feature extractor and specify its parameters\n\n##### Positional Arguments\n- **self**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n\n##### Keyword Arguments\n- **gradient_magnitude_min_value**: `float`.\n\n  Minimal gradient magnitude value for edge pixels (default: 0, check is disabled)\n\n##### Return\n- **retval**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n\n This feature extractor is used by default according to article.\n Implementation has additional filtering for regions with low-amplitude noise.\n This filtering is enabled through parameter of minimal gradient amplitude (use some small value 4, 8, 16).\n**Note**: Current implementation of this feature extractor is based on processing of grayscale images (color image is converted to grayscale image first).\n**Note**: Canny edge detector is a bit slower, but provides better results (especially on color images): use setEdgeFeatureCannyParameters().\n\nPython prototype (for reference only):\n```python3\nsetEdgeFeatureZeroCrossingParameters([, gradient_magnitude_min_value]) -> retval\n```","ref":"Evision.Segmentation.IntelligentScissorsMB.html#setEdgeFeatureZeroCrossingParameters/2"},{"type":"function","title":"Evision.Segmentation.IntelligentScissorsMB.setGradientMagnitudeMaxLimit/1","doc":"Specify gradient magnitude max value threshold\n\n##### Positional Arguments\n- **self**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n\n##### Keyword Arguments\n- **gradient_magnitude_threshold_max**: `float`.\n\n  Specify gradient magnitude max value threshold (default: 0, disabled)\n\n##### Return\n- **retval**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n\n Zero limit value is used to disable gradient magnitude thresholding (default behavior, as described in original article).\n Otherwize pixels with `gradient magnitude >= threshold` have zero cost.\n**Note**: Thresholding should be used for images with irregular regions (to avoid stuck on parameters from high-contract areas, like embedded logos).\n\nPython prototype (for reference only):\n```python3\nsetGradientMagnitudeMaxLimit([, gradient_magnitude_threshold_max]) -> retval\n```","ref":"Evision.Segmentation.IntelligentScissorsMB.html#setGradientMagnitudeMaxLimit/1"},{"type":"function","title":"Evision.Segmentation.IntelligentScissorsMB.setGradientMagnitudeMaxLimit/2","doc":"Specify gradient magnitude max value threshold\n\n##### Positional Arguments\n- **self**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n\n##### Keyword Arguments\n- **gradient_magnitude_threshold_max**: `float`.\n\n  Specify gradient magnitude max value threshold (default: 0, disabled)\n\n##### Return\n- **retval**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n\n Zero limit value is used to disable gradient magnitude thresholding (default behavior, as described in original article).\n Otherwize pixels with `gradient magnitude >= threshold` have zero cost.\n**Note**: Thresholding should be used for images with irregular regions (to avoid stuck on parameters from high-contract areas, like embedded logos).\n\nPython prototype (for reference only):\n```python3\nsetGradientMagnitudeMaxLimit([, gradient_magnitude_threshold_max]) -> retval\n```","ref":"Evision.Segmentation.IntelligentScissorsMB.html#setGradientMagnitudeMaxLimit/2"},{"type":"function","title":"Evision.Segmentation.IntelligentScissorsMB.setWeights/1","doc":"","ref":"Evision.Segmentation.IntelligentScissorsMB.html#setWeights/1"},{"type":"function","title":"Evision.Segmentation.IntelligentScissorsMB.setWeights/4","doc":"Specify weights of feature functions\n\n##### Positional Arguments\n- **self**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n- **weight_non_edge**: `float`.\n\n  Specify cost of non-edge pixels (default: 0.43f)\n\n- **weight_gradient_direction**: `float`.\n\n  Specify cost of gradient direction function (default: 0.43f)\n\n- **weight_gradient_magnitude**: `float`.\n\n  Specify cost of gradient magnitude function (default: 0.14f)\n\n##### Return\n- **retval**: `Evision.Segmentation.IntelligentScissorsMB.t()`\n\n Consider keeping weights normalized (sum of weights equals to 1.0)\n Discrete dynamic programming (DP) goal is minimization of costs between pixels.\n\nPython prototype (for reference only):\n```python3\nsetWeights(weight_non_edge, weight_gradient_direction, weight_gradient_magnitude) -> retval\n```","ref":"Evision.Segmentation.IntelligentScissorsMB.html#setWeights/4"},{"type":"type","title":"Evision.Segmentation.IntelligentScissorsMB.t/0","doc":"Type that represents an `Segmentation.IntelligentScissorsMB` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Segmentation.IntelligentScissorsMB.html#t:t/0"},{"type":"module","title":"Evision.ShapeContextDistanceExtractor","doc":"","ref":"Evision.ShapeContextDistanceExtractor.html"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.getAngularBins/1","doc":"getAngularBins\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetAngularBins() -> retval\n```","ref":"Evision.ShapeContextDistanceExtractor.html#getAngularBins/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.getBendingEnergyWeight/1","doc":"getBendingEnergyWeight\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetBendingEnergyWeight() -> retval\n```","ref":"Evision.ShapeContextDistanceExtractor.html#getBendingEnergyWeight/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.getCostExtractor/1","doc":"getCostExtractor\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n\n##### Return\n- **retval**: `Evision.HistogramCostExtractor.t()`\n\nPython prototype (for reference only):\n```python3\ngetCostExtractor() -> retval\n```","ref":"Evision.ShapeContextDistanceExtractor.html#getCostExtractor/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.getImageAppearanceWeight/1","doc":"getImageAppearanceWeight\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetImageAppearanceWeight() -> retval\n```","ref":"Evision.ShapeContextDistanceExtractor.html#getImageAppearanceWeight/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.getImages/1","doc":"getImages\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n\n##### Return\n- **image1**: `Evision.Mat.t()`.\n- **image2**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetImages([, image1[, image2]]) -> image1, image2\n```","ref":"Evision.ShapeContextDistanceExtractor.html#getImages/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.getImages/2","doc":"getImages\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n\n##### Return\n- **image1**: `Evision.Mat.t()`.\n- **image2**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ngetImages([, image1[, image2]]) -> image1, image2\n```","ref":"Evision.ShapeContextDistanceExtractor.html#getImages/2"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.getInnerRadius/1","doc":"getInnerRadius\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetInnerRadius() -> retval\n```","ref":"Evision.ShapeContextDistanceExtractor.html#getInnerRadius/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.getIterations/1","doc":"getIterations\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetIterations() -> retval\n```","ref":"Evision.ShapeContextDistanceExtractor.html#getIterations/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.getOuterRadius/1","doc":"getOuterRadius\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetOuterRadius() -> retval\n```","ref":"Evision.ShapeContextDistanceExtractor.html#getOuterRadius/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.getRadialBins/1","doc":"getRadialBins\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetRadialBins() -> retval\n```","ref":"Evision.ShapeContextDistanceExtractor.html#getRadialBins/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.getRotationInvariant/1","doc":"getRotationInvariant\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetRotationInvariant() -> retval\n```","ref":"Evision.ShapeContextDistanceExtractor.html#getRotationInvariant/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.getShapeContextWeight/1","doc":"getShapeContextWeight\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetShapeContextWeight() -> retval\n```","ref":"Evision.ShapeContextDistanceExtractor.html#getShapeContextWeight/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.getStdDev/1","doc":"getStdDev\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetStdDev() -> retval\n```","ref":"Evision.ShapeContextDistanceExtractor.html#getStdDev/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.getTransformAlgorithm/1","doc":"getTransformAlgorithm\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n\n##### Return\n- **retval**: `Evision.ShapeTransformer.t()`\n\nPython prototype (for reference only):\n```python3\ngetTransformAlgorithm() -> retval\n```","ref":"Evision.ShapeContextDistanceExtractor.html#getTransformAlgorithm/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setAngularBins/1","doc":"","ref":"Evision.ShapeContextDistanceExtractor.html#setAngularBins/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setAngularBins/2","doc":"Establish the number of angular bins for the Shape Context Descriptor used in the shape matching\npipeline.\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n- **nAngularBins**: `integer()`.\n\n  The number of angular bins in the shape context descriptor.\n\nPython prototype (for reference only):\n```python3\nsetAngularBins(nAngularBins) -> None\n```","ref":"Evision.ShapeContextDistanceExtractor.html#setAngularBins/2"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setBendingEnergyWeight/1","doc":"","ref":"Evision.ShapeContextDistanceExtractor.html#setBendingEnergyWeight/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setBendingEnergyWeight/2","doc":"Set the weight of the Bending Energy in the final value of the shape distance. The bending energy\ndefinition depends on what transformation is being used to align the shapes. The final value of the\nshape distance is a user-defined linear combination of the shape context distance, an image\nappearance distance, and a bending energy.\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n- **bendingEnergyWeight**: `float`.\n\n  The weight of the Bending Energy in the final distance value.\n\nPython prototype (for reference only):\n```python3\nsetBendingEnergyWeight(bendingEnergyWeight) -> None\n```","ref":"Evision.ShapeContextDistanceExtractor.html#setBendingEnergyWeight/2"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setCostExtractor/1","doc":"","ref":"Evision.ShapeContextDistanceExtractor.html#setCostExtractor/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setCostExtractor/2","doc":"Set the algorithm used for building the shape context descriptor cost matrix.\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n- **comparer**: `Evision.HistogramCostExtractor`.\n\n  Smart pointer to a HistogramCostExtractor, an algorithm that defines the cost\n  matrix between descriptors.\n\nPython prototype (for reference only):\n```python3\nsetCostExtractor(comparer) -> None\n```","ref":"Evision.ShapeContextDistanceExtractor.html#setCostExtractor/2"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setImageAppearanceWeight/1","doc":"","ref":"Evision.ShapeContextDistanceExtractor.html#setImageAppearanceWeight/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setImageAppearanceWeight/2","doc":"Set the weight of the Image Appearance cost in the final value of the shape distance. The image\nappearance cost is defined as the sum of squared brightness differences in Gaussian windows around\ncorresponding image points. The final value of the shape distance is a user-defined linear\ncombination of the shape context distance, an image appearance distance, and a bending energy. If\nthis value is set to a number different from 0, is mandatory to set the images that correspond to\neach shape.\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n- **imageAppearanceWeight**: `float`.\n\n  The weight of the appearance cost in the final distance value.\n\nPython prototype (for reference only):\n```python3\nsetImageAppearanceWeight(imageAppearanceWeight) -> None\n```","ref":"Evision.ShapeContextDistanceExtractor.html#setImageAppearanceWeight/2"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setImages/1","doc":"","ref":"Evision.ShapeContextDistanceExtractor.html#setImages/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setImages/3","doc":"Set the images that correspond to each shape. This images are used in the calculation of the Image\nAppearance cost.\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n- **image1**: `Evision.Mat`.\n\n  Image corresponding to the shape defined by contours1.\n\n- **image2**: `Evision.Mat`.\n\n  Image corresponding to the shape defined by contours2.\n\nPython prototype (for reference only):\n```python3\nsetImages(image1, image2) -> None\n```","ref":"Evision.ShapeContextDistanceExtractor.html#setImages/3"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setInnerRadius/1","doc":"","ref":"Evision.ShapeContextDistanceExtractor.html#setInnerRadius/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setInnerRadius/2","doc":"Set the inner radius of the shape context descriptor.\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n- **innerRadius**: `float`.\n\n  The value of the inner radius.\n\nPython prototype (for reference only):\n```python3\nsetInnerRadius(innerRadius) -> None\n```","ref":"Evision.ShapeContextDistanceExtractor.html#setInnerRadius/2"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setIterations/1","doc":"","ref":"Evision.ShapeContextDistanceExtractor.html#setIterations/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setIterations/2","doc":"setIterations\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n- **iterations**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetIterations(iterations) -> None\n```","ref":"Evision.ShapeContextDistanceExtractor.html#setIterations/2"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setOuterRadius/1","doc":"","ref":"Evision.ShapeContextDistanceExtractor.html#setOuterRadius/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setOuterRadius/2","doc":"Set the outer radius of the shape context descriptor.\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n- **outerRadius**: `float`.\n\n  The value of the outer radius.\n\nPython prototype (for reference only):\n```python3\nsetOuterRadius(outerRadius) -> None\n```","ref":"Evision.ShapeContextDistanceExtractor.html#setOuterRadius/2"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setRadialBins/1","doc":"","ref":"Evision.ShapeContextDistanceExtractor.html#setRadialBins/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setRadialBins/2","doc":"Establish the number of radial bins for the Shape Context Descriptor used in the shape matching\npipeline.\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n- **nRadialBins**: `integer()`.\n\n  The number of radial bins in the shape context descriptor.\n\nPython prototype (for reference only):\n```python3\nsetRadialBins(nRadialBins) -> None\n```","ref":"Evision.ShapeContextDistanceExtractor.html#setRadialBins/2"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setRotationInvariant/1","doc":"","ref":"Evision.ShapeContextDistanceExtractor.html#setRotationInvariant/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setRotationInvariant/2","doc":"setRotationInvariant\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n- **rotationInvariant**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetRotationInvariant(rotationInvariant) -> None\n```","ref":"Evision.ShapeContextDistanceExtractor.html#setRotationInvariant/2"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setShapeContextWeight/1","doc":"","ref":"Evision.ShapeContextDistanceExtractor.html#setShapeContextWeight/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setShapeContextWeight/2","doc":"Set the weight of the shape context distance in the final value of the shape distance. The shape\ncontext distance between two shapes is defined as the symmetric sum of shape context matching costs\nover best matching points. The final value of the shape distance is a user-defined linear\ncombination of the shape context distance, an image appearance distance, and a bending energy.\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n- **shapeContextWeight**: `float`.\n\n  The weight of the shape context distance in the final distance value.\n\nPython prototype (for reference only):\n```python3\nsetShapeContextWeight(shapeContextWeight) -> None\n```","ref":"Evision.ShapeContextDistanceExtractor.html#setShapeContextWeight/2"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setStdDev/1","doc":"","ref":"Evision.ShapeContextDistanceExtractor.html#setStdDev/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setStdDev/2","doc":"Set the value of the standard deviation for the Gaussian window for the image appearance cost.\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n- **sigma**: `float`.\n\n  Standard Deviation.\n\nPython prototype (for reference only):\n```python3\nsetStdDev(sigma) -> None\n```","ref":"Evision.ShapeContextDistanceExtractor.html#setStdDev/2"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setTransformAlgorithm/1","doc":"","ref":"Evision.ShapeContextDistanceExtractor.html#setTransformAlgorithm/1"},{"type":"function","title":"Evision.ShapeContextDistanceExtractor.setTransformAlgorithm/2","doc":"Set the algorithm used for aligning the shapes.\n\n##### Positional Arguments\n- **self**: `Evision.ShapeContextDistanceExtractor.t()`\n- **transformer**: `Evision.ShapeTransformer`.\n\n  Smart pointer to a ShapeTransformer, an algorithm that defines the aligning\n  transformation.\n\nPython prototype (for reference only):\n```python3\nsetTransformAlgorithm(transformer) -> None\n```","ref":"Evision.ShapeContextDistanceExtractor.html#setTransformAlgorithm/2"},{"type":"type","title":"Evision.ShapeContextDistanceExtractor.t/0","doc":"Type that represents an `ShapeContextDistanceExtractor` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ShapeContextDistanceExtractor.html#t:t/0"},{"type":"module","title":"Evision.ShapeDistanceExtractor","doc":"","ref":"Evision.ShapeDistanceExtractor.html"},{"type":"function","title":"Evision.ShapeDistanceExtractor.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.ShapeDistanceExtractor.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.ShapeDistanceExtractor.html#clear/1"},{"type":"function","title":"Evision.ShapeDistanceExtractor.computeDistance/1","doc":"","ref":"Evision.ShapeDistanceExtractor.html#computeDistance/1"},{"type":"function","title":"Evision.ShapeDistanceExtractor.computeDistance/3","doc":"Compute the shape distance between two shapes defined by its contours.\n\n##### Positional Arguments\n- **self**: `Evision.ShapeDistanceExtractor.t()`\n- **contour1**: `Evision.Mat`.\n\n  Contour defining first shape.\n\n- **contour2**: `Evision.Mat`.\n\n  Contour defining second shape.\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ncomputeDistance(contour1, contour2) -> retval\n```","ref":"Evision.ShapeDistanceExtractor.html#computeDistance/3"},{"type":"function","title":"Evision.ShapeDistanceExtractor.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.ShapeDistanceExtractor.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.ShapeDistanceExtractor.html#empty/1"},{"type":"function","title":"Evision.ShapeDistanceExtractor.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.ShapeDistanceExtractor.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.ShapeDistanceExtractor.html#getDefaultName/1"},{"type":"function","title":"Evision.ShapeDistanceExtractor.read/1","doc":"","ref":"Evision.ShapeDistanceExtractor.html#read/1"},{"type":"function","title":"Evision.ShapeDistanceExtractor.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ShapeDistanceExtractor.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.ShapeDistanceExtractor.html#read/2"},{"type":"function","title":"Evision.ShapeDistanceExtractor.save/1","doc":"","ref":"Evision.ShapeDistanceExtractor.html#save/1"},{"type":"function","title":"Evision.ShapeDistanceExtractor.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.ShapeDistanceExtractor.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.ShapeDistanceExtractor.html#save/2"},{"type":"function","title":"Evision.ShapeDistanceExtractor.write/1","doc":"","ref":"Evision.ShapeDistanceExtractor.html#write/1"},{"type":"function","title":"Evision.ShapeDistanceExtractor.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ShapeDistanceExtractor.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.ShapeDistanceExtractor.html#write/2"},{"type":"function","title":"Evision.ShapeDistanceExtractor.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.ShapeDistanceExtractor.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.ShapeDistanceExtractor.html#write/3"},{"type":"type","title":"Evision.ShapeDistanceExtractor.t/0","doc":"Type that represents an `ShapeDistanceExtractor` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ShapeDistanceExtractor.html#t:t/0"},{"type":"module","title":"Evision.ShapeMatchModes","doc":"","ref":"Evision.ShapeMatchModes.html"},{"type":"function","title":"Evision.ShapeMatchModes.cv_CONTOURS_MATCH_I1/0","doc":"","ref":"Evision.ShapeMatchModes.html#cv_CONTOURS_MATCH_I1/0"},{"type":"function","title":"Evision.ShapeMatchModes.cv_CONTOURS_MATCH_I2/0","doc":"","ref":"Evision.ShapeMatchModes.html#cv_CONTOURS_MATCH_I2/0"},{"type":"function","title":"Evision.ShapeMatchModes.cv_CONTOURS_MATCH_I3/0","doc":"","ref":"Evision.ShapeMatchModes.html#cv_CONTOURS_MATCH_I3/0"},{"type":"type","title":"Evision.ShapeMatchModes.enum/0","doc":"","ref":"Evision.ShapeMatchModes.html#t:enum/0"},{"type":"module","title":"Evision.ShapeTransformer","doc":"","ref":"Evision.ShapeTransformer.html"},{"type":"function","title":"Evision.ShapeTransformer.applyTransformation/1","doc":"","ref":"Evision.ShapeTransformer.html#applyTransformation/1"},{"type":"function","title":"Evision.ShapeTransformer.applyTransformation/2","doc":"Apply a transformation, given a pre-estimated transformation parameters.\n\n##### Positional Arguments\n- **self**: `Evision.ShapeTransformer.t()`\n- **input**: `Evision.Mat`.\n\n  Contour (set of points) to apply the transformation.\n\n##### Return\n- **retval**: `float`\n- **output**: `Evision.Mat.t()`.\n\n  Output contour.\n\nPython prototype (for reference only):\n```python3\napplyTransformation(input[, output]) -> retval, output\n```","ref":"Evision.ShapeTransformer.html#applyTransformation/2"},{"type":"function","title":"Evision.ShapeTransformer.applyTransformation/3","doc":"Apply a transformation, given a pre-estimated transformation parameters.\n\n##### Positional Arguments\n- **self**: `Evision.ShapeTransformer.t()`\n- **input**: `Evision.Mat`.\n\n  Contour (set of points) to apply the transformation.\n\n##### Return\n- **retval**: `float`\n- **output**: `Evision.Mat.t()`.\n\n  Output contour.\n\nPython prototype (for reference only):\n```python3\napplyTransformation(input[, output]) -> retval, output\n```","ref":"Evision.ShapeTransformer.html#applyTransformation/3"},{"type":"function","title":"Evision.ShapeTransformer.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.ShapeTransformer.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.ShapeTransformer.html#clear/1"},{"type":"function","title":"Evision.ShapeTransformer.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.ShapeTransformer.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.ShapeTransformer.html#empty/1"},{"type":"function","title":"Evision.ShapeTransformer.estimateTransformation/1","doc":"","ref":"Evision.ShapeTransformer.html#estimateTransformation/1"},{"type":"function","title":"Evision.ShapeTransformer.estimateTransformation/4","doc":"Estimate the transformation parameters of the current transformer algorithm, based on point matches.\n\n##### Positional Arguments\n- **self**: `Evision.ShapeTransformer.t()`\n- **transformingShape**: `Evision.Mat`.\n\n  Contour defining first shape.\n\n- **targetShape**: `Evision.Mat`.\n\n  Contour defining second shape (Target).\n\n- **matches**: `[Evision.DMatch]`.\n\n  Standard vector of Matches between points.\n\nPython prototype (for reference only):\n```python3\nestimateTransformation(transformingShape, targetShape, matches) -> None\n```","ref":"Evision.ShapeTransformer.html#estimateTransformation/4"},{"type":"function","title":"Evision.ShapeTransformer.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.ShapeTransformer.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.ShapeTransformer.html#getDefaultName/1"},{"type":"function","title":"Evision.ShapeTransformer.read/1","doc":"","ref":"Evision.ShapeTransformer.html#read/1"},{"type":"function","title":"Evision.ShapeTransformer.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ShapeTransformer.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.ShapeTransformer.html#read/2"},{"type":"function","title":"Evision.ShapeTransformer.save/1","doc":"","ref":"Evision.ShapeTransformer.html#save/1"},{"type":"function","title":"Evision.ShapeTransformer.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.ShapeTransformer.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.ShapeTransformer.html#save/2"},{"type":"function","title":"Evision.ShapeTransformer.warpImage/1","doc":"","ref":"Evision.ShapeTransformer.html#warpImage/1"},{"type":"function","title":"Evision.ShapeTransformer.warpImage/2","doc":"Apply a transformation, given a pre-estimated transformation parameters, to an Image.\n\n##### Positional Arguments\n- **self**: `Evision.ShapeTransformer.t()`\n- **transformingImage**: `Evision.Mat`.\n\n  Input image.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Image interpolation method.\n\n- **borderMode**: `integer()`.\n\n  border style.\n\n- **borderValue**: `Evision.scalar()`.\n\n  border value.\n\n##### Return\n- **output**: `Evision.Mat.t()`.\n\n  Output image.\n\nPython prototype (for reference only):\n```python3\nwarpImage(transformingImage[, output[, flags[, borderMode[, borderValue]]]]) -> output\n```","ref":"Evision.ShapeTransformer.html#warpImage/2"},{"type":"function","title":"Evision.ShapeTransformer.warpImage/3","doc":"Apply a transformation, given a pre-estimated transformation parameters, to an Image.\n\n##### Positional Arguments\n- **self**: `Evision.ShapeTransformer.t()`\n- **transformingImage**: `Evision.Mat`.\n\n  Input image.\n\n##### Keyword Arguments\n- **flags**: `integer()`.\n\n  Image interpolation method.\n\n- **borderMode**: `integer()`.\n\n  border style.\n\n- **borderValue**: `Evision.scalar()`.\n\n  border value.\n\n##### Return\n- **output**: `Evision.Mat.t()`.\n\n  Output image.\n\nPython prototype (for reference only):\n```python3\nwarpImage(transformingImage[, output[, flags[, borderMode[, borderValue]]]]) -> output\n```","ref":"Evision.ShapeTransformer.html#warpImage/3"},{"type":"function","title":"Evision.ShapeTransformer.write/1","doc":"","ref":"Evision.ShapeTransformer.html#write/1"},{"type":"function","title":"Evision.ShapeTransformer.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.ShapeTransformer.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.ShapeTransformer.html#write/2"},{"type":"function","title":"Evision.ShapeTransformer.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.ShapeTransformer.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.ShapeTransformer.html#write/3"},{"type":"type","title":"Evision.ShapeTransformer.t/0","doc":"Type that represents an `ShapeTransformer` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ShapeTransformer.html#t:t/0"},{"type":"module","title":"Evision.Signal","doc":"","ref":"Evision.Signal.html"},{"type":"function","title":"Evision.Signal.resampleSignal/1","doc":"","ref":"Evision.Signal.html#resampleSignal/1"},{"type":"function","title":"Evision.Signal.resampleSignal/3","doc":"Signal resampling\n\n##### Positional Arguments\n- **inputSignal**: `Evision.Mat`\n- **inFreq**: `integer()`\n- **outFreq**: `integer()`\n\n##### Return\n- **outSignal**: `Evision.Mat.t()`.\n\n  Array with output signal\n\nDetail: https://en.wikipedia.org/wiki/Sample-rate_conversion\n\nPython prototype (for reference only):\n```python3\nresampleSignal(inputSignal, inFreq, outFreq[, outSignal]) -> outSignal\n```","ref":"Evision.Signal.html#resampleSignal/3"},{"type":"function","title":"Evision.Signal.resampleSignal/4","doc":"Signal resampling\n\n##### Positional Arguments\n- **inputSignal**: `Evision.Mat`\n- **inFreq**: `integer()`\n- **outFreq**: `integer()`\n\n##### Return\n- **outSignal**: `Evision.Mat.t()`.\n\n  Array with output signal\n\nDetail: https://en.wikipedia.org/wiki/Sample-rate_conversion\n\nPython prototype (for reference only):\n```python3\nresampleSignal(inputSignal, inFreq, outFreq[, outSignal]) -> outSignal\n```","ref":"Evision.Signal.html#resampleSignal/4"},{"type":"type","title":"Evision.Signal.t/0","doc":"Type that represents an `Signal` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Signal.html#t:t/0"},{"type":"module","title":"Evision.SimpleBlobDetector","doc":"","ref":"Evision.SimpleBlobDetector.html"},{"type":"function","title":"Evision.SimpleBlobDetector.compute/1","doc":"","ref":"Evision.SimpleBlobDetector.html#compute/1"},{"type":"function","title":"Evision.SimpleBlobDetector.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.SimpleBlobDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.SimpleBlobDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.SimpleBlobDetector.html#compute/3"},{"type":"function","title":"Evision.SimpleBlobDetector.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.SimpleBlobDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.SimpleBlobDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.SimpleBlobDetector.html#compute/4"},{"type":"function","title":"Evision.SimpleBlobDetector.create/0","doc":"create\n##### Keyword Arguments\n- **parameters**: `Evision.SimpleBlobDetector.Params`.\n\n##### Return\n- **retval**: `Evision.SimpleBlobDetector.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, parameters]) -> retval\n```","ref":"Evision.SimpleBlobDetector.html#create/0"},{"type":"function","title":"Evision.SimpleBlobDetector.create/1","doc":"create\n##### Keyword Arguments\n- **parameters**: `Evision.SimpleBlobDetector.Params`.\n\n##### Return\n- **retval**: `Evision.SimpleBlobDetector.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, parameters]) -> retval\n```","ref":"Evision.SimpleBlobDetector.html#create/1"},{"type":"function","title":"Evision.SimpleBlobDetector.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.SimpleBlobDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.SimpleBlobDetector.html#defaultNorm/1"},{"type":"function","title":"Evision.SimpleBlobDetector.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.SimpleBlobDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.SimpleBlobDetector.html#descriptorSize/1"},{"type":"function","title":"Evision.SimpleBlobDetector.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.SimpleBlobDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.SimpleBlobDetector.html#descriptorType/1"},{"type":"function","title":"Evision.SimpleBlobDetector.detect/1","doc":"","ref":"Evision.SimpleBlobDetector.html#detect/1"},{"type":"function","title":"Evision.SimpleBlobDetector.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.SimpleBlobDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.SimpleBlobDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.SimpleBlobDetector.html#detect/2"},{"type":"function","title":"Evision.SimpleBlobDetector.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.SimpleBlobDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.SimpleBlobDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.SimpleBlobDetector.html#detect/3"},{"type":"function","title":"Evision.SimpleBlobDetector.detectAndCompute/1","doc":"","ref":"Evision.SimpleBlobDetector.html#detectAndCompute/1"},{"type":"function","title":"Evision.SimpleBlobDetector.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.SimpleBlobDetector.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.SimpleBlobDetector.html#detectAndCompute/3"},{"type":"function","title":"Evision.SimpleBlobDetector.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.SimpleBlobDetector.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.SimpleBlobDetector.html#detectAndCompute/4"},{"type":"function","title":"Evision.SimpleBlobDetector.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.SimpleBlobDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.SimpleBlobDetector.html#empty/1"},{"type":"function","title":"Evision.SimpleBlobDetector.getBlobContours/1","doc":"getBlobContours\n\n##### Positional Arguments\n- **self**: `Evision.SimpleBlobDetector.t()`\n\n##### Return\n- **retval**: `[[cv::Point]]`\n\nPython prototype (for reference only):\n```python3\ngetBlobContours() -> retval\n```","ref":"Evision.SimpleBlobDetector.html#getBlobContours/1"},{"type":"function","title":"Evision.SimpleBlobDetector.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.SimpleBlobDetector.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.SimpleBlobDetector.html#getDefaultName/1"},{"type":"function","title":"Evision.SimpleBlobDetector.getParams/1","doc":"getParams\n\n##### Positional Arguments\n- **self**: `Evision.SimpleBlobDetector.t()`\n\n##### Return\n- **retval**: `Evision.SimpleBlobDetector.Params.t()`\n\nPython prototype (for reference only):\n```python3\ngetParams() -> retval\n```","ref":"Evision.SimpleBlobDetector.html#getParams/1"},{"type":"function","title":"Evision.SimpleBlobDetector.read/1","doc":"","ref":"Evision.SimpleBlobDetector.html#read/1"},{"type":"function","title":"Evision.SimpleBlobDetector.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.SimpleBlobDetector.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.SimpleBlobDetector.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.SimpleBlobDetector.html#read/2"},{"type":"function","title":"Evision.SimpleBlobDetector.setParams/1","doc":"","ref":"Evision.SimpleBlobDetector.html#setParams/1"},{"type":"function","title":"Evision.SimpleBlobDetector.setParams/2","doc":"setParams\n\n##### Positional Arguments\n- **self**: `Evision.SimpleBlobDetector.t()`\n- **params**: `Evision.SimpleBlobDetector.Params`\n\nPython prototype (for reference only):\n```python3\nsetParams(params) -> None\n```","ref":"Evision.SimpleBlobDetector.html#setParams/2"},{"type":"function","title":"Evision.SimpleBlobDetector.write/1","doc":"","ref":"Evision.SimpleBlobDetector.html#write/1"},{"type":"function","title":"Evision.SimpleBlobDetector.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.SimpleBlobDetector.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.SimpleBlobDetector.html#write/2"},{"type":"function","title":"Evision.SimpleBlobDetector.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.SimpleBlobDetector.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.SimpleBlobDetector.html#write/3"},{"type":"type","title":"Evision.SimpleBlobDetector.t/0","doc":"Type that represents an `SimpleBlobDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.SimpleBlobDetector.html#t:t/0"},{"type":"module","title":"Evision.SimpleBlobDetector.Params","doc":"","ref":"Evision.SimpleBlobDetector.Params.html"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.get_blobColor/1","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#get_blobColor/1"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.get_collectContours/1","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#get_collectContours/1"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.get_filterByArea/1","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#get_filterByArea/1"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.get_filterByCircularity/1","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#get_filterByCircularity/1"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.get_filterByColor/1","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#get_filterByColor/1"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.get_filterByConvexity/1","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#get_filterByConvexity/1"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.get_filterByInertia/1","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#get_filterByInertia/1"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.get_maxArea/1","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#get_maxArea/1"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.get_maxCircularity/1","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#get_maxCircularity/1"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.get_maxConvexity/1","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#get_maxConvexity/1"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.get_maxInertiaRatio/1","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#get_maxInertiaRatio/1"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.get_maxThreshold/1","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#get_maxThreshold/1"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.get_minArea/1","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#get_minArea/1"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.get_minCircularity/1","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#get_minCircularity/1"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.get_minConvexity/1","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#get_minConvexity/1"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.get_minDistBetweenBlobs/1","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#get_minDistBetweenBlobs/1"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.get_minInertiaRatio/1","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#get_minInertiaRatio/1"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.get_minRepeatability/1","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#get_minRepeatability/1"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.get_minThreshold/1","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#get_minThreshold/1"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.get_thresholdStep/1","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#get_thresholdStep/1"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.params/0","doc":"SimpleBlobDetector_Params\n##### Return\n- **self**: `Evision.SimpleBlobDetector.Params.t()`\n\nPython prototype (for reference only):\n```python3\nSimpleBlobDetector_Params() ->  \n```","ref":"Evision.SimpleBlobDetector.Params.html#params/0"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.params/1","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#params/1"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.set_blobColor/2","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#set_blobColor/2"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.set_collectContours/2","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#set_collectContours/2"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.set_filterByArea/2","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#set_filterByArea/2"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.set_filterByCircularity/2","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#set_filterByCircularity/2"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.set_filterByColor/2","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#set_filterByColor/2"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.set_filterByConvexity/2","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#set_filterByConvexity/2"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.set_filterByInertia/2","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#set_filterByInertia/2"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.set_maxArea/2","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#set_maxArea/2"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.set_maxCircularity/2","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#set_maxCircularity/2"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.set_maxConvexity/2","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#set_maxConvexity/2"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.set_maxInertiaRatio/2","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#set_maxInertiaRatio/2"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.set_maxThreshold/2","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#set_maxThreshold/2"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.set_minArea/2","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#set_minArea/2"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.set_minCircularity/2","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#set_minCircularity/2"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.set_minConvexity/2","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#set_minConvexity/2"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.set_minDistBetweenBlobs/2","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#set_minDistBetweenBlobs/2"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.set_minInertiaRatio/2","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#set_minInertiaRatio/2"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.set_minRepeatability/2","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#set_minRepeatability/2"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.set_minThreshold/2","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#set_minThreshold/2"},{"type":"function","title":"Evision.SimpleBlobDetector.Params.set_thresholdStep/2","doc":"","ref":"Evision.SimpleBlobDetector.Params.html#set_thresholdStep/2"},{"type":"type","title":"Evision.SimpleBlobDetector.Params.t/0","doc":"Type that represents an `SimpleBlobDetector.Params` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.SimpleBlobDetector.Params.html#t:t/0"},{"type":"module","title":"Evision.SmartCell","doc":"Evision SmartCell Collection\n\nTo use smartcell in Livebook, `:kino >= 0.7` is required\n\n```elixir\ndefp deps do\n  [\n    # ...\n    {:kino, \"~> 0.7\"},\n    # ...\n  ]\nend\n```","ref":"Evision.SmartCell.html"},{"type":"function","title":"Evision.SmartCell.available_smartcells/0","doc":"Get all available smartcells.\n\nTo register smartcells to `:kino`, please use `Evision.SmartCell.register_smartcells/1`.","ref":"Evision.SmartCell.html#available_smartcells/0"},{"type":"function","title":"Evision.SmartCell.register_smartcells/1","doc":"Register Smartcells\n\nIt will register all available smartcells by default.\n\nTo see all available smartcells, please use `Evision.SmartCell.available_smartcells/0`.","ref":"Evision.SmartCell.html#register_smartcells/1"},{"type":"module","title":"Evision.SmartCell.ML.DTrees","doc":"","ref":"Evision.SmartCell.ML.DTrees.html"},{"type":"function","title":"Evision.SmartCell.ML.DTrees.child_spec/1","doc":"","ref":"Evision.SmartCell.ML.DTrees.html#child_spec/1"},{"type":"function","title":"Evision.SmartCell.ML.DTrees.defaults/0","doc":"","ref":"Evision.SmartCell.ML.DTrees.html#defaults/0"},{"type":"function","title":"Evision.SmartCell.ML.DTrees.get_quoted_code/1","doc":"","ref":"Evision.SmartCell.ML.DTrees.html#get_quoted_code/1"},{"type":"function","title":"Evision.SmartCell.ML.DTrees.id/0","doc":"","ref":"Evision.SmartCell.ML.DTrees.html#id/0"},{"type":"function","title":"Evision.SmartCell.ML.DTrees.properties/0","doc":"","ref":"Evision.SmartCell.ML.DTrees.html#properties/0"},{"type":"function","title":"Evision.SmartCell.ML.DTrees.to_updates/3","doc":"","ref":"Evision.SmartCell.ML.DTrees.html#to_updates/3"},{"type":"module","title":"Evision.SmartCell.ML.RTrees","doc":"","ref":"Evision.SmartCell.ML.RTrees.html"},{"type":"function","title":"Evision.SmartCell.ML.RTrees.child_spec/1","doc":"","ref":"Evision.SmartCell.ML.RTrees.html#child_spec/1"},{"type":"function","title":"Evision.SmartCell.ML.RTrees.defaults/0","doc":"","ref":"Evision.SmartCell.ML.RTrees.html#defaults/0"},{"type":"function","title":"Evision.SmartCell.ML.RTrees.get_quoted_code/1","doc":"","ref":"Evision.SmartCell.ML.RTrees.html#get_quoted_code/1"},{"type":"function","title":"Evision.SmartCell.ML.RTrees.id/0","doc":"","ref":"Evision.SmartCell.ML.RTrees.html#id/0"},{"type":"function","title":"Evision.SmartCell.ML.RTrees.properties/0","doc":"","ref":"Evision.SmartCell.ML.RTrees.html#properties/0"},{"type":"function","title":"Evision.SmartCell.ML.RTrees.to_updates/3","doc":"","ref":"Evision.SmartCell.ML.RTrees.html#to_updates/3"},{"type":"module","title":"Evision.SmartCell.ML.SVM","doc":"","ref":"Evision.SmartCell.ML.SVM.html"},{"type":"function","title":"Evision.SmartCell.ML.SVM.child_spec/1","doc":"","ref":"Evision.SmartCell.ML.SVM.html#child_spec/1"},{"type":"function","title":"Evision.SmartCell.ML.SVM.defaults/0","doc":"","ref":"Evision.SmartCell.ML.SVM.html#defaults/0"},{"type":"function","title":"Evision.SmartCell.ML.SVM.get_quoted_code/1","doc":"","ref":"Evision.SmartCell.ML.SVM.html#get_quoted_code/1"},{"type":"function","title":"Evision.SmartCell.ML.SVM.id/0","doc":"","ref":"Evision.SmartCell.ML.SVM.html#id/0"},{"type":"function","title":"Evision.SmartCell.ML.SVM.properties/0","doc":"","ref":"Evision.SmartCell.ML.SVM.html#properties/0"},{"type":"function","title":"Evision.SmartCell.ML.SVM.to_updates/3","doc":"","ref":"Evision.SmartCell.ML.SVM.html#to_updates/3"},{"type":"module","title":"Evision.SmartCell.ML.TrainData","doc":"","ref":"Evision.SmartCell.ML.TrainData.html"},{"type":"function","title":"Evision.SmartCell.ML.TrainData.child_spec/1","doc":"","ref":"Evision.SmartCell.ML.TrainData.html#child_spec/1"},{"type":"function","title":"Evision.SmartCell.ML.TrainData.data_layout/1","doc":"","ref":"Evision.SmartCell.ML.TrainData.html#data_layout/1"},{"type":"function","title":"Evision.SmartCell.ML.TrainData.defaults/0","doc":"","ref":"Evision.SmartCell.ML.TrainData.html#defaults/0"},{"type":"function","title":"Evision.SmartCell.ML.TrainData.get_calc_error/3","doc":"","ref":"Evision.SmartCell.ML.TrainData.html#get_calc_error/3"},{"type":"function","title":"Evision.SmartCell.ML.TrainData.get_quoted_code/1","doc":"","ref":"Evision.SmartCell.ML.TrainData.html#get_quoted_code/1"},{"type":"function","title":"Evision.SmartCell.ML.TrainData.id/0","doc":"","ref":"Evision.SmartCell.ML.TrainData.html#id/0"},{"type":"function","title":"Evision.SmartCell.ML.TrainData.properties/0","doc":"","ref":"Evision.SmartCell.ML.TrainData.html#properties/0"},{"type":"function","title":"Evision.SmartCell.ML.TrainData.to_updates/3","doc":"","ref":"Evision.SmartCell.ML.TrainData.html#to_updates/3"},{"type":"module","title":"Evision.SmartCell.SimpleList","doc":"A kino for displaying a list of labels.\nThis kino is primarily used to present top classification predictions.","ref":"Evision.SmartCell.SimpleList.html"},{"type":"module","title":"Examples - Evision.SmartCell.SimpleList","doc":"predictions =  [\n      \"malamute\",\n      \"Siberian husky\",\n      \"Eskimo dog\",\n      \"Tibetan mastiff\",\n      \"German shepherd\"\n    ]\n    Evision.SmartCell.SimpleList.new(predictions)","ref":"Evision.SmartCell.SimpleList.html#module-examples"},{"type":"function","title":"Evision.SmartCell.SimpleList.new/1","doc":"Creates a new kino displaying the given list of items.\nExpects a list of tuples, each element being the label and its score.","ref":"Evision.SmartCell.SimpleList.html#new/1"},{"type":"type","title":"Evision.SmartCell.SimpleList.t/0","doc":"","ref":"Evision.SmartCell.SimpleList.html#t:t/0"},{"type":"module","title":"Evision.SolveLPResult","doc":"","ref":"Evision.SolveLPResult.html"},{"type":"function","title":"Evision.SolveLPResult.cv_SOLVELP_LOST/0","doc":"","ref":"Evision.SolveLPResult.html#cv_SOLVELP_LOST/0"},{"type":"function","title":"Evision.SolveLPResult.cv_SOLVELP_MULTI/0","doc":"","ref":"Evision.SolveLPResult.html#cv_SOLVELP_MULTI/0"},{"type":"function","title":"Evision.SolveLPResult.cv_SOLVELP_SINGLE/0","doc":"","ref":"Evision.SolveLPResult.html#cv_SOLVELP_SINGLE/0"},{"type":"function","title":"Evision.SolveLPResult.cv_SOLVELP_UNBOUNDED/0","doc":"","ref":"Evision.SolveLPResult.html#cv_SOLVELP_UNBOUNDED/0"},{"type":"function","title":"Evision.SolveLPResult.cv_SOLVELP_UNFEASIBLE/0","doc":"","ref":"Evision.SolveLPResult.html#cv_SOLVELP_UNFEASIBLE/0"},{"type":"type","title":"Evision.SolveLPResult.enum/0","doc":"","ref":"Evision.SolveLPResult.html#t:enum/0"},{"type":"module","title":"Evision.SolvePnPMethod","doc":"","ref":"Evision.SolvePnPMethod.html"},{"type":"function","title":"Evision.SolvePnPMethod.cv_SOLVEPNP_AP3P/0","doc":"","ref":"Evision.SolvePnPMethod.html#cv_SOLVEPNP_AP3P/0"},{"type":"function","title":"Evision.SolvePnPMethod.cv_SOLVEPNP_DLS/0","doc":"","ref":"Evision.SolvePnPMethod.html#cv_SOLVEPNP_DLS/0"},{"type":"function","title":"Evision.SolvePnPMethod.cv_SOLVEPNP_EPNP/0","doc":"","ref":"Evision.SolvePnPMethod.html#cv_SOLVEPNP_EPNP/0"},{"type":"function","title":"Evision.SolvePnPMethod.cv_SOLVEPNP_IPPE/0","doc":"","ref":"Evision.SolvePnPMethod.html#cv_SOLVEPNP_IPPE/0"},{"type":"function","title":"Evision.SolvePnPMethod.cv_SOLVEPNP_IPPE_SQUARE/0","doc":"","ref":"Evision.SolvePnPMethod.html#cv_SOLVEPNP_IPPE_SQUARE/0"},{"type":"function","title":"Evision.SolvePnPMethod.cv_SOLVEPNP_ITERATIVE/0","doc":"","ref":"Evision.SolvePnPMethod.html#cv_SOLVEPNP_ITERATIVE/0"},{"type":"function","title":"Evision.SolvePnPMethod.cv_SOLVEPNP_MAX_COUNT/0","doc":"","ref":"Evision.SolvePnPMethod.html#cv_SOLVEPNP_MAX_COUNT/0"},{"type":"function","title":"Evision.SolvePnPMethod.cv_SOLVEPNP_P3P/0","doc":"","ref":"Evision.SolvePnPMethod.html#cv_SOLVEPNP_P3P/0"},{"type":"function","title":"Evision.SolvePnPMethod.cv_SOLVEPNP_SQPNP/0","doc":"","ref":"Evision.SolvePnPMethod.html#cv_SOLVEPNP_SQPNP/0"},{"type":"function","title":"Evision.SolvePnPMethod.cv_SOLVEPNP_UPNP/0","doc":"","ref":"Evision.SolvePnPMethod.html#cv_SOLVEPNP_UPNP/0"},{"type":"type","title":"Evision.SolvePnPMethod.enum/0","doc":"","ref":"Evision.SolvePnPMethod.html#t:enum/0"},{"type":"module","title":"Evision.SortFlags","doc":"","ref":"Evision.SortFlags.html"},{"type":"function","title":"Evision.SortFlags.cv_SORT_ASCENDING/0","doc":"","ref":"Evision.SortFlags.html#cv_SORT_ASCENDING/0"},{"type":"function","title":"Evision.SortFlags.cv_SORT_DESCENDING/0","doc":"","ref":"Evision.SortFlags.html#cv_SORT_DESCENDING/0"},{"type":"function","title":"Evision.SortFlags.cv_SORT_EVERY_COLUMN/0","doc":"","ref":"Evision.SortFlags.html#cv_SORT_EVERY_COLUMN/0"},{"type":"function","title":"Evision.SortFlags.cv_SORT_EVERY_ROW/0","doc":"","ref":"Evision.SortFlags.html#cv_SORT_EVERY_ROW/0"},{"type":"type","title":"Evision.SortFlags.enum/0","doc":"","ref":"Evision.SortFlags.html#t:enum/0"},{"type":"module","title":"Evision.SparseMat","doc":"","ref":"Evision.SparseMat.html"},{"type":"function","title":"Evision.SparseMat.cv_HASH_BIT/0","doc":"","ref":"Evision.SparseMat.html#cv_HASH_BIT/0"},{"type":"function","title":"Evision.SparseMat.cv_HASH_SCALE/0","doc":"","ref":"Evision.SparseMat.html#cv_HASH_SCALE/0"},{"type":"function","title":"Evision.SparseMat.cv_MAGIC_VAL/0","doc":"","ref":"Evision.SparseMat.html#cv_MAGIC_VAL/0"},{"type":"function","title":"Evision.SparseMat.cv_MAX_DIM/0","doc":"","ref":"Evision.SparseMat.html#cv_MAX_DIM/0"},{"type":"type","title":"Evision.SparseMat.enum/0","doc":"","ref":"Evision.SparseMat.html#t:enum/0"},{"type":"module","title":"Evision.SparseOpticalFlow","doc":"","ref":"Evision.SparseOpticalFlow.html"},{"type":"function","title":"Evision.SparseOpticalFlow.calc/1","doc":"","ref":"Evision.SparseOpticalFlow.html#calc/1"},{"type":"function","title":"Evision.SparseOpticalFlow.calc/5","doc":"Calculates a sparse optical flow.\n\n##### Positional Arguments\n- **self**: `Evision.SparseOpticalFlow.t()`\n- **prevImg**: `Evision.Mat`.\n\n  First input image.\n\n- **nextImg**: `Evision.Mat`.\n\n  Second input image of the same size and the same type as prevImg.\n\n- **prevPts**: `Evision.Mat`.\n\n  Vector of 2D points for which the flow needs to be found.\n\n##### Return\n- **nextPts**: `Evision.Mat.t()`.\n\n  Output vector of 2D points containing the calculated new positions of input features in the second image.\n\n- **status**: `Evision.Mat.t()`.\n\n  Output status vector. Each element of the vector is set to 1 if the\n  flow for the corresponding features has been found. Otherwise, it is set to 0.\n\n- **err**: `Evision.Mat.t()`.\n\n  Optional output vector that contains error response for each point (inverse confidence).\n\nPython prototype (for reference only):\n```python3\ncalc(prevImg, nextImg, prevPts, nextPts[, status[, err]]) -> nextPts, status, err\n```","ref":"Evision.SparseOpticalFlow.html#calc/5"},{"type":"function","title":"Evision.SparseOpticalFlow.calc/6","doc":"Calculates a sparse optical flow.\n\n##### Positional Arguments\n- **self**: `Evision.SparseOpticalFlow.t()`\n- **prevImg**: `Evision.Mat`.\n\n  First input image.\n\n- **nextImg**: `Evision.Mat`.\n\n  Second input image of the same size and the same type as prevImg.\n\n- **prevPts**: `Evision.Mat`.\n\n  Vector of 2D points for which the flow needs to be found.\n\n##### Return\n- **nextPts**: `Evision.Mat.t()`.\n\n  Output vector of 2D points containing the calculated new positions of input features in the second image.\n\n- **status**: `Evision.Mat.t()`.\n\n  Output status vector. Each element of the vector is set to 1 if the\n  flow for the corresponding features has been found. Otherwise, it is set to 0.\n\n- **err**: `Evision.Mat.t()`.\n\n  Optional output vector that contains error response for each point (inverse confidence).\n\nPython prototype (for reference only):\n```python3\ncalc(prevImg, nextImg, prevPts, nextPts[, status[, err]]) -> nextPts, status, err\n```","ref":"Evision.SparseOpticalFlow.html#calc/6"},{"type":"function","title":"Evision.SparseOpticalFlow.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.SparseOpticalFlow.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.SparseOpticalFlow.html#clear/1"},{"type":"function","title":"Evision.SparseOpticalFlow.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.SparseOpticalFlow.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.SparseOpticalFlow.html#empty/1"},{"type":"function","title":"Evision.SparseOpticalFlow.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.SparseOpticalFlow.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.SparseOpticalFlow.html#getDefaultName/1"},{"type":"function","title":"Evision.SparseOpticalFlow.read/1","doc":"","ref":"Evision.SparseOpticalFlow.html#read/1"},{"type":"function","title":"Evision.SparseOpticalFlow.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.SparseOpticalFlow.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.SparseOpticalFlow.html#read/2"},{"type":"function","title":"Evision.SparseOpticalFlow.save/1","doc":"","ref":"Evision.SparseOpticalFlow.html#save/1"},{"type":"function","title":"Evision.SparseOpticalFlow.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.SparseOpticalFlow.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.SparseOpticalFlow.html#save/2"},{"type":"function","title":"Evision.SparseOpticalFlow.write/1","doc":"","ref":"Evision.SparseOpticalFlow.html#write/1"},{"type":"function","title":"Evision.SparseOpticalFlow.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.SparseOpticalFlow.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.SparseOpticalFlow.html#write/2"},{"type":"function","title":"Evision.SparseOpticalFlow.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.SparseOpticalFlow.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.SparseOpticalFlow.html#write/3"},{"type":"type","title":"Evision.SparseOpticalFlow.t/0","doc":"Type that represents an `SparseOpticalFlow` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.SparseOpticalFlow.html#t:t/0"},{"type":"module","title":"Evision.SparsePyrLKOpticalFlow","doc":"","ref":"Evision.SparsePyrLKOpticalFlow.html"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.calc/1","doc":"","ref":"Evision.SparsePyrLKOpticalFlow.html#calc/1"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.calc/5","doc":"Calculates a sparse optical flow.\n\n##### Positional Arguments\n- **self**: `Evision.SparsePyrLKOpticalFlow.t()`\n- **prevImg**: `Evision.Mat`.\n\n  First input image.\n\n- **nextImg**: `Evision.Mat`.\n\n  Second input image of the same size and the same type as prevImg.\n\n- **prevPts**: `Evision.Mat`.\n\n  Vector of 2D points for which the flow needs to be found.\n\n##### Return\n- **nextPts**: `Evision.Mat.t()`.\n\n  Output vector of 2D points containing the calculated new positions of input features in the second image.\n\n- **status**: `Evision.Mat.t()`.\n\n  Output status vector. Each element of the vector is set to 1 if the\n  flow for the corresponding features has been found. Otherwise, it is set to 0.\n\n- **err**: `Evision.Mat.t()`.\n\n  Optional output vector that contains error response for each point (inverse confidence).\n\nPython prototype (for reference only):\n```python3\ncalc(prevImg, nextImg, prevPts, nextPts[, status[, err]]) -> nextPts, status, err\n```","ref":"Evision.SparsePyrLKOpticalFlow.html#calc/5"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.calc/6","doc":"Calculates a sparse optical flow.\n\n##### Positional Arguments\n- **self**: `Evision.SparsePyrLKOpticalFlow.t()`\n- **prevImg**: `Evision.Mat`.\n\n  First input image.\n\n- **nextImg**: `Evision.Mat`.\n\n  Second input image of the same size and the same type as prevImg.\n\n- **prevPts**: `Evision.Mat`.\n\n  Vector of 2D points for which the flow needs to be found.\n\n##### Return\n- **nextPts**: `Evision.Mat.t()`.\n\n  Output vector of 2D points containing the calculated new positions of input features in the second image.\n\n- **status**: `Evision.Mat.t()`.\n\n  Output status vector. Each element of the vector is set to 1 if the\n  flow for the corresponding features has been found. Otherwise, it is set to 0.\n\n- **err**: `Evision.Mat.t()`.\n\n  Optional output vector that contains error response for each point (inverse confidence).\n\nPython prototype (for reference only):\n```python3\ncalc(prevImg, nextImg, prevPts, nextPts[, status[, err]]) -> nextPts, status, err\n```","ref":"Evision.SparsePyrLKOpticalFlow.html#calc/6"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.SparsePyrLKOpticalFlow.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.SparsePyrLKOpticalFlow.html#clear/1"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.create/0","doc":"create\n##### Keyword Arguments\n- **winSize**: `Size`.\n- **maxLevel**: `integer()`.\n- **crit**: `TermCriteria`.\n- **flags**: `integer()`.\n- **minEigThreshold**: `double`.\n\n##### Return\n- **retval**: `Evision.SparsePyrLKOpticalFlow.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, winSize[, maxLevel[, crit[, flags[, minEigThreshold]]]]]) -> retval\n```","ref":"Evision.SparsePyrLKOpticalFlow.html#create/0"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.create/1","doc":"create\n##### Keyword Arguments\n- **winSize**: `Size`.\n- **maxLevel**: `integer()`.\n- **crit**: `TermCriteria`.\n- **flags**: `integer()`.\n- **minEigThreshold**: `double`.\n\n##### Return\n- **retval**: `Evision.SparsePyrLKOpticalFlow.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, winSize[, maxLevel[, crit[, flags[, minEigThreshold]]]]]) -> retval\n```","ref":"Evision.SparsePyrLKOpticalFlow.html#create/1"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.SparsePyrLKOpticalFlow.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.SparsePyrLKOpticalFlow.html#empty/1"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.SparsePyrLKOpticalFlow.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.SparsePyrLKOpticalFlow.html#getDefaultName/1"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.getFlags/1","doc":"getFlags\n\n##### Positional Arguments\n- **self**: `Evision.SparsePyrLKOpticalFlow.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetFlags() -> retval\n```","ref":"Evision.SparsePyrLKOpticalFlow.html#getFlags/1"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.getMaxLevel/1","doc":"getMaxLevel\n\n##### Positional Arguments\n- **self**: `Evision.SparsePyrLKOpticalFlow.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxLevel() -> retval\n```","ref":"Evision.SparsePyrLKOpticalFlow.html#getMaxLevel/1"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.getMinEigThreshold/1","doc":"getMinEigThreshold\n\n##### Positional Arguments\n- **self**: `Evision.SparsePyrLKOpticalFlow.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetMinEigThreshold() -> retval\n```","ref":"Evision.SparsePyrLKOpticalFlow.html#getMinEigThreshold/1"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.getTermCriteria/1","doc":"getTermCriteria\n\n##### Positional Arguments\n- **self**: `Evision.SparsePyrLKOpticalFlow.t()`\n\n##### Return\n- **retval**: `TermCriteria`\n\nPython prototype (for reference only):\n```python3\ngetTermCriteria() -> retval\n```","ref":"Evision.SparsePyrLKOpticalFlow.html#getTermCriteria/1"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.getWinSize/1","doc":"getWinSize\n\n##### Positional Arguments\n- **self**: `Evision.SparsePyrLKOpticalFlow.t()`\n\n##### Return\n- **retval**: `Size`\n\nPython prototype (for reference only):\n```python3\ngetWinSize() -> retval\n```","ref":"Evision.SparsePyrLKOpticalFlow.html#getWinSize/1"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.read/1","doc":"","ref":"Evision.SparsePyrLKOpticalFlow.html#read/1"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.SparsePyrLKOpticalFlow.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.SparsePyrLKOpticalFlow.html#read/2"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.save/1","doc":"","ref":"Evision.SparsePyrLKOpticalFlow.html#save/1"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.SparsePyrLKOpticalFlow.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.SparsePyrLKOpticalFlow.html#save/2"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.setFlags/1","doc":"","ref":"Evision.SparsePyrLKOpticalFlow.html#setFlags/1"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.setFlags/2","doc":"setFlags\n\n##### Positional Arguments\n- **self**: `Evision.SparsePyrLKOpticalFlow.t()`\n- **flags**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetFlags(flags) -> None\n```","ref":"Evision.SparsePyrLKOpticalFlow.html#setFlags/2"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.setMaxLevel/1","doc":"","ref":"Evision.SparsePyrLKOpticalFlow.html#setMaxLevel/1"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.setMaxLevel/2","doc":"setMaxLevel\n\n##### Positional Arguments\n- **self**: `Evision.SparsePyrLKOpticalFlow.t()`\n- **maxLevel**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxLevel(maxLevel) -> None\n```","ref":"Evision.SparsePyrLKOpticalFlow.html#setMaxLevel/2"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.setMinEigThreshold/1","doc":"","ref":"Evision.SparsePyrLKOpticalFlow.html#setMinEigThreshold/1"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.setMinEigThreshold/2","doc":"setMinEigThreshold\n\n##### Positional Arguments\n- **self**: `Evision.SparsePyrLKOpticalFlow.t()`\n- **minEigThreshold**: `double`\n\nPython prototype (for reference only):\n```python3\nsetMinEigThreshold(minEigThreshold) -> None\n```","ref":"Evision.SparsePyrLKOpticalFlow.html#setMinEigThreshold/2"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.setTermCriteria/1","doc":"","ref":"Evision.SparsePyrLKOpticalFlow.html#setTermCriteria/1"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.setTermCriteria/2","doc":"setTermCriteria\n\n##### Positional Arguments\n- **self**: `Evision.SparsePyrLKOpticalFlow.t()`\n- **crit**: `TermCriteria`\n\nPython prototype (for reference only):\n```python3\nsetTermCriteria(crit) -> None\n```","ref":"Evision.SparsePyrLKOpticalFlow.html#setTermCriteria/2"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.setWinSize/1","doc":"","ref":"Evision.SparsePyrLKOpticalFlow.html#setWinSize/1"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.setWinSize/2","doc":"setWinSize\n\n##### Positional Arguments\n- **self**: `Evision.SparsePyrLKOpticalFlow.t()`\n- **winSize**: `Size`\n\nPython prototype (for reference only):\n```python3\nsetWinSize(winSize) -> None\n```","ref":"Evision.SparsePyrLKOpticalFlow.html#setWinSize/2"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.write/1","doc":"","ref":"Evision.SparsePyrLKOpticalFlow.html#write/1"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.SparsePyrLKOpticalFlow.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.SparsePyrLKOpticalFlow.html#write/2"},{"type":"function","title":"Evision.SparsePyrLKOpticalFlow.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.SparsePyrLKOpticalFlow.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.SparsePyrLKOpticalFlow.html#write/3"},{"type":"type","title":"Evision.SparsePyrLKOpticalFlow.t/0","doc":"Type that represents an `SparsePyrLKOpticalFlow` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.SparsePyrLKOpticalFlow.html#t:t/0"},{"type":"module","title":"Evision.SpecialFilter","doc":"","ref":"Evision.SpecialFilter.html"},{"type":"function","title":"Evision.SpecialFilter.cv_FILTER_SCHARR/0","doc":"","ref":"Evision.SpecialFilter.html#cv_FILTER_SCHARR/0"},{"type":"type","title":"Evision.SpecialFilter.enum/0","doc":"","ref":"Evision.SpecialFilter.html#t:enum/0"},{"type":"module","title":"Evision.Stereo","doc":"","ref":"Evision.Stereo.html"},{"type":"function","title":"Evision.Stereo.cv_CV_CS_CENSUS/0","doc":"","ref":"Evision.Stereo.html#cv_CV_CS_CENSUS/0"},{"type":"function","title":"Evision.Stereo.cv_CV_DENSE_CENSUS/0","doc":"","ref":"Evision.Stereo.html#cv_CV_DENSE_CENSUS/0"},{"type":"function","title":"Evision.Stereo.cv_CV_MEAN_VARIATION/0","doc":"","ref":"Evision.Stereo.html#cv_CV_MEAN_VARIATION/0"},{"type":"function","title":"Evision.Stereo.cv_CV_MODIFIED_CENSUS_TRANSFORM/0","doc":"","ref":"Evision.Stereo.html#cv_CV_MODIFIED_CENSUS_TRANSFORM/0"},{"type":"function","title":"Evision.Stereo.cv_CV_MODIFIED_CS_CENSUS/0","doc":"","ref":"Evision.Stereo.html#cv_CV_MODIFIED_CS_CENSUS/0"},{"type":"function","title":"Evision.Stereo.cv_CV_QUADRATIC_INTERPOLATION/0","doc":"","ref":"Evision.Stereo.html#cv_CV_QUADRATIC_INTERPOLATION/0"},{"type":"function","title":"Evision.Stereo.cv_CV_SIMETRICV_INTERPOLATION/0","doc":"","ref":"Evision.Stereo.html#cv_CV_SIMETRICV_INTERPOLATION/0"},{"type":"function","title":"Evision.Stereo.cv_CV_SPARSE_CENSUS/0","doc":"","ref":"Evision.Stereo.html#cv_CV_SPARSE_CENSUS/0"},{"type":"function","title":"Evision.Stereo.cv_CV_SPECKLE_REMOVAL_ALGORITHM/0","doc":"","ref":"Evision.Stereo.html#cv_CV_SPECKLE_REMOVAL_ALGORITHM/0"},{"type":"function","title":"Evision.Stereo.cv_CV_SPECKLE_REMOVAL_AVG_ALGORITHM/0","doc":"","ref":"Evision.Stereo.html#cv_CV_SPECKLE_REMOVAL_AVG_ALGORITHM/0"},{"type":"function","title":"Evision.Stereo.cv_CV_STAR_KERNEL/0","doc":"","ref":"Evision.Stereo.html#cv_CV_STAR_KERNEL/0"},{"type":"type","title":"Evision.Stereo.enum/0","doc":"","ref":"Evision.Stereo.html#t:enum/0"},{"type":"type","title":"Evision.Stereo.t/0","doc":"Type that represents an `Stereo` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Stereo.html#t:t/0"},{"type":"module","title":"Evision.Stereo.MatchQuasiDense","doc":"","ref":"Evision.Stereo.MatchQuasiDense.html"},{"type":"function","title":"Evision.Stereo.MatchQuasiDense.apply/1","doc":"","ref":"Evision.Stereo.MatchQuasiDense.html#apply/1"},{"type":"function","title":"Evision.Stereo.MatchQuasiDense.apply/2","doc":"apply\n\n##### Positional Arguments\n- **self**: `Evision.Stereo.MatchQuasiDense.t()`\n- **rhs**: `MatchQuasiDense`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\napply(rhs) -> retval\n```","ref":"Evision.Stereo.MatchQuasiDense.html#apply/2"},{"type":"function","title":"Evision.Stereo.MatchQuasiDense.get_corr/1","doc":"","ref":"Evision.Stereo.MatchQuasiDense.html#get_corr/1"},{"type":"function","title":"Evision.Stereo.MatchQuasiDense.get_p0/1","doc":"","ref":"Evision.Stereo.MatchQuasiDense.html#get_p0/1"},{"type":"function","title":"Evision.Stereo.MatchQuasiDense.get_p1/1","doc":"","ref":"Evision.Stereo.MatchQuasiDense.html#get_p1/1"},{"type":"function","title":"Evision.Stereo.MatchQuasiDense.matchQuasiDense/0","doc":"MatchQuasiDense\n##### Return\n- **self**: `MatchQuasiDense`\n\nPython prototype (for reference only):\n```python3\nMatchQuasiDense() ->  \n```","ref":"Evision.Stereo.MatchQuasiDense.html#matchQuasiDense/0"},{"type":"function","title":"Evision.Stereo.MatchQuasiDense.matchQuasiDense/1","doc":"","ref":"Evision.Stereo.MatchQuasiDense.html#matchQuasiDense/1"},{"type":"function","title":"Evision.Stereo.MatchQuasiDense.set_corr/2","doc":"","ref":"Evision.Stereo.MatchQuasiDense.html#set_corr/2"},{"type":"function","title":"Evision.Stereo.MatchQuasiDense.set_p0/2","doc":"","ref":"Evision.Stereo.MatchQuasiDense.html#set_p0/2"},{"type":"function","title":"Evision.Stereo.MatchQuasiDense.set_p1/2","doc":"","ref":"Evision.Stereo.MatchQuasiDense.html#set_p1/2"},{"type":"type","title":"Evision.Stereo.MatchQuasiDense.t/0","doc":"Type that represents an `Stereo.MatchQuasiDense` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Stereo.MatchQuasiDense.html#t:t/0"},{"type":"module","title":"Evision.Stereo.PropagationParameters","doc":"","ref":"Evision.Stereo.PropagationParameters.html"},{"type":"function","title":"Evision.Stereo.PropagationParameters.get_borderX/1","doc":"","ref":"Evision.Stereo.PropagationParameters.html#get_borderX/1"},{"type":"function","title":"Evision.Stereo.PropagationParameters.get_borderY/1","doc":"","ref":"Evision.Stereo.PropagationParameters.html#get_borderY/1"},{"type":"function","title":"Evision.Stereo.PropagationParameters.get_correlationThreshold/1","doc":"","ref":"Evision.Stereo.PropagationParameters.html#get_correlationThreshold/1"},{"type":"function","title":"Evision.Stereo.PropagationParameters.get_corrWinSizeX/1","doc":"","ref":"Evision.Stereo.PropagationParameters.html#get_corrWinSizeX/1"},{"type":"function","title":"Evision.Stereo.PropagationParameters.get_corrWinSizeY/1","doc":"","ref":"Evision.Stereo.PropagationParameters.html#get_corrWinSizeY/1"},{"type":"function","title":"Evision.Stereo.PropagationParameters.get_disparityGradient/1","doc":"","ref":"Evision.Stereo.PropagationParameters.html#get_disparityGradient/1"},{"type":"function","title":"Evision.Stereo.PropagationParameters.get_gftMaxNumFeatures/1","doc":"","ref":"Evision.Stereo.PropagationParameters.html#get_gftMaxNumFeatures/1"},{"type":"function","title":"Evision.Stereo.PropagationParameters.get_gftMinSeperationDist/1","doc":"","ref":"Evision.Stereo.PropagationParameters.html#get_gftMinSeperationDist/1"},{"type":"function","title":"Evision.Stereo.PropagationParameters.get_gftQualityThres/1","doc":"","ref":"Evision.Stereo.PropagationParameters.html#get_gftQualityThres/1"},{"type":"function","title":"Evision.Stereo.PropagationParameters.get_lkPyrLvl/1","doc":"","ref":"Evision.Stereo.PropagationParameters.html#get_lkPyrLvl/1"},{"type":"function","title":"Evision.Stereo.PropagationParameters.get_lkTemplateSize/1","doc":"","ref":"Evision.Stereo.PropagationParameters.html#get_lkTemplateSize/1"},{"type":"function","title":"Evision.Stereo.PropagationParameters.get_lkTermParam1/1","doc":"","ref":"Evision.Stereo.PropagationParameters.html#get_lkTermParam1/1"},{"type":"function","title":"Evision.Stereo.PropagationParameters.get_lkTermParam2/1","doc":"","ref":"Evision.Stereo.PropagationParameters.html#get_lkTermParam2/1"},{"type":"function","title":"Evision.Stereo.PropagationParameters.get_neighborhoodSize/1","doc":"","ref":"Evision.Stereo.PropagationParameters.html#get_neighborhoodSize/1"},{"type":"function","title":"Evision.Stereo.PropagationParameters.get_textrureThreshold/1","doc":"","ref":"Evision.Stereo.PropagationParameters.html#get_textrureThreshold/1"},{"type":"function","title":"Evision.Stereo.PropagationParameters.set_borderX/2","doc":"","ref":"Evision.Stereo.PropagationParameters.html#set_borderX/2"},{"type":"function","title":"Evision.Stereo.PropagationParameters.set_borderY/2","doc":"","ref":"Evision.Stereo.PropagationParameters.html#set_borderY/2"},{"type":"function","title":"Evision.Stereo.PropagationParameters.set_correlationThreshold/2","doc":"","ref":"Evision.Stereo.PropagationParameters.html#set_correlationThreshold/2"},{"type":"function","title":"Evision.Stereo.PropagationParameters.set_corrWinSizeX/2","doc":"","ref":"Evision.Stereo.PropagationParameters.html#set_corrWinSizeX/2"},{"type":"function","title":"Evision.Stereo.PropagationParameters.set_corrWinSizeY/2","doc":"","ref":"Evision.Stereo.PropagationParameters.html#set_corrWinSizeY/2"},{"type":"function","title":"Evision.Stereo.PropagationParameters.set_disparityGradient/2","doc":"","ref":"Evision.Stereo.PropagationParameters.html#set_disparityGradient/2"},{"type":"function","title":"Evision.Stereo.PropagationParameters.set_gftMaxNumFeatures/2","doc":"","ref":"Evision.Stereo.PropagationParameters.html#set_gftMaxNumFeatures/2"},{"type":"function","title":"Evision.Stereo.PropagationParameters.set_gftMinSeperationDist/2","doc":"","ref":"Evision.Stereo.PropagationParameters.html#set_gftMinSeperationDist/2"},{"type":"function","title":"Evision.Stereo.PropagationParameters.set_gftQualityThres/2","doc":"","ref":"Evision.Stereo.PropagationParameters.html#set_gftQualityThres/2"},{"type":"function","title":"Evision.Stereo.PropagationParameters.set_lkPyrLvl/2","doc":"","ref":"Evision.Stereo.PropagationParameters.html#set_lkPyrLvl/2"},{"type":"function","title":"Evision.Stereo.PropagationParameters.set_lkTemplateSize/2","doc":"","ref":"Evision.Stereo.PropagationParameters.html#set_lkTemplateSize/2"},{"type":"function","title":"Evision.Stereo.PropagationParameters.set_lkTermParam1/2","doc":"","ref":"Evision.Stereo.PropagationParameters.html#set_lkTermParam1/2"},{"type":"function","title":"Evision.Stereo.PropagationParameters.set_lkTermParam2/2","doc":"","ref":"Evision.Stereo.PropagationParameters.html#set_lkTermParam2/2"},{"type":"function","title":"Evision.Stereo.PropagationParameters.set_neighborhoodSize/2","doc":"","ref":"Evision.Stereo.PropagationParameters.html#set_neighborhoodSize/2"},{"type":"function","title":"Evision.Stereo.PropagationParameters.set_textrureThreshold/2","doc":"","ref":"Evision.Stereo.PropagationParameters.html#set_textrureThreshold/2"},{"type":"type","title":"Evision.Stereo.PropagationParameters.t/0","doc":"Type that represents an `Stereo.PropagationParameters` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Stereo.PropagationParameters.html#t:t/0"},{"type":"module","title":"Evision.Stereo.QuasiDenseStereo","doc":"","ref":"Evision.Stereo.QuasiDenseStereo.html"},{"type":"function","title":"Evision.Stereo.QuasiDenseStereo.create/1","doc":"create\n\n##### Positional Arguments\n- **monoImgSize**: `Size`\n\n##### Keyword Arguments\n- **paramFilepath**: `String`.\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ncreate(monoImgSize[, paramFilepath]) -> retval\n```","ref":"Evision.Stereo.QuasiDenseStereo.html#create/1"},{"type":"function","title":"Evision.Stereo.QuasiDenseStereo.create/2","doc":"create\n\n##### Positional Arguments\n- **monoImgSize**: `Size`\n\n##### Keyword Arguments\n- **paramFilepath**: `String`.\n\n##### Return\n- **retval**: `cv::Ptr `\n\nPython prototype (for reference only):\n```python3\ncreate(monoImgSize[, paramFilepath]) -> retval\n```","ref":"Evision.Stereo.QuasiDenseStereo.html#create/2"},{"type":"function","title":"Evision.Stereo.QuasiDenseStereo.get_Param/1","doc":"","ref":"Evision.Stereo.QuasiDenseStereo.html#get_Param/1"},{"type":"function","title":"Evision.Stereo.QuasiDenseStereo.getDenseMatches/1","doc":"Get The dense corresponding points.\n\n##### Positional Arguments\n- **self**: `Evision.Stereo.QuasiDenseStereo.t()`\n\n##### Return\n- **denseMatches**: `[MatchQuasiDense]`.\n\n  A vector containing all dense matches.\n\n**Note**: The method clears the denseMatches vector.\n**Note**: The returned Match elements inside the sMatches vector, do not use corr member.\n\nPython prototype (for reference only):\n```python3\ngetDenseMatches() -> denseMatches\n```","ref":"Evision.Stereo.QuasiDenseStereo.html#getDenseMatches/1"},{"type":"function","title":"Evision.Stereo.QuasiDenseStereo.getDisparity/1","doc":"Compute and return the disparity map based on the correspondences found in the \"process\" method.\n\n##### Positional Arguments\n- **self**: `Evision.Stereo.QuasiDenseStereo.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n**Note**: Default level is 50\n@return cv::Mat containing a the disparity image in grayscale.\n@sa computeDisparity\n@sa quantizeDisparity\n\nPython prototype (for reference only):\n```python3\ngetDisparity() -> retval\n```","ref":"Evision.Stereo.QuasiDenseStereo.html#getDisparity/1"},{"type":"function","title":"Evision.Stereo.QuasiDenseStereo.getMatch/1","doc":"","ref":"Evision.Stereo.QuasiDenseStereo.html#getMatch/1"},{"type":"function","title":"Evision.Stereo.QuasiDenseStereo.getMatch/3","doc":"Specify pixel coordinates in the left image and get its corresponding location in the right image.\n\n##### Positional Arguments\n- **self**: `Evision.Stereo.QuasiDenseStereo.t()`\n- **x**: `integer()`.\n\n  The x pixel coordinate in the left image channel.\n\n- **y**: `integer()`.\n\n  The y pixel coordinate in the left image channel.\n\n##### Return\n- **retval**: `cv::Point2f`\n\n@retval cv::Point(x, y) The location of the corresponding pixel in the right image.\n@retval cv::Point(0, 0) (NO_MATCH)  if no match is found in the right image for the specified pixel location in the left image.\n**Note**: This method should be always called after process, otherwise the matches will not be correct.\n\nPython prototype (for reference only):\n```python3\ngetMatch(x, y) -> retval\n```","ref":"Evision.Stereo.QuasiDenseStereo.html#getMatch/3"},{"type":"function","title":"Evision.Stereo.QuasiDenseStereo.getSparseMatches/1","doc":"Get The sparse corresponding points.\n\n##### Positional Arguments\n- **self**: `Evision.Stereo.QuasiDenseStereo.t()`\n\n##### Return\n- **sMatches**: `[MatchQuasiDense]`.\n\n  A vector containing all sparse correspondences.\n\n**Note**: The method clears the sMatches vector.\n**Note**: The returned Match elements inside the sMatches vector, do not use corr member.\n\nPython prototype (for reference only):\n```python3\ngetSparseMatches() -> sMatches\n```","ref":"Evision.Stereo.QuasiDenseStereo.html#getSparseMatches/1"},{"type":"function","title":"Evision.Stereo.QuasiDenseStereo.loadParameters/1","doc":"","ref":"Evision.Stereo.QuasiDenseStereo.html#loadParameters/1"},{"type":"function","title":"Evision.Stereo.QuasiDenseStereo.loadParameters/2","doc":"Load a file containing the configuration parameters of the class.\n\n##### Positional Arguments\n- **self**: `Evision.Stereo.QuasiDenseStereo.t()`\n- **filepath**: `String`.\n\n  The location of the .YAML file containing the configuration parameters.\n\n##### Return\n- **retval**: `integer()`\n\n**Note**: default value is an empty string in which case the default parameters will be loaded.\n@retval 1: If the path is not empty and the program loaded the parameters successfully.\n@retval 0: If the path is empty and the program loaded default parameters.\n@retval -1: If the file location is not valid or the program could not open the file and\n loaded default parameters from defaults.hpp.\n**Note**: The method is automatically called in the constructor and configures the class.\n**Note**: Loading different parameters will have an effect on the output. This is useful for tuning\n in case of video processing.\n@sa loadParameters\n\nPython prototype (for reference only):\n```python3\nloadParameters(filepath) -> retval\n```","ref":"Evision.Stereo.QuasiDenseStereo.html#loadParameters/2"},{"type":"function","title":"Evision.Stereo.QuasiDenseStereo.process/1","doc":"","ref":"Evision.Stereo.QuasiDenseStereo.html#process/1"},{"type":"function","title":"Evision.Stereo.QuasiDenseStereo.process/3","doc":"Main process of the algorithm. This method computes the sparse seeds and then densifies them.\n\n##### Positional Arguments\n- **self**: `Evision.Stereo.QuasiDenseStereo.t()`\n- **imgLeft**: `Evision.Mat`.\n\n  The left Channel of a stereo image pair.\n\n- **imgRight**: `Evision.Mat`.\n\n  The right Channel of a stereo image pair.\n\n Initially input images are converted to gray-scale and then the sparseMatching method\n is called to obtain the sparse stereo. Finally quasiDenseMatching is called to densify the corresponding\n points.\n**Note**: If input images are in color, the method assumes that are BGR and converts them to grayscale.\n@sa sparseMatching\n@sa quasiDenseMatching\n\nPython prototype (for reference only):\n```python3\nprocess(imgLeft, imgRight) -> None\n```","ref":"Evision.Stereo.QuasiDenseStereo.html#process/3"},{"type":"function","title":"Evision.Stereo.QuasiDenseStereo.saveParameters/1","doc":"","ref":"Evision.Stereo.QuasiDenseStereo.html#saveParameters/1"},{"type":"function","title":"Evision.Stereo.QuasiDenseStereo.saveParameters/2","doc":"Save a file containing all the configuration parameters the class is currently set to.\n\n##### Positional Arguments\n- **self**: `Evision.Stereo.QuasiDenseStereo.t()`\n- **filepath**: `String`.\n\n  The location to store the parameters file.\n\n##### Return\n- **retval**: `integer()`\n\n**Note**: Calling this method with no arguments will result in storing class parameters to a file\n names \"qds_parameters.yaml\" in the root project folder.\n**Note**: This method can be used to generate a template file for tuning the class.\n@sa loadParameters\n\nPython prototype (for reference only):\n```python3\nsaveParameters(filepath) -> retval\n```","ref":"Evision.Stereo.QuasiDenseStereo.html#saveParameters/2"},{"type":"function","title":"Evision.Stereo.QuasiDenseStereo.set_Param/2","doc":"","ref":"Evision.Stereo.QuasiDenseStereo.html#set_Param/2"},{"type":"type","title":"Evision.Stereo.QuasiDenseStereo.t/0","doc":"Type that represents an `Stereo.QuasiDenseStereo` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Stereo.QuasiDenseStereo.html#t:t/0"},{"type":"module","title":"Evision.Stereo.StereoBinaryBM","doc":"","ref":"Evision.Stereo.StereoBinaryBM.html"},{"type":"function","title":"Evision.Stereo.StereoBinaryBM.cv_PREFILTER_NORMALIZED_RESPONSE/0","doc":"","ref":"Evision.Stereo.StereoBinaryBM.html#cv_PREFILTER_NORMALIZED_RESPONSE/0"},{"type":"function","title":"Evision.Stereo.StereoBinaryBM.cv_PREFILTER_XSOBEL/0","doc":"","ref":"Evision.Stereo.StereoBinaryBM.html#cv_PREFILTER_XSOBEL/0"},{"type":"type","title":"Evision.Stereo.StereoBinaryBM.enum/0","doc":"","ref":"Evision.Stereo.StereoBinaryBM.html#t:enum/0"},{"type":"module","title":"Evision.Stereo.StereoBinarySGBM","doc":"","ref":"Evision.Stereo.StereoBinarySGBM.html"},{"type":"function","title":"Evision.Stereo.StereoBinarySGBM.cv_MODE_HH/0","doc":"","ref":"Evision.Stereo.StereoBinarySGBM.html#cv_MODE_HH/0"},{"type":"function","title":"Evision.Stereo.StereoBinarySGBM.cv_MODE_SGBM/0","doc":"","ref":"Evision.Stereo.StereoBinarySGBM.html#cv_MODE_SGBM/0"},{"type":"type","title":"Evision.Stereo.StereoBinarySGBM.enum/0","doc":"","ref":"Evision.Stereo.StereoBinarySGBM.html#t:enum/0"},{"type":"module","title":"Evision.Stereo.StereoMatcher","doc":"","ref":"Evision.Stereo.StereoMatcher.html"},{"type":"function","title":"Evision.Stereo.StereoMatcher.cv_DISP_SCALE/0","doc":"","ref":"Evision.Stereo.StereoMatcher.html#cv_DISP_SCALE/0"},{"type":"function","title":"Evision.Stereo.StereoMatcher.cv_DISP_SHIFT/0","doc":"","ref":"Evision.Stereo.StereoMatcher.html#cv_DISP_SHIFT/0"},{"type":"type","title":"Evision.Stereo.StereoMatcher.enum/0","doc":"","ref":"Evision.Stereo.StereoMatcher.html#t:enum/0"},{"type":"module","title":"Evision.StereoBM","doc":"","ref":"Evision.StereoBM.html"},{"type":"function","title":"Evision.StereoBM.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.StereoBM.html#clear/1"},{"type":"function","title":"Evision.StereoBM.compute/1","doc":"","ref":"Evision.StereoBM.html#compute/1"},{"type":"function","title":"Evision.StereoBM.compute/3","doc":"Computes disparity map for the specified stereo pair\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n- **left**: `Evision.Mat`.\n\n  Left 8-bit single-channel image.\n\n- **right**: `Evision.Mat`.\n\n  Right image of the same size and the same type as the left one.\n\n##### Return\n- **disparity**: `Evision.Mat.t()`.\n\n  Output disparity map. It has the same size as the input images. Some algorithms,\n  like StereoBM or StereoSGBM compute 16-bit fixed-point disparity map (where each disparity value\n  has 4 fractional bits), whereas other algorithms output 32-bit floating-point disparity map.\n\nPython prototype (for reference only):\n```python3\ncompute(left, right[, disparity]) -> disparity\n```","ref":"Evision.StereoBM.html#compute/3"},{"type":"function","title":"Evision.StereoBM.compute/4","doc":"Computes disparity map for the specified stereo pair\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n- **left**: `Evision.Mat`.\n\n  Left 8-bit single-channel image.\n\n- **right**: `Evision.Mat`.\n\n  Right image of the same size and the same type as the left one.\n\n##### Return\n- **disparity**: `Evision.Mat.t()`.\n\n  Output disparity map. It has the same size as the input images. Some algorithms,\n  like StereoBM or StereoSGBM compute 16-bit fixed-point disparity map (where each disparity value\n  has 4 fractional bits), whereas other algorithms output 32-bit floating-point disparity map.\n\nPython prototype (for reference only):\n```python3\ncompute(left, right[, disparity]) -> disparity\n```","ref":"Evision.StereoBM.html#compute/4"},{"type":"function","title":"Evision.StereoBM.create/0","doc":"Creates StereoBM object\n##### Keyword Arguments\n- **numDisparities**: `integer()`.\n\n  the disparity search range. For each pixel algorithm will find the best\n  disparity from 0 (default minimum disparity) to numDisparities. The search range can then be\n  shifted by changing the minimum disparity.\n\n- **blockSize**: `integer()`.\n\n  the linear size of the blocks compared by the algorithm. The size should be odd\n  (as the block is centered at the current pixel). Larger block size implies smoother, though less\n  accurate disparity map. Smaller block size gives more detailed disparity map, but there is higher\n  chance for algorithm to find a wrong correspondence.\n\n##### Return\n- **retval**: `Evision.StereoBM.t()`\n\nThe function create StereoBM object. You can then call StereoBM::compute() to compute disparity for\na specific stereo pair.\n\nPython prototype (for reference only):\n```python3\ncreate([, numDisparities[, blockSize]]) -> retval\n```","ref":"Evision.StereoBM.html#create/0"},{"type":"function","title":"Evision.StereoBM.create/1","doc":"Creates StereoBM object\n##### Keyword Arguments\n- **numDisparities**: `integer()`.\n\n  the disparity search range. For each pixel algorithm will find the best\n  disparity from 0 (default minimum disparity) to numDisparities. The search range can then be\n  shifted by changing the minimum disparity.\n\n- **blockSize**: `integer()`.\n\n  the linear size of the blocks compared by the algorithm. The size should be odd\n  (as the block is centered at the current pixel). Larger block size implies smoother, though less\n  accurate disparity map. Smaller block size gives more detailed disparity map, but there is higher\n  chance for algorithm to find a wrong correspondence.\n\n##### Return\n- **retval**: `Evision.StereoBM.t()`\n\nThe function create StereoBM object. You can then call StereoBM::compute() to compute disparity for\na specific stereo pair.\n\nPython prototype (for reference only):\n```python3\ncreate([, numDisparities[, blockSize]]) -> retval\n```","ref":"Evision.StereoBM.html#create/1"},{"type":"function","title":"Evision.StereoBM.cv_PREFILTER_NORMALIZED_RESPONSE/0","doc":"","ref":"Evision.StereoBM.html#cv_PREFILTER_NORMALIZED_RESPONSE/0"},{"type":"function","title":"Evision.StereoBM.cv_PREFILTER_XSOBEL/0","doc":"","ref":"Evision.StereoBM.html#cv_PREFILTER_XSOBEL/0"},{"type":"function","title":"Evision.StereoBM.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.StereoBM.html#empty/1"},{"type":"function","title":"Evision.StereoBM.getBlockSize/1","doc":"getBlockSize\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetBlockSize() -> retval\n```","ref":"Evision.StereoBM.html#getBlockSize/1"},{"type":"function","title":"Evision.StereoBM.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.StereoBM.html#getDefaultName/1"},{"type":"function","title":"Evision.StereoBM.getDisp12MaxDiff/1","doc":"getDisp12MaxDiff\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetDisp12MaxDiff() -> retval\n```","ref":"Evision.StereoBM.html#getDisp12MaxDiff/1"},{"type":"function","title":"Evision.StereoBM.getMinDisparity/1","doc":"getMinDisparity\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMinDisparity() -> retval\n```","ref":"Evision.StereoBM.html#getMinDisparity/1"},{"type":"function","title":"Evision.StereoBM.getNumDisparities/1","doc":"getNumDisparities\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNumDisparities() -> retval\n```","ref":"Evision.StereoBM.html#getNumDisparities/1"},{"type":"function","title":"Evision.StereoBM.getPreFilterCap/1","doc":"getPreFilterCap\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetPreFilterCap() -> retval\n```","ref":"Evision.StereoBM.html#getPreFilterCap/1"},{"type":"function","title":"Evision.StereoBM.getPreFilterSize/1","doc":"getPreFilterSize\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetPreFilterSize() -> retval\n```","ref":"Evision.StereoBM.html#getPreFilterSize/1"},{"type":"function","title":"Evision.StereoBM.getPreFilterType/1","doc":"getPreFilterType\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetPreFilterType() -> retval\n```","ref":"Evision.StereoBM.html#getPreFilterType/1"},{"type":"function","title":"Evision.StereoBM.getROI1/1","doc":"getROI1\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n\n##### Return\n- **retval**: `Rect`\n\nPython prototype (for reference only):\n```python3\ngetROI1() -> retval\n```","ref":"Evision.StereoBM.html#getROI1/1"},{"type":"function","title":"Evision.StereoBM.getROI2/1","doc":"getROI2\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n\n##### Return\n- **retval**: `Rect`\n\nPython prototype (for reference only):\n```python3\ngetROI2() -> retval\n```","ref":"Evision.StereoBM.html#getROI2/1"},{"type":"function","title":"Evision.StereoBM.getSmallerBlockSize/1","doc":"getSmallerBlockSize\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetSmallerBlockSize() -> retval\n```","ref":"Evision.StereoBM.html#getSmallerBlockSize/1"},{"type":"function","title":"Evision.StereoBM.getSpeckleRange/1","doc":"getSpeckleRange\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetSpeckleRange() -> retval\n```","ref":"Evision.StereoBM.html#getSpeckleRange/1"},{"type":"function","title":"Evision.StereoBM.getSpeckleWindowSize/1","doc":"getSpeckleWindowSize\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetSpeckleWindowSize() -> retval\n```","ref":"Evision.StereoBM.html#getSpeckleWindowSize/1"},{"type":"function","title":"Evision.StereoBM.getTextureThreshold/1","doc":"getTextureThreshold\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetTextureThreshold() -> retval\n```","ref":"Evision.StereoBM.html#getTextureThreshold/1"},{"type":"function","title":"Evision.StereoBM.getUniquenessRatio/1","doc":"getUniquenessRatio\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetUniquenessRatio() -> retval\n```","ref":"Evision.StereoBM.html#getUniquenessRatio/1"},{"type":"function","title":"Evision.StereoBM.read/1","doc":"","ref":"Evision.StereoBM.html#read/1"},{"type":"function","title":"Evision.StereoBM.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.StereoBM.html#read/2"},{"type":"function","title":"Evision.StereoBM.save/1","doc":"","ref":"Evision.StereoBM.html#save/1"},{"type":"function","title":"Evision.StereoBM.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.StereoBM.html#save/2"},{"type":"function","title":"Evision.StereoBM.setBlockSize/1","doc":"","ref":"Evision.StereoBM.html#setBlockSize/1"},{"type":"function","title":"Evision.StereoBM.setBlockSize/2","doc":"setBlockSize\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n- **blockSize**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetBlockSize(blockSize) -> None\n```","ref":"Evision.StereoBM.html#setBlockSize/2"},{"type":"function","title":"Evision.StereoBM.setDisp12MaxDiff/1","doc":"","ref":"Evision.StereoBM.html#setDisp12MaxDiff/1"},{"type":"function","title":"Evision.StereoBM.setDisp12MaxDiff/2","doc":"setDisp12MaxDiff\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n- **disp12MaxDiff**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetDisp12MaxDiff(disp12MaxDiff) -> None\n```","ref":"Evision.StereoBM.html#setDisp12MaxDiff/2"},{"type":"function","title":"Evision.StereoBM.setMinDisparity/1","doc":"","ref":"Evision.StereoBM.html#setMinDisparity/1"},{"type":"function","title":"Evision.StereoBM.setMinDisparity/2","doc":"setMinDisparity\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n- **minDisparity**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMinDisparity(minDisparity) -> None\n```","ref":"Evision.StereoBM.html#setMinDisparity/2"},{"type":"function","title":"Evision.StereoBM.setNumDisparities/1","doc":"","ref":"Evision.StereoBM.html#setNumDisparities/1"},{"type":"function","title":"Evision.StereoBM.setNumDisparities/2","doc":"setNumDisparities\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n- **numDisparities**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNumDisparities(numDisparities) -> None\n```","ref":"Evision.StereoBM.html#setNumDisparities/2"},{"type":"function","title":"Evision.StereoBM.setPreFilterCap/1","doc":"","ref":"Evision.StereoBM.html#setPreFilterCap/1"},{"type":"function","title":"Evision.StereoBM.setPreFilterCap/2","doc":"setPreFilterCap\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n- **preFilterCap**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetPreFilterCap(preFilterCap) -> None\n```","ref":"Evision.StereoBM.html#setPreFilterCap/2"},{"type":"function","title":"Evision.StereoBM.setPreFilterSize/1","doc":"","ref":"Evision.StereoBM.html#setPreFilterSize/1"},{"type":"function","title":"Evision.StereoBM.setPreFilterSize/2","doc":"setPreFilterSize\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n- **preFilterSize**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetPreFilterSize(preFilterSize) -> None\n```","ref":"Evision.StereoBM.html#setPreFilterSize/2"},{"type":"function","title":"Evision.StereoBM.setPreFilterType/1","doc":"","ref":"Evision.StereoBM.html#setPreFilterType/1"},{"type":"function","title":"Evision.StereoBM.setPreFilterType/2","doc":"setPreFilterType\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n- **preFilterType**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetPreFilterType(preFilterType) -> None\n```","ref":"Evision.StereoBM.html#setPreFilterType/2"},{"type":"function","title":"Evision.StereoBM.setROI1/1","doc":"","ref":"Evision.StereoBM.html#setROI1/1"},{"type":"function","title":"Evision.StereoBM.setROI1/2","doc":"setROI1\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n- **roi1**: `Rect`\n\nPython prototype (for reference only):\n```python3\nsetROI1(roi1) -> None\n```","ref":"Evision.StereoBM.html#setROI1/2"},{"type":"function","title":"Evision.StereoBM.setROI2/1","doc":"","ref":"Evision.StereoBM.html#setROI2/1"},{"type":"function","title":"Evision.StereoBM.setROI2/2","doc":"setROI2\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n- **roi2**: `Rect`\n\nPython prototype (for reference only):\n```python3\nsetROI2(roi2) -> None\n```","ref":"Evision.StereoBM.html#setROI2/2"},{"type":"function","title":"Evision.StereoBM.setSmallerBlockSize/1","doc":"","ref":"Evision.StereoBM.html#setSmallerBlockSize/1"},{"type":"function","title":"Evision.StereoBM.setSmallerBlockSize/2","doc":"setSmallerBlockSize\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n- **blockSize**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetSmallerBlockSize(blockSize) -> None\n```","ref":"Evision.StereoBM.html#setSmallerBlockSize/2"},{"type":"function","title":"Evision.StereoBM.setSpeckleRange/1","doc":"","ref":"Evision.StereoBM.html#setSpeckleRange/1"},{"type":"function","title":"Evision.StereoBM.setSpeckleRange/2","doc":"setSpeckleRange\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n- **speckleRange**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetSpeckleRange(speckleRange) -> None\n```","ref":"Evision.StereoBM.html#setSpeckleRange/2"},{"type":"function","title":"Evision.StereoBM.setSpeckleWindowSize/1","doc":"","ref":"Evision.StereoBM.html#setSpeckleWindowSize/1"},{"type":"function","title":"Evision.StereoBM.setSpeckleWindowSize/2","doc":"setSpeckleWindowSize\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n- **speckleWindowSize**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetSpeckleWindowSize(speckleWindowSize) -> None\n```","ref":"Evision.StereoBM.html#setSpeckleWindowSize/2"},{"type":"function","title":"Evision.StereoBM.setTextureThreshold/1","doc":"","ref":"Evision.StereoBM.html#setTextureThreshold/1"},{"type":"function","title":"Evision.StereoBM.setTextureThreshold/2","doc":"setTextureThreshold\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n- **textureThreshold**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetTextureThreshold(textureThreshold) -> None\n```","ref":"Evision.StereoBM.html#setTextureThreshold/2"},{"type":"function","title":"Evision.StereoBM.setUniquenessRatio/1","doc":"","ref":"Evision.StereoBM.html#setUniquenessRatio/1"},{"type":"function","title":"Evision.StereoBM.setUniquenessRatio/2","doc":"setUniquenessRatio\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n- **uniquenessRatio**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetUniquenessRatio(uniquenessRatio) -> None\n```","ref":"Evision.StereoBM.html#setUniquenessRatio/2"},{"type":"function","title":"Evision.StereoBM.write/1","doc":"","ref":"Evision.StereoBM.html#write/1"},{"type":"function","title":"Evision.StereoBM.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.StereoBM.html#write/2"},{"type":"function","title":"Evision.StereoBM.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.StereoBM.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.StereoBM.html#write/3"},{"type":"type","title":"Evision.StereoBM.enum/0","doc":"","ref":"Evision.StereoBM.html#t:enum/0"},{"type":"type","title":"Evision.StereoBM.t/0","doc":"Type that represents an `StereoBM` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.StereoBM.html#t:t/0"},{"type":"module","title":"Evision.StereoMatcher","doc":"","ref":"Evision.StereoMatcher.html"},{"type":"function","title":"Evision.StereoMatcher.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.StereoMatcher.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.StereoMatcher.html#clear/1"},{"type":"function","title":"Evision.StereoMatcher.compute/1","doc":"","ref":"Evision.StereoMatcher.html#compute/1"},{"type":"function","title":"Evision.StereoMatcher.compute/3","doc":"Computes disparity map for the specified stereo pair\n\n##### Positional Arguments\n- **self**: `Evision.StereoMatcher.t()`\n- **left**: `Evision.Mat`.\n\n  Left 8-bit single-channel image.\n\n- **right**: `Evision.Mat`.\n\n  Right image of the same size and the same type as the left one.\n\n##### Return\n- **disparity**: `Evision.Mat.t()`.\n\n  Output disparity map. It has the same size as the input images. Some algorithms,\n  like StereoBM or StereoSGBM compute 16-bit fixed-point disparity map (where each disparity value\n  has 4 fractional bits), whereas other algorithms output 32-bit floating-point disparity map.\n\nPython prototype (for reference only):\n```python3\ncompute(left, right[, disparity]) -> disparity\n```","ref":"Evision.StereoMatcher.html#compute/3"},{"type":"function","title":"Evision.StereoMatcher.compute/4","doc":"Computes disparity map for the specified stereo pair\n\n##### Positional Arguments\n- **self**: `Evision.StereoMatcher.t()`\n- **left**: `Evision.Mat`.\n\n  Left 8-bit single-channel image.\n\n- **right**: `Evision.Mat`.\n\n  Right image of the same size and the same type as the left one.\n\n##### Return\n- **disparity**: `Evision.Mat.t()`.\n\n  Output disparity map. It has the same size as the input images. Some algorithms,\n  like StereoBM or StereoSGBM compute 16-bit fixed-point disparity map (where each disparity value\n  has 4 fractional bits), whereas other algorithms output 32-bit floating-point disparity map.\n\nPython prototype (for reference only):\n```python3\ncompute(left, right[, disparity]) -> disparity\n```","ref":"Evision.StereoMatcher.html#compute/4"},{"type":"function","title":"Evision.StereoMatcher.cv_DISP_SCALE/0","doc":"","ref":"Evision.StereoMatcher.html#cv_DISP_SCALE/0"},{"type":"function","title":"Evision.StereoMatcher.cv_DISP_SHIFT/0","doc":"","ref":"Evision.StereoMatcher.html#cv_DISP_SHIFT/0"},{"type":"function","title":"Evision.StereoMatcher.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.StereoMatcher.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.StereoMatcher.html#empty/1"},{"type":"function","title":"Evision.StereoMatcher.getBlockSize/1","doc":"getBlockSize\n\n##### Positional Arguments\n- **self**: `Evision.StereoMatcher.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetBlockSize() -> retval\n```","ref":"Evision.StereoMatcher.html#getBlockSize/1"},{"type":"function","title":"Evision.StereoMatcher.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.StereoMatcher.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.StereoMatcher.html#getDefaultName/1"},{"type":"function","title":"Evision.StereoMatcher.getDisp12MaxDiff/1","doc":"getDisp12MaxDiff\n\n##### Positional Arguments\n- **self**: `Evision.StereoMatcher.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetDisp12MaxDiff() -> retval\n```","ref":"Evision.StereoMatcher.html#getDisp12MaxDiff/1"},{"type":"function","title":"Evision.StereoMatcher.getMinDisparity/1","doc":"getMinDisparity\n\n##### Positional Arguments\n- **self**: `Evision.StereoMatcher.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMinDisparity() -> retval\n```","ref":"Evision.StereoMatcher.html#getMinDisparity/1"},{"type":"function","title":"Evision.StereoMatcher.getNumDisparities/1","doc":"getNumDisparities\n\n##### Positional Arguments\n- **self**: `Evision.StereoMatcher.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNumDisparities() -> retval\n```","ref":"Evision.StereoMatcher.html#getNumDisparities/1"},{"type":"function","title":"Evision.StereoMatcher.getSpeckleRange/1","doc":"getSpeckleRange\n\n##### Positional Arguments\n- **self**: `Evision.StereoMatcher.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetSpeckleRange() -> retval\n```","ref":"Evision.StereoMatcher.html#getSpeckleRange/1"},{"type":"function","title":"Evision.StereoMatcher.getSpeckleWindowSize/1","doc":"getSpeckleWindowSize\n\n##### Positional Arguments\n- **self**: `Evision.StereoMatcher.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetSpeckleWindowSize() -> retval\n```","ref":"Evision.StereoMatcher.html#getSpeckleWindowSize/1"},{"type":"function","title":"Evision.StereoMatcher.read/1","doc":"","ref":"Evision.StereoMatcher.html#read/1"},{"type":"function","title":"Evision.StereoMatcher.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.StereoMatcher.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.StereoMatcher.html#read/2"},{"type":"function","title":"Evision.StereoMatcher.save/1","doc":"","ref":"Evision.StereoMatcher.html#save/1"},{"type":"function","title":"Evision.StereoMatcher.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.StereoMatcher.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.StereoMatcher.html#save/2"},{"type":"function","title":"Evision.StereoMatcher.setBlockSize/1","doc":"","ref":"Evision.StereoMatcher.html#setBlockSize/1"},{"type":"function","title":"Evision.StereoMatcher.setBlockSize/2","doc":"setBlockSize\n\n##### Positional Arguments\n- **self**: `Evision.StereoMatcher.t()`\n- **blockSize**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetBlockSize(blockSize) -> None\n```","ref":"Evision.StereoMatcher.html#setBlockSize/2"},{"type":"function","title":"Evision.StereoMatcher.setDisp12MaxDiff/1","doc":"","ref":"Evision.StereoMatcher.html#setDisp12MaxDiff/1"},{"type":"function","title":"Evision.StereoMatcher.setDisp12MaxDiff/2","doc":"setDisp12MaxDiff\n\n##### Positional Arguments\n- **self**: `Evision.StereoMatcher.t()`\n- **disp12MaxDiff**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetDisp12MaxDiff(disp12MaxDiff) -> None\n```","ref":"Evision.StereoMatcher.html#setDisp12MaxDiff/2"},{"type":"function","title":"Evision.StereoMatcher.setMinDisparity/1","doc":"","ref":"Evision.StereoMatcher.html#setMinDisparity/1"},{"type":"function","title":"Evision.StereoMatcher.setMinDisparity/2","doc":"setMinDisparity\n\n##### Positional Arguments\n- **self**: `Evision.StereoMatcher.t()`\n- **minDisparity**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMinDisparity(minDisparity) -> None\n```","ref":"Evision.StereoMatcher.html#setMinDisparity/2"},{"type":"function","title":"Evision.StereoMatcher.setNumDisparities/1","doc":"","ref":"Evision.StereoMatcher.html#setNumDisparities/1"},{"type":"function","title":"Evision.StereoMatcher.setNumDisparities/2","doc":"setNumDisparities\n\n##### Positional Arguments\n- **self**: `Evision.StereoMatcher.t()`\n- **numDisparities**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNumDisparities(numDisparities) -> None\n```","ref":"Evision.StereoMatcher.html#setNumDisparities/2"},{"type":"function","title":"Evision.StereoMatcher.setSpeckleRange/1","doc":"","ref":"Evision.StereoMatcher.html#setSpeckleRange/1"},{"type":"function","title":"Evision.StereoMatcher.setSpeckleRange/2","doc":"setSpeckleRange\n\n##### Positional Arguments\n- **self**: `Evision.StereoMatcher.t()`\n- **speckleRange**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetSpeckleRange(speckleRange) -> None\n```","ref":"Evision.StereoMatcher.html#setSpeckleRange/2"},{"type":"function","title":"Evision.StereoMatcher.setSpeckleWindowSize/1","doc":"","ref":"Evision.StereoMatcher.html#setSpeckleWindowSize/1"},{"type":"function","title":"Evision.StereoMatcher.setSpeckleWindowSize/2","doc":"setSpeckleWindowSize\n\n##### Positional Arguments\n- **self**: `Evision.StereoMatcher.t()`\n- **speckleWindowSize**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetSpeckleWindowSize(speckleWindowSize) -> None\n```","ref":"Evision.StereoMatcher.html#setSpeckleWindowSize/2"},{"type":"function","title":"Evision.StereoMatcher.write/1","doc":"","ref":"Evision.StereoMatcher.html#write/1"},{"type":"function","title":"Evision.StereoMatcher.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.StereoMatcher.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.StereoMatcher.html#write/2"},{"type":"function","title":"Evision.StereoMatcher.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.StereoMatcher.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.StereoMatcher.html#write/3"},{"type":"type","title":"Evision.StereoMatcher.enum/0","doc":"","ref":"Evision.StereoMatcher.html#t:enum/0"},{"type":"type","title":"Evision.StereoMatcher.t/0","doc":"Type that represents an `StereoMatcher` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.StereoMatcher.html#t:t/0"},{"type":"module","title":"Evision.StereoSGBM","doc":"","ref":"Evision.StereoSGBM.html"},{"type":"function","title":"Evision.StereoSGBM.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.StereoSGBM.html#clear/1"},{"type":"function","title":"Evision.StereoSGBM.compute/1","doc":"","ref":"Evision.StereoSGBM.html#compute/1"},{"type":"function","title":"Evision.StereoSGBM.compute/3","doc":"Computes disparity map for the specified stereo pair\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n- **left**: `Evision.Mat`.\n\n  Left 8-bit single-channel image.\n\n- **right**: `Evision.Mat`.\n\n  Right image of the same size and the same type as the left one.\n\n##### Return\n- **disparity**: `Evision.Mat.t()`.\n\n  Output disparity map. It has the same size as the input images. Some algorithms,\n  like StereoBM or StereoSGBM compute 16-bit fixed-point disparity map (where each disparity value\n  has 4 fractional bits), whereas other algorithms output 32-bit floating-point disparity map.\n\nPython prototype (for reference only):\n```python3\ncompute(left, right[, disparity]) -> disparity\n```","ref":"Evision.StereoSGBM.html#compute/3"},{"type":"function","title":"Evision.StereoSGBM.compute/4","doc":"Computes disparity map for the specified stereo pair\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n- **left**: `Evision.Mat`.\n\n  Left 8-bit single-channel image.\n\n- **right**: `Evision.Mat`.\n\n  Right image of the same size and the same type as the left one.\n\n##### Return\n- **disparity**: `Evision.Mat.t()`.\n\n  Output disparity map. It has the same size as the input images. Some algorithms,\n  like StereoBM or StereoSGBM compute 16-bit fixed-point disparity map (where each disparity value\n  has 4 fractional bits), whereas other algorithms output 32-bit floating-point disparity map.\n\nPython prototype (for reference only):\n```python3\ncompute(left, right[, disparity]) -> disparity\n```","ref":"Evision.StereoSGBM.html#compute/4"},{"type":"function","title":"Evision.StereoSGBM.create/0","doc":"Creates StereoSGBM object\n##### Keyword Arguments\n- **minDisparity**: `integer()`.\n\n  Minimum possible disparity value. Normally, it is zero but sometimes\n  rectification algorithms can shift images, so this parameter needs to be adjusted accordingly.\n\n- **numDisparities**: `integer()`.\n\n  Maximum disparity minus minimum disparity. The value is always greater than\n  zero. In the current implementation, this parameter must be divisible by 16.\n\n- **blockSize**: `integer()`.\n\n  Matched block size. It must be an odd number \\>=1 . Normally, it should be\n  somewhere in the 3..11 range.\n\n- **p1**: `integer()`.\n\n  The first parameter controlling the disparity smoothness. See below.\n\n- **p2**: `integer()`.\n\n  The second parameter controlling the disparity smoothness. The larger the values are,\n  the smoother the disparity is. P1 is the penalty on the disparity change by plus or minus 1\n  between neighbor pixels. P2 is the penalty on the disparity change by more than 1 between neighbor\n  pixels. The algorithm requires P2 \\> P1 . See stereo_match.cpp sample where some reasonably good\n  P1 and P2 values are shown (like 8\\*number_of_image_channels\\*blockSize\\*blockSize and\n  32\\*number_of_image_channels\\*blockSize\\*blockSize , respectively).\n\n- **disp12MaxDiff**: `integer()`.\n\n  Maximum allowed difference (in integer pixel units) in the left-right\n  disparity check. Set it to a non-positive value to disable the check.\n\n- **preFilterCap**: `integer()`.\n\n  Truncation value for the prefiltered image pixels. The algorithm first\n  computes x-derivative at each pixel and clips its value by [-preFilterCap, preFilterCap] interval.\n  The result values are passed to the Birchfield-Tomasi pixel cost function.\n\n- **uniquenessRatio**: `integer()`.\n\n  Margin in percentage by which the best (minimum) computed cost function\n  value should \"win\" the second best value to consider the found match correct. Normally, a value\n  within the 5-15 range is good enough.\n\n- **speckleWindowSize**: `integer()`.\n\n  Maximum size of smooth disparity regions to consider their noise speckles\n  and invalidate. Set it to 0 to disable speckle filtering. Otherwise, set it somewhere in the\n  50-200 range.\n\n- **speckleRange**: `integer()`.\n\n  Maximum disparity variation within each connected component. If you do speckle\n  filtering, set the parameter to a positive value, it will be implicitly multiplied by 16.\n  Normally, 1 or 2 is good enough.\n\n- **mode**: `integer()`.\n\n  Set it to StereoSGBM::MODE_HH to run the full-scale two-pass dynamic programming\n  algorithm. It will consume O(W\\*H\\*numDisparities) bytes, which is large for 640x480 stereo and\n  huge for HD-size pictures. By default, it is set to false .\n\n##### Return\n- **retval**: `Evision.StereoSGBM.t()`\n\nThe first constructor initializes StereoSGBM with all the default parameters. So, you only have to\nset StereoSGBM::numDisparities at minimum. The second constructor enables you to set each parameter\nto a custom value.\n\nPython prototype (for reference only):\n```python3\ncreate([, minDisparity[, numDisparities[, blockSize[, P1[, P2[, disp12MaxDiff[, preFilterCap[, uniquenessRatio[, speckleWindowSize[, speckleRange[, mode]]]]]]]]]]]) -> retval\n```","ref":"Evision.StereoSGBM.html#create/0"},{"type":"function","title":"Evision.StereoSGBM.create/1","doc":"Creates StereoSGBM object\n##### Keyword Arguments\n- **minDisparity**: `integer()`.\n\n  Minimum possible disparity value. Normally, it is zero but sometimes\n  rectification algorithms can shift images, so this parameter needs to be adjusted accordingly.\n\n- **numDisparities**: `integer()`.\n\n  Maximum disparity minus minimum disparity. The value is always greater than\n  zero. In the current implementation, this parameter must be divisible by 16.\n\n- **blockSize**: `integer()`.\n\n  Matched block size. It must be an odd number \\>=1 . Normally, it should be\n  somewhere in the 3..11 range.\n\n- **p1**: `integer()`.\n\n  The first parameter controlling the disparity smoothness. See below.\n\n- **p2**: `integer()`.\n\n  The second parameter controlling the disparity smoothness. The larger the values are,\n  the smoother the disparity is. P1 is the penalty on the disparity change by plus or minus 1\n  between neighbor pixels. P2 is the penalty on the disparity change by more than 1 between neighbor\n  pixels. The algorithm requires P2 \\> P1 . See stereo_match.cpp sample where some reasonably good\n  P1 and P2 values are shown (like 8\\*number_of_image_channels\\*blockSize\\*blockSize and\n  32\\*number_of_image_channels\\*blockSize\\*blockSize , respectively).\n\n- **disp12MaxDiff**: `integer()`.\n\n  Maximum allowed difference (in integer pixel units) in the left-right\n  disparity check. Set it to a non-positive value to disable the check.\n\n- **preFilterCap**: `integer()`.\n\n  Truncation value for the prefiltered image pixels. The algorithm first\n  computes x-derivative at each pixel and clips its value by [-preFilterCap, preFilterCap] interval.\n  The result values are passed to the Birchfield-Tomasi pixel cost function.\n\n- **uniquenessRatio**: `integer()`.\n\n  Margin in percentage by which the best (minimum) computed cost function\n  value should \"win\" the second best value to consider the found match correct. Normally, a value\n  within the 5-15 range is good enough.\n\n- **speckleWindowSize**: `integer()`.\n\n  Maximum size of smooth disparity regions to consider their noise speckles\n  and invalidate. Set it to 0 to disable speckle filtering. Otherwise, set it somewhere in the\n  50-200 range.\n\n- **speckleRange**: `integer()`.\n\n  Maximum disparity variation within each connected component. If you do speckle\n  filtering, set the parameter to a positive value, it will be implicitly multiplied by 16.\n  Normally, 1 or 2 is good enough.\n\n- **mode**: `integer()`.\n\n  Set it to StereoSGBM::MODE_HH to run the full-scale two-pass dynamic programming\n  algorithm. It will consume O(W\\*H\\*numDisparities) bytes, which is large for 640x480 stereo and\n  huge for HD-size pictures. By default, it is set to false .\n\n##### Return\n- **retval**: `Evision.StereoSGBM.t()`\n\nThe first constructor initializes StereoSGBM with all the default parameters. So, you only have to\nset StereoSGBM::numDisparities at minimum. The second constructor enables you to set each parameter\nto a custom value.\n\nPython prototype (for reference only):\n```python3\ncreate([, minDisparity[, numDisparities[, blockSize[, P1[, P2[, disp12MaxDiff[, preFilterCap[, uniquenessRatio[, speckleWindowSize[, speckleRange[, mode]]]]]]]]]]]) -> retval\n```","ref":"Evision.StereoSGBM.html#create/1"},{"type":"function","title":"Evision.StereoSGBM.cv_MODE_HH4/0","doc":"","ref":"Evision.StereoSGBM.html#cv_MODE_HH4/0"},{"type":"function","title":"Evision.StereoSGBM.cv_MODE_HH/0","doc":"","ref":"Evision.StereoSGBM.html#cv_MODE_HH/0"},{"type":"function","title":"Evision.StereoSGBM.cv_MODE_SGBM/0","doc":"","ref":"Evision.StereoSGBM.html#cv_MODE_SGBM/0"},{"type":"function","title":"Evision.StereoSGBM.cv_MODE_SGBM_3WAY/0","doc":"","ref":"Evision.StereoSGBM.html#cv_MODE_SGBM_3WAY/0"},{"type":"function","title":"Evision.StereoSGBM.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.StereoSGBM.html#empty/1"},{"type":"function","title":"Evision.StereoSGBM.getBlockSize/1","doc":"getBlockSize\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetBlockSize() -> retval\n```","ref":"Evision.StereoSGBM.html#getBlockSize/1"},{"type":"function","title":"Evision.StereoSGBM.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.StereoSGBM.html#getDefaultName/1"},{"type":"function","title":"Evision.StereoSGBM.getDisp12MaxDiff/1","doc":"getDisp12MaxDiff\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetDisp12MaxDiff() -> retval\n```","ref":"Evision.StereoSGBM.html#getDisp12MaxDiff/1"},{"type":"function","title":"Evision.StereoSGBM.getMinDisparity/1","doc":"getMinDisparity\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMinDisparity() -> retval\n```","ref":"Evision.StereoSGBM.html#getMinDisparity/1"},{"type":"function","title":"Evision.StereoSGBM.getMode/1","doc":"getMode\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMode() -> retval\n```","ref":"Evision.StereoSGBM.html#getMode/1"},{"type":"function","title":"Evision.StereoSGBM.getNumDisparities/1","doc":"getNumDisparities\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNumDisparities() -> retval\n```","ref":"Evision.StereoSGBM.html#getNumDisparities/1"},{"type":"function","title":"Evision.StereoSGBM.getP1/1","doc":"getP1\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetP1() -> retval\n```","ref":"Evision.StereoSGBM.html#getP1/1"},{"type":"function","title":"Evision.StereoSGBM.getP2/1","doc":"getP2\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetP2() -> retval\n```","ref":"Evision.StereoSGBM.html#getP2/1"},{"type":"function","title":"Evision.StereoSGBM.getPreFilterCap/1","doc":"getPreFilterCap\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetPreFilterCap() -> retval\n```","ref":"Evision.StereoSGBM.html#getPreFilterCap/1"},{"type":"function","title":"Evision.StereoSGBM.getSpeckleRange/1","doc":"getSpeckleRange\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetSpeckleRange() -> retval\n```","ref":"Evision.StereoSGBM.html#getSpeckleRange/1"},{"type":"function","title":"Evision.StereoSGBM.getSpeckleWindowSize/1","doc":"getSpeckleWindowSize\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetSpeckleWindowSize() -> retval\n```","ref":"Evision.StereoSGBM.html#getSpeckleWindowSize/1"},{"type":"function","title":"Evision.StereoSGBM.getUniquenessRatio/1","doc":"getUniquenessRatio\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetUniquenessRatio() -> retval\n```","ref":"Evision.StereoSGBM.html#getUniquenessRatio/1"},{"type":"function","title":"Evision.StereoSGBM.read/1","doc":"","ref":"Evision.StereoSGBM.html#read/1"},{"type":"function","title":"Evision.StereoSGBM.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.StereoSGBM.html#read/2"},{"type":"function","title":"Evision.StereoSGBM.save/1","doc":"","ref":"Evision.StereoSGBM.html#save/1"},{"type":"function","title":"Evision.StereoSGBM.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.StereoSGBM.html#save/2"},{"type":"function","title":"Evision.StereoSGBM.setBlockSize/1","doc":"","ref":"Evision.StereoSGBM.html#setBlockSize/1"},{"type":"function","title":"Evision.StereoSGBM.setBlockSize/2","doc":"setBlockSize\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n- **blockSize**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetBlockSize(blockSize) -> None\n```","ref":"Evision.StereoSGBM.html#setBlockSize/2"},{"type":"function","title":"Evision.StereoSGBM.setDisp12MaxDiff/1","doc":"","ref":"Evision.StereoSGBM.html#setDisp12MaxDiff/1"},{"type":"function","title":"Evision.StereoSGBM.setDisp12MaxDiff/2","doc":"setDisp12MaxDiff\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n- **disp12MaxDiff**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetDisp12MaxDiff(disp12MaxDiff) -> None\n```","ref":"Evision.StereoSGBM.html#setDisp12MaxDiff/2"},{"type":"function","title":"Evision.StereoSGBM.setMinDisparity/1","doc":"","ref":"Evision.StereoSGBM.html#setMinDisparity/1"},{"type":"function","title":"Evision.StereoSGBM.setMinDisparity/2","doc":"setMinDisparity\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n- **minDisparity**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMinDisparity(minDisparity) -> None\n```","ref":"Evision.StereoSGBM.html#setMinDisparity/2"},{"type":"function","title":"Evision.StereoSGBM.setMode/1","doc":"","ref":"Evision.StereoSGBM.html#setMode/1"},{"type":"function","title":"Evision.StereoSGBM.setMode/2","doc":"setMode\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n- **mode**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMode(mode) -> None\n```","ref":"Evision.StereoSGBM.html#setMode/2"},{"type":"function","title":"Evision.StereoSGBM.setNumDisparities/1","doc":"","ref":"Evision.StereoSGBM.html#setNumDisparities/1"},{"type":"function","title":"Evision.StereoSGBM.setNumDisparities/2","doc":"setNumDisparities\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n- **numDisparities**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNumDisparities(numDisparities) -> None\n```","ref":"Evision.StereoSGBM.html#setNumDisparities/2"},{"type":"function","title":"Evision.StereoSGBM.setP1/1","doc":"","ref":"Evision.StereoSGBM.html#setP1/1"},{"type":"function","title":"Evision.StereoSGBM.setP1/2","doc":"setP1\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n- **p1**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetP1(P1) -> None\n```","ref":"Evision.StereoSGBM.html#setP1/2"},{"type":"function","title":"Evision.StereoSGBM.setP2/1","doc":"","ref":"Evision.StereoSGBM.html#setP2/1"},{"type":"function","title":"Evision.StereoSGBM.setP2/2","doc":"setP2\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n- **p2**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetP2(P2) -> None\n```","ref":"Evision.StereoSGBM.html#setP2/2"},{"type":"function","title":"Evision.StereoSGBM.setPreFilterCap/1","doc":"","ref":"Evision.StereoSGBM.html#setPreFilterCap/1"},{"type":"function","title":"Evision.StereoSGBM.setPreFilterCap/2","doc":"setPreFilterCap\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n- **preFilterCap**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetPreFilterCap(preFilterCap) -> None\n```","ref":"Evision.StereoSGBM.html#setPreFilterCap/2"},{"type":"function","title":"Evision.StereoSGBM.setSpeckleRange/1","doc":"","ref":"Evision.StereoSGBM.html#setSpeckleRange/1"},{"type":"function","title":"Evision.StereoSGBM.setSpeckleRange/2","doc":"setSpeckleRange\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n- **speckleRange**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetSpeckleRange(speckleRange) -> None\n```","ref":"Evision.StereoSGBM.html#setSpeckleRange/2"},{"type":"function","title":"Evision.StereoSGBM.setSpeckleWindowSize/1","doc":"","ref":"Evision.StereoSGBM.html#setSpeckleWindowSize/1"},{"type":"function","title":"Evision.StereoSGBM.setSpeckleWindowSize/2","doc":"setSpeckleWindowSize\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n- **speckleWindowSize**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetSpeckleWindowSize(speckleWindowSize) -> None\n```","ref":"Evision.StereoSGBM.html#setSpeckleWindowSize/2"},{"type":"function","title":"Evision.StereoSGBM.setUniquenessRatio/1","doc":"","ref":"Evision.StereoSGBM.html#setUniquenessRatio/1"},{"type":"function","title":"Evision.StereoSGBM.setUniquenessRatio/2","doc":"setUniquenessRatio\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n- **uniquenessRatio**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetUniquenessRatio(uniquenessRatio) -> None\n```","ref":"Evision.StereoSGBM.html#setUniquenessRatio/2"},{"type":"function","title":"Evision.StereoSGBM.write/1","doc":"","ref":"Evision.StereoSGBM.html#write/1"},{"type":"function","title":"Evision.StereoSGBM.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.StereoSGBM.html#write/2"},{"type":"function","title":"Evision.StereoSGBM.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.StereoSGBM.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.StereoSGBM.html#write/3"},{"type":"type","title":"Evision.StereoSGBM.enum/0","doc":"","ref":"Evision.StereoSGBM.html#t:enum/0"},{"type":"type","title":"Evision.StereoSGBM.t/0","doc":"Type that represents an `StereoSGBM` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.StereoSGBM.html#t:t/0"},{"type":"module","title":"Evision.Stitcher","doc":"","ref":"Evision.Stitcher.html"},{"type":"function","title":"Evision.Stitcher.composePanorama/1","doc":"composePanorama\n\n##### Positional Arguments\n- **self**: `Evision.Stitcher.t()`\n\n##### Return\n- **retval**: `Status`\n- **pano**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncomposePanorama([, pano]) -> retval, pano\n```","ref":"Evision.Stitcher.html#composePanorama/1"},{"type":"function","title":"Evision.Stitcher.composePanorama/2","doc":"#### Variant 1:\nThese functions try to compose the given images (or images stored internally from the other function\ncalls) into the final pano under the assumption that the image transformations were estimated\nbefore.\n\n##### Positional Arguments\n- **self**: `Evision.Stitcher.t()`\n- **images**: `[Evision.Mat]`.\n\n  Input images.\n\n##### Return\n- **retval**: `Status`\n- **pano**: `Evision.Mat.t()`.\n\n  Final pano.\n\n**Note**: Use the functions only if you're aware of the stitching pipeline, otherwise use\nStitcher::stitch.\n@return Status code.\n\nPython prototype (for reference only):\n```python3\ncomposePanorama(images[, pano]) -> retval, pano\n```\n#### Variant 2:\ncomposePanorama\n\n##### Positional Arguments\n- **self**: `Evision.Stitcher.t()`\n\n##### Return\n- **retval**: `Status`\n- **pano**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncomposePanorama([, pano]) -> retval, pano\n```","ref":"Evision.Stitcher.html#composePanorama/2"},{"type":"function","title":"Evision.Stitcher.composePanorama/3","doc":"These functions try to compose the given images (or images stored internally from the other function\ncalls) into the final pano under the assumption that the image transformations were estimated\nbefore.\n\n##### Positional Arguments\n- **self**: `Evision.Stitcher.t()`\n- **images**: `[Evision.Mat]`.\n\n  Input images.\n\n##### Return\n- **retval**: `Status`\n- **pano**: `Evision.Mat.t()`.\n\n  Final pano.\n\n**Note**: Use the functions only if you're aware of the stitching pipeline, otherwise use\nStitcher::stitch.\n@return Status code.\n\nPython prototype (for reference only):\n```python3\ncomposePanorama(images[, pano]) -> retval, pano\n```","ref":"Evision.Stitcher.html#composePanorama/3"},{"type":"function","title":"Evision.Stitcher.compositingResol/1","doc":"compositingResol\n\n##### Positional Arguments\n- **self**: `Evision.Stitcher.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ncompositingResol() -> retval\n```","ref":"Evision.Stitcher.html#compositingResol/1"},{"type":"function","title":"Evision.Stitcher.create/0","doc":"Creates a Stitcher configured in one of the stitching modes.\n##### Keyword Arguments\n- **mode**: `Mode`.\n\n  Scenario for stitcher operation. This is usually determined by source of images\n  to stitch and their transformation. Default parameters will be chosen for operation in given\n  scenario.\n\n##### Return\n- **retval**: `Evision.Stitcher.t()`\n\n@return Stitcher class instance.\n\nPython prototype (for reference only):\n```python3\ncreate([, mode]) -> retval\n```","ref":"Evision.Stitcher.html#create/0"},{"type":"function","title":"Evision.Stitcher.create/1","doc":"Creates a Stitcher configured in one of the stitching modes.\n##### Keyword Arguments\n- **mode**: `Mode`.\n\n  Scenario for stitcher operation. This is usually determined by source of images\n  to stitch and their transformation. Default parameters will be chosen for operation in given\n  scenario.\n\n##### Return\n- **retval**: `Evision.Stitcher.t()`\n\n@return Stitcher class instance.\n\nPython prototype (for reference only):\n```python3\ncreate([, mode]) -> retval\n```","ref":"Evision.Stitcher.html#create/1"},{"type":"function","title":"Evision.Stitcher.estimateTransform/1","doc":"","ref":"Evision.Stitcher.html#estimateTransform/1"},{"type":"function","title":"Evision.Stitcher.estimateTransform/2","doc":"These functions try to match the given images and to estimate rotations of each camera.\n\n##### Positional Arguments\n- **self**: `Evision.Stitcher.t()`\n- **images**: `[Evision.Mat]`.\n\n  Input images.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n\n##### Return\n- **retval**: `Status`\n\n**Note**: Use the functions only if you're aware of the stitching pipeline, otherwise use\nStitcher::stitch.\n@return Status code.\n\nPython prototype (for reference only):\n```python3\nestimateTransform(images[, masks]) -> retval\n```","ref":"Evision.Stitcher.html#estimateTransform/2"},{"type":"function","title":"Evision.Stitcher.estimateTransform/3","doc":"These functions try to match the given images and to estimate rotations of each camera.\n\n##### Positional Arguments\n- **self**: `Evision.Stitcher.t()`\n- **images**: `[Evision.Mat]`.\n\n  Input images.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n\n##### Return\n- **retval**: `Status`\n\n**Note**: Use the functions only if you're aware of the stitching pipeline, otherwise use\nStitcher::stitch.\n@return Status code.\n\nPython prototype (for reference only):\n```python3\nestimateTransform(images[, masks]) -> retval\n```","ref":"Evision.Stitcher.html#estimateTransform/3"},{"type":"function","title":"Evision.Stitcher.interpolationFlags/1","doc":"interpolationFlags\n\n##### Positional Arguments\n- **self**: `Evision.Stitcher.t()`\n\n##### Return\n- **retval**: `InterpolationFlags`\n\nPython prototype (for reference only):\n```python3\ninterpolationFlags() -> retval\n```","ref":"Evision.Stitcher.html#interpolationFlags/1"},{"type":"function","title":"Evision.Stitcher.panoConfidenceThresh/1","doc":"panoConfidenceThresh\n\n##### Positional Arguments\n- **self**: `Evision.Stitcher.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\npanoConfidenceThresh() -> retval\n```","ref":"Evision.Stitcher.html#panoConfidenceThresh/1"},{"type":"function","title":"Evision.Stitcher.registrationResol/1","doc":"registrationResol\n\n##### Positional Arguments\n- **self**: `Evision.Stitcher.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\nregistrationResol() -> retval\n```","ref":"Evision.Stitcher.html#registrationResol/1"},{"type":"function","title":"Evision.Stitcher.seamEstimationResol/1","doc":"seamEstimationResol\n\n##### Positional Arguments\n- **self**: `Evision.Stitcher.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\nseamEstimationResol() -> retval\n```","ref":"Evision.Stitcher.html#seamEstimationResol/1"},{"type":"function","title":"Evision.Stitcher.setCompositingResol/1","doc":"","ref":"Evision.Stitcher.html#setCompositingResol/1"},{"type":"function","title":"Evision.Stitcher.setCompositingResol/2","doc":"setCompositingResol\n\n##### Positional Arguments\n- **self**: `Evision.Stitcher.t()`\n- **resol_mpx**: `double`\n\nPython prototype (for reference only):\n```python3\nsetCompositingResol(resol_mpx) -> None\n```","ref":"Evision.Stitcher.html#setCompositingResol/2"},{"type":"function","title":"Evision.Stitcher.setInterpolationFlags/1","doc":"","ref":"Evision.Stitcher.html#setInterpolationFlags/1"},{"type":"function","title":"Evision.Stitcher.setInterpolationFlags/2","doc":"setInterpolationFlags\n\n##### Positional Arguments\n- **self**: `Evision.Stitcher.t()`\n- **interp_flags**: `InterpolationFlags`\n\nPython prototype (for reference only):\n```python3\nsetInterpolationFlags(interp_flags) -> None\n```","ref":"Evision.Stitcher.html#setInterpolationFlags/2"},{"type":"function","title":"Evision.Stitcher.setPanoConfidenceThresh/1","doc":"","ref":"Evision.Stitcher.html#setPanoConfidenceThresh/1"},{"type":"function","title":"Evision.Stitcher.setPanoConfidenceThresh/2","doc":"setPanoConfidenceThresh\n\n##### Positional Arguments\n- **self**: `Evision.Stitcher.t()`\n- **conf_thresh**: `double`\n\nPython prototype (for reference only):\n```python3\nsetPanoConfidenceThresh(conf_thresh) -> None\n```","ref":"Evision.Stitcher.html#setPanoConfidenceThresh/2"},{"type":"function","title":"Evision.Stitcher.setRegistrationResol/1","doc":"","ref":"Evision.Stitcher.html#setRegistrationResol/1"},{"type":"function","title":"Evision.Stitcher.setRegistrationResol/2","doc":"setRegistrationResol\n\n##### Positional Arguments\n- **self**: `Evision.Stitcher.t()`\n- **resol_mpx**: `double`\n\nPython prototype (for reference only):\n```python3\nsetRegistrationResol(resol_mpx) -> None\n```","ref":"Evision.Stitcher.html#setRegistrationResol/2"},{"type":"function","title":"Evision.Stitcher.setSeamEstimationResol/1","doc":"","ref":"Evision.Stitcher.html#setSeamEstimationResol/1"},{"type":"function","title":"Evision.Stitcher.setSeamEstimationResol/2","doc":"setSeamEstimationResol\n\n##### Positional Arguments\n- **self**: `Evision.Stitcher.t()`\n- **resol_mpx**: `double`\n\nPython prototype (for reference only):\n```python3\nsetSeamEstimationResol(resol_mpx) -> None\n```","ref":"Evision.Stitcher.html#setSeamEstimationResol/2"},{"type":"function","title":"Evision.Stitcher.setWaveCorrection/1","doc":"","ref":"Evision.Stitcher.html#setWaveCorrection/1"},{"type":"function","title":"Evision.Stitcher.setWaveCorrection/2","doc":"setWaveCorrection\n\n##### Positional Arguments\n- **self**: `Evision.Stitcher.t()`\n- **flag**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetWaveCorrection(flag) -> None\n```","ref":"Evision.Stitcher.html#setWaveCorrection/2"},{"type":"function","title":"Evision.Stitcher.stitch/1","doc":"","ref":"Evision.Stitcher.html#stitch/1"},{"type":"function","title":"Evision.Stitcher.stitch/2","doc":"stitch\n\n##### Positional Arguments\n- **self**: `Evision.Stitcher.t()`\n- **images**: `[Evision.Mat]`\n\n##### Return\n- **retval**: `Status`\n- **pano**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nstitch(images[, pano]) -> retval, pano\n```","ref":"Evision.Stitcher.html#stitch/2"},{"type":"function","title":"Evision.Stitcher.stitch/3","doc":"#### Variant 1:\nThese functions try to stitch the given images.\n\n##### Positional Arguments\n- **self**: `Evision.Stitcher.t()`\n- **images**: `[Evision.Mat]`.\n\n  Input images.\n\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n\n##### Return\n- **retval**: `Status`\n- **pano**: `Evision.Mat.t()`.\n\n  Final pano.\n\n@return Status code.\n\nPython prototype (for reference only):\n```python3\nstitch(images, masks[, pano]) -> retval, pano\n```\n#### Variant 2:\nstitch\n\n##### Positional Arguments\n- **self**: `Evision.Stitcher.t()`\n- **images**: `[Evision.Mat]`\n\n##### Return\n- **retval**: `Status`\n- **pano**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nstitch(images[, pano]) -> retval, pano\n```","ref":"Evision.Stitcher.html#stitch/3"},{"type":"function","title":"Evision.Stitcher.stitch/4","doc":"These functions try to stitch the given images.\n\n##### Positional Arguments\n- **self**: `Evision.Stitcher.t()`\n- **images**: `[Evision.Mat]`.\n\n  Input images.\n\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n\n##### Return\n- **retval**: `Status`\n- **pano**: `Evision.Mat.t()`.\n\n  Final pano.\n\n@return Status code.\n\nPython prototype (for reference only):\n```python3\nstitch(images, masks[, pano]) -> retval, pano\n```","ref":"Evision.Stitcher.html#stitch/4"},{"type":"function","title":"Evision.Stitcher.waveCorrection/1","doc":"waveCorrection\n\n##### Positional Arguments\n- **self**: `Evision.Stitcher.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nwaveCorrection() -> retval\n```","ref":"Evision.Stitcher.html#waveCorrection/1"},{"type":"function","title":"Evision.Stitcher.workScale/1","doc":"workScale\n\n##### Positional Arguments\n- **self**: `Evision.Stitcher.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\nworkScale() -> retval\n```","ref":"Evision.Stitcher.html#workScale/1"},{"type":"type","title":"Evision.Stitcher.t/0","doc":"Type that represents an `Stitcher` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Stitcher.html#t:t/0"},{"type":"module","title":"Evision.Stitcher.Mode","doc":"","ref":"Evision.Stitcher.Mode.html"},{"type":"function","title":"Evision.Stitcher.Mode.cv_PANORAMA/0","doc":"","ref":"Evision.Stitcher.Mode.html#cv_PANORAMA/0"},{"type":"function","title":"Evision.Stitcher.Mode.cv_SCANS/0","doc":"","ref":"Evision.Stitcher.Mode.html#cv_SCANS/0"},{"type":"type","title":"Evision.Stitcher.Mode.enum/0","doc":"","ref":"Evision.Stitcher.Mode.html#t:enum/0"},{"type":"module","title":"Evision.Stitcher.Status","doc":"","ref":"Evision.Stitcher.Status.html"},{"type":"function","title":"Evision.Stitcher.Status.cv_ERR_CAMERA_PARAMS_ADJUST_FAIL/0","doc":"","ref":"Evision.Stitcher.Status.html#cv_ERR_CAMERA_PARAMS_ADJUST_FAIL/0"},{"type":"function","title":"Evision.Stitcher.Status.cv_ERR_HOMOGRAPHY_EST_FAIL/0","doc":"","ref":"Evision.Stitcher.Status.html#cv_ERR_HOMOGRAPHY_EST_FAIL/0"},{"type":"function","title":"Evision.Stitcher.Status.cv_ERR_NEED_MORE_IMGS/0","doc":"","ref":"Evision.Stitcher.Status.html#cv_ERR_NEED_MORE_IMGS/0"},{"type":"function","title":"Evision.Stitcher.Status.cv_OK/0","doc":"","ref":"Evision.Stitcher.Status.html#cv_OK/0"},{"type":"type","title":"Evision.Stitcher.Status.enum/0","doc":"","ref":"Evision.Stitcher.Status.html#t:enum/0"},{"type":"module","title":"Evision.StructuredLight","doc":"","ref":"Evision.StructuredLight.html"},{"type":"function","title":"Evision.StructuredLight.cv_DECODE_3D_UNDERWORLD/0","doc":"","ref":"Evision.StructuredLight.html#cv_DECODE_3D_UNDERWORLD/0"},{"type":"function","title":"Evision.StructuredLight.cv_FAPS/0","doc":"","ref":"Evision.StructuredLight.html#cv_FAPS/0"},{"type":"function","title":"Evision.StructuredLight.cv_FTP/0","doc":"","ref":"Evision.StructuredLight.html#cv_FTP/0"},{"type":"function","title":"Evision.StructuredLight.cv_PSP/0","doc":"","ref":"Evision.StructuredLight.html#cv_PSP/0"},{"type":"type","title":"Evision.StructuredLight.enum/0","doc":"","ref":"Evision.StructuredLight.html#t:enum/0"},{"type":"type","title":"Evision.StructuredLight.t/0","doc":"Type that represents an `StructuredLight` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.StructuredLight.html#t:t/0"},{"type":"module","title":"Evision.StructuredLight.GrayCodePattern","doc":"","ref":"Evision.StructuredLight.GrayCodePattern.html"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.GrayCodePattern.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.StructuredLight.GrayCodePattern.html#clear/1"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.create/1","doc":"","ref":"Evision.StructuredLight.GrayCodePattern.html#create/1"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.create/2","doc":"Constructor\n\n##### Positional Arguments\n- **width**: `integer()`\n- **height**: `integer()`\n\n##### Return\n- **retval**: `Evision.StructuredLight.GrayCodePattern.t()`\n\nPython prototype (for reference only):\n```python3\ncreate(width, height) -> retval\n```","ref":"Evision.StructuredLight.GrayCodePattern.html#create/2"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.decode/1","doc":"","ref":"Evision.StructuredLight.GrayCodePattern.html#decode/1"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.decode/2","doc":"Decodes the structured light pattern, generating a disparity map\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.GrayCodePattern.t()`\n- **patternImages**: `[[Evision.Mat]]`.\n\n  The acquired pattern images to decode (vector >), loaded as grayscale and previously rectified.\n\n##### Keyword Arguments\n- **blackImages**: `[Evision.Mat]`.\n\n  The all-black images needed for shadowMasks computation.\n\n- **whiteImages**: `[Evision.Mat]`.\n\n  The all-white images needed for shadowMasks computation.\n\n- **flags**: `integer()`.\n\n  Flags setting decoding algorithms. Default: DECODE_3D_UNDERWORLD.\n\n##### Return\n- **retval**: `bool`\n- **disparityMap**: `Evision.Mat.t()`.\n\n  The decoding result: a CV_64F Mat at image resolution, storing the computed disparity map.\n\n**Note**: All the images must be at the same resolution.\n\nPython prototype (for reference only):\n```python3\ndecode(patternImages[, disparityMap[, blackImages[, whiteImages[, flags]]]]) -> retval, disparityMap\n```","ref":"Evision.StructuredLight.GrayCodePattern.html#decode/2"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.decode/3","doc":"Decodes the structured light pattern, generating a disparity map\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.GrayCodePattern.t()`\n- **patternImages**: `[[Evision.Mat]]`.\n\n  The acquired pattern images to decode (vector >), loaded as grayscale and previously rectified.\n\n##### Keyword Arguments\n- **blackImages**: `[Evision.Mat]`.\n\n  The all-black images needed for shadowMasks computation.\n\n- **whiteImages**: `[Evision.Mat]`.\n\n  The all-white images needed for shadowMasks computation.\n\n- **flags**: `integer()`.\n\n  Flags setting decoding algorithms. Default: DECODE_3D_UNDERWORLD.\n\n##### Return\n- **retval**: `bool`\n- **disparityMap**: `Evision.Mat.t()`.\n\n  The decoding result: a CV_64F Mat at image resolution, storing the computed disparity map.\n\n**Note**: All the images must be at the same resolution.\n\nPython prototype (for reference only):\n```python3\ndecode(patternImages[, disparityMap[, blackImages[, whiteImages[, flags]]]]) -> retval, disparityMap\n```","ref":"Evision.StructuredLight.GrayCodePattern.html#decode/3"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.GrayCodePattern.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.StructuredLight.GrayCodePattern.html#empty/1"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.generate/1","doc":"Generates the structured light pattern to project.\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.GrayCodePattern.t()`\n\n##### Return\n- **retval**: `bool`\n- **patternImages**: `[Evision.Mat]`.\n\n  The generated pattern: a vector , in which each image is a CV_8U Mat at projector's resolution.\n\nPython prototype (for reference only):\n```python3\ngenerate([, patternImages]) -> retval, patternImages\n```","ref":"Evision.StructuredLight.GrayCodePattern.html#generate/1"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.generate/2","doc":"Generates the structured light pattern to project.\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.GrayCodePattern.t()`\n\n##### Return\n- **retval**: `bool`\n- **patternImages**: `[Evision.Mat]`.\n\n  The generated pattern: a vector , in which each image is a CV_8U Mat at projector's resolution.\n\nPython prototype (for reference only):\n```python3\ngenerate([, patternImages]) -> retval, patternImages\n```","ref":"Evision.StructuredLight.GrayCodePattern.html#generate/2"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.GrayCodePattern.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.StructuredLight.GrayCodePattern.html#getDefaultName/1"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.getImagesForShadowMasks/1","doc":"","ref":"Evision.StructuredLight.GrayCodePattern.html#getImagesForShadowMasks/1"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.getImagesForShadowMasks/3","doc":"Generates the all-black and all-white images needed for shadowMasks computation.\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.GrayCodePattern.t()`\n\n##### Return\n- **blackImage**: `Evision.Mat.t()`.\n\n  The generated all-black CV_8U image, at projector's resolution.\n\n- **whiteImage**: `Evision.Mat.t()`.\n\n  The generated all-white CV_8U image, at projector's resolution.\n\n  To identify shadow regions, the regions of two images where the pixels are not lit by projector's light and thus where there is not coded information,\n  the 3DUNDERWORLD algorithm computes a shadow mask for the two cameras views, starting from a white and a black images captured by each camera.\n  This method generates these two additional images to project.\n\nPython prototype (for reference only):\n```python3\ngetImagesForShadowMasks(blackImage, whiteImage) -> blackImage, whiteImage\n```","ref":"Evision.StructuredLight.GrayCodePattern.html#getImagesForShadowMasks/3"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.getNumberOfPatternImages/1","doc":"Get the number of pattern images needed for the graycode pattern.\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.GrayCodePattern.t()`\n\n##### Return\n- **retval**: `size_t`\n\n@return The number of pattern images needed for the graycode pattern.\n\nPython prototype (for reference only):\n```python3\ngetNumberOfPatternImages() -> retval\n```","ref":"Evision.StructuredLight.GrayCodePattern.html#getNumberOfPatternImages/1"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.getProjPixel/1","doc":"","ref":"Evision.StructuredLight.GrayCodePattern.html#getProjPixel/1"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.getProjPixel/4","doc":"For a (x,y) pixel of a camera returns the corresponding projector pixel.\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.GrayCodePattern.t()`\n- **patternImages**: `[Evision.Mat]`.\n\n  The pattern images acquired by the camera, stored in a grayscale vector  .\n\n- **x**: `integer()`.\n\n  x coordinate of the image pixel.\n\n- **y**: `integer()`.\n\n  y coordinate of the image pixel.\n\n##### Return\n- **retval**: `bool`\n- **projPix**: `Point`.\n\n  Projector's pixel corresponding to the camera's pixel: projPix.x and projPix.y are the image coordinates of the projector's pixel corresponding to the pixel being decoded in a camera.\n\n  The function decodes each pixel in the pattern images acquired by a camera into their corresponding decimal numbers representing the projector's column and row,\n  providing a mapping between camera's and projector's pixel.\n\nPython prototype (for reference only):\n```python3\ngetProjPixel(patternImages, x, y) -> retval, projPix\n```","ref":"Evision.StructuredLight.GrayCodePattern.html#getProjPixel/4"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.read/1","doc":"","ref":"Evision.StructuredLight.GrayCodePattern.html#read/1"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.GrayCodePattern.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.StructuredLight.GrayCodePattern.html#read/2"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.save/1","doc":"","ref":"Evision.StructuredLight.GrayCodePattern.html#save/1"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.GrayCodePattern.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.StructuredLight.GrayCodePattern.html#save/2"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.setBlackThreshold/1","doc":"","ref":"Evision.StructuredLight.GrayCodePattern.html#setBlackThreshold/1"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.setBlackThreshold/2","doc":"Sets the value for black threshold, needed for decoding (shadowsmasks computation).\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.GrayCodePattern.t()`\n- **value**: `size_t`.\n\n  The desired black threshold value.\n\n  Black threshold is a number between 0-255 that represents the minimum brightness difference required for valid pixels, between the fully illuminated (white) and the not illuminated images (black); used in computeShadowMasks method.\n\nPython prototype (for reference only):\n```python3\nsetBlackThreshold(value) -> None\n```","ref":"Evision.StructuredLight.GrayCodePattern.html#setBlackThreshold/2"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.setWhiteThreshold/1","doc":"","ref":"Evision.StructuredLight.GrayCodePattern.html#setWhiteThreshold/1"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.setWhiteThreshold/2","doc":"Sets the value for white threshold, needed for decoding.\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.GrayCodePattern.t()`\n- **value**: `size_t`.\n\n  The desired white threshold value.\n\n  White threshold is a number between 0-255 that represents the minimum brightness difference required for valid pixels, between the graycode pattern and its inverse images; used in getProjPixel method.\n\nPython prototype (for reference only):\n```python3\nsetWhiteThreshold(value) -> None\n```","ref":"Evision.StructuredLight.GrayCodePattern.html#setWhiteThreshold/2"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.write/1","doc":"","ref":"Evision.StructuredLight.GrayCodePattern.html#write/1"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.GrayCodePattern.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.StructuredLight.GrayCodePattern.html#write/2"},{"type":"function","title":"Evision.StructuredLight.GrayCodePattern.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.GrayCodePattern.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.StructuredLight.GrayCodePattern.html#write/3"},{"type":"type","title":"Evision.StructuredLight.GrayCodePattern.t/0","doc":"Type that represents an `StructuredLight.GrayCodePattern` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.StructuredLight.GrayCodePattern.html#t:t/0"},{"type":"module","title":"Evision.StructuredLight.SinusoidalPattern","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.html"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.SinusoidalPattern.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.StructuredLight.SinusoidalPattern.html#clear/1"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.computeDataModulationTerm/1","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.html#computeDataModulationTerm/1"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.computeDataModulationTerm/3","doc":"compute the data modulation term.\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.SinusoidalPattern.t()`\n- **patternImages**: `[Evision.Mat]`.\n\n  captured images with projected patterns.\n\n- **shadowMask**: `Evision.Mat`.\n\n  Mask used to discard shadow regions.\n\n##### Return\n- **dataModulationTerm**: `Evision.Mat.t()`.\n\n  Mat where the data modulation term is saved.\n\nPython prototype (for reference only):\n```python3\ncomputeDataModulationTerm(patternImages, shadowMask[, dataModulationTerm]) -> dataModulationTerm\n```","ref":"Evision.StructuredLight.SinusoidalPattern.html#computeDataModulationTerm/3"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.computeDataModulationTerm/4","doc":"compute the data modulation term.\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.SinusoidalPattern.t()`\n- **patternImages**: `[Evision.Mat]`.\n\n  captured images with projected patterns.\n\n- **shadowMask**: `Evision.Mat`.\n\n  Mask used to discard shadow regions.\n\n##### Return\n- **dataModulationTerm**: `Evision.Mat.t()`.\n\n  Mat where the data modulation term is saved.\n\nPython prototype (for reference only):\n```python3\ncomputeDataModulationTerm(patternImages, shadowMask[, dataModulationTerm]) -> dataModulationTerm\n```","ref":"Evision.StructuredLight.SinusoidalPattern.html#computeDataModulationTerm/4"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.computePhaseMap/1","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.html#computePhaseMap/1"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.computePhaseMap/2","doc":"Compute a wrapped phase map from sinusoidal patterns.\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.SinusoidalPattern.t()`\n- **patternImages**: `[Evision.Mat]`.\n\n  Input data to compute the wrapped phase map.\n\n##### Keyword Arguments\n- **fundamental**: `Evision.Mat`.\n\n  Fundamental matrix used to compute epipolar lines and ease the matching step.\n\n##### Return\n- **wrappedPhaseMap**: `Evision.Mat.t()`.\n\n  Wrapped phase map obtained through one of the three methods.\n\n- **shadowMask**: `Evision.Mat.t()`.\n\n  Mask used to discard shadow regions.\n\nPython prototype (for reference only):\n```python3\ncomputePhaseMap(patternImages[, wrappedPhaseMap[, shadowMask[, fundamental]]]) -> wrappedPhaseMap, shadowMask\n```","ref":"Evision.StructuredLight.SinusoidalPattern.html#computePhaseMap/2"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.computePhaseMap/3","doc":"Compute a wrapped phase map from sinusoidal patterns.\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.SinusoidalPattern.t()`\n- **patternImages**: `[Evision.Mat]`.\n\n  Input data to compute the wrapped phase map.\n\n##### Keyword Arguments\n- **fundamental**: `Evision.Mat`.\n\n  Fundamental matrix used to compute epipolar lines and ease the matching step.\n\n##### Return\n- **wrappedPhaseMap**: `Evision.Mat.t()`.\n\n  Wrapped phase map obtained through one of the three methods.\n\n- **shadowMask**: `Evision.Mat.t()`.\n\n  Mask used to discard shadow regions.\n\nPython prototype (for reference only):\n```python3\ncomputePhaseMap(patternImages[, wrappedPhaseMap[, shadowMask[, fundamental]]]) -> wrappedPhaseMap, shadowMask\n```","ref":"Evision.StructuredLight.SinusoidalPattern.html#computePhaseMap/3"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.create/0","doc":"Constructor.\n##### Keyword Arguments\n- **parameters**: `Evision.StructuredLight.SinusoidalPattern.Params`.\n\n  SinusoidalPattern parameters SinusoidalPattern::Params: width, height of the projector and patterns parameters.\n\n##### Return\n- **retval**: `Evision.StructuredLight.SinusoidalPattern.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, parameters]) -> retval\n```","ref":"Evision.StructuredLight.SinusoidalPattern.html#create/0"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.create/1","doc":"Constructor.\n##### Keyword Arguments\n- **parameters**: `Evision.StructuredLight.SinusoidalPattern.Params`.\n\n  SinusoidalPattern parameters SinusoidalPattern::Params: width, height of the projector and patterns parameters.\n\n##### Return\n- **retval**: `Evision.StructuredLight.SinusoidalPattern.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, parameters]) -> retval\n```","ref":"Evision.StructuredLight.SinusoidalPattern.html#create/1"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.decode/1","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.html#decode/1"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.decode/2","doc":"Decodes the structured light pattern, generating a disparity map\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.SinusoidalPattern.t()`\n- **patternImages**: `[[Evision.Mat]]`.\n\n  The acquired pattern images to decode (vector >), loaded as grayscale and previously rectified.\n\n##### Keyword Arguments\n- **blackImages**: `[Evision.Mat]`.\n\n  The all-black images needed for shadowMasks computation.\n\n- **whiteImages**: `[Evision.Mat]`.\n\n  The all-white images needed for shadowMasks computation.\n\n- **flags**: `integer()`.\n\n  Flags setting decoding algorithms. Default: DECODE_3D_UNDERWORLD.\n\n##### Return\n- **retval**: `bool`\n- **disparityMap**: `Evision.Mat.t()`.\n\n  The decoding result: a CV_64F Mat at image resolution, storing the computed disparity map.\n\n**Note**: All the images must be at the same resolution.\n\nPython prototype (for reference only):\n```python3\ndecode(patternImages[, disparityMap[, blackImages[, whiteImages[, flags]]]]) -> retval, disparityMap\n```","ref":"Evision.StructuredLight.SinusoidalPattern.html#decode/2"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.decode/3","doc":"Decodes the structured light pattern, generating a disparity map\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.SinusoidalPattern.t()`\n- **patternImages**: `[[Evision.Mat]]`.\n\n  The acquired pattern images to decode (vector >), loaded as grayscale and previously rectified.\n\n##### Keyword Arguments\n- **blackImages**: `[Evision.Mat]`.\n\n  The all-black images needed for shadowMasks computation.\n\n- **whiteImages**: `[Evision.Mat]`.\n\n  The all-white images needed for shadowMasks computation.\n\n- **flags**: `integer()`.\n\n  Flags setting decoding algorithms. Default: DECODE_3D_UNDERWORLD.\n\n##### Return\n- **retval**: `bool`\n- **disparityMap**: `Evision.Mat.t()`.\n\n  The decoding result: a CV_64F Mat at image resolution, storing the computed disparity map.\n\n**Note**: All the images must be at the same resolution.\n\nPython prototype (for reference only):\n```python3\ndecode(patternImages[, disparityMap[, blackImages[, whiteImages[, flags]]]]) -> retval, disparityMap\n```","ref":"Evision.StructuredLight.SinusoidalPattern.html#decode/3"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.SinusoidalPattern.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.StructuredLight.SinusoidalPattern.html#empty/1"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.findProCamMatches/1","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.html#findProCamMatches/1"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.findProCamMatches/3","doc":"Find correspondences between the two devices thanks to unwrapped phase maps.\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.SinusoidalPattern.t()`\n- **projUnwrappedPhaseMap**: `Evision.Mat`.\n\n  Projector's unwrapped phase map.\n\n- **camUnwrappedPhaseMap**: `Evision.Mat`.\n\n  Camera's unwrapped phase map.\n\n##### Return\n- **matches**: `[Evision.Mat]`.\n\n  Images used to display correspondences map.\n\nPython prototype (for reference only):\n```python3\nfindProCamMatches(projUnwrappedPhaseMap, camUnwrappedPhaseMap[, matches]) -> matches\n```","ref":"Evision.StructuredLight.SinusoidalPattern.html#findProCamMatches/3"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.findProCamMatches/4","doc":"Find correspondences between the two devices thanks to unwrapped phase maps.\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.SinusoidalPattern.t()`\n- **projUnwrappedPhaseMap**: `Evision.Mat`.\n\n  Projector's unwrapped phase map.\n\n- **camUnwrappedPhaseMap**: `Evision.Mat`.\n\n  Camera's unwrapped phase map.\n\n##### Return\n- **matches**: `[Evision.Mat]`.\n\n  Images used to display correspondences map.\n\nPython prototype (for reference only):\n```python3\nfindProCamMatches(projUnwrappedPhaseMap, camUnwrappedPhaseMap[, matches]) -> matches\n```","ref":"Evision.StructuredLight.SinusoidalPattern.html#findProCamMatches/4"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.generate/1","doc":"Generates the structured light pattern to project.\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.SinusoidalPattern.t()`\n\n##### Return\n- **retval**: `bool`\n- **patternImages**: `[Evision.Mat]`.\n\n  The generated pattern: a vector , in which each image is a CV_8U Mat at projector's resolution.\n\nPython prototype (for reference only):\n```python3\ngenerate([, patternImages]) -> retval, patternImages\n```","ref":"Evision.StructuredLight.SinusoidalPattern.html#generate/1"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.generate/2","doc":"Generates the structured light pattern to project.\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.SinusoidalPattern.t()`\n\n##### Return\n- **retval**: `bool`\n- **patternImages**: `[Evision.Mat]`.\n\n  The generated pattern: a vector , in which each image is a CV_8U Mat at projector's resolution.\n\nPython prototype (for reference only):\n```python3\ngenerate([, patternImages]) -> retval, patternImages\n```","ref":"Evision.StructuredLight.SinusoidalPattern.html#generate/2"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.SinusoidalPattern.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.StructuredLight.SinusoidalPattern.html#getDefaultName/1"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.read/1","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.html#read/1"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.SinusoidalPattern.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.StructuredLight.SinusoidalPattern.html#read/2"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.save/1","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.html#save/1"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.SinusoidalPattern.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.StructuredLight.SinusoidalPattern.html#save/2"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.unwrapPhaseMap/1","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.html#unwrapPhaseMap/1"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.unwrapPhaseMap/3","doc":"Unwrap the wrapped phase map to remove phase ambiguities.\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.SinusoidalPattern.t()`\n- **wrappedPhaseMap**: `Evision.Mat`.\n\n  The wrapped phase map computed from the pattern.\n\n- **camSize**: `Size`.\n\n  Resolution of the camera.\n\n##### Keyword Arguments\n- **shadowMask**: `Evision.Mat`.\n\n  Mask used to discard shadow regions.\n\n##### Return\n- **unwrappedPhaseMap**: `Evision.Mat.t()`.\n\n  The unwrapped phase map used to find correspondences between the two devices.\n\nPython prototype (for reference only):\n```python3\nunwrapPhaseMap(wrappedPhaseMap, camSize[, unwrappedPhaseMap[, shadowMask]]) -> unwrappedPhaseMap\n```","ref":"Evision.StructuredLight.SinusoidalPattern.html#unwrapPhaseMap/3"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.unwrapPhaseMap/4","doc":"Unwrap the wrapped phase map to remove phase ambiguities.\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.SinusoidalPattern.t()`\n- **wrappedPhaseMap**: `Evision.Mat`.\n\n  The wrapped phase map computed from the pattern.\n\n- **camSize**: `Size`.\n\n  Resolution of the camera.\n\n##### Keyword Arguments\n- **shadowMask**: `Evision.Mat`.\n\n  Mask used to discard shadow regions.\n\n##### Return\n- **unwrappedPhaseMap**: `Evision.Mat.t()`.\n\n  The unwrapped phase map used to find correspondences between the two devices.\n\nPython prototype (for reference only):\n```python3\nunwrapPhaseMap(wrappedPhaseMap, camSize[, unwrappedPhaseMap[, shadowMask]]) -> unwrappedPhaseMap\n```","ref":"Evision.StructuredLight.SinusoidalPattern.html#unwrapPhaseMap/4"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.write/1","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.html#write/1"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.SinusoidalPattern.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.StructuredLight.SinusoidalPattern.html#write/2"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.SinusoidalPattern.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.StructuredLight.SinusoidalPattern.html#write/3"},{"type":"type","title":"Evision.StructuredLight.SinusoidalPattern.t/0","doc":"Type that represents an `StructuredLight.SinusoidalPattern` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.StructuredLight.SinusoidalPattern.html#t:t/0"},{"type":"module","title":"Evision.StructuredLight.SinusoidalPattern.Params","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.Params.html"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.Params.get_height/1","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.Params.html#get_height/1"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.Params.get_horizontal/1","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.Params.html#get_horizontal/1"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.Params.get_methodId/1","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.Params.html#get_methodId/1"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.Params.get_nbrOfPeriods/1","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.Params.html#get_nbrOfPeriods/1"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.Params.get_nbrOfPixelsBetweenMarkers/1","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.Params.html#get_nbrOfPixelsBetweenMarkers/1"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.Params.get_setMarkers/1","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.Params.html#get_setMarkers/1"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.Params.get_shiftValue/1","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.Params.html#get_shiftValue/1"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.Params.get_width/1","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.Params.html#get_width/1"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.Params.set_height/2","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.Params.html#set_height/2"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.Params.set_horizontal/2","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.Params.html#set_horizontal/2"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.Params.set_methodId/2","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.Params.html#set_methodId/2"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.Params.set_nbrOfPeriods/2","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.Params.html#set_nbrOfPeriods/2"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.Params.set_nbrOfPixelsBetweenMarkers/2","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.Params.html#set_nbrOfPixelsBetweenMarkers/2"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.Params.set_setMarkers/2","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.Params.html#set_setMarkers/2"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.Params.set_shiftValue/2","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.Params.html#set_shiftValue/2"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.Params.set_width/2","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.Params.html#set_width/2"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.Params.structured_light_SinusoidalPattern_Params/0","doc":"SinusoidalPattern_Params\n##### Return\n- **self**: `Evision.StructuredLight.SinusoidalPattern.Params.t()`\n\nPython prototype (for reference only):\n```python3\nSinusoidalPattern_Params() ->  \n```","ref":"Evision.StructuredLight.SinusoidalPattern.Params.html#structured_light_SinusoidalPattern_Params/0"},{"type":"function","title":"Evision.StructuredLight.SinusoidalPattern.Params.structured_light_SinusoidalPattern_Params/1","doc":"","ref":"Evision.StructuredLight.SinusoidalPattern.Params.html#structured_light_SinusoidalPattern_Params/1"},{"type":"type","title":"Evision.StructuredLight.SinusoidalPattern.Params.t/0","doc":"Type that represents an `StructuredLight.SinusoidalPattern.Params` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.StructuredLight.SinusoidalPattern.Params.html#t:t/0"},{"type":"module","title":"Evision.StructuredLight.StructuredLightPattern","doc":"","ref":"Evision.StructuredLight.StructuredLightPattern.html"},{"type":"function","title":"Evision.StructuredLight.StructuredLightPattern.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.StructuredLightPattern.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.StructuredLight.StructuredLightPattern.html#clear/1"},{"type":"function","title":"Evision.StructuredLight.StructuredLightPattern.decode/1","doc":"","ref":"Evision.StructuredLight.StructuredLightPattern.html#decode/1"},{"type":"function","title":"Evision.StructuredLight.StructuredLightPattern.decode/2","doc":"Decodes the structured light pattern, generating a disparity map\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.StructuredLightPattern.t()`\n- **patternImages**: `[[Evision.Mat]]`.\n\n  The acquired pattern images to decode (vector >), loaded as grayscale and previously rectified.\n\n##### Keyword Arguments\n- **blackImages**: `[Evision.Mat]`.\n\n  The all-black images needed for shadowMasks computation.\n\n- **whiteImages**: `[Evision.Mat]`.\n\n  The all-white images needed for shadowMasks computation.\n\n- **flags**: `integer()`.\n\n  Flags setting decoding algorithms. Default: DECODE_3D_UNDERWORLD.\n\n##### Return\n- **retval**: `bool`\n- **disparityMap**: `Evision.Mat.t()`.\n\n  The decoding result: a CV_64F Mat at image resolution, storing the computed disparity map.\n\n**Note**: All the images must be at the same resolution.\n\nPython prototype (for reference only):\n```python3\ndecode(patternImages[, disparityMap[, blackImages[, whiteImages[, flags]]]]) -> retval, disparityMap\n```","ref":"Evision.StructuredLight.StructuredLightPattern.html#decode/2"},{"type":"function","title":"Evision.StructuredLight.StructuredLightPattern.decode/3","doc":"Decodes the structured light pattern, generating a disparity map\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.StructuredLightPattern.t()`\n- **patternImages**: `[[Evision.Mat]]`.\n\n  The acquired pattern images to decode (vector >), loaded as grayscale and previously rectified.\n\n##### Keyword Arguments\n- **blackImages**: `[Evision.Mat]`.\n\n  The all-black images needed for shadowMasks computation.\n\n- **whiteImages**: `[Evision.Mat]`.\n\n  The all-white images needed for shadowMasks computation.\n\n- **flags**: `integer()`.\n\n  Flags setting decoding algorithms. Default: DECODE_3D_UNDERWORLD.\n\n##### Return\n- **retval**: `bool`\n- **disparityMap**: `Evision.Mat.t()`.\n\n  The decoding result: a CV_64F Mat at image resolution, storing the computed disparity map.\n\n**Note**: All the images must be at the same resolution.\n\nPython prototype (for reference only):\n```python3\ndecode(patternImages[, disparityMap[, blackImages[, whiteImages[, flags]]]]) -> retval, disparityMap\n```","ref":"Evision.StructuredLight.StructuredLightPattern.html#decode/3"},{"type":"function","title":"Evision.StructuredLight.StructuredLightPattern.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.StructuredLightPattern.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.StructuredLight.StructuredLightPattern.html#empty/1"},{"type":"function","title":"Evision.StructuredLight.StructuredLightPattern.generate/1","doc":"Generates the structured light pattern to project.\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.StructuredLightPattern.t()`\n\n##### Return\n- **retval**: `bool`\n- **patternImages**: `[Evision.Mat]`.\n\n  The generated pattern: a vector , in which each image is a CV_8U Mat at projector's resolution.\n\nPython prototype (for reference only):\n```python3\ngenerate([, patternImages]) -> retval, patternImages\n```","ref":"Evision.StructuredLight.StructuredLightPattern.html#generate/1"},{"type":"function","title":"Evision.StructuredLight.StructuredLightPattern.generate/2","doc":"Generates the structured light pattern to project.\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.StructuredLightPattern.t()`\n\n##### Return\n- **retval**: `bool`\n- **patternImages**: `[Evision.Mat]`.\n\n  The generated pattern: a vector , in which each image is a CV_8U Mat at projector's resolution.\n\nPython prototype (for reference only):\n```python3\ngenerate([, patternImages]) -> retval, patternImages\n```","ref":"Evision.StructuredLight.StructuredLightPattern.html#generate/2"},{"type":"function","title":"Evision.StructuredLight.StructuredLightPattern.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.StructuredLightPattern.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.StructuredLight.StructuredLightPattern.html#getDefaultName/1"},{"type":"function","title":"Evision.StructuredLight.StructuredLightPattern.read/1","doc":"","ref":"Evision.StructuredLight.StructuredLightPattern.html#read/1"},{"type":"function","title":"Evision.StructuredLight.StructuredLightPattern.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.StructuredLightPattern.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.StructuredLight.StructuredLightPattern.html#read/2"},{"type":"function","title":"Evision.StructuredLight.StructuredLightPattern.save/1","doc":"","ref":"Evision.StructuredLight.StructuredLightPattern.html#save/1"},{"type":"function","title":"Evision.StructuredLight.StructuredLightPattern.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.StructuredLightPattern.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.StructuredLight.StructuredLightPattern.html#save/2"},{"type":"function","title":"Evision.StructuredLight.StructuredLightPattern.write/1","doc":"","ref":"Evision.StructuredLight.StructuredLightPattern.html#write/1"},{"type":"function","title":"Evision.StructuredLight.StructuredLightPattern.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.StructuredLightPattern.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.StructuredLight.StructuredLightPattern.html#write/2"},{"type":"function","title":"Evision.StructuredLight.StructuredLightPattern.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.StructuredLight.StructuredLightPattern.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.StructuredLight.StructuredLightPattern.html#write/3"},{"type":"type","title":"Evision.StructuredLight.StructuredLightPattern.t/0","doc":"Type that represents an `StructuredLight.StructuredLightPattern` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.StructuredLight.StructuredLightPattern.html#t:t/0"},{"type":"module","title":"Evision.Subdiv2D","doc":"","ref":"Evision.Subdiv2D.html"},{"type":"function","title":"Evision.Subdiv2D.cv_NEXT_AROUND_DST/0","doc":"","ref":"Evision.Subdiv2D.html#cv_NEXT_AROUND_DST/0"},{"type":"function","title":"Evision.Subdiv2D.cv_NEXT_AROUND_LEFT/0","doc":"","ref":"Evision.Subdiv2D.html#cv_NEXT_AROUND_LEFT/0"},{"type":"function","title":"Evision.Subdiv2D.cv_NEXT_AROUND_ORG/0","doc":"","ref":"Evision.Subdiv2D.html#cv_NEXT_AROUND_ORG/0"},{"type":"function","title":"Evision.Subdiv2D.cv_NEXT_AROUND_RIGHT/0","doc":"","ref":"Evision.Subdiv2D.html#cv_NEXT_AROUND_RIGHT/0"},{"type":"function","title":"Evision.Subdiv2D.cv_PREV_AROUND_DST/0","doc":"","ref":"Evision.Subdiv2D.html#cv_PREV_AROUND_DST/0"},{"type":"function","title":"Evision.Subdiv2D.cv_PREV_AROUND_LEFT/0","doc":"","ref":"Evision.Subdiv2D.html#cv_PREV_AROUND_LEFT/0"},{"type":"function","title":"Evision.Subdiv2D.cv_PREV_AROUND_ORG/0","doc":"","ref":"Evision.Subdiv2D.html#cv_PREV_AROUND_ORG/0"},{"type":"function","title":"Evision.Subdiv2D.cv_PREV_AROUND_RIGHT/0","doc":"","ref":"Evision.Subdiv2D.html#cv_PREV_AROUND_RIGHT/0"},{"type":"function","title":"Evision.Subdiv2D.cv_PTLOC_ERROR/0","doc":"","ref":"Evision.Subdiv2D.html#cv_PTLOC_ERROR/0"},{"type":"function","title":"Evision.Subdiv2D.cv_PTLOC_INSIDE/0","doc":"","ref":"Evision.Subdiv2D.html#cv_PTLOC_INSIDE/0"},{"type":"function","title":"Evision.Subdiv2D.cv_PTLOC_ON_EDGE/0","doc":"","ref":"Evision.Subdiv2D.html#cv_PTLOC_ON_EDGE/0"},{"type":"function","title":"Evision.Subdiv2D.cv_PTLOC_OUTSIDE_RECT/0","doc":"","ref":"Evision.Subdiv2D.html#cv_PTLOC_OUTSIDE_RECT/0"},{"type":"function","title":"Evision.Subdiv2D.cv_PTLOC_VERTEX/0","doc":"","ref":"Evision.Subdiv2D.html#cv_PTLOC_VERTEX/0"},{"type":"function","title":"Evision.Subdiv2D.edgeDst/1","doc":"","ref":"Evision.Subdiv2D.html#edgeDst/1"},{"type":"function","title":"Evision.Subdiv2D.edgeDst/2","doc":"Returns the edge destination.\n\n##### Positional Arguments\n- **self**: `Evision.Subdiv2D.t()`\n- **edge**: `integer()`.\n\n  Subdivision edge ID.\n\n##### Return\n- **retval**: `integer()`\n- **dstpt**: `Point2f*`.\n\n  Output vertex location.\n\n@returns vertex ID.\n\nPython prototype (for reference only):\n```python3\nedgeDst(edge) -> retval, dstpt\n```","ref":"Evision.Subdiv2D.html#edgeDst/2"},{"type":"function","title":"Evision.Subdiv2D.edgeOrg/1","doc":"","ref":"Evision.Subdiv2D.html#edgeOrg/1"},{"type":"function","title":"Evision.Subdiv2D.edgeOrg/2","doc":"Returns the edge origin.\n\n##### Positional Arguments\n- **self**: `Evision.Subdiv2D.t()`\n- **edge**: `integer()`.\n\n  Subdivision edge ID.\n\n##### Return\n- **retval**: `integer()`\n- **orgpt**: `Point2f*`.\n\n  Output vertex location.\n\n@returns vertex ID.\n\nPython prototype (for reference only):\n```python3\nedgeOrg(edge) -> retval, orgpt\n```","ref":"Evision.Subdiv2D.html#edgeOrg/2"},{"type":"function","title":"Evision.Subdiv2D.findNearest/1","doc":"","ref":"Evision.Subdiv2D.html#findNearest/1"},{"type":"function","title":"Evision.Subdiv2D.findNearest/2","doc":"Finds the subdivision vertex closest to the given point.\n\n##### Positional Arguments\n- **self**: `Evision.Subdiv2D.t()`\n- **pt**: `Point2f`.\n\n  Input point.\n\n##### Return\n- **retval**: `integer()`\n- **nearestPt**: `Point2f*`.\n\n  Output subdivision vertex point.\n\nThe function is another function that locates the input point within the subdivision. It finds the\nsubdivision vertex that is the closest to the input point. It is not necessarily one of vertices\nof the facet containing the input point, though the facet (located using locate() ) is used as a\nstarting point.\n@returns vertex ID.\n\nPython prototype (for reference only):\n```python3\nfindNearest(pt) -> retval, nearestPt\n```","ref":"Evision.Subdiv2D.html#findNearest/2"},{"type":"function","title":"Evision.Subdiv2D.getEdge/1","doc":"","ref":"Evision.Subdiv2D.html#getEdge/1"},{"type":"function","title":"Evision.Subdiv2D.getEdge/3","doc":"Returns one of the edges related to the given edge.\n\n##### Positional Arguments\n- **self**: `Evision.Subdiv2D.t()`\n- **edge**: `integer()`.\n\n  Subdivision edge ID.\n\n- **nextEdgeType**: `integer()`.\n\n  Parameter specifying which of the related edges to return.\n  The following values are possible:\n  - NEXT_AROUND_ORG next around the edge origin ( eOnext on the picture below if e is the input edge)\n  - NEXT_AROUND_DST next around the edge vertex ( eDnext )\n  - PREV_AROUND_ORG previous around the edge origin (reversed eRnext )\n  - PREV_AROUND_DST previous around the edge destination (reversed eLnext )\n  - NEXT_AROUND_LEFT next around the left facet ( eLnext )\n  - NEXT_AROUND_RIGHT next around the right facet ( eRnext )\n  - PREV_AROUND_LEFT previous around the left facet (reversed eOnext )\n  - PREV_AROUND_RIGHT previous around the right facet (reversed eDnext )\n\n##### Return\n- **retval**: `integer()`\n\n![sample output](pics/quadedge.png)\n@returns edge ID related to the input edge.\n\nPython prototype (for reference only):\n```python3\ngetEdge(edge, nextEdgeType) -> retval\n```","ref":"Evision.Subdiv2D.html#getEdge/3"},{"type":"function","title":"Evision.Subdiv2D.getEdgeList/1","doc":"Returns a list of all edges.\n\n##### Positional Arguments\n- **self**: `Evision.Subdiv2D.t()`\n\n##### Return\n- **edgeList**: `[Vec4f]`.\n\n  Output vector.\n\nThe function gives each edge as a 4 numbers vector, where each two are one of the edge\nvertices. i.e. org_x = v[0], org_y = v[1], dst_x = v[2], dst_y = v[3].\n\nPython prototype (for reference only):\n```python3\ngetEdgeList() -> edgeList\n```","ref":"Evision.Subdiv2D.html#getEdgeList/1"},{"type":"function","title":"Evision.Subdiv2D.getLeadingEdgeList/1","doc":"Returns a list of the leading edge ID connected to each triangle.\n\n##### Positional Arguments\n- **self**: `Evision.Subdiv2D.t()`\n\n##### Return\n- **leadingEdgeList**: `[integer()]`.\n\n  Output vector.\n\nThe function gives one edge ID for each triangle.\n\nPython prototype (for reference only):\n```python3\ngetLeadingEdgeList() -> leadingEdgeList\n```","ref":"Evision.Subdiv2D.html#getLeadingEdgeList/1"},{"type":"function","title":"Evision.Subdiv2D.getTriangleList/1","doc":"Returns a list of all triangles.\n\n##### Positional Arguments\n- **self**: `Evision.Subdiv2D.t()`\n\n##### Return\n- **triangleList**: `[Vec6f]`.\n\n  Output vector.\n\nThe function gives each triangle as a 6 numbers vector, where each two are one of the triangle\nvertices. i.e. p1_x = v[0], p1_y = v[1], p2_x = v[2], p2_y = v[3], p3_x = v[4], p3_y = v[5].\n\nPython prototype (for reference only):\n```python3\ngetTriangleList() -> triangleList\n```","ref":"Evision.Subdiv2D.html#getTriangleList/1"},{"type":"function","title":"Evision.Subdiv2D.getVertex/1","doc":"","ref":"Evision.Subdiv2D.html#getVertex/1"},{"type":"function","title":"Evision.Subdiv2D.getVertex/2","doc":"Returns vertex location from vertex ID.\n\n##### Positional Arguments\n- **self**: `Evision.Subdiv2D.t()`\n- **vertex**: `integer()`.\n\n  vertex ID.\n\n##### Return\n- **retval**: `Point2f`\n- **firstEdge**: `int*`.\n\n  Optional. The first edge ID which is connected to the vertex.\n\n@returns vertex (x,y)\n\nPython prototype (for reference only):\n```python3\ngetVertex(vertex) -> retval, firstEdge\n```","ref":"Evision.Subdiv2D.html#getVertex/2"},{"type":"function","title":"Evision.Subdiv2D.getVoronoiFacetList/1","doc":"","ref":"Evision.Subdiv2D.html#getVoronoiFacetList/1"},{"type":"function","title":"Evision.Subdiv2D.getVoronoiFacetList/2","doc":"Returns a list of all Voronoi facets.\n\n##### Positional Arguments\n- **self**: `Evision.Subdiv2D.t()`\n- **idx**: `[integer()]`.\n\n  Vector of vertices IDs to consider. For all vertices you can pass empty vector.\n\n##### Return\n- **facetList**: `[[Point2f]]`.\n\n  Output vector of the Voronoi facets.\n\n- **facetCenters**: `[Point2f]`.\n\n  Output vector of the Voronoi facets center points.\n\nPython prototype (for reference only):\n```python3\ngetVoronoiFacetList(idx) -> facetList, facetCenters\n```","ref":"Evision.Subdiv2D.html#getVoronoiFacetList/2"},{"type":"function","title":"Evision.Subdiv2D.initDelaunay/1","doc":"","ref":"Evision.Subdiv2D.html#initDelaunay/1"},{"type":"function","title":"Evision.Subdiv2D.initDelaunay/2","doc":"Creates a new empty Delaunay subdivision\n\n##### Positional Arguments\n- **self**: `Evision.Subdiv2D.t()`\n- **rect**: `Rect`.\n\n  Rectangle that includes all of the 2D points that are to be added to the subdivision.\n\nPython prototype (for reference only):\n```python3\ninitDelaunay(rect) -> None\n```","ref":"Evision.Subdiv2D.html#initDelaunay/2"},{"type":"function","title":"Evision.Subdiv2D.insert/1","doc":"","ref":"Evision.Subdiv2D.html#insert/1"},{"type":"function","title":"Evision.Subdiv2D.insert/2","doc":"#### Variant 1:\nInsert multiple points into a Delaunay triangulation.\n\n##### Positional Arguments\n- **self**: `Evision.Subdiv2D.t()`\n- **ptvec**: `[Point2f]`.\n\n  Points to insert.\n\nThe function inserts a vector of points into a subdivision and modifies the subdivision topology\nappropriately.\n\nPython prototype (for reference only):\n```python3\ninsert(ptvec) -> None\n```\n#### Variant 2:\nInsert a single point into a Delaunay triangulation.\n\n##### Positional Arguments\n- **self**: `Evision.Subdiv2D.t()`\n- **pt**: `Point2f`.\n\n  Point to insert.\n\n##### Return\n- **retval**: `integer()`\n\nThe function inserts a single point into a subdivision and modifies the subdivision topology\nappropriately. If a point with the same coordinates exists already, no new point is added.\n@returns the ID of the point.\n**Note**: If the point is outside of the triangulation specified rect a runtime error is raised.\n\nPython prototype (for reference only):\n```python3\ninsert(pt) -> retval\n```","ref":"Evision.Subdiv2D.html#insert/2"},{"type":"function","title":"Evision.Subdiv2D.locate/1","doc":"","ref":"Evision.Subdiv2D.html#locate/1"},{"type":"function","title":"Evision.Subdiv2D.locate/2","doc":"Returns the location of a point within a Delaunay triangulation.\n\n##### Positional Arguments\n- **self**: `Evision.Subdiv2D.t()`\n- **pt**: `Point2f`.\n\n  Point to locate.\n\n##### Return\n- **retval**: `integer()`\n- **edge**: `integer()`.\n\n  Output edge that the point belongs to or is located to the right of it.\n\n- **vertex**: `integer()`.\n\n  Optional output vertex the input point coincides with.\n\nThe function locates the input point within the subdivision and gives one of the triangle edges\nor vertices.\n@returns an integer which specify one of the following five cases for point location:\n- The point falls into some facet. The function returns #PTLOC_INSIDE and edge will contain one of\n  edges of the facet.\n\n- The point falls onto the edge. The function returns #PTLOC_ON_EDGE and edge will contain this edge.\n- The point coincides with one of the subdivision vertices. The function returns #PTLOC_VERTEX and\n  vertex will contain a pointer to the vertex.\n\n- The point is outside the subdivision reference rectangle. The function returns #PTLOC_OUTSIDE_RECT\n  and no pointers are filled.\n\n- One of input arguments is invalid. A runtime error is raised or, if silent or \"parent\" error\n  processing mode is selected, #PTLOC_ERROR is returned.\n\nPython prototype (for reference only):\n```python3\nlocate(pt) -> retval, edge, vertex\n```","ref":"Evision.Subdiv2D.html#locate/2"},{"type":"function","title":"Evision.Subdiv2D.nextEdge/1","doc":"","ref":"Evision.Subdiv2D.html#nextEdge/1"},{"type":"function","title":"Evision.Subdiv2D.nextEdge/2","doc":"Returns next edge around the edge origin.\n\n##### Positional Arguments\n- **self**: `Evision.Subdiv2D.t()`\n- **edge**: `integer()`.\n\n  Subdivision edge ID.\n\n##### Return\n- **retval**: `integer()`\n\n@returns an integer which is next edge ID around the edge origin: eOnext on the\npicture above if e is the input edge).\n\nPython prototype (for reference only):\n```python3\nnextEdge(edge) -> retval\n```","ref":"Evision.Subdiv2D.html#nextEdge/2"},{"type":"function","title":"Evision.Subdiv2D.rotateEdge/1","doc":"","ref":"Evision.Subdiv2D.html#rotateEdge/1"},{"type":"function","title":"Evision.Subdiv2D.rotateEdge/3","doc":"Returns another edge of the same quad-edge.\n\n##### Positional Arguments\n- **self**: `Evision.Subdiv2D.t()`\n- **edge**: `integer()`.\n\n  Subdivision edge ID.\n\n- **rotate**: `integer()`.\n\n  Parameter specifying which of the edges of the same quad-edge as the input\n  one to return. The following values are possible:\n  - 0 - the input edge ( e on the picture below if e is the input edge)\n  - 1 - the rotated edge ( eRot )\n  - 2 - the reversed edge (reversed e (in green))\n  - 3 - the reversed rotated edge (reversed eRot (in green))\n\n##### Return\n- **retval**: `integer()`\n\n@returns one of the edges ID of the same quad-edge as the input edge.\n\nPython prototype (for reference only):\n```python3\nrotateEdge(edge, rotate) -> retval\n```","ref":"Evision.Subdiv2D.html#rotateEdge/3"},{"type":"function","title":"Evision.Subdiv2D.subdiv2D/0","doc":"Subdiv2D\n##### Return\n- **self**: `Evision.Subdiv2D.t()`\n\ncreates an empty Subdiv2D object.\nTo create a new empty Delaunay subdivision you need to use the #initDelaunay function.\n\nPython prototype (for reference only):\n```python3\nSubdiv2D() ->  \n```","ref":"Evision.Subdiv2D.html#subdiv2D/0"},{"type":"function","title":"Evision.Subdiv2D.subdiv2D/1","doc":"Subdiv2D\n\n##### Positional Arguments\n- **rect**: `Rect`.\n\n  Rectangle that includes all of the 2D points that are to be added to the subdivision.\n\n##### Return\n- **self**: `Evision.Subdiv2D.t()`\n\nHas overloading in C++\n\nThe function creates an empty Delaunay subdivision where 2D points can be added using the function\ninsert() . All of the points to be added must be within the specified rectangle, otherwise a runtime\nerror is raised.\n\nPython prototype (for reference only):\n```python3\nSubdiv2D(rect) ->  \n```","ref":"Evision.Subdiv2D.html#subdiv2D/1"},{"type":"function","title":"Evision.Subdiv2D.symEdge/1","doc":"","ref":"Evision.Subdiv2D.html#symEdge/1"},{"type":"function","title":"Evision.Subdiv2D.symEdge/2","doc":"symEdge\n\n##### Positional Arguments\n- **self**: `Evision.Subdiv2D.t()`\n- **edge**: `integer()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsymEdge(edge) -> retval\n```","ref":"Evision.Subdiv2D.html#symEdge/2"},{"type":"type","title":"Evision.Subdiv2D.enum/0","doc":"","ref":"Evision.Subdiv2D.html#t:enum/0"},{"type":"type","title":"Evision.Subdiv2D.t/0","doc":"Type that represents an `Subdiv2D` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Subdiv2D.html#t:t/0"},{"type":"module","title":"Evision.TemplateMatchModes","doc":"","ref":"Evision.TemplateMatchModes.html"},{"type":"function","title":"Evision.TemplateMatchModes.cv_TM_CCOEFF/0","doc":"","ref":"Evision.TemplateMatchModes.html#cv_TM_CCOEFF/0"},{"type":"function","title":"Evision.TemplateMatchModes.cv_TM_CCOEFF_NORMED/0","doc":"","ref":"Evision.TemplateMatchModes.html#cv_TM_CCOEFF_NORMED/0"},{"type":"function","title":"Evision.TemplateMatchModes.cv_TM_CCORR/0","doc":"","ref":"Evision.TemplateMatchModes.html#cv_TM_CCORR/0"},{"type":"function","title":"Evision.TemplateMatchModes.cv_TM_CCORR_NORMED/0","doc":"","ref":"Evision.TemplateMatchModes.html#cv_TM_CCORR_NORMED/0"},{"type":"function","title":"Evision.TemplateMatchModes.cv_TM_SQDIFF/0","doc":"","ref":"Evision.TemplateMatchModes.html#cv_TM_SQDIFF/0"},{"type":"function","title":"Evision.TemplateMatchModes.cv_TM_SQDIFF_NORMED/0","doc":"","ref":"Evision.TemplateMatchModes.html#cv_TM_SQDIFF_NORMED/0"},{"type":"type","title":"Evision.TemplateMatchModes.enum/0","doc":"","ref":"Evision.TemplateMatchModes.html#t:enum/0"},{"type":"module","title":"Evision.TermCriteria.Type","doc":"","ref":"Evision.TermCriteria.Type.html"},{"type":"function","title":"Evision.TermCriteria.Type.cv_COUNT/0","doc":"","ref":"Evision.TermCriteria.Type.html#cv_COUNT/0"},{"type":"function","title":"Evision.TermCriteria.Type.cv_EPS/0","doc":"","ref":"Evision.TermCriteria.Type.html#cv_EPS/0"},{"type":"function","title":"Evision.TermCriteria.Type.cv_MAX_ITER/0","doc":"","ref":"Evision.TermCriteria.Type.html#cv_MAX_ITER/0"},{"type":"type","title":"Evision.TermCriteria.Type.enum/0","doc":"","ref":"Evision.TermCriteria.Type.html#t:enum/0"},{"type":"module","title":"Evision.Text","doc":"","ref":"Evision.Text.html"},{"type":"function","title":"Evision.Text.computeNMChannels/1","doc":"Compute the different channels to be processed independently in the N&M algorithm @cite Neumann12.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. Must be RGB CV_8UC3.\n\n##### Keyword Arguments\n- **mode**: `integer()`.\n\n  Mode of operation. Currently the only available options are:\n  * ERFILTER_NM_RGBLGrad** (used by default) and **ERFILTER_NM_IHSGrad**.\n\n##### Return\n- **channels**: `[Evision.Mat]`.\n\n  Output vector\\  where computed channels are stored.\n\nIn N&M algorithm, the combination of intensity (I), hue (H), saturation (S), and gradient magnitude\nchannels (Grad) are used in order to obtain high localization recall. This implementation also\nprovides an alternative combination of red (R), green (G), blue (B), lightness (L), and gradient\nmagnitude (Grad).\n\nPython prototype (for reference only):\n```python3\ncomputeNMChannels(_src[, _channels[, _mode]]) -> _channels\n```","ref":"Evision.Text.html#computeNMChannels/1"},{"type":"function","title":"Evision.Text.computeNMChannels/2","doc":"Compute the different channels to be processed independently in the N&M algorithm @cite Neumann12.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image. Must be RGB CV_8UC3.\n\n##### Keyword Arguments\n- **mode**: `integer()`.\n\n  Mode of operation. Currently the only available options are:\n  * ERFILTER_NM_RGBLGrad** (used by default) and **ERFILTER_NM_IHSGrad**.\n\n##### Return\n- **channels**: `[Evision.Mat]`.\n\n  Output vector\\  where computed channels are stored.\n\nIn N&M algorithm, the combination of intensity (I), hue (H), saturation (S), and gradient magnitude\nchannels (Grad) are used in order to obtain high localization recall. This implementation also\nprovides an alternative combination of red (R), green (G), blue (B), lightness (L), and gradient\nmagnitude (Grad).\n\nPython prototype (for reference only):\n```python3\ncomputeNMChannels(_src[, _channels[, _mode]]) -> _channels\n```","ref":"Evision.Text.html#computeNMChannels/2"},{"type":"function","title":"Evision.Text.createERFilterNM1/1","doc":"#### Variant 1:\nReads an Extremal Region Filter for the 1st stage classifier of N&M algorithm\nfrom the provided path e.g. /path/to/cpp/trained_classifierNM1.xml\n\n##### Positional Arguments\n- **filename**: `String`\n\n##### Keyword Arguments\n- **thresholdDelta**: `integer()`.\n- **minArea**: `float`.\n- **maxArea**: `float`.\n- **minProbability**: `float`.\n- **nonMaxSuppression**: `bool`.\n- **minProbabilityDiff**: `float`.\n\n##### Return\n- **retval**: `Evision.Text.ERFilter.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncreateERFilterNM1(filename[, thresholdDelta[, minArea[, maxArea[, minProbability[, nonMaxSuppression[, minProbabilityDiff]]]]]]) -> retval\n```\n#### Variant 2:\nCreate an Extremal Region Filter for the 1st stage classifier of N&M algorithm @cite Neumann12.\n\n##### Positional Arguments\n- **cb**: `Evision.Text.ERFilter.Callback`\n\n##### Keyword Arguments\n- **thresholdDelta**: `integer()`.\n- **minArea**: `float`.\n- **maxArea**: `float`.\n- **minProbability**: `float`.\n- **nonMaxSuppression**: `bool`.\n- **minProbabilityDiff**: `float`.\n\n##### Return\n- **retval**: `Evision.Text.ERFilter.t()`\n\nThe component tree of the image is extracted by a threshold increased step by step from 0 to 255,\nincrementally computable descriptors (aspect_ratio, compactness, number of holes, and number of\nhorizontal crossings) are computed for each ER and used as features for a classifier which estimates\nthe class-conditional probability P(er|character). The value of P(er|character) is tracked using the\ninclusion relation of ER across all thresholds and only the ERs which correspond to local maximum of\nthe probability P(er|character) are selected (if the local maximum of the probability is above a\nglobal limit pmin and the difference between local maximum and local minimum is greater than\nminProbabilityDiff).\n\nPython prototype (for reference only):\n```python3\ncreateERFilterNM1(cb[, thresholdDelta[, minArea[, maxArea[, minProbability[, nonMaxSuppression[, minProbabilityDiff]]]]]]) -> retval\n```","ref":"Evision.Text.html#createERFilterNM1/1"},{"type":"function","title":"Evision.Text.createERFilterNM1/2","doc":"#### Variant 1:\nReads an Extremal Region Filter for the 1st stage classifier of N&M algorithm\nfrom the provided path e.g. /path/to/cpp/trained_classifierNM1.xml\n\n##### Positional Arguments\n- **filename**: `String`\n\n##### Keyword Arguments\n- **thresholdDelta**: `integer()`.\n- **minArea**: `float`.\n- **maxArea**: `float`.\n- **minProbability**: `float`.\n- **nonMaxSuppression**: `bool`.\n- **minProbabilityDiff**: `float`.\n\n##### Return\n- **retval**: `Evision.Text.ERFilter.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncreateERFilterNM1(filename[, thresholdDelta[, minArea[, maxArea[, minProbability[, nonMaxSuppression[, minProbabilityDiff]]]]]]) -> retval\n```\n#### Variant 2:\nCreate an Extremal Region Filter for the 1st stage classifier of N&M algorithm @cite Neumann12.\n\n##### Positional Arguments\n- **cb**: `Evision.Text.ERFilter.Callback`\n\n##### Keyword Arguments\n- **thresholdDelta**: `integer()`.\n- **minArea**: `float`.\n- **maxArea**: `float`.\n- **minProbability**: `float`.\n- **nonMaxSuppression**: `bool`.\n- **minProbabilityDiff**: `float`.\n\n##### Return\n- **retval**: `Evision.Text.ERFilter.t()`\n\nThe component tree of the image is extracted by a threshold increased step by step from 0 to 255,\nincrementally computable descriptors (aspect_ratio, compactness, number of holes, and number of\nhorizontal crossings) are computed for each ER and used as features for a classifier which estimates\nthe class-conditional probability P(er|character). The value of P(er|character) is tracked using the\ninclusion relation of ER across all thresholds and only the ERs which correspond to local maximum of\nthe probability P(er|character) are selected (if the local maximum of the probability is above a\nglobal limit pmin and the difference between local maximum and local minimum is greater than\nminProbabilityDiff).\n\nPython prototype (for reference only):\n```python3\ncreateERFilterNM1(cb[, thresholdDelta[, minArea[, maxArea[, minProbability[, nonMaxSuppression[, minProbabilityDiff]]]]]]) -> retval\n```","ref":"Evision.Text.html#createERFilterNM1/2"},{"type":"function","title":"Evision.Text.createERFilterNM2/1","doc":"#### Variant 1:\nReads an Extremal Region Filter for the 2nd stage classifier of N&M algorithm\nfrom the provided path e.g. /path/to/cpp/trained_classifierNM2.xml\n\n##### Positional Arguments\n- **filename**: `String`\n\n##### Keyword Arguments\n- **minProbability**: `float`.\n\n##### Return\n- **retval**: `Evision.Text.ERFilter.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncreateERFilterNM2(filename[, minProbability]) -> retval\n```\n#### Variant 2:\nCreate an Extremal Region Filter for the 2nd stage classifier of N&M algorithm @cite Neumann12.\n\n##### Positional Arguments\n- **cb**: `Evision.Text.ERFilter.Callback`\n\n##### Keyword Arguments\n- **minProbability**: `float`.\n\n##### Return\n- **retval**: `Evision.Text.ERFilter.t()`\n\nIn the second stage, the ERs that passed the first stage are classified into character and\nnon-character classes using more informative but also more computationally expensive features. The\nclassifier uses all the features calculated in the first stage and the following additional\nfeatures: hole area ratio, convex hull ratio, and number of outer inflexion points.\n\nPython prototype (for reference only):\n```python3\ncreateERFilterNM2(cb[, minProbability]) -> retval\n```","ref":"Evision.Text.html#createERFilterNM2/1"},{"type":"function","title":"Evision.Text.createERFilterNM2/2","doc":"#### Variant 1:\nReads an Extremal Region Filter for the 2nd stage classifier of N&M algorithm\nfrom the provided path e.g. /path/to/cpp/trained_classifierNM2.xml\n\n##### Positional Arguments\n- **filename**: `String`\n\n##### Keyword Arguments\n- **minProbability**: `float`.\n\n##### Return\n- **retval**: `Evision.Text.ERFilter.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncreateERFilterNM2(filename[, minProbability]) -> retval\n```\n#### Variant 2:\nCreate an Extremal Region Filter for the 2nd stage classifier of N&M algorithm @cite Neumann12.\n\n##### Positional Arguments\n- **cb**: `Evision.Text.ERFilter.Callback`\n\n##### Keyword Arguments\n- **minProbability**: `float`.\n\n##### Return\n- **retval**: `Evision.Text.ERFilter.t()`\n\nIn the second stage, the ERs that passed the first stage are classified into character and\nnon-character classes using more informative but also more computationally expensive features. The\nclassifier uses all the features calculated in the first stage and the following additional\nfeatures: hole area ratio, convex hull ratio, and number of outer inflexion points.\n\nPython prototype (for reference only):\n```python3\ncreateERFilterNM2(cb[, minProbability]) -> retval\n```","ref":"Evision.Text.html#createERFilterNM2/2"},{"type":"function","title":"Evision.Text.createOCRHMMTransitionsTable/1","doc":"","ref":"Evision.Text.html#createOCRHMMTransitionsTable/1"},{"type":"function","title":"Evision.Text.createOCRHMMTransitionsTable/2","doc":"Utility function to create a tailored language model transitions table from a given list of words (lexicon).\n\n##### Positional Arguments\n- **vocabulary**: `String`.\n\n  The language vocabulary (chars when ASCII English text).\n\n- **lexicon**: `[String]`.\n\n  The list of words that are expected to be found in a particular image.\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\n The function calculate frequency statistics of character pairs from the given lexicon and fills the output transition_probabilities_table with them. The transition_probabilities_table can be used as input in the OCRHMMDecoder::create() and OCRBeamSearchDecoder::create() methods.\n**Note**: \n- (C++) An alternative would be to load the default generic language transition table provided in the text module samples folder (created from ispell 42869 english words list) :\n   \n\nPython prototype (for reference only):\n```python3\ncreateOCRHMMTransitionsTable(vocabulary, lexicon) -> retval\n```","ref":"Evision.Text.html#createOCRHMMTransitionsTable/2"},{"type":"function","title":"Evision.Text.cv_ERFILTER_NM_IHSGrad/0","doc":"","ref":"Evision.Text.html#cv_ERFILTER_NM_IHSGrad/0"},{"type":"function","title":"Evision.Text.cv_ERFILTER_NM_RGBLGrad/0","doc":"","ref":"Evision.Text.html#cv_ERFILTER_NM_RGBLGrad/0"},{"type":"function","title":"Evision.Text.cv_OCR_LEVEL_TEXTLINE/0","doc":"","ref":"Evision.Text.html#cv_OCR_LEVEL_TEXTLINE/0"},{"type":"function","title":"Evision.Text.cv_OCR_LEVEL_WORD/0","doc":"","ref":"Evision.Text.html#cv_OCR_LEVEL_WORD/0"},{"type":"function","title":"Evision.Text.detectRegions/1","doc":"","ref":"Evision.Text.html#detectRegions/1"},{"type":"function","title":"Evision.Text.detectRegions/3","doc":"Extracts text regions from image.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Source image where text blocks needs to be extracted from.  Should be CV_8UC3 (color).\n\n- **er_filter1**: `Evision.Text.ERFilter`.\n\n  Extremal Region Filter for the 1st stage classifier of N&M algorithm @cite Neumann12\n\n- **er_filter2**: `Evision.Text.ERFilter`.\n\n  Extremal Region Filter for the 2nd stage classifier of N&M algorithm @cite Neumann12\n\n##### Keyword Arguments\n- **method**: `integer()`.\n\n  Grouping method (see text::erGrouping_Modes). Can be one of ERGROUPING_ORIENTATION_HORIZ, ERGROUPING_ORIENTATION_ANY.\n\n- **filename**: `String`.\n\n  The XML or YAML file with the classifier model (e.g. samples/trained_classifier_erGrouping.xml). Only to use when grouping method is ERGROUPING_ORIENTATION_ANY.\n\n- **minProbability**: `float`.\n\n  The minimum probability for accepting a group. Only to use when grouping method is ERGROUPING_ORIENTATION_ANY.\n\n##### Return\n- **groups_rects**: `[Rect]`.\n\n  Output list of rectangle blocks with text\n\nPython prototype (for reference only):\n```python3\ndetectRegions(image, er_filter1, er_filter2[, method[, filename[, minProbability]]]) -> groups_rects\n```","ref":"Evision.Text.html#detectRegions/3"},{"type":"function","title":"Evision.Text.detectRegions/4","doc":"Extracts text regions from image.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Source image where text blocks needs to be extracted from.  Should be CV_8UC3 (color).\n\n- **er_filter1**: `Evision.Text.ERFilter`.\n\n  Extremal Region Filter for the 1st stage classifier of N&M algorithm @cite Neumann12\n\n- **er_filter2**: `Evision.Text.ERFilter`.\n\n  Extremal Region Filter for the 2nd stage classifier of N&M algorithm @cite Neumann12\n\n##### Keyword Arguments\n- **method**: `integer()`.\n\n  Grouping method (see text::erGrouping_Modes). Can be one of ERGROUPING_ORIENTATION_HORIZ, ERGROUPING_ORIENTATION_ANY.\n\n- **filename**: `String`.\n\n  The XML or YAML file with the classifier model (e.g. samples/trained_classifier_erGrouping.xml). Only to use when grouping method is ERGROUPING_ORIENTATION_ANY.\n\n- **minProbability**: `float`.\n\n  The minimum probability for accepting a group. Only to use when grouping method is ERGROUPING_ORIENTATION_ANY.\n\n##### Return\n- **groups_rects**: `[Rect]`.\n\n  Output list of rectangle blocks with text\n\nPython prototype (for reference only):\n```python3\ndetectRegions(image, er_filter1, er_filter2[, method[, filename[, minProbability]]]) -> groups_rects\n```","ref":"Evision.Text.html#detectRegions/4"},{"type":"function","title":"Evision.Text.detectTextSWT/1","doc":"","ref":"Evision.Text.html#detectTextSWT/1"},{"type":"function","title":"Evision.Text.detectTextSWT/2","doc":"Applies the Stroke Width Transform operator followed by filtering of connected components of similar Stroke Widths to return letter candidates. It also chain them by proximity and size, saving the result in chainBBs.\n\n##### Positional Arguments\n- **input**: `Evision.Mat`.\n\n  the input image with 3 channels.\n\n- **dark_on_light**: `bool`.\n\n  a boolean value signifying whether the text is darker or lighter than the background, it is observed to reverse the gradient obtained from Scharr operator, and significantly affect the result.\n\n##### Return\n- **result**: `[Rect]`.\n\n  a vector of resulting bounding boxes where probability of finding text is high\n\n- **draw**: `Evision.Mat.t()`.\n\n  an optional Mat of type CV_8UC3 which visualises the detected letters using bounding boxes.\n\n- **chainBBs**: `Evision.Mat.t()`.\n\n  an optional parameter which chains the letter candidates according to heuristics in the paper and returns all possible regions where text is likely to occur.\n\nPython prototype (for reference only):\n```python3\ndetectTextSWT(input, dark_on_light[, draw[, chainBBs]]) -> result, draw, chainBBs\n```","ref":"Evision.Text.html#detectTextSWT/2"},{"type":"function","title":"Evision.Text.detectTextSWT/3","doc":"Applies the Stroke Width Transform operator followed by filtering of connected components of similar Stroke Widths to return letter candidates. It also chain them by proximity and size, saving the result in chainBBs.\n\n##### Positional Arguments\n- **input**: `Evision.Mat`.\n\n  the input image with 3 channels.\n\n- **dark_on_light**: `bool`.\n\n  a boolean value signifying whether the text is darker or lighter than the background, it is observed to reverse the gradient obtained from Scharr operator, and significantly affect the result.\n\n##### Return\n- **result**: `[Rect]`.\n\n  a vector of resulting bounding boxes where probability of finding text is high\n\n- **draw**: `Evision.Mat.t()`.\n\n  an optional Mat of type CV_8UC3 which visualises the detected letters using bounding boxes.\n\n- **chainBBs**: `Evision.Mat.t()`.\n\n  an optional parameter which chains the letter candidates according to heuristics in the paper and returns all possible regions where text is likely to occur.\n\nPython prototype (for reference only):\n```python3\ndetectTextSWT(input, dark_on_light[, draw[, chainBBs]]) -> result, draw, chainBBs\n```","ref":"Evision.Text.html#detectTextSWT/3"},{"type":"function","title":"Evision.Text.erGrouping/1","doc":"","ref":"Evision.Text.html#erGrouping/1"},{"type":"function","title":"Evision.Text.erGrouping/3","doc":"Find groups of Extremal Regions that are organized as text blocks.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`\n- **channel**: `Evision.Mat`\n- **regions**: `[[Point]]`.\n\n  Vector of ER's retrieved from the ERFilter algorithm from each channel.\n\n##### Keyword Arguments\n- **method**: `integer()`.\n\n  Grouping method (see text::erGrouping_Modes). Can be one of ERGROUPING_ORIENTATION_HORIZ,\n  ERGROUPING_ORIENTATION_ANY.\n\n- **filename**: `String`.\n\n  The XML or YAML file with the classifier model (e.g.\n  samples/trained_classifier_erGrouping.xml). Only to use when grouping method is\n  ERGROUPING_ORIENTATION_ANY.\n\n- **minProbablity**: `float`.\n\n  The minimum probability for accepting a group. Only to use when grouping\n  method is ERGROUPING_ORIENTATION_ANY.\n\n##### Return\n- **groups_rects**: `[Rect]`.\n\n  The output of the algorithm are stored in this parameter as list of rectangles.\n\nPython prototype (for reference only):\n```python3\nerGrouping(image, channel, regions[, method[, filename[, minProbablity]]]) -> groups_rects\n```","ref":"Evision.Text.html#erGrouping/3"},{"type":"function","title":"Evision.Text.erGrouping/4","doc":"Find groups of Extremal Regions that are organized as text blocks.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`\n- **channel**: `Evision.Mat`\n- **regions**: `[[Point]]`.\n\n  Vector of ER's retrieved from the ERFilter algorithm from each channel.\n\n##### Keyword Arguments\n- **method**: `integer()`.\n\n  Grouping method (see text::erGrouping_Modes). Can be one of ERGROUPING_ORIENTATION_HORIZ,\n  ERGROUPING_ORIENTATION_ANY.\n\n- **filename**: `String`.\n\n  The XML or YAML file with the classifier model (e.g.\n  samples/trained_classifier_erGrouping.xml). Only to use when grouping method is\n  ERGROUPING_ORIENTATION_ANY.\n\n- **minProbablity**: `float`.\n\n  The minimum probability for accepting a group. Only to use when grouping\n  method is ERGROUPING_ORIENTATION_ANY.\n\n##### Return\n- **groups_rects**: `[Rect]`.\n\n  The output of the algorithm are stored in this parameter as list of rectangles.\n\nPython prototype (for reference only):\n```python3\nerGrouping(image, channel, regions[, method[, filename[, minProbablity]]]) -> groups_rects\n```","ref":"Evision.Text.html#erGrouping/4"},{"type":"function","title":"Evision.Text.loadClassifierNM1/1","doc":"Allow to implicitly load the default classifier when creating an ERFilter object.\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  The XML or YAML file with the classifier model (e.g. trained_classifierNM1.xml)\n\n##### Return\n- **retval**: `Evision.Text.ERFilter.Callback.t()`\n\nreturns a pointer to ERFilter::Callback.\n\nPython prototype (for reference only):\n```python3\nloadClassifierNM1(filename) -> retval\n```","ref":"Evision.Text.html#loadClassifierNM1/1"},{"type":"function","title":"Evision.Text.loadClassifierNM2/1","doc":"Allow to implicitly load the default classifier when creating an ERFilter object.\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  The XML or YAML file with the classifier model (e.g. trained_classifierNM2.xml)\n\n##### Return\n- **retval**: `Evision.Text.ERFilter.Callback.t()`\n\nreturns a pointer to ERFilter::Callback.\n\nPython prototype (for reference only):\n```python3\nloadClassifierNM2(filename) -> retval\n```","ref":"Evision.Text.html#loadClassifierNM2/1"},{"type":"function","title":"Evision.Text.loadOCRBeamSearchClassifierCNN/1","doc":"Allow to implicitly load the default character classifier when creating an OCRBeamSearchDecoder object.\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  The XML or YAML file with the classifier model (e.g. OCRBeamSearch_CNN_model_data.xml.gz)\n\n##### Return\n- **retval**: `Evision.Text.OCRBeamSearchDecoder.ClassifierCallback.t()`\n\nThe CNN default classifier is based in the scene text recognition method proposed by Adam Coates &\nAndrew NG in [Coates11a]. The character classifier consists in a Single Layer Convolutional Neural Network and\na linear classifier. It is applied to the input image in a sliding window fashion, providing a set of recognitions\nat each window location.\n\nPython prototype (for reference only):\n```python3\nloadOCRBeamSearchClassifierCNN(filename) -> retval\n```","ref":"Evision.Text.html#loadOCRBeamSearchClassifierCNN/1"},{"type":"function","title":"Evision.Text.loadOCRHMMClassifier/1","doc":"","ref":"Evision.Text.html#loadOCRHMMClassifier/1"},{"type":"function","title":"Evision.Text.loadOCRHMMClassifier/2","doc":"Allow to implicitly load the default character classifier when creating an OCRHMMDecoder object.\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  The XML or YAML file with the classifier model (e.g. OCRBeamSearch_CNN_model_data.xml.gz)\n\n- **classifier**: `integer()`.\n\n  Can be one of classifier_type enum values.\n\n##### Return\n- **retval**: `Evision.Text.OCRHMMDecoder.ClassifierCallback.t()`\n\nPython prototype (for reference only):\n```python3\nloadOCRHMMClassifier(filename, classifier) -> retval\n```","ref":"Evision.Text.html#loadOCRHMMClassifier/2"},{"type":"function","title":"Evision.Text.loadOCRHMMClassifierCNN/1","doc":"Allow to implicitly load the default character classifier when creating an OCRHMMDecoder object.\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  The XML or YAML file with the classifier model (e.g. OCRBeamSearch_CNN_model_data.xml.gz)\n\n##### Return\n- **retval**: `Evision.Text.OCRHMMDecoder.ClassifierCallback.t()`\n\nThe CNN default classifier is based in the scene text recognition method proposed by Adam Coates &\nAndrew NG in [Coates11a]. The character classifier consists in a Single Layer Convolutional Neural Network and\na linear classifier. It is applied to the input image in a sliding window fashion, providing a set of recognitions\nat each window location.\n@deprecated use loadOCRHMMClassifier instead\n\nPython prototype (for reference only):\n```python3\nloadOCRHMMClassifierCNN(filename) -> retval\n```","ref":"Evision.Text.html#loadOCRHMMClassifierCNN/1"},{"type":"function","title":"Evision.Text.loadOCRHMMClassifierNM/1","doc":"Allow to implicitly load the default character classifier when creating an OCRHMMDecoder object.\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  The XML or YAML file with the classifier model (e.g. OCRHMM_knn_model_data.xml)\n\n##### Return\n- **retval**: `Evision.Text.OCRHMMDecoder.ClassifierCallback.t()`\n\nThe KNN default classifier is based in the scene text recognition method proposed by Lukás Neumann &\nJiri Matas in [Neumann11b]. Basically, the region (contour) in the input image is normalized to a\nfixed size, while retaining the centroid and aspect ratio, in order to extract a feature vector\nbased on gradient orientations along the chain-code of its perimeter. Then, the region is classified\nusing a KNN model trained with synthetic data of rendered characters with different standard font\ntypes.\n@deprecated loadOCRHMMClassifier instead\n\nPython prototype (for reference only):\n```python3\nloadOCRHMMClassifierNM(filename) -> retval\n```","ref":"Evision.Text.html#loadOCRHMMClassifierNM/1"},{"type":"type","title":"Evision.Text.enum/0","doc":"","ref":"Evision.Text.html#t:enum/0"},{"type":"type","title":"Evision.Text.t/0","doc":"Type that represents an `Text` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Text.html#t:t/0"},{"type":"module","title":"Evision.Text.BaseOCR","doc":"","ref":"Evision.Text.BaseOCR.html"},{"type":"type","title":"Evision.Text.BaseOCR.t/0","doc":"Type that represents an `Text.BaseOCR` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Text.BaseOCR.html#t:t/0"},{"type":"module","title":"Evision.Text.ClassifierType","doc":"","ref":"Evision.Text.ClassifierType.html"},{"type":"function","title":"Evision.Text.ClassifierType.cv_OCR_CNN_CLASSIFIER/0","doc":"","ref":"Evision.Text.ClassifierType.html#cv_OCR_CNN_CLASSIFIER/0"},{"type":"function","title":"Evision.Text.ClassifierType.cv_OCR_KNN_CLASSIFIER/0","doc":"","ref":"Evision.Text.ClassifierType.html#cv_OCR_KNN_CLASSIFIER/0"},{"type":"type","title":"Evision.Text.ClassifierType.enum/0","doc":"","ref":"Evision.Text.ClassifierType.html#t:enum/0"},{"type":"module","title":"Evision.Text.DecoderMode","doc":"","ref":"Evision.Text.DecoderMode.html"},{"type":"function","title":"Evision.Text.DecoderMode.cv_OCR_DECODER_VITERBI/0","doc":"","ref":"Evision.Text.DecoderMode.html#cv_OCR_DECODER_VITERBI/0"},{"type":"type","title":"Evision.Text.DecoderMode.enum/0","doc":"","ref":"Evision.Text.DecoderMode.html#t:enum/0"},{"type":"module","title":"Evision.Text.ERFilter","doc":"","ref":"Evision.Text.ERFilter.html"},{"type":"function","title":"Evision.Text.ERFilter.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Text.ERFilter.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Text.ERFilter.html#clear/1"},{"type":"function","title":"Evision.Text.ERFilter.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Text.ERFilter.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Text.ERFilter.html#empty/1"},{"type":"function","title":"Evision.Text.ERFilter.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Text.ERFilter.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Text.ERFilter.html#getDefaultName/1"},{"type":"function","title":"Evision.Text.ERFilter.read/1","doc":"","ref":"Evision.Text.ERFilter.html#read/1"},{"type":"function","title":"Evision.Text.ERFilter.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Text.ERFilter.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Text.ERFilter.html#read/2"},{"type":"function","title":"Evision.Text.ERFilter.save/1","doc":"","ref":"Evision.Text.ERFilter.html#save/1"},{"type":"function","title":"Evision.Text.ERFilter.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Text.ERFilter.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Text.ERFilter.html#save/2"},{"type":"function","title":"Evision.Text.ERFilter.write/1","doc":"","ref":"Evision.Text.ERFilter.html#write/1"},{"type":"function","title":"Evision.Text.ERFilter.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Text.ERFilter.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Text.ERFilter.html#write/2"},{"type":"function","title":"Evision.Text.ERFilter.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Text.ERFilter.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Text.ERFilter.html#write/3"},{"type":"type","title":"Evision.Text.ERFilter.t/0","doc":"Type that represents an `Text.ERFilter` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Text.ERFilter.html#t:t/0"},{"type":"module","title":"Evision.Text.ERGroupingModes","doc":"","ref":"Evision.Text.ERGroupingModes.html"},{"type":"function","title":"Evision.Text.ERGroupingModes.cv_ERGROUPING_ORIENTATION_ANY/0","doc":"","ref":"Evision.Text.ERGroupingModes.html#cv_ERGROUPING_ORIENTATION_ANY/0"},{"type":"function","title":"Evision.Text.ERGroupingModes.cv_ERGROUPING_ORIENTATION_HORIZ/0","doc":"","ref":"Evision.Text.ERGroupingModes.html#cv_ERGROUPING_ORIENTATION_HORIZ/0"},{"type":"type","title":"Evision.Text.ERGroupingModes.enum/0","doc":"","ref":"Evision.Text.ERGroupingModes.html#t:enum/0"},{"type":"module","title":"Evision.Text.OCRBeamSearchDecoder","doc":"","ref":"Evision.Text.OCRBeamSearchDecoder.html"},{"type":"function","title":"Evision.Text.OCRBeamSearchDecoder.create/1","doc":"","ref":"Evision.Text.OCRBeamSearchDecoder.html#create/1"},{"type":"function","title":"Evision.Text.OCRBeamSearchDecoder.create/4","doc":"Creates an instance of the OCRBeamSearchDecoder class. Initializes HMMDecoder.\n\n##### Positional Arguments\n- **classifier**: `Evision.Text.OCRBeamSearchDecoder.ClassifierCallback`.\n\n  The character classifier with built in feature extractor.\n\n- **vocabulary**: `string`.\n\n  The language vocabulary (chars when ASCII English text). vocabulary.size()\n  must be equal to the number of classes of the classifier.\n\n- **transition_probabilities_table**: `Evision.Mat`.\n\n  Table with transition probabilities between character\n  pairs. cols == rows == vocabulary.size().\n\n- **emission_probabilities_table**: `Evision.Mat`.\n\n  Table with observation emission probabilities. cols ==\n  rows == vocabulary.size().\n\n##### Keyword Arguments\n- **mode**: `text_decoder_mode`.\n\n  HMM Decoding algorithm. Only OCR_DECODER_VITERBI is available for the moment\n  ( ).\n\n- **beam_size**: `integer()`.\n\n  Size of the beam in Beam Search algorithm.\n\n##### Return\n- **retval**: `OCRBeamSearchDecoder`\n\nPython prototype (for reference only):\n```python3\ncreate(classifier, vocabulary, transition_probabilities_table, emission_probabilities_table[, mode[, beam_size]]) -> retval\n```","ref":"Evision.Text.OCRBeamSearchDecoder.html#create/4"},{"type":"function","title":"Evision.Text.OCRBeamSearchDecoder.create/5","doc":"Creates an instance of the OCRBeamSearchDecoder class. Initializes HMMDecoder.\n\n##### Positional Arguments\n- **classifier**: `Evision.Text.OCRBeamSearchDecoder.ClassifierCallback`.\n\n  The character classifier with built in feature extractor.\n\n- **vocabulary**: `string`.\n\n  The language vocabulary (chars when ASCII English text). vocabulary.size()\n  must be equal to the number of classes of the classifier.\n\n- **transition_probabilities_table**: `Evision.Mat`.\n\n  Table with transition probabilities between character\n  pairs. cols == rows == vocabulary.size().\n\n- **emission_probabilities_table**: `Evision.Mat`.\n\n  Table with observation emission probabilities. cols ==\n  rows == vocabulary.size().\n\n##### Keyword Arguments\n- **mode**: `text_decoder_mode`.\n\n  HMM Decoding algorithm. Only OCR_DECODER_VITERBI is available for the moment\n  ( ).\n\n- **beam_size**: `integer()`.\n\n  Size of the beam in Beam Search algorithm.\n\n##### Return\n- **retval**: `OCRBeamSearchDecoder`\n\nPython prototype (for reference only):\n```python3\ncreate(classifier, vocabulary, transition_probabilities_table, emission_probabilities_table[, mode[, beam_size]]) -> retval\n```","ref":"Evision.Text.OCRBeamSearchDecoder.html#create/5"},{"type":"function","title":"Evision.Text.OCRBeamSearchDecoder.run/1","doc":"","ref":"Evision.Text.OCRBeamSearchDecoder.html#run/1"},{"type":"function","title":"Evision.Text.OCRBeamSearchDecoder.run/3","doc":"Recognize text using Beam Search.\n\n##### Positional Arguments\n- **self**: `Evision.Text.OCRBeamSearchDecoder.t()`\n- **image**: `Evision.Mat`.\n\n  Input binary image CV_8UC1 with a single text line (or word).\n\n- **min_confidence**: `integer()`\n\n##### Keyword Arguments\n- **component_level**: `integer()`.\n\n  Only OCR_LEVEL_WORD is supported.\n\n##### Return\n- **retval**: `String`\n\nTakes image on input and returns recognized text in the output_text parameter. Optionally\nprovides also the Rects for individual text elements found (e.g. words), and the list of those\ntext elements with their confidence values.\n\nPython prototype (for reference only):\n```python3\nrun(image, min_confidence[, component_level]) -> retval\n```","ref":"Evision.Text.OCRBeamSearchDecoder.html#run/3"},{"type":"function","title":"Evision.Text.OCRBeamSearchDecoder.run/4","doc":"#### Variant 1:\nrun\n\n##### Positional Arguments\n- **self**: `Evision.Text.OCRBeamSearchDecoder.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n- **min_confidence**: `integer()`\n\n##### Keyword Arguments\n- **component_level**: `integer()`.\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\nrun(image, mask, min_confidence[, component_level]) -> retval\n```\n#### Variant 2:\nRecognize text using Beam Search.\n\n##### Positional Arguments\n- **self**: `Evision.Text.OCRBeamSearchDecoder.t()`\n- **image**: `Evision.Mat`.\n\n  Input binary image CV_8UC1 with a single text line (or word).\n\n- **min_confidence**: `integer()`\n\n##### Keyword Arguments\n- **component_level**: `integer()`.\n\n  Only OCR_LEVEL_WORD is supported.\n\n##### Return\n- **retval**: `String`\n\nTakes image on input and returns recognized text in the output_text parameter. Optionally\nprovides also the Rects for individual text elements found (e.g. words), and the list of those\ntext elements with their confidence values.\n\nPython prototype (for reference only):\n```python3\nrun(image, min_confidence[, component_level]) -> retval\n```","ref":"Evision.Text.OCRBeamSearchDecoder.html#run/4"},{"type":"function","title":"Evision.Text.OCRBeamSearchDecoder.run/5","doc":"run\n\n##### Positional Arguments\n- **self**: `Evision.Text.OCRBeamSearchDecoder.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n- **min_confidence**: `integer()`\n\n##### Keyword Arguments\n- **component_level**: `integer()`.\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\nrun(image, mask, min_confidence[, component_level]) -> retval\n```","ref":"Evision.Text.OCRBeamSearchDecoder.html#run/5"},{"type":"type","title":"Evision.Text.OCRBeamSearchDecoder.t/0","doc":"Type that represents an `Text.OCRBeamSearchDecoder` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Text.OCRBeamSearchDecoder.html#t:t/0"},{"type":"module","title":"Evision.Text.OCRBeamSearchDecoder.ClassifierCallback","doc":"","ref":"Evision.Text.OCRBeamSearchDecoder.ClassifierCallback.html"},{"type":"type","title":"Evision.Text.OCRBeamSearchDecoder.ClassifierCallback.t/0","doc":"Type that represents an `Text.OCRBeamSearchDecoder.ClassifierCallback` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Text.OCRBeamSearchDecoder.ClassifierCallback.html#t:t/0"},{"type":"module","title":"Evision.Text.OCREngineMode","doc":"","ref":"Evision.Text.OCREngineMode.html"},{"type":"function","title":"Evision.Text.OCREngineMode.cv_OEM_CUBE_ONLY/0","doc":"","ref":"Evision.Text.OCREngineMode.html#cv_OEM_CUBE_ONLY/0"},{"type":"function","title":"Evision.Text.OCREngineMode.cv_OEM_DEFAULT/0","doc":"","ref":"Evision.Text.OCREngineMode.html#cv_OEM_DEFAULT/0"},{"type":"function","title":"Evision.Text.OCREngineMode.cv_OEM_TESSERACT_CUBE_COMBINED/0","doc":"","ref":"Evision.Text.OCREngineMode.html#cv_OEM_TESSERACT_CUBE_COMBINED/0"},{"type":"function","title":"Evision.Text.OCREngineMode.cv_OEM_TESSERACT_ONLY/0","doc":"","ref":"Evision.Text.OCREngineMode.html#cv_OEM_TESSERACT_ONLY/0"},{"type":"type","title":"Evision.Text.OCREngineMode.enum/0","doc":"","ref":"Evision.Text.OCREngineMode.html#t:enum/0"},{"type":"module","title":"Evision.Text.OCRHMMDecoder","doc":"","ref":"Evision.Text.OCRHMMDecoder.html"},{"type":"function","title":"Evision.Text.OCRHMMDecoder.create/1","doc":"","ref":"Evision.Text.OCRHMMDecoder.html#create/1"},{"type":"function","title":"Evision.Text.OCRHMMDecoder.create/4","doc":"#### Variant 1:\nCreates an instance of the OCRHMMDecoder class. Loads and initializes HMMDecoder from the specified path\n\n##### Positional Arguments\n- **filename**: `String`\n- **vocabulary**: `String`\n- **transition_probabilities_table**: `Evision.Mat`\n- **emission_probabilities_table**: `Evision.Mat`\n\n##### Keyword Arguments\n- **mode**: `integer()`.\n- **classifier**: `integer()`.\n\n##### Return\n- **retval**: `OCRHMMDecoder`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncreate(filename, vocabulary, transition_probabilities_table, emission_probabilities_table[, mode[, classifier]]) -> retval\n```\n#### Variant 2:\nCreates an instance of the OCRHMMDecoder class. Initializes HMMDecoder.\n\n##### Positional Arguments\n- **classifier**: `Evision.Text.OCRHMMDecoder.ClassifierCallback`.\n\n  The character classifier with built in feature extractor.\n\n- **vocabulary**: `String`.\n\n  The language vocabulary (chars when ascii english text). vocabulary.size()\n  must be equal to the number of classes of the classifier.\n\n- **transition_probabilities_table**: `Evision.Mat`.\n\n  Table with transition probabilities between character\n  pairs. cols == rows == vocabulary.size().\n\n- **emission_probabilities_table**: `Evision.Mat`.\n\n  Table with observation emission probabilities. cols ==\n  rows == vocabulary.size().\n\n##### Keyword Arguments\n- **mode**: `integer()`.\n\n  HMM Decoding algorithm. Only OCR_DECODER_VITERBI is available for the moment\n  ( ).\n\n##### Return\n- **retval**: `OCRHMMDecoder`\n\nPython prototype (for reference only):\n```python3\ncreate(classifier, vocabulary, transition_probabilities_table, emission_probabilities_table[, mode]) -> retval\n```","ref":"Evision.Text.OCRHMMDecoder.html#create/4"},{"type":"function","title":"Evision.Text.OCRHMMDecoder.create/5","doc":"#### Variant 1:\nCreates an instance of the OCRHMMDecoder class. Loads and initializes HMMDecoder from the specified path\n\n##### Positional Arguments\n- **filename**: `String`\n- **vocabulary**: `String`\n- **transition_probabilities_table**: `Evision.Mat`\n- **emission_probabilities_table**: `Evision.Mat`\n\n##### Keyword Arguments\n- **mode**: `integer()`.\n- **classifier**: `integer()`.\n\n##### Return\n- **retval**: `OCRHMMDecoder`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncreate(filename, vocabulary, transition_probabilities_table, emission_probabilities_table[, mode[, classifier]]) -> retval\n```\n#### Variant 2:\nCreates an instance of the OCRHMMDecoder class. Initializes HMMDecoder.\n\n##### Positional Arguments\n- **classifier**: `Evision.Text.OCRHMMDecoder.ClassifierCallback`.\n\n  The character classifier with built in feature extractor.\n\n- **vocabulary**: `String`.\n\n  The language vocabulary (chars when ascii english text). vocabulary.size()\n  must be equal to the number of classes of the classifier.\n\n- **transition_probabilities_table**: `Evision.Mat`.\n\n  Table with transition probabilities between character\n  pairs. cols == rows == vocabulary.size().\n\n- **emission_probabilities_table**: `Evision.Mat`.\n\n  Table with observation emission probabilities. cols ==\n  rows == vocabulary.size().\n\n##### Keyword Arguments\n- **mode**: `integer()`.\n\n  HMM Decoding algorithm. Only OCR_DECODER_VITERBI is available for the moment\n  ( ).\n\n##### Return\n- **retval**: `OCRHMMDecoder`\n\nPython prototype (for reference only):\n```python3\ncreate(classifier, vocabulary, transition_probabilities_table, emission_probabilities_table[, mode]) -> retval\n```","ref":"Evision.Text.OCRHMMDecoder.html#create/5"},{"type":"function","title":"Evision.Text.OCRHMMDecoder.run/1","doc":"","ref":"Evision.Text.OCRHMMDecoder.html#run/1"},{"type":"function","title":"Evision.Text.OCRHMMDecoder.run/3","doc":"Recognize text using HMM.\n\n##### Positional Arguments\n- **self**: `Evision.Text.OCRHMMDecoder.t()`\n- **image**: `Evision.Mat`.\n\n  Input image CV_8UC1 or CV_8UC3 with a single text line (or word).\n\n- **min_confidence**: `integer()`\n\n##### Keyword Arguments\n- **component_level**: `integer()`.\n\n  Only OCR_LEVEL_WORD is supported.\n\n##### Return\n- **retval**: `String`\n\nTakes an image and a mask (where each connected component corresponds to a segmented character)\non input and returns recognized text in the output_text parameter. Optionally\nprovides also the Rects for individual text elements found (e.g. words), and the list of those\ntext elements with their confidence values.\n\nPython prototype (for reference only):\n```python3\nrun(image, min_confidence[, component_level]) -> retval\n```","ref":"Evision.Text.OCRHMMDecoder.html#run/3"},{"type":"function","title":"Evision.Text.OCRHMMDecoder.run/4","doc":"#### Variant 1:\nrun\n\n##### Positional Arguments\n- **self**: `Evision.Text.OCRHMMDecoder.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n- **min_confidence**: `integer()`\n\n##### Keyword Arguments\n- **component_level**: `integer()`.\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\nrun(image, mask, min_confidence[, component_level]) -> retval\n```\n#### Variant 2:\nRecognize text using HMM.\n\n##### Positional Arguments\n- **self**: `Evision.Text.OCRHMMDecoder.t()`\n- **image**: `Evision.Mat`.\n\n  Input image CV_8UC1 or CV_8UC3 with a single text line (or word).\n\n- **min_confidence**: `integer()`\n\n##### Keyword Arguments\n- **component_level**: `integer()`.\n\n  Only OCR_LEVEL_WORD is supported.\n\n##### Return\n- **retval**: `String`\n\nTakes an image and a mask (where each connected component corresponds to a segmented character)\non input and returns recognized text in the output_text parameter. Optionally\nprovides also the Rects for individual text elements found (e.g. words), and the list of those\ntext elements with their confidence values.\n\nPython prototype (for reference only):\n```python3\nrun(image, min_confidence[, component_level]) -> retval\n```","ref":"Evision.Text.OCRHMMDecoder.html#run/4"},{"type":"function","title":"Evision.Text.OCRHMMDecoder.run/5","doc":"run\n\n##### Positional Arguments\n- **self**: `Evision.Text.OCRHMMDecoder.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n- **min_confidence**: `integer()`\n\n##### Keyword Arguments\n- **component_level**: `integer()`.\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\nrun(image, mask, min_confidence[, component_level]) -> retval\n```","ref":"Evision.Text.OCRHMMDecoder.html#run/5"},{"type":"type","title":"Evision.Text.OCRHMMDecoder.t/0","doc":"Type that represents an `Text.OCRHMMDecoder` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Text.OCRHMMDecoder.html#t:t/0"},{"type":"module","title":"Evision.Text.OCRHMMDecoder.ClassifierCallback","doc":"","ref":"Evision.Text.OCRHMMDecoder.ClassifierCallback.html"},{"type":"type","title":"Evision.Text.OCRHMMDecoder.ClassifierCallback.t/0","doc":"Type that represents an `Text.OCRHMMDecoder.ClassifierCallback` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Text.OCRHMMDecoder.ClassifierCallback.html#t:t/0"},{"type":"module","title":"Evision.Text.OCRTesseract","doc":"","ref":"Evision.Text.OCRTesseract.html"},{"type":"function","title":"Evision.Text.OCRTesseract.create/0","doc":"Creates an instance of the OCRTesseract class. Initializes Tesseract.\n##### Keyword Arguments\n- **datapath**: `c_string`.\n\n  the name of the parent directory of tessdata ended with \"/\", or NULL to use the\n  system's default directory.\n\n- **language**: `c_string`.\n\n  an ISO 639-3 code or NULL will default to \"eng\".\n\n- **char_whitelist**: `c_string`.\n\n  specifies the list of characters used for recognition. NULL defaults to \"\"\n  (All characters will be used for recognition).\n\n- **oem**: `integer()`.\n\n  tesseract-ocr offers different OCR Engine Modes (OEM), by default\n  tesseract::OEM_DEFAULT is used. See the tesseract-ocr API documentation for other possible\n  values.\n\n- **psmode**: `integer()`.\n\n  tesseract-ocr offers different Page Segmentation Modes (PSM) tesseract::PSM_AUTO\n  (fully automatic layout analysis) is used. See the tesseract-ocr API documentation for other\n  possible values.\n\n##### Return\n- **retval**: `OCRTesseract`\n\n**Note**: The char_whitelist default is changed after OpenCV 4.7.0/3.19.0 from \"0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ\" to \"\".\n\nPython prototype (for reference only):\n```python3\ncreate([, datapath[, language[, char_whitelist[, oem[, psmode]]]]]) -> retval\n```","ref":"Evision.Text.OCRTesseract.html#create/0"},{"type":"function","title":"Evision.Text.OCRTesseract.create/1","doc":"Creates an instance of the OCRTesseract class. Initializes Tesseract.\n##### Keyword Arguments\n- **datapath**: `c_string`.\n\n  the name of the parent directory of tessdata ended with \"/\", or NULL to use the\n  system's default directory.\n\n- **language**: `c_string`.\n\n  an ISO 639-3 code or NULL will default to \"eng\".\n\n- **char_whitelist**: `c_string`.\n\n  specifies the list of characters used for recognition. NULL defaults to \"\"\n  (All characters will be used for recognition).\n\n- **oem**: `integer()`.\n\n  tesseract-ocr offers different OCR Engine Modes (OEM), by default\n  tesseract::OEM_DEFAULT is used. See the tesseract-ocr API documentation for other possible\n  values.\n\n- **psmode**: `integer()`.\n\n  tesseract-ocr offers different Page Segmentation Modes (PSM) tesseract::PSM_AUTO\n  (fully automatic layout analysis) is used. See the tesseract-ocr API documentation for other\n  possible values.\n\n##### Return\n- **retval**: `OCRTesseract`\n\n**Note**: The char_whitelist default is changed after OpenCV 4.7.0/3.19.0 from \"0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ\" to \"\".\n\nPython prototype (for reference only):\n```python3\ncreate([, datapath[, language[, char_whitelist[, oem[, psmode]]]]]) -> retval\n```","ref":"Evision.Text.OCRTesseract.html#create/1"},{"type":"function","title":"Evision.Text.OCRTesseract.run/1","doc":"","ref":"Evision.Text.OCRTesseract.html#run/1"},{"type":"function","title":"Evision.Text.OCRTesseract.run/3","doc":"Recognize text using the tesseract-ocr API.\n\n##### Positional Arguments\n- **self**: `Evision.Text.OCRTesseract.t()`\n- **image**: `Evision.Mat`.\n\n  Input image CV_8UC1 or CV_8UC3\n\n- **min_confidence**: `integer()`\n\n##### Keyword Arguments\n- **component_level**: `integer()`.\n\n  OCR_LEVEL_WORD (by default), or OCR_LEVEL_TEXTLINE.\n\n##### Return\n- **retval**: `String`\n\nTakes image on input and returns recognized text in the output_text parameter. Optionally\nprovides also the Rects for individual text elements found (e.g. words), and the list of those\ntext elements with their confidence values.\n\nPython prototype (for reference only):\n```python3\nrun(image, min_confidence[, component_level]) -> retval\n```","ref":"Evision.Text.OCRTesseract.html#run/3"},{"type":"function","title":"Evision.Text.OCRTesseract.run/4","doc":"#### Variant 1:\nrun\n\n##### Positional Arguments\n- **self**: `Evision.Text.OCRTesseract.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n- **min_confidence**: `integer()`\n\n##### Keyword Arguments\n- **component_level**: `integer()`.\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\nrun(image, mask, min_confidence[, component_level]) -> retval\n```\n#### Variant 2:\nRecognize text using the tesseract-ocr API.\n\n##### Positional Arguments\n- **self**: `Evision.Text.OCRTesseract.t()`\n- **image**: `Evision.Mat`.\n\n  Input image CV_8UC1 or CV_8UC3\n\n- **min_confidence**: `integer()`\n\n##### Keyword Arguments\n- **component_level**: `integer()`.\n\n  OCR_LEVEL_WORD (by default), or OCR_LEVEL_TEXTLINE.\n\n##### Return\n- **retval**: `String`\n\nTakes image on input and returns recognized text in the output_text parameter. Optionally\nprovides also the Rects for individual text elements found (e.g. words), and the list of those\ntext elements with their confidence values.\n\nPython prototype (for reference only):\n```python3\nrun(image, min_confidence[, component_level]) -> retval\n```","ref":"Evision.Text.OCRTesseract.html#run/4"},{"type":"function","title":"Evision.Text.OCRTesseract.run/5","doc":"run\n\n##### Positional Arguments\n- **self**: `Evision.Text.OCRTesseract.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n- **min_confidence**: `integer()`\n\n##### Keyword Arguments\n- **component_level**: `integer()`.\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\nrun(image, mask, min_confidence[, component_level]) -> retval\n```","ref":"Evision.Text.OCRTesseract.html#run/5"},{"type":"function","title":"Evision.Text.OCRTesseract.setWhiteList/1","doc":"","ref":"Evision.Text.OCRTesseract.html#setWhiteList/1"},{"type":"function","title":"Evision.Text.OCRTesseract.setWhiteList/2","doc":"setWhiteList\n\n##### Positional Arguments\n- **self**: `Evision.Text.OCRTesseract.t()`\n- **char_whitelist**: `String`\n\nPython prototype (for reference only):\n```python3\nsetWhiteList(char_whitelist) -> None\n```","ref":"Evision.Text.OCRTesseract.html#setWhiteList/2"},{"type":"type","title":"Evision.Text.OCRTesseract.t/0","doc":"Type that represents an `Text.OCRTesseract` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Text.OCRTesseract.html#t:t/0"},{"type":"module","title":"Evision.Text.PageSegMode","doc":"","ref":"Evision.Text.PageSegMode.html"},{"type":"function","title":"Evision.Text.PageSegMode.cv_PSM_AUTO/0","doc":"","ref":"Evision.Text.PageSegMode.html#cv_PSM_AUTO/0"},{"type":"function","title":"Evision.Text.PageSegMode.cv_PSM_AUTO_ONLY/0","doc":"","ref":"Evision.Text.PageSegMode.html#cv_PSM_AUTO_ONLY/0"},{"type":"function","title":"Evision.Text.PageSegMode.cv_PSM_AUTO_OSD/0","doc":"","ref":"Evision.Text.PageSegMode.html#cv_PSM_AUTO_OSD/0"},{"type":"function","title":"Evision.Text.PageSegMode.cv_PSM_CIRCLE_WORD/0","doc":"","ref":"Evision.Text.PageSegMode.html#cv_PSM_CIRCLE_WORD/0"},{"type":"function","title":"Evision.Text.PageSegMode.cv_PSM_OSD_ONLY/0","doc":"","ref":"Evision.Text.PageSegMode.html#cv_PSM_OSD_ONLY/0"},{"type":"function","title":"Evision.Text.PageSegMode.cv_PSM_SINGLE_BLOCK/0","doc":"","ref":"Evision.Text.PageSegMode.html#cv_PSM_SINGLE_BLOCK/0"},{"type":"function","title":"Evision.Text.PageSegMode.cv_PSM_SINGLE_BLOCK_VERT_TEXT/0","doc":"","ref":"Evision.Text.PageSegMode.html#cv_PSM_SINGLE_BLOCK_VERT_TEXT/0"},{"type":"function","title":"Evision.Text.PageSegMode.cv_PSM_SINGLE_CHAR/0","doc":"","ref":"Evision.Text.PageSegMode.html#cv_PSM_SINGLE_CHAR/0"},{"type":"function","title":"Evision.Text.PageSegMode.cv_PSM_SINGLE_COLUMN/0","doc":"","ref":"Evision.Text.PageSegMode.html#cv_PSM_SINGLE_COLUMN/0"},{"type":"function","title":"Evision.Text.PageSegMode.cv_PSM_SINGLE_LINE/0","doc":"","ref":"Evision.Text.PageSegMode.html#cv_PSM_SINGLE_LINE/0"},{"type":"function","title":"Evision.Text.PageSegMode.cv_PSM_SINGLE_WORD/0","doc":"","ref":"Evision.Text.PageSegMode.html#cv_PSM_SINGLE_WORD/0"},{"type":"type","title":"Evision.Text.PageSegMode.enum/0","doc":"","ref":"Evision.Text.PageSegMode.html#t:enum/0"},{"type":"module","title":"Evision.Text.TextDetector","doc":"","ref":"Evision.Text.TextDetector.html"},{"type":"function","title":"Evision.Text.TextDetector.detect/1","doc":"","ref":"Evision.Text.TextDetector.html#detect/1"},{"type":"function","title":"Evision.Text.TextDetector.detect/2","doc":"Method that provides a quick and simple interface to detect text inside an image\n\n##### Positional Arguments\n- **self**: `Evision.Text.TextDetector.t()`\n- **inputImage**: `Evision.Mat`.\n\n  an image to process\n\n##### Return\n- **bbox**: `[Rect]`.\n\n  a vector of Rect that will store the detected word bounding box\n\n- **confidence**: `[float]`.\n\n  a vector of float that will be updated with the confidence the classifier has for the selected bounding box\n\nPython prototype (for reference only):\n```python3\ndetect(inputImage) -> Bbox, confidence\n```","ref":"Evision.Text.TextDetector.html#detect/2"},{"type":"type","title":"Evision.Text.TextDetector.t/0","doc":"Type that represents an `Text.TextDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Text.TextDetector.html#t:t/0"},{"type":"module","title":"Evision.Text.TextDetectorCNN","doc":"","ref":"Evision.Text.TextDetectorCNN.html"},{"type":"function","title":"Evision.Text.TextDetectorCNN.create/1","doc":"","ref":"Evision.Text.TextDetectorCNN.html#create/1"},{"type":"function","title":"Evision.Text.TextDetectorCNN.create/2","doc":"create\n\n##### Positional Arguments\n- **modelArchFilename**: `String`\n- **modelWeightsFilename**: `String`\n\n##### Return\n- **retval**: `Evision.Text.TextDetectorCNN.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncreate(modelArchFilename, modelWeightsFilename) -> retval\n```","ref":"Evision.Text.TextDetectorCNN.html#create/2"},{"type":"function","title":"Evision.Text.TextDetectorCNN.detect/1","doc":"","ref":"Evision.Text.TextDetectorCNN.html#detect/1"},{"type":"function","title":"Evision.Text.TextDetectorCNN.detect/2","doc":"detect\n\n##### Positional Arguments\n- **self**: `Evision.Text.TextDetectorCNN.t()`\n- **inputImage**: `Evision.Mat`.\n\n  an image expected to be a CV_U8C3 of any size\n\n##### Return\n- **bbox**: `[Rect]`.\n\n  a vector of Rect that will store the detected word bounding box\n\n- **confidence**: `[float]`.\n\n  a vector of float that will be updated with the confidence the classifier has for the selected bounding box\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(inputImage) -> Bbox, confidence\n```","ref":"Evision.Text.TextDetectorCNN.html#detect/2"},{"type":"type","title":"Evision.Text.TextDetectorCNN.t/0","doc":"Type that represents an `Text.TextDetectorCNN` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Text.TextDetectorCNN.html#t:t/0"},{"type":"module","title":"Evision.ThinPlateSplineShapeTransformer","doc":"","ref":"Evision.ThinPlateSplineShapeTransformer.html"},{"type":"function","title":"Evision.ThinPlateSplineShapeTransformer.getRegularizationParameter/1","doc":"getRegularizationParameter\n\n##### Positional Arguments\n- **self**: `Evision.ThinPlateSplineShapeTransformer.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetRegularizationParameter() -> retval\n```","ref":"Evision.ThinPlateSplineShapeTransformer.html#getRegularizationParameter/1"},{"type":"function","title":"Evision.ThinPlateSplineShapeTransformer.setRegularizationParameter/1","doc":"","ref":"Evision.ThinPlateSplineShapeTransformer.html#setRegularizationParameter/1"},{"type":"function","title":"Evision.ThinPlateSplineShapeTransformer.setRegularizationParameter/2","doc":"Set the regularization parameter for relaxing the exact interpolation requirements of the TPS\nalgorithm.\n\n##### Positional Arguments\n- **self**: `Evision.ThinPlateSplineShapeTransformer.t()`\n- **beta**: `double`.\n\n  value of the regularization parameter.\n\nPython prototype (for reference only):\n```python3\nsetRegularizationParameter(beta) -> None\n```","ref":"Evision.ThinPlateSplineShapeTransformer.html#setRegularizationParameter/2"},{"type":"type","title":"Evision.ThinPlateSplineShapeTransformer.t/0","doc":"Type that represents an `ThinPlateSplineShapeTransformer` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.ThinPlateSplineShapeTransformer.html#t:t/0"},{"type":"module","title":"Evision.ThresholdTypes","doc":"","ref":"Evision.ThresholdTypes.html"},{"type":"function","title":"Evision.ThresholdTypes.cv_THRESH_BINARY/0","doc":"","ref":"Evision.ThresholdTypes.html#cv_THRESH_BINARY/0"},{"type":"function","title":"Evision.ThresholdTypes.cv_THRESH_BINARY_INV/0","doc":"","ref":"Evision.ThresholdTypes.html#cv_THRESH_BINARY_INV/0"},{"type":"function","title":"Evision.ThresholdTypes.cv_THRESH_MASK/0","doc":"","ref":"Evision.ThresholdTypes.html#cv_THRESH_MASK/0"},{"type":"function","title":"Evision.ThresholdTypes.cv_THRESH_OTSU/0","doc":"","ref":"Evision.ThresholdTypes.html#cv_THRESH_OTSU/0"},{"type":"function","title":"Evision.ThresholdTypes.cv_THRESH_TOZERO/0","doc":"","ref":"Evision.ThresholdTypes.html#cv_THRESH_TOZERO/0"},{"type":"function","title":"Evision.ThresholdTypes.cv_THRESH_TOZERO_INV/0","doc":"","ref":"Evision.ThresholdTypes.html#cv_THRESH_TOZERO_INV/0"},{"type":"function","title":"Evision.ThresholdTypes.cv_THRESH_TRIANGLE/0","doc":"","ref":"Evision.ThresholdTypes.html#cv_THRESH_TRIANGLE/0"},{"type":"function","title":"Evision.ThresholdTypes.cv_THRESH_TRUNC/0","doc":"","ref":"Evision.ThresholdTypes.html#cv_THRESH_TRUNC/0"},{"type":"type","title":"Evision.ThresholdTypes.enum/0","doc":"","ref":"Evision.ThresholdTypes.html#t:enum/0"},{"type":"module","title":"Evision.TickMeter","doc":"","ref":"Evision.TickMeter.html"},{"type":"function","title":"Evision.TickMeter.getAvgTimeMilli/1","doc":"getAvgTimeMilli\n\n##### Positional Arguments\n- **self**: `Evision.TickMeter.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetAvgTimeMilli() -> retval\n```","ref":"Evision.TickMeter.html#getAvgTimeMilli/1"},{"type":"function","title":"Evision.TickMeter.getAvgTimeSec/1","doc":"getAvgTimeSec\n\n##### Positional Arguments\n- **self**: `Evision.TickMeter.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetAvgTimeSec() -> retval\n```","ref":"Evision.TickMeter.html#getAvgTimeSec/1"},{"type":"function","title":"Evision.TickMeter.getCounter/1","doc":"getCounter\n\n##### Positional Arguments\n- **self**: `Evision.TickMeter.t()`\n\n##### Return\n- **retval**: `int64`\n\nPython prototype (for reference only):\n```python3\ngetCounter() -> retval\n```","ref":"Evision.TickMeter.html#getCounter/1"},{"type":"function","title":"Evision.TickMeter.getFPS/1","doc":"getFPS\n\n##### Positional Arguments\n- **self**: `Evision.TickMeter.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetFPS() -> retval\n```","ref":"Evision.TickMeter.html#getFPS/1"},{"type":"function","title":"Evision.TickMeter.getTimeMicro/1","doc":"getTimeMicro\n\n##### Positional Arguments\n- **self**: `Evision.TickMeter.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetTimeMicro() -> retval\n```","ref":"Evision.TickMeter.html#getTimeMicro/1"},{"type":"function","title":"Evision.TickMeter.getTimeMilli/1","doc":"getTimeMilli\n\n##### Positional Arguments\n- **self**: `Evision.TickMeter.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetTimeMilli() -> retval\n```","ref":"Evision.TickMeter.html#getTimeMilli/1"},{"type":"function","title":"Evision.TickMeter.getTimeSec/1","doc":"getTimeSec\n\n##### Positional Arguments\n- **self**: `Evision.TickMeter.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetTimeSec() -> retval\n```","ref":"Evision.TickMeter.html#getTimeSec/1"},{"type":"function","title":"Evision.TickMeter.getTimeTicks/1","doc":"getTimeTicks\n\n##### Positional Arguments\n- **self**: `Evision.TickMeter.t()`\n\n##### Return\n- **retval**: `int64`\n\nPython prototype (for reference only):\n```python3\ngetTimeTicks() -> retval\n```","ref":"Evision.TickMeter.html#getTimeTicks/1"},{"type":"function","title":"Evision.TickMeter.reset/1","doc":"reset\n\n##### Positional Arguments\n- **self**: `Evision.TickMeter.t()`\n\nPython prototype (for reference only):\n```python3\nreset() -> None\n```","ref":"Evision.TickMeter.html#reset/1"},{"type":"function","title":"Evision.TickMeter.start/1","doc":"start\n\n##### Positional Arguments\n- **self**: `Evision.TickMeter.t()`\n\nPython prototype (for reference only):\n```python3\nstart() -> None\n```","ref":"Evision.TickMeter.html#start/1"},{"type":"function","title":"Evision.TickMeter.stop/1","doc":"stop\n\n##### Positional Arguments\n- **self**: `Evision.TickMeter.t()`\n\nPython prototype (for reference only):\n```python3\nstop() -> None\n```","ref":"Evision.TickMeter.html#stop/1"},{"type":"function","title":"Evision.TickMeter.tickMeter/0","doc":"TickMeter\n##### Return\n- **self**: `Evision.TickMeter.t()`\n\nPython prototype (for reference only):\n```python3\nTickMeter() ->  \n```","ref":"Evision.TickMeter.html#tickMeter/0"},{"type":"function","title":"Evision.TickMeter.tickMeter/1","doc":"","ref":"Evision.TickMeter.html#tickMeter/1"},{"type":"type","title":"Evision.TickMeter.t/0","doc":"Type that represents an `TickMeter` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.TickMeter.html#t:t/0"},{"type":"module","title":"Evision.Tonemap","doc":"","ref":"Evision.Tonemap.html"},{"type":"function","title":"Evision.Tonemap.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.Tonemap.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.Tonemap.html#clear/1"},{"type":"function","title":"Evision.Tonemap.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.Tonemap.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.Tonemap.html#empty/1"},{"type":"function","title":"Evision.Tonemap.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.Tonemap.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.Tonemap.html#getDefaultName/1"},{"type":"function","title":"Evision.Tonemap.getGamma/1","doc":"getGamma\n\n##### Positional Arguments\n- **self**: `Evision.Tonemap.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetGamma() -> retval\n```","ref":"Evision.Tonemap.html#getGamma/1"},{"type":"function","title":"Evision.Tonemap.process/1","doc":"","ref":"Evision.Tonemap.html#process/1"},{"type":"function","title":"Evision.Tonemap.process/2","doc":"Tonemaps image\n\n##### Positional Arguments\n- **self**: `Evision.Tonemap.t()`\n- **src**: `Evision.Mat`.\n\n  source image - CV_32FC3 Mat (float 32 bits 3 channels)\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  destination image - CV_32FC3 Mat with values in [0, 1] range\n\nPython prototype (for reference only):\n```python3\nprocess(src[, dst]) -> dst\n```","ref":"Evision.Tonemap.html#process/2"},{"type":"function","title":"Evision.Tonemap.process/3","doc":"Tonemaps image\n\n##### Positional Arguments\n- **self**: `Evision.Tonemap.t()`\n- **src**: `Evision.Mat`.\n\n  source image - CV_32FC3 Mat (float 32 bits 3 channels)\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  destination image - CV_32FC3 Mat with values in [0, 1] range\n\nPython prototype (for reference only):\n```python3\nprocess(src[, dst]) -> dst\n```","ref":"Evision.Tonemap.html#process/3"},{"type":"function","title":"Evision.Tonemap.read/1","doc":"","ref":"Evision.Tonemap.html#read/1"},{"type":"function","title":"Evision.Tonemap.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Tonemap.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.Tonemap.html#read/2"},{"type":"function","title":"Evision.Tonemap.save/1","doc":"","ref":"Evision.Tonemap.html#save/1"},{"type":"function","title":"Evision.Tonemap.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.Tonemap.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.Tonemap.html#save/2"},{"type":"function","title":"Evision.Tonemap.setGamma/1","doc":"","ref":"Evision.Tonemap.html#setGamma/1"},{"type":"function","title":"Evision.Tonemap.setGamma/2","doc":"setGamma\n\n##### Positional Arguments\n- **self**: `Evision.Tonemap.t()`\n- **gamma**: `float`\n\nPython prototype (for reference only):\n```python3\nsetGamma(gamma) -> None\n```","ref":"Evision.Tonemap.html#setGamma/2"},{"type":"function","title":"Evision.Tonemap.write/1","doc":"","ref":"Evision.Tonemap.html#write/1"},{"type":"function","title":"Evision.Tonemap.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.Tonemap.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.Tonemap.html#write/2"},{"type":"function","title":"Evision.Tonemap.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.Tonemap.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.Tonemap.html#write/3"},{"type":"type","title":"Evision.Tonemap.t/0","doc":"Type that represents an `Tonemap` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Tonemap.html#t:t/0"},{"type":"module","title":"Evision.TonemapDrago","doc":"","ref":"Evision.TonemapDrago.html"},{"type":"function","title":"Evision.TonemapDrago.getBias/1","doc":"getBias\n\n##### Positional Arguments\n- **self**: `Evision.TonemapDrago.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetBias() -> retval\n```","ref":"Evision.TonemapDrago.html#getBias/1"},{"type":"function","title":"Evision.TonemapDrago.getSaturation/1","doc":"getSaturation\n\n##### Positional Arguments\n- **self**: `Evision.TonemapDrago.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetSaturation() -> retval\n```","ref":"Evision.TonemapDrago.html#getSaturation/1"},{"type":"function","title":"Evision.TonemapDrago.setBias/1","doc":"","ref":"Evision.TonemapDrago.html#setBias/1"},{"type":"function","title":"Evision.TonemapDrago.setBias/2","doc":"setBias\n\n##### Positional Arguments\n- **self**: `Evision.TonemapDrago.t()`\n- **bias**: `float`\n\nPython prototype (for reference only):\n```python3\nsetBias(bias) -> None\n```","ref":"Evision.TonemapDrago.html#setBias/2"},{"type":"function","title":"Evision.TonemapDrago.setSaturation/1","doc":"","ref":"Evision.TonemapDrago.html#setSaturation/1"},{"type":"function","title":"Evision.TonemapDrago.setSaturation/2","doc":"setSaturation\n\n##### Positional Arguments\n- **self**: `Evision.TonemapDrago.t()`\n- **saturation**: `float`\n\nPython prototype (for reference only):\n```python3\nsetSaturation(saturation) -> None\n```","ref":"Evision.TonemapDrago.html#setSaturation/2"},{"type":"type","title":"Evision.TonemapDrago.t/0","doc":"Type that represents an `TonemapDrago` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.TonemapDrago.html#t:t/0"},{"type":"module","title":"Evision.TonemapMantiuk","doc":"","ref":"Evision.TonemapMantiuk.html"},{"type":"function","title":"Evision.TonemapMantiuk.getSaturation/1","doc":"getSaturation\n\n##### Positional Arguments\n- **self**: `Evision.TonemapMantiuk.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetSaturation() -> retval\n```","ref":"Evision.TonemapMantiuk.html#getSaturation/1"},{"type":"function","title":"Evision.TonemapMantiuk.getScale/1","doc":"getScale\n\n##### Positional Arguments\n- **self**: `Evision.TonemapMantiuk.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetScale() -> retval\n```","ref":"Evision.TonemapMantiuk.html#getScale/1"},{"type":"function","title":"Evision.TonemapMantiuk.setSaturation/1","doc":"","ref":"Evision.TonemapMantiuk.html#setSaturation/1"},{"type":"function","title":"Evision.TonemapMantiuk.setSaturation/2","doc":"setSaturation\n\n##### Positional Arguments\n- **self**: `Evision.TonemapMantiuk.t()`\n- **saturation**: `float`\n\nPython prototype (for reference only):\n```python3\nsetSaturation(saturation) -> None\n```","ref":"Evision.TonemapMantiuk.html#setSaturation/2"},{"type":"function","title":"Evision.TonemapMantiuk.setScale/1","doc":"","ref":"Evision.TonemapMantiuk.html#setScale/1"},{"type":"function","title":"Evision.TonemapMantiuk.setScale/2","doc":"setScale\n\n##### Positional Arguments\n- **self**: `Evision.TonemapMantiuk.t()`\n- **scale**: `float`\n\nPython prototype (for reference only):\n```python3\nsetScale(scale) -> None\n```","ref":"Evision.TonemapMantiuk.html#setScale/2"},{"type":"type","title":"Evision.TonemapMantiuk.t/0","doc":"Type that represents an `TonemapMantiuk` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.TonemapMantiuk.html#t:t/0"},{"type":"module","title":"Evision.TonemapReinhard","doc":"","ref":"Evision.TonemapReinhard.html"},{"type":"function","title":"Evision.TonemapReinhard.getColorAdaptation/1","doc":"getColorAdaptation\n\n##### Positional Arguments\n- **self**: `Evision.TonemapReinhard.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetColorAdaptation() -> retval\n```","ref":"Evision.TonemapReinhard.html#getColorAdaptation/1"},{"type":"function","title":"Evision.TonemapReinhard.getIntensity/1","doc":"getIntensity\n\n##### Positional Arguments\n- **self**: `Evision.TonemapReinhard.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetIntensity() -> retval\n```","ref":"Evision.TonemapReinhard.html#getIntensity/1"},{"type":"function","title":"Evision.TonemapReinhard.getLightAdaptation/1","doc":"getLightAdaptation\n\n##### Positional Arguments\n- **self**: `Evision.TonemapReinhard.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetLightAdaptation() -> retval\n```","ref":"Evision.TonemapReinhard.html#getLightAdaptation/1"},{"type":"function","title":"Evision.TonemapReinhard.setColorAdaptation/1","doc":"","ref":"Evision.TonemapReinhard.html#setColorAdaptation/1"},{"type":"function","title":"Evision.TonemapReinhard.setColorAdaptation/2","doc":"setColorAdaptation\n\n##### Positional Arguments\n- **self**: `Evision.TonemapReinhard.t()`\n- **color_adapt**: `float`\n\nPython prototype (for reference only):\n```python3\nsetColorAdaptation(color_adapt) -> None\n```","ref":"Evision.TonemapReinhard.html#setColorAdaptation/2"},{"type":"function","title":"Evision.TonemapReinhard.setIntensity/1","doc":"","ref":"Evision.TonemapReinhard.html#setIntensity/1"},{"type":"function","title":"Evision.TonemapReinhard.setIntensity/2","doc":"setIntensity\n\n##### Positional Arguments\n- **self**: `Evision.TonemapReinhard.t()`\n- **intensity**: `float`\n\nPython prototype (for reference only):\n```python3\nsetIntensity(intensity) -> None\n```","ref":"Evision.TonemapReinhard.html#setIntensity/2"},{"type":"function","title":"Evision.TonemapReinhard.setLightAdaptation/1","doc":"","ref":"Evision.TonemapReinhard.html#setLightAdaptation/1"},{"type":"function","title":"Evision.TonemapReinhard.setLightAdaptation/2","doc":"setLightAdaptation\n\n##### Positional Arguments\n- **self**: `Evision.TonemapReinhard.t()`\n- **light_adapt**: `float`\n\nPython prototype (for reference only):\n```python3\nsetLightAdaptation(light_adapt) -> None\n```","ref":"Evision.TonemapReinhard.html#setLightAdaptation/2"},{"type":"type","title":"Evision.TonemapReinhard.t/0","doc":"Type that represents an `TonemapReinhard` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.TonemapReinhard.html#t:t/0"},{"type":"module","title":"Evision.Tracker","doc":"","ref":"Evision.Tracker.html"},{"type":"function","title":"Evision.Tracker.init/1","doc":"","ref":"Evision.Tracker.html#init/1"},{"type":"function","title":"Evision.Tracker.init/3","doc":"Initialize the tracker with a known bounding box that surrounded the target\n\n##### Positional Arguments\n- **self**: `Evision.Tracker.t()`\n- **image**: `Evision.Mat`.\n\n  The initial frame\n\n- **boundingBox**: `Rect`.\n\n  The initial bounding box\n\nPython prototype (for reference only):\n```python3\ninit(image, boundingBox) -> None\n```","ref":"Evision.Tracker.html#init/3"},{"type":"function","title":"Evision.Tracker.update/1","doc":"","ref":"Evision.Tracker.html#update/1"},{"type":"function","title":"Evision.Tracker.update/2","doc":"Update the tracker, find the new most likely bounding box for the target\n\n##### Positional Arguments\n- **self**: `Evision.Tracker.t()`\n- **image**: `Evision.Mat`.\n\n  The current frame\n\n##### Return\n- **retval**: `bool`\n- **boundingBox**: `Rect`.\n\n  The bounding box that represent the new target location, if true was returned, not\n  modified otherwise\n\n@return True means that target was located and false means that tracker cannot locate target in\ncurrent frame. Note, that latter *does not* imply that tracker has failed, maybe target is indeed\nmissing from the frame (say, out of sight)\n\nPython prototype (for reference only):\n```python3\nupdate(image) -> retval, boundingBox\n```","ref":"Evision.Tracker.html#update/2"},{"type":"type","title":"Evision.Tracker.t/0","doc":"Type that represents an `Tracker` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Tracker.html#t:t/0"},{"type":"module","title":"Evision.TrackerCSRT","doc":"","ref":"Evision.TrackerCSRT.html"},{"type":"function","title":"Evision.TrackerCSRT.create/0","doc":"Create CSRT tracker instance\n##### Keyword Arguments\n- **parameters**: `Evision.TrackerCSRT.Params`.\n\n  CSRT parameters TrackerCSRT::Params\n\n##### Return\n- **retval**: `Evision.TrackerCSRT.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, parameters]) -> retval\n```","ref":"Evision.TrackerCSRT.html#create/0"},{"type":"function","title":"Evision.TrackerCSRT.create/1","doc":"Create CSRT tracker instance\n##### Keyword Arguments\n- **parameters**: `Evision.TrackerCSRT.Params`.\n\n  CSRT parameters TrackerCSRT::Params\n\n##### Return\n- **retval**: `Evision.TrackerCSRT.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, parameters]) -> retval\n```","ref":"Evision.TrackerCSRT.html#create/1"},{"type":"function","title":"Evision.TrackerCSRT.setInitialMask/1","doc":"","ref":"Evision.TrackerCSRT.html#setInitialMask/1"},{"type":"function","title":"Evision.TrackerCSRT.setInitialMask/2","doc":"setInitialMask\n\n##### Positional Arguments\n- **self**: `Evision.TrackerCSRT.t()`\n- **mask**: `Evision.Mat`\n\nPython prototype (for reference only):\n```python3\nsetInitialMask(mask) -> None\n```","ref":"Evision.TrackerCSRT.html#setInitialMask/2"},{"type":"type","title":"Evision.TrackerCSRT.t/0","doc":"Type that represents an `TrackerCSRT` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.TrackerCSRT.html#t:t/0"},{"type":"module","title":"Evision.TrackerCSRT.Params","doc":"","ref":"Evision.TrackerCSRT.Params.html"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_admm_iterations/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_admm_iterations/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_background_ratio/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_background_ratio/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_cheb_attenuation/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_cheb_attenuation/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_filter_lr/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_filter_lr/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_gsl_sigma/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_gsl_sigma/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_histogram_bins/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_histogram_bins/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_histogram_lr/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_histogram_lr/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_hog_clip/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_hog_clip/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_hog_orientations/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_hog_orientations/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_kaiser_alpha/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_kaiser_alpha/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_num_hog_channels_used/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_num_hog_channels_used/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_number_of_scales/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_number_of_scales/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_padding/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_padding/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_psr_threshold/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_psr_threshold/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_scale_lr/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_scale_lr/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_scale_model_max_area/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_scale_model_max_area/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_scale_sigma_factor/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_scale_sigma_factor/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_scale_step/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_scale_step/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_template_size/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_template_size/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_use_channel_weights/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_use_channel_weights/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_use_color_names/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_use_color_names/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_use_gray/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_use_gray/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_use_hog/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_use_hog/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_use_rgb/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_use_rgb/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_use_segmentation/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_use_segmentation/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_weights_lr/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_weights_lr/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.get_window_function/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#get_window_function/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.params/0","doc":"TrackerCSRT_Params\n##### Return\n- **self**: `Evision.TrackerCSRT.Params.t()`\n\nPython prototype (for reference only):\n```python3\nTrackerCSRT_Params() ->  \n```","ref":"Evision.TrackerCSRT.Params.html#params/0"},{"type":"function","title":"Evision.TrackerCSRT.Params.params/1","doc":"","ref":"Evision.TrackerCSRT.Params.html#params/1"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_admm_iterations/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_admm_iterations/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_background_ratio/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_background_ratio/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_cheb_attenuation/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_cheb_attenuation/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_filter_lr/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_filter_lr/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_gsl_sigma/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_gsl_sigma/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_histogram_bins/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_histogram_bins/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_histogram_lr/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_histogram_lr/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_hog_clip/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_hog_clip/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_hog_orientations/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_hog_orientations/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_kaiser_alpha/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_kaiser_alpha/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_num_hog_channels_used/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_num_hog_channels_used/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_number_of_scales/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_number_of_scales/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_padding/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_padding/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_psr_threshold/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_psr_threshold/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_scale_lr/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_scale_lr/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_scale_model_max_area/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_scale_model_max_area/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_scale_sigma_factor/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_scale_sigma_factor/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_scale_step/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_scale_step/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_template_size/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_template_size/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_use_channel_weights/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_use_channel_weights/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_use_color_names/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_use_color_names/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_use_gray/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_use_gray/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_use_hog/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_use_hog/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_use_rgb/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_use_rgb/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_use_segmentation/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_use_segmentation/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_weights_lr/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_weights_lr/2"},{"type":"function","title":"Evision.TrackerCSRT.Params.set_window_function/2","doc":"","ref":"Evision.TrackerCSRT.Params.html#set_window_function/2"},{"type":"type","title":"Evision.TrackerCSRT.Params.t/0","doc":"Type that represents an `TrackerCSRT.Params` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.TrackerCSRT.Params.html#t:t/0"},{"type":"module","title":"Evision.TrackerDaSiamRPN","doc":"","ref":"Evision.TrackerDaSiamRPN.html"},{"type":"function","title":"Evision.TrackerDaSiamRPN.create/0","doc":"Constructor\n##### Keyword Arguments\n- **parameters**: `Evision.TrackerDaSiamRPN.Params`.\n\n  DaSiamRPN parameters TrackerDaSiamRPN::Params\n\n##### Return\n- **retval**: `Evision.TrackerDaSiamRPN.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, parameters]) -> retval\n```","ref":"Evision.TrackerDaSiamRPN.html#create/0"},{"type":"function","title":"Evision.TrackerDaSiamRPN.create/1","doc":"Constructor\n##### Keyword Arguments\n- **parameters**: `Evision.TrackerDaSiamRPN.Params`.\n\n  DaSiamRPN parameters TrackerDaSiamRPN::Params\n\n##### Return\n- **retval**: `Evision.TrackerDaSiamRPN.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, parameters]) -> retval\n```","ref":"Evision.TrackerDaSiamRPN.html#create/1"},{"type":"function","title":"Evision.TrackerDaSiamRPN.getTrackingScore/1","doc":"Return tracking score\n\n##### Positional Arguments\n- **self**: `Evision.TrackerDaSiamRPN.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetTrackingScore() -> retval\n```","ref":"Evision.TrackerDaSiamRPN.html#getTrackingScore/1"},{"type":"type","title":"Evision.TrackerDaSiamRPN.t/0","doc":"Type that represents an `TrackerDaSiamRPN` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.TrackerDaSiamRPN.html#t:t/0"},{"type":"module","title":"Evision.TrackerDaSiamRPN.Params","doc":"","ref":"Evision.TrackerDaSiamRPN.Params.html"},{"type":"function","title":"Evision.TrackerDaSiamRPN.Params.get_backend/1","doc":"","ref":"Evision.TrackerDaSiamRPN.Params.html#get_backend/1"},{"type":"function","title":"Evision.TrackerDaSiamRPN.Params.get_kernel_cls1/1","doc":"","ref":"Evision.TrackerDaSiamRPN.Params.html#get_kernel_cls1/1"},{"type":"function","title":"Evision.TrackerDaSiamRPN.Params.get_kernel_r1/1","doc":"","ref":"Evision.TrackerDaSiamRPN.Params.html#get_kernel_r1/1"},{"type":"function","title":"Evision.TrackerDaSiamRPN.Params.get_model/1","doc":"","ref":"Evision.TrackerDaSiamRPN.Params.html#get_model/1"},{"type":"function","title":"Evision.TrackerDaSiamRPN.Params.get_target/1","doc":"","ref":"Evision.TrackerDaSiamRPN.Params.html#get_target/1"},{"type":"function","title":"Evision.TrackerDaSiamRPN.Params.params/0","doc":"TrackerDaSiamRPN_Params\n##### Return\n- **self**: `Evision.TrackerDaSiamRPN.Params.t()`\n\nPython prototype (for reference only):\n```python3\nTrackerDaSiamRPN_Params() ->  \n```","ref":"Evision.TrackerDaSiamRPN.Params.html#params/0"},{"type":"function","title":"Evision.TrackerDaSiamRPN.Params.params/1","doc":"","ref":"Evision.TrackerDaSiamRPN.Params.html#params/1"},{"type":"function","title":"Evision.TrackerDaSiamRPN.Params.set_backend/2","doc":"","ref":"Evision.TrackerDaSiamRPN.Params.html#set_backend/2"},{"type":"function","title":"Evision.TrackerDaSiamRPN.Params.set_kernel_cls1/2","doc":"","ref":"Evision.TrackerDaSiamRPN.Params.html#set_kernel_cls1/2"},{"type":"function","title":"Evision.TrackerDaSiamRPN.Params.set_kernel_r1/2","doc":"","ref":"Evision.TrackerDaSiamRPN.Params.html#set_kernel_r1/2"},{"type":"function","title":"Evision.TrackerDaSiamRPN.Params.set_model/2","doc":"","ref":"Evision.TrackerDaSiamRPN.Params.html#set_model/2"},{"type":"function","title":"Evision.TrackerDaSiamRPN.Params.set_target/2","doc":"","ref":"Evision.TrackerDaSiamRPN.Params.html#set_target/2"},{"type":"type","title":"Evision.TrackerDaSiamRPN.Params.t/0","doc":"Type that represents an `TrackerDaSiamRPN.Params` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.TrackerDaSiamRPN.Params.html#t:t/0"},{"type":"module","title":"Evision.TrackerGOTURN","doc":"","ref":"Evision.TrackerGOTURN.html"},{"type":"function","title":"Evision.TrackerGOTURN.create/0","doc":"Constructor\n##### Keyword Arguments\n- **parameters**: `Evision.TrackerGOTURN.Params`.\n\n  GOTURN parameters TrackerGOTURN::Params\n\n##### Return\n- **retval**: `Evision.TrackerGOTURN.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, parameters]) -> retval\n```","ref":"Evision.TrackerGOTURN.html#create/0"},{"type":"function","title":"Evision.TrackerGOTURN.create/1","doc":"Constructor\n##### Keyword Arguments\n- **parameters**: `Evision.TrackerGOTURN.Params`.\n\n  GOTURN parameters TrackerGOTURN::Params\n\n##### Return\n- **retval**: `Evision.TrackerGOTURN.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, parameters]) -> retval\n```","ref":"Evision.TrackerGOTURN.html#create/1"},{"type":"type","title":"Evision.TrackerGOTURN.t/0","doc":"Type that represents an `TrackerGOTURN` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.TrackerGOTURN.html#t:t/0"},{"type":"module","title":"Evision.TrackerGOTURN.Params","doc":"","ref":"Evision.TrackerGOTURN.Params.html"},{"type":"function","title":"Evision.TrackerGOTURN.Params.get_modelBin/1","doc":"","ref":"Evision.TrackerGOTURN.Params.html#get_modelBin/1"},{"type":"function","title":"Evision.TrackerGOTURN.Params.get_modelTxt/1","doc":"","ref":"Evision.TrackerGOTURN.Params.html#get_modelTxt/1"},{"type":"function","title":"Evision.TrackerGOTURN.Params.params/0","doc":"TrackerGOTURN_Params\n##### Return\n- **self**: `Evision.TrackerGOTURN.Params.t()`\n\nPython prototype (for reference only):\n```python3\nTrackerGOTURN_Params() ->  \n```","ref":"Evision.TrackerGOTURN.Params.html#params/0"},{"type":"function","title":"Evision.TrackerGOTURN.Params.params/1","doc":"","ref":"Evision.TrackerGOTURN.Params.html#params/1"},{"type":"function","title":"Evision.TrackerGOTURN.Params.set_modelBin/2","doc":"","ref":"Evision.TrackerGOTURN.Params.html#set_modelBin/2"},{"type":"function","title":"Evision.TrackerGOTURN.Params.set_modelTxt/2","doc":"","ref":"Evision.TrackerGOTURN.Params.html#set_modelTxt/2"},{"type":"type","title":"Evision.TrackerGOTURN.Params.t/0","doc":"Type that represents an `TrackerGOTURN.Params` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.TrackerGOTURN.Params.html#t:t/0"},{"type":"module","title":"Evision.TrackerKCF","doc":"","ref":"Evision.TrackerKCF.html"},{"type":"function","title":"Evision.TrackerKCF.create/0","doc":"Create KCF tracker instance\n##### Keyword Arguments\n- **parameters**: `Evision.TrackerKCF.Params`.\n\n  KCF parameters TrackerKCF::Params\n\n##### Return\n- **retval**: `Evision.TrackerKCF.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, parameters]) -> retval\n```","ref":"Evision.TrackerKCF.html#create/0"},{"type":"function","title":"Evision.TrackerKCF.create/1","doc":"Create KCF tracker instance\n##### Keyword Arguments\n- **parameters**: `Evision.TrackerKCF.Params`.\n\n  KCF parameters TrackerKCF::Params\n\n##### Return\n- **retval**: `Evision.TrackerKCF.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, parameters]) -> retval\n```","ref":"Evision.TrackerKCF.html#create/1"},{"type":"type","title":"Evision.TrackerKCF.t/0","doc":"Type that represents an `TrackerKCF` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.TrackerKCF.html#t:t/0"},{"type":"module","title":"Evision.TrackerKCF.MODE","doc":"","ref":"Evision.TrackerKCF.MODE.html"},{"type":"function","title":"Evision.TrackerKCF.MODE.cv_CN/0","doc":"","ref":"Evision.TrackerKCF.MODE.html#cv_CN/0"},{"type":"function","title":"Evision.TrackerKCF.MODE.cv_CUSTOM/0","doc":"","ref":"Evision.TrackerKCF.MODE.html#cv_CUSTOM/0"},{"type":"function","title":"Evision.TrackerKCF.MODE.cv_GRAY/0","doc":"","ref":"Evision.TrackerKCF.MODE.html#cv_GRAY/0"},{"type":"type","title":"Evision.TrackerKCF.MODE.enum/0","doc":"","ref":"Evision.TrackerKCF.MODE.html#t:enum/0"},{"type":"module","title":"Evision.TrackerKCF.Params","doc":"","ref":"Evision.TrackerKCF.Params.html"},{"type":"function","title":"Evision.TrackerKCF.Params.get_compress_feature/1","doc":"","ref":"Evision.TrackerKCF.Params.html#get_compress_feature/1"},{"type":"function","title":"Evision.TrackerKCF.Params.get_compressed_size/1","doc":"","ref":"Evision.TrackerKCF.Params.html#get_compressed_size/1"},{"type":"function","title":"Evision.TrackerKCF.Params.get_desc_npca/1","doc":"","ref":"Evision.TrackerKCF.Params.html#get_desc_npca/1"},{"type":"function","title":"Evision.TrackerKCF.Params.get_desc_pca/1","doc":"","ref":"Evision.TrackerKCF.Params.html#get_desc_pca/1"},{"type":"function","title":"Evision.TrackerKCF.Params.get_detect_thresh/1","doc":"","ref":"Evision.TrackerKCF.Params.html#get_detect_thresh/1"},{"type":"function","title":"Evision.TrackerKCF.Params.get_interp_factor/1","doc":"","ref":"Evision.TrackerKCF.Params.html#get_interp_factor/1"},{"type":"function","title":"Evision.TrackerKCF.Params.get_lambda/1","doc":"","ref":"Evision.TrackerKCF.Params.html#get_lambda/1"},{"type":"function","title":"Evision.TrackerKCF.Params.get_max_patch_size/1","doc":"","ref":"Evision.TrackerKCF.Params.html#get_max_patch_size/1"},{"type":"function","title":"Evision.TrackerKCF.Params.get_output_sigma_factor/1","doc":"","ref":"Evision.TrackerKCF.Params.html#get_output_sigma_factor/1"},{"type":"function","title":"Evision.TrackerKCF.Params.get_pca_learning_rate/1","doc":"","ref":"Evision.TrackerKCF.Params.html#get_pca_learning_rate/1"},{"type":"function","title":"Evision.TrackerKCF.Params.get_resize/1","doc":"","ref":"Evision.TrackerKCF.Params.html#get_resize/1"},{"type":"function","title":"Evision.TrackerKCF.Params.get_sigma/1","doc":"","ref":"Evision.TrackerKCF.Params.html#get_sigma/1"},{"type":"function","title":"Evision.TrackerKCF.Params.get_split_coeff/1","doc":"","ref":"Evision.TrackerKCF.Params.html#get_split_coeff/1"},{"type":"function","title":"Evision.TrackerKCF.Params.get_wrap_kernel/1","doc":"","ref":"Evision.TrackerKCF.Params.html#get_wrap_kernel/1"},{"type":"function","title":"Evision.TrackerKCF.Params.params/0","doc":"TrackerKCF_Params\n##### Return\n- **self**: `Evision.TrackerKCF.Params.t()`\n\nPython prototype (for reference only):\n```python3\nTrackerKCF_Params() ->  \n```","ref":"Evision.TrackerKCF.Params.html#params/0"},{"type":"function","title":"Evision.TrackerKCF.Params.params/1","doc":"","ref":"Evision.TrackerKCF.Params.html#params/1"},{"type":"function","title":"Evision.TrackerKCF.Params.set_compress_feature/2","doc":"","ref":"Evision.TrackerKCF.Params.html#set_compress_feature/2"},{"type":"function","title":"Evision.TrackerKCF.Params.set_compressed_size/2","doc":"","ref":"Evision.TrackerKCF.Params.html#set_compressed_size/2"},{"type":"function","title":"Evision.TrackerKCF.Params.set_desc_npca/2","doc":"","ref":"Evision.TrackerKCF.Params.html#set_desc_npca/2"},{"type":"function","title":"Evision.TrackerKCF.Params.set_desc_pca/2","doc":"","ref":"Evision.TrackerKCF.Params.html#set_desc_pca/2"},{"type":"function","title":"Evision.TrackerKCF.Params.set_detect_thresh/2","doc":"","ref":"Evision.TrackerKCF.Params.html#set_detect_thresh/2"},{"type":"function","title":"Evision.TrackerKCF.Params.set_interp_factor/2","doc":"","ref":"Evision.TrackerKCF.Params.html#set_interp_factor/2"},{"type":"function","title":"Evision.TrackerKCF.Params.set_lambda/2","doc":"","ref":"Evision.TrackerKCF.Params.html#set_lambda/2"},{"type":"function","title":"Evision.TrackerKCF.Params.set_max_patch_size/2","doc":"","ref":"Evision.TrackerKCF.Params.html#set_max_patch_size/2"},{"type":"function","title":"Evision.TrackerKCF.Params.set_output_sigma_factor/2","doc":"","ref":"Evision.TrackerKCF.Params.html#set_output_sigma_factor/2"},{"type":"function","title":"Evision.TrackerKCF.Params.set_pca_learning_rate/2","doc":"","ref":"Evision.TrackerKCF.Params.html#set_pca_learning_rate/2"},{"type":"function","title":"Evision.TrackerKCF.Params.set_resize/2","doc":"","ref":"Evision.TrackerKCF.Params.html#set_resize/2"},{"type":"function","title":"Evision.TrackerKCF.Params.set_sigma/2","doc":"","ref":"Evision.TrackerKCF.Params.html#set_sigma/2"},{"type":"function","title":"Evision.TrackerKCF.Params.set_split_coeff/2","doc":"","ref":"Evision.TrackerKCF.Params.html#set_split_coeff/2"},{"type":"function","title":"Evision.TrackerKCF.Params.set_wrap_kernel/2","doc":"","ref":"Evision.TrackerKCF.Params.html#set_wrap_kernel/2"},{"type":"type","title":"Evision.TrackerKCF.Params.t/0","doc":"Type that represents an `TrackerKCF.Params` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.TrackerKCF.Params.html#t:t/0"},{"type":"module","title":"Evision.TrackerMIL","doc":"","ref":"Evision.TrackerMIL.html"},{"type":"function","title":"Evision.TrackerMIL.create/0","doc":"Create MIL tracker instance\n##### Keyword Arguments\n- **parameters**: `Evision.TrackerMIL.Params`.\n\n  MIL parameters TrackerMIL::Params\n\n##### Return\n- **retval**: `Evision.TrackerMIL.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, parameters]) -> retval\n```","ref":"Evision.TrackerMIL.html#create/0"},{"type":"function","title":"Evision.TrackerMIL.create/1","doc":"Create MIL tracker instance\n##### Keyword Arguments\n- **parameters**: `Evision.TrackerMIL.Params`.\n\n  MIL parameters TrackerMIL::Params\n\n##### Return\n- **retval**: `Evision.TrackerMIL.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, parameters]) -> retval\n```","ref":"Evision.TrackerMIL.html#create/1"},{"type":"type","title":"Evision.TrackerMIL.t/0","doc":"Type that represents an `TrackerMIL` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.TrackerMIL.html#t:t/0"},{"type":"module","title":"Evision.TrackerMIL.Params","doc":"","ref":"Evision.TrackerMIL.Params.html"},{"type":"function","title":"Evision.TrackerMIL.Params.get_featureSetNumFeatures/1","doc":"","ref":"Evision.TrackerMIL.Params.html#get_featureSetNumFeatures/1"},{"type":"function","title":"Evision.TrackerMIL.Params.get_samplerInitInRadius/1","doc":"","ref":"Evision.TrackerMIL.Params.html#get_samplerInitInRadius/1"},{"type":"function","title":"Evision.TrackerMIL.Params.get_samplerInitMaxNegNum/1","doc":"","ref":"Evision.TrackerMIL.Params.html#get_samplerInitMaxNegNum/1"},{"type":"function","title":"Evision.TrackerMIL.Params.get_samplerSearchWinSize/1","doc":"","ref":"Evision.TrackerMIL.Params.html#get_samplerSearchWinSize/1"},{"type":"function","title":"Evision.TrackerMIL.Params.get_samplerTrackInRadius/1","doc":"","ref":"Evision.TrackerMIL.Params.html#get_samplerTrackInRadius/1"},{"type":"function","title":"Evision.TrackerMIL.Params.get_samplerTrackMaxNegNum/1","doc":"","ref":"Evision.TrackerMIL.Params.html#get_samplerTrackMaxNegNum/1"},{"type":"function","title":"Evision.TrackerMIL.Params.get_samplerTrackMaxPosNum/1","doc":"","ref":"Evision.TrackerMIL.Params.html#get_samplerTrackMaxPosNum/1"},{"type":"function","title":"Evision.TrackerMIL.Params.params/0","doc":"TrackerMIL_Params\n##### Return\n- **self**: `Evision.TrackerMIL.Params.t()`\n\nPython prototype (for reference only):\n```python3\nTrackerMIL_Params() ->  \n```","ref":"Evision.TrackerMIL.Params.html#params/0"},{"type":"function","title":"Evision.TrackerMIL.Params.params/1","doc":"","ref":"Evision.TrackerMIL.Params.html#params/1"},{"type":"function","title":"Evision.TrackerMIL.Params.set_featureSetNumFeatures/2","doc":"","ref":"Evision.TrackerMIL.Params.html#set_featureSetNumFeatures/2"},{"type":"function","title":"Evision.TrackerMIL.Params.set_samplerInitInRadius/2","doc":"","ref":"Evision.TrackerMIL.Params.html#set_samplerInitInRadius/2"},{"type":"function","title":"Evision.TrackerMIL.Params.set_samplerInitMaxNegNum/2","doc":"","ref":"Evision.TrackerMIL.Params.html#set_samplerInitMaxNegNum/2"},{"type":"function","title":"Evision.TrackerMIL.Params.set_samplerSearchWinSize/2","doc":"","ref":"Evision.TrackerMIL.Params.html#set_samplerSearchWinSize/2"},{"type":"function","title":"Evision.TrackerMIL.Params.set_samplerTrackInRadius/2","doc":"","ref":"Evision.TrackerMIL.Params.html#set_samplerTrackInRadius/2"},{"type":"function","title":"Evision.TrackerMIL.Params.set_samplerTrackMaxNegNum/2","doc":"","ref":"Evision.TrackerMIL.Params.html#set_samplerTrackMaxNegNum/2"},{"type":"function","title":"Evision.TrackerMIL.Params.set_samplerTrackMaxPosNum/2","doc":"","ref":"Evision.TrackerMIL.Params.html#set_samplerTrackMaxPosNum/2"},{"type":"type","title":"Evision.TrackerMIL.Params.t/0","doc":"Type that represents an `TrackerMIL.Params` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.TrackerMIL.Params.html#t:t/0"},{"type":"module","title":"Evision.TrackerNano","doc":"","ref":"Evision.TrackerNano.html"},{"type":"function","title":"Evision.TrackerNano.create/0","doc":"Constructor\n##### Keyword Arguments\n- **parameters**: `Evision.TrackerNano.Params`.\n\n  NanoTrack parameters TrackerNano::Params\n\n##### Return\n- **retval**: `Evision.TrackerNano.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, parameters]) -> retval\n```","ref":"Evision.TrackerNano.html#create/0"},{"type":"function","title":"Evision.TrackerNano.create/1","doc":"Constructor\n##### Keyword Arguments\n- **parameters**: `Evision.TrackerNano.Params`.\n\n  NanoTrack parameters TrackerNano::Params\n\n##### Return\n- **retval**: `Evision.TrackerNano.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, parameters]) -> retval\n```","ref":"Evision.TrackerNano.html#create/1"},{"type":"function","title":"Evision.TrackerNano.getTrackingScore/1","doc":"Return tracking score\n\n##### Positional Arguments\n- **self**: `Evision.TrackerNano.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetTrackingScore() -> retval\n```","ref":"Evision.TrackerNano.html#getTrackingScore/1"},{"type":"type","title":"Evision.TrackerNano.t/0","doc":"Type that represents an `TrackerNano` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.TrackerNano.html#t:t/0"},{"type":"module","title":"Evision.TrackerNano.Params","doc":"","ref":"Evision.TrackerNano.Params.html"},{"type":"function","title":"Evision.TrackerNano.Params.get_backbone/1","doc":"","ref":"Evision.TrackerNano.Params.html#get_backbone/1"},{"type":"function","title":"Evision.TrackerNano.Params.get_backend/1","doc":"","ref":"Evision.TrackerNano.Params.html#get_backend/1"},{"type":"function","title":"Evision.TrackerNano.Params.get_neckhead/1","doc":"","ref":"Evision.TrackerNano.Params.html#get_neckhead/1"},{"type":"function","title":"Evision.TrackerNano.Params.get_target/1","doc":"","ref":"Evision.TrackerNano.Params.html#get_target/1"},{"type":"function","title":"Evision.TrackerNano.Params.params/0","doc":"TrackerNano_Params\n##### Return\n- **self**: `Evision.TrackerNano.Params.t()`\n\nPython prototype (for reference only):\n```python3\nTrackerNano_Params() ->  \n```","ref":"Evision.TrackerNano.Params.html#params/0"},{"type":"function","title":"Evision.TrackerNano.Params.params/1","doc":"","ref":"Evision.TrackerNano.Params.html#params/1"},{"type":"function","title":"Evision.TrackerNano.Params.set_backbone/2","doc":"","ref":"Evision.TrackerNano.Params.html#set_backbone/2"},{"type":"function","title":"Evision.TrackerNano.Params.set_backend/2","doc":"","ref":"Evision.TrackerNano.Params.html#set_backend/2"},{"type":"function","title":"Evision.TrackerNano.Params.set_neckhead/2","doc":"","ref":"Evision.TrackerNano.Params.html#set_neckhead/2"},{"type":"function","title":"Evision.TrackerNano.Params.set_target/2","doc":"","ref":"Evision.TrackerNano.Params.html#set_target/2"},{"type":"type","title":"Evision.TrackerNano.Params.t/0","doc":"Type that represents an `TrackerNano.Params` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.TrackerNano.Params.html#t:t/0"},{"type":"module","title":"Evision.TrackerVit","doc":"","ref":"Evision.TrackerVit.html"},{"type":"function","title":"Evision.TrackerVit.create/0","doc":"Constructor\n##### Keyword Arguments\n- **parameters**: `Evision.TrackerVit.Params`.\n\n  vit tracker parameters TrackerVit::Params\n\n##### Return\n- **retval**: `Evision.TrackerVit.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, parameters]) -> retval\n```","ref":"Evision.TrackerVit.html#create/0"},{"type":"function","title":"Evision.TrackerVit.create/1","doc":"Constructor\n##### Keyword Arguments\n- **parameters**: `Evision.TrackerVit.Params`.\n\n  vit tracker parameters TrackerVit::Params\n\n##### Return\n- **retval**: `Evision.TrackerVit.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, parameters]) -> retval\n```","ref":"Evision.TrackerVit.html#create/1"},{"type":"function","title":"Evision.TrackerVit.getTrackingScore/1","doc":"Return tracking score\n\n##### Positional Arguments\n- **self**: `Evision.TrackerVit.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetTrackingScore() -> retval\n```","ref":"Evision.TrackerVit.html#getTrackingScore/1"},{"type":"type","title":"Evision.TrackerVit.t/0","doc":"Type that represents an `TrackerVit` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.TrackerVit.html#t:t/0"},{"type":"module","title":"Evision.TrackerVit.Params","doc":"","ref":"Evision.TrackerVit.Params.html"},{"type":"function","title":"Evision.TrackerVit.Params.get_backend/1","doc":"","ref":"Evision.TrackerVit.Params.html#get_backend/1"},{"type":"function","title":"Evision.TrackerVit.Params.get_meanvalue/1","doc":"","ref":"Evision.TrackerVit.Params.html#get_meanvalue/1"},{"type":"function","title":"Evision.TrackerVit.Params.get_net/1","doc":"","ref":"Evision.TrackerVit.Params.html#get_net/1"},{"type":"function","title":"Evision.TrackerVit.Params.get_stdvalue/1","doc":"","ref":"Evision.TrackerVit.Params.html#get_stdvalue/1"},{"type":"function","title":"Evision.TrackerVit.Params.get_target/1","doc":"","ref":"Evision.TrackerVit.Params.html#get_target/1"},{"type":"function","title":"Evision.TrackerVit.Params.params/0","doc":"TrackerVit_Params\n##### Return\n- **self**: `Evision.TrackerVit.Params.t()`\n\nPython prototype (for reference only):\n```python3\nTrackerVit_Params() ->  \n```","ref":"Evision.TrackerVit.Params.html#params/0"},{"type":"function","title":"Evision.TrackerVit.Params.params/1","doc":"","ref":"Evision.TrackerVit.Params.html#params/1"},{"type":"function","title":"Evision.TrackerVit.Params.set_backend/2","doc":"","ref":"Evision.TrackerVit.Params.html#set_backend/2"},{"type":"function","title":"Evision.TrackerVit.Params.set_meanvalue/2","doc":"","ref":"Evision.TrackerVit.Params.html#set_meanvalue/2"},{"type":"function","title":"Evision.TrackerVit.Params.set_net/2","doc":"","ref":"Evision.TrackerVit.Params.html#set_net/2"},{"type":"function","title":"Evision.TrackerVit.Params.set_stdvalue/2","doc":"","ref":"Evision.TrackerVit.Params.html#set_stdvalue/2"},{"type":"function","title":"Evision.TrackerVit.Params.set_target/2","doc":"","ref":"Evision.TrackerVit.Params.html#set_target/2"},{"type":"type","title":"Evision.TrackerVit.Params.t/0","doc":"Type that represents an `TrackerVit.Params` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.TrackerVit.Params.html#t:t/0"},{"type":"module","title":"Evision.UMat","doc":"","ref":"Evision.UMat.html"},{"type":"function","title":"Evision.UMat.context/0","doc":"context\n##### Return\n- **retval**: `void*`\n\nPython prototype (for reference only):\n```python3\ncontext() -> retval\n```","ref":"Evision.UMat.html#context/0"},{"type":"function","title":"Evision.UMat.context/1","doc":"","ref":"Evision.UMat.html#context/1"},{"type":"function","title":"Evision.UMat.get/1","doc":"get\n\n##### Positional Arguments\n- **self**: `Evision.UMat.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nget() -> retval\n```","ref":"Evision.UMat.html#get/1"},{"type":"function","title":"Evision.UMat.get_offset/1","doc":"","ref":"Evision.UMat.html#get_offset/1"},{"type":"function","title":"Evision.UMat.handle/1","doc":"","ref":"Evision.UMat.html#handle/1"},{"type":"function","title":"Evision.UMat.handle/2","doc":"handle\n\n##### Positional Arguments\n- **self**: `Evision.UMat.t()`\n- **accessFlags**: `AccessFlag`\n\n##### Return\n- **retval**: `void*`\n\nPython prototype (for reference only):\n```python3\nhandle(accessFlags) -> retval\n```","ref":"Evision.UMat.html#handle/2"},{"type":"function","title":"Evision.UMat.isContinuous/1","doc":"isContinuous\n\n##### Positional Arguments\n- **self**: `Evision.UMat.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisContinuous() -> retval\n```","ref":"Evision.UMat.html#isContinuous/1"},{"type":"function","title":"Evision.UMat.isSubmatrix/1","doc":"isSubmatrix\n\n##### Positional Arguments\n- **self**: `Evision.UMat.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisSubmatrix() -> retval\n```","ref":"Evision.UMat.html#isSubmatrix/1"},{"type":"function","title":"Evision.UMat.queue/0","doc":"queue\n##### Return\n- **retval**: `void*`\n\nPython prototype (for reference only):\n```python3\nqueue() -> retval\n```","ref":"Evision.UMat.html#queue/0"},{"type":"function","title":"Evision.UMat.queue/1","doc":"","ref":"Evision.UMat.html#queue/1"},{"type":"function","title":"Evision.UMat.set_offset/2","doc":"","ref":"Evision.UMat.html#set_offset/2"},{"type":"function","title":"Evision.UMat.uMat/0","doc":"UMat\n##### Keyword Arguments\n- **usageFlags**: `UMatUsageFlags`.\n\n##### Return\n- **self**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nUMat([, usageFlags]) ->  \n```","ref":"Evision.UMat.html#uMat/0"},{"type":"function","title":"Evision.UMat.uMat/1","doc":"#### Variant 1:\nUMat\n\n##### Positional Arguments\n- **m**: `Evision.Mat`\n\n##### Return\n- **self**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nUMat(m) ->  \n```\n#### Variant 2:\nUMat\n##### Keyword Arguments\n- **usageFlags**: `UMatUsageFlags`.\n\n##### Return\n- **self**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nUMat([, usageFlags]) ->  \n```","ref":"Evision.UMat.html#uMat/1"},{"type":"function","title":"Evision.UMat.uMat/2","doc":"#### Variant 1:\nUMat\n\n##### Positional Arguments\n- **m**: `Evision.Mat`\n- **ranges**: `[Range]`\n\n##### Return\n- **self**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nUMat(m, ranges) ->  \n```\n#### Variant 2:\nUMat\n\n##### Positional Arguments\n- **m**: `Evision.Mat`\n- **roi**: `Rect`\n\n##### Return\n- **self**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nUMat(m, roi) ->  \n```\n#### Variant 3:\nUMat\n\n##### Positional Arguments\n- **m**: `Evision.Mat`\n- **rowRange**: `Range`\n\n##### Keyword Arguments\n- **colRange**: `Range`.\n\n##### Return\n- **self**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nUMat(m, rowRange[, colRange]) ->  \n```\n#### Variant 4:\nUMat\n\n##### Positional Arguments\n- **size**: `Size`\n- **type**: `integer()`\n\n##### Keyword Arguments\n- **usageFlags**: `UMatUsageFlags`.\n\n##### Return\n- **self**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nUMat(size, type[, usageFlags]) ->  \n```","ref":"Evision.UMat.html#uMat/2"},{"type":"function","title":"Evision.UMat.uMat/3","doc":"#### Variant 1:\nUMat\n\n##### Positional Arguments\n- **size**: `Size`\n- **type**: `integer()`\n- **s**: `Evision.scalar()`\n\n##### Keyword Arguments\n- **usageFlags**: `UMatUsageFlags`.\n\n##### Return\n- **self**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nUMat(size, type, s[, usageFlags]) ->  \n```\n#### Variant 2:\nUMat\n\n##### Positional Arguments\n- **rows**: `integer()`\n- **cols**: `integer()`\n- **type**: `integer()`\n\n##### Keyword Arguments\n- **usageFlags**: `UMatUsageFlags`.\n\n##### Return\n- **self**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nUMat(rows, cols, type[, usageFlags]) ->  \n```\n#### Variant 3:\nUMat\n\n##### Positional Arguments\n- **m**: `Evision.Mat`\n- **rowRange**: `Range`\n\n##### Keyword Arguments\n- **colRange**: `Range`.\n\n##### Return\n- **self**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nUMat(m, rowRange[, colRange]) ->  \n```\n#### Variant 4:\nUMat\n\n##### Positional Arguments\n- **size**: `Size`\n- **type**: `integer()`\n\n##### Keyword Arguments\n- **usageFlags**: `UMatUsageFlags`.\n\n##### Return\n- **self**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nUMat(size, type[, usageFlags]) ->  \n```","ref":"Evision.UMat.html#uMat/3"},{"type":"function","title":"Evision.UMat.uMat/4","doc":"#### Variant 1:\nUMat\n\n##### Positional Arguments\n- **rows**: `integer()`\n- **cols**: `integer()`\n- **type**: `integer()`\n- **s**: `Evision.scalar()`\n\n##### Keyword Arguments\n- **usageFlags**: `UMatUsageFlags`.\n\n##### Return\n- **self**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nUMat(rows, cols, type, s[, usageFlags]) ->  \n```\n#### Variant 2:\nUMat\n\n##### Positional Arguments\n- **size**: `Size`\n- **type**: `integer()`\n- **s**: `Evision.scalar()`\n\n##### Keyword Arguments\n- **usageFlags**: `UMatUsageFlags`.\n\n##### Return\n- **self**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nUMat(size, type, s[, usageFlags]) ->  \n```\n#### Variant 3:\nUMat\n\n##### Positional Arguments\n- **rows**: `integer()`\n- **cols**: `integer()`\n- **type**: `integer()`\n\n##### Keyword Arguments\n- **usageFlags**: `UMatUsageFlags`.\n\n##### Return\n- **self**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nUMat(rows, cols, type[, usageFlags]) ->  \n```","ref":"Evision.UMat.html#uMat/4"},{"type":"function","title":"Evision.UMat.uMat/5","doc":"UMat\n\n##### Positional Arguments\n- **rows**: `integer()`\n- **cols**: `integer()`\n- **type**: `integer()`\n- **s**: `Evision.scalar()`\n\n##### Keyword Arguments\n- **usageFlags**: `UMatUsageFlags`.\n\n##### Return\n- **self**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\nUMat(rows, cols, type, s[, usageFlags]) ->  \n```","ref":"Evision.UMat.html#uMat/5"},{"type":"type","title":"Evision.UMat.t/0","doc":"Type that represents an `UMat` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.UMat.html#t:t/0"},{"type":"module","title":"Evision.UMatData.MemoryFlag","doc":"","ref":"Evision.UMatData.MemoryFlag.html"},{"type":"function","title":"Evision.UMatData.MemoryFlag.cv_ASYNC_CLEANUP/0","doc":"","ref":"Evision.UMatData.MemoryFlag.html#cv_ASYNC_CLEANUP/0"},{"type":"function","title":"Evision.UMatData.MemoryFlag.cv_COPY_ON_MAP/0","doc":"","ref":"Evision.UMatData.MemoryFlag.html#cv_COPY_ON_MAP/0"},{"type":"function","title":"Evision.UMatData.MemoryFlag.cv_DEVICE_COPY_OBSOLETE/0","doc":"","ref":"Evision.UMatData.MemoryFlag.html#cv_DEVICE_COPY_OBSOLETE/0"},{"type":"function","title":"Evision.UMatData.MemoryFlag.cv_DEVICE_MEM_MAPPED/0","doc":"","ref":"Evision.UMatData.MemoryFlag.html#cv_DEVICE_MEM_MAPPED/0"},{"type":"function","title":"Evision.UMatData.MemoryFlag.cv_HOST_COPY_OBSOLETE/0","doc":"","ref":"Evision.UMatData.MemoryFlag.html#cv_HOST_COPY_OBSOLETE/0"},{"type":"function","title":"Evision.UMatData.MemoryFlag.cv_TEMP_COPIED_UMAT/0","doc":"","ref":"Evision.UMatData.MemoryFlag.html#cv_TEMP_COPIED_UMAT/0"},{"type":"function","title":"Evision.UMatData.MemoryFlag.cv_TEMP_UMAT/0","doc":"","ref":"Evision.UMatData.MemoryFlag.html#cv_TEMP_UMAT/0"},{"type":"function","title":"Evision.UMatData.MemoryFlag.cv_USER_ALLOCATED/0","doc":"","ref":"Evision.UMatData.MemoryFlag.html#cv_USER_ALLOCATED/0"},{"type":"type","title":"Evision.UMatData.MemoryFlag.enum/0","doc":"","ref":"Evision.UMatData.MemoryFlag.html#t:enum/0"},{"type":"module","title":"Evision.UMatUsageFlags","doc":"","ref":"Evision.UMatUsageFlags.html"},{"type":"function","title":"Evision.UMatUsageFlags.cv_UMAT_USAGE_FLAGS_32BIT/0","doc":"","ref":"Evision.UMatUsageFlags.html#cv_UMAT_USAGE_FLAGS_32BIT/0"},{"type":"function","title":"Evision.UMatUsageFlags.cv_USAGE_ALLOCATE_DEVICE_MEMORY/0","doc":"","ref":"Evision.UMatUsageFlags.html#cv_USAGE_ALLOCATE_DEVICE_MEMORY/0"},{"type":"function","title":"Evision.UMatUsageFlags.cv_USAGE_ALLOCATE_HOST_MEMORY/0","doc":"","ref":"Evision.UMatUsageFlags.html#cv_USAGE_ALLOCATE_HOST_MEMORY/0"},{"type":"function","title":"Evision.UMatUsageFlags.cv_USAGE_ALLOCATE_SHARED_MEMORY/0","doc":"","ref":"Evision.UMatUsageFlags.html#cv_USAGE_ALLOCATE_SHARED_MEMORY/0"},{"type":"function","title":"Evision.UMatUsageFlags.cv_USAGE_DEFAULT/0","doc":"","ref":"Evision.UMatUsageFlags.html#cv_USAGE_DEFAULT/0"},{"type":"type","title":"Evision.UMatUsageFlags.enum/0","doc":"","ref":"Evision.UMatUsageFlags.html#t:enum/0"},{"type":"module","title":"Evision.UndistortTypes","doc":"","ref":"Evision.UndistortTypes.html"},{"type":"function","title":"Evision.UndistortTypes.cv_PROJ_SPHERICAL_EQRECT/0","doc":"","ref":"Evision.UndistortTypes.html#cv_PROJ_SPHERICAL_EQRECT/0"},{"type":"function","title":"Evision.UndistortTypes.cv_PROJ_SPHERICAL_ORTHO/0","doc":"","ref":"Evision.UndistortTypes.html#cv_PROJ_SPHERICAL_ORTHO/0"},{"type":"type","title":"Evision.UndistortTypes.enum/0","doc":"","ref":"Evision.UndistortTypes.html#t:enum/0"},{"type":"module","title":"Evision.UsacParams","doc":"","ref":"Evision.UsacParams.html"},{"type":"function","title":"Evision.UsacParams.get_confidence/1","doc":"","ref":"Evision.UsacParams.html#get_confidence/1"},{"type":"function","title":"Evision.UsacParams.get_final_polisher/1","doc":"","ref":"Evision.UsacParams.html#get_final_polisher/1"},{"type":"function","title":"Evision.UsacParams.get_final_polisher_iterations/1","doc":"","ref":"Evision.UsacParams.html#get_final_polisher_iterations/1"},{"type":"function","title":"Evision.UsacParams.get_isParallel/1","doc":"","ref":"Evision.UsacParams.html#get_isParallel/1"},{"type":"function","title":"Evision.UsacParams.get_loIterations/1","doc":"","ref":"Evision.UsacParams.html#get_loIterations/1"},{"type":"function","title":"Evision.UsacParams.get_loMethod/1","doc":"","ref":"Evision.UsacParams.html#get_loMethod/1"},{"type":"function","title":"Evision.UsacParams.get_loSampleSize/1","doc":"","ref":"Evision.UsacParams.html#get_loSampleSize/1"},{"type":"function","title":"Evision.UsacParams.get_maxIterations/1","doc":"","ref":"Evision.UsacParams.html#get_maxIterations/1"},{"type":"function","title":"Evision.UsacParams.get_neighborsSearch/1","doc":"","ref":"Evision.UsacParams.html#get_neighborsSearch/1"},{"type":"function","title":"Evision.UsacParams.get_randomGeneratorState/1","doc":"","ref":"Evision.UsacParams.html#get_randomGeneratorState/1"},{"type":"function","title":"Evision.UsacParams.get_sampler/1","doc":"","ref":"Evision.UsacParams.html#get_sampler/1"},{"type":"function","title":"Evision.UsacParams.get_score/1","doc":"","ref":"Evision.UsacParams.html#get_score/1"},{"type":"function","title":"Evision.UsacParams.get_threshold/1","doc":"","ref":"Evision.UsacParams.html#get_threshold/1"},{"type":"function","title":"Evision.UsacParams.set_confidence/2","doc":"","ref":"Evision.UsacParams.html#set_confidence/2"},{"type":"function","title":"Evision.UsacParams.set_final_polisher/2","doc":"","ref":"Evision.UsacParams.html#set_final_polisher/2"},{"type":"function","title":"Evision.UsacParams.set_final_polisher_iterations/2","doc":"","ref":"Evision.UsacParams.html#set_final_polisher_iterations/2"},{"type":"function","title":"Evision.UsacParams.set_isParallel/2","doc":"","ref":"Evision.UsacParams.html#set_isParallel/2"},{"type":"function","title":"Evision.UsacParams.set_loIterations/2","doc":"","ref":"Evision.UsacParams.html#set_loIterations/2"},{"type":"function","title":"Evision.UsacParams.set_loMethod/2","doc":"","ref":"Evision.UsacParams.html#set_loMethod/2"},{"type":"function","title":"Evision.UsacParams.set_loSampleSize/2","doc":"","ref":"Evision.UsacParams.html#set_loSampleSize/2"},{"type":"function","title":"Evision.UsacParams.set_maxIterations/2","doc":"","ref":"Evision.UsacParams.html#set_maxIterations/2"},{"type":"function","title":"Evision.UsacParams.set_neighborsSearch/2","doc":"","ref":"Evision.UsacParams.html#set_neighborsSearch/2"},{"type":"function","title":"Evision.UsacParams.set_randomGeneratorState/2","doc":"","ref":"Evision.UsacParams.html#set_randomGeneratorState/2"},{"type":"function","title":"Evision.UsacParams.set_sampler/2","doc":"","ref":"Evision.UsacParams.html#set_sampler/2"},{"type":"function","title":"Evision.UsacParams.set_score/2","doc":"","ref":"Evision.UsacParams.html#set_score/2"},{"type":"function","title":"Evision.UsacParams.set_threshold/2","doc":"","ref":"Evision.UsacParams.html#set_threshold/2"},{"type":"function","title":"Evision.UsacParams.usacParams/0","doc":"UsacParams\n##### Return\n- **self**: `Evision.UsacParams.t()`\n\nPython prototype (for reference only):\n```python3\nUsacParams() ->  \n```","ref":"Evision.UsacParams.html#usacParams/0"},{"type":"function","title":"Evision.UsacParams.usacParams/1","doc":"","ref":"Evision.UsacParams.html#usacParams/1"},{"type":"type","title":"Evision.UsacParams.t/0","doc":"Type that represents an `UsacParams` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.UsacParams.html#t:t/0"},{"type":"module","title":"Evision.Utils","doc":"","ref":"Evision.Utils.html"},{"type":"function","title":"Evision.Utils.copyMatAndDumpNamedArguments/1","doc":"copyMatAndDumpNamedArguments\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **params**: `FunctionParams`.\n\n##### Return\n- **retval**: `String`\n- **dst**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ncopyMatAndDumpNamedArguments(src[, dst[, params]]) -> retval, dst\n```","ref":"Evision.Utils.html#copyMatAndDumpNamedArguments/1"},{"type":"function","title":"Evision.Utils.copyMatAndDumpNamedArguments/2","doc":"copyMatAndDumpNamedArguments\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **params**: `FunctionParams`.\n\n##### Return\n- **retval**: `String`\n- **dst**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ncopyMatAndDumpNamedArguments(src[, dst[, params]]) -> retval, dst\n```","ref":"Evision.Utils.html#copyMatAndDumpNamedArguments/2"},{"type":"function","title":"Evision.Utils.dumpBool/1","doc":"dumpBool\n\n##### Positional Arguments\n- **argument**: `bool`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ndumpBool(argument) -> retval\n```","ref":"Evision.Utils.html#dumpBool/1"},{"type":"function","title":"Evision.Utils.dumpCString/1","doc":"dumpCString\n\n##### Positional Arguments\n- **argument**: `c_string`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ndumpCString(argument) -> retval\n```","ref":"Evision.Utils.html#dumpCString/1"},{"type":"function","title":"Evision.Utils.dumpDouble/1","doc":"dumpDouble\n\n##### Positional Arguments\n- **argument**: `double`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ndumpDouble(argument) -> retval\n```","ref":"Evision.Utils.html#dumpDouble/1"},{"type":"function","title":"Evision.Utils.dumpFloat/1","doc":"dumpFloat\n\n##### Positional Arguments\n- **argument**: `float`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ndumpFloat(argument) -> retval\n```","ref":"Evision.Utils.html#dumpFloat/1"},{"type":"function","title":"Evision.Utils.dumpInputArray/1","doc":"dumpInputArray\n\n##### Positional Arguments\n- **argument**: `Evision.Mat`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ndumpInputArray(argument) -> retval\n```","ref":"Evision.Utils.html#dumpInputArray/1"},{"type":"function","title":"Evision.Utils.dumpInputArrayOfArrays/1","doc":"dumpInputArrayOfArrays\n\n##### Positional Arguments\n- **argument**: `[Evision.Mat]`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ndumpInputArrayOfArrays(argument) -> retval\n```","ref":"Evision.Utils.html#dumpInputArrayOfArrays/1"},{"type":"function","title":"Evision.Utils.dumpInputOutputArray/1","doc":"dumpInputOutputArray\n##### Return\n- **retval**: `String`\n- **argument**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ndumpInputOutputArray(argument) -> retval, argument\n```","ref":"Evision.Utils.html#dumpInputOutputArray/1"},{"type":"function","title":"Evision.Utils.dumpInputOutputArrayOfArrays/1","doc":"dumpInputOutputArrayOfArrays\n##### Return\n- **retval**: `String`\n- **argument**: `[Evision.Mat]`\n\nPython prototype (for reference only):\n```python3\ndumpInputOutputArrayOfArrays(argument) -> retval, argument\n```","ref":"Evision.Utils.html#dumpInputOutputArrayOfArrays/1"},{"type":"function","title":"Evision.Utils.dumpInt64/1","doc":"dumpInt64\n\n##### Positional Arguments\n- **argument**: `int64`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ndumpInt64(argument) -> retval\n```","ref":"Evision.Utils.html#dumpInt64/1"},{"type":"function","title":"Evision.Utils.dumpInt/1","doc":"dumpInt\n\n##### Positional Arguments\n- **argument**: `integer()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ndumpInt(argument) -> retval\n```","ref":"Evision.Utils.html#dumpInt/1"},{"type":"function","title":"Evision.Utils.dumpRange/1","doc":"dumpRange\n\n##### Positional Arguments\n- **argument**: `Range`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ndumpRange(argument) -> retval\n```","ref":"Evision.Utils.html#dumpRange/1"},{"type":"function","title":"Evision.Utils.dumpRect/1","doc":"dumpRect\n\n##### Positional Arguments\n- **argument**: `Rect`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ndumpRect(argument) -> retval\n```","ref":"Evision.Utils.html#dumpRect/1"},{"type":"function","title":"Evision.Utils.dumpRotatedRect/1","doc":"dumpRotatedRect\n\n##### Positional Arguments\n- **argument**: `{centre={x, y}, size={s1, s2}, angle}`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ndumpRotatedRect(argument) -> retval\n```","ref":"Evision.Utils.html#dumpRotatedRect/1"},{"type":"function","title":"Evision.Utils.dumpSizeT/1","doc":"dumpSizeT\n\n##### Positional Arguments\n- **argument**: `size_t`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ndumpSizeT(argument) -> retval\n```","ref":"Evision.Utils.html#dumpSizeT/1"},{"type":"function","title":"Evision.Utils.dumpString/1","doc":"dumpString\n\n##### Positional Arguments\n- **argument**: `String`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ndumpString(argument) -> retval\n```","ref":"Evision.Utils.html#dumpString/1"},{"type":"function","title":"Evision.Utils.dumpTermCriteria/1","doc":"dumpTermCriteria\n\n##### Positional Arguments\n- **argument**: `TermCriteria`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ndumpTermCriteria(argument) -> retval\n```","ref":"Evision.Utils.html#dumpTermCriteria/1"},{"type":"function","title":"Evision.Utils.dumpVec2i/0","doc":"dumpVec2i\n##### Keyword Arguments\n- **value**: `Vec2i`.\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ndumpVec2i([, value]) -> retval\n```","ref":"Evision.Utils.html#dumpVec2i/0"},{"type":"function","title":"Evision.Utils.dumpVec2i/1","doc":"dumpVec2i\n##### Keyword Arguments\n- **value**: `Vec2i`.\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ndumpVec2i([, value]) -> retval\n```","ref":"Evision.Utils.html#dumpVec2i/1"},{"type":"function","title":"Evision.Utils.dumpVectorOfDouble/1","doc":"dumpVectorOfDouble\n\n##### Positional Arguments\n- **vec**: `[double]`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ndumpVectorOfDouble(vec) -> retval\n```","ref":"Evision.Utils.html#dumpVectorOfDouble/1"},{"type":"function","title":"Evision.Utils.dumpVectorOfInt/1","doc":"dumpVectorOfInt\n\n##### Positional Arguments\n- **vec**: `[integer()]`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ndumpVectorOfInt(vec) -> retval\n```","ref":"Evision.Utils.html#dumpVectorOfInt/1"},{"type":"function","title":"Evision.Utils.dumpVectorOfRect/1","doc":"dumpVectorOfRect\n\n##### Positional Arguments\n- **vec**: `[Rect]`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ndumpVectorOfRect(vec) -> retval\n```","ref":"Evision.Utils.html#dumpVectorOfRect/1"},{"type":"function","title":"Evision.Utils.generateVectorOfInt/1","doc":"generateVectorOfInt\n\n##### Positional Arguments\n- **len**: `size_t`\n\n##### Return\n- **vec**: `[integer()]`\n\nPython prototype (for reference only):\n```python3\ngenerateVectorOfInt(len) -> vec\n```","ref":"Evision.Utils.html#generateVectorOfInt/1"},{"type":"function","title":"Evision.Utils.generateVectorOfMat/1","doc":"","ref":"Evision.Utils.html#generateVectorOfMat/1"},{"type":"function","title":"Evision.Utils.generateVectorOfMat/4","doc":"generateVectorOfMat\n\n##### Positional Arguments\n- **len**: `size_t`\n- **rows**: `integer()`\n- **cols**: `integer()`\n- **dtype**: `integer()`\n\n##### Return\n- **vec**: `[Evision.Mat]`.\n\nPython prototype (for reference only):\n```python3\ngenerateVectorOfMat(len, rows, cols, dtype[, vec]) -> vec\n```","ref":"Evision.Utils.html#generateVectorOfMat/4"},{"type":"function","title":"Evision.Utils.generateVectorOfMat/5","doc":"generateVectorOfMat\n\n##### Positional Arguments\n- **len**: `size_t`\n- **rows**: `integer()`\n- **cols**: `integer()`\n- **dtype**: `integer()`\n\n##### Return\n- **vec**: `[Evision.Mat]`.\n\nPython prototype (for reference only):\n```python3\ngenerateVectorOfMat(len, rows, cols, dtype[, vec]) -> vec\n```","ref":"Evision.Utils.html#generateVectorOfMat/5"},{"type":"function","title":"Evision.Utils.generateVectorOfRect/1","doc":"generateVectorOfRect\n\n##### Positional Arguments\n- **len**: `size_t`\n\n##### Return\n- **vec**: `[Rect]`\n\nPython prototype (for reference only):\n```python3\ngenerateVectorOfRect(len) -> vec\n```","ref":"Evision.Utils.html#generateVectorOfRect/1"},{"type":"function","title":"Evision.Utils.testAsyncArray/1","doc":"testAsyncArray\n\n##### Positional Arguments\n- **argument**: `Evision.Mat`\n\n##### Return\n- **retval**: `Evision.AsyncArray.t()`\n\nPython prototype (for reference only):\n```python3\ntestAsyncArray(argument) -> retval\n```","ref":"Evision.Utils.html#testAsyncArray/1"},{"type":"function","title":"Evision.Utils.testAsyncException/0","doc":"testAsyncException\n##### Return\n- **retval**: `Evision.AsyncArray.t()`\n\nPython prototype (for reference only):\n```python3\ntestAsyncException() -> retval\n```","ref":"Evision.Utils.html#testAsyncException/0"},{"type":"function","title":"Evision.Utils.testAsyncException/1","doc":"","ref":"Evision.Utils.html#testAsyncException/1"},{"type":"function","title":"Evision.Utils.testOverloadResolution/1","doc":"#### Variant 1:\ntestOverloadResolution\n\n##### Positional Arguments\n- **rect**: `Rect`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ntestOverloadResolution(rect) -> retval\n```\n#### Variant 2:\ntestOverloadResolution\n\n##### Positional Arguments\n- **value**: `integer()`\n\n##### Keyword Arguments\n- **point**: `Point`.\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ntestOverloadResolution(value[, point]) -> retval\n```","ref":"Evision.Utils.html#testOverloadResolution/1"},{"type":"function","title":"Evision.Utils.testOverloadResolution/2","doc":"testOverloadResolution\n\n##### Positional Arguments\n- **value**: `integer()`\n\n##### Keyword Arguments\n- **point**: `Point`.\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ntestOverloadResolution(value[, point]) -> retval\n```","ref":"Evision.Utils.html#testOverloadResolution/2"},{"type":"function","title":"Evision.Utils.testOverwriteNativeMethod/1","doc":"testOverwriteNativeMethod\n\n##### Positional Arguments\n- **argument**: `integer()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ntestOverwriteNativeMethod(argument) -> retval\n```","ref":"Evision.Utils.html#testOverwriteNativeMethod/1"},{"type":"function","title":"Evision.Utils.testRaiseGeneralException/0","doc":"testRaiseGeneralException\n\nPython prototype (for reference only):\n```python3\ntestRaiseGeneralException() -> None\n```","ref":"Evision.Utils.html#testRaiseGeneralException/0"},{"type":"function","title":"Evision.Utils.testRaiseGeneralException/1","doc":"","ref":"Evision.Utils.html#testRaiseGeneralException/1"},{"type":"function","title":"Evision.Utils.testReservedKeywordConversion/1","doc":"testReservedKeywordConversion\n\n##### Positional Arguments\n- **positional_argument**: `integer()`\n\n##### Keyword Arguments\n- **lambda**: `integer()`.\n- **from**: `integer()`.\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ntestReservedKeywordConversion(positional_argument[, lambda[, from]]) -> retval\n```","ref":"Evision.Utils.html#testReservedKeywordConversion/1"},{"type":"function","title":"Evision.Utils.testReservedKeywordConversion/2","doc":"testReservedKeywordConversion\n\n##### Positional Arguments\n- **positional_argument**: `integer()`\n\n##### Keyword Arguments\n- **lambda**: `integer()`.\n- **from**: `integer()`.\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ntestReservedKeywordConversion(positional_argument[, lambda[, from]]) -> retval\n```","ref":"Evision.Utils.html#testReservedKeywordConversion/2"},{"type":"function","title":"Evision.Utils.testRotatedRect/1","doc":"","ref":"Evision.Utils.html#testRotatedRect/1"},{"type":"function","title":"Evision.Utils.testRotatedRect/5","doc":"testRotatedRect\n\n##### Positional Arguments\n- **x**: `float`\n- **y**: `float`\n- **w**: `float`\n- **h**: `float`\n- **angle**: `float`\n\n##### Return\n- **retval**: `{centre={x, y}, size={s1, s2}, angle}`\n\nPython prototype (for reference only):\n```python3\ntestRotatedRect(x, y, w, h, angle) -> retval\n```","ref":"Evision.Utils.html#testRotatedRect/5"},{"type":"function","title":"Evision.Utils.testRotatedRectVector/1","doc":"","ref":"Evision.Utils.html#testRotatedRectVector/1"},{"type":"function","title":"Evision.Utils.testRotatedRectVector/5","doc":"testRotatedRectVector\n\n##### Positional Arguments\n- **x**: `float`\n- **y**: `float`\n- **w**: `float`\n- **h**: `float`\n- **angle**: `float`\n\n##### Return\n- **retval**: `[{centre={x, y}, size={s1, s2}, angle}]`\n\nPython prototype (for reference only):\n```python3\ntestRotatedRectVector(x, y, w, h, angle) -> retval\n```","ref":"Evision.Utils.html#testRotatedRectVector/5"},{"type":"type","title":"Evision.Utils.t/0","doc":"Type that represents an `Utils` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Utils.html#t:t/0"},{"type":"module","title":"Evision.Utils.ClassWithKeywordProperties","doc":"","ref":"Evision.Utils.ClassWithKeywordProperties.html"},{"type":"function","title":"Evision.Utils.ClassWithKeywordProperties.classWithKeywordProperties/0","doc":"ClassWithKeywordProperties\n##### Keyword Arguments\n- **lambda_arg**: `integer()`.\n- **except_arg**: `integer()`.\n\n##### Return\n- **self**: `ClassWithKeywordProperties`\n\nPython prototype (for reference only):\n```python3\nClassWithKeywordProperties([, lambda_arg[, except_arg]]) ->  \n```","ref":"Evision.Utils.ClassWithKeywordProperties.html#classWithKeywordProperties/0"},{"type":"function","title":"Evision.Utils.ClassWithKeywordProperties.classWithKeywordProperties/1","doc":"ClassWithKeywordProperties\n##### Keyword Arguments\n- **lambda_arg**: `integer()`.\n- **except_arg**: `integer()`.\n\n##### Return\n- **self**: `ClassWithKeywordProperties`\n\nPython prototype (for reference only):\n```python3\nClassWithKeywordProperties([, lambda_arg[, except_arg]]) ->  \n```","ref":"Evision.Utils.ClassWithKeywordProperties.html#classWithKeywordProperties/1"},{"type":"function","title":"Evision.Utils.ClassWithKeywordProperties.get_except/1","doc":"","ref":"Evision.Utils.ClassWithKeywordProperties.html#get_except/1"},{"type":"function","title":"Evision.Utils.ClassWithKeywordProperties.get_lambda/1","doc":"","ref":"Evision.Utils.ClassWithKeywordProperties.html#get_lambda/1"},{"type":"function","title":"Evision.Utils.ClassWithKeywordProperties.set_lambda/2","doc":"","ref":"Evision.Utils.ClassWithKeywordProperties.html#set_lambda/2"},{"type":"type","title":"Evision.Utils.ClassWithKeywordProperties.t/0","doc":"Type that represents an `Utils.ClassWithKeywordProperties` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Utils.ClassWithKeywordProperties.html#t:t/0"},{"type":"module","title":"Evision.Utils.Nested","doc":"","ref":"Evision.Utils.Nested.html"},{"type":"function","title":"Evision.Utils.Nested.testEchoBooleanFunction/1","doc":"testEchoBooleanFunction\n\n##### Positional Arguments\n- **flag**: `bool`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ntestEchoBooleanFunction(flag) -> retval\n```","ref":"Evision.Utils.Nested.html#testEchoBooleanFunction/1"},{"type":"type","title":"Evision.Utils.Nested.t/0","doc":"Type that represents an `Utils.Nested` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Utils.Nested.html#t:t/0"},{"type":"module","title":"Evision.Utils.Nested.OriginalClassName","doc":"","ref":"Evision.Utils.Nested.OriginalClassName.html"},{"type":"function","title":"Evision.Utils.Nested.OriginalClassName.create/0","doc":"create\n##### Keyword Arguments\n- **params**: `Evision.Utils.Nested.OriginalClassName.Params`.\n\n##### Return\n- **retval**: `Evision.Utils.Nested.OriginalClassName.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, params]) -> retval\n```","ref":"Evision.Utils.Nested.OriginalClassName.html#create/0"},{"type":"function","title":"Evision.Utils.Nested.OriginalClassName.create/1","doc":"create\n##### Keyword Arguments\n- **params**: `Evision.Utils.Nested.OriginalClassName.Params`.\n\n##### Return\n- **retval**: `Evision.Utils.Nested.OriginalClassName.t()`\n\nPython prototype (for reference only):\n```python3\ncreate([, params]) -> retval\n```","ref":"Evision.Utils.Nested.OriginalClassName.html#create/1"},{"type":"function","title":"Evision.Utils.Nested.OriginalClassName.getFloatParam/1","doc":"getFloatParam\n\n##### Positional Arguments\n- **self**: `Evision.Utils.Nested.OriginalClassName.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetFloatParam() -> retval\n```","ref":"Evision.Utils.Nested.OriginalClassName.html#getFloatParam/1"},{"type":"function","title":"Evision.Utils.Nested.OriginalClassName.getIntParam/1","doc":"getIntParam\n\n##### Positional Arguments\n- **self**: `Evision.Utils.Nested.OriginalClassName.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetIntParam() -> retval\n```","ref":"Evision.Utils.Nested.OriginalClassName.html#getIntParam/1"},{"type":"function","title":"Evision.Utils.Nested.OriginalClassName.originalName/0","doc":"originalName\n##### Return\n- **retval**: `string`\n\nPython prototype (for reference only):\n```python3\noriginalName() -> retval\n```","ref":"Evision.Utils.Nested.OriginalClassName.html#originalName/0"},{"type":"function","title":"Evision.Utils.Nested.OriginalClassName.originalName/1","doc":"","ref":"Evision.Utils.Nested.OriginalClassName.html#originalName/1"},{"type":"type","title":"Evision.Utils.Nested.OriginalClassName.t/0","doc":"Type that represents an `Utils.Nested.OriginalClassName` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Utils.Nested.OriginalClassName.html#t:t/0"},{"type":"module","title":"Evision.Utils.Nested.OriginalClassName.Params","doc":"","ref":"Evision.Utils.Nested.OriginalClassName.Params.html"},{"type":"function","title":"Evision.Utils.Nested.OriginalClassName.Params.get_float_value/1","doc":"","ref":"Evision.Utils.Nested.OriginalClassName.Params.html#get_float_value/1"},{"type":"function","title":"Evision.Utils.Nested.OriginalClassName.Params.get_int_value/1","doc":"","ref":"Evision.Utils.Nested.OriginalClassName.Params.html#get_int_value/1"},{"type":"function","title":"Evision.Utils.Nested.OriginalClassName.Params.set_float_value/2","doc":"","ref":"Evision.Utils.Nested.OriginalClassName.Params.html#set_float_value/2"},{"type":"function","title":"Evision.Utils.Nested.OriginalClassName.Params.set_int_value/2","doc":"","ref":"Evision.Utils.Nested.OriginalClassName.Params.html#set_int_value/2"},{"type":"function","title":"Evision.Utils.Nested.OriginalClassName.Params.utils_nested_OriginalClassName_Params/0","doc":"OriginalClassName_Params\n##### Keyword Arguments\n- **int_param**: `integer()`.\n- **float_param**: `float`.\n\n##### Return\n- **self**: `Evision.Utils.Nested.OriginalClassName.Params.t()`\n\nPython prototype (for reference only):\n```python3\nOriginalClassName_Params([, int_param[, float_param]]) ->  \n```","ref":"Evision.Utils.Nested.OriginalClassName.Params.html#utils_nested_OriginalClassName_Params/0"},{"type":"function","title":"Evision.Utils.Nested.OriginalClassName.Params.utils_nested_OriginalClassName_Params/1","doc":"OriginalClassName_Params\n##### Keyword Arguments\n- **int_param**: `integer()`.\n- **float_param**: `float`.\n\n##### Return\n- **self**: `Evision.Utils.Nested.OriginalClassName.Params.t()`\n\nPython prototype (for reference only):\n```python3\nOriginalClassName_Params([, int_param[, float_param]]) ->  \n```","ref":"Evision.Utils.Nested.OriginalClassName.Params.html#utils_nested_OriginalClassName_Params/1"},{"type":"type","title":"Evision.Utils.Nested.OriginalClassName.Params.t/0","doc":"Type that represents an `Utils.Nested.OriginalClassName.Params` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.Utils.Nested.OriginalClassName.Params.html#t:t/0"},{"type":"module","title":"Evision.UtilsFS","doc":"","ref":"Evision.UtilsFS.html"},{"type":"function","title":"Evision.UtilsFS.getCacheDirectoryForDownloads/0","doc":"getCacheDirectoryForDownloads\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetCacheDirectoryForDownloads() -> retval\n```","ref":"Evision.UtilsFS.html#getCacheDirectoryForDownloads/0"},{"type":"function","title":"Evision.UtilsFS.getCacheDirectoryForDownloads/1","doc":"","ref":"Evision.UtilsFS.html#getCacheDirectoryForDownloads/1"},{"type":"type","title":"Evision.UtilsFS.t/0","doc":"Type that represents an `UtilsFS` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.UtilsFS.html#t:t/0"},{"type":"module","title":"Evision.VariationalRefinement","doc":"","ref":"Evision.VariationalRefinement.html"},{"type":"function","title":"Evision.VariationalRefinement.calcUV/1","doc":"","ref":"Evision.VariationalRefinement.html#calcUV/1"},{"type":"function","title":"Evision.VariationalRefinement.calcUV/5","doc":"@ref calc function overload to handle separate horizontal (u) and vertical (v) flow components\n(to avoid extra splits/merges)\n\n##### Positional Arguments\n- **self**: `Evision.VariationalRefinement.t()`\n- **i0**: `Evision.Mat`\n- **i1**: `Evision.Mat`\n\n##### Return\n- **flow_u**: `Evision.Mat.t()`\n- **flow_v**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ncalcUV(I0, I1, flow_u, flow_v) -> flow_u, flow_v\n```","ref":"Evision.VariationalRefinement.html#calcUV/5"},{"type":"function","title":"Evision.VariationalRefinement.create/0","doc":"Creates an instance of VariationalRefinement\n##### Return\n- **retval**: `Evision.VariationalRefinement.t()`\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.VariationalRefinement.html#create/0"},{"type":"function","title":"Evision.VariationalRefinement.create/1","doc":"","ref":"Evision.VariationalRefinement.html#create/1"},{"type":"function","title":"Evision.VariationalRefinement.getAlpha/1","doc":"Weight of the smoothness term\n\n##### Positional Arguments\n- **self**: `Evision.VariationalRefinement.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setAlpha/2`\n\nPython prototype (for reference only):\n```python3\ngetAlpha() -> retval\n```","ref":"Evision.VariationalRefinement.html#getAlpha/1"},{"type":"function","title":"Evision.VariationalRefinement.getDelta/1","doc":"Weight of the color constancy term\n\n##### Positional Arguments\n- **self**: `Evision.VariationalRefinement.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setDelta/2`\n\nPython prototype (for reference only):\n```python3\ngetDelta() -> retval\n```","ref":"Evision.VariationalRefinement.html#getDelta/1"},{"type":"function","title":"Evision.VariationalRefinement.getEpsilon/1","doc":"Norm value shift for robust penalizer\n\n##### Positional Arguments\n- **self**: `Evision.VariationalRefinement.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setEpsilon/2`\n\nPython prototype (for reference only):\n```python3\ngetEpsilon() -> retval\n```","ref":"Evision.VariationalRefinement.html#getEpsilon/1"},{"type":"function","title":"Evision.VariationalRefinement.getFixedPointIterations/1","doc":"Number of outer (fixed-point) iterations in the minimization procedure.\n\n##### Positional Arguments\n- **self**: `Evision.VariationalRefinement.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setFixedPointIterations/2`\n\nPython prototype (for reference only):\n```python3\ngetFixedPointIterations() -> retval\n```","ref":"Evision.VariationalRefinement.html#getFixedPointIterations/1"},{"type":"function","title":"Evision.VariationalRefinement.getGamma/1","doc":"Weight of the gradient constancy term\n\n##### Positional Arguments\n- **self**: `Evision.VariationalRefinement.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setGamma/2`\n\nPython prototype (for reference only):\n```python3\ngetGamma() -> retval\n```","ref":"Evision.VariationalRefinement.html#getGamma/1"},{"type":"function","title":"Evision.VariationalRefinement.getOmega/1","doc":"Relaxation factor in SOR\n\n##### Positional Arguments\n- **self**: `Evision.VariationalRefinement.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setOmega/2`\n\nPython prototype (for reference only):\n```python3\ngetOmega() -> retval\n```","ref":"Evision.VariationalRefinement.html#getOmega/1"},{"type":"function","title":"Evision.VariationalRefinement.getSorIterations/1","doc":"Number of inner successive over-relaxation (SOR) iterations\nin the minimization procedure to solve the respective linear system.\n\n##### Positional Arguments\n- **self**: `Evision.VariationalRefinement.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setSorIterations/2`\n\nPython prototype (for reference only):\n```python3\ngetSorIterations() -> retval\n```","ref":"Evision.VariationalRefinement.html#getSorIterations/1"},{"type":"function","title":"Evision.VariationalRefinement.setAlpha/1","doc":"","ref":"Evision.VariationalRefinement.html#setAlpha/1"},{"type":"function","title":"Evision.VariationalRefinement.setAlpha/2","doc":"setAlpha\n\n##### Positional Arguments\n- **self**: `Evision.VariationalRefinement.t()`\n- **val**: `float`\n\n@see `getAlpha/1`\n\nPython prototype (for reference only):\n```python3\nsetAlpha(val) -> None\n```","ref":"Evision.VariationalRefinement.html#setAlpha/2"},{"type":"function","title":"Evision.VariationalRefinement.setDelta/1","doc":"","ref":"Evision.VariationalRefinement.html#setDelta/1"},{"type":"function","title":"Evision.VariationalRefinement.setDelta/2","doc":"setDelta\n\n##### Positional Arguments\n- **self**: `Evision.VariationalRefinement.t()`\n- **val**: `float`\n\n@see `getDelta/1`\n\nPython prototype (for reference only):\n```python3\nsetDelta(val) -> None\n```","ref":"Evision.VariationalRefinement.html#setDelta/2"},{"type":"function","title":"Evision.VariationalRefinement.setEpsilon/1","doc":"","ref":"Evision.VariationalRefinement.html#setEpsilon/1"},{"type":"function","title":"Evision.VariationalRefinement.setEpsilon/2","doc":"setEpsilon\n\n##### Positional Arguments\n- **self**: `Evision.VariationalRefinement.t()`\n- **val**: `float`\n\n@see `getEpsilon/1`\n\nPython prototype (for reference only):\n```python3\nsetEpsilon(val) -> None\n```","ref":"Evision.VariationalRefinement.html#setEpsilon/2"},{"type":"function","title":"Evision.VariationalRefinement.setFixedPointIterations/1","doc":"","ref":"Evision.VariationalRefinement.html#setFixedPointIterations/1"},{"type":"function","title":"Evision.VariationalRefinement.setFixedPointIterations/2","doc":"setFixedPointIterations\n\n##### Positional Arguments\n- **self**: `Evision.VariationalRefinement.t()`\n- **val**: `integer()`\n\n@see `getFixedPointIterations/1`\n\nPython prototype (for reference only):\n```python3\nsetFixedPointIterations(val) -> None\n```","ref":"Evision.VariationalRefinement.html#setFixedPointIterations/2"},{"type":"function","title":"Evision.VariationalRefinement.setGamma/1","doc":"","ref":"Evision.VariationalRefinement.html#setGamma/1"},{"type":"function","title":"Evision.VariationalRefinement.setGamma/2","doc":"setGamma\n\n##### Positional Arguments\n- **self**: `Evision.VariationalRefinement.t()`\n- **val**: `float`\n\n@see `getGamma/1`\n\nPython prototype (for reference only):\n```python3\nsetGamma(val) -> None\n```","ref":"Evision.VariationalRefinement.html#setGamma/2"},{"type":"function","title":"Evision.VariationalRefinement.setOmega/1","doc":"","ref":"Evision.VariationalRefinement.html#setOmega/1"},{"type":"function","title":"Evision.VariationalRefinement.setOmega/2","doc":"setOmega\n\n##### Positional Arguments\n- **self**: `Evision.VariationalRefinement.t()`\n- **val**: `float`\n\n@see `getOmega/1`\n\nPython prototype (for reference only):\n```python3\nsetOmega(val) -> None\n```","ref":"Evision.VariationalRefinement.html#setOmega/2"},{"type":"function","title":"Evision.VariationalRefinement.setSorIterations/1","doc":"","ref":"Evision.VariationalRefinement.html#setSorIterations/1"},{"type":"function","title":"Evision.VariationalRefinement.setSorIterations/2","doc":"setSorIterations\n\n##### Positional Arguments\n- **self**: `Evision.VariationalRefinement.t()`\n- **val**: `integer()`\n\n@see `getSorIterations/1`\n\nPython prototype (for reference only):\n```python3\nsetSorIterations(val) -> None\n```","ref":"Evision.VariationalRefinement.html#setSorIterations/2"},{"type":"type","title":"Evision.VariationalRefinement.t/0","doc":"Type that represents an `VariationalRefinement` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.VariationalRefinement.html#t:t/0"},{"type":"module","title":"Evision.VideoAccelerationType","doc":"","ref":"Evision.VideoAccelerationType.html"},{"type":"function","title":"Evision.VideoAccelerationType.cv_VIDEO_ACCELERATION_ANY/0","doc":"","ref":"Evision.VideoAccelerationType.html#cv_VIDEO_ACCELERATION_ANY/0"},{"type":"function","title":"Evision.VideoAccelerationType.cv_VIDEO_ACCELERATION_D3D11/0","doc":"","ref":"Evision.VideoAccelerationType.html#cv_VIDEO_ACCELERATION_D3D11/0"},{"type":"function","title":"Evision.VideoAccelerationType.cv_VIDEO_ACCELERATION_MFX/0","doc":"","ref":"Evision.VideoAccelerationType.html#cv_VIDEO_ACCELERATION_MFX/0"},{"type":"function","title":"Evision.VideoAccelerationType.cv_VIDEO_ACCELERATION_NONE/0","doc":"","ref":"Evision.VideoAccelerationType.html#cv_VIDEO_ACCELERATION_NONE/0"},{"type":"function","title":"Evision.VideoAccelerationType.cv_VIDEO_ACCELERATION_VAAPI/0","doc":"","ref":"Evision.VideoAccelerationType.html#cv_VIDEO_ACCELERATION_VAAPI/0"},{"type":"type","title":"Evision.VideoAccelerationType.enum/0","doc":"","ref":"Evision.VideoAccelerationType.html#t:enum/0"},{"type":"module","title":"Evision.VideoCapture","doc":"","ref":"Evision.VideoCapture.html"},{"type":"function","title":"Evision.VideoCapture.get/1","doc":"","ref":"Evision.VideoCapture.html#get/1"},{"type":"function","title":"Evision.VideoCapture.get/2","doc":"Returns the specified VideoCapture property\n\n##### Positional Arguments\n- **self**: `Evision.VideoCapture.t()`\n- **propId**: `integer()`.\n\n  Property identifier from cv::VideoCaptureProperties (eg. cv::CAP_PROP_POS_MSEC, cv::CAP_PROP_POS_FRAMES, ...)\n  or one from @ref videoio_flags_others\n\n##### Return\n- **retval**: `double`\n\n@return Value for the specified property. Value 0 is returned when querying a property that is\nnot supported by the backend used by the VideoCapture instance.\n**Note**: Reading / writing properties involves many layers. Some unexpected result might happens\nalong this chain.\n```txt\nVideoCapture -> API Backend -> Operating System -> Device Driver -> Device Hardware\n```\nThe returned value might be different from what really used by the device or it could be encoded\nusing device dependent rules (eg. steps or percentage). Effective behaviour depends from device\ndriver and API Backend\n\nPython prototype (for reference only):\n```python3\nget(propId) -> retval\n```","ref":"Evision.VideoCapture.html#get/2"},{"type":"function","title":"Evision.VideoCapture.getBackendName/1","doc":"Returns used backend API name\n\n##### Positional Arguments\n- **self**: `Evision.VideoCapture.t()`\n\n##### Return\n- **retval**: `String`\n\n**Note**: Stream should be opened.\n\nPython prototype (for reference only):\n```python3\ngetBackendName() -> retval\n```","ref":"Evision.VideoCapture.html#getBackendName/1"},{"type":"function","title":"Evision.VideoCapture.getExceptionMode/1","doc":"getExceptionMode\n\n##### Positional Arguments\n- **self**: `Evision.VideoCapture.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetExceptionMode() -> retval\n```","ref":"Evision.VideoCapture.html#getExceptionMode/1"},{"type":"function","title":"Evision.VideoCapture.grab/1","doc":"Grabs the next frame from video file or capturing device.\n\n##### Positional Arguments\n- **self**: `Evision.VideoCapture.t()`\n\n##### Return\n- **retval**: `bool`\n\n@return `true` (non-zero) in the case of success.\nThe method/function grabs the next frame from video file or camera and returns true (non-zero) in\nthe case of success.\nThe primary use of the function is in multi-camera environments, especially when the cameras do not\nhave hardware synchronization. That is, you call VideoCapture::grab() for each camera and after that\ncall the slower method VideoCapture::retrieve() to decode and get frame from each camera. This way\nthe overhead on demosaicing or motion jpeg decompression etc. is eliminated and the retrieved frames\nfrom different cameras will be closer in time.\nAlso, when a connected camera is multi-head (for example, a stereo camera or a Kinect device), the\ncorrect way of retrieving data from it is to call VideoCapture::grab() first and then call\nVideoCapture::retrieve() one or more times with different values of the channel parameter.\n@ref tutorial_kinect_openni\n\nPython prototype (for reference only):\n```python3\ngrab() -> retval\n```","ref":"Evision.VideoCapture.html#grab/1"},{"type":"function","title":"Evision.VideoCapture.isOpened/1","doc":"Returns true if video capturing has been initialized already.\n\n##### Positional Arguments\n- **self**: `Evision.VideoCapture.t()`\n\n##### Return\n- **retval**: `bool`\n\nIf the previous call to VideoCapture constructor or VideoCapture::open() succeeded, the method returns\ntrue.\n\nPython prototype (for reference only):\n```python3\nisOpened() -> retval\n```","ref":"Evision.VideoCapture.html#isOpened/1"},{"type":"function","title":"Evision.VideoCapture.open/1","doc":"","ref":"Evision.VideoCapture.html#open/1"},{"type":"function","title":"Evision.VideoCapture.open/2","doc":"#### Variant 1:\nOpens a camera for video capturing\n\n##### Positional Arguments\n- **self**: `Evision.VideoCapture.t()`\n- **index**: `integer()`\n\n##### Keyword Arguments\n- **apiPreference**: `integer()`.\n\n##### Return\n- **retval**: `bool`\n\nHas overloading in C++\n\nParameters are same as the constructor VideoCapture(int index, int apiPreference = CAP_ANY)\n@return `true` if the camera has been successfully opened.\nThe method first calls VideoCapture::release to close the already opened file or camera.\n\nPython prototype (for reference only):\n```python3\nopen(index[, apiPreference]) -> retval\n```\n#### Variant 2:\nOpens a video file or a capturing device or an IP video stream for video capturing.\n\n##### Positional Arguments\n- **self**: `Evision.VideoCapture.t()`\n- **filename**: `String`\n\n##### Keyword Arguments\n- **apiPreference**: `integer()`.\n\n##### Return\n- **retval**: `bool`\n\nHas overloading in C++\n\nParameters are same as the constructor VideoCapture(const String& filename, int apiPreference = CAP_ANY)\n@return `true` if the file has been successfully opened\nThe method first calls VideoCapture::release to close the already opened file or camera.\n\nPython prototype (for reference only):\n```python3\nopen(filename[, apiPreference]) -> retval\n```","ref":"Evision.VideoCapture.html#open/2"},{"type":"function","title":"Evision.VideoCapture.open/3","doc":"#### Variant 1:\nOpens a camera for video capturing\n\n##### Positional Arguments\n- **self**: `Evision.VideoCapture.t()`\n- **index**: `integer()`\n\n##### Keyword Arguments\n- **apiPreference**: `integer()`.\n\n##### Return\n- **retval**: `bool`\n\nHas overloading in C++\n\nParameters are same as the constructor VideoCapture(int index, int apiPreference = CAP_ANY)\n@return `true` if the camera has been successfully opened.\nThe method first calls VideoCapture::release to close the already opened file or camera.\n\nPython prototype (for reference only):\n```python3\nopen(index[, apiPreference]) -> retval\n```\n#### Variant 2:\nOpens a video file or a capturing device or an IP video stream for video capturing.\n\n##### Positional Arguments\n- **self**: `Evision.VideoCapture.t()`\n- **filename**: `String`\n\n##### Keyword Arguments\n- **apiPreference**: `integer()`.\n\n##### Return\n- **retval**: `bool`\n\nHas overloading in C++\n\nParameters are same as the constructor VideoCapture(const String& filename, int apiPreference = CAP_ANY)\n@return `true` if the file has been successfully opened\nThe method first calls VideoCapture::release to close the already opened file or camera.\n\nPython prototype (for reference only):\n```python3\nopen(filename[, apiPreference]) -> retval\n```","ref":"Evision.VideoCapture.html#open/3"},{"type":"function","title":"Evision.VideoCapture.open/4","doc":"#### Variant 1:\nOpens a camera for video capturing with API Preference and parameters\n\n##### Positional Arguments\n- **self**: `Evision.VideoCapture.t()`\n- **index**: `integer()`\n- **apiPreference**: `integer()`\n- **params**: `[integer()]`\n\n##### Return\n- **retval**: `bool`\n\nHas overloading in C++\n\nThe `params` parameter allows to specify extra parameters encoded as pairs `(paramId_1, paramValue_1, paramId_2, paramValue_2, ...)`.\nSee cv::VideoCaptureProperties\n@return `true` if the camera has been successfully opened.\nThe method first calls VideoCapture::release to close the already opened file or camera.\n\nPython prototype (for reference only):\n```python3\nopen(index, apiPreference, params) -> retval\n```\n#### Variant 2:\nOpens a video file or a capturing device or an IP video stream for video capturing with API Preference and parameters\n\n##### Positional Arguments\n- **self**: `Evision.VideoCapture.t()`\n- **filename**: `String`\n- **apiPreference**: `integer()`\n- **params**: `[integer()]`\n\n##### Return\n- **retval**: `bool`\n\nHas overloading in C++\n\nThe `params` parameter allows to specify extra parameters encoded as pairs `(paramId_1, paramValue_1, paramId_2, paramValue_2, ...)`.\nSee cv::VideoCaptureProperties\n@return `true` if the file has been successfully opened\nThe method first calls VideoCapture::release to close the already opened file or camera.\n\nPython prototype (for reference only):\n```python3\nopen(filename, apiPreference, params) -> retval\n```","ref":"Evision.VideoCapture.html#open/4"},{"type":"function","title":"Evision.VideoCapture.read/1","doc":"Grabs, decodes and returns the next video frame.\n\n##### Positional Arguments\n- **self**: `Evision.VideoCapture.t()`\n\n##### Return\n- **retval**: `bool`\n- **image**: `Evision.Mat.t()`.\n\n@return `false` if no frames has been grabbed\nThe method/function combines VideoCapture::grab() and VideoCapture::retrieve() in one call. This is the\nmost convenient method for reading video files or capturing data from decode and returns the just\ngrabbed frame. If no frames has been grabbed (camera has been disconnected, or there are no more\nframes in video file), the method returns false and the function returns empty image (with %cv::Mat, test it with Mat::empty()).\n**Note**: In @ref videoio_c \"C API\", functions cvRetrieveFrame() and cv.RetrieveFrame() return image stored inside the video\ncapturing structure. It is not allowed to modify or release the image! You can copy the frame using\ncvCloneImage and then do whatever you want with the copy.\n\nPython prototype (for reference only):\n```python3\nread([, image]) -> retval, image\n```","ref":"Evision.VideoCapture.html#read/1"},{"type":"function","title":"Evision.VideoCapture.read/2","doc":"Grabs, decodes and returns the next video frame.\n\n##### Positional Arguments\n- **self**: `Evision.VideoCapture.t()`\n\n##### Return\n- **retval**: `bool`\n- **image**: `Evision.Mat.t()`.\n\n@return `false` if no frames has been grabbed\nThe method/function combines VideoCapture::grab() and VideoCapture::retrieve() in one call. This is the\nmost convenient method for reading video files or capturing data from decode and returns the just\ngrabbed frame. If no frames has been grabbed (camera has been disconnected, or there are no more\nframes in video file), the method returns false and the function returns empty image (with %cv::Mat, test it with Mat::empty()).\n**Note**: In @ref videoio_c \"C API\", functions cvRetrieveFrame() and cv.RetrieveFrame() return image stored inside the video\ncapturing structure. It is not allowed to modify or release the image! You can copy the frame using\ncvCloneImage and then do whatever you want with the copy.\n\nPython prototype (for reference only):\n```python3\nread([, image]) -> retval, image\n```","ref":"Evision.VideoCapture.html#read/2"},{"type":"function","title":"Evision.VideoCapture.release/1","doc":"Closes video file or capturing device.\n\n##### Positional Arguments\n- **self**: `Evision.VideoCapture.t()`\n\nThe method is automatically called by subsequent VideoCapture::open and by VideoCapture\ndestructor.\nThe C function also deallocates memory and clears \\*capture pointer.\n\nPython prototype (for reference only):\n```python3\nrelease() -> None\n```","ref":"Evision.VideoCapture.html#release/1"},{"type":"function","title":"Evision.VideoCapture.retrieve/1","doc":"Decodes and returns the grabbed video frame.\n\n##### Positional Arguments\n- **self**: `Evision.VideoCapture.t()`\n\n##### Keyword Arguments\n- **flag**: `integer()`.\n\n  it could be a frame index or a driver specific flag\n\n##### Return\n- **retval**: `bool`\n- **image**: `Evision.Mat.t()`.\n\n@return `false` if no frames has been grabbed\nThe method decodes and returns the just grabbed frame. If no frames has been grabbed\n(camera has been disconnected, or there are no more frames in video file), the method returns false\nand the function returns an empty image (with %cv::Mat, test it with Mat::empty()).\n@sa read()\n**Note**: In @ref videoio_c \"C API\", functions cvRetrieveFrame() and cv.RetrieveFrame() return image stored inside the video\ncapturing structure. It is not allowed to modify or release the image! You can copy the frame using\ncvCloneImage and then do whatever you want with the copy.\n\nPython prototype (for reference only):\n```python3\nretrieve([, image[, flag]]) -> retval, image\n```","ref":"Evision.VideoCapture.html#retrieve/1"},{"type":"function","title":"Evision.VideoCapture.retrieve/2","doc":"Decodes and returns the grabbed video frame.\n\n##### Positional Arguments\n- **self**: `Evision.VideoCapture.t()`\n\n##### Keyword Arguments\n- **flag**: `integer()`.\n\n  it could be a frame index or a driver specific flag\n\n##### Return\n- **retval**: `bool`\n- **image**: `Evision.Mat.t()`.\n\n@return `false` if no frames has been grabbed\nThe method decodes and returns the just grabbed frame. If no frames has been grabbed\n(camera has been disconnected, or there are no more frames in video file), the method returns false\nand the function returns an empty image (with %cv::Mat, test it with Mat::empty()).\n@sa read()\n**Note**: In @ref videoio_c \"C API\", functions cvRetrieveFrame() and cv.RetrieveFrame() return image stored inside the video\ncapturing structure. It is not allowed to modify or release the image! You can copy the frame using\ncvCloneImage and then do whatever you want with the copy.\n\nPython prototype (for reference only):\n```python3\nretrieve([, image[, flag]]) -> retval, image\n```","ref":"Evision.VideoCapture.html#retrieve/2"},{"type":"function","title":"Evision.VideoCapture.set/1","doc":"","ref":"Evision.VideoCapture.html#set/1"},{"type":"function","title":"Evision.VideoCapture.set/3","doc":"Sets a property in the VideoCapture.\n\n##### Positional Arguments\n- **self**: `Evision.VideoCapture.t()`\n- **propId**: `integer()`.\n\n  Property identifier from cv::VideoCaptureProperties (eg. cv::CAP_PROP_POS_MSEC, cv::CAP_PROP_POS_FRAMES, ...)\n  or one from @ref videoio_flags_others\n\n- **value**: `double`.\n\n  Value of the property.\n\n##### Return\n- **retval**: `bool`\n\n@return `true` if the property is supported by backend used by the VideoCapture instance.\n**Note**: Even if it returns `true` this doesn't ensure that the property\nvalue has been accepted by the capture device. See note in VideoCapture::get()\n\nPython prototype (for reference only):\n```python3\nset(propId, value) -> retval\n```","ref":"Evision.VideoCapture.html#set/3"},{"type":"function","title":"Evision.VideoCapture.setExceptionMode/1","doc":"","ref":"Evision.VideoCapture.html#setExceptionMode/1"},{"type":"function","title":"Evision.VideoCapture.setExceptionMode/2","doc":"setExceptionMode\n\n##### Positional Arguments\n- **self**: `Evision.VideoCapture.t()`\n- **enable**: `bool`\n\nSwitches exceptions mode\n methods raise exceptions if not successful instead of returning an error code\n\nPython prototype (for reference only):\n```python3\nsetExceptionMode(enable) -> None\n```","ref":"Evision.VideoCapture.html#setExceptionMode/2"},{"type":"function","title":"Evision.VideoCapture.videoCapture/0","doc":"Default constructor\n##### Return\n- **self**: `Evision.VideoCapture.t()`\n\n**Note**: In @ref videoio_c \"C API\", when you finished working with video, release CvCapture structure with\ncvReleaseCapture(), or use Ptr\\  that calls cvReleaseCapture() automatically in the\ndestructor.\n\nPython prototype (for reference only):\n```python3\nVideoCapture() ->  \n```","ref":"Evision.VideoCapture.html#videoCapture/0"},{"type":"function","title":"Evision.VideoCapture.videoCapture/1","doc":"#### Variant 1:\nOpens a camera for video capturing\n\n##### Positional Arguments\n- **index**: `integer()`.\n\n  id of the video capturing device to open. To open default camera using default backend just pass 0.\n  (to backward compatibility usage of camera_id + domain_offset (CAP_*) is valid when apiPreference is CAP_ANY)\n\n##### Keyword Arguments\n- **apiPreference**: `integer()`.\n\n  preferred Capture API backends to use. Can be used to enforce a specific reader\n  implementation if multiple are available: e.g. cv::CAP_DSHOW or cv::CAP_MSMF or cv::CAP_V4L.\n\n##### Return\n- **self**: `Evision.VideoCapture.t()`\n\nHas overloading in C++\n\n@sa cv::VideoCaptureAPIs\n\nPython prototype (for reference only):\n```python3\nVideoCapture(index[, apiPreference]) ->  \n```\n#### Variant 2:\nOpens a video file or a capturing device or an IP video stream for video capturing with API Preference\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  it can be:\n  - name of video file (eg. `video.avi`)\n  - or image sequence (eg. `img_%02d.jpg`, which will read samples like `img_00.jpg, img_01.jpg, img_02.jpg, ...`)\n  - or URL of video stream (eg. `protocol://host:port/script_name?script_params|auth`)\n  - or GStreamer pipeline string in gst-launch tool format in case if GStreamer is used as backend\n    Note that each video stream or IP camera feed has its own URL scheme. Please refer to the\n    documentation of source stream to know the right URL.\n\n##### Keyword Arguments\n- **apiPreference**: `integer()`.\n\n  preferred Capture API backends to use. Can be used to enforce a specific reader\n  implementation if multiple are available: e.g. cv::CAP_FFMPEG or cv::CAP_IMAGES or cv::CAP_DSHOW.\n\n##### Return\n- **self**: `Evision.VideoCapture.t()`\n\nHas overloading in C++\n\n@sa cv::VideoCaptureAPIs\n\nPython prototype (for reference only):\n```python3\nVideoCapture(filename[, apiPreference]) ->  \n```","ref":"Evision.VideoCapture.html#videoCapture/1"},{"type":"function","title":"Evision.VideoCapture.videoCapture/2","doc":"#### Variant 1:\nOpens a camera for video capturing\n\n##### Positional Arguments\n- **index**: `integer()`.\n\n  id of the video capturing device to open. To open default camera using default backend just pass 0.\n  (to backward compatibility usage of camera_id + domain_offset (CAP_*) is valid when apiPreference is CAP_ANY)\n\n##### Keyword Arguments\n- **apiPreference**: `integer()`.\n\n  preferred Capture API backends to use. Can be used to enforce a specific reader\n  implementation if multiple are available: e.g. cv::CAP_DSHOW or cv::CAP_MSMF or cv::CAP_V4L.\n\n##### Return\n- **self**: `Evision.VideoCapture.t()`\n\nHas overloading in C++\n\n@sa cv::VideoCaptureAPIs\n\nPython prototype (for reference only):\n```python3\nVideoCapture(index[, apiPreference]) ->  \n```\n#### Variant 2:\nOpens a video file or a capturing device or an IP video stream for video capturing with API Preference\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  it can be:\n  - name of video file (eg. `video.avi`)\n  - or image sequence (eg. `img_%02d.jpg`, which will read samples like `img_00.jpg, img_01.jpg, img_02.jpg, ...`)\n  - or URL of video stream (eg. `protocol://host:port/script_name?script_params|auth`)\n  - or GStreamer pipeline string in gst-launch tool format in case if GStreamer is used as backend\n    Note that each video stream or IP camera feed has its own URL scheme. Please refer to the\n    documentation of source stream to know the right URL.\n\n##### Keyword Arguments\n- **apiPreference**: `integer()`.\n\n  preferred Capture API backends to use. Can be used to enforce a specific reader\n  implementation if multiple are available: e.g. cv::CAP_FFMPEG or cv::CAP_IMAGES or cv::CAP_DSHOW.\n\n##### Return\n- **self**: `Evision.VideoCapture.t()`\n\nHas overloading in C++\n\n@sa cv::VideoCaptureAPIs\n\nPython prototype (for reference only):\n```python3\nVideoCapture(filename[, apiPreference]) ->  \n```","ref":"Evision.VideoCapture.html#videoCapture/2"},{"type":"function","title":"Evision.VideoCapture.videoCapture/3","doc":"#### Variant 1:\nOpens a camera for video capturing with API Preference and parameters\n\n##### Positional Arguments\n- **index**: `integer()`\n- **apiPreference**: `integer()`\n- **params**: `[integer()]`\n\n##### Return\n- **self**: `Evision.VideoCapture.t()`\n\nHas overloading in C++\n\nThe `params` parameter allows to specify extra parameters encoded as pairs `(paramId_1, paramValue_1, paramId_2, paramValue_2, ...)`.\nSee cv::VideoCaptureProperties\n\nPython prototype (for reference only):\n```python3\nVideoCapture(index, apiPreference, params) ->  \n```\n#### Variant 2:\nOpens a video file or a capturing device or an IP video stream for video capturing with API Preference and parameters\n\n##### Positional Arguments\n- **filename**: `String`\n- **apiPreference**: `integer()`\n- **params**: `[integer()]`\n\n##### Return\n- **self**: `Evision.VideoCapture.t()`\n\nHas overloading in C++\n\nThe `params` parameter allows to specify extra parameters encoded as pairs `(paramId_1, paramValue_1, paramId_2, paramValue_2, ...)`.\nSee cv::VideoCaptureProperties\n\nPython prototype (for reference only):\n```python3\nVideoCapture(filename, apiPreference, params) ->  \n```","ref":"Evision.VideoCapture.html#videoCapture/3"},{"type":"function","title":"Evision.VideoCapture.waitAny/1","doc":"Wait for ready frames from VideoCapture.\n\n##### Positional Arguments\n- **streams**: `[Evision.VideoCapture]`.\n\n  input video streams\n\n##### Keyword Arguments\n- **timeoutNs**: `int64`.\n\n  number of nanoseconds (0 - infinite)\n\n##### Return\n- **retval**: `bool`\n- **readyIndex**: `[int]`.\n\n  stream indexes with grabbed frames (ready to use .retrieve() to fetch actual frame)\n\n@return `true` if streamReady is not empty\n@throws Exception %Exception on stream errors (check .isOpened() to filter out malformed streams) or VideoCapture type is not supported\nThe primary use of the function is in multi-camera environments.\nThe method fills the ready state vector, grabs video frame, if camera is ready.\nAfter this call use VideoCapture::retrieve() to decode and fetch frame data.\n\nPython prototype (for reference only):\n```python3\nwaitAny(streams[, timeoutNs]) -> retval, readyIndex\n```","ref":"Evision.VideoCapture.html#waitAny/1"},{"type":"function","title":"Evision.VideoCapture.waitAny/2","doc":"Wait for ready frames from VideoCapture.\n\n##### Positional Arguments\n- **streams**: `[Evision.VideoCapture]`.\n\n  input video streams\n\n##### Keyword Arguments\n- **timeoutNs**: `int64`.\n\n  number of nanoseconds (0 - infinite)\n\n##### Return\n- **retval**: `bool`\n- **readyIndex**: `[int]`.\n\n  stream indexes with grabbed frames (ready to use .retrieve() to fetch actual frame)\n\n@return `true` if streamReady is not empty\n@throws Exception %Exception on stream errors (check .isOpened() to filter out malformed streams) or VideoCapture type is not supported\nThe primary use of the function is in multi-camera environments.\nThe method fills the ready state vector, grabs video frame, if camera is ready.\nAfter this call use VideoCapture::retrieve() to decode and fetch frame data.\n\nPython prototype (for reference only):\n```python3\nwaitAny(streams[, timeoutNs]) -> retval, readyIndex\n```","ref":"Evision.VideoCapture.html#waitAny/2"},{"type":"type","title":"Evision.VideoCapture.t/0","doc":"Type that represents an `Evision.VideoCapture` struct.\n\n- **fps**. `double`.\n\n  Frames per second.\n\n- **frame_count**. `double`.\n\n  Total number of frames.\n\n- **frame_width**. `double`.\n\n  Width of each frame.\n\n- **frame_height**. `double`.\n\n  Height of each frame.\n\n- **isOpened**. `boolean`.\n\n  Is successfully opened the video source.\n\n- **ref**. `reference`.\n\n  The underlying erlang resource variable.","ref":"Evision.VideoCapture.html#t:t/0"},{"type":"module","title":"Evision.VideoCaptureAPIs","doc":"","ref":"Evision.VideoCaptureAPIs.html"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_ANDROID/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_ANDROID/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_ANY/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_ANY/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_ARAVIS/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_ARAVIS/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_AVFOUNDATION/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_AVFOUNDATION/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_CMU1394/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_CMU1394/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_DC1394/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_DC1394/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_DSHOW/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_DSHOW/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_FFMPEG/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_FFMPEG/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_FIREWARE/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_FIREWARE/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_FIREWIRE/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_FIREWIRE/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_GIGANETIX/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_GIGANETIX/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_GPHOTO2/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_GPHOTO2/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_GSTREAMER/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_GSTREAMER/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_IEEE1394/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_IEEE1394/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_IMAGES/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_IMAGES/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_INTEL_MFX/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_INTEL_MFX/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_INTELPERC/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_INTELPERC/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_MSMF/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_MSMF/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_OBSENSOR/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_OBSENSOR/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_OPENCV_MJPEG/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_OPENCV_MJPEG/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_OPENNI2/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_OPENNI2/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_OPENNI2_ASTRA/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_OPENNI2_ASTRA/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_OPENNI2_ASUS/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_OPENNI2_ASUS/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_OPENNI/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_OPENNI/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_OPENNI_ASUS/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_OPENNI_ASUS/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_PVAPI/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_PVAPI/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_QT/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_QT/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_REALSENSE/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_REALSENSE/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_UEYE/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_UEYE/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_UNICAP/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_UNICAP/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_V4L2/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_V4L2/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_V4L/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_V4L/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_VFW/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_VFW/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_WINRT/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_WINRT/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_XIAPI/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_XIAPI/0"},{"type":"function","title":"Evision.VideoCaptureAPIs.cv_CAP_XINE/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#cv_CAP_XINE/0"},{"type":"type","title":"Evision.VideoCaptureAPIs.enum/0","doc":"","ref":"Evision.VideoCaptureAPIs.html#t:enum/0"},{"type":"module","title":"Evision.VideoCaptureOBSensorDataType","doc":"","ref":"Evision.VideoCaptureOBSensorDataType.html"},{"type":"function","title":"Evision.VideoCaptureOBSensorDataType.cv_CAP_OBSENSOR_BGR_IMAGE/0","doc":"","ref":"Evision.VideoCaptureOBSensorDataType.html#cv_CAP_OBSENSOR_BGR_IMAGE/0"},{"type":"function","title":"Evision.VideoCaptureOBSensorDataType.cv_CAP_OBSENSOR_DEPTH_MAP/0","doc":"","ref":"Evision.VideoCaptureOBSensorDataType.html#cv_CAP_OBSENSOR_DEPTH_MAP/0"},{"type":"function","title":"Evision.VideoCaptureOBSensorDataType.cv_CAP_OBSENSOR_IR_IMAGE/0","doc":"","ref":"Evision.VideoCaptureOBSensorDataType.html#cv_CAP_OBSENSOR_IR_IMAGE/0"},{"type":"type","title":"Evision.VideoCaptureOBSensorDataType.enum/0","doc":"","ref":"Evision.VideoCaptureOBSensorDataType.html#t:enum/0"},{"type":"module","title":"Evision.VideoCaptureOBSensorGenerators","doc":"","ref":"Evision.VideoCaptureOBSensorGenerators.html"},{"type":"function","title":"Evision.VideoCaptureOBSensorGenerators.cv_CAP_OBSENSOR_DEPTH_GENERATOR/0","doc":"","ref":"Evision.VideoCaptureOBSensorGenerators.html#cv_CAP_OBSENSOR_DEPTH_GENERATOR/0"},{"type":"function","title":"Evision.VideoCaptureOBSensorGenerators.cv_CAP_OBSENSOR_GENERATORS_MASK/0","doc":"","ref":"Evision.VideoCaptureOBSensorGenerators.html#cv_CAP_OBSENSOR_GENERATORS_MASK/0"},{"type":"function","title":"Evision.VideoCaptureOBSensorGenerators.cv_CAP_OBSENSOR_IMAGE_GENERATOR/0","doc":"","ref":"Evision.VideoCaptureOBSensorGenerators.html#cv_CAP_OBSENSOR_IMAGE_GENERATOR/0"},{"type":"function","title":"Evision.VideoCaptureOBSensorGenerators.cv_CAP_OBSENSOR_IR_GENERATOR/0","doc":"","ref":"Evision.VideoCaptureOBSensorGenerators.html#cv_CAP_OBSENSOR_IR_GENERATOR/0"},{"type":"type","title":"Evision.VideoCaptureOBSensorGenerators.enum/0","doc":"","ref":"Evision.VideoCaptureOBSensorGenerators.html#t:enum/0"},{"type":"module","title":"Evision.VideoCaptureOBSensorProperties","doc":"","ref":"Evision.VideoCaptureOBSensorProperties.html"},{"type":"function","title":"Evision.VideoCaptureOBSensorProperties.cv_CAP_PROP_OBSENSOR_INTRINSIC_CX/0","doc":"","ref":"Evision.VideoCaptureOBSensorProperties.html#cv_CAP_PROP_OBSENSOR_INTRINSIC_CX/0"},{"type":"function","title":"Evision.VideoCaptureOBSensorProperties.cv_CAP_PROP_OBSENSOR_INTRINSIC_CY/0","doc":"","ref":"Evision.VideoCaptureOBSensorProperties.html#cv_CAP_PROP_OBSENSOR_INTRINSIC_CY/0"},{"type":"function","title":"Evision.VideoCaptureOBSensorProperties.cv_CAP_PROP_OBSENSOR_INTRINSIC_FX/0","doc":"","ref":"Evision.VideoCaptureOBSensorProperties.html#cv_CAP_PROP_OBSENSOR_INTRINSIC_FX/0"},{"type":"function","title":"Evision.VideoCaptureOBSensorProperties.cv_CAP_PROP_OBSENSOR_INTRINSIC_FY/0","doc":"","ref":"Evision.VideoCaptureOBSensorProperties.html#cv_CAP_PROP_OBSENSOR_INTRINSIC_FY/0"},{"type":"type","title":"Evision.VideoCaptureOBSensorProperties.enum/0","doc":"","ref":"Evision.VideoCaptureOBSensorProperties.html#t:enum/0"},{"type":"module","title":"Evision.VideoCaptureProperties","doc":"","ref":"Evision.VideoCaptureProperties.html"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_AUDIO_BASE_INDEX/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_AUDIO_BASE_INDEX/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_AUDIO_DATA_DEPTH/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_AUDIO_DATA_DEPTH/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_AUDIO_POS/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_AUDIO_POS/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_AUDIO_SAMPLES_PER_SECOND/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_AUDIO_SAMPLES_PER_SECOND/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_AUDIO_SHIFT_NSEC/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_AUDIO_SHIFT_NSEC/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_AUDIO_STREAM/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_AUDIO_STREAM/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_AUDIO_SYNCHRONIZE/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_AUDIO_SYNCHRONIZE/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_AUDIO_TOTAL_CHANNELS/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_AUDIO_TOTAL_CHANNELS/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_AUDIO_TOTAL_STREAMS/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_AUDIO_TOTAL_STREAMS/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_AUTO_EXPOSURE/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_AUTO_EXPOSURE/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_AUTO_WB/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_AUTO_WB/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_AUTOFOCUS/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_AUTOFOCUS/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_BACKEND/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_BACKEND/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_BACKLIGHT/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_BACKLIGHT/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_BITRATE/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_BITRATE/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_BRIGHTNESS/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_BRIGHTNESS/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_BUFFERSIZE/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_BUFFERSIZE/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_CHANNEL/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_CHANNEL/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_CODEC_EXTRADATA_INDEX/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_CODEC_EXTRADATA_INDEX/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_CODEC_PIXEL_FORMAT/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_CODEC_PIXEL_FORMAT/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_CONTRAST/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_CONTRAST/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_CONVERT_RGB/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_CONVERT_RGB/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_EXPOSURE/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_EXPOSURE/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_FOCUS/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_FOCUS/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_FORMAT/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_FORMAT/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_FOURCC/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_FOURCC/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_FPS/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_FPS/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_FRAME_COUNT/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_FRAME_COUNT/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_FRAME_HEIGHT/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_FRAME_HEIGHT/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_FRAME_TYPE/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_FRAME_TYPE/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_FRAME_WIDTH/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_FRAME_WIDTH/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_GAIN/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_GAIN/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_GAMMA/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_GAMMA/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_GUID/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_GUID/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_HUE/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_HUE/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_HW_ACCELERATION/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_HW_ACCELERATION/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_HW_ACCELERATION_USE_OPENCL/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_HW_ACCELERATION_USE_OPENCL/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_HW_DEVICE/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_HW_DEVICE/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_IRIS/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_IRIS/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_ISO_SPEED/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_ISO_SPEED/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_LRF_HAS_KEY_FRAME/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_LRF_HAS_KEY_FRAME/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_MODE/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_MODE/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_MONOCHROME/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_MONOCHROME/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_N_THREADS/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_N_THREADS/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_OPEN_TIMEOUT_MSEC/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_OPEN_TIMEOUT_MSEC/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_ORIENTATION_AUTO/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_ORIENTATION_AUTO/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_ORIENTATION_META/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_ORIENTATION_META/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_PAN/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_PAN/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_POS_AVI_RATIO/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_POS_AVI_RATIO/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_POS_FRAMES/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_POS_FRAMES/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_POS_MSEC/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_POS_MSEC/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_READ_TIMEOUT_MSEC/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_READ_TIMEOUT_MSEC/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_RECTIFICATION/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_RECTIFICATION/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_ROLL/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_ROLL/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_SAR_DEN/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_SAR_DEN/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_SAR_NUM/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_SAR_NUM/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_SATURATION/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_SATURATION/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_SETTINGS/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_SETTINGS/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_SHARPNESS/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_SHARPNESS/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_STREAM_OPEN_TIME_USEC/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_STREAM_OPEN_TIME_USEC/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_TEMPERATURE/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_TEMPERATURE/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_TILT/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_TILT/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_TRIGGER/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_TRIGGER/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_TRIGGER_DELAY/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_TRIGGER_DELAY/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_VIDEO_STREAM/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_VIDEO_STREAM/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_VIDEO_TOTAL_CHANNELS/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_VIDEO_TOTAL_CHANNELS/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_WB_TEMPERATURE/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_WB_TEMPERATURE/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_WHITE_BALANCE_BLUE_U/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_WHITE_BALANCE_BLUE_U/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_WHITE_BALANCE_RED_V/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_WHITE_BALANCE_RED_V/0"},{"type":"function","title":"Evision.VideoCaptureProperties.cv_CAP_PROP_ZOOM/0","doc":"","ref":"Evision.VideoCaptureProperties.html#cv_CAP_PROP_ZOOM/0"},{"type":"type","title":"Evision.VideoCaptureProperties.enum/0","doc":"","ref":"Evision.VideoCaptureProperties.html#t:enum/0"},{"type":"module","title":"Evision.VideoIORegistry","doc":"","ref":"Evision.VideoIORegistry.html"},{"type":"function","title":"Evision.VideoIORegistry.getBackendName/1","doc":"Returns backend API name or \"UnknownVideoAPI(xxx)\"\n\n##### Positional Arguments\n- **api**: `VideoCaptureAPIs`.\n\n  backend ID (#VideoCaptureAPIs)\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetBackendName(api) -> retval\n```","ref":"Evision.VideoIORegistry.html#getBackendName/1"},{"type":"function","title":"Evision.VideoIORegistry.getBackends/0","doc":"Returns list of all available backends\n##### Return\n- **retval**: `[VideoCaptureAPIs]`\n\nPython prototype (for reference only):\n```python3\ngetBackends() -> retval\n```","ref":"Evision.VideoIORegistry.html#getBackends/0"},{"type":"function","title":"Evision.VideoIORegistry.getBackends/1","doc":"","ref":"Evision.VideoIORegistry.html#getBackends/1"},{"type":"function","title":"Evision.VideoIORegistry.getCameraBackendPluginVersion/1","doc":"Returns description and ABI/API version of videoio plugin's camera interface\n\n##### Positional Arguments\n- **api**: `VideoCaptureAPIs`\n\n##### Return\n- **retval**: `string`\n- **version_ABI**: `integer()`\n- **version_API**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetCameraBackendPluginVersion(api) -> retval, version_ABI, version_API\n```","ref":"Evision.VideoIORegistry.html#getCameraBackendPluginVersion/1"},{"type":"function","title":"Evision.VideoIORegistry.getCameraBackends/0","doc":"Returns list of available backends which works via `cv::VideoCapture(int index)`\n##### Return\n- **retval**: `[VideoCaptureAPIs]`\n\nPython prototype (for reference only):\n```python3\ngetCameraBackends() -> retval\n```","ref":"Evision.VideoIORegistry.html#getCameraBackends/0"},{"type":"function","title":"Evision.VideoIORegistry.getCameraBackends/1","doc":"","ref":"Evision.VideoIORegistry.html#getCameraBackends/1"},{"type":"function","title":"Evision.VideoIORegistry.getStreamBackendPluginVersion/1","doc":"Returns description and ABI/API version of videoio plugin's stream capture interface\n\n##### Positional Arguments\n- **api**: `VideoCaptureAPIs`\n\n##### Return\n- **retval**: `string`\n- **version_ABI**: `integer()`\n- **version_API**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetStreamBackendPluginVersion(api) -> retval, version_ABI, version_API\n```","ref":"Evision.VideoIORegistry.html#getStreamBackendPluginVersion/1"},{"type":"function","title":"Evision.VideoIORegistry.getStreamBackends/0","doc":"Returns list of available backends which works via `cv::VideoCapture(filename)`\n##### Return\n- **retval**: `[VideoCaptureAPIs]`\n\nPython prototype (for reference only):\n```python3\ngetStreamBackends() -> retval\n```","ref":"Evision.VideoIORegistry.html#getStreamBackends/0"},{"type":"function","title":"Evision.VideoIORegistry.getStreamBackends/1","doc":"","ref":"Evision.VideoIORegistry.html#getStreamBackends/1"},{"type":"function","title":"Evision.VideoIORegistry.getWriterBackendPluginVersion/1","doc":"Returns description and ABI/API version of videoio plugin's writer interface\n\n##### Positional Arguments\n- **api**: `VideoCaptureAPIs`\n\n##### Return\n- **retval**: `string`\n- **version_ABI**: `integer()`\n- **version_API**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetWriterBackendPluginVersion(api) -> retval, version_ABI, version_API\n```","ref":"Evision.VideoIORegistry.html#getWriterBackendPluginVersion/1"},{"type":"function","title":"Evision.VideoIORegistry.getWriterBackends/0","doc":"Returns list of available backends which works via `cv::VideoWriter()`\n##### Return\n- **retval**: `[VideoCaptureAPIs]`\n\nPython prototype (for reference only):\n```python3\ngetWriterBackends() -> retval\n```","ref":"Evision.VideoIORegistry.html#getWriterBackends/0"},{"type":"function","title":"Evision.VideoIORegistry.getWriterBackends/1","doc":"","ref":"Evision.VideoIORegistry.html#getWriterBackends/1"},{"type":"function","title":"Evision.VideoIORegistry.hasBackend/1","doc":"Returns true if backend is available\n\n##### Positional Arguments\n- **api**: `VideoCaptureAPIs`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nhasBackend(api) -> retval\n```","ref":"Evision.VideoIORegistry.html#hasBackend/1"},{"type":"function","title":"Evision.VideoIORegistry.isBackendBuiltIn/1","doc":"Returns true if backend is built in (false if backend is used as plugin)\n\n##### Positional Arguments\n- **api**: `VideoCaptureAPIs`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisBackendBuiltIn(api) -> retval\n```","ref":"Evision.VideoIORegistry.html#isBackendBuiltIn/1"},{"type":"type","title":"Evision.VideoIORegistry.t/0","doc":"Type that represents an `VideoIORegistry` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.VideoIORegistry.html#t:t/0"},{"type":"module","title":"Evision.VideoWriter","doc":"","ref":"Evision.VideoWriter.html"},{"type":"function","title":"Evision.VideoWriter.fourcc/1","doc":"","ref":"Evision.VideoWriter.html#fourcc/1"},{"type":"function","title":"Evision.VideoWriter.fourcc/4","doc":"Concatenates 4 chars to a fourcc code\n\n##### Positional Arguments\n- **c1**: `char`\n- **c2**: `char`\n- **c3**: `char`\n- **c4**: `char`\n\n##### Return\n- **retval**: `integer()`\n\n@return a fourcc code\nThis static method constructs the fourcc code of the codec to be used in the constructor\nVideoWriter::VideoWriter or VideoWriter::open.\n\nPython prototype (for reference only):\n```python3\nfourcc(c1, c2, c3, c4) -> retval\n```","ref":"Evision.VideoWriter.html#fourcc/4"},{"type":"function","title":"Evision.VideoWriter.get/1","doc":"","ref":"Evision.VideoWriter.html#get/1"},{"type":"function","title":"Evision.VideoWriter.get/2","doc":"Returns the specified VideoWriter property\n\n##### Positional Arguments\n- **self**: `Evision.VideoWriter.t()`\n- **propId**: `integer()`.\n\n  Property identifier from cv::VideoWriterProperties (eg. cv::VIDEOWRITER_PROP_QUALITY)\n  or one of @ref videoio_flags_others\n\n##### Return\n- **retval**: `double`\n\n@return Value for the specified property. Value 0 is returned when querying a property that is\nnot supported by the backend used by the VideoWriter instance.\n\nPython prototype (for reference only):\n```python3\nget(propId) -> retval\n```","ref":"Evision.VideoWriter.html#get/2"},{"type":"function","title":"Evision.VideoWriter.getBackendName/1","doc":"Returns used backend API name\n\n##### Positional Arguments\n- **self**: `Evision.VideoWriter.t()`\n\n##### Return\n- **retval**: `String`\n\n**Note**: Stream should be opened.\n\nPython prototype (for reference only):\n```python3\ngetBackendName() -> retval\n```","ref":"Evision.VideoWriter.html#getBackendName/1"},{"type":"function","title":"Evision.VideoWriter.isOpened/1","doc":"Returns true if video writer has been successfully initialized.\n\n##### Positional Arguments\n- **self**: `Evision.VideoWriter.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nisOpened() -> retval\n```","ref":"Evision.VideoWriter.html#isOpened/1"},{"type":"function","title":"Evision.VideoWriter.open/1","doc":"","ref":"Evision.VideoWriter.html#open/1"},{"type":"function","title":"Evision.VideoWriter.open/5","doc":"Initializes or reinitializes video writer.\n\n##### Positional Arguments\n- **self**: `Evision.VideoWriter.t()`\n- **filename**: `String`\n- **fourcc**: `integer()`\n- **fps**: `double`\n- **frameSize**: `Size`\n\n##### Keyword Arguments\n- **isColor**: `bool`.\n\n##### Return\n- **retval**: `bool`\n\nThe method opens video writer. Parameters are the same as in the constructor\nVideoWriter::VideoWriter.\n@return `true` if video writer has been successfully initialized\nThe method first calls VideoWriter::release to close the already opened file.\n\nPython prototype (for reference only):\n```python3\nopen(filename, fourcc, fps, frameSize[, isColor]) -> retval\n```","ref":"Evision.VideoWriter.html#open/5"},{"type":"function","title":"Evision.VideoWriter.open/6","doc":"#### Variant 1:\nopen\n\n##### Positional Arguments\n- **self**: `Evision.VideoWriter.t()`\n- **filename**: `String`\n- **fourcc**: `integer()`\n- **fps**: `double`\n- **frameSize**: `Size`\n- **params**: `[integer()]`\n\n##### Return\n- **retval**: `bool`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nopen(filename, fourcc, fps, frameSize, params) -> retval\n```\n#### Variant 2:\nopen\n\n##### Positional Arguments\n- **self**: `Evision.VideoWriter.t()`\n- **filename**: `String`\n- **apiPreference**: `integer()`\n- **fourcc**: `integer()`\n- **fps**: `double`\n- **frameSize**: `Size`\n\n##### Keyword Arguments\n- **isColor**: `bool`.\n\n##### Return\n- **retval**: `bool`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nopen(filename, apiPreference, fourcc, fps, frameSize[, isColor]) -> retval\n```\n#### Variant 3:\nInitializes or reinitializes video writer.\n\n##### Positional Arguments\n- **self**: `Evision.VideoWriter.t()`\n- **filename**: `String`\n- **fourcc**: `integer()`\n- **fps**: `double`\n- **frameSize**: `Size`\n\n##### Keyword Arguments\n- **isColor**: `bool`.\n\n##### Return\n- **retval**: `bool`\n\nThe method opens video writer. Parameters are the same as in the constructor\nVideoWriter::VideoWriter.\n@return `true` if video writer has been successfully initialized\nThe method first calls VideoWriter::release to close the already opened file.\n\nPython prototype (for reference only):\n```python3\nopen(filename, fourcc, fps, frameSize[, isColor]) -> retval\n```","ref":"Evision.VideoWriter.html#open/6"},{"type":"function","title":"Evision.VideoWriter.open/7","doc":"#### Variant 1:\nopen\n\n##### Positional Arguments\n- **self**: `Evision.VideoWriter.t()`\n- **filename**: `String`\n- **apiPreference**: `integer()`\n- **fourcc**: `integer()`\n- **fps**: `double`\n- **frameSize**: `Size`\n- **params**: `[integer()]`\n\n##### Return\n- **retval**: `bool`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nopen(filename, apiPreference, fourcc, fps, frameSize, params) -> retval\n```\n#### Variant 2:\nopen\n\n##### Positional Arguments\n- **self**: `Evision.VideoWriter.t()`\n- **filename**: `String`\n- **apiPreference**: `integer()`\n- **fourcc**: `integer()`\n- **fps**: `double`\n- **frameSize**: `Size`\n\n##### Keyword Arguments\n- **isColor**: `bool`.\n\n##### Return\n- **retval**: `bool`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nopen(filename, apiPreference, fourcc, fps, frameSize[, isColor]) -> retval\n```","ref":"Evision.VideoWriter.html#open/7"},{"type":"function","title":"Evision.VideoWriter.release/1","doc":"Closes the video writer.\n\n##### Positional Arguments\n- **self**: `Evision.VideoWriter.t()`\n\nThe method is automatically called by subsequent VideoWriter::open and by the VideoWriter\ndestructor.\n\nPython prototype (for reference only):\n```python3\nrelease() -> None\n```","ref":"Evision.VideoWriter.html#release/1"},{"type":"function","title":"Evision.VideoWriter.set/1","doc":"","ref":"Evision.VideoWriter.html#set/1"},{"type":"function","title":"Evision.VideoWriter.set/3","doc":"Sets a property in the VideoWriter.\n\n##### Positional Arguments\n- **self**: `Evision.VideoWriter.t()`\n- **propId**: `integer()`.\n\n  Property identifier from cv::VideoWriterProperties (eg. cv::VIDEOWRITER_PROP_QUALITY)\n  or one of @ref videoio_flags_others\n\n- **value**: `double`.\n\n  Value of the property.\n\n##### Return\n- **retval**: `bool`\n\n@return  `true` if the property is supported by the backend used by the VideoWriter instance.\n\nPython prototype (for reference only):\n```python3\nset(propId, value) -> retval\n```","ref":"Evision.VideoWriter.html#set/3"},{"type":"function","title":"Evision.VideoWriter.videoWriter/0","doc":"Default constructors\n##### Return\n- **self**: `Evision.VideoWriter.t()`\n\nThe constructors/functions initialize video writers.\n- On Linux FFMPEG is used to write videos;\n- On Windows FFMPEG or MSWF or DSHOW is used;\n- On MacOSX AVFoundation is used.\n\nPython prototype (for reference only):\n```python3\nVideoWriter() ->  \n```","ref":"Evision.VideoWriter.html#videoWriter/0"},{"type":"function","title":"Evision.VideoWriter.videoWriter/1","doc":"","ref":"Evision.VideoWriter.html#videoWriter/1"},{"type":"function","title":"Evision.VideoWriter.videoWriter/4","doc":"VideoWriter\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  Name of the output video file.\n\n- **fourcc**: `integer()`.\n\n  4-character code of codec used to compress the frames. For example,\n  VideoWriter::fourcc('P','I','M','1') is a MPEG-1 codec, VideoWriter::fourcc('M','J','P','G')\n  is a motion-jpeg codec etc. List of codes can be obtained at\n  [MSDN](https://docs.microsoft.com/en-us/windows/win32/medfound/video-fourccs) page\n  or with this [page](https://fourcc.org/codecs.php)\n  of the fourcc site for a more complete list). FFMPEG backend with MP4 container natively uses\n  other values as fourcc code: see [ObjectType](http://mp4ra.org/#/codecs),\n  so you may receive a warning message from OpenCV about fourcc code conversion.\n\n- **fps**: `double`.\n\n  Framerate of the created video stream.\n\n- **frameSize**: `Size`.\n\n  Size of the video frames.\n\n##### Keyword Arguments\n- **isColor**: `bool`.\n\n  If it is not zero, the encoder will expect and encode color frames, otherwise it\n  will work with grayscale frames.\n\n##### Return\n- **self**: `Evision.VideoWriter.t()`\n\nHas overloading in C++\n\n@b Tips:\n- With some backends `fourcc=-1` pops up the codec selection dialog from the system.\n- To save image sequence use a proper filename (eg. `img_%02d.jpg`) and `fourcc=0`\n  OR `fps=0`. Use uncompressed image format (eg. `img_%02d.BMP`) to save raw frames.\n\n- Most codecs are lossy. If you want lossless video file you need to use a lossless codecs\n  (eg. FFMPEG FFV1, Huffman HFYU, Lagarith LAGS, etc...)\n\n- If FFMPEG is enabled, using `codec=0; fps=0;` you can create an uncompressed (raw) video file.\n- If FFMPEG is used, we allow frames of odd width or height, but in this case we truncate\n  the rightmost column/the bottom row. Probably, this should be handled more elegantly,\n  but some internal functions inside FFMPEG swscale require even width/height.\n\nPython prototype (for reference only):\n```python3\nVideoWriter(filename, fourcc, fps, frameSize[, isColor]) ->  \n```","ref":"Evision.VideoWriter.html#videoWriter/4"},{"type":"function","title":"Evision.VideoWriter.videoWriter/5","doc":"#### Variant 1:\nVideoWriter\n\n##### Positional Arguments\n- **filename**: `String`\n- **fourcc**: `integer()`\n- **fps**: `double`\n- **frameSize**: `Size`\n- **params**: `[integer()]`\n\n##### Return\n- **self**: `Evision.VideoWriter.t()`\n\nHas overloading in C++\n\n The `params` parameter allows to specify extra encoder parameters encoded as pairs (paramId_1, paramValue_1, paramId_2, paramValue_2, ... .)\n see cv::VideoWriterProperties\n\nPython prototype (for reference only):\n```python3\nVideoWriter(filename, fourcc, fps, frameSize, params) ->  \n```\n#### Variant 2:\nVideoWriter\n\n##### Positional Arguments\n- **filename**: `String`\n- **apiPreference**: `integer()`\n- **fourcc**: `integer()`\n- **fps**: `double`\n- **frameSize**: `Size`\n\n##### Keyword Arguments\n- **isColor**: `bool`.\n\n##### Return\n- **self**: `Evision.VideoWriter.t()`\n\nHas overloading in C++\n\nThe `apiPreference` parameter allows to specify API backends to use. Can be used to enforce a specific reader implementation\nif multiple are available: e.g. cv::CAP_FFMPEG or cv::CAP_GSTREAMER.\n\nPython prototype (for reference only):\n```python3\nVideoWriter(filename, apiPreference, fourcc, fps, frameSize[, isColor]) ->  \n```\n#### Variant 3:\nVideoWriter\n\n##### Positional Arguments\n- **filename**: `String`.\n\n  Name of the output video file.\n\n- **fourcc**: `integer()`.\n\n  4-character code of codec used to compress the frames. For example,\n  VideoWriter::fourcc('P','I','M','1') is a MPEG-1 codec, VideoWriter::fourcc('M','J','P','G')\n  is a motion-jpeg codec etc. List of codes can be obtained at\n  [MSDN](https://docs.microsoft.com/en-us/windows/win32/medfound/video-fourccs) page\n  or with this [page](https://fourcc.org/codecs.php)\n  of the fourcc site for a more complete list). FFMPEG backend with MP4 container natively uses\n  other values as fourcc code: see [ObjectType](http://mp4ra.org/#/codecs),\n  so you may receive a warning message from OpenCV about fourcc code conversion.\n\n- **fps**: `double`.\n\n  Framerate of the created video stream.\n\n- **frameSize**: `Size`.\n\n  Size of the video frames.\n\n##### Keyword Arguments\n- **isColor**: `bool`.\n\n  If it is not zero, the encoder will expect and encode color frames, otherwise it\n  will work with grayscale frames.\n\n##### Return\n- **self**: `Evision.VideoWriter.t()`\n\nHas overloading in C++\n\n@b Tips:\n- With some backends `fourcc=-1` pops up the codec selection dialog from the system.\n- To save image sequence use a proper filename (eg. `img_%02d.jpg`) and `fourcc=0`\n  OR `fps=0`. Use uncompressed image format (eg. `img_%02d.BMP`) to save raw frames.\n\n- Most codecs are lossy. If you want lossless video file you need to use a lossless codecs\n  (eg. FFMPEG FFV1, Huffman HFYU, Lagarith LAGS, etc...)\n\n- If FFMPEG is enabled, using `codec=0; fps=0;` you can create an uncompressed (raw) video file.\n- If FFMPEG is used, we allow frames of odd width or height, but in this case we truncate\n  the rightmost column/the bottom row. Probably, this should be handled more elegantly,\n  but some internal functions inside FFMPEG swscale require even width/height.\n\nPython prototype (for reference only):\n```python3\nVideoWriter(filename, fourcc, fps, frameSize[, isColor]) ->  \n```","ref":"Evision.VideoWriter.html#videoWriter/5"},{"type":"function","title":"Evision.VideoWriter.videoWriter/6","doc":"#### Variant 1:\nVideoWriter\n\n##### Positional Arguments\n- **filename**: `String`\n- **apiPreference**: `integer()`\n- **fourcc**: `integer()`\n- **fps**: `double`\n- **frameSize**: `Size`\n- **params**: `[integer()]`\n\n##### Return\n- **self**: `Evision.VideoWriter.t()`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nVideoWriter(filename, apiPreference, fourcc, fps, frameSize, params) ->  \n```\n#### Variant 2:\nVideoWriter\n\n##### Positional Arguments\n- **filename**: `String`\n- **apiPreference**: `integer()`\n- **fourcc**: `integer()`\n- **fps**: `double`\n- **frameSize**: `Size`\n\n##### Keyword Arguments\n- **isColor**: `bool`.\n\n##### Return\n- **self**: `Evision.VideoWriter.t()`\n\nHas overloading in C++\n\nThe `apiPreference` parameter allows to specify API backends to use. Can be used to enforce a specific reader implementation\nif multiple are available: e.g. cv::CAP_FFMPEG or cv::CAP_GSTREAMER.\n\nPython prototype (for reference only):\n```python3\nVideoWriter(filename, apiPreference, fourcc, fps, frameSize[, isColor]) ->  \n```","ref":"Evision.VideoWriter.html#videoWriter/6"},{"type":"function","title":"Evision.VideoWriter.write/1","doc":"","ref":"Evision.VideoWriter.html#write/1"},{"type":"function","title":"Evision.VideoWriter.write/2","doc":"Writes the next video frame\n\n##### Positional Arguments\n- **self**: `Evision.VideoWriter.t()`\n- **image**: `Evision.Mat`.\n\n  The written frame. In general, color images are expected in BGR format.\n\nThe function/method writes the specified image to video file. It must have the same size as has\nbeen specified when opening the video writer.\n\nPython prototype (for reference only):\n```python3\nwrite(image) -> None\n```","ref":"Evision.VideoWriter.html#write/2"},{"type":"type","title":"Evision.VideoWriter.t/0","doc":"Type that represents an `VideoWriter` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.VideoWriter.html#t:t/0"},{"type":"module","title":"Evision.VideoWriterProperties","doc":"","ref":"Evision.VideoWriterProperties.html"},{"type":"function","title":"Evision.VideoWriterProperties.cv_VIDEOWRITER_PROP_DEPTH/0","doc":"","ref":"Evision.VideoWriterProperties.html#cv_VIDEOWRITER_PROP_DEPTH/0"},{"type":"function","title":"Evision.VideoWriterProperties.cv_VIDEOWRITER_PROP_FRAMEBYTES/0","doc":"","ref":"Evision.VideoWriterProperties.html#cv_VIDEOWRITER_PROP_FRAMEBYTES/0"},{"type":"function","title":"Evision.VideoWriterProperties.cv_VIDEOWRITER_PROP_HW_ACCELERATION/0","doc":"","ref":"Evision.VideoWriterProperties.html#cv_VIDEOWRITER_PROP_HW_ACCELERATION/0"},{"type":"function","title":"Evision.VideoWriterProperties.cv_VIDEOWRITER_PROP_HW_ACCELERATION_USE_OPENCL/0","doc":"","ref":"Evision.VideoWriterProperties.html#cv_VIDEOWRITER_PROP_HW_ACCELERATION_USE_OPENCL/0"},{"type":"function","title":"Evision.VideoWriterProperties.cv_VIDEOWRITER_PROP_HW_DEVICE/0","doc":"","ref":"Evision.VideoWriterProperties.html#cv_VIDEOWRITER_PROP_HW_DEVICE/0"},{"type":"function","title":"Evision.VideoWriterProperties.cv_VIDEOWRITER_PROP_IS_COLOR/0","doc":"","ref":"Evision.VideoWriterProperties.html#cv_VIDEOWRITER_PROP_IS_COLOR/0"},{"type":"function","title":"Evision.VideoWriterProperties.cv_VIDEOWRITER_PROP_KEY_FLAG/0","doc":"","ref":"Evision.VideoWriterProperties.html#cv_VIDEOWRITER_PROP_KEY_FLAG/0"},{"type":"function","title":"Evision.VideoWriterProperties.cv_VIDEOWRITER_PROP_KEY_INTERVAL/0","doc":"","ref":"Evision.VideoWriterProperties.html#cv_VIDEOWRITER_PROP_KEY_INTERVAL/0"},{"type":"function","title":"Evision.VideoWriterProperties.cv_VIDEOWRITER_PROP_NSTRIPES/0","doc":"","ref":"Evision.VideoWriterProperties.html#cv_VIDEOWRITER_PROP_NSTRIPES/0"},{"type":"function","title":"Evision.VideoWriterProperties.cv_VIDEOWRITER_PROP_QUALITY/0","doc":"","ref":"Evision.VideoWriterProperties.html#cv_VIDEOWRITER_PROP_QUALITY/0"},{"type":"function","title":"Evision.VideoWriterProperties.cv_VIDEOWRITER_PROP_RAW_VIDEO/0","doc":"","ref":"Evision.VideoWriterProperties.html#cv_VIDEOWRITER_PROP_RAW_VIDEO/0"},{"type":"type","title":"Evision.VideoWriterProperties.enum/0","doc":"","ref":"Evision.VideoWriterProperties.html#t:enum/0"},{"type":"module","title":"Evision.WarpPolarMode","doc":"","ref":"Evision.WarpPolarMode.html"},{"type":"function","title":"Evision.WarpPolarMode.cv_WARP_POLAR_LINEAR/0","doc":"","ref":"Evision.WarpPolarMode.html#cv_WARP_POLAR_LINEAR/0"},{"type":"function","title":"Evision.WarpPolarMode.cv_WARP_POLAR_LOG/0","doc":"","ref":"Evision.WarpPolarMode.html#cv_WARP_POLAR_LOG/0"},{"type":"type","title":"Evision.WarpPolarMode.enum/0","doc":"","ref":"Evision.WarpPolarMode.html#t:enum/0"},{"type":"module","title":"Evision.WarperCreator","doc":"","ref":"Evision.WarperCreator.html"},{"type":"type","title":"Evision.WarperCreator.t/0","doc":"Type that represents an `WarperCreator` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.WarperCreator.html#t:t/0"},{"type":"module","title":"Evision.WeChatQRCode","doc":"","ref":"Evision.WeChatQRCode.html"},{"type":"type","title":"Evision.WeChatQRCode.t/0","doc":"Type that represents an `WeChatQRCode` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.WeChatQRCode.html#t:t/0"},{"type":"module","title":"Evision.WeChatQRCode.WeChatQRCode","doc":"","ref":"Evision.WeChatQRCode.WeChatQRCode.html"},{"type":"function","title":"Evision.WeChatQRCode.WeChatQRCode.detectAndDecode/1","doc":"","ref":"Evision.WeChatQRCode.WeChatQRCode.html#detectAndDecode/1"},{"type":"function","title":"Evision.WeChatQRCode.WeChatQRCode.detectAndDecode/2","doc":"Both detects and decodes QR code.\nTo simplify the usage, there is a only API: detectAndDecode\n\n##### Positional Arguments\n- **self**: `Evision.WeChatQRCode.WeChatQRCode.t()`\n- **img**: `Evision.Mat`.\n\n  supports grayscale or color (BGR) image.\n\n##### Return\n- **retval**: `[string]`\n- **points**: `[Evision.Mat]`.\n\n  optional output array of vertices of the found QR code quadrangle. Will be\n  empty if not found.\n\n@return list of decoded string.\n\nPython prototype (for reference only):\n```python3\ndetectAndDecode(img[, points]) -> retval, points\n```","ref":"Evision.WeChatQRCode.WeChatQRCode.html#detectAndDecode/2"},{"type":"function","title":"Evision.WeChatQRCode.WeChatQRCode.detectAndDecode/3","doc":"Both detects and decodes QR code.\nTo simplify the usage, there is a only API: detectAndDecode\n\n##### Positional Arguments\n- **self**: `Evision.WeChatQRCode.WeChatQRCode.t()`\n- **img**: `Evision.Mat`.\n\n  supports grayscale or color (BGR) image.\n\n##### Return\n- **retval**: `[string]`\n- **points**: `[Evision.Mat]`.\n\n  optional output array of vertices of the found QR code quadrangle. Will be\n  empty if not found.\n\n@return list of decoded string.\n\nPython prototype (for reference only):\n```python3\ndetectAndDecode(img[, points]) -> retval, points\n```","ref":"Evision.WeChatQRCode.WeChatQRCode.html#detectAndDecode/3"},{"type":"function","title":"Evision.WeChatQRCode.WeChatQRCode.getScaleFactor/1","doc":"getScaleFactor\n\n##### Positional Arguments\n- **self**: `Evision.WeChatQRCode.WeChatQRCode.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetScaleFactor() -> retval\n```","ref":"Evision.WeChatQRCode.WeChatQRCode.html#getScaleFactor/1"},{"type":"function","title":"Evision.WeChatQRCode.WeChatQRCode.setScaleFactor/1","doc":"","ref":"Evision.WeChatQRCode.WeChatQRCode.html#setScaleFactor/1"},{"type":"function","title":"Evision.WeChatQRCode.WeChatQRCode.setScaleFactor/2","doc":"set scale factor\nQR code detector use neural network to detect QR.\nBefore running the neural network, the input image is pre-processed by scaling.\nBy default, the input image is scaled to an image with an area of 160000 pixels.\nThe scale factor allows to use custom scale the input image:\nwidth = scaleFactor*width\nheight = scaleFactor*width\n\n##### Positional Arguments\n- **self**: `Evision.WeChatQRCode.WeChatQRCode.t()`\n- **scalingFactor**: `float`\n\n scaleFactor valuse must be > 0 and <= 1, otherwise the scaleFactor value is set to -1\n and use default scaled to an image with an area of 160000 pixels.\n\nPython prototype (for reference only):\n```python3\nsetScaleFactor(_scalingFactor) -> None\n```","ref":"Evision.WeChatQRCode.WeChatQRCode.html#setScaleFactor/2"},{"type":"function","title":"Evision.WeChatQRCode.WeChatQRCode.weChatQRCode/0","doc":"Initialize the WeChatQRCode.\nIt includes two models, which are packaged with caffe format.\nTherefore, there are prototxt and caffe models (In total, four paramenters).\n\n##### Keyword Arguments\n- **detector_prototxt_path**: `string`.\n\n  prototxt file path for the detector\n\n- **detector_caffe_model_path**: `string`.\n\n  caffe model file path for the detector\n\n- **super_resolution_prototxt_path**: `string`.\n\n  prototxt file path for the super resolution model\n\n- **super_resolution_caffe_model_path**: `string`.\n\n  caffe file path for the super resolution model\n\n##### Return\n- **self**: `Evision.WeChatQRCode.WeChatQRCode.t()`\n\nPython prototype (for reference only):\n```python3\nWeChatQRCode([, detector_prototxt_path[, detector_caffe_model_path[, super_resolution_prototxt_path[, super_resolution_caffe_model_path]]]]) ->  \n```","ref":"Evision.WeChatQRCode.WeChatQRCode.html#weChatQRCode/0"},{"type":"function","title":"Evision.WeChatQRCode.WeChatQRCode.weChatQRCode/1","doc":"Initialize the WeChatQRCode.\nIt includes two models, which are packaged with caffe format.\nTherefore, there are prototxt and caffe models (In total, four paramenters).\n\n##### Keyword Arguments\n- **detector_prototxt_path**: `string`.\n\n  prototxt file path for the detector\n\n- **detector_caffe_model_path**: `string`.\n\n  caffe model file path for the detector\n\n- **super_resolution_prototxt_path**: `string`.\n\n  prototxt file path for the super resolution model\n\n- **super_resolution_caffe_model_path**: `string`.\n\n  caffe file path for the super resolution model\n\n##### Return\n- **self**: `Evision.WeChatQRCode.WeChatQRCode.t()`\n\nPython prototype (for reference only):\n```python3\nWeChatQRCode([, detector_prototxt_path[, detector_caffe_model_path[, super_resolution_prototxt_path[, super_resolution_caffe_model_path]]]]) ->  \n```","ref":"Evision.WeChatQRCode.WeChatQRCode.html#weChatQRCode/1"},{"type":"type","title":"Evision.WeChatQRCode.WeChatQRCode.t/0","doc":"Type that represents an `WeChatQRCode.WeChatQRCode` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.WeChatQRCode.WeChatQRCode.html#t:t/0"},{"type":"module","title":"Evision.WindowFlags","doc":"","ref":"Evision.WindowFlags.html"},{"type":"function","title":"Evision.WindowFlags.cv_WINDOW_AUTOSIZE/0","doc":"","ref":"Evision.WindowFlags.html#cv_WINDOW_AUTOSIZE/0"},{"type":"function","title":"Evision.WindowFlags.cv_WINDOW_FREERATIO/0","doc":"","ref":"Evision.WindowFlags.html#cv_WINDOW_FREERATIO/0"},{"type":"function","title":"Evision.WindowFlags.cv_WINDOW_FULLSCREEN/0","doc":"","ref":"Evision.WindowFlags.html#cv_WINDOW_FULLSCREEN/0"},{"type":"function","title":"Evision.WindowFlags.cv_WINDOW_GUI_EXPANDED/0","doc":"","ref":"Evision.WindowFlags.html#cv_WINDOW_GUI_EXPANDED/0"},{"type":"function","title":"Evision.WindowFlags.cv_WINDOW_GUI_NORMAL/0","doc":"","ref":"Evision.WindowFlags.html#cv_WINDOW_GUI_NORMAL/0"},{"type":"function","title":"Evision.WindowFlags.cv_WINDOW_KEEPRATIO/0","doc":"","ref":"Evision.WindowFlags.html#cv_WINDOW_KEEPRATIO/0"},{"type":"function","title":"Evision.WindowFlags.cv_WINDOW_NORMAL/0","doc":"","ref":"Evision.WindowFlags.html#cv_WINDOW_NORMAL/0"},{"type":"function","title":"Evision.WindowFlags.cv_WINDOW_OPENGL/0","doc":"","ref":"Evision.WindowFlags.html#cv_WINDOW_OPENGL/0"},{"type":"type","title":"Evision.WindowFlags.enum/0","doc":"","ref":"Evision.WindowFlags.html#t:enum/0"},{"type":"module","title":"Evision.WindowPropertyFlags","doc":"","ref":"Evision.WindowPropertyFlags.html"},{"type":"function","title":"Evision.WindowPropertyFlags.cv_WND_PROP_ASPECT_RATIO/0","doc":"","ref":"Evision.WindowPropertyFlags.html#cv_WND_PROP_ASPECT_RATIO/0"},{"type":"function","title":"Evision.WindowPropertyFlags.cv_WND_PROP_AUTOSIZE/0","doc":"","ref":"Evision.WindowPropertyFlags.html#cv_WND_PROP_AUTOSIZE/0"},{"type":"function","title":"Evision.WindowPropertyFlags.cv_WND_PROP_FULLSCREEN/0","doc":"","ref":"Evision.WindowPropertyFlags.html#cv_WND_PROP_FULLSCREEN/0"},{"type":"function","title":"Evision.WindowPropertyFlags.cv_WND_PROP_OPENGL/0","doc":"","ref":"Evision.WindowPropertyFlags.html#cv_WND_PROP_OPENGL/0"},{"type":"function","title":"Evision.WindowPropertyFlags.cv_WND_PROP_TOPMOST/0","doc":"","ref":"Evision.WindowPropertyFlags.html#cv_WND_PROP_TOPMOST/0"},{"type":"function","title":"Evision.WindowPropertyFlags.cv_WND_PROP_VISIBLE/0","doc":"","ref":"Evision.WindowPropertyFlags.html#cv_WND_PROP_VISIBLE/0"},{"type":"function","title":"Evision.WindowPropertyFlags.cv_WND_PROP_VSYNC/0","doc":"","ref":"Evision.WindowPropertyFlags.html#cv_WND_PROP_VSYNC/0"},{"type":"type","title":"Evision.WindowPropertyFlags.enum/0","doc":"","ref":"Evision.WindowPropertyFlags.html#t:enum/0"},{"type":"module","title":"Evision.Wx","doc":"Interact with wxWidgets","ref":"Evision.Wx.html"},{"type":"function","title":"Evision.Wx.destroyAllWindows/0","doc":"","ref":"Evision.Wx.html#destroyAllWindows/0"},{"type":"function","title":"Evision.Wx.destroyWindow/1","doc":"","ref":"Evision.Wx.html#destroyWindow/1"},{"type":"function","title":"Evision.Wx.imshow/2","doc":"","ref":"Evision.Wx.html#imshow/2"},{"type":"module","title":"Evision.XFeatures2D","doc":"","ref":"Evision.XFeatures2D.html"},{"type":"function","title":"Evision.XFeatures2D.matchGMS/1","doc":"","ref":"Evision.XFeatures2D.html#matchGMS/1"},{"type":"function","title":"Evision.XFeatures2D.matchGMS/5","doc":"GMS (Grid-based Motion Statistics) feature matching strategy described in @cite Bian2017gms .\n\n##### Positional Arguments\n- **size1**: `Size`.\n\n  Input size of image1.\n\n- **size2**: `Size`.\n\n  Input size of image2.\n\n- **keypoints1**: `[Evision.KeyPoint]`.\n\n  Input keypoints of image1.\n\n- **keypoints2**: `[Evision.KeyPoint]`.\n\n  Input keypoints of image2.\n\n- **matches1to2**: `[Evision.DMatch]`.\n\n  Input 1-nearest neighbor matches.\n\n##### Keyword Arguments\n- **withRotation**: `bool`.\n\n  Take rotation transformation into account.\n\n- **withScale**: `bool`.\n\n  Take scale transformation into account.\n\n- **thresholdFactor**: `double`.\n\n  The higher, the less matches.\n\n##### Return\n- **matchesGMS**: `[Evision.DMatch]`.\n\n  Matches returned by the GMS matching strategy.\n\n**Note**: \nSince GMS works well when the number of features is large, we recommend to use the ORB feature and set FastThreshold to 0 to get as many as possible features quickly.\nIf matching results are not satisfying, please add more features. (We use 10000 for images with 640 X 480).\nIf your images have big rotation and scale changes, please set withRotation or withScale to true.\n\nPython prototype (for reference only):\n```python3\nmatchGMS(size1, size2, keypoints1, keypoints2, matches1to2[, withRotation[, withScale[, thresholdFactor]]]) -> matchesGMS\n```","ref":"Evision.XFeatures2D.html#matchGMS/5"},{"type":"function","title":"Evision.XFeatures2D.matchGMS/6","doc":"GMS (Grid-based Motion Statistics) feature matching strategy described in @cite Bian2017gms .\n\n##### Positional Arguments\n- **size1**: `Size`.\n\n  Input size of image1.\n\n- **size2**: `Size`.\n\n  Input size of image2.\n\n- **keypoints1**: `[Evision.KeyPoint]`.\n\n  Input keypoints of image1.\n\n- **keypoints2**: `[Evision.KeyPoint]`.\n\n  Input keypoints of image2.\n\n- **matches1to2**: `[Evision.DMatch]`.\n\n  Input 1-nearest neighbor matches.\n\n##### Keyword Arguments\n- **withRotation**: `bool`.\n\n  Take rotation transformation into account.\n\n- **withScale**: `bool`.\n\n  Take scale transformation into account.\n\n- **thresholdFactor**: `double`.\n\n  The higher, the less matches.\n\n##### Return\n- **matchesGMS**: `[Evision.DMatch]`.\n\n  Matches returned by the GMS matching strategy.\n\n**Note**: \nSince GMS works well when the number of features is large, we recommend to use the ORB feature and set FastThreshold to 0 to get as many as possible features quickly.\nIf matching results are not satisfying, please add more features. (We use 10000 for images with 640 X 480).\nIf your images have big rotation and scale changes, please set withRotation or withScale to true.\n\nPython prototype (for reference only):\n```python3\nmatchGMS(size1, size2, keypoints1, keypoints2, matches1to2[, withRotation[, withScale[, thresholdFactor]]]) -> matchesGMS\n```","ref":"Evision.XFeatures2D.html#matchGMS/6"},{"type":"function","title":"Evision.XFeatures2D.matchLOGOS/1","doc":"","ref":"Evision.XFeatures2D.html#matchLOGOS/1"},{"type":"function","title":"Evision.XFeatures2D.matchLOGOS/4","doc":"LOGOS (Local geometric support for high-outlier spatial verification) feature matching strategy described in @cite Lowry2018LOGOSLG .\n\n##### Positional Arguments\n- **keypoints1**: `[Evision.KeyPoint]`.\n\n  Input keypoints of image1.\n\n- **keypoints2**: `[Evision.KeyPoint]`.\n\n  Input keypoints of image2.\n\n- **nn1**: `[integer()]`.\n\n  Index to the closest BoW centroid for each descriptors of image1.\n\n- **nn2**: `[integer()]`.\n\n  Index to the closest BoW centroid for each descriptors of image2.\n\n##### Return\n- **matches1to2**: `[Evision.DMatch]`.\n\n  Matches returned by the LOGOS matching strategy.\n\n**Note**: \nThis matching strategy is suitable for features matching against large scale database.\nFirst step consists in constructing the bag-of-words (BoW) from a representative image database.\nImage descriptors are then represented by their closest codevector (nearest BoW centroid).\n\nPython prototype (for reference only):\n```python3\nmatchLOGOS(keypoints1, keypoints2, nn1, nn2) -> matches1to2\n```","ref":"Evision.XFeatures2D.html#matchLOGOS/4"},{"type":"type","title":"Evision.XFeatures2D.t/0","doc":"Type that represents an `XFeatures2D` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XFeatures2D.html#t:t/0"},{"type":"module","title":"Evision.XFeatures2D.AffineFeature2D","doc":"","ref":"Evision.XFeatures2D.AffineFeature2D.html"},{"type":"function","title":"Evision.XFeatures2D.AffineFeature2D.compute/1","doc":"","ref":"Evision.XFeatures2D.AffineFeature2D.html#compute/1"},{"type":"function","title":"Evision.XFeatures2D.AffineFeature2D.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.AffineFeature2D.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.AffineFeature2D.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.AffineFeature2D.html#compute/3"},{"type":"function","title":"Evision.XFeatures2D.AffineFeature2D.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.AffineFeature2D.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.AffineFeature2D.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.AffineFeature2D.html#compute/4"},{"type":"function","title":"Evision.XFeatures2D.AffineFeature2D.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.AffineFeature2D.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.XFeatures2D.AffineFeature2D.html#defaultNorm/1"},{"type":"function","title":"Evision.XFeatures2D.AffineFeature2D.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.AffineFeature2D.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.XFeatures2D.AffineFeature2D.html#descriptorSize/1"},{"type":"function","title":"Evision.XFeatures2D.AffineFeature2D.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.AffineFeature2D.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.XFeatures2D.AffineFeature2D.html#descriptorType/1"},{"type":"function","title":"Evision.XFeatures2D.AffineFeature2D.detect/1","doc":"","ref":"Evision.XFeatures2D.AffineFeature2D.html#detect/1"},{"type":"function","title":"Evision.XFeatures2D.AffineFeature2D.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.AffineFeature2D.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.AffineFeature2D.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.AffineFeature2D.html#detect/2"},{"type":"function","title":"Evision.XFeatures2D.AffineFeature2D.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.AffineFeature2D.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.AffineFeature2D.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.AffineFeature2D.html#detect/3"},{"type":"function","title":"Evision.XFeatures2D.AffineFeature2D.detectAndCompute/1","doc":"","ref":"Evision.XFeatures2D.AffineFeature2D.html#detectAndCompute/1"},{"type":"function","title":"Evision.XFeatures2D.AffineFeature2D.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.AffineFeature2D.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.AffineFeature2D.html#detectAndCompute/3"},{"type":"function","title":"Evision.XFeatures2D.AffineFeature2D.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.AffineFeature2D.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.AffineFeature2D.html#detectAndCompute/4"},{"type":"function","title":"Evision.XFeatures2D.AffineFeature2D.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.AffineFeature2D.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XFeatures2D.AffineFeature2D.html#empty/1"},{"type":"function","title":"Evision.XFeatures2D.AffineFeature2D.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.AffineFeature2D.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XFeatures2D.AffineFeature2D.html#getDefaultName/1"},{"type":"function","title":"Evision.XFeatures2D.AffineFeature2D.read/1","doc":"","ref":"Evision.XFeatures2D.AffineFeature2D.html#read/1"},{"type":"function","title":"Evision.XFeatures2D.AffineFeature2D.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.AffineFeature2D.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.AffineFeature2D.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.XFeatures2D.AffineFeature2D.html#read/2"},{"type":"function","title":"Evision.XFeatures2D.AffineFeature2D.write/1","doc":"","ref":"Evision.XFeatures2D.AffineFeature2D.html#write/1"},{"type":"function","title":"Evision.XFeatures2D.AffineFeature2D.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.AffineFeature2D.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.XFeatures2D.AffineFeature2D.html#write/2"},{"type":"function","title":"Evision.XFeatures2D.AffineFeature2D.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.AffineFeature2D.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XFeatures2D.AffineFeature2D.html#write/3"},{"type":"type","title":"Evision.XFeatures2D.AffineFeature2D.t/0","doc":"Type that represents an `XFeatures2D.AffineFeature2D` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XFeatures2D.AffineFeature2D.html#t:t/0"},{"type":"module","title":"Evision.XFeatures2D.BEBLID","doc":"","ref":"Evision.XFeatures2D.BEBLID.html"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.compute/1","doc":"","ref":"Evision.XFeatures2D.BEBLID.html#compute/1"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BEBLID.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BEBLID.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.BEBLID.html#compute/3"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BEBLID.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BEBLID.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.BEBLID.html#compute/4"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.create/1","doc":"Creates the BEBLID descriptor.\n\n##### Positional Arguments\n- **scale_factor**: `float`.\n\n  Adjust the sampling window around detected keypoints:\n  -   1.00f   should be the scale for ORB keypoints\n  -   6.75f   should be the scale for SIFT detected keypoints\n  -   6.25f   is default and fits for KAZE, SURF detected keypoints\n  -   5.00f   should be the scale for AKAZE, MSD, AGAST, FAST, BRISK keypoints\n\n##### Keyword Arguments\n- **n_bits**: `integer()`.\n\n  Determine the number of bits in the descriptor. Should be either\n  BEBLID::SIZE_512_BITS or BEBLID::SIZE_256_BITS.\n\n##### Return\n- **retval**: `BEBLID`\n\nPython prototype (for reference only):\n```python3\ncreate(scale_factor[, n_bits]) -> retval\n```","ref":"Evision.XFeatures2D.BEBLID.html#create/1"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.create/2","doc":"Creates the BEBLID descriptor.\n\n##### Positional Arguments\n- **scale_factor**: `float`.\n\n  Adjust the sampling window around detected keypoints:\n  -   1.00f   should be the scale for ORB keypoints\n  -   6.75f   should be the scale for SIFT detected keypoints\n  -   6.25f   is default and fits for KAZE, SURF detected keypoints\n  -   5.00f   should be the scale for AKAZE, MSD, AGAST, FAST, BRISK keypoints\n\n##### Keyword Arguments\n- **n_bits**: `integer()`.\n\n  Determine the number of bits in the descriptor. Should be either\n  BEBLID::SIZE_512_BITS or BEBLID::SIZE_256_BITS.\n\n##### Return\n- **retval**: `BEBLID`\n\nPython prototype (for reference only):\n```python3\ncreate(scale_factor[, n_bits]) -> retval\n```","ref":"Evision.XFeatures2D.BEBLID.html#create/2"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BEBLID.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.XFeatures2D.BEBLID.html#defaultNorm/1"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BEBLID.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.XFeatures2D.BEBLID.html#descriptorSize/1"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BEBLID.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.XFeatures2D.BEBLID.html#descriptorType/1"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.detect/1","doc":"","ref":"Evision.XFeatures2D.BEBLID.html#detect/1"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BEBLID.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BEBLID.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.BEBLID.html#detect/2"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BEBLID.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BEBLID.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.BEBLID.html#detect/3"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.detectAndCompute/1","doc":"","ref":"Evision.XFeatures2D.BEBLID.html#detectAndCompute/1"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BEBLID.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.BEBLID.html#detectAndCompute/3"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BEBLID.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.BEBLID.html#detectAndCompute/4"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BEBLID.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XFeatures2D.BEBLID.html#empty/1"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BEBLID.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XFeatures2D.BEBLID.html#getDefaultName/1"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.getScaleFactor/1","doc":"getScaleFactor\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BEBLID.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetScaleFactor() -> retval\n```","ref":"Evision.XFeatures2D.BEBLID.html#getScaleFactor/1"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.read/1","doc":"","ref":"Evision.XFeatures2D.BEBLID.html#read/1"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BEBLID.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BEBLID.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.XFeatures2D.BEBLID.html#read/2"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.setScaleFactor/1","doc":"","ref":"Evision.XFeatures2D.BEBLID.html#setScaleFactor/1"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.setScaleFactor/2","doc":"setScaleFactor\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BEBLID.t()`\n- **scale_factor**: `float`\n\nPython prototype (for reference only):\n```python3\nsetScaleFactor(scale_factor) -> None\n```","ref":"Evision.XFeatures2D.BEBLID.html#setScaleFactor/2"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.write/1","doc":"","ref":"Evision.XFeatures2D.BEBLID.html#write/1"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BEBLID.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.XFeatures2D.BEBLID.html#write/2"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BEBLID.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XFeatures2D.BEBLID.html#write/3"},{"type":"type","title":"Evision.XFeatures2D.BEBLID.t/0","doc":"Type that represents an `XFeatures2D.BEBLID` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XFeatures2D.BEBLID.html#t:t/0"},{"type":"module","title":"Evision.XFeatures2D.BEBLID.BeblidSize","doc":"","ref":"Evision.XFeatures2D.BEBLID.BeblidSize.html"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.BeblidSize.cv_SIZE_256_BITS/0","doc":"","ref":"Evision.XFeatures2D.BEBLID.BeblidSize.html#cv_SIZE_256_BITS/0"},{"type":"function","title":"Evision.XFeatures2D.BEBLID.BeblidSize.cv_SIZE_512_BITS/0","doc":"","ref":"Evision.XFeatures2D.BEBLID.BeblidSize.html#cv_SIZE_512_BITS/0"},{"type":"type","title":"Evision.XFeatures2D.BEBLID.BeblidSize.enum/0","doc":"","ref":"Evision.XFeatures2D.BEBLID.BeblidSize.html#t:enum/0"},{"type":"module","title":"Evision.XFeatures2D.BoostDesc","doc":"","ref":"Evision.XFeatures2D.BoostDesc.html"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.compute/1","doc":"","ref":"Evision.XFeatures2D.BoostDesc.html#compute/1"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BoostDesc.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BoostDesc.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.BoostDesc.html#compute/3"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BoostDesc.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BoostDesc.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.BoostDesc.html#compute/4"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.create/0","doc":"create\n##### Keyword Arguments\n- **desc**: `integer()`.\n- **use_scale_orientation**: `bool`.\n- **scale_factor**: `float`.\n\n##### Return\n- **retval**: `BoostDesc`\n\nPython prototype (for reference only):\n```python3\ncreate([, desc[, use_scale_orientation[, scale_factor]]]) -> retval\n```","ref":"Evision.XFeatures2D.BoostDesc.html#create/0"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.create/1","doc":"create\n##### Keyword Arguments\n- **desc**: `integer()`.\n- **use_scale_orientation**: `bool`.\n- **scale_factor**: `float`.\n\n##### Return\n- **retval**: `BoostDesc`\n\nPython prototype (for reference only):\n```python3\ncreate([, desc[, use_scale_orientation[, scale_factor]]]) -> retval\n```","ref":"Evision.XFeatures2D.BoostDesc.html#create/1"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BoostDesc.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.XFeatures2D.BoostDesc.html#defaultNorm/1"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BoostDesc.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.XFeatures2D.BoostDesc.html#descriptorSize/1"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BoostDesc.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.XFeatures2D.BoostDesc.html#descriptorType/1"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.detect/1","doc":"","ref":"Evision.XFeatures2D.BoostDesc.html#detect/1"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BoostDesc.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BoostDesc.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.BoostDesc.html#detect/2"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BoostDesc.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BoostDesc.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.BoostDesc.html#detect/3"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.detectAndCompute/1","doc":"","ref":"Evision.XFeatures2D.BoostDesc.html#detectAndCompute/1"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BoostDesc.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.BoostDesc.html#detectAndCompute/3"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BoostDesc.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.BoostDesc.html#detectAndCompute/4"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BoostDesc.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XFeatures2D.BoostDesc.html#empty/1"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BoostDesc.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XFeatures2D.BoostDesc.html#getDefaultName/1"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.getScaleFactor/1","doc":"getScaleFactor\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BoostDesc.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetScaleFactor() -> retval\n```","ref":"Evision.XFeatures2D.BoostDesc.html#getScaleFactor/1"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.getUseScaleOrientation/1","doc":"getUseScaleOrientation\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BoostDesc.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetUseScaleOrientation() -> retval\n```","ref":"Evision.XFeatures2D.BoostDesc.html#getUseScaleOrientation/1"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.read/1","doc":"","ref":"Evision.XFeatures2D.BoostDesc.html#read/1"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BoostDesc.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BoostDesc.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.XFeatures2D.BoostDesc.html#read/2"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.setScaleFactor/1","doc":"","ref":"Evision.XFeatures2D.BoostDesc.html#setScaleFactor/1"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.setScaleFactor/2","doc":"setScaleFactor\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BoostDesc.t()`\n- **scale_factor**: `float`\n\nPython prototype (for reference only):\n```python3\nsetScaleFactor(scale_factor) -> None\n```","ref":"Evision.XFeatures2D.BoostDesc.html#setScaleFactor/2"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.setUseScaleOrientation/1","doc":"","ref":"Evision.XFeatures2D.BoostDesc.html#setUseScaleOrientation/1"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.setUseScaleOrientation/2","doc":"setUseScaleOrientation\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BoostDesc.t()`\n- **use_scale_orientation**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetUseScaleOrientation(use_scale_orientation) -> None\n```","ref":"Evision.XFeatures2D.BoostDesc.html#setUseScaleOrientation/2"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.write/1","doc":"","ref":"Evision.XFeatures2D.BoostDesc.html#write/1"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BoostDesc.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.XFeatures2D.BoostDesc.html#write/2"},{"type":"function","title":"Evision.XFeatures2D.BoostDesc.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BoostDesc.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XFeatures2D.BoostDesc.html#write/3"},{"type":"type","title":"Evision.XFeatures2D.BoostDesc.t/0","doc":"Type that represents an `XFeatures2D.BoostDesc` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XFeatures2D.BoostDesc.html#t:t/0"},{"type":"module","title":"Evision.XFeatures2D.BriefDescriptorExtractor","doc":"","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.compute/1","doc":"","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#compute/1"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BriefDescriptorExtractor.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BriefDescriptorExtractor.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#compute/3"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BriefDescriptorExtractor.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BriefDescriptorExtractor.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#compute/4"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.create/0","doc":"create\n##### Keyword Arguments\n- **bytes**: `integer()`.\n- **use_orientation**: `bool`.\n\n##### Return\n- **retval**: `BriefDescriptorExtractor`\n\nPython prototype (for reference only):\n```python3\ncreate([, bytes[, use_orientation]]) -> retval\n```","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#create/0"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.create/1","doc":"create\n##### Keyword Arguments\n- **bytes**: `integer()`.\n- **use_orientation**: `bool`.\n\n##### Return\n- **retval**: `BriefDescriptorExtractor`\n\nPython prototype (for reference only):\n```python3\ncreate([, bytes[, use_orientation]]) -> retval\n```","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#create/1"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BriefDescriptorExtractor.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#defaultNorm/1"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BriefDescriptorExtractor.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#descriptorSize/1"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BriefDescriptorExtractor.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#descriptorType/1"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.detect/1","doc":"","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#detect/1"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BriefDescriptorExtractor.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BriefDescriptorExtractor.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#detect/2"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BriefDescriptorExtractor.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BriefDescriptorExtractor.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#detect/3"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.detectAndCompute/1","doc":"","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#detectAndCompute/1"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BriefDescriptorExtractor.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#detectAndCompute/3"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BriefDescriptorExtractor.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#detectAndCompute/4"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BriefDescriptorExtractor.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#empty/1"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BriefDescriptorExtractor.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#getDefaultName/1"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.getDescriptorSize/1","doc":"getDescriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BriefDescriptorExtractor.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetDescriptorSize() -> retval\n```","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#getDescriptorSize/1"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.getUseOrientation/1","doc":"getUseOrientation\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BriefDescriptorExtractor.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetUseOrientation() -> retval\n```","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#getUseOrientation/1"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.read/1","doc":"","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#read/1"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BriefDescriptorExtractor.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BriefDescriptorExtractor.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#read/2"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.setDescriptorSize/1","doc":"","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#setDescriptorSize/1"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.setDescriptorSize/2","doc":"setDescriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BriefDescriptorExtractor.t()`\n- **bytes**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetDescriptorSize(bytes) -> None\n```","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#setDescriptorSize/2"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.setUseOrientation/1","doc":"","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#setUseOrientation/1"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.setUseOrientation/2","doc":"setUseOrientation\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BriefDescriptorExtractor.t()`\n- **use_orientation**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetUseOrientation(use_orientation) -> None\n```","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#setUseOrientation/2"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.write/1","doc":"","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#write/1"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BriefDescriptorExtractor.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#write/2"},{"type":"function","title":"Evision.XFeatures2D.BriefDescriptorExtractor.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.BriefDescriptorExtractor.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#write/3"},{"type":"type","title":"Evision.XFeatures2D.BriefDescriptorExtractor.t/0","doc":"Type that represents an `XFeatures2D.BriefDescriptorExtractor` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XFeatures2D.BriefDescriptorExtractor.html#t:t/0"},{"type":"module","title":"Evision.XFeatures2D.DAISY","doc":"","ref":"Evision.XFeatures2D.DAISY.html"},{"type":"function","title":"Evision.XFeatures2D.DAISY.compute/1","doc":"","ref":"Evision.XFeatures2D.DAISY.html#compute/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.DAISY.html#compute/3"},{"type":"function","title":"Evision.XFeatures2D.DAISY.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.DAISY.html#compute/4"},{"type":"function","title":"Evision.XFeatures2D.DAISY.create/0","doc":"create\n##### Keyword Arguments\n- **radius**: `float`.\n- **q_radius**: `integer()`.\n- **q_theta**: `integer()`.\n- **q_hist**: `integer()`.\n- **norm**: `DAISY_NormalizationType`.\n- **h**: `Evision.Mat`.\n- **interpolation**: `bool`.\n- **use_orientation**: `bool`.\n\n##### Return\n- **retval**: `DAISY`\n\nPython prototype (for reference only):\n```python3\ncreate([, radius[, q_radius[, q_theta[, q_hist[, norm[, H[, interpolation[, use_orientation]]]]]]]]) -> retval\n```","ref":"Evision.XFeatures2D.DAISY.html#create/0"},{"type":"function","title":"Evision.XFeatures2D.DAISY.create/1","doc":"create\n##### Keyword Arguments\n- **radius**: `float`.\n- **q_radius**: `integer()`.\n- **q_theta**: `integer()`.\n- **q_hist**: `integer()`.\n- **norm**: `DAISY_NormalizationType`.\n- **h**: `Evision.Mat`.\n- **interpolation**: `bool`.\n- **use_orientation**: `bool`.\n\n##### Return\n- **retval**: `DAISY`\n\nPython prototype (for reference only):\n```python3\ncreate([, radius[, q_radius[, q_theta[, q_hist[, norm[, H[, interpolation[, use_orientation]]]]]]]]) -> retval\n```","ref":"Evision.XFeatures2D.DAISY.html#create/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.XFeatures2D.DAISY.html#defaultNorm/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.XFeatures2D.DAISY.html#descriptorSize/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.XFeatures2D.DAISY.html#descriptorType/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.detect/1","doc":"","ref":"Evision.XFeatures2D.DAISY.html#detect/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.DAISY.html#detect/2"},{"type":"function","title":"Evision.XFeatures2D.DAISY.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.DAISY.html#detect/3"},{"type":"function","title":"Evision.XFeatures2D.DAISY.detectAndCompute/1","doc":"","ref":"Evision.XFeatures2D.DAISY.html#detectAndCompute/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.DAISY.html#detectAndCompute/3"},{"type":"function","title":"Evision.XFeatures2D.DAISY.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.DAISY.html#detectAndCompute/4"},{"type":"function","title":"Evision.XFeatures2D.DAISY.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XFeatures2D.DAISY.html#empty/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XFeatures2D.DAISY.html#getDefaultName/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.getH/1","doc":"getH\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetH() -> retval\n```","ref":"Evision.XFeatures2D.DAISY.html#getH/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.getInterpolation/1","doc":"getInterpolation\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetInterpolation() -> retval\n```","ref":"Evision.XFeatures2D.DAISY.html#getInterpolation/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.getNorm/1","doc":"getNorm\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNorm() -> retval\n```","ref":"Evision.XFeatures2D.DAISY.html#getNorm/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.getQHist/1","doc":"getQHist\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetQHist() -> retval\n```","ref":"Evision.XFeatures2D.DAISY.html#getQHist/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.getQRadius/1","doc":"getQRadius\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetQRadius() -> retval\n```","ref":"Evision.XFeatures2D.DAISY.html#getQRadius/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.getQTheta/1","doc":"getQTheta\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetQTheta() -> retval\n```","ref":"Evision.XFeatures2D.DAISY.html#getQTheta/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.getRadius/1","doc":"getRadius\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetRadius() -> retval\n```","ref":"Evision.XFeatures2D.DAISY.html#getRadius/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.getUseOrientation/1","doc":"getUseOrientation\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetUseOrientation() -> retval\n```","ref":"Evision.XFeatures2D.DAISY.html#getUseOrientation/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.read/1","doc":"","ref":"Evision.XFeatures2D.DAISY.html#read/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.XFeatures2D.DAISY.html#read/2"},{"type":"function","title":"Evision.XFeatures2D.DAISY.setH/1","doc":"","ref":"Evision.XFeatures2D.DAISY.html#setH/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.setH/2","doc":"setH\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n- **h**: `Evision.Mat`\n\nPython prototype (for reference only):\n```python3\nsetH(H) -> None\n```","ref":"Evision.XFeatures2D.DAISY.html#setH/2"},{"type":"function","title":"Evision.XFeatures2D.DAISY.setInterpolation/1","doc":"","ref":"Evision.XFeatures2D.DAISY.html#setInterpolation/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.setInterpolation/2","doc":"setInterpolation\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n- **interpolation**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetInterpolation(interpolation) -> None\n```","ref":"Evision.XFeatures2D.DAISY.html#setInterpolation/2"},{"type":"function","title":"Evision.XFeatures2D.DAISY.setNorm/1","doc":"","ref":"Evision.XFeatures2D.DAISY.html#setNorm/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.setNorm/2","doc":"setNorm\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n- **norm**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNorm(norm) -> None\n```","ref":"Evision.XFeatures2D.DAISY.html#setNorm/2"},{"type":"function","title":"Evision.XFeatures2D.DAISY.setQHist/1","doc":"","ref":"Evision.XFeatures2D.DAISY.html#setQHist/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.setQHist/2","doc":"setQHist\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n- **q_hist**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetQHist(q_hist) -> None\n```","ref":"Evision.XFeatures2D.DAISY.html#setQHist/2"},{"type":"function","title":"Evision.XFeatures2D.DAISY.setQRadius/1","doc":"","ref":"Evision.XFeatures2D.DAISY.html#setQRadius/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.setQRadius/2","doc":"setQRadius\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n- **q_radius**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetQRadius(q_radius) -> None\n```","ref":"Evision.XFeatures2D.DAISY.html#setQRadius/2"},{"type":"function","title":"Evision.XFeatures2D.DAISY.setQTheta/1","doc":"","ref":"Evision.XFeatures2D.DAISY.html#setQTheta/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.setQTheta/2","doc":"setQTheta\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n- **q_theta**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetQTheta(q_theta) -> None\n```","ref":"Evision.XFeatures2D.DAISY.html#setQTheta/2"},{"type":"function","title":"Evision.XFeatures2D.DAISY.setRadius/1","doc":"","ref":"Evision.XFeatures2D.DAISY.html#setRadius/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.setRadius/2","doc":"setRadius\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n- **radius**: `float`\n\nPython prototype (for reference only):\n```python3\nsetRadius(radius) -> None\n```","ref":"Evision.XFeatures2D.DAISY.html#setRadius/2"},{"type":"function","title":"Evision.XFeatures2D.DAISY.setUseOrientation/1","doc":"","ref":"Evision.XFeatures2D.DAISY.html#setUseOrientation/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.setUseOrientation/2","doc":"setUseOrientation\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n- **use_orientation**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetUseOrientation(use_orientation) -> None\n```","ref":"Evision.XFeatures2D.DAISY.html#setUseOrientation/2"},{"type":"function","title":"Evision.XFeatures2D.DAISY.write/1","doc":"","ref":"Evision.XFeatures2D.DAISY.html#write/1"},{"type":"function","title":"Evision.XFeatures2D.DAISY.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.XFeatures2D.DAISY.html#write/2"},{"type":"function","title":"Evision.XFeatures2D.DAISY.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.DAISY.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XFeatures2D.DAISY.html#write/3"},{"type":"type","title":"Evision.XFeatures2D.DAISY.t/0","doc":"Type that represents an `XFeatures2D.DAISY` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XFeatures2D.DAISY.html#t:t/0"},{"type":"module","title":"Evision.XFeatures2D.DAISY.NormalizationType","doc":"","ref":"Evision.XFeatures2D.DAISY.NormalizationType.html"},{"type":"function","title":"Evision.XFeatures2D.DAISY.NormalizationType.cv_NRM_FULL/0","doc":"","ref":"Evision.XFeatures2D.DAISY.NormalizationType.html#cv_NRM_FULL/0"},{"type":"function","title":"Evision.XFeatures2D.DAISY.NormalizationType.cv_NRM_NONE/0","doc":"","ref":"Evision.XFeatures2D.DAISY.NormalizationType.html#cv_NRM_NONE/0"},{"type":"function","title":"Evision.XFeatures2D.DAISY.NormalizationType.cv_NRM_PARTIAL/0","doc":"","ref":"Evision.XFeatures2D.DAISY.NormalizationType.html#cv_NRM_PARTIAL/0"},{"type":"function","title":"Evision.XFeatures2D.DAISY.NormalizationType.cv_NRM_SIFT/0","doc":"","ref":"Evision.XFeatures2D.DAISY.NormalizationType.html#cv_NRM_SIFT/0"},{"type":"type","title":"Evision.XFeatures2D.DAISY.NormalizationType.enum/0","doc":"","ref":"Evision.XFeatures2D.DAISY.NormalizationType.html#t:enum/0"},{"type":"module","title":"Evision.XFeatures2D.FREAK","doc":"","ref":"Evision.XFeatures2D.FREAK.html"},{"type":"function","title":"Evision.XFeatures2D.FREAK.compute/1","doc":"","ref":"Evision.XFeatures2D.FREAK.html#compute/1"},{"type":"function","title":"Evision.XFeatures2D.FREAK.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.FREAK.html#compute/3"},{"type":"function","title":"Evision.XFeatures2D.FREAK.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.FREAK.html#compute/4"},{"type":"function","title":"Evision.XFeatures2D.FREAK.create/0","doc":"create\n##### Keyword Arguments\n- **orientationNormalized**: `bool`.\n\n  Enable orientation normalization.\n\n- **scaleNormalized**: `bool`.\n\n  Enable scale normalization.\n\n- **patternScale**: `float`.\n\n  Scaling of the description pattern.\n\n- **nOctaves**: `integer()`.\n\n  Number of octaves covered by the detected keypoints.\n\n- **selectedPairs**: `[integer()]`.\n\n  (Optional) user defined selected pairs indexes,\n\n##### Return\n- **retval**: `FREAK`\n\nPython prototype (for reference only):\n```python3\ncreate([, orientationNormalized[, scaleNormalized[, patternScale[, nOctaves[, selectedPairs]]]]]) -> retval\n```","ref":"Evision.XFeatures2D.FREAK.html#create/0"},{"type":"function","title":"Evision.XFeatures2D.FREAK.create/1","doc":"create\n##### Keyword Arguments\n- **orientationNormalized**: `bool`.\n\n  Enable orientation normalization.\n\n- **scaleNormalized**: `bool`.\n\n  Enable scale normalization.\n\n- **patternScale**: `float`.\n\n  Scaling of the description pattern.\n\n- **nOctaves**: `integer()`.\n\n  Number of octaves covered by the detected keypoints.\n\n- **selectedPairs**: `[integer()]`.\n\n  (Optional) user defined selected pairs indexes,\n\n##### Return\n- **retval**: `FREAK`\n\nPython prototype (for reference only):\n```python3\ncreate([, orientationNormalized[, scaleNormalized[, patternScale[, nOctaves[, selectedPairs]]]]]) -> retval\n```","ref":"Evision.XFeatures2D.FREAK.html#create/1"},{"type":"function","title":"Evision.XFeatures2D.FREAK.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.XFeatures2D.FREAK.html#defaultNorm/1"},{"type":"function","title":"Evision.XFeatures2D.FREAK.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.XFeatures2D.FREAK.html#descriptorSize/1"},{"type":"function","title":"Evision.XFeatures2D.FREAK.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.XFeatures2D.FREAK.html#descriptorType/1"},{"type":"function","title":"Evision.XFeatures2D.FREAK.detect/1","doc":"","ref":"Evision.XFeatures2D.FREAK.html#detect/1"},{"type":"function","title":"Evision.XFeatures2D.FREAK.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.FREAK.html#detect/2"},{"type":"function","title":"Evision.XFeatures2D.FREAK.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.FREAK.html#detect/3"},{"type":"function","title":"Evision.XFeatures2D.FREAK.detectAndCompute/1","doc":"","ref":"Evision.XFeatures2D.FREAK.html#detectAndCompute/1"},{"type":"function","title":"Evision.XFeatures2D.FREAK.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.FREAK.html#detectAndCompute/3"},{"type":"function","title":"Evision.XFeatures2D.FREAK.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.FREAK.html#detectAndCompute/4"},{"type":"function","title":"Evision.XFeatures2D.FREAK.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XFeatures2D.FREAK.html#empty/1"},{"type":"function","title":"Evision.XFeatures2D.FREAK.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XFeatures2D.FREAK.html#getDefaultName/1"},{"type":"function","title":"Evision.XFeatures2D.FREAK.getNOctaves/1","doc":"getNOctaves\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNOctaves() -> retval\n```","ref":"Evision.XFeatures2D.FREAK.html#getNOctaves/1"},{"type":"function","title":"Evision.XFeatures2D.FREAK.getOrientationNormalized/1","doc":"getOrientationNormalized\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetOrientationNormalized() -> retval\n```","ref":"Evision.XFeatures2D.FREAK.html#getOrientationNormalized/1"},{"type":"function","title":"Evision.XFeatures2D.FREAK.getPatternScale/1","doc":"getPatternScale\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetPatternScale() -> retval\n```","ref":"Evision.XFeatures2D.FREAK.html#getPatternScale/1"},{"type":"function","title":"Evision.XFeatures2D.FREAK.getScaleNormalized/1","doc":"getScaleNormalized\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetScaleNormalized() -> retval\n```","ref":"Evision.XFeatures2D.FREAK.html#getScaleNormalized/1"},{"type":"function","title":"Evision.XFeatures2D.FREAK.read/1","doc":"","ref":"Evision.XFeatures2D.FREAK.html#read/1"},{"type":"function","title":"Evision.XFeatures2D.FREAK.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.XFeatures2D.FREAK.html#read/2"},{"type":"function","title":"Evision.XFeatures2D.FREAK.setNOctaves/1","doc":"","ref":"Evision.XFeatures2D.FREAK.html#setNOctaves/1"},{"type":"function","title":"Evision.XFeatures2D.FREAK.setNOctaves/2","doc":"setNOctaves\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n- **nOctaves**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNOctaves(nOctaves) -> None\n```","ref":"Evision.XFeatures2D.FREAK.html#setNOctaves/2"},{"type":"function","title":"Evision.XFeatures2D.FREAK.setOrientationNormalized/1","doc":"","ref":"Evision.XFeatures2D.FREAK.html#setOrientationNormalized/1"},{"type":"function","title":"Evision.XFeatures2D.FREAK.setOrientationNormalized/2","doc":"setOrientationNormalized\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n- **orientationNormalized**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetOrientationNormalized(orientationNormalized) -> None\n```","ref":"Evision.XFeatures2D.FREAK.html#setOrientationNormalized/2"},{"type":"function","title":"Evision.XFeatures2D.FREAK.setPatternScale/1","doc":"","ref":"Evision.XFeatures2D.FREAK.html#setPatternScale/1"},{"type":"function","title":"Evision.XFeatures2D.FREAK.setPatternScale/2","doc":"setPatternScale\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n- **patternScale**: `double`\n\nPython prototype (for reference only):\n```python3\nsetPatternScale(patternScale) -> None\n```","ref":"Evision.XFeatures2D.FREAK.html#setPatternScale/2"},{"type":"function","title":"Evision.XFeatures2D.FREAK.setScaleNormalized/1","doc":"","ref":"Evision.XFeatures2D.FREAK.html#setScaleNormalized/1"},{"type":"function","title":"Evision.XFeatures2D.FREAK.setScaleNormalized/2","doc":"setScaleNormalized\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n- **scaleNormalized**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetScaleNormalized(scaleNormalized) -> None\n```","ref":"Evision.XFeatures2D.FREAK.html#setScaleNormalized/2"},{"type":"function","title":"Evision.XFeatures2D.FREAK.write/1","doc":"","ref":"Evision.XFeatures2D.FREAK.html#write/1"},{"type":"function","title":"Evision.XFeatures2D.FREAK.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.XFeatures2D.FREAK.html#write/2"},{"type":"function","title":"Evision.XFeatures2D.FREAK.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.FREAK.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XFeatures2D.FREAK.html#write/3"},{"type":"type","title":"Evision.XFeatures2D.FREAK.t/0","doc":"Type that represents an `XFeatures2D.FREAK` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XFeatures2D.FREAK.html#t:t/0"},{"type":"module","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector","doc":"","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.compute/1","doc":"","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#compute/1"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#compute/3"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#compute/4"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.create/0","doc":"Creates a new implementation instance.\n##### Keyword Arguments\n- **numOctaves**: `integer()`.\n\n  the number of octaves in the scale-space pyramid\n\n- **corn_thresh**: `float`.\n\n  the threshold for the Harris cornerness measure\n\n- **dOG_thresh**: `float`.\n\n  the threshold for the Difference-of-Gaussians scale selection\n\n- **maxCorners**: `integer()`.\n\n  the maximum number of corners to consider\n\n- **num_layers**: `integer()`.\n\n  the number of intermediate scales per octave\n\n##### Return\n- **retval**: `HarrisLaplaceFeatureDetector`\n\nPython prototype (for reference only):\n```python3\ncreate([, numOctaves[, corn_thresh[, DOG_thresh[, maxCorners[, num_layers]]]]]) -> retval\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#create/0"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.create/1","doc":"Creates a new implementation instance.\n##### Keyword Arguments\n- **numOctaves**: `integer()`.\n\n  the number of octaves in the scale-space pyramid\n\n- **corn_thresh**: `float`.\n\n  the threshold for the Harris cornerness measure\n\n- **dOG_thresh**: `float`.\n\n  the threshold for the Difference-of-Gaussians scale selection\n\n- **maxCorners**: `integer()`.\n\n  the maximum number of corners to consider\n\n- **num_layers**: `integer()`.\n\n  the number of intermediate scales per octave\n\n##### Return\n- **retval**: `HarrisLaplaceFeatureDetector`\n\nPython prototype (for reference only):\n```python3\ncreate([, numOctaves[, corn_thresh[, DOG_thresh[, maxCorners[, num_layers]]]]]) -> retval\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#create/1"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#defaultNorm/1"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#descriptorSize/1"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#descriptorType/1"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.detect/1","doc":"","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#detect/1"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#detect/2"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#detect/3"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.detectAndCompute/1","doc":"","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#detectAndCompute/1"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#detectAndCompute/3"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#detectAndCompute/4"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#empty/1"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.getCornThresh/1","doc":"getCornThresh\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetCornThresh() -> retval\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#getCornThresh/1"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#getDefaultName/1"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.getDOGThresh/1","doc":"getDOGThresh\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetDOGThresh() -> retval\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#getDOGThresh/1"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.getMaxCorners/1","doc":"getMaxCorners\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxCorners() -> retval\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#getMaxCorners/1"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.getNumLayers/1","doc":"getNumLayers\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNumLayers() -> retval\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#getNumLayers/1"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.getNumOctaves/1","doc":"getNumOctaves\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNumOctaves() -> retval\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#getNumOctaves/1"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.read/1","doc":"","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#read/1"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#read/2"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.setCornThresh/1","doc":"","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#setCornThresh/1"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.setCornThresh/2","doc":"setCornThresh\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n- **corn_thresh_**: `float`\n\nPython prototype (for reference only):\n```python3\nsetCornThresh(corn_thresh_) -> None\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#setCornThresh/2"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.setDOGThresh/1","doc":"","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#setDOGThresh/1"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.setDOGThresh/2","doc":"setDOGThresh\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n- **dOG_thresh_**: `float`\n\nPython prototype (for reference only):\n```python3\nsetDOGThresh(DOG_thresh_) -> None\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#setDOGThresh/2"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.setMaxCorners/1","doc":"","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#setMaxCorners/1"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.setMaxCorners/2","doc":"setMaxCorners\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n- **maxCorners_**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxCorners(maxCorners_) -> None\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#setMaxCorners/2"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.setNumLayers/1","doc":"","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#setNumLayers/1"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.setNumLayers/2","doc":"setNumLayers\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n- **num_layers_**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNumLayers(num_layers_) -> None\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#setNumLayers/2"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.setNumOctaves/1","doc":"","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#setNumOctaves/1"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.setNumOctaves/2","doc":"setNumOctaves\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n- **numOctaves_**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNumOctaves(numOctaves_) -> None\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#setNumOctaves/2"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.write/1","doc":"","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#write/1"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#write/2"},{"type":"function","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#write/3"},{"type":"type","title":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.t/0","doc":"Type that represents an `XFeatures2D.HarrisLaplaceFeatureDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XFeatures2D.HarrisLaplaceFeatureDetector.html#t:t/0"},{"type":"module","title":"Evision.XFeatures2D.LATCH","doc":"","ref":"Evision.XFeatures2D.LATCH.html"},{"type":"function","title":"Evision.XFeatures2D.LATCH.compute/1","doc":"","ref":"Evision.XFeatures2D.LATCH.html#compute/1"},{"type":"function","title":"Evision.XFeatures2D.LATCH.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.LATCH.html#compute/3"},{"type":"function","title":"Evision.XFeatures2D.LATCH.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.LATCH.html#compute/4"},{"type":"function","title":"Evision.XFeatures2D.LATCH.create/0","doc":"create\n##### Keyword Arguments\n- **bytes**: `integer()`.\n- **rotationInvariance**: `bool`.\n- **half_ssd_size**: `integer()`.\n- **sigma**: `double`.\n\n##### Return\n- **retval**: `LATCH`\n\nPython prototype (for reference only):\n```python3\ncreate([, bytes[, rotationInvariance[, half_ssd_size[, sigma]]]]) -> retval\n```","ref":"Evision.XFeatures2D.LATCH.html#create/0"},{"type":"function","title":"Evision.XFeatures2D.LATCH.create/1","doc":"create\n##### Keyword Arguments\n- **bytes**: `integer()`.\n- **rotationInvariance**: `bool`.\n- **half_ssd_size**: `integer()`.\n- **sigma**: `double`.\n\n##### Return\n- **retval**: `LATCH`\n\nPython prototype (for reference only):\n```python3\ncreate([, bytes[, rotationInvariance[, half_ssd_size[, sigma]]]]) -> retval\n```","ref":"Evision.XFeatures2D.LATCH.html#create/1"},{"type":"function","title":"Evision.XFeatures2D.LATCH.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.XFeatures2D.LATCH.html#defaultNorm/1"},{"type":"function","title":"Evision.XFeatures2D.LATCH.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.XFeatures2D.LATCH.html#descriptorSize/1"},{"type":"function","title":"Evision.XFeatures2D.LATCH.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.XFeatures2D.LATCH.html#descriptorType/1"},{"type":"function","title":"Evision.XFeatures2D.LATCH.detect/1","doc":"","ref":"Evision.XFeatures2D.LATCH.html#detect/1"},{"type":"function","title":"Evision.XFeatures2D.LATCH.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.LATCH.html#detect/2"},{"type":"function","title":"Evision.XFeatures2D.LATCH.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.LATCH.html#detect/3"},{"type":"function","title":"Evision.XFeatures2D.LATCH.detectAndCompute/1","doc":"","ref":"Evision.XFeatures2D.LATCH.html#detectAndCompute/1"},{"type":"function","title":"Evision.XFeatures2D.LATCH.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.LATCH.html#detectAndCompute/3"},{"type":"function","title":"Evision.XFeatures2D.LATCH.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.LATCH.html#detectAndCompute/4"},{"type":"function","title":"Evision.XFeatures2D.LATCH.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XFeatures2D.LATCH.html#empty/1"},{"type":"function","title":"Evision.XFeatures2D.LATCH.getBytes/1","doc":"getBytes\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetBytes() -> retval\n```","ref":"Evision.XFeatures2D.LATCH.html#getBytes/1"},{"type":"function","title":"Evision.XFeatures2D.LATCH.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XFeatures2D.LATCH.html#getDefaultName/1"},{"type":"function","title":"Evision.XFeatures2D.LATCH.getHalfSSDsize/1","doc":"getHalfSSDsize\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetHalfSSDsize() -> retval\n```","ref":"Evision.XFeatures2D.LATCH.html#getHalfSSDsize/1"},{"type":"function","title":"Evision.XFeatures2D.LATCH.getRotationInvariance/1","doc":"getRotationInvariance\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetRotationInvariance() -> retval\n```","ref":"Evision.XFeatures2D.LATCH.html#getRotationInvariance/1"},{"type":"function","title":"Evision.XFeatures2D.LATCH.getSigma/1","doc":"getSigma\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetSigma() -> retval\n```","ref":"Evision.XFeatures2D.LATCH.html#getSigma/1"},{"type":"function","title":"Evision.XFeatures2D.LATCH.read/1","doc":"","ref":"Evision.XFeatures2D.LATCH.html#read/1"},{"type":"function","title":"Evision.XFeatures2D.LATCH.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.XFeatures2D.LATCH.html#read/2"},{"type":"function","title":"Evision.XFeatures2D.LATCH.setBytes/1","doc":"","ref":"Evision.XFeatures2D.LATCH.html#setBytes/1"},{"type":"function","title":"Evision.XFeatures2D.LATCH.setBytes/2","doc":"setBytes\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n- **bytes**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetBytes(bytes) -> None\n```","ref":"Evision.XFeatures2D.LATCH.html#setBytes/2"},{"type":"function","title":"Evision.XFeatures2D.LATCH.setHalfSSDsize/1","doc":"","ref":"Evision.XFeatures2D.LATCH.html#setHalfSSDsize/1"},{"type":"function","title":"Evision.XFeatures2D.LATCH.setHalfSSDsize/2","doc":"setHalfSSDsize\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n- **half_ssd_size**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetHalfSSDsize(half_ssd_size) -> None\n```","ref":"Evision.XFeatures2D.LATCH.html#setHalfSSDsize/2"},{"type":"function","title":"Evision.XFeatures2D.LATCH.setRotationInvariance/1","doc":"","ref":"Evision.XFeatures2D.LATCH.html#setRotationInvariance/1"},{"type":"function","title":"Evision.XFeatures2D.LATCH.setRotationInvariance/2","doc":"setRotationInvariance\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n- **rotationInvariance**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetRotationInvariance(rotationInvariance) -> None\n```","ref":"Evision.XFeatures2D.LATCH.html#setRotationInvariance/2"},{"type":"function","title":"Evision.XFeatures2D.LATCH.setSigma/1","doc":"","ref":"Evision.XFeatures2D.LATCH.html#setSigma/1"},{"type":"function","title":"Evision.XFeatures2D.LATCH.setSigma/2","doc":"setSigma\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n- **sigma**: `double`\n\nPython prototype (for reference only):\n```python3\nsetSigma(sigma) -> None\n```","ref":"Evision.XFeatures2D.LATCH.html#setSigma/2"},{"type":"function","title":"Evision.XFeatures2D.LATCH.write/1","doc":"","ref":"Evision.XFeatures2D.LATCH.html#write/1"},{"type":"function","title":"Evision.XFeatures2D.LATCH.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.XFeatures2D.LATCH.html#write/2"},{"type":"function","title":"Evision.XFeatures2D.LATCH.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LATCH.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XFeatures2D.LATCH.html#write/3"},{"type":"type","title":"Evision.XFeatures2D.LATCH.t/0","doc":"Type that represents an `XFeatures2D.LATCH` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XFeatures2D.LATCH.html#t:t/0"},{"type":"module","title":"Evision.XFeatures2D.LUCID","doc":"","ref":"Evision.XFeatures2D.LUCID.html"},{"type":"function","title":"Evision.XFeatures2D.LUCID.compute/1","doc":"","ref":"Evision.XFeatures2D.LUCID.html#compute/1"},{"type":"function","title":"Evision.XFeatures2D.LUCID.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LUCID.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LUCID.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.LUCID.html#compute/3"},{"type":"function","title":"Evision.XFeatures2D.LUCID.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LUCID.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LUCID.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.LUCID.html#compute/4"},{"type":"function","title":"Evision.XFeatures2D.LUCID.create/0","doc":"create\n##### Keyword Arguments\n- **lucid_kernel**: `integer()`.\n\n  kernel for descriptor construction, where 1=3x3, 2=5x5, 3=7x7 and so forth\n\n- **blur_kernel**: `integer()`.\n\n  kernel for blurring image prior to descriptor construction, where 1=3x3, 2=5x5, 3=7x7 and so forth\n\n##### Return\n- **retval**: `LUCID`\n\nPython prototype (for reference only):\n```python3\ncreate([, lucid_kernel[, blur_kernel]]) -> retval\n```","ref":"Evision.XFeatures2D.LUCID.html#create/0"},{"type":"function","title":"Evision.XFeatures2D.LUCID.create/1","doc":"create\n##### Keyword Arguments\n- **lucid_kernel**: `integer()`.\n\n  kernel for descriptor construction, where 1=3x3, 2=5x5, 3=7x7 and so forth\n\n- **blur_kernel**: `integer()`.\n\n  kernel for blurring image prior to descriptor construction, where 1=3x3, 2=5x5, 3=7x7 and so forth\n\n##### Return\n- **retval**: `LUCID`\n\nPython prototype (for reference only):\n```python3\ncreate([, lucid_kernel[, blur_kernel]]) -> retval\n```","ref":"Evision.XFeatures2D.LUCID.html#create/1"},{"type":"function","title":"Evision.XFeatures2D.LUCID.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LUCID.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.XFeatures2D.LUCID.html#defaultNorm/1"},{"type":"function","title":"Evision.XFeatures2D.LUCID.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LUCID.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.XFeatures2D.LUCID.html#descriptorSize/1"},{"type":"function","title":"Evision.XFeatures2D.LUCID.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LUCID.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.XFeatures2D.LUCID.html#descriptorType/1"},{"type":"function","title":"Evision.XFeatures2D.LUCID.detect/1","doc":"","ref":"Evision.XFeatures2D.LUCID.html#detect/1"},{"type":"function","title":"Evision.XFeatures2D.LUCID.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LUCID.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LUCID.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.LUCID.html#detect/2"},{"type":"function","title":"Evision.XFeatures2D.LUCID.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LUCID.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LUCID.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.LUCID.html#detect/3"},{"type":"function","title":"Evision.XFeatures2D.LUCID.detectAndCompute/1","doc":"","ref":"Evision.XFeatures2D.LUCID.html#detectAndCompute/1"},{"type":"function","title":"Evision.XFeatures2D.LUCID.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LUCID.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.LUCID.html#detectAndCompute/3"},{"type":"function","title":"Evision.XFeatures2D.LUCID.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LUCID.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.LUCID.html#detectAndCompute/4"},{"type":"function","title":"Evision.XFeatures2D.LUCID.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LUCID.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XFeatures2D.LUCID.html#empty/1"},{"type":"function","title":"Evision.XFeatures2D.LUCID.getBlurKernel/1","doc":"getBlurKernel\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LUCID.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetBlurKernel() -> retval\n```","ref":"Evision.XFeatures2D.LUCID.html#getBlurKernel/1"},{"type":"function","title":"Evision.XFeatures2D.LUCID.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LUCID.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XFeatures2D.LUCID.html#getDefaultName/1"},{"type":"function","title":"Evision.XFeatures2D.LUCID.getLucidKernel/1","doc":"getLucidKernel\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LUCID.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetLucidKernel() -> retval\n```","ref":"Evision.XFeatures2D.LUCID.html#getLucidKernel/1"},{"type":"function","title":"Evision.XFeatures2D.LUCID.read/1","doc":"","ref":"Evision.XFeatures2D.LUCID.html#read/1"},{"type":"function","title":"Evision.XFeatures2D.LUCID.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LUCID.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LUCID.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.XFeatures2D.LUCID.html#read/2"},{"type":"function","title":"Evision.XFeatures2D.LUCID.setBlurKernel/1","doc":"","ref":"Evision.XFeatures2D.LUCID.html#setBlurKernel/1"},{"type":"function","title":"Evision.XFeatures2D.LUCID.setBlurKernel/2","doc":"setBlurKernel\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LUCID.t()`\n- **blur_kernel**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetBlurKernel(blur_kernel) -> None\n```","ref":"Evision.XFeatures2D.LUCID.html#setBlurKernel/2"},{"type":"function","title":"Evision.XFeatures2D.LUCID.setLucidKernel/1","doc":"","ref":"Evision.XFeatures2D.LUCID.html#setLucidKernel/1"},{"type":"function","title":"Evision.XFeatures2D.LUCID.setLucidKernel/2","doc":"setLucidKernel\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LUCID.t()`\n- **lucid_kernel**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetLucidKernel(lucid_kernel) -> None\n```","ref":"Evision.XFeatures2D.LUCID.html#setLucidKernel/2"},{"type":"function","title":"Evision.XFeatures2D.LUCID.write/1","doc":"","ref":"Evision.XFeatures2D.LUCID.html#write/1"},{"type":"function","title":"Evision.XFeatures2D.LUCID.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LUCID.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.XFeatures2D.LUCID.html#write/2"},{"type":"function","title":"Evision.XFeatures2D.LUCID.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.LUCID.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XFeatures2D.LUCID.html#write/3"},{"type":"type","title":"Evision.XFeatures2D.LUCID.t/0","doc":"Type that represents an `XFeatures2D.LUCID` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XFeatures2D.LUCID.html#t:t/0"},{"type":"module","title":"Evision.XFeatures2D.MSDDetector","doc":"","ref":"Evision.XFeatures2D.MSDDetector.html"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.compute/1","doc":"","ref":"Evision.XFeatures2D.MSDDetector.html#compute/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.MSDDetector.html#compute/3"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.MSDDetector.html#compute/4"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.create/0","doc":"create\n##### Keyword Arguments\n- **m_patch_radius**: `integer()`.\n- **m_search_area_radius**: `integer()`.\n- **m_nms_radius**: `integer()`.\n- **m_nms_scale_radius**: `integer()`.\n- **m_th_saliency**: `float`.\n- **m_kNN**: `integer()`.\n- **m_scale_factor**: `float`.\n- **m_n_scales**: `integer()`.\n- **m_compute_orientation**: `bool`.\n\n##### Return\n- **retval**: `MSDDetector`\n\nPython prototype (for reference only):\n```python3\ncreate([, m_patch_radius[, m_search_area_radius[, m_nms_radius[, m_nms_scale_radius[, m_th_saliency[, m_kNN[, m_scale_factor[, m_n_scales[, m_compute_orientation]]]]]]]]]) -> retval\n```","ref":"Evision.XFeatures2D.MSDDetector.html#create/0"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.create/1","doc":"create\n##### Keyword Arguments\n- **m_patch_radius**: `integer()`.\n- **m_search_area_radius**: `integer()`.\n- **m_nms_radius**: `integer()`.\n- **m_nms_scale_radius**: `integer()`.\n- **m_th_saliency**: `float`.\n- **m_kNN**: `integer()`.\n- **m_scale_factor**: `float`.\n- **m_n_scales**: `integer()`.\n- **m_compute_orientation**: `bool`.\n\n##### Return\n- **retval**: `MSDDetector`\n\nPython prototype (for reference only):\n```python3\ncreate([, m_patch_radius[, m_search_area_radius[, m_nms_radius[, m_nms_scale_radius[, m_th_saliency[, m_kNN[, m_scale_factor[, m_n_scales[, m_compute_orientation]]]]]]]]]) -> retval\n```","ref":"Evision.XFeatures2D.MSDDetector.html#create/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.XFeatures2D.MSDDetector.html#defaultNorm/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.XFeatures2D.MSDDetector.html#descriptorSize/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.XFeatures2D.MSDDetector.html#descriptorType/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.detect/1","doc":"","ref":"Evision.XFeatures2D.MSDDetector.html#detect/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.MSDDetector.html#detect/2"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.MSDDetector.html#detect/3"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.detectAndCompute/1","doc":"","ref":"Evision.XFeatures2D.MSDDetector.html#detectAndCompute/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.MSDDetector.html#detectAndCompute/3"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.MSDDetector.html#detectAndCompute/4"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XFeatures2D.MSDDetector.html#empty/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.getComputeOrientation/1","doc":"getComputeOrientation\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetComputeOrientation() -> retval\n```","ref":"Evision.XFeatures2D.MSDDetector.html#getComputeOrientation/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XFeatures2D.MSDDetector.html#getDefaultName/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.getKNN/1","doc":"getKNN\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetKNN() -> retval\n```","ref":"Evision.XFeatures2D.MSDDetector.html#getKNN/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.getNmsRadius/1","doc":"getNmsRadius\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNmsRadius() -> retval\n```","ref":"Evision.XFeatures2D.MSDDetector.html#getNmsRadius/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.getNmsScaleRadius/1","doc":"getNmsScaleRadius\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNmsScaleRadius() -> retval\n```","ref":"Evision.XFeatures2D.MSDDetector.html#getNmsScaleRadius/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.getNScales/1","doc":"getNScales\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNScales() -> retval\n```","ref":"Evision.XFeatures2D.MSDDetector.html#getNScales/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.getPatchRadius/1","doc":"getPatchRadius\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetPatchRadius() -> retval\n```","ref":"Evision.XFeatures2D.MSDDetector.html#getPatchRadius/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.getScaleFactor/1","doc":"getScaleFactor\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetScaleFactor() -> retval\n```","ref":"Evision.XFeatures2D.MSDDetector.html#getScaleFactor/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.getSearchAreaRadius/1","doc":"getSearchAreaRadius\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetSearchAreaRadius() -> retval\n```","ref":"Evision.XFeatures2D.MSDDetector.html#getSearchAreaRadius/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.getThSaliency/1","doc":"getThSaliency\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetThSaliency() -> retval\n```","ref":"Evision.XFeatures2D.MSDDetector.html#getThSaliency/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.read/1","doc":"","ref":"Evision.XFeatures2D.MSDDetector.html#read/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.XFeatures2D.MSDDetector.html#read/2"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.setComputeOrientation/1","doc":"","ref":"Evision.XFeatures2D.MSDDetector.html#setComputeOrientation/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.setComputeOrientation/2","doc":"setComputeOrientation\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n- **compute_orientation**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetComputeOrientation(compute_orientation) -> None\n```","ref":"Evision.XFeatures2D.MSDDetector.html#setComputeOrientation/2"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.setKNN/1","doc":"","ref":"Evision.XFeatures2D.MSDDetector.html#setKNN/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.setKNN/2","doc":"setKNN\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n- **kNN**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetKNN(kNN) -> None\n```","ref":"Evision.XFeatures2D.MSDDetector.html#setKNN/2"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.setNmsRadius/1","doc":"","ref":"Evision.XFeatures2D.MSDDetector.html#setNmsRadius/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.setNmsRadius/2","doc":"setNmsRadius\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n- **nms_radius**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNmsRadius(nms_radius) -> None\n```","ref":"Evision.XFeatures2D.MSDDetector.html#setNmsRadius/2"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.setNmsScaleRadius/1","doc":"","ref":"Evision.XFeatures2D.MSDDetector.html#setNmsScaleRadius/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.setNmsScaleRadius/2","doc":"setNmsScaleRadius\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n- **nms_scale_radius**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNmsScaleRadius(nms_scale_radius) -> None\n```","ref":"Evision.XFeatures2D.MSDDetector.html#setNmsScaleRadius/2"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.setNScales/1","doc":"","ref":"Evision.XFeatures2D.MSDDetector.html#setNScales/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.setNScales/2","doc":"setNScales\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n- **use_orientation**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNScales(use_orientation) -> None\n```","ref":"Evision.XFeatures2D.MSDDetector.html#setNScales/2"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.setPatchRadius/1","doc":"","ref":"Evision.XFeatures2D.MSDDetector.html#setPatchRadius/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.setPatchRadius/2","doc":"setPatchRadius\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n- **patch_radius**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetPatchRadius(patch_radius) -> None\n```","ref":"Evision.XFeatures2D.MSDDetector.html#setPatchRadius/2"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.setScaleFactor/1","doc":"","ref":"Evision.XFeatures2D.MSDDetector.html#setScaleFactor/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.setScaleFactor/2","doc":"setScaleFactor\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n- **scale_factor**: `float`\n\nPython prototype (for reference only):\n```python3\nsetScaleFactor(scale_factor) -> None\n```","ref":"Evision.XFeatures2D.MSDDetector.html#setScaleFactor/2"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.setSearchAreaRadius/1","doc":"","ref":"Evision.XFeatures2D.MSDDetector.html#setSearchAreaRadius/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.setSearchAreaRadius/2","doc":"setSearchAreaRadius\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n- **use_orientation**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetSearchAreaRadius(use_orientation) -> None\n```","ref":"Evision.XFeatures2D.MSDDetector.html#setSearchAreaRadius/2"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.setThSaliency/1","doc":"","ref":"Evision.XFeatures2D.MSDDetector.html#setThSaliency/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.setThSaliency/2","doc":"setThSaliency\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n- **th_saliency**: `float`\n\nPython prototype (for reference only):\n```python3\nsetThSaliency(th_saliency) -> None\n```","ref":"Evision.XFeatures2D.MSDDetector.html#setThSaliency/2"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.write/1","doc":"","ref":"Evision.XFeatures2D.MSDDetector.html#write/1"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.XFeatures2D.MSDDetector.html#write/2"},{"type":"function","title":"Evision.XFeatures2D.MSDDetector.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.MSDDetector.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XFeatures2D.MSDDetector.html#write/3"},{"type":"type","title":"Evision.XFeatures2D.MSDDetector.t/0","doc":"Type that represents an `XFeatures2D.MSDDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XFeatures2D.MSDDetector.html#t:t/0"},{"type":"module","title":"Evision.XFeatures2D.PCTSignatures","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#clear/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.computeSignature/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#computeSignature/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.computeSignature/2","doc":"Computes signature of given image.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **image**: `Evision.Mat`.\n\n  Input image of CV_8U type.\n\n##### Return\n- **signature**: `Evision.Mat.t()`.\n\n  Output computed signature.\n\nPython prototype (for reference only):\n```python3\ncomputeSignature(image[, signature]) -> signature\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#computeSignature/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.computeSignature/3","doc":"Computes signature of given image.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **image**: `Evision.Mat`.\n\n  Input image of CV_8U type.\n\n##### Return\n- **signature**: `Evision.Mat.t()`.\n\n  Output computed signature.\n\nPython prototype (for reference only):\n```python3\ncomputeSignature(image[, signature]) -> signature\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#computeSignature/3"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.computeSignatures/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#computeSignatures/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.computeSignatures/3","doc":"Computes signatures for multiple images in parallel.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **images**: `[Evision.Mat]`.\n\n  Vector of input images of CV_8U type.\n\n- **signatures**: `[Evision.Mat]`.\n\n  Vector of computed signatures.\n\nPython prototype (for reference only):\n```python3\ncomputeSignatures(images, signatures) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#computeSignatures/3"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.create/0","doc":"Creates PCTSignatures algorithm using sample and seed count.\nIt generates its own sets of sampling points and clusterization seed indexes.\n\n##### Keyword Arguments\n- **initSampleCount**: `integer()`.\n\n  Number of points used for image sampling.\n\n- **initSeedCount**: `integer()`.\n\n  Number of initial clusterization seeds.\n  Must be lower or equal to initSampleCount\n\n- **pointDistribution**: `integer()`.\n\n  Distribution of generated points. Default: UNIFORM.\n  Available: UNIFORM, REGULAR, NORMAL.\n\n##### Return\n- **retval**: `PCTSignatures`\n\n@return Created algorithm.\n\nPython prototype (for reference only):\n```python3\ncreate([, initSampleCount[, initSeedCount[, pointDistribution]]]) -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#create/0"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.create/1","doc":"Creates PCTSignatures algorithm using sample and seed count.\nIt generates its own sets of sampling points and clusterization seed indexes.\n\n##### Keyword Arguments\n- **initSampleCount**: `integer()`.\n\n  Number of points used for image sampling.\n\n- **initSeedCount**: `integer()`.\n\n  Number of initial clusterization seeds.\n  Must be lower or equal to initSampleCount\n\n- **pointDistribution**: `integer()`.\n\n  Distribution of generated points. Default: UNIFORM.\n  Available: UNIFORM, REGULAR, NORMAL.\n\n##### Return\n- **retval**: `PCTSignatures`\n\n@return Created algorithm.\n\nPython prototype (for reference only):\n```python3\ncreate([, initSampleCount[, initSeedCount[, pointDistribution]]]) -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#create/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.create/2","doc":"#### Variant 1:\nCreates PCTSignatures algorithm using pre-generated sampling points\nand clusterization seeds indexes.\n\n##### Positional Arguments\n- **initSamplingPoints**: `[Point2f]`.\n\n  Sampling points used in image sampling.\n\n- **initClusterSeedIndexes**: `[integer()]`.\n\n  Indexes of initial clusterization seeds.\n  Its size must be lower or equal to initSamplingPoints.size().\n\n##### Return\n- **retval**: `PCTSignatures`\n\n@return Created algorithm.\n\nPython prototype (for reference only):\n```python3\ncreate(initSamplingPoints, initClusterSeedIndexes) -> retval\n```\n#### Variant 2:\nCreates PCTSignatures algorithm using pre-generated sampling points\nand number of clusterization seeds. It uses the provided\nsampling points and generates its own clusterization seed indexes.\n\n##### Positional Arguments\n- **initSamplingPoints**: `[Point2f]`.\n\n  Sampling points used in image sampling.\n\n- **initSeedCount**: `integer()`.\n\n  Number of initial clusterization seeds.\n  Must be lower or equal to initSamplingPoints.size().\n\n##### Return\n- **retval**: `PCTSignatures`\n\n@return Created algorithm.\n\nPython prototype (for reference only):\n```python3\ncreate(initSamplingPoints, initSeedCount) -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#create/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.drawSignature/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#drawSignature/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.drawSignature/2","doc":"Draws signature in the source image and outputs the result.\nSignatures are visualized as a circle\nwith radius based on signature weight\nand color based on signature color.\nContrast and entropy are not visualized.\n\n##### Positional Arguments\n- **source**: `Evision.Mat`.\n\n  Source image.\n\n- **signature**: `Evision.Mat`.\n\n  Image signature.\n\n##### Keyword Arguments\n- **radiusToShorterSideRatio**: `float`.\n\n  Determines maximal radius of signature in the output image.\n\n- **borderThickness**: `integer()`.\n\n  Border thickness of the visualized signature.\n\n##### Return\n- **result**: `Evision.Mat.t()`.\n\n  Output result.\n\nPython prototype (for reference only):\n```python3\ndrawSignature(source, signature[, result[, radiusToShorterSideRatio[, borderThickness]]]) -> result\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#drawSignature/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.drawSignature/3","doc":"Draws signature in the source image and outputs the result.\nSignatures are visualized as a circle\nwith radius based on signature weight\nand color based on signature color.\nContrast and entropy are not visualized.\n\n##### Positional Arguments\n- **source**: `Evision.Mat`.\n\n  Source image.\n\n- **signature**: `Evision.Mat`.\n\n  Image signature.\n\n##### Keyword Arguments\n- **radiusToShorterSideRatio**: `float`.\n\n  Determines maximal radius of signature in the output image.\n\n- **borderThickness**: `integer()`.\n\n  Border thickness of the visualized signature.\n\n##### Return\n- **result**: `Evision.Mat.t()`.\n\n  Output result.\n\nPython prototype (for reference only):\n```python3\ndrawSignature(source, signature[, result[, radiusToShorterSideRatio[, borderThickness]]]) -> result\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#drawSignature/3"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#empty/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.generateInitPoints/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#generateInitPoints/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.generateInitPoints/3","doc":"Generates initial sampling points according to selected point distribution.\n\n##### Positional Arguments\n- **initPoints**: `[Point2f]`.\n\n  Output vector where the generated points will be saved.\n\n- **count**: `integer()`.\n\n  Number of points to generate.\n\n- **pointDistribution**: `integer()`.\n\n  Point distribution selector.\n  Available: UNIFORM, REGULAR, NORMAL.\n\n**Note**: Generated coordinates are in range [0..1)\n\nPython prototype (for reference only):\n```python3\ngenerateInitPoints(initPoints, count, pointDistribution) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#generateInitPoints/3"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.getClusterMinSize/1","doc":"This parameter multiplied by the index of iteration gives lower limit for cluster size.\nClusters containing fewer points than specified by the limit have their centroid dismissed\nand points are reassigned.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetClusterMinSize() -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#getClusterMinSize/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#getDefaultName/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.getDistanceFunction/1","doc":"Distance function selector used for measuring distance between two points in k-means.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetDistanceFunction() -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#getDistanceFunction/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.getDropThreshold/1","doc":"Remove centroids in k-means whose weight is lesser or equal to given threshold.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetDropThreshold() -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#getDropThreshold/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.getGrayscaleBits/1","doc":"Color resolution of the greyscale bitmap represented in allocated bits\n(i.e., value 4 means that 16 shades of grey are used).\nThe greyscale bitmap is used for computing contrast and entropy values.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetGrayscaleBits() -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#getGrayscaleBits/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.getInitSeedCount/1","doc":"Number of initial seeds (initial number of clusters) for the k-means algorithm.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetInitSeedCount() -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#getInitSeedCount/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.getInitSeedIndexes/1","doc":"Initial seeds (initial number of clusters) for the k-means algorithm.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n\n##### Return\n- **retval**: `[integer()]`\n\nPython prototype (for reference only):\n```python3\ngetInitSeedIndexes() -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#getInitSeedIndexes/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.getIterationCount/1","doc":"Number of iterations of the k-means clustering.\nWe use fixed number of iterations, since the modified clustering is pruning clusters\n(not iteratively refining k clusters).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetIterationCount() -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#getIterationCount/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.getJoiningDistance/1","doc":"Threshold euclidean distance between two centroids.\nIf two cluster centers are closer than this distance,\none of the centroid is dismissed and points are reassigned.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetJoiningDistance() -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#getJoiningDistance/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.getMaxClustersCount/1","doc":"Maximal number of generated clusters. If the number is exceeded,\nthe clusters are sorted by their weights and the smallest clusters are cropped.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxClustersCount() -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#getMaxClustersCount/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.getSampleCount/1","doc":"Number of initial samples taken from the image.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetSampleCount() -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#getSampleCount/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.getSamplingPoints/1","doc":"Initial samples taken from the image.\nThese sampled features become the input for clustering.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n\n##### Return\n- **retval**: `[Point2f]`\n\nPython prototype (for reference only):\n```python3\ngetSamplingPoints() -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#getSamplingPoints/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.getWeightA/1","doc":"Weights (multiplicative constants) that linearly stretch individual axes of the feature space\n(x,y = position; L,a,b = color in CIE Lab space; c = contrast. e = entropy)\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetWeightA() -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#getWeightA/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.getWeightB/1","doc":"Weights (multiplicative constants) that linearly stretch individual axes of the feature space\n(x,y = position; L,a,b = color in CIE Lab space; c = contrast. e = entropy)\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetWeightB() -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#getWeightB/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.getWeightContrast/1","doc":"Weights (multiplicative constants) that linearly stretch individual axes of the feature space\n(x,y = position; L,a,b = color in CIE Lab space; c = contrast. e = entropy)\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetWeightContrast() -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#getWeightContrast/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.getWeightEntropy/1","doc":"Weights (multiplicative constants) that linearly stretch individual axes of the feature space\n(x,y = position; L,a,b = color in CIE Lab space; c = contrast. e = entropy)\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetWeightEntropy() -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#getWeightEntropy/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.getWeightL/1","doc":"Weights (multiplicative constants) that linearly stretch individual axes of the feature space\n(x,y = position; L,a,b = color in CIE Lab space; c = contrast. e = entropy)\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetWeightL() -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#getWeightL/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.getWeightX/1","doc":"Weights (multiplicative constants) that linearly stretch individual axes of the feature space\n(x,y = position; L,a,b = color in CIE Lab space; c = contrast. e = entropy)\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetWeightX() -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#getWeightX/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.getWeightY/1","doc":"Weights (multiplicative constants) that linearly stretch individual axes of the feature space\n(x,y = position; L,a,b = color in CIE Lab space; c = contrast. e = entropy)\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetWeightY() -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#getWeightY/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.getWindowRadius/1","doc":"Size of the texture sampling window used to compute contrast and entropy\n(center of the window is always in the pixel selected by x,y coordinates\nof the corresponding feature sample).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetWindowRadius() -> retval\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#getWindowRadius/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.read/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#read/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#read/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.save/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#save/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#save/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setClusterMinSize/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#setClusterMinSize/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setClusterMinSize/2","doc":"This parameter multiplied by the index of iteration gives lower limit for cluster size.\nClusters containing fewer points than specified by the limit have their centroid dismissed\nand points are reassigned.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **clusterMinSize**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetClusterMinSize(clusterMinSize) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#setClusterMinSize/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setDistanceFunction/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#setDistanceFunction/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setDistanceFunction/2","doc":"Distance function selector used for measuring distance between two points in k-means.\nAvailable: L0_25, L0_5, L1, L2, L2SQUARED, L5, L_INFINITY.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **distanceFunction**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetDistanceFunction(distanceFunction) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#setDistanceFunction/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setDropThreshold/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#setDropThreshold/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setDropThreshold/2","doc":"Remove centroids in k-means whose weight is lesser or equal to given threshold.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **dropThreshold**: `float`\n\nPython prototype (for reference only):\n```python3\nsetDropThreshold(dropThreshold) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#setDropThreshold/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setGrayscaleBits/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#setGrayscaleBits/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setGrayscaleBits/2","doc":"Color resolution of the greyscale bitmap represented in allocated bits\n(i.e., value 4 means that 16 shades of grey are used).\nThe greyscale bitmap is used for computing contrast and entropy values.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **grayscaleBits**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetGrayscaleBits(grayscaleBits) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#setGrayscaleBits/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setInitSeedIndexes/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#setInitSeedIndexes/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setInitSeedIndexes/2","doc":"Initial seed indexes for the k-means algorithm.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **initSeedIndexes**: `[integer()]`\n\nPython prototype (for reference only):\n```python3\nsetInitSeedIndexes(initSeedIndexes) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#setInitSeedIndexes/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setIterationCount/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#setIterationCount/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setIterationCount/2","doc":"Number of iterations of the k-means clustering.\nWe use fixed number of iterations, since the modified clustering is pruning clusters\n(not iteratively refining k clusters).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **iterationCount**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetIterationCount(iterationCount) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#setIterationCount/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setJoiningDistance/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#setJoiningDistance/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setJoiningDistance/2","doc":"Threshold euclidean distance between two centroids.\nIf two cluster centers are closer than this distance,\none of the centroid is dismissed and points are reassigned.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **joiningDistance**: `float`\n\nPython prototype (for reference only):\n```python3\nsetJoiningDistance(joiningDistance) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#setJoiningDistance/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setMaxClustersCount/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#setMaxClustersCount/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setMaxClustersCount/2","doc":"Maximal number of generated clusters. If the number is exceeded,\nthe clusters are sorted by their weights and the smallest clusters are cropped.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **maxClustersCount**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxClustersCount(maxClustersCount) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#setMaxClustersCount/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setSamplingPoints/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#setSamplingPoints/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setSamplingPoints/2","doc":"Sets sampling points used to sample the input image.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **samplingPoints**: `[Point2f]`.\n\n  Vector of sampling points in range [0..1)\n\n**Note**: Number of sampling points must be greater or equal to clusterization seed count.\n\nPython prototype (for reference only):\n```python3\nsetSamplingPoints(samplingPoints) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#setSamplingPoints/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setTranslation/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#setTranslation/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setTranslation/3","doc":"Translations of the individual axes of the feature space.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **idx**: `integer()`.\n\n  ID of the translation\n\n- **value**: `float`.\n\n  Value of the translation\n\n**Note**: \n       WEIGHT_IDX = 0;\n       X_IDX = 1;\n       Y_IDX = 2;\n       L_IDX = 3;\n       A_IDX = 4;\n       B_IDX = 5;\n       CONTRAST_IDX = 6;\n       ENTROPY_IDX = 7;\n\nPython prototype (for reference only):\n```python3\nsetTranslation(idx, value) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#setTranslation/3"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setTranslations/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#setTranslations/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setTranslations/2","doc":"Translations of the individual axes of the feature space.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **translations**: `[float]`.\n\n  Values of all translations.\n\n**Note**: \n       WEIGHT_IDX = 0;\n       X_IDX = 1;\n       Y_IDX = 2;\n       L_IDX = 3;\n       A_IDX = 4;\n       B_IDX = 5;\n       CONTRAST_IDX = 6;\n       ENTROPY_IDX = 7;\n\nPython prototype (for reference only):\n```python3\nsetTranslations(translations) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#setTranslations/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setWeight/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#setWeight/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setWeight/3","doc":"Weights (multiplicative constants) that linearly stretch individual axes of the feature space.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **idx**: `integer()`.\n\n  ID of the weight\n\n- **value**: `float`.\n\n  Value of the weight\n\n**Note**: \n       WEIGHT_IDX = 0;\n       X_IDX = 1;\n       Y_IDX = 2;\n       L_IDX = 3;\n       A_IDX = 4;\n       B_IDX = 5;\n       CONTRAST_IDX = 6;\n       ENTROPY_IDX = 7;\n\nPython prototype (for reference only):\n```python3\nsetWeight(idx, value) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#setWeight/3"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setWeightA/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#setWeightA/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setWeightA/2","doc":"Weights (multiplicative constants) that linearly stretch individual axes of the feature space\n(x,y = position; L,a,b = color in CIE Lab space; c = contrast. e = entropy)\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **weight**: `float`\n\nPython prototype (for reference only):\n```python3\nsetWeightA(weight) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#setWeightA/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setWeightB/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#setWeightB/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setWeightB/2","doc":"Weights (multiplicative constants) that linearly stretch individual axes of the feature space\n(x,y = position; L,a,b = color in CIE Lab space; c = contrast. e = entropy)\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **weight**: `float`\n\nPython prototype (for reference only):\n```python3\nsetWeightB(weight) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#setWeightB/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setWeightContrast/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#setWeightContrast/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setWeightContrast/2","doc":"Weights (multiplicative constants) that linearly stretch individual axes of the feature space\n(x,y = position; L,a,b = color in CIE Lab space; c = contrast. e = entropy)\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **weight**: `float`\n\nPython prototype (for reference only):\n```python3\nsetWeightContrast(weight) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#setWeightContrast/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setWeightEntropy/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#setWeightEntropy/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setWeightEntropy/2","doc":"Weights (multiplicative constants) that linearly stretch individual axes of the feature space\n(x,y = position; L,a,b = color in CIE Lab space; c = contrast. e = entropy)\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **weight**: `float`\n\nPython prototype (for reference only):\n```python3\nsetWeightEntropy(weight) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#setWeightEntropy/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setWeightL/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#setWeightL/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setWeightL/2","doc":"Weights (multiplicative constants) that linearly stretch individual axes of the feature space\n(x,y = position; L,a,b = color in CIE Lab space; c = contrast. e = entropy)\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **weight**: `float`\n\nPython prototype (for reference only):\n```python3\nsetWeightL(weight) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#setWeightL/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setWeights/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#setWeights/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setWeights/2","doc":"Weights (multiplicative constants) that linearly stretch individual axes of the feature space.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **weights**: `[float]`.\n\n  Values of all weights.\n\n**Note**: \n       WEIGHT_IDX = 0;\n       X_IDX = 1;\n       Y_IDX = 2;\n       L_IDX = 3;\n       A_IDX = 4;\n       B_IDX = 5;\n       CONTRAST_IDX = 6;\n       ENTROPY_IDX = 7;\n\nPython prototype (for reference only):\n```python3\nsetWeights(weights) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#setWeights/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setWeightX/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#setWeightX/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setWeightX/2","doc":"Weights (multiplicative constants) that linearly stretch individual axes of the feature space\n(x,y = position; L,a,b = color in CIE Lab space; c = contrast. e = entropy)\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **weight**: `float`\n\nPython prototype (for reference only):\n```python3\nsetWeightX(weight) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#setWeightX/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setWeightY/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#setWeightY/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setWeightY/2","doc":"Weights (multiplicative constants) that linearly stretch individual axes of the feature space\n(x,y = position; L,a,b = color in CIE Lab space; c = contrast. e = entropy)\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **weight**: `float`\n\nPython prototype (for reference only):\n```python3\nsetWeightY(weight) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#setWeightY/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setWindowRadius/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#setWindowRadius/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.setWindowRadius/2","doc":"Size of the texture sampling window used to compute contrast and entropy\n(center of the window is always in the pixel selected by x,y coordinates\nof the corresponding feature sample).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **radius**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetWindowRadius(radius) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#setWindowRadius/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.write/1","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.html#write/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#write/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignatures.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XFeatures2D.PCTSignatures.html#write/3"},{"type":"type","title":"Evision.XFeatures2D.PCTSignatures.t/0","doc":"Type that represents an `XFeatures2D.PCTSignatures` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XFeatures2D.PCTSignatures.html#t:t/0"},{"type":"module","title":"Evision.XFeatures2D.PCTSignatures.DistanceFunction","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.DistanceFunction.html"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.DistanceFunction.cv_L0_5/0","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.DistanceFunction.html#cv_L0_5/0"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.DistanceFunction.cv_L0_25/0","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.DistanceFunction.html#cv_L0_25/0"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.DistanceFunction.cv_L1/0","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.DistanceFunction.html#cv_L1/0"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.DistanceFunction.cv_L2/0","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.DistanceFunction.html#cv_L2/0"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.DistanceFunction.cv_L2SQUARED/0","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.DistanceFunction.html#cv_L2SQUARED/0"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.DistanceFunction.cv_L5/0","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.DistanceFunction.html#cv_L5/0"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.DistanceFunction.cv_L_INFINITY/0","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.DistanceFunction.html#cv_L_INFINITY/0"},{"type":"type","title":"Evision.XFeatures2D.PCTSignatures.DistanceFunction.enum/0","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.DistanceFunction.html#t:enum/0"},{"type":"module","title":"Evision.XFeatures2D.PCTSignatures.PointDistribution","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.PointDistribution.html"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.PointDistribution.cv_NORMAL/0","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.PointDistribution.html#cv_NORMAL/0"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.PointDistribution.cv_REGULAR/0","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.PointDistribution.html#cv_REGULAR/0"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.PointDistribution.cv_UNIFORM/0","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.PointDistribution.html#cv_UNIFORM/0"},{"type":"type","title":"Evision.XFeatures2D.PCTSignatures.PointDistribution.enum/0","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.PointDistribution.html#t:enum/0"},{"type":"module","title":"Evision.XFeatures2D.PCTSignatures.SimilarityFunction","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.SimilarityFunction.html"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.SimilarityFunction.cv_GAUSSIAN/0","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.SimilarityFunction.html#cv_GAUSSIAN/0"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.SimilarityFunction.cv_HEURISTIC/0","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.SimilarityFunction.html#cv_HEURISTIC/0"},{"type":"function","title":"Evision.XFeatures2D.PCTSignatures.SimilarityFunction.cv_MINUS/0","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.SimilarityFunction.html#cv_MINUS/0"},{"type":"type","title":"Evision.XFeatures2D.PCTSignatures.SimilarityFunction.enum/0","doc":"","ref":"Evision.XFeatures2D.PCTSignatures.SimilarityFunction.html#t:enum/0"},{"type":"module","title":"Evision.XFeatures2D.PCTSignaturesSQFD","doc":"","ref":"Evision.XFeatures2D.PCTSignaturesSQFD.html"},{"type":"function","title":"Evision.XFeatures2D.PCTSignaturesSQFD.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignaturesSQFD.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XFeatures2D.PCTSignaturesSQFD.html#clear/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignaturesSQFD.computeQuadraticFormDistance/1","doc":"","ref":"Evision.XFeatures2D.PCTSignaturesSQFD.html#computeQuadraticFormDistance/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignaturesSQFD.computeQuadraticFormDistance/3","doc":"Computes Signature Quadratic Form Distance of two signatures.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignaturesSQFD.t()`\n- **signature0**: `Evision.Mat`.\n\n  The first signature.\n\n- **signature1**: `Evision.Mat`.\n\n  The second signature.\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ncomputeQuadraticFormDistance(_signature0, _signature1) -> retval\n```","ref":"Evision.XFeatures2D.PCTSignaturesSQFD.html#computeQuadraticFormDistance/3"},{"type":"function","title":"Evision.XFeatures2D.PCTSignaturesSQFD.computeQuadraticFormDistances/1","doc":"","ref":"Evision.XFeatures2D.PCTSignaturesSQFD.html#computeQuadraticFormDistances/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignaturesSQFD.computeQuadraticFormDistances/4","doc":"Computes Signature Quadratic Form Distance between the reference signature\nand each of the other image signatures.\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignaturesSQFD.t()`\n- **sourceSignature**: `Evision.Mat`.\n\n  The signature to measure distance of other signatures from.\n\n- **imageSignatures**: `[Evision.Mat]`.\n\n  Vector of signatures to measure distance from the source signature.\n\n- **distances**: `[float]`.\n\n  Output vector of measured distances.\n\nPython prototype (for reference only):\n```python3\ncomputeQuadraticFormDistances(sourceSignature, imageSignatures, distances) -> None\n```","ref":"Evision.XFeatures2D.PCTSignaturesSQFD.html#computeQuadraticFormDistances/4"},{"type":"function","title":"Evision.XFeatures2D.PCTSignaturesSQFD.create/0","doc":"Creates the algorithm instance using selected distance function,\nsimilarity function and similarity function parameter.\n\n##### Keyword Arguments\n- **distanceFunction**: `integer()`.\n\n  Distance function selector. Default: L2\n  Available: L0_25, L0_5, L1, L2, L2SQUARED, L5, L_INFINITY\n\n- **similarityFunction**: `integer()`.\n\n  Similarity function selector. Default: HEURISTIC\n  Available: MINUS, GAUSSIAN, HEURISTIC\n\n- **similarityParameter**: `float`.\n\n  Parameter of the similarity function.\n\n##### Return\n- **retval**: `PCTSignaturesSQFD`\n\nPython prototype (for reference only):\n```python3\ncreate([, distanceFunction[, similarityFunction[, similarityParameter]]]) -> retval\n```","ref":"Evision.XFeatures2D.PCTSignaturesSQFD.html#create/0"},{"type":"function","title":"Evision.XFeatures2D.PCTSignaturesSQFD.create/1","doc":"Creates the algorithm instance using selected distance function,\nsimilarity function and similarity function parameter.\n\n##### Keyword Arguments\n- **distanceFunction**: `integer()`.\n\n  Distance function selector. Default: L2\n  Available: L0_25, L0_5, L1, L2, L2SQUARED, L5, L_INFINITY\n\n- **similarityFunction**: `integer()`.\n\n  Similarity function selector. Default: HEURISTIC\n  Available: MINUS, GAUSSIAN, HEURISTIC\n\n- **similarityParameter**: `float`.\n\n  Parameter of the similarity function.\n\n##### Return\n- **retval**: `PCTSignaturesSQFD`\n\nPython prototype (for reference only):\n```python3\ncreate([, distanceFunction[, similarityFunction[, similarityParameter]]]) -> retval\n```","ref":"Evision.XFeatures2D.PCTSignaturesSQFD.html#create/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignaturesSQFD.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignaturesSQFD.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XFeatures2D.PCTSignaturesSQFD.html#empty/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignaturesSQFD.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignaturesSQFD.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XFeatures2D.PCTSignaturesSQFD.html#getDefaultName/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignaturesSQFD.read/1","doc":"","ref":"Evision.XFeatures2D.PCTSignaturesSQFD.html#read/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignaturesSQFD.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignaturesSQFD.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XFeatures2D.PCTSignaturesSQFD.html#read/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignaturesSQFD.save/1","doc":"","ref":"Evision.XFeatures2D.PCTSignaturesSQFD.html#save/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignaturesSQFD.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignaturesSQFD.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XFeatures2D.PCTSignaturesSQFD.html#save/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignaturesSQFD.write/1","doc":"","ref":"Evision.XFeatures2D.PCTSignaturesSQFD.html#write/1"},{"type":"function","title":"Evision.XFeatures2D.PCTSignaturesSQFD.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignaturesSQFD.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XFeatures2D.PCTSignaturesSQFD.html#write/2"},{"type":"function","title":"Evision.XFeatures2D.PCTSignaturesSQFD.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.PCTSignaturesSQFD.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XFeatures2D.PCTSignaturesSQFD.html#write/3"},{"type":"type","title":"Evision.XFeatures2D.PCTSignaturesSQFD.t/0","doc":"Type that represents an `XFeatures2D.PCTSignaturesSQFD` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XFeatures2D.PCTSignaturesSQFD.html#t:t/0"},{"type":"module","title":"Evision.XFeatures2D.SURF","doc":"","ref":"Evision.XFeatures2D.SURF.html"},{"type":"function","title":"Evision.XFeatures2D.SURF.compute/1","doc":"","ref":"Evision.XFeatures2D.SURF.html#compute/1"},{"type":"function","title":"Evision.XFeatures2D.SURF.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.SURF.html#compute/3"},{"type":"function","title":"Evision.XFeatures2D.SURF.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.SURF.html#compute/4"},{"type":"function","title":"Evision.XFeatures2D.SURF.create/0","doc":"create\n##### Keyword Arguments\n- **hessianThreshold**: `double`.\n\n  Threshold for hessian keypoint detector used in SURF.\n\n- **nOctaves**: `integer()`.\n\n  Number of pyramid octaves the keypoint detector will use.\n\n- **nOctaveLayers**: `integer()`.\n\n  Number of octave layers within each octave.\n\n- **extended**: `bool`.\n\n  Extended descriptor flag (true - use extended 128-element descriptors; false - use\n  64-element descriptors).\n\n- **upright**: `bool`.\n\n  Up-right or rotated features flag (true - do not compute orientation of features;\n  false - compute orientation).\n\n##### Return\n- **retval**: `SURF`\n\nPython prototype (for reference only):\n```python3\ncreate([, hessianThreshold[, nOctaves[, nOctaveLayers[, extended[, upright]]]]]) -> retval\n```","ref":"Evision.XFeatures2D.SURF.html#create/0"},{"type":"function","title":"Evision.XFeatures2D.SURF.create/1","doc":"create\n##### Keyword Arguments\n- **hessianThreshold**: `double`.\n\n  Threshold for hessian keypoint detector used in SURF.\n\n- **nOctaves**: `integer()`.\n\n  Number of pyramid octaves the keypoint detector will use.\n\n- **nOctaveLayers**: `integer()`.\n\n  Number of octave layers within each octave.\n\n- **extended**: `bool`.\n\n  Extended descriptor flag (true - use extended 128-element descriptors; false - use\n  64-element descriptors).\n\n- **upright**: `bool`.\n\n  Up-right or rotated features flag (true - do not compute orientation of features;\n  false - compute orientation).\n\n##### Return\n- **retval**: `SURF`\n\nPython prototype (for reference only):\n```python3\ncreate([, hessianThreshold[, nOctaves[, nOctaveLayers[, extended[, upright]]]]]) -> retval\n```","ref":"Evision.XFeatures2D.SURF.html#create/1"},{"type":"function","title":"Evision.XFeatures2D.SURF.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.XFeatures2D.SURF.html#defaultNorm/1"},{"type":"function","title":"Evision.XFeatures2D.SURF.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.XFeatures2D.SURF.html#descriptorSize/1"},{"type":"function","title":"Evision.XFeatures2D.SURF.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.XFeatures2D.SURF.html#descriptorType/1"},{"type":"function","title":"Evision.XFeatures2D.SURF.detect/1","doc":"","ref":"Evision.XFeatures2D.SURF.html#detect/1"},{"type":"function","title":"Evision.XFeatures2D.SURF.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.SURF.html#detect/2"},{"type":"function","title":"Evision.XFeatures2D.SURF.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.SURF.html#detect/3"},{"type":"function","title":"Evision.XFeatures2D.SURF.detectAndCompute/1","doc":"","ref":"Evision.XFeatures2D.SURF.html#detectAndCompute/1"},{"type":"function","title":"Evision.XFeatures2D.SURF.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.SURF.html#detectAndCompute/3"},{"type":"function","title":"Evision.XFeatures2D.SURF.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.SURF.html#detectAndCompute/4"},{"type":"function","title":"Evision.XFeatures2D.SURF.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XFeatures2D.SURF.html#empty/1"},{"type":"function","title":"Evision.XFeatures2D.SURF.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XFeatures2D.SURF.html#getDefaultName/1"},{"type":"function","title":"Evision.XFeatures2D.SURF.getExtended/1","doc":"getExtended\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetExtended() -> retval\n```","ref":"Evision.XFeatures2D.SURF.html#getExtended/1"},{"type":"function","title":"Evision.XFeatures2D.SURF.getHessianThreshold/1","doc":"getHessianThreshold\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetHessianThreshold() -> retval\n```","ref":"Evision.XFeatures2D.SURF.html#getHessianThreshold/1"},{"type":"function","title":"Evision.XFeatures2D.SURF.getNOctaveLayers/1","doc":"getNOctaveLayers\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNOctaveLayers() -> retval\n```","ref":"Evision.XFeatures2D.SURF.html#getNOctaveLayers/1"},{"type":"function","title":"Evision.XFeatures2D.SURF.getNOctaves/1","doc":"getNOctaves\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNOctaves() -> retval\n```","ref":"Evision.XFeatures2D.SURF.html#getNOctaves/1"},{"type":"function","title":"Evision.XFeatures2D.SURF.getUpright/1","doc":"getUpright\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetUpright() -> retval\n```","ref":"Evision.XFeatures2D.SURF.html#getUpright/1"},{"type":"function","title":"Evision.XFeatures2D.SURF.read/1","doc":"","ref":"Evision.XFeatures2D.SURF.html#read/1"},{"type":"function","title":"Evision.XFeatures2D.SURF.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.XFeatures2D.SURF.html#read/2"},{"type":"function","title":"Evision.XFeatures2D.SURF.setExtended/1","doc":"","ref":"Evision.XFeatures2D.SURF.html#setExtended/1"},{"type":"function","title":"Evision.XFeatures2D.SURF.setExtended/2","doc":"setExtended\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n- **extended**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetExtended(extended) -> None\n```","ref":"Evision.XFeatures2D.SURF.html#setExtended/2"},{"type":"function","title":"Evision.XFeatures2D.SURF.setHessianThreshold/1","doc":"","ref":"Evision.XFeatures2D.SURF.html#setHessianThreshold/1"},{"type":"function","title":"Evision.XFeatures2D.SURF.setHessianThreshold/2","doc":"setHessianThreshold\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n- **hessianThreshold**: `double`\n\nPython prototype (for reference only):\n```python3\nsetHessianThreshold(hessianThreshold) -> None\n```","ref":"Evision.XFeatures2D.SURF.html#setHessianThreshold/2"},{"type":"function","title":"Evision.XFeatures2D.SURF.setNOctaveLayers/1","doc":"","ref":"Evision.XFeatures2D.SURF.html#setNOctaveLayers/1"},{"type":"function","title":"Evision.XFeatures2D.SURF.setNOctaveLayers/2","doc":"setNOctaveLayers\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n- **nOctaveLayers**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNOctaveLayers(nOctaveLayers) -> None\n```","ref":"Evision.XFeatures2D.SURF.html#setNOctaveLayers/2"},{"type":"function","title":"Evision.XFeatures2D.SURF.setNOctaves/1","doc":"","ref":"Evision.XFeatures2D.SURF.html#setNOctaves/1"},{"type":"function","title":"Evision.XFeatures2D.SURF.setNOctaves/2","doc":"setNOctaves\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n- **nOctaves**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNOctaves(nOctaves) -> None\n```","ref":"Evision.XFeatures2D.SURF.html#setNOctaves/2"},{"type":"function","title":"Evision.XFeatures2D.SURF.setUpright/1","doc":"","ref":"Evision.XFeatures2D.SURF.html#setUpright/1"},{"type":"function","title":"Evision.XFeatures2D.SURF.setUpright/2","doc":"setUpright\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n- **upright**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetUpright(upright) -> None\n```","ref":"Evision.XFeatures2D.SURF.html#setUpright/2"},{"type":"function","title":"Evision.XFeatures2D.SURF.write/1","doc":"","ref":"Evision.XFeatures2D.SURF.html#write/1"},{"type":"function","title":"Evision.XFeatures2D.SURF.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.XFeatures2D.SURF.html#write/2"},{"type":"function","title":"Evision.XFeatures2D.SURF.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.SURF.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XFeatures2D.SURF.html#write/3"},{"type":"type","title":"Evision.XFeatures2D.SURF.t/0","doc":"Type that represents an `XFeatures2D.SURF` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XFeatures2D.SURF.html#t:t/0"},{"type":"module","title":"Evision.XFeatures2D.StarDetector","doc":"","ref":"Evision.XFeatures2D.StarDetector.html"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.compute/1","doc":"","ref":"Evision.XFeatures2D.StarDetector.html#compute/1"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.StarDetector.html#compute/3"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.StarDetector.html#compute/4"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.create/0","doc":"create\n##### Keyword Arguments\n- **maxSize**: `integer()`.\n- **responseThreshold**: `integer()`.\n- **lineThresholdProjected**: `integer()`.\n- **lineThresholdBinarized**: `integer()`.\n- **suppressNonmaxSize**: `integer()`.\n\n##### Return\n- **retval**: `StarDetector`\n\nPython prototype (for reference only):\n```python3\ncreate([, maxSize[, responseThreshold[, lineThresholdProjected[, lineThresholdBinarized[, suppressNonmaxSize]]]]]) -> retval\n```","ref":"Evision.XFeatures2D.StarDetector.html#create/0"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.create/1","doc":"create\n##### Keyword Arguments\n- **maxSize**: `integer()`.\n- **responseThreshold**: `integer()`.\n- **lineThresholdProjected**: `integer()`.\n- **lineThresholdBinarized**: `integer()`.\n- **suppressNonmaxSize**: `integer()`.\n\n##### Return\n- **retval**: `StarDetector`\n\nPython prototype (for reference only):\n```python3\ncreate([, maxSize[, responseThreshold[, lineThresholdProjected[, lineThresholdBinarized[, suppressNonmaxSize]]]]]) -> retval\n```","ref":"Evision.XFeatures2D.StarDetector.html#create/1"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.XFeatures2D.StarDetector.html#defaultNorm/1"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.XFeatures2D.StarDetector.html#descriptorSize/1"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.XFeatures2D.StarDetector.html#descriptorType/1"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.detect/1","doc":"","ref":"Evision.XFeatures2D.StarDetector.html#detect/1"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.StarDetector.html#detect/2"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.StarDetector.html#detect/3"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.detectAndCompute/1","doc":"","ref":"Evision.XFeatures2D.StarDetector.html#detectAndCompute/1"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.StarDetector.html#detectAndCompute/3"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.StarDetector.html#detectAndCompute/4"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XFeatures2D.StarDetector.html#empty/1"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XFeatures2D.StarDetector.html#getDefaultName/1"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.getLineThresholdBinarized/1","doc":"getLineThresholdBinarized\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetLineThresholdBinarized() -> retval\n```","ref":"Evision.XFeatures2D.StarDetector.html#getLineThresholdBinarized/1"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.getLineThresholdProjected/1","doc":"getLineThresholdProjected\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetLineThresholdProjected() -> retval\n```","ref":"Evision.XFeatures2D.StarDetector.html#getLineThresholdProjected/1"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.getMaxSize/1","doc":"getMaxSize\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxSize() -> retval\n```","ref":"Evision.XFeatures2D.StarDetector.html#getMaxSize/1"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.getResponseThreshold/1","doc":"getResponseThreshold\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetResponseThreshold() -> retval\n```","ref":"Evision.XFeatures2D.StarDetector.html#getResponseThreshold/1"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.getSuppressNonmaxSize/1","doc":"getSuppressNonmaxSize\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetSuppressNonmaxSize() -> retval\n```","ref":"Evision.XFeatures2D.StarDetector.html#getSuppressNonmaxSize/1"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.read/1","doc":"","ref":"Evision.XFeatures2D.StarDetector.html#read/1"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.XFeatures2D.StarDetector.html#read/2"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.setLineThresholdBinarized/1","doc":"","ref":"Evision.XFeatures2D.StarDetector.html#setLineThresholdBinarized/1"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.setLineThresholdBinarized/2","doc":"setLineThresholdBinarized\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n- **lineThresholdBinarized**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetLineThresholdBinarized(_lineThresholdBinarized) -> None\n```","ref":"Evision.XFeatures2D.StarDetector.html#setLineThresholdBinarized/2"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.setLineThresholdProjected/1","doc":"","ref":"Evision.XFeatures2D.StarDetector.html#setLineThresholdProjected/1"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.setLineThresholdProjected/2","doc":"setLineThresholdProjected\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n- **lineThresholdProjected**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetLineThresholdProjected(_lineThresholdProjected) -> None\n```","ref":"Evision.XFeatures2D.StarDetector.html#setLineThresholdProjected/2"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.setMaxSize/1","doc":"","ref":"Evision.XFeatures2D.StarDetector.html#setMaxSize/1"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.setMaxSize/2","doc":"setMaxSize\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n- **maxSize**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxSize(_maxSize) -> None\n```","ref":"Evision.XFeatures2D.StarDetector.html#setMaxSize/2"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.setResponseThreshold/1","doc":"","ref":"Evision.XFeatures2D.StarDetector.html#setResponseThreshold/1"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.setResponseThreshold/2","doc":"setResponseThreshold\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n- **responseThreshold**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetResponseThreshold(_responseThreshold) -> None\n```","ref":"Evision.XFeatures2D.StarDetector.html#setResponseThreshold/2"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.setSuppressNonmaxSize/1","doc":"","ref":"Evision.XFeatures2D.StarDetector.html#setSuppressNonmaxSize/1"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.setSuppressNonmaxSize/2","doc":"setSuppressNonmaxSize\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n- **suppressNonmaxSize**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetSuppressNonmaxSize(_suppressNonmaxSize) -> None\n```","ref":"Evision.XFeatures2D.StarDetector.html#setSuppressNonmaxSize/2"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.write/1","doc":"","ref":"Evision.XFeatures2D.StarDetector.html#write/1"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.XFeatures2D.StarDetector.html#write/2"},{"type":"function","title":"Evision.XFeatures2D.StarDetector.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.StarDetector.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XFeatures2D.StarDetector.html#write/3"},{"type":"type","title":"Evision.XFeatures2D.StarDetector.t/0","doc":"Type that represents an `XFeatures2D.StarDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XFeatures2D.StarDetector.html#t:t/0"},{"type":"module","title":"Evision.XFeatures2D.TBMR","doc":"","ref":"Evision.XFeatures2D.TBMR.html"},{"type":"function","title":"Evision.XFeatures2D.TBMR.compute/1","doc":"","ref":"Evision.XFeatures2D.TBMR.html#compute/1"},{"type":"function","title":"Evision.XFeatures2D.TBMR.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.TBMR.html#compute/3"},{"type":"function","title":"Evision.XFeatures2D.TBMR.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.TBMR.html#compute/4"},{"type":"function","title":"Evision.XFeatures2D.TBMR.create/0","doc":"create\n##### Keyword Arguments\n- **min_area**: `integer()`.\n- **max_area_relative**: `float`.\n- **scale_factor**: `float`.\n- **n_scales**: `integer()`.\n\n##### Return\n- **retval**: `TBMR`\n\nPython prototype (for reference only):\n```python3\ncreate([, min_area[, max_area_relative[, scale_factor[, n_scales]]]]) -> retval\n```","ref":"Evision.XFeatures2D.TBMR.html#create/0"},{"type":"function","title":"Evision.XFeatures2D.TBMR.create/1","doc":"create\n##### Keyword Arguments\n- **min_area**: `integer()`.\n- **max_area_relative**: `float`.\n- **scale_factor**: `float`.\n- **n_scales**: `integer()`.\n\n##### Return\n- **retval**: `TBMR`\n\nPython prototype (for reference only):\n```python3\ncreate([, min_area[, max_area_relative[, scale_factor[, n_scales]]]]) -> retval\n```","ref":"Evision.XFeatures2D.TBMR.html#create/1"},{"type":"function","title":"Evision.XFeatures2D.TBMR.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.XFeatures2D.TBMR.html#defaultNorm/1"},{"type":"function","title":"Evision.XFeatures2D.TBMR.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.XFeatures2D.TBMR.html#descriptorSize/1"},{"type":"function","title":"Evision.XFeatures2D.TBMR.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.XFeatures2D.TBMR.html#descriptorType/1"},{"type":"function","title":"Evision.XFeatures2D.TBMR.detect/1","doc":"","ref":"Evision.XFeatures2D.TBMR.html#detect/1"},{"type":"function","title":"Evision.XFeatures2D.TBMR.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.TBMR.html#detect/2"},{"type":"function","title":"Evision.XFeatures2D.TBMR.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.TBMR.html#detect/3"},{"type":"function","title":"Evision.XFeatures2D.TBMR.detectAndCompute/1","doc":"","ref":"Evision.XFeatures2D.TBMR.html#detectAndCompute/1"},{"type":"function","title":"Evision.XFeatures2D.TBMR.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.TBMR.html#detectAndCompute/3"},{"type":"function","title":"Evision.XFeatures2D.TBMR.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.TBMR.html#detectAndCompute/4"},{"type":"function","title":"Evision.XFeatures2D.TBMR.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XFeatures2D.TBMR.html#empty/1"},{"type":"function","title":"Evision.XFeatures2D.TBMR.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XFeatures2D.TBMR.html#getDefaultName/1"},{"type":"function","title":"Evision.XFeatures2D.TBMR.getMaxAreaRelative/1","doc":"getMaxAreaRelative\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetMaxAreaRelative() -> retval\n```","ref":"Evision.XFeatures2D.TBMR.html#getMaxAreaRelative/1"},{"type":"function","title":"Evision.XFeatures2D.TBMR.getMinArea/1","doc":"getMinArea\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMinArea() -> retval\n```","ref":"Evision.XFeatures2D.TBMR.html#getMinArea/1"},{"type":"function","title":"Evision.XFeatures2D.TBMR.getNScales/1","doc":"getNScales\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNScales() -> retval\n```","ref":"Evision.XFeatures2D.TBMR.html#getNScales/1"},{"type":"function","title":"Evision.XFeatures2D.TBMR.getScaleFactor/1","doc":"getScaleFactor\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetScaleFactor() -> retval\n```","ref":"Evision.XFeatures2D.TBMR.html#getScaleFactor/1"},{"type":"function","title":"Evision.XFeatures2D.TBMR.read/1","doc":"","ref":"Evision.XFeatures2D.TBMR.html#read/1"},{"type":"function","title":"Evision.XFeatures2D.TBMR.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.XFeatures2D.TBMR.html#read/2"},{"type":"function","title":"Evision.XFeatures2D.TBMR.setMaxAreaRelative/1","doc":"","ref":"Evision.XFeatures2D.TBMR.html#setMaxAreaRelative/1"},{"type":"function","title":"Evision.XFeatures2D.TBMR.setMaxAreaRelative/2","doc":"setMaxAreaRelative\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n- **maxArea**: `float`\n\nPython prototype (for reference only):\n```python3\nsetMaxAreaRelative(maxArea) -> None\n```","ref":"Evision.XFeatures2D.TBMR.html#setMaxAreaRelative/2"},{"type":"function","title":"Evision.XFeatures2D.TBMR.setMinArea/1","doc":"","ref":"Evision.XFeatures2D.TBMR.html#setMinArea/1"},{"type":"function","title":"Evision.XFeatures2D.TBMR.setMinArea/2","doc":"setMinArea\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n- **minArea**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMinArea(minArea) -> None\n```","ref":"Evision.XFeatures2D.TBMR.html#setMinArea/2"},{"type":"function","title":"Evision.XFeatures2D.TBMR.setNScales/1","doc":"","ref":"Evision.XFeatures2D.TBMR.html#setNScales/1"},{"type":"function","title":"Evision.XFeatures2D.TBMR.setNScales/2","doc":"setNScales\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n- **n_scales**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetNScales(n_scales) -> None\n```","ref":"Evision.XFeatures2D.TBMR.html#setNScales/2"},{"type":"function","title":"Evision.XFeatures2D.TBMR.setScaleFactor/1","doc":"","ref":"Evision.XFeatures2D.TBMR.html#setScaleFactor/1"},{"type":"function","title":"Evision.XFeatures2D.TBMR.setScaleFactor/2","doc":"setScaleFactor\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n- **scale_factor**: `float`\n\nPython prototype (for reference only):\n```python3\nsetScaleFactor(scale_factor) -> None\n```","ref":"Evision.XFeatures2D.TBMR.html#setScaleFactor/2"},{"type":"function","title":"Evision.XFeatures2D.TBMR.write/1","doc":"","ref":"Evision.XFeatures2D.TBMR.html#write/1"},{"type":"function","title":"Evision.XFeatures2D.TBMR.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.XFeatures2D.TBMR.html#write/2"},{"type":"function","title":"Evision.XFeatures2D.TBMR.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TBMR.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XFeatures2D.TBMR.html#write/3"},{"type":"type","title":"Evision.XFeatures2D.TBMR.t/0","doc":"Type that represents an `XFeatures2D.TBMR` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XFeatures2D.TBMR.html#t:t/0"},{"type":"module","title":"Evision.XFeatures2D.TEBLID","doc":"","ref":"Evision.XFeatures2D.TEBLID.html"},{"type":"function","title":"Evision.XFeatures2D.TEBLID.compute/1","doc":"","ref":"Evision.XFeatures2D.TEBLID.html#compute/1"},{"type":"function","title":"Evision.XFeatures2D.TEBLID.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TEBLID.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TEBLID.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.TEBLID.html#compute/3"},{"type":"function","title":"Evision.XFeatures2D.TEBLID.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TEBLID.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TEBLID.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.TEBLID.html#compute/4"},{"type":"function","title":"Evision.XFeatures2D.TEBLID.create/1","doc":"Creates the TEBLID descriptor.\n\n##### Positional Arguments\n- **scale_factor**: `float`.\n\n  Adjust the sampling window around detected keypoints:\n  -   1.00f   should be the scale for ORB keypoints\n  -   6.75f   should be the scale for SIFT detected keypoints\n  -   6.25f   is default and fits for KAZE, SURF detected keypoints\n  -   5.00f   should be the scale for AKAZE, MSD, AGAST, FAST, BRISK keypoints\n\n##### Keyword Arguments\n- **n_bits**: `integer()`.\n\n  Determine the number of bits in the descriptor. Should be either\n  TEBLID::SIZE_256_BITS or TEBLID::SIZE_512_BITS.\n\n##### Return\n- **retval**: `TEBLID`\n\nPython prototype (for reference only):\n```python3\ncreate(scale_factor[, n_bits]) -> retval\n```","ref":"Evision.XFeatures2D.TEBLID.html#create/1"},{"type":"function","title":"Evision.XFeatures2D.TEBLID.create/2","doc":"Creates the TEBLID descriptor.\n\n##### Positional Arguments\n- **scale_factor**: `float`.\n\n  Adjust the sampling window around detected keypoints:\n  -   1.00f   should be the scale for ORB keypoints\n  -   6.75f   should be the scale for SIFT detected keypoints\n  -   6.25f   is default and fits for KAZE, SURF detected keypoints\n  -   5.00f   should be the scale for AKAZE, MSD, AGAST, FAST, BRISK keypoints\n\n##### Keyword Arguments\n- **n_bits**: `integer()`.\n\n  Determine the number of bits in the descriptor. Should be either\n  TEBLID::SIZE_256_BITS or TEBLID::SIZE_512_BITS.\n\n##### Return\n- **retval**: `TEBLID`\n\nPython prototype (for reference only):\n```python3\ncreate(scale_factor[, n_bits]) -> retval\n```","ref":"Evision.XFeatures2D.TEBLID.html#create/2"},{"type":"function","title":"Evision.XFeatures2D.TEBLID.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TEBLID.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.XFeatures2D.TEBLID.html#defaultNorm/1"},{"type":"function","title":"Evision.XFeatures2D.TEBLID.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TEBLID.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.XFeatures2D.TEBLID.html#descriptorSize/1"},{"type":"function","title":"Evision.XFeatures2D.TEBLID.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TEBLID.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.XFeatures2D.TEBLID.html#descriptorType/1"},{"type":"function","title":"Evision.XFeatures2D.TEBLID.detect/1","doc":"","ref":"Evision.XFeatures2D.TEBLID.html#detect/1"},{"type":"function","title":"Evision.XFeatures2D.TEBLID.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TEBLID.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TEBLID.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.TEBLID.html#detect/2"},{"type":"function","title":"Evision.XFeatures2D.TEBLID.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TEBLID.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TEBLID.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.TEBLID.html#detect/3"},{"type":"function","title":"Evision.XFeatures2D.TEBLID.detectAndCompute/1","doc":"","ref":"Evision.XFeatures2D.TEBLID.html#detectAndCompute/1"},{"type":"function","title":"Evision.XFeatures2D.TEBLID.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TEBLID.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.TEBLID.html#detectAndCompute/3"},{"type":"function","title":"Evision.XFeatures2D.TEBLID.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TEBLID.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.TEBLID.html#detectAndCompute/4"},{"type":"function","title":"Evision.XFeatures2D.TEBLID.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TEBLID.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XFeatures2D.TEBLID.html#empty/1"},{"type":"function","title":"Evision.XFeatures2D.TEBLID.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TEBLID.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XFeatures2D.TEBLID.html#getDefaultName/1"},{"type":"function","title":"Evision.XFeatures2D.TEBLID.read/1","doc":"","ref":"Evision.XFeatures2D.TEBLID.html#read/1"},{"type":"function","title":"Evision.XFeatures2D.TEBLID.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TEBLID.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TEBLID.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.XFeatures2D.TEBLID.html#read/2"},{"type":"function","title":"Evision.XFeatures2D.TEBLID.write/1","doc":"","ref":"Evision.XFeatures2D.TEBLID.html#write/1"},{"type":"function","title":"Evision.XFeatures2D.TEBLID.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TEBLID.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.XFeatures2D.TEBLID.html#write/2"},{"type":"function","title":"Evision.XFeatures2D.TEBLID.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.TEBLID.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XFeatures2D.TEBLID.html#write/3"},{"type":"type","title":"Evision.XFeatures2D.TEBLID.t/0","doc":"Type that represents an `XFeatures2D.TEBLID` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XFeatures2D.TEBLID.html#t:t/0"},{"type":"module","title":"Evision.XFeatures2D.TEBLID.TeblidSize","doc":"","ref":"Evision.XFeatures2D.TEBLID.TeblidSize.html"},{"type":"function","title":"Evision.XFeatures2D.TEBLID.TeblidSize.cv_SIZE_256_BITS/0","doc":"","ref":"Evision.XFeatures2D.TEBLID.TeblidSize.html#cv_SIZE_256_BITS/0"},{"type":"function","title":"Evision.XFeatures2D.TEBLID.TeblidSize.cv_SIZE_512_BITS/0","doc":"","ref":"Evision.XFeatures2D.TEBLID.TeblidSize.html#cv_SIZE_512_BITS/0"},{"type":"type","title":"Evision.XFeatures2D.TEBLID.TeblidSize.enum/0","doc":"","ref":"Evision.XFeatures2D.TEBLID.TeblidSize.html#t:enum/0"},{"type":"module","title":"Evision.XFeatures2D.VGG","doc":"","ref":"Evision.XFeatures2D.VGG.html"},{"type":"function","title":"Evision.XFeatures2D.VGG.compute/1","doc":"","ref":"Evision.XFeatures2D.VGG.html#compute/1"},{"type":"function","title":"Evision.XFeatures2D.VGG.compute/3","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.VGG.html#compute/3"},{"type":"function","title":"Evision.XFeatures2D.VGG.compute/4","doc":"#### Variant 1:\ncompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `[Evision.Mat]`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ncompute(images, keypoints[, descriptors]) -> keypoints, descriptors\n```\n#### Variant 2:\nComputes the descriptors for a set of keypoints detected in an image (first variant) or image set\n(second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  Input collection of keypoints. Keypoints for which a descriptor cannot be\n  computed are removed. Sometimes new keypoints can be added, for example: SIFT duplicates keypoint\n  with several dominant orientations (for each orientation).\n\n- **descriptors**: `Evision.Mat.t()`.\n\n  Computed descriptors. In the second variant of the method descriptors[i] are\n  descriptors computed for a keypoints[i]. Row j is the keypoints (or keypoints[i]) is the\n  descriptor for keypoint j-th keypoint.\n\nPython prototype (for reference only):\n```python3\ncompute(image, keypoints[, descriptors]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.VGG.html#compute/4"},{"type":"function","title":"Evision.XFeatures2D.VGG.create/0","doc":"create\n##### Keyword Arguments\n- **desc**: `integer()`.\n- **isigma**: `float`.\n- **img_normalize**: `bool`.\n- **use_scale_orientation**: `bool`.\n- **scale_factor**: `float`.\n- **dsc_normalize**: `bool`.\n\n##### Return\n- **retval**: `VGG`\n\nPython prototype (for reference only):\n```python3\ncreate([, desc[, isigma[, img_normalize[, use_scale_orientation[, scale_factor[, dsc_normalize]]]]]]) -> retval\n```","ref":"Evision.XFeatures2D.VGG.html#create/0"},{"type":"function","title":"Evision.XFeatures2D.VGG.create/1","doc":"create\n##### Keyword Arguments\n- **desc**: `integer()`.\n- **isigma**: `float`.\n- **img_normalize**: `bool`.\n- **use_scale_orientation**: `bool`.\n- **scale_factor**: `float`.\n- **dsc_normalize**: `bool`.\n\n##### Return\n- **retval**: `VGG`\n\nPython prototype (for reference only):\n```python3\ncreate([, desc[, isigma[, img_normalize[, use_scale_orientation[, scale_factor[, dsc_normalize]]]]]]) -> retval\n```","ref":"Evision.XFeatures2D.VGG.html#create/1"},{"type":"function","title":"Evision.XFeatures2D.VGG.defaultNorm/1","doc":"defaultNorm\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndefaultNorm() -> retval\n```","ref":"Evision.XFeatures2D.VGG.html#defaultNorm/1"},{"type":"function","title":"Evision.XFeatures2D.VGG.descriptorSize/1","doc":"descriptorSize\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorSize() -> retval\n```","ref":"Evision.XFeatures2D.VGG.html#descriptorSize/1"},{"type":"function","title":"Evision.XFeatures2D.VGG.descriptorType/1","doc":"descriptorType\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ndescriptorType() -> retval\n```","ref":"Evision.XFeatures2D.VGG.html#descriptorType/1"},{"type":"function","title":"Evision.XFeatures2D.VGG.detect/1","doc":"","ref":"Evision.XFeatures2D.VGG.html#detect/1"},{"type":"function","title":"Evision.XFeatures2D.VGG.detect/2","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.VGG.html#detect/2"},{"type":"function","title":"Evision.XFeatures2D.VGG.detect/3","doc":"#### Variant 1:\ndetect\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n- **images**: `[Evision.Mat]`.\n\n  Image set.\n\n##### Keyword Arguments\n- **masks**: `[Evision.Mat]`.\n\n  Masks for each input image specifying where to look for keypoints (optional).\n  masks[i] is a mask for images[i].\n\n##### Return\n- **keypoints**: `[[Evision.KeyPoint]]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\ndetect(images[, masks]) -> keypoints\n```\n#### Variant 2:\nDetects keypoints in an image (first variant) or image set (second variant).\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n- **image**: `Evision.Mat`.\n\n  Image.\n\n##### Keyword Arguments\n- **mask**: `Evision.Mat`.\n\n  Mask specifying where to look for keypoints (optional). It must be a 8-bit integer\n  matrix with non-zero values in the region of interest.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`.\n\n  The detected keypoints. In the second variant of the method keypoints[i] is a set\n  of keypoints detected in images[i] .\n\nPython prototype (for reference only):\n```python3\ndetect(image[, mask]) -> keypoints\n```","ref":"Evision.XFeatures2D.VGG.html#detect/3"},{"type":"function","title":"Evision.XFeatures2D.VGG.detectAndCompute/1","doc":"","ref":"Evision.XFeatures2D.VGG.html#detectAndCompute/1"},{"type":"function","title":"Evision.XFeatures2D.VGG.detectAndCompute/3","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.VGG.html#detectAndCompute/3"},{"type":"function","title":"Evision.XFeatures2D.VGG.detectAndCompute/4","doc":"detectAndCompute\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n- **image**: `Evision.Mat`\n- **mask**: `Evision.Mat`\n\n##### Keyword Arguments\n- **useProvidedKeypoints**: `bool`.\n\n##### Return\n- **keypoints**: `[Evision.KeyPoint]`\n- **descriptors**: `Evision.Mat.t()`.\n\nDetects keypoints and computes the descriptors\n\nPython prototype (for reference only):\n```python3\ndetectAndCompute(image, mask[, descriptors[, useProvidedKeypoints]]) -> keypoints, descriptors\n```","ref":"Evision.XFeatures2D.VGG.html#detectAndCompute/4"},{"type":"function","title":"Evision.XFeatures2D.VGG.empty/1","doc":"empty\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XFeatures2D.VGG.html#empty/1"},{"type":"function","title":"Evision.XFeatures2D.VGG.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n\n##### Return\n- **retval**: `String`\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XFeatures2D.VGG.html#getDefaultName/1"},{"type":"function","title":"Evision.XFeatures2D.VGG.getScaleFactor/1","doc":"getScaleFactor\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetScaleFactor() -> retval\n```","ref":"Evision.XFeatures2D.VGG.html#getScaleFactor/1"},{"type":"function","title":"Evision.XFeatures2D.VGG.getSigma/1","doc":"getSigma\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetSigma() -> retval\n```","ref":"Evision.XFeatures2D.VGG.html#getSigma/1"},{"type":"function","title":"Evision.XFeatures2D.VGG.getUseNormalizeDescriptor/1","doc":"getUseNormalizeDescriptor\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetUseNormalizeDescriptor() -> retval\n```","ref":"Evision.XFeatures2D.VGG.html#getUseNormalizeDescriptor/1"},{"type":"function","title":"Evision.XFeatures2D.VGG.getUseNormalizeImage/1","doc":"getUseNormalizeImage\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetUseNormalizeImage() -> retval\n```","ref":"Evision.XFeatures2D.VGG.html#getUseNormalizeImage/1"},{"type":"function","title":"Evision.XFeatures2D.VGG.getUseScaleOrientation/1","doc":"getUseScaleOrientation\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\ngetUseScaleOrientation() -> retval\n```","ref":"Evision.XFeatures2D.VGG.html#getUseScaleOrientation/1"},{"type":"function","title":"Evision.XFeatures2D.VGG.read/1","doc":"","ref":"Evision.XFeatures2D.VGG.html#read/1"},{"type":"function","title":"Evision.XFeatures2D.VGG.read/2","doc":"#### Variant 1:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n- **arg1**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(arg1) -> None\n```\n#### Variant 2:\nread\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nread(fileName) -> None\n```","ref":"Evision.XFeatures2D.VGG.html#read/2"},{"type":"function","title":"Evision.XFeatures2D.VGG.setScaleFactor/1","doc":"","ref":"Evision.XFeatures2D.VGG.html#setScaleFactor/1"},{"type":"function","title":"Evision.XFeatures2D.VGG.setScaleFactor/2","doc":"setScaleFactor\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n- **scale_factor**: `float`\n\nPython prototype (for reference only):\n```python3\nsetScaleFactor(scale_factor) -> None\n```","ref":"Evision.XFeatures2D.VGG.html#setScaleFactor/2"},{"type":"function","title":"Evision.XFeatures2D.VGG.setSigma/1","doc":"","ref":"Evision.XFeatures2D.VGG.html#setSigma/1"},{"type":"function","title":"Evision.XFeatures2D.VGG.setSigma/2","doc":"setSigma\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n- **isigma**: `float`\n\nPython prototype (for reference only):\n```python3\nsetSigma(isigma) -> None\n```","ref":"Evision.XFeatures2D.VGG.html#setSigma/2"},{"type":"function","title":"Evision.XFeatures2D.VGG.setUseNormalizeDescriptor/1","doc":"","ref":"Evision.XFeatures2D.VGG.html#setUseNormalizeDescriptor/1"},{"type":"function","title":"Evision.XFeatures2D.VGG.setUseNormalizeDescriptor/2","doc":"setUseNormalizeDescriptor\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n- **dsc_normalize**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetUseNormalizeDescriptor(dsc_normalize) -> None\n```","ref":"Evision.XFeatures2D.VGG.html#setUseNormalizeDescriptor/2"},{"type":"function","title":"Evision.XFeatures2D.VGG.setUseNormalizeImage/1","doc":"","ref":"Evision.XFeatures2D.VGG.html#setUseNormalizeImage/1"},{"type":"function","title":"Evision.XFeatures2D.VGG.setUseNormalizeImage/2","doc":"setUseNormalizeImage\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n- **img_normalize**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetUseNormalizeImage(img_normalize) -> None\n```","ref":"Evision.XFeatures2D.VGG.html#setUseNormalizeImage/2"},{"type":"function","title":"Evision.XFeatures2D.VGG.setUseScaleOrientation/1","doc":"","ref":"Evision.XFeatures2D.VGG.html#setUseScaleOrientation/1"},{"type":"function","title":"Evision.XFeatures2D.VGG.setUseScaleOrientation/2","doc":"setUseScaleOrientation\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n- **use_scale_orientation**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetUseScaleOrientation(use_scale_orientation) -> None\n```","ref":"Evision.XFeatures2D.VGG.html#setUseScaleOrientation/2"},{"type":"function","title":"Evision.XFeatures2D.VGG.write/1","doc":"","ref":"Evision.XFeatures2D.VGG.html#write/1"},{"type":"function","title":"Evision.XFeatures2D.VGG.write/2","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n- **fileName**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fileName) -> None\n```","ref":"Evision.XFeatures2D.VGG.html#write/2"},{"type":"function","title":"Evision.XFeatures2D.VGG.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XFeatures2D.VGG.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XFeatures2D.VGG.html#write/3"},{"type":"type","title":"Evision.XFeatures2D.VGG.t/0","doc":"Type that represents an `XFeatures2D.VGG` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XFeatures2D.VGG.html#t:t/0"},{"type":"module","title":"Evision.XImgProc","doc":"","ref":"Evision.XImgProc.html"},{"type":"function","title":"Evision.XImgProc.amFilter/1","doc":"","ref":"Evision.XImgProc.html#amFilter/1"},{"type":"function","title":"Evision.XImgProc.amFilter/4","doc":"Simple one-line Adaptive Manifold Filter call.\n\n##### Positional Arguments\n- **joint**: `Evision.Mat`.\n\n  joint (also called as guided) image or array of images with any numbers of channels.\n\n- **src**: `Evision.Mat`.\n\n  filtering image with any numbers of channels.\n\n- **sigma_s**: `double`.\n\n  spatial standard deviation.\n\n- **sigma_r**: `double`.\n\n  color space standard deviation, it is similar to the sigma in the color space into\n  bilateralFilter.\n\n##### Keyword Arguments\n- **adjust_outliers**: `bool`.\n\n  optional, specify perform outliers adjust operation or not, (Eq. 9) in the\n  original paper.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image.\n\n**Note**: Joint images with CV_8U and CV_16U depth converted to images with CV_32F depth and [0; 1]\ncolor range before processing. Hence color space sigma sigma_r must be in [0; 1] range, unlike same\nsigmas in bilateralFilter and dtFilter functions. @sa bilateralFilter, dtFilter, guidedFilter\n\nPython prototype (for reference only):\n```python3\namFilter(joint, src, sigma_s, sigma_r[, dst[, adjust_outliers]]) -> dst\n```","ref":"Evision.XImgProc.html#amFilter/4"},{"type":"function","title":"Evision.XImgProc.amFilter/5","doc":"Simple one-line Adaptive Manifold Filter call.\n\n##### Positional Arguments\n- **joint**: `Evision.Mat`.\n\n  joint (also called as guided) image or array of images with any numbers of channels.\n\n- **src**: `Evision.Mat`.\n\n  filtering image with any numbers of channels.\n\n- **sigma_s**: `double`.\n\n  spatial standard deviation.\n\n- **sigma_r**: `double`.\n\n  color space standard deviation, it is similar to the sigma in the color space into\n  bilateralFilter.\n\n##### Keyword Arguments\n- **adjust_outliers**: `bool`.\n\n  optional, specify perform outliers adjust operation or not, (Eq. 9) in the\n  original paper.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image.\n\n**Note**: Joint images with CV_8U and CV_16U depth converted to images with CV_32F depth and [0; 1]\ncolor range before processing. Hence color space sigma sigma_r must be in [0; 1] range, unlike same\nsigmas in bilateralFilter and dtFilter functions. @sa bilateralFilter, dtFilter, guidedFilter\n\nPython prototype (for reference only):\n```python3\namFilter(joint, src, sigma_s, sigma_r[, dst[, adjust_outliers]]) -> dst\n```","ref":"Evision.XImgProc.html#amFilter/5"},{"type":"function","title":"Evision.XImgProc.anisotropicDiffusion/1","doc":"","ref":"Evision.XImgProc.html#anisotropicDiffusion/1"},{"type":"function","title":"Evision.XImgProc.anisotropicDiffusion/4","doc":"Performs anisotropic diffusion on an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image with 3 channels.\n\n- **alpha**: `float`.\n\n  The amount of time to step forward by on each iteration (normally, it's between 0 and 1).\n\n- **k**: `float`.\n\n  sensitivity to the edges\n\n- **niters**: `integer()`.\n\n  The number of iterations\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and the same number of channels as src .\n\nThe function applies Perona-Malik anisotropic diffusion to an image. This is the solution to the partial differential equation:\n\\f[{\\frac  {\\partial I}{\\partial t}}={\\mathrm  {div}}\\left(c(x,y,t)\\nabla I\\right)=\\nabla c\\cdot \\nabla I+c(x,y,t)\\Delta I\\f]\nSuggested functions for c(x,y,t) are:\n\\f[c\\left(\\|\\nabla I\\|\\right)=e^{{-\\left(\\|\\nabla I\\|/K\\right)^{2}}}\\f]\nor\n\\f[ c\\left(\\|\\nabla I\\|\\right)={\\frac {1}{1+\\left({\\frac  {\\|\\nabla I\\|}{K}}\\right)^{2}}} \\f]\n\nPython prototype (for reference only):\n```python3\nanisotropicDiffusion(src, alpha, K, niters[, dst]) -> dst\n```","ref":"Evision.XImgProc.html#anisotropicDiffusion/4"},{"type":"function","title":"Evision.XImgProc.anisotropicDiffusion/5","doc":"Performs anisotropic diffusion on an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image with 3 channels.\n\n- **alpha**: `float`.\n\n  The amount of time to step forward by on each iteration (normally, it's between 0 and 1).\n\n- **k**: `float`.\n\n  sensitivity to the edges\n\n- **niters**: `integer()`.\n\n  The number of iterations\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and the same number of channels as src .\n\nThe function applies Perona-Malik anisotropic diffusion to an image. This is the solution to the partial differential equation:\n\\f[{\\frac  {\\partial I}{\\partial t}}={\\mathrm  {div}}\\left(c(x,y,t)\\nabla I\\right)=\\nabla c\\cdot \\nabla I+c(x,y,t)\\Delta I\\f]\nSuggested functions for c(x,y,t) are:\n\\f[c\\left(\\|\\nabla I\\|\\right)=e^{{-\\left(\\|\\nabla I\\|/K\\right)^{2}}}\\f]\nor\n\\f[ c\\left(\\|\\nabla I\\|\\right)={\\frac {1}{1+\\left({\\frac  {\\|\\nabla I\\|}{K}}\\right)^{2}}} \\f]\n\nPython prototype (for reference only):\n```python3\nanisotropicDiffusion(src, alpha, K, niters[, dst]) -> dst\n```","ref":"Evision.XImgProc.html#anisotropicDiffusion/5"},{"type":"function","title":"Evision.XImgProc.bilateralTextureFilter/1","doc":"Applies the bilateral texture filter to an image. It performs structure-preserving texture filter.\nFor more details about this filter see @cite Cho2014.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image whose depth is 8-bit UINT or 32-bit FLOAT\n\n##### Keyword Arguments\n- **fr**: `integer()`.\n\n  Radius of kernel to be used for filtering. It should be positive integer\n\n- **numIter**: `integer()`.\n\n  Number of iterations of algorithm, It should be positive integer\n\n- **sigmaAlpha**: `double`.\n\n  Controls the sharpness of the weight transition from edges to smooth/texture regions, where\n  a bigger value means sharper transition. When the value is negative, it is automatically calculated.\n\n- **sigmaAvg**: `double`.\n\n  Range blur parameter for texture blurring. Larger value makes result to be more blurred. When the\n  value is negative, it is automatically calculated as described in the paper.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and type as src.\n\n@sa rollingGuidanceFilter, bilateralFilter\n\nPython prototype (for reference only):\n```python3\nbilateralTextureFilter(src[, dst[, fr[, numIter[, sigmaAlpha[, sigmaAvg]]]]]) -> dst\n```","ref":"Evision.XImgProc.html#bilateralTextureFilter/1"},{"type":"function","title":"Evision.XImgProc.bilateralTextureFilter/2","doc":"Applies the bilateral texture filter to an image. It performs structure-preserving texture filter.\nFor more details about this filter see @cite Cho2014.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source image whose depth is 8-bit UINT or 32-bit FLOAT\n\n##### Keyword Arguments\n- **fr**: `integer()`.\n\n  Radius of kernel to be used for filtering. It should be positive integer\n\n- **numIter**: `integer()`.\n\n  Number of iterations of algorithm, It should be positive integer\n\n- **sigmaAlpha**: `double`.\n\n  Controls the sharpness of the weight transition from edges to smooth/texture regions, where\n  a bigger value means sharper transition. When the value is negative, it is automatically calculated.\n\n- **sigmaAvg**: `double`.\n\n  Range blur parameter for texture blurring. Larger value makes result to be more blurred. When the\n  value is negative, it is automatically calculated as described in the paper.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and type as src.\n\n@sa rollingGuidanceFilter, bilateralFilter\n\nPython prototype (for reference only):\n```python3\nbilateralTextureFilter(src[, dst[, fr[, numIter[, sigmaAlpha[, sigmaAvg]]]]]) -> dst\n```","ref":"Evision.XImgProc.html#bilateralTextureFilter/2"},{"type":"function","title":"Evision.XImgProc.colorMatchTemplate/1","doc":"","ref":"Evision.XImgProc.html#colorMatchTemplate/1"},{"type":"function","title":"Evision.XImgProc.colorMatchTemplate/2","doc":"Compares a color template against overlapped color image regions.\n\n##### Positional Arguments\n- **img**: `Evision.Mat`\n- **templ**: `Evision.Mat`\n\n##### Return\n- **result**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ncolorMatchTemplate(img, templ[, result]) -> result\n```","ref":"Evision.XImgProc.html#colorMatchTemplate/2"},{"type":"function","title":"Evision.XImgProc.colorMatchTemplate/3","doc":"Compares a color template against overlapped color image regions.\n\n##### Positional Arguments\n- **img**: `Evision.Mat`\n- **templ**: `Evision.Mat`\n\n##### Return\n- **result**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ncolorMatchTemplate(img, templ[, result]) -> result\n```","ref":"Evision.XImgProc.html#colorMatchTemplate/3"},{"type":"function","title":"Evision.XImgProc.computeBadPixelPercent/1","doc":"","ref":"Evision.XImgProc.html#computeBadPixelPercent/1"},{"type":"function","title":"Evision.XImgProc.computeBadPixelPercent/3","doc":"Function for computing the percent of \"bad\" pixels in the disparity map\n(pixels where error is higher than a specified threshold)\n\n##### Positional Arguments\n- **gT**: `Evision.Mat`.\n\n  ground truth disparity map\n\n- **src**: `Evision.Mat`.\n\n  disparity map to evaluate\n\n- **rOI**: `Rect`.\n\n  region of interest\n\n##### Keyword Arguments\n- **thresh**: `integer()`.\n\n  threshold used to determine \"bad\" pixels\n\n##### Return\n- **retval**: `double`\n\n@result returns mean square error between GT and src\n\nPython prototype (for reference only):\n```python3\ncomputeBadPixelPercent(GT, src, ROI[, thresh]) -> retval\n```","ref":"Evision.XImgProc.html#computeBadPixelPercent/3"},{"type":"function","title":"Evision.XImgProc.computeBadPixelPercent/4","doc":"Function for computing the percent of \"bad\" pixels in the disparity map\n(pixels where error is higher than a specified threshold)\n\n##### Positional Arguments\n- **gT**: `Evision.Mat`.\n\n  ground truth disparity map\n\n- **src**: `Evision.Mat`.\n\n  disparity map to evaluate\n\n- **rOI**: `Rect`.\n\n  region of interest\n\n##### Keyword Arguments\n- **thresh**: `integer()`.\n\n  threshold used to determine \"bad\" pixels\n\n##### Return\n- **retval**: `double`\n\n@result returns mean square error between GT and src\n\nPython prototype (for reference only):\n```python3\ncomputeBadPixelPercent(GT, src, ROI[, thresh]) -> retval\n```","ref":"Evision.XImgProc.html#computeBadPixelPercent/4"},{"type":"function","title":"Evision.XImgProc.computeMSE/1","doc":"","ref":"Evision.XImgProc.html#computeMSE/1"},{"type":"function","title":"Evision.XImgProc.computeMSE/3","doc":"Function for computing mean square error for disparity maps\n\n##### Positional Arguments\n- **gT**: `Evision.Mat`.\n\n  ground truth disparity map\n\n- **src**: `Evision.Mat`.\n\n  disparity map to evaluate\n\n- **rOI**: `Rect`.\n\n  region of interest\n\n##### Return\n- **retval**: `double`\n\n@result returns mean square error between GT and src\n\nPython prototype (for reference only):\n```python3\ncomputeMSE(GT, src, ROI) -> retval\n```","ref":"Evision.XImgProc.html#computeMSE/3"},{"type":"function","title":"Evision.XImgProc.contourSampling/1","doc":"","ref":"Evision.XImgProc.html#contourSampling/1"},{"type":"function","title":"Evision.XImgProc.contourSampling/2","doc":"Contour sampling .\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n- **nbElt**: `integer()`\n\n##### Return\n- **out**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ncontourSampling(src, nbElt[, out]) -> out\n```","ref":"Evision.XImgProc.html#contourSampling/2"},{"type":"function","title":"Evision.XImgProc.contourSampling/3","doc":"Contour sampling .\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n- **nbElt**: `integer()`\n\n##### Return\n- **out**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ncontourSampling(src, nbElt[, out]) -> out\n```","ref":"Evision.XImgProc.html#contourSampling/3"},{"type":"function","title":"Evision.XImgProc.covarianceEstimation/1","doc":"","ref":"Evision.XImgProc.html#covarianceEstimation/1"},{"type":"function","title":"Evision.XImgProc.covarianceEstimation/3","doc":"Computes the estimated covariance matrix of an image using the sliding\nwindow forumlation.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  The source image. Input image must be of a complex type.\n\n- **windowRows**: `integer()`.\n\n  The number of rows in the window.\n\n- **windowCols**: `integer()`.\n\n  The number of cols in the window.\n  The window size parameters control the accuracy of the estimation.\n  The sliding window moves over the entire image from the top-left corner\n  to the bottom right corner. Each location of the window represents a sample.\n  If the window is the size of the image, then this gives the exact covariance matrix.\n  For all other cases, the sizes of the window will impact the number of samples\n  and the number of elements in the estimated covariance matrix.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  The destination estimated covariance matrix. Output matrix will be size (windowRows*windowCols, windowRows*windowCols).\n\nPython prototype (for reference only):\n```python3\ncovarianceEstimation(src, windowRows, windowCols[, dst]) -> dst\n```","ref":"Evision.XImgProc.html#covarianceEstimation/3"},{"type":"function","title":"Evision.XImgProc.covarianceEstimation/4","doc":"Computes the estimated covariance matrix of an image using the sliding\nwindow forumlation.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  The source image. Input image must be of a complex type.\n\n- **windowRows**: `integer()`.\n\n  The number of rows in the window.\n\n- **windowCols**: `integer()`.\n\n  The number of cols in the window.\n  The window size parameters control the accuracy of the estimation.\n  The sliding window moves over the entire image from the top-left corner\n  to the bottom right corner. Each location of the window represents a sample.\n  If the window is the size of the image, then this gives the exact covariance matrix.\n  For all other cases, the sizes of the window will impact the number of samples\n  and the number of elements in the estimated covariance matrix.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  The destination estimated covariance matrix. Output matrix will be size (windowRows*windowCols, windowRows*windowCols).\n\nPython prototype (for reference only):\n```python3\ncovarianceEstimation(src, windowRows, windowCols[, dst]) -> dst\n```","ref":"Evision.XImgProc.html#covarianceEstimation/4"},{"type":"function","title":"Evision.XImgProc.createAMFilter/1","doc":"","ref":"Evision.XImgProc.html#createAMFilter/1"},{"type":"function","title":"Evision.XImgProc.createAMFilter/2","doc":"Factory method, create instance of AdaptiveManifoldFilter and produce some initialization routines.\n\n##### Positional Arguments\n- **sigma_s**: `double`.\n\n  spatial standard deviation.\n\n- **sigma_r**: `double`.\n\n  color space standard deviation, it is similar to the sigma in the color space into\n  bilateralFilter.\n\n##### Keyword Arguments\n- **adjust_outliers**: `bool`.\n\n  optional, specify perform outliers adjust operation or not, (Eq. 9) in the\n  original paper.\n\n##### Return\n- **retval**: `Evision.XImgProc.AdaptiveManifoldFilter.t()`\n\nFor more details about Adaptive Manifold Filter parameters, see the original article @cite Gastal12 .\n**Note**: Joint images with CV_8U and CV_16U depth converted to images with CV_32F depth and [0; 1]\ncolor range before processing. Hence color space sigma sigma_r must be in [0; 1] range, unlike same\nsigmas in bilateralFilter and dtFilter functions.\n\nPython prototype (for reference only):\n```python3\ncreateAMFilter(sigma_s, sigma_r[, adjust_outliers]) -> retval\n```","ref":"Evision.XImgProc.html#createAMFilter/2"},{"type":"function","title":"Evision.XImgProc.createAMFilter/3","doc":"Factory method, create instance of AdaptiveManifoldFilter and produce some initialization routines.\n\n##### Positional Arguments\n- **sigma_s**: `double`.\n\n  spatial standard deviation.\n\n- **sigma_r**: `double`.\n\n  color space standard deviation, it is similar to the sigma in the color space into\n  bilateralFilter.\n\n##### Keyword Arguments\n- **adjust_outliers**: `bool`.\n\n  optional, specify perform outliers adjust operation or not, (Eq. 9) in the\n  original paper.\n\n##### Return\n- **retval**: `Evision.XImgProc.AdaptiveManifoldFilter.t()`\n\nFor more details about Adaptive Manifold Filter parameters, see the original article @cite Gastal12 .\n**Note**: Joint images with CV_8U and CV_16U depth converted to images with CV_32F depth and [0; 1]\ncolor range before processing. Hence color space sigma sigma_r must be in [0; 1] range, unlike same\nsigmas in bilateralFilter and dtFilter functions.\n\nPython prototype (for reference only):\n```python3\ncreateAMFilter(sigma_s, sigma_r[, adjust_outliers]) -> retval\n```","ref":"Evision.XImgProc.html#createAMFilter/3"},{"type":"function","title":"Evision.XImgProc.createContourFitting/0","doc":"create ContourFitting algorithm object\n##### Keyword Arguments\n- **ctr**: `integer()`.\n\n  number of Fourier descriptors equal to number of contour points after resampling.\n\n- **fd**: `integer()`.\n\n  Contour defining second shape (Target).\n\n##### Return\n- **retval**: `Evision.XImgProc.ContourFitting.t()`\n\nPython prototype (for reference only):\n```python3\ncreateContourFitting([, ctr[, fd]]) -> retval\n```","ref":"Evision.XImgProc.html#createContourFitting/0"},{"type":"function","title":"Evision.XImgProc.createContourFitting/1","doc":"create ContourFitting algorithm object\n##### Keyword Arguments\n- **ctr**: `integer()`.\n\n  number of Fourier descriptors equal to number of contour points after resampling.\n\n- **fd**: `integer()`.\n\n  Contour defining second shape (Target).\n\n##### Return\n- **retval**: `Evision.XImgProc.ContourFitting.t()`\n\nPython prototype (for reference only):\n```python3\ncreateContourFitting([, ctr[, fd]]) -> retval\n```","ref":"Evision.XImgProc.html#createContourFitting/1"},{"type":"function","title":"Evision.XImgProc.createDisparityWLSFilter/1","doc":"Convenience factory method that creates an instance of DisparityWLSFilter and sets up all the relevant\nfilter parameters automatically based on the matcher instance. Currently supports only StereoBM and StereoSGBM.\n\n##### Positional Arguments\n- **matcher_left**: `Evision.StereoMatcher`.\n\n  stereo matcher instance that will be used with the filter\n\n##### Return\n- **retval**: `Evision.XImgProc.DisparityWLSFilter.t()`\n\nPython prototype (for reference only):\n```python3\ncreateDisparityWLSFilter(matcher_left) -> retval\n```","ref":"Evision.XImgProc.html#createDisparityWLSFilter/1"},{"type":"function","title":"Evision.XImgProc.createDisparityWLSFilterGeneric/1","doc":"More generic factory method, create instance of DisparityWLSFilter and execute basic\ninitialization routines. When using this method you will need to set-up the ROI, matchers and\nother parameters by yourself.\n\n##### Positional Arguments\n- **use_confidence**: `bool`.\n\n  filtering with confidence requires two disparity maps (for the left and right views) and is\n  approximately two times slower. However, quality is typically significantly better.\n\n##### Return\n- **retval**: `Evision.XImgProc.DisparityWLSFilter.t()`\n\nPython prototype (for reference only):\n```python3\ncreateDisparityWLSFilterGeneric(use_confidence) -> retval\n```","ref":"Evision.XImgProc.html#createDisparityWLSFilterGeneric/1"},{"type":"function","title":"Evision.XImgProc.createDTFilter/1","doc":"","ref":"Evision.XImgProc.html#createDTFilter/1"},{"type":"function","title":"Evision.XImgProc.createDTFilter/3","doc":"Factory method, create instance of DTFilter and produce initialization routines.\n\n##### Positional Arguments\n- **guide**: `Evision.Mat`.\n\n  guided image (used to build transformed distance, which describes edge structure of\n  guided image).\n\n- **sigmaSpatial**: `double`.\n\n  \\f${\\sigma}_H\\f$ parameter in the original article, it's similar to the sigma in the\n  coordinate space into bilateralFilter.\n\n- **sigmaColor**: `double`.\n\n  \\f${\\sigma}_r\\f$ parameter in the original article, it's similar to the sigma in the\n  color space into bilateralFilter.\n\n##### Keyword Arguments\n- **mode**: `integer()`.\n\n  one form three modes DTF_NC, DTF_RF and DTF_IC which corresponds to three modes for\n  filtering 2D signals in the article.\n\n- **numIters**: `integer()`.\n\n  optional number of iterations used for filtering, 3 is quite enough.\n\n##### Return\n- **retval**: `Evision.XImgProc.DTFilter.t()`\n\nFor more details about Domain Transform filter parameters, see the original article @cite Gastal11 and\n[Domain Transform filter homepage](http://www.inf.ufrgs.br/~eslgastal/DomainTransform/).\n\nPython prototype (for reference only):\n```python3\ncreateDTFilter(guide, sigmaSpatial, sigmaColor[, mode[, numIters]]) -> retval\n```","ref":"Evision.XImgProc.html#createDTFilter/3"},{"type":"function","title":"Evision.XImgProc.createDTFilter/4","doc":"Factory method, create instance of DTFilter and produce initialization routines.\n\n##### Positional Arguments\n- **guide**: `Evision.Mat`.\n\n  guided image (used to build transformed distance, which describes edge structure of\n  guided image).\n\n- **sigmaSpatial**: `double`.\n\n  \\f${\\sigma}_H\\f$ parameter in the original article, it's similar to the sigma in the\n  coordinate space into bilateralFilter.\n\n- **sigmaColor**: `double`.\n\n  \\f${\\sigma}_r\\f$ parameter in the original article, it's similar to the sigma in the\n  color space into bilateralFilter.\n\n##### Keyword Arguments\n- **mode**: `integer()`.\n\n  one form three modes DTF_NC, DTF_RF and DTF_IC which corresponds to three modes for\n  filtering 2D signals in the article.\n\n- **numIters**: `integer()`.\n\n  optional number of iterations used for filtering, 3 is quite enough.\n\n##### Return\n- **retval**: `Evision.XImgProc.DTFilter.t()`\n\nFor more details about Domain Transform filter parameters, see the original article @cite Gastal11 and\n[Domain Transform filter homepage](http://www.inf.ufrgs.br/~eslgastal/DomainTransform/).\n\nPython prototype (for reference only):\n```python3\ncreateDTFilter(guide, sigmaSpatial, sigmaColor[, mode[, numIters]]) -> retval\n```","ref":"Evision.XImgProc.html#createDTFilter/4"},{"type":"function","title":"Evision.XImgProc.createEdgeAwareInterpolator/0","doc":"Factory method that creates an instance of the\nEdgeAwareInterpolator.\n\n##### Return\n- **retval**: `Evision.XImgProc.EdgeAwareInterpolator.t()`\n\nPython prototype (for reference only):\n```python3\ncreateEdgeAwareInterpolator() -> retval\n```","ref":"Evision.XImgProc.html#createEdgeAwareInterpolator/0"},{"type":"function","title":"Evision.XImgProc.createEdgeAwareInterpolator/1","doc":"","ref":"Evision.XImgProc.html#createEdgeAwareInterpolator/1"},{"type":"function","title":"Evision.XImgProc.createEdgeBoxes/0","doc":"Creates a Edgeboxes\n##### Keyword Arguments\n- **alpha**: `float`.\n\n  step size of sliding window search.\n\n- **beta**: `float`.\n\n  nms threshold for object proposals.\n\n- **eta**: `float`.\n\n  adaptation rate for nms threshold.\n\n- **minScore**: `float`.\n\n  min score of boxes to detect.\n\n- **maxBoxes**: `integer()`.\n\n  max number of boxes to detect.\n\n- **edgeMinMag**: `float`.\n\n  edge min magnitude. Increase to trade off accuracy for speed.\n\n- **edgeMergeThr**: `float`.\n\n  edge merge threshold. Increase to trade off accuracy for speed.\n\n- **clusterMinMag**: `float`.\n\n  cluster min magnitude. Increase to trade off accuracy for speed.\n\n- **maxAspectRatio**: `float`.\n\n  max aspect ratio of boxes.\n\n- **minBoxArea**: `float`.\n\n  minimum area of boxes.\n\n- **gamma**: `float`.\n\n  affinity sensitivity.\n\n- **kappa**: `float`.\n\n  scale sensitivity.\n\n##### Return\n- **retval**: `Evision.XImgProc.EdgeBoxes.t()`\n\nPython prototype (for reference only):\n```python3\ncreateEdgeBoxes([, alpha[, beta[, eta[, minScore[, maxBoxes[, edgeMinMag[, edgeMergeThr[, clusterMinMag[, maxAspectRatio[, minBoxArea[, gamma[, kappa]]]]]]]]]]]]) -> retval\n```","ref":"Evision.XImgProc.html#createEdgeBoxes/0"},{"type":"function","title":"Evision.XImgProc.createEdgeBoxes/1","doc":"Creates a Edgeboxes\n##### Keyword Arguments\n- **alpha**: `float`.\n\n  step size of sliding window search.\n\n- **beta**: `float`.\n\n  nms threshold for object proposals.\n\n- **eta**: `float`.\n\n  adaptation rate for nms threshold.\n\n- **minScore**: `float`.\n\n  min score of boxes to detect.\n\n- **maxBoxes**: `integer()`.\n\n  max number of boxes to detect.\n\n- **edgeMinMag**: `float`.\n\n  edge min magnitude. Increase to trade off accuracy for speed.\n\n- **edgeMergeThr**: `float`.\n\n  edge merge threshold. Increase to trade off accuracy for speed.\n\n- **clusterMinMag**: `float`.\n\n  cluster min magnitude. Increase to trade off accuracy for speed.\n\n- **maxAspectRatio**: `float`.\n\n  max aspect ratio of boxes.\n\n- **minBoxArea**: `float`.\n\n  minimum area of boxes.\n\n- **gamma**: `float`.\n\n  affinity sensitivity.\n\n- **kappa**: `float`.\n\n  scale sensitivity.\n\n##### Return\n- **retval**: `Evision.XImgProc.EdgeBoxes.t()`\n\nPython prototype (for reference only):\n```python3\ncreateEdgeBoxes([, alpha[, beta[, eta[, minScore[, maxBoxes[, edgeMinMag[, edgeMergeThr[, clusterMinMag[, maxAspectRatio[, minBoxArea[, gamma[, kappa]]]]]]]]]]]]) -> retval\n```","ref":"Evision.XImgProc.html#createEdgeBoxes/1"},{"type":"function","title":"Evision.XImgProc.createEdgeDrawing/0","doc":"Creates a smart pointer to a EdgeDrawing object and initializes it\n##### Return\n- **retval**: `Evision.XImgProc.EdgeDrawing.t()`\n\nPython prototype (for reference only):\n```python3\ncreateEdgeDrawing() -> retval\n```","ref":"Evision.XImgProc.html#createEdgeDrawing/0"},{"type":"function","title":"Evision.XImgProc.createEdgeDrawing/1","doc":"","ref":"Evision.XImgProc.html#createEdgeDrawing/1"},{"type":"function","title":"Evision.XImgProc.createFastBilateralSolverFilter/1","doc":"","ref":"Evision.XImgProc.html#createFastBilateralSolverFilter/1"},{"type":"function","title":"Evision.XImgProc.createFastBilateralSolverFilter/4","doc":"Factory method, create instance of FastBilateralSolverFilter and execute the initialization routines.\n\n##### Positional Arguments\n- **guide**: `Evision.Mat`.\n\n  image serving as guide for filtering. It should have 8-bit depth and either 1 or 3 channels.\n\n- **sigma_spatial**: `double`.\n\n  parameter, that is similar to spatial space sigma (bandwidth) in bilateralFilter.\n\n- **sigma_luma**: `double`.\n\n  parameter, that is similar to luma space sigma (bandwidth) in bilateralFilter.\n\n- **sigma_chroma**: `double`.\n\n  parameter, that is similar to chroma space sigma (bandwidth) in bilateralFilter.\n\n##### Keyword Arguments\n- **lambda**: `double`.\n\n  smoothness strength parameter for solver.\n\n- **num_iter**: `integer()`.\n\n  number of iterations used for solver, 25 is usually enough.\n\n- **max_tol**: `double`.\n\n  convergence tolerance used for solver.\n\n##### Return\n- **retval**: `Evision.XImgProc.FastBilateralSolverFilter.t()`\n\nFor more details about the Fast Bilateral Solver parameters, see the original paper @cite BarronPoole2016.\n\nPython prototype (for reference only):\n```python3\ncreateFastBilateralSolverFilter(guide, sigma_spatial, sigma_luma, sigma_chroma[, lambda[, num_iter[, max_tol]]]) -> retval\n```","ref":"Evision.XImgProc.html#createFastBilateralSolverFilter/4"},{"type":"function","title":"Evision.XImgProc.createFastBilateralSolverFilter/5","doc":"Factory method, create instance of FastBilateralSolverFilter and execute the initialization routines.\n\n##### Positional Arguments\n- **guide**: `Evision.Mat`.\n\n  image serving as guide for filtering. It should have 8-bit depth and either 1 or 3 channels.\n\n- **sigma_spatial**: `double`.\n\n  parameter, that is similar to spatial space sigma (bandwidth) in bilateralFilter.\n\n- **sigma_luma**: `double`.\n\n  parameter, that is similar to luma space sigma (bandwidth) in bilateralFilter.\n\n- **sigma_chroma**: `double`.\n\n  parameter, that is similar to chroma space sigma (bandwidth) in bilateralFilter.\n\n##### Keyword Arguments\n- **lambda**: `double`.\n\n  smoothness strength parameter for solver.\n\n- **num_iter**: `integer()`.\n\n  number of iterations used for solver, 25 is usually enough.\n\n- **max_tol**: `double`.\n\n  convergence tolerance used for solver.\n\n##### Return\n- **retval**: `Evision.XImgProc.FastBilateralSolverFilter.t()`\n\nFor more details about the Fast Bilateral Solver parameters, see the original paper @cite BarronPoole2016.\n\nPython prototype (for reference only):\n```python3\ncreateFastBilateralSolverFilter(guide, sigma_spatial, sigma_luma, sigma_chroma[, lambda[, num_iter[, max_tol]]]) -> retval\n```","ref":"Evision.XImgProc.html#createFastBilateralSolverFilter/5"},{"type":"function","title":"Evision.XImgProc.createFastGlobalSmootherFilter/1","doc":"","ref":"Evision.XImgProc.html#createFastGlobalSmootherFilter/1"},{"type":"function","title":"Evision.XImgProc.createFastGlobalSmootherFilter/3","doc":"Factory method, create instance of FastGlobalSmootherFilter and execute the initialization routines.\n\n##### Positional Arguments\n- **guide**: `Evision.Mat`.\n\n  image serving as guide for filtering. It should have 8-bit depth and either 1 or 3 channels.\n\n- **lambda**: `double`.\n\n  parameter defining the amount of regularization\n\n- **sigma_color**: `double`.\n\n  parameter, that is similar to color space sigma in bilateralFilter.\n\n##### Keyword Arguments\n- **lambda_attenuation**: `double`.\n\n  internal parameter, defining how much lambda decreases after each iteration. Normally,\n  it should be 0.25. Setting it to 1.0 may lead to streaking artifacts.\n\n- **num_iter**: `integer()`.\n\n  number of iterations used for filtering, 3 is usually enough.\n\n##### Return\n- **retval**: `Evision.XImgProc.FastGlobalSmootherFilter.t()`\n\nFor more details about Fast Global Smoother parameters, see the original paper @cite Min2014. However, please note that\nthere are several differences. Lambda attenuation described in the paper is implemented a bit differently so do not\nexpect the results to be identical to those from the paper; sigma_color values from the paper should be multiplied by 255.0 to\nachieve the same effect. Also, in case of image filtering where source and guide image are the same, authors\npropose to dynamically update the guide image after each iteration. To maximize the performance this feature\nwas not implemented here.\n\nPython prototype (for reference only):\n```python3\ncreateFastGlobalSmootherFilter(guide, lambda, sigma_color[, lambda_attenuation[, num_iter]]) -> retval\n```","ref":"Evision.XImgProc.html#createFastGlobalSmootherFilter/3"},{"type":"function","title":"Evision.XImgProc.createFastGlobalSmootherFilter/4","doc":"Factory method, create instance of FastGlobalSmootherFilter and execute the initialization routines.\n\n##### Positional Arguments\n- **guide**: `Evision.Mat`.\n\n  image serving as guide for filtering. It should have 8-bit depth and either 1 or 3 channels.\n\n- **lambda**: `double`.\n\n  parameter defining the amount of regularization\n\n- **sigma_color**: `double`.\n\n  parameter, that is similar to color space sigma in bilateralFilter.\n\n##### Keyword Arguments\n- **lambda_attenuation**: `double`.\n\n  internal parameter, defining how much lambda decreases after each iteration. Normally,\n  it should be 0.25. Setting it to 1.0 may lead to streaking artifacts.\n\n- **num_iter**: `integer()`.\n\n  number of iterations used for filtering, 3 is usually enough.\n\n##### Return\n- **retval**: `Evision.XImgProc.FastGlobalSmootherFilter.t()`\n\nFor more details about Fast Global Smoother parameters, see the original paper @cite Min2014. However, please note that\nthere are several differences. Lambda attenuation described in the paper is implemented a bit differently so do not\nexpect the results to be identical to those from the paper; sigma_color values from the paper should be multiplied by 255.0 to\nachieve the same effect. Also, in case of image filtering where source and guide image are the same, authors\npropose to dynamically update the guide image after each iteration. To maximize the performance this feature\nwas not implemented here.\n\nPython prototype (for reference only):\n```python3\ncreateFastGlobalSmootherFilter(guide, lambda, sigma_color[, lambda_attenuation[, num_iter]]) -> retval\n```","ref":"Evision.XImgProc.html#createFastGlobalSmootherFilter/4"},{"type":"function","title":"Evision.XImgProc.createFastLineDetector/0","doc":"Creates a smart pointer to a FastLineDetector object and initializes it\n##### Keyword Arguments\n- **length_threshold**: `integer()`.\n\n  Segment shorter than this will be discarded\n\n- **distance_threshold**: `float`.\n\n  A point placed from a hypothesis line\n  segment farther than this will be regarded as an outlier\n\n- **canny_th1**: `double`.\n\n  First threshold for hysteresis procedure in Canny()\n\n- **canny_th2**: `double`.\n\n  Second threshold for hysteresis procedure in Canny()\n\n- **canny_aperture_size**: `integer()`.\n\n  Aperturesize for the sobel operator in Canny().\n  If zero, Canny() is not applied and the input image is taken as an edge image.\n\n- **do_merge**: `bool`.\n\n  If true, incremental merging of segments will be performed\n\n##### Return\n- **retval**: `Evision.XImgProc.FastLineDetector.t()`\n\nPython prototype (for reference only):\n```python3\ncreateFastLineDetector([, length_threshold[, distance_threshold[, canny_th1[, canny_th2[, canny_aperture_size[, do_merge]]]]]]) -> retval\n```","ref":"Evision.XImgProc.html#createFastLineDetector/0"},{"type":"function","title":"Evision.XImgProc.createFastLineDetector/1","doc":"Creates a smart pointer to a FastLineDetector object and initializes it\n##### Keyword Arguments\n- **length_threshold**: `integer()`.\n\n  Segment shorter than this will be discarded\n\n- **distance_threshold**: `float`.\n\n  A point placed from a hypothesis line\n  segment farther than this will be regarded as an outlier\n\n- **canny_th1**: `double`.\n\n  First threshold for hysteresis procedure in Canny()\n\n- **canny_th2**: `double`.\n\n  Second threshold for hysteresis procedure in Canny()\n\n- **canny_aperture_size**: `integer()`.\n\n  Aperturesize for the sobel operator in Canny().\n  If zero, Canny() is not applied and the input image is taken as an edge image.\n\n- **do_merge**: `bool`.\n\n  If true, incremental merging of segments will be performed\n\n##### Return\n- **retval**: `Evision.XImgProc.FastLineDetector.t()`\n\nPython prototype (for reference only):\n```python3\ncreateFastLineDetector([, length_threshold[, distance_threshold[, canny_th1[, canny_th2[, canny_aperture_size[, do_merge]]]]]]) -> retval\n```","ref":"Evision.XImgProc.html#createFastLineDetector/1"},{"type":"function","title":"Evision.XImgProc.createGraphSegmentation/0","doc":"Creates a graph based segmentor\n##### Keyword Arguments\n- **sigma**: `double`.\n\n  The sigma parameter, used to smooth image\n\n- **k**: `float`.\n\n  The k parameter of the algorythm\n\n- **min_size**: `integer()`.\n\n  The minimum size of segments\n\n##### Return\n- **retval**: `Evision.XImgProc.GraphSegmentation.t()`\n\nPython prototype (for reference only):\n```python3\ncreateGraphSegmentation([, sigma[, k[, min_size]]]) -> retval\n```","ref":"Evision.XImgProc.html#createGraphSegmentation/0"},{"type":"function","title":"Evision.XImgProc.createGraphSegmentation/1","doc":"Creates a graph based segmentor\n##### Keyword Arguments\n- **sigma**: `double`.\n\n  The sigma parameter, used to smooth image\n\n- **k**: `float`.\n\n  The k parameter of the algorythm\n\n- **min_size**: `integer()`.\n\n  The minimum size of segments\n\n##### Return\n- **retval**: `Evision.XImgProc.GraphSegmentation.t()`\n\nPython prototype (for reference only):\n```python3\ncreateGraphSegmentation([, sigma[, k[, min_size]]]) -> retval\n```","ref":"Evision.XImgProc.html#createGraphSegmentation/1"},{"type":"function","title":"Evision.XImgProc.createGuidedFilter/1","doc":"","ref":"Evision.XImgProc.html#createGuidedFilter/1"},{"type":"function","title":"Evision.XImgProc.createGuidedFilter/3","doc":"Factory method, create instance of GuidedFilter and produce initialization routines.\n\n##### Positional Arguments\n- **guide**: `Evision.Mat`.\n\n  guided image (or array of images) with up to 3 channels, if it have more then 3\n  channels then only first 3 channels will be used.\n\n- **radius**: `integer()`.\n\n  radius of Guided Filter.\n\n- **eps**: `double`.\n\n  regularization term of Guided Filter. \\f${eps}^2\\f$ is similar to the sigma in the color\n  space into bilateralFilter.\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  subsample factor of Fast Guided Filter, use a scale less than 1 to speeds up computation\n  with almost no visible degradation. (e.g. scale==0.5 shrinks the image by 2x inside the filter)\n\n##### Return\n- **retval**: `Evision.XImgProc.GuidedFilter.t()`\n\nFor more details about (Fast) Guided Filter parameters, see the original articles @cite Kaiming10 @cite Kaiming15 .\n\nPython prototype (for reference only):\n```python3\ncreateGuidedFilter(guide, radius, eps[, scale]) -> retval\n```","ref":"Evision.XImgProc.html#createGuidedFilter/3"},{"type":"function","title":"Evision.XImgProc.createGuidedFilter/4","doc":"Factory method, create instance of GuidedFilter and produce initialization routines.\n\n##### Positional Arguments\n- **guide**: `Evision.Mat`.\n\n  guided image (or array of images) with up to 3 channels, if it have more then 3\n  channels then only first 3 channels will be used.\n\n- **radius**: `integer()`.\n\n  radius of Guided Filter.\n\n- **eps**: `double`.\n\n  regularization term of Guided Filter. \\f${eps}^2\\f$ is similar to the sigma in the color\n  space into bilateralFilter.\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  subsample factor of Fast Guided Filter, use a scale less than 1 to speeds up computation\n  with almost no visible degradation. (e.g. scale==0.5 shrinks the image by 2x inside the filter)\n\n##### Return\n- **retval**: `Evision.XImgProc.GuidedFilter.t()`\n\nFor more details about (Fast) Guided Filter parameters, see the original articles @cite Kaiming10 @cite Kaiming15 .\n\nPython prototype (for reference only):\n```python3\ncreateGuidedFilter(guide, radius, eps[, scale]) -> retval\n```","ref":"Evision.XImgProc.html#createGuidedFilter/4"},{"type":"function","title":"Evision.XImgProc.createQuaternionImage/1","doc":"creates a quaternion image.\n\n##### Positional Arguments\n- **img**: `Evision.Mat`\n\n##### Return\n- **qimg**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ncreateQuaternionImage(img[, qimg]) -> qimg\n```","ref":"Evision.XImgProc.html#createQuaternionImage/1"},{"type":"function","title":"Evision.XImgProc.createQuaternionImage/2","doc":"creates a quaternion image.\n\n##### Positional Arguments\n- **img**: `Evision.Mat`\n\n##### Return\n- **qimg**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ncreateQuaternionImage(img[, qimg]) -> qimg\n```","ref":"Evision.XImgProc.html#createQuaternionImage/2"},{"type":"function","title":"Evision.XImgProc.createRFFeatureGetter/0","doc":"createRFFeatureGetter\n##### Return\n- **retval**: `Evision.XImgProc.RFFeatureGetter.t()`\n\nPython prototype (for reference only):\n```python3\ncreateRFFeatureGetter() -> retval\n```","ref":"Evision.XImgProc.html#createRFFeatureGetter/0"},{"type":"function","title":"Evision.XImgProc.createRFFeatureGetter/1","doc":"","ref":"Evision.XImgProc.html#createRFFeatureGetter/1"},{"type":"function","title":"Evision.XImgProc.createRICInterpolator/0","doc":"Factory method that creates an instance of the\nRICInterpolator.\n\n##### Return\n- **retval**: `Evision.XImgProc.RICInterpolator.t()`\n\nPython prototype (for reference only):\n```python3\ncreateRICInterpolator() -> retval\n```","ref":"Evision.XImgProc.html#createRICInterpolator/0"},{"type":"function","title":"Evision.XImgProc.createRICInterpolator/1","doc":"","ref":"Evision.XImgProc.html#createRICInterpolator/1"},{"type":"function","title":"Evision.XImgProc.createRightMatcher/1","doc":"Convenience method to set up the matcher for computing the right-view disparity map\nthat is required in case of filtering with confidence.\n\n##### Positional Arguments\n- **matcher_left**: `Evision.StereoMatcher`.\n\n  main stereo matcher instance that will be used with the filter\n\n##### Return\n- **retval**: `Evision.StereoMatcher.t()`\n\nPython prototype (for reference only):\n```python3\ncreateRightMatcher(matcher_left) -> retval\n```","ref":"Evision.XImgProc.html#createRightMatcher/1"},{"type":"function","title":"Evision.XImgProc.createScanSegment/1","doc":"","ref":"Evision.XImgProc.html#createScanSegment/1"},{"type":"function","title":"Evision.XImgProc.createScanSegment/3","doc":"Initializes a ScanSegment object.\n\n##### Positional Arguments\n- **image_width**: `integer()`.\n\n  Image width.\n\n- **image_height**: `integer()`.\n\n  Image height.\n\n- **num_superpixels**: `integer()`.\n\n  Desired number of superpixels. Note that the actual number may be smaller\n  due to restrictions (depending on the image size). Use getNumberOfSuperpixels() to\n  get the actual number.\n\n##### Keyword Arguments\n- **slices**: `integer()`.\n\n  Number of processing threads for parallelisation. Setting -1 uses the maximum number\n  of threads. In practice, four threads is enough for smaller images and eight threads for larger ones.\n\n- **merge_small**: `bool`.\n\n  merge small segments to give the desired number of superpixels. Processing is\n  much faster without merging, but many small segments will be left in the image.\n\n##### Return\n- **retval**: `Evision.XImgProc.ScanSegment.t()`\n\nThe function initializes a ScanSegment object for the input image. It stores the parameters of\nthe image: image_width and image_height. It also sets the parameters of the F-DBSCAN superpixel\nalgorithm, which are: num_superpixels, threads, and merge_small.\n\nPython prototype (for reference only):\n```python3\ncreateScanSegment(image_width, image_height, num_superpixels[, slices[, merge_small]]) -> retval\n```","ref":"Evision.XImgProc.html#createScanSegment/3"},{"type":"function","title":"Evision.XImgProc.createScanSegment/4","doc":"Initializes a ScanSegment object.\n\n##### Positional Arguments\n- **image_width**: `integer()`.\n\n  Image width.\n\n- **image_height**: `integer()`.\n\n  Image height.\n\n- **num_superpixels**: `integer()`.\n\n  Desired number of superpixels. Note that the actual number may be smaller\n  due to restrictions (depending on the image size). Use getNumberOfSuperpixels() to\n  get the actual number.\n\n##### Keyword Arguments\n- **slices**: `integer()`.\n\n  Number of processing threads for parallelisation. Setting -1 uses the maximum number\n  of threads. In practice, four threads is enough for smaller images and eight threads for larger ones.\n\n- **merge_small**: `bool`.\n\n  merge small segments to give the desired number of superpixels. Processing is\n  much faster without merging, but many small segments will be left in the image.\n\n##### Return\n- **retval**: `Evision.XImgProc.ScanSegment.t()`\n\nThe function initializes a ScanSegment object for the input image. It stores the parameters of\nthe image: image_width and image_height. It also sets the parameters of the F-DBSCAN superpixel\nalgorithm, which are: num_superpixels, threads, and merge_small.\n\nPython prototype (for reference only):\n```python3\ncreateScanSegment(image_width, image_height, num_superpixels[, slices[, merge_small]]) -> retval\n```","ref":"Evision.XImgProc.html#createScanSegment/4"},{"type":"function","title":"Evision.XImgProc.createSelectiveSearchSegmentation/0","doc":"Create a new SelectiveSearchSegmentation class.\n##### Return\n- **retval**: `Evision.XImgProc.SelectiveSearchSegmentation.t()`\n\nPython prototype (for reference only):\n```python3\ncreateSelectiveSearchSegmentation() -> retval\n```","ref":"Evision.XImgProc.html#createSelectiveSearchSegmentation/0"},{"type":"function","title":"Evision.XImgProc.createSelectiveSearchSegmentation/1","doc":"","ref":"Evision.XImgProc.html#createSelectiveSearchSegmentation/1"},{"type":"function","title":"Evision.XImgProc.createSelectiveSearchSegmentationStrategyColor/0","doc":"Create a new color-based strategy\n##### Return\n- **retval**: `Evision.XImgProc.SelectiveSearchSegmentationStrategyColor.t()`\n\nPython prototype (for reference only):\n```python3\ncreateSelectiveSearchSegmentationStrategyColor() -> retval\n```","ref":"Evision.XImgProc.html#createSelectiveSearchSegmentationStrategyColor/0"},{"type":"function","title":"Evision.XImgProc.createSelectiveSearchSegmentationStrategyColor/1","doc":"","ref":"Evision.XImgProc.html#createSelectiveSearchSegmentationStrategyColor/1"},{"type":"function","title":"Evision.XImgProc.createSelectiveSearchSegmentationStrategyFill/0","doc":"Create a new fill-based strategy\n##### Return\n- **retval**: `Evision.XImgProc.SelectiveSearchSegmentationStrategyFill.t()`\n\nPython prototype (for reference only):\n```python3\ncreateSelectiveSearchSegmentationStrategyFill() -> retval\n```","ref":"Evision.XImgProc.html#createSelectiveSearchSegmentationStrategyFill/0"},{"type":"function","title":"Evision.XImgProc.createSelectiveSearchSegmentationStrategyFill/1","doc":"","ref":"Evision.XImgProc.html#createSelectiveSearchSegmentationStrategyFill/1"},{"type":"function","title":"Evision.XImgProc.createSelectiveSearchSegmentationStrategyMultiple/0","doc":"Create a new multiple strategy\n##### Return\n- **retval**: `Evision.XImgProc.SelectiveSearchSegmentationStrategyMultiple.t()`\n\nPython prototype (for reference only):\n```python3\ncreateSelectiveSearchSegmentationStrategyMultiple() -> retval\n```","ref":"Evision.XImgProc.html#createSelectiveSearchSegmentationStrategyMultiple/0"},{"type":"function","title":"Evision.XImgProc.createSelectiveSearchSegmentationStrategyMultiple/1","doc":"Create a new multiple strategy and set one subtrategy\n\n##### Positional Arguments\n- **s1**: `Evision.XImgProc.SelectiveSearchSegmentationStrategy.t()`.\n\n  The first strategy\n\n##### Return\n- **retval**: `Evision.XImgProc.SelectiveSearchSegmentationStrategyMultiple.t()`\n\nPython prototype (for reference only):\n```python3\ncreateSelectiveSearchSegmentationStrategyMultiple(s1) -> retval\n```","ref":"Evision.XImgProc.html#createSelectiveSearchSegmentationStrategyMultiple/1"},{"type":"function","title":"Evision.XImgProc.createSelectiveSearchSegmentationStrategyMultiple/2","doc":"Create a new multiple strategy and set two subtrategies, with equal weights\n\n##### Positional Arguments\n- **s1**: `Evision.XImgProc.SelectiveSearchSegmentationStrategy.t()`.\n\n  The first strategy\n\n- **s2**: `Evision.XImgProc.SelectiveSearchSegmentationStrategy.t()`.\n\n  The second strategy\n\n##### Return\n- **retval**: `Evision.XImgProc.SelectiveSearchSegmentationStrategyMultiple.t()`\n\nPython prototype (for reference only):\n```python3\ncreateSelectiveSearchSegmentationStrategyMultiple(s1, s2) -> retval\n```","ref":"Evision.XImgProc.html#createSelectiveSearchSegmentationStrategyMultiple/2"},{"type":"function","title":"Evision.XImgProc.createSelectiveSearchSegmentationStrategyMultiple/3","doc":"Create a new multiple strategy and set three subtrategies, with equal weights\n\n##### Positional Arguments\n- **s1**: `Evision.XImgProc.SelectiveSearchSegmentationStrategy.t()`.\n\n  The first strategy\n\n- **s2**: `Evision.XImgProc.SelectiveSearchSegmentationStrategy.t()`.\n\n  The second strategy\n\n- **s3**: `Evision.XImgProc.SelectiveSearchSegmentationStrategy.t()`.\n\n  The third strategy\n\n##### Return\n- **retval**: `Evision.XImgProc.SelectiveSearchSegmentationStrategyMultiple.t()`\n\nPython prototype (for reference only):\n```python3\ncreateSelectiveSearchSegmentationStrategyMultiple(s1, s2, s3) -> retval\n```","ref":"Evision.XImgProc.html#createSelectiveSearchSegmentationStrategyMultiple/3"},{"type":"function","title":"Evision.XImgProc.createSelectiveSearchSegmentationStrategyMultiple/4","doc":"Create a new multiple strategy and set four subtrategies, with equal weights\n\n##### Positional Arguments\n- **s1**: `Evision.XImgProc.SelectiveSearchSegmentationStrategy.t()`.\n\n  The first strategy\n\n- **s2**: `Evision.XImgProc.SelectiveSearchSegmentationStrategy.t()`.\n\n  The second strategy\n\n- **s3**: `Evision.XImgProc.SelectiveSearchSegmentationStrategy.t()`.\n\n  The third strategy\n\n- **s4**: `Evision.XImgProc.SelectiveSearchSegmentationStrategy.t()`.\n\n  The forth strategy\n\n##### Return\n- **retval**: `Evision.XImgProc.SelectiveSearchSegmentationStrategyMultiple.t()`\n\nPython prototype (for reference only):\n```python3\ncreateSelectiveSearchSegmentationStrategyMultiple(s1, s2, s3, s4) -> retval\n```","ref":"Evision.XImgProc.html#createSelectiveSearchSegmentationStrategyMultiple/4"},{"type":"function","title":"Evision.XImgProc.createSelectiveSearchSegmentationStrategySize/0","doc":"Create a new size-based strategy\n##### Return\n- **retval**: `Evision.XImgProc.SelectiveSearchSegmentationStrategySize.t()`\n\nPython prototype (for reference only):\n```python3\ncreateSelectiveSearchSegmentationStrategySize() -> retval\n```","ref":"Evision.XImgProc.html#createSelectiveSearchSegmentationStrategySize/0"},{"type":"function","title":"Evision.XImgProc.createSelectiveSearchSegmentationStrategySize/1","doc":"","ref":"Evision.XImgProc.html#createSelectiveSearchSegmentationStrategySize/1"},{"type":"function","title":"Evision.XImgProc.createSelectiveSearchSegmentationStrategyTexture/0","doc":"Create a new size-based strategy\n##### Return\n- **retval**: `Evision.XImgProc.SelectiveSearchSegmentationStrategyTexture.t()`\n\nPython prototype (for reference only):\n```python3\ncreateSelectiveSearchSegmentationStrategyTexture() -> retval\n```","ref":"Evision.XImgProc.html#createSelectiveSearchSegmentationStrategyTexture/0"},{"type":"function","title":"Evision.XImgProc.createSelectiveSearchSegmentationStrategyTexture/1","doc":"","ref":"Evision.XImgProc.html#createSelectiveSearchSegmentationStrategyTexture/1"},{"type":"function","title":"Evision.XImgProc.createStructuredEdgeDetection/1","doc":"createStructuredEdgeDetection\n\n##### Positional Arguments\n- **model**: `String`\n\n##### Keyword Arguments\n- **howToGetFeatures**: `Evision.XImgProc.RFFeatureGetter.t()`.\n\n##### Return\n- **retval**: `Evision.XImgProc.StructuredEdgeDetection.t()`\n\nPython prototype (for reference only):\n```python3\ncreateStructuredEdgeDetection(model[, howToGetFeatures]) -> retval\n```","ref":"Evision.XImgProc.html#createStructuredEdgeDetection/1"},{"type":"function","title":"Evision.XImgProc.createStructuredEdgeDetection/2","doc":"createStructuredEdgeDetection\n\n##### Positional Arguments\n- **model**: `String`\n\n##### Keyword Arguments\n- **howToGetFeatures**: `Evision.XImgProc.RFFeatureGetter.t()`.\n\n##### Return\n- **retval**: `Evision.XImgProc.StructuredEdgeDetection.t()`\n\nPython prototype (for reference only):\n```python3\ncreateStructuredEdgeDetection(model[, howToGetFeatures]) -> retval\n```","ref":"Evision.XImgProc.html#createStructuredEdgeDetection/2"},{"type":"function","title":"Evision.XImgProc.createSuperpixelLSC/1","doc":"Class implementing the LSC (Linear Spectral Clustering) superpixels\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Image to segment\n\n##### Keyword Arguments\n- **region_size**: `integer()`.\n\n  Chooses an average superpixel size measured in pixels\n\n- **ratio**: `float`.\n\n  Chooses the enforcement of superpixel compactness factor of superpixel\n\n##### Return\n- **retval**: `Evision.XImgProc.SuperpixelLSC.t()`\n\nThe function initializes a SuperpixelLSC object for the input image. It sets the parameters of\nsuperpixel algorithm, which are: region_size and ruler. It preallocate some buffers for future\ncomputing iterations over the given image. An example of LSC is ilustrated in the following picture.\nFor enanched results it is recommended for color images to preprocess image with little gaussian blur\nwith a small 3 x 3 kernel and additional conversion into CieLAB color space.\n![image](pics/superpixels_lsc.png)\n\nPython prototype (for reference only):\n```python3\ncreateSuperpixelLSC(image[, region_size[, ratio]]) -> retval\n```","ref":"Evision.XImgProc.html#createSuperpixelLSC/1"},{"type":"function","title":"Evision.XImgProc.createSuperpixelLSC/2","doc":"Class implementing the LSC (Linear Spectral Clustering) superpixels\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Image to segment\n\n##### Keyword Arguments\n- **region_size**: `integer()`.\n\n  Chooses an average superpixel size measured in pixels\n\n- **ratio**: `float`.\n\n  Chooses the enforcement of superpixel compactness factor of superpixel\n\n##### Return\n- **retval**: `Evision.XImgProc.SuperpixelLSC.t()`\n\nThe function initializes a SuperpixelLSC object for the input image. It sets the parameters of\nsuperpixel algorithm, which are: region_size and ruler. It preallocate some buffers for future\ncomputing iterations over the given image. An example of LSC is ilustrated in the following picture.\nFor enanched results it is recommended for color images to preprocess image with little gaussian blur\nwith a small 3 x 3 kernel and additional conversion into CieLAB color space.\n![image](pics/superpixels_lsc.png)\n\nPython prototype (for reference only):\n```python3\ncreateSuperpixelLSC(image[, region_size[, ratio]]) -> retval\n```","ref":"Evision.XImgProc.html#createSuperpixelLSC/2"},{"type":"function","title":"Evision.XImgProc.createSuperpixelSEEDS/1","doc":"","ref":"Evision.XImgProc.html#createSuperpixelSEEDS/1"},{"type":"function","title":"Evision.XImgProc.createSuperpixelSEEDS/5","doc":"Initializes a SuperpixelSEEDS object.\n\n##### Positional Arguments\n- **image_width**: `integer()`.\n\n  Image width.\n\n- **image_height**: `integer()`.\n\n  Image height.\n\n- **image_channels**: `integer()`.\n\n  Number of channels of the image.\n\n- **num_superpixels**: `integer()`.\n\n  Desired number of superpixels. Note that the actual number may be smaller\n  due to restrictions (depending on the image size and num_levels). Use getNumberOfSuperpixels() to\n  get the actual number.\n\n- **num_levels**: `integer()`.\n\n  Number of block levels. The more levels, the more accurate is the segmentation,\n  but needs more memory and CPU time.\n\n##### Keyword Arguments\n- **prior**: `integer()`.\n\n  enable 3x3 shape smoothing term if \\>0. A larger value leads to smoother shapes. prior\n  must be in the range [0, 5].\n\n- **histogram_bins**: `integer()`.\n\n  Number of histogram bins.\n\n- **double_step**: `bool`.\n\n  If true, iterate each block level twice for higher accuracy.\n\n##### Return\n- **retval**: `Evision.XImgProc.SuperpixelSEEDS.t()`\n\nThe function initializes a SuperpixelSEEDS object for the input image. It stores the parameters of\nthe image: image_width, image_height and image_channels. It also sets the parameters of the SEEDS\nsuperpixel algorithm, which are: num_superpixels, num_levels, use_prior, histogram_bins and\ndouble_step.\nThe number of levels in num_levels defines the amount of block levels that the algorithm use in the\noptimization. The initialization is a grid, in which the superpixels are equally distributed through\nthe width and the height of the image. The larger blocks correspond to the superpixel size, and the\nlevels with smaller blocks are formed by dividing the larger blocks into 2 x 2 blocks of pixels,\nrecursively until the smaller block level. An example of initialization of 4 block levels is\nillustrated in the following figure.\n![image](pics/superpixels_blocks.png)\n\nPython prototype (for reference only):\n```python3\ncreateSuperpixelSEEDS(image_width, image_height, image_channels, num_superpixels, num_levels[, prior[, histogram_bins[, double_step]]]) -> retval\n```","ref":"Evision.XImgProc.html#createSuperpixelSEEDS/5"},{"type":"function","title":"Evision.XImgProc.createSuperpixelSEEDS/6","doc":"Initializes a SuperpixelSEEDS object.\n\n##### Positional Arguments\n- **image_width**: `integer()`.\n\n  Image width.\n\n- **image_height**: `integer()`.\n\n  Image height.\n\n- **image_channels**: `integer()`.\n\n  Number of channels of the image.\n\n- **num_superpixels**: `integer()`.\n\n  Desired number of superpixels. Note that the actual number may be smaller\n  due to restrictions (depending on the image size and num_levels). Use getNumberOfSuperpixels() to\n  get the actual number.\n\n- **num_levels**: `integer()`.\n\n  Number of block levels. The more levels, the more accurate is the segmentation,\n  but needs more memory and CPU time.\n\n##### Keyword Arguments\n- **prior**: `integer()`.\n\n  enable 3x3 shape smoothing term if \\>0. A larger value leads to smoother shapes. prior\n  must be in the range [0, 5].\n\n- **histogram_bins**: `integer()`.\n\n  Number of histogram bins.\n\n- **double_step**: `bool`.\n\n  If true, iterate each block level twice for higher accuracy.\n\n##### Return\n- **retval**: `Evision.XImgProc.SuperpixelSEEDS.t()`\n\nThe function initializes a SuperpixelSEEDS object for the input image. It stores the parameters of\nthe image: image_width, image_height and image_channels. It also sets the parameters of the SEEDS\nsuperpixel algorithm, which are: num_superpixels, num_levels, use_prior, histogram_bins and\ndouble_step.\nThe number of levels in num_levels defines the amount of block levels that the algorithm use in the\noptimization. The initialization is a grid, in which the superpixels are equally distributed through\nthe width and the height of the image. The larger blocks correspond to the superpixel size, and the\nlevels with smaller blocks are formed by dividing the larger blocks into 2 x 2 blocks of pixels,\nrecursively until the smaller block level. An example of initialization of 4 block levels is\nillustrated in the following figure.\n![image](pics/superpixels_blocks.png)\n\nPython prototype (for reference only):\n```python3\ncreateSuperpixelSEEDS(image_width, image_height, image_channels, num_superpixels, num_levels[, prior[, histogram_bins[, double_step]]]) -> retval\n```","ref":"Evision.XImgProc.html#createSuperpixelSEEDS/6"},{"type":"function","title":"Evision.XImgProc.createSuperpixelSLIC/1","doc":"Initialize a SuperpixelSLIC object\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Image to segment\n\n##### Keyword Arguments\n- **algorithm**: `integer()`.\n\n  Chooses the algorithm variant to use:\n  SLIC segments image using a desired region_size, and in addition SLICO will optimize using adaptive compactness factor,\n  while MSLIC will optimize using manifold methods resulting in more content-sensitive superpixels.\n\n- **region_size**: `integer()`.\n\n  Chooses an average superpixel size measured in pixels\n\n- **ruler**: `float`.\n\n  Chooses the enforcement of superpixel smoothness factor of superpixel\n\n##### Return\n- **retval**: `Evision.XImgProc.SuperpixelSLIC.t()`\n\nThe function initializes a SuperpixelSLIC object for the input image. It sets the parameters of choosed\nsuperpixel algorithm, which are: region_size and ruler. It preallocate some buffers for future\ncomputing iterations over the given image. For enanched results it is recommended for color images to\npreprocess image with little gaussian blur using a small 3 x 3 kernel and additional conversion into\nCieLAB color space. An example of SLIC versus SLICO and MSLIC is ilustrated in the following picture.\n![image](pics/superpixels_slic.png)\n\nPython prototype (for reference only):\n```python3\ncreateSuperpixelSLIC(image[, algorithm[, region_size[, ruler]]]) -> retval\n```","ref":"Evision.XImgProc.html#createSuperpixelSLIC/1"},{"type":"function","title":"Evision.XImgProc.createSuperpixelSLIC/2","doc":"Initialize a SuperpixelSLIC object\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  Image to segment\n\n##### Keyword Arguments\n- **algorithm**: `integer()`.\n\n  Chooses the algorithm variant to use:\n  SLIC segments image using a desired region_size, and in addition SLICO will optimize using adaptive compactness factor,\n  while MSLIC will optimize using manifold methods resulting in more content-sensitive superpixels.\n\n- **region_size**: `integer()`.\n\n  Chooses an average superpixel size measured in pixels\n\n- **ruler**: `float`.\n\n  Chooses the enforcement of superpixel smoothness factor of superpixel\n\n##### Return\n- **retval**: `Evision.XImgProc.SuperpixelSLIC.t()`\n\nThe function initializes a SuperpixelSLIC object for the input image. It sets the parameters of choosed\nsuperpixel algorithm, which are: region_size and ruler. It preallocate some buffers for future\ncomputing iterations over the given image. For enanched results it is recommended for color images to\npreprocess image with little gaussian blur using a small 3 x 3 kernel and additional conversion into\nCieLAB color space. An example of SLIC versus SLICO and MSLIC is ilustrated in the following picture.\n![image](pics/superpixels_slic.png)\n\nPython prototype (for reference only):\n```python3\ncreateSuperpixelSLIC(image[, algorithm[, region_size[, ruler]]]) -> retval\n```","ref":"Evision.XImgProc.html#createSuperpixelSLIC/2"},{"type":"function","title":"Evision.XImgProc.dtFilter/1","doc":"","ref":"Evision.XImgProc.html#dtFilter/1"},{"type":"function","title":"Evision.XImgProc.dtFilter/4","doc":"Simple one-line Domain Transform filter call. If you have multiple images to filter with the same\nguided image then use DTFilter interface to avoid extra computations on initialization stage.\n\n##### Positional Arguments\n- **guide**: `Evision.Mat`.\n\n  guided image (also called as joint image) with unsigned 8-bit or floating-point 32-bit\n  depth and up to 4 channels.\n\n- **src**: `Evision.Mat`.\n\n  filtering image with unsigned 8-bit or floating-point 32-bit depth and up to 4 channels.\n\n- **sigmaSpatial**: `double`.\n\n  \\f${\\sigma}_H\\f$ parameter in the original article, it's similar to the sigma in the\n  coordinate space into bilateralFilter.\n\n- **sigmaColor**: `double`.\n\n  \\f${\\sigma}_r\\f$ parameter in the original article, it's similar to the sigma in the\n  color space into bilateralFilter.\n\n##### Keyword Arguments\n- **mode**: `integer()`.\n\n  one form three modes DTF_NC, DTF_RF and DTF_IC which corresponds to three modes for\n  filtering 2D signals in the article.\n\n- **numIters**: `integer()`.\n\n  optional number of iterations used for filtering, 3 is quite enough.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  destination image\n\n@sa bilateralFilter, guidedFilter, amFilter\n\nPython prototype (for reference only):\n```python3\ndtFilter(guide, src, sigmaSpatial, sigmaColor[, dst[, mode[, numIters]]]) -> dst\n```","ref":"Evision.XImgProc.html#dtFilter/4"},{"type":"function","title":"Evision.XImgProc.dtFilter/5","doc":"Simple one-line Domain Transform filter call. If you have multiple images to filter with the same\nguided image then use DTFilter interface to avoid extra computations on initialization stage.\n\n##### Positional Arguments\n- **guide**: `Evision.Mat`.\n\n  guided image (also called as joint image) with unsigned 8-bit or floating-point 32-bit\n  depth and up to 4 channels.\n\n- **src**: `Evision.Mat`.\n\n  filtering image with unsigned 8-bit or floating-point 32-bit depth and up to 4 channels.\n\n- **sigmaSpatial**: `double`.\n\n  \\f${\\sigma}_H\\f$ parameter in the original article, it's similar to the sigma in the\n  coordinate space into bilateralFilter.\n\n- **sigmaColor**: `double`.\n\n  \\f${\\sigma}_r\\f$ parameter in the original article, it's similar to the sigma in the\n  color space into bilateralFilter.\n\n##### Keyword Arguments\n- **mode**: `integer()`.\n\n  one form three modes DTF_NC, DTF_RF and DTF_IC which corresponds to three modes for\n  filtering 2D signals in the article.\n\n- **numIters**: `integer()`.\n\n  optional number of iterations used for filtering, 3 is quite enough.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  destination image\n\n@sa bilateralFilter, guidedFilter, amFilter\n\nPython prototype (for reference only):\n```python3\ndtFilter(guide, src, sigmaSpatial, sigmaColor[, dst[, mode[, numIters]]]) -> dst\n```","ref":"Evision.XImgProc.html#dtFilter/5"},{"type":"function","title":"Evision.XImgProc.edgePreservingFilter/1","doc":"","ref":"Evision.XImgProc.html#edgePreservingFilter/1"},{"type":"function","title":"Evision.XImgProc.edgePreservingFilter/3","doc":"Smoothes an image using the Edge-Preserving filter.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source 8-bit 3-channel image.\n\n- **d**: `integer()`.\n\n  Diameter of each pixel neighborhood that is used during filtering. Must be greater or equal 3.\n\n- **threshold**: `double`.\n\n  Threshold, which distinguishes between noise, outliers, and data.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and type as src.\n\n The function smoothes Gaussian noise as well as salt & pepper noise.\n For more details about this implementation, please see\n [ReiWoe18]  Reich, S. and Wörgötter, F. and Dellen, B. (2018). A Real-Time Edge-Preserving Denoising Filter. Proceedings of the 13th International Joint Conference on Computer Vision, Imaging and Computer Graphics Theory and Applications (VISIGRAPP): Visapp, 85-94, 4. DOI: 10.5220/0006509000850094.\n\nPython prototype (for reference only):\n```python3\nedgePreservingFilter(src, d, threshold[, dst]) -> dst\n```","ref":"Evision.XImgProc.html#edgePreservingFilter/3"},{"type":"function","title":"Evision.XImgProc.edgePreservingFilter/4","doc":"Smoothes an image using the Edge-Preserving filter.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source 8-bit 3-channel image.\n\n- **d**: `integer()`.\n\n  Diameter of each pixel neighborhood that is used during filtering. Must be greater or equal 3.\n\n- **threshold**: `double`.\n\n  Threshold, which distinguishes between noise, outliers, and data.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and type as src.\n\n The function smoothes Gaussian noise as well as salt & pepper noise.\n For more details about this implementation, please see\n [ReiWoe18]  Reich, S. and Wörgötter, F. and Dellen, B. (2018). A Real-Time Edge-Preserving Denoising Filter. Proceedings of the 13th International Joint Conference on Computer Vision, Imaging and Computer Graphics Theory and Applications (VISIGRAPP): Visapp, 85-94, 4. DOI: 10.5220/0006509000850094.\n\nPython prototype (for reference only):\n```python3\nedgePreservingFilter(src, d, threshold[, dst]) -> dst\n```","ref":"Evision.XImgProc.html#edgePreservingFilter/4"},{"type":"function","title":"Evision.XImgProc.fastBilateralSolverFilter/1","doc":"","ref":"Evision.XImgProc.html#fastBilateralSolverFilter/1"},{"type":"function","title":"Evision.XImgProc.fastBilateralSolverFilter/3","doc":"Simple one-line Fast Bilateral Solver filter call. If you have multiple images to filter with the same\nguide then use FastBilateralSolverFilter interface to avoid extra computations.\n\n##### Positional Arguments\n- **guide**: `Evision.Mat`.\n\n  image serving as guide for filtering. It should have 8-bit depth and either 1 or 3 channels.\n\n- **src**: `Evision.Mat`.\n\n  source image for filtering with unsigned 8-bit or signed 16-bit or floating-point 32-bit depth and up to 4 channels.\n\n- **confidence**: `Evision.Mat`.\n\n  confidence image with unsigned 8-bit or floating-point 32-bit confidence and 1 channel.\n\n##### Keyword Arguments\n- **sigma_spatial**: `double`.\n\n  parameter, that is similar to spatial space sigma (bandwidth) in bilateralFilter.\n\n- **sigma_luma**: `double`.\n\n  parameter, that is similar to luma space sigma (bandwidth) in bilateralFilter.\n\n- **sigma_chroma**: `double`.\n\n  parameter, that is similar to chroma space sigma (bandwidth) in bilateralFilter.\n\n- **lambda**: `double`.\n\n  smoothness strength parameter for solver.\n\n- **num_iter**: `integer()`.\n\n  number of iterations used for solver, 25 is usually enough.\n\n- **max_tol**: `double`.\n\n  convergence tolerance used for solver.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  destination image.\n\nFor more details about the Fast Bilateral Solver parameters, see the original paper @cite BarronPoole2016.\n**Note**: Confidence images with CV_8U depth are expected to in [0, 255] and CV_32F in [0, 1] range.\n\nPython prototype (for reference only):\n```python3\nfastBilateralSolverFilter(guide, src, confidence[, dst[, sigma_spatial[, sigma_luma[, sigma_chroma[, lambda[, num_iter[, max_tol]]]]]]]) -> dst\n```","ref":"Evision.XImgProc.html#fastBilateralSolverFilter/3"},{"type":"function","title":"Evision.XImgProc.fastBilateralSolverFilter/4","doc":"Simple one-line Fast Bilateral Solver filter call. If you have multiple images to filter with the same\nguide then use FastBilateralSolverFilter interface to avoid extra computations.\n\n##### Positional Arguments\n- **guide**: `Evision.Mat`.\n\n  image serving as guide for filtering. It should have 8-bit depth and either 1 or 3 channels.\n\n- **src**: `Evision.Mat`.\n\n  source image for filtering with unsigned 8-bit or signed 16-bit or floating-point 32-bit depth and up to 4 channels.\n\n- **confidence**: `Evision.Mat`.\n\n  confidence image with unsigned 8-bit or floating-point 32-bit confidence and 1 channel.\n\n##### Keyword Arguments\n- **sigma_spatial**: `double`.\n\n  parameter, that is similar to spatial space sigma (bandwidth) in bilateralFilter.\n\n- **sigma_luma**: `double`.\n\n  parameter, that is similar to luma space sigma (bandwidth) in bilateralFilter.\n\n- **sigma_chroma**: `double`.\n\n  parameter, that is similar to chroma space sigma (bandwidth) in bilateralFilter.\n\n- **lambda**: `double`.\n\n  smoothness strength parameter for solver.\n\n- **num_iter**: `integer()`.\n\n  number of iterations used for solver, 25 is usually enough.\n\n- **max_tol**: `double`.\n\n  convergence tolerance used for solver.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  destination image.\n\nFor more details about the Fast Bilateral Solver parameters, see the original paper @cite BarronPoole2016.\n**Note**: Confidence images with CV_8U depth are expected to in [0, 255] and CV_32F in [0, 1] range.\n\nPython prototype (for reference only):\n```python3\nfastBilateralSolverFilter(guide, src, confidence[, dst[, sigma_spatial[, sigma_luma[, sigma_chroma[, lambda[, num_iter[, max_tol]]]]]]]) -> dst\n```","ref":"Evision.XImgProc.html#fastBilateralSolverFilter/4"},{"type":"function","title":"Evision.XImgProc.fastGlobalSmootherFilter/1","doc":"","ref":"Evision.XImgProc.html#fastGlobalSmootherFilter/1"},{"type":"function","title":"Evision.XImgProc.fastGlobalSmootherFilter/4","doc":"Simple one-line Fast Global Smoother filter call. If you have multiple images to filter with the same\nguide then use FastGlobalSmootherFilter interface to avoid extra computations.\n\n##### Positional Arguments\n- **guide**: `Evision.Mat`.\n\n  image serving as guide for filtering. It should have 8-bit depth and either 1 or 3 channels.\n\n- **src**: `Evision.Mat`.\n\n  source image for filtering with unsigned 8-bit or signed 16-bit or floating-point 32-bit depth and up to 4 channels.\n\n- **lambda**: `double`.\n\n  parameter defining the amount of regularization\n\n- **sigma_color**: `double`.\n\n  parameter, that is similar to color space sigma in bilateralFilter.\n\n##### Keyword Arguments\n- **lambda_attenuation**: `double`.\n\n  internal parameter, defining how much lambda decreases after each iteration. Normally,\n  it should be 0.25. Setting it to 1.0 may lead to streaking artifacts.\n\n- **num_iter**: `integer()`.\n\n  number of iterations used for filtering, 3 is usually enough.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  destination image.\n\nPython prototype (for reference only):\n```python3\nfastGlobalSmootherFilter(guide, src, lambda, sigma_color[, dst[, lambda_attenuation[, num_iter]]]) -> dst\n```","ref":"Evision.XImgProc.html#fastGlobalSmootherFilter/4"},{"type":"function","title":"Evision.XImgProc.fastGlobalSmootherFilter/5","doc":"Simple one-line Fast Global Smoother filter call. If you have multiple images to filter with the same\nguide then use FastGlobalSmootherFilter interface to avoid extra computations.\n\n##### Positional Arguments\n- **guide**: `Evision.Mat`.\n\n  image serving as guide for filtering. It should have 8-bit depth and either 1 or 3 channels.\n\n- **src**: `Evision.Mat`.\n\n  source image for filtering with unsigned 8-bit or signed 16-bit or floating-point 32-bit depth and up to 4 channels.\n\n- **lambda**: `double`.\n\n  parameter defining the amount of regularization\n\n- **sigma_color**: `double`.\n\n  parameter, that is similar to color space sigma in bilateralFilter.\n\n##### Keyword Arguments\n- **lambda_attenuation**: `double`.\n\n  internal parameter, defining how much lambda decreases after each iteration. Normally,\n  it should be 0.25. Setting it to 1.0 may lead to streaking artifacts.\n\n- **num_iter**: `integer()`.\n\n  number of iterations used for filtering, 3 is usually enough.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  destination image.\n\nPython prototype (for reference only):\n```python3\nfastGlobalSmootherFilter(guide, src, lambda, sigma_color[, dst[, lambda_attenuation[, num_iter]]]) -> dst\n```","ref":"Evision.XImgProc.html#fastGlobalSmootherFilter/5"},{"type":"function","title":"Evision.XImgProc.fastHoughTransform/1","doc":"","ref":"Evision.XImgProc.html#fastHoughTransform/1"},{"type":"function","title":"Evision.XImgProc.fastHoughTransform/2","doc":"Calculates 2D Fast Hough transform of an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n- **dstMatDepth**: `integer()`\n\n##### Keyword Arguments\n- **angleRange**: `integer()`.\n- **op**: `integer()`.\n- **makeSkew**: `integer()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n The function calculates the fast Hough transform for full, half or quarter\n range of angles.\n\nPython prototype (for reference only):\n```python3\nFastHoughTransform(src, dstMatDepth[, dst[, angleRange[, op[, makeSkew]]]]) -> dst\n```","ref":"Evision.XImgProc.html#fastHoughTransform/2"},{"type":"function","title":"Evision.XImgProc.fastHoughTransform/3","doc":"Calculates 2D Fast Hough transform of an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n- **dstMatDepth**: `integer()`\n\n##### Keyword Arguments\n- **angleRange**: `integer()`.\n- **op**: `integer()`.\n- **makeSkew**: `integer()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n The function calculates the fast Hough transform for full, half or quarter\n range of angles.\n\nPython prototype (for reference only):\n```python3\nFastHoughTransform(src, dstMatDepth[, dst[, angleRange[, op[, makeSkew]]]]) -> dst\n```","ref":"Evision.XImgProc.html#fastHoughTransform/3"},{"type":"function","title":"Evision.XImgProc.findEllipses/1","doc":"Finds ellipses fastly in an image using projective invariant pruning.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  input image, could be gray or color.\n\n##### Keyword Arguments\n- **scoreThreshold**: `float`.\n\n  float, the threshold of ellipse score.\n\n- **reliabilityThreshold**: `float`.\n\n  float, the threshold of reliability.\n\n- **centerDistanceThreshold**: `float`.\n\n  float, the threshold of center distance.\n\n##### Return\n- **ellipses**: `Evision.Mat.t()`.\n\n  output vector of found ellipses. each vector is encoded as five float $x, y, a, b, radius, score$.\n\n The function detects ellipses in images using projective invariant pruning.\n For more details about this implementation, please see @cite jia2017fast\n Jia, Qi et al, (2017).\n A Fast Ellipse Detector using Projective Invariant Pruning. IEEE Transactions on Image Processing.\n\nPython prototype (for reference only):\n```python3\nfindEllipses(image[, ellipses[, scoreThreshold[, reliabilityThreshold[, centerDistanceThreshold]]]]) -> ellipses\n```","ref":"Evision.XImgProc.html#findEllipses/1"},{"type":"function","title":"Evision.XImgProc.findEllipses/2","doc":"Finds ellipses fastly in an image using projective invariant pruning.\n\n##### Positional Arguments\n- **image**: `Evision.Mat`.\n\n  input image, could be gray or color.\n\n##### Keyword Arguments\n- **scoreThreshold**: `float`.\n\n  float, the threshold of ellipse score.\n\n- **reliabilityThreshold**: `float`.\n\n  float, the threshold of reliability.\n\n- **centerDistanceThreshold**: `float`.\n\n  float, the threshold of center distance.\n\n##### Return\n- **ellipses**: `Evision.Mat.t()`.\n\n  output vector of found ellipses. each vector is encoded as five float $x, y, a, b, radius, score$.\n\n The function detects ellipses in images using projective invariant pruning.\n For more details about this implementation, please see @cite jia2017fast\n Jia, Qi et al, (2017).\n A Fast Ellipse Detector using Projective Invariant Pruning. IEEE Transactions on Image Processing.\n\nPython prototype (for reference only):\n```python3\nfindEllipses(image[, ellipses[, scoreThreshold[, reliabilityThreshold[, centerDistanceThreshold]]]]) -> ellipses\n```","ref":"Evision.XImgProc.html#findEllipses/2"},{"type":"function","title":"Evision.XImgProc.fourierDescriptor/1","doc":"Fourier descriptors for planed closed curves\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **nbElt**: `integer()`.\n- **nbFD**: `integer()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n For more details about this implementation, please see @cite PersoonFu1977\n\nPython prototype (for reference only):\n```python3\nfourierDescriptor(src[, dst[, nbElt[, nbFD]]]) -> dst\n```","ref":"Evision.XImgProc.html#fourierDescriptor/1"},{"type":"function","title":"Evision.XImgProc.fourierDescriptor/2","doc":"Fourier descriptors for planed closed curves\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **nbElt**: `integer()`.\n- **nbFD**: `integer()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n For more details about this implementation, please see @cite PersoonFu1977\n\nPython prototype (for reference only):\n```python3\nfourierDescriptor(src[, dst[, nbElt[, nbFD]]]) -> dst\n```","ref":"Evision.XImgProc.html#fourierDescriptor/2"},{"type":"function","title":"Evision.XImgProc.getDisparityVis/1","doc":"Function for creating a disparity map visualization (clamped CV_8U image)\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input disparity map (CV_16S depth)\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  disparity map will be multiplied by this value for visualization\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output visualization\n\nPython prototype (for reference only):\n```python3\ngetDisparityVis(src[, dst[, scale]]) -> dst\n```","ref":"Evision.XImgProc.html#getDisparityVis/1"},{"type":"function","title":"Evision.XImgProc.getDisparityVis/2","doc":"Function for creating a disparity map visualization (clamped CV_8U image)\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  input disparity map (CV_16S depth)\n\n##### Keyword Arguments\n- **scale**: `double`.\n\n  disparity map will be multiplied by this value for visualization\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output visualization\n\nPython prototype (for reference only):\n```python3\ngetDisparityVis(src[, dst[, scale]]) -> dst\n```","ref":"Evision.XImgProc.html#getDisparityVis/2"},{"type":"function","title":"Evision.XImgProc.gradientDericheX/1","doc":"","ref":"Evision.XImgProc.html#gradientDericheX/1"},{"type":"function","title":"Evision.XImgProc.gradientDericheX/3","doc":"Applies X Deriche filter to an image.\n\n##### Positional Arguments\n- **op**: `Evision.Mat`\n- **alpha**: `double`\n- **omega**: `double`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n For more details about this implementation, please see http://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.476.5736&rep=rep1&type=pdf\n\nPython prototype (for reference only):\n```python3\nGradientDericheX(op, alpha, omega[, dst]) -> dst\n```","ref":"Evision.XImgProc.html#gradientDericheX/3"},{"type":"function","title":"Evision.XImgProc.gradientDericheX/4","doc":"Applies X Deriche filter to an image.\n\n##### Positional Arguments\n- **op**: `Evision.Mat`\n- **alpha**: `double`\n- **omega**: `double`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n For more details about this implementation, please see http://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.476.5736&rep=rep1&type=pdf\n\nPython prototype (for reference only):\n```python3\nGradientDericheX(op, alpha, omega[, dst]) -> dst\n```","ref":"Evision.XImgProc.html#gradientDericheX/4"},{"type":"function","title":"Evision.XImgProc.gradientDericheY/1","doc":"","ref":"Evision.XImgProc.html#gradientDericheY/1"},{"type":"function","title":"Evision.XImgProc.gradientDericheY/3","doc":"Applies Y Deriche filter to an image.\n\n##### Positional Arguments\n- **op**: `Evision.Mat`\n- **alpha**: `double`\n- **omega**: `double`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n For more details about this implementation, please see http://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.476.5736&rep=rep1&type=pdf\n\nPython prototype (for reference only):\n```python3\nGradientDericheY(op, alpha, omega[, dst]) -> dst\n```","ref":"Evision.XImgProc.html#gradientDericheY/3"},{"type":"function","title":"Evision.XImgProc.gradientDericheY/4","doc":"Applies Y Deriche filter to an image.\n\n##### Positional Arguments\n- **op**: `Evision.Mat`\n- **alpha**: `double`\n- **omega**: `double`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n For more details about this implementation, please see http://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.476.5736&rep=rep1&type=pdf\n\nPython prototype (for reference only):\n```python3\nGradientDericheY(op, alpha, omega[, dst]) -> dst\n```","ref":"Evision.XImgProc.html#gradientDericheY/4"},{"type":"function","title":"Evision.XImgProc.guidedFilter/1","doc":"","ref":"Evision.XImgProc.html#guidedFilter/1"},{"type":"function","title":"Evision.XImgProc.guidedFilter/4","doc":"Simple one-line (Fast) Guided Filter call.\n\n##### Positional Arguments\n- **guide**: `Evision.Mat`.\n\n  guided image (or array of images) with up to 3 channels, if it have more then 3\n  channels then only first 3 channels will be used.\n\n- **src**: `Evision.Mat`.\n\n  filtering image with any numbers of channels.\n\n- **radius**: `integer()`.\n\n  radius of Guided Filter.\n\n- **eps**: `double`.\n\n  regularization term of Guided Filter. \\f${eps}^2\\f$ is similar to the sigma in the color\n  space into bilateralFilter.\n\n##### Keyword Arguments\n- **dDepth**: `integer()`.\n\n  optional depth of the output image.\n\n- **scale**: `double`.\n\n  subsample factor of Fast Guided Filter, use a scale less than 1 to speeds up computation\n  with almost no visible degradation. (e.g. scale==0.5 shrinks the image by 2x inside the filter)\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image.\n\nIf you have multiple images to filter with the same guided image then use GuidedFilter interface to\navoid extra computations on initialization stage.\n\n@sa bilateralFilter, dtFilter, amFilter\n\nPython prototype (for reference only):\n```python3\nguidedFilter(guide, src, radius, eps[, dst[, dDepth[, scale]]]) -> dst\n```","ref":"Evision.XImgProc.html#guidedFilter/4"},{"type":"function","title":"Evision.XImgProc.guidedFilter/5","doc":"Simple one-line (Fast) Guided Filter call.\n\n##### Positional Arguments\n- **guide**: `Evision.Mat`.\n\n  guided image (or array of images) with up to 3 channels, if it have more then 3\n  channels then only first 3 channels will be used.\n\n- **src**: `Evision.Mat`.\n\n  filtering image with any numbers of channels.\n\n- **radius**: `integer()`.\n\n  radius of Guided Filter.\n\n- **eps**: `double`.\n\n  regularization term of Guided Filter. \\f${eps}^2\\f$ is similar to the sigma in the color\n  space into bilateralFilter.\n\n##### Keyword Arguments\n- **dDepth**: `integer()`.\n\n  optional depth of the output image.\n\n- **scale**: `double`.\n\n  subsample factor of Fast Guided Filter, use a scale less than 1 to speeds up computation\n  with almost no visible degradation. (e.g. scale==0.5 shrinks the image by 2x inside the filter)\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image.\n\nIf you have multiple images to filter with the same guided image then use GuidedFilter interface to\navoid extra computations on initialization stage.\n\n@sa bilateralFilter, dtFilter, amFilter\n\nPython prototype (for reference only):\n```python3\nguidedFilter(guide, src, radius, eps[, dst[, dDepth[, scale]]]) -> dst\n```","ref":"Evision.XImgProc.html#guidedFilter/5"},{"type":"function","title":"Evision.XImgProc.houghPoint2Line/1","doc":"","ref":"Evision.XImgProc.html#houghPoint2Line/1"},{"type":"function","title":"Evision.XImgProc.houghPoint2Line/2","doc":"Calculates coordinates of line segment corresponded by point in Hough space.\n\n##### Positional Arguments\n- **houghPoint**: `Point`\n- **srcImgInfo**: `Evision.Mat`\n\n##### Keyword Arguments\n- **angleRange**: `integer()`.\n- **makeSkew**: `integer()`.\n- **rules**: `integer()`.\n\n##### Return\n- **retval**: `Vec4i`\n\n@retval  [Vec4i]     Coordinates of line segment corresponded by point in Hough space.\n@remarks If rules parameter set to RO_STRICT\nthen returned line cut along the border of source image.\n@remarks If rules parameter set to RO_WEAK then in case of point, which belongs\nthe incorrect part of Hough image, returned line will not intersect source image.\n The function calculates coordinates of line segment corresponded by point in Hough space.\n\nPython prototype (for reference only):\n```python3\nHoughPoint2Line(houghPoint, srcImgInfo[, angleRange[, makeSkew[, rules]]]) -> retval\n```","ref":"Evision.XImgProc.html#houghPoint2Line/2"},{"type":"function","title":"Evision.XImgProc.houghPoint2Line/3","doc":"Calculates coordinates of line segment corresponded by point in Hough space.\n\n##### Positional Arguments\n- **houghPoint**: `Point`\n- **srcImgInfo**: `Evision.Mat`\n\n##### Keyword Arguments\n- **angleRange**: `integer()`.\n- **makeSkew**: `integer()`.\n- **rules**: `integer()`.\n\n##### Return\n- **retval**: `Vec4i`\n\n@retval  [Vec4i]     Coordinates of line segment corresponded by point in Hough space.\n@remarks If rules parameter set to RO_STRICT\nthen returned line cut along the border of source image.\n@remarks If rules parameter set to RO_WEAK then in case of point, which belongs\nthe incorrect part of Hough image, returned line will not intersect source image.\n The function calculates coordinates of line segment corresponded by point in Hough space.\n\nPython prototype (for reference only):\n```python3\nHoughPoint2Line(houghPoint, srcImgInfo[, angleRange[, makeSkew[, rules]]]) -> retval\n```","ref":"Evision.XImgProc.html#houghPoint2Line/3"},{"type":"function","title":"Evision.XImgProc.jointBilateralFilter/1","doc":"","ref":"Evision.XImgProc.html#jointBilateralFilter/1"},{"type":"function","title":"Evision.XImgProc.jointBilateralFilter/5","doc":"Applies the joint bilateral filter to an image.\n\n##### Positional Arguments\n- **joint**: `Evision.Mat`.\n\n  Joint 8-bit or floating-point, 1-channel or 3-channel image.\n\n- **src**: `Evision.Mat`.\n\n  Source 8-bit or floating-point, 1-channel or 3-channel image with the same depth as joint\n  image.\n\n- **d**: `integer()`.\n\n  Diameter of each pixel neighborhood that is used during filtering. If it is non-positive,\n  it is computed from sigmaSpace .\n\n- **sigmaColor**: `double`.\n\n  Filter sigma in the color space. A larger value of the parameter means that\n  farther colors within the pixel neighborhood (see sigmaSpace ) will be mixed together, resulting in\n  larger areas of semi-equal color.\n\n- **sigmaSpace**: `double`.\n\n  Filter sigma in the coordinate space. A larger value of the parameter means that\n  farther pixels will influence each other as long as their colors are close enough (see sigmaColor ).\n  When d\\>0 , it specifies the neighborhood size regardless of sigmaSpace . Otherwise, d is\n  proportional to sigmaSpace .\n\n##### Keyword Arguments\n- **borderType**: `integer()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and type as src .\n\n**Note**: bilateralFilter and jointBilateralFilter use L1 norm to compute difference between colors.\n@sa bilateralFilter, amFilter\n\nPython prototype (for reference only):\n```python3\njointBilateralFilter(joint, src, d, sigmaColor, sigmaSpace[, dst[, borderType]]) -> dst\n```","ref":"Evision.XImgProc.html#jointBilateralFilter/5"},{"type":"function","title":"Evision.XImgProc.jointBilateralFilter/6","doc":"Applies the joint bilateral filter to an image.\n\n##### Positional Arguments\n- **joint**: `Evision.Mat`.\n\n  Joint 8-bit or floating-point, 1-channel or 3-channel image.\n\n- **src**: `Evision.Mat`.\n\n  Source 8-bit or floating-point, 1-channel or 3-channel image with the same depth as joint\n  image.\n\n- **d**: `integer()`.\n\n  Diameter of each pixel neighborhood that is used during filtering. If it is non-positive,\n  it is computed from sigmaSpace .\n\n- **sigmaColor**: `double`.\n\n  Filter sigma in the color space. A larger value of the parameter means that\n  farther colors within the pixel neighborhood (see sigmaSpace ) will be mixed together, resulting in\n  larger areas of semi-equal color.\n\n- **sigmaSpace**: `double`.\n\n  Filter sigma in the coordinate space. A larger value of the parameter means that\n  farther pixels will influence each other as long as their colors are close enough (see sigmaColor ).\n  When d\\>0 , it specifies the neighborhood size regardless of sigmaSpace . Otherwise, d is\n  proportional to sigmaSpace .\n\n##### Keyword Arguments\n- **borderType**: `integer()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and type as src .\n\n**Note**: bilateralFilter and jointBilateralFilter use L1 norm to compute difference between colors.\n@sa bilateralFilter, amFilter\n\nPython prototype (for reference only):\n```python3\njointBilateralFilter(joint, src, d, sigmaColor, sigmaSpace[, dst[, borderType]]) -> dst\n```","ref":"Evision.XImgProc.html#jointBilateralFilter/6"},{"type":"function","title":"Evision.XImgProc.l0Smooth/1","doc":"Global image smoothing via L0 gradient minimization.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  source image for filtering with unsigned 8-bit or signed 16-bit or floating-point depth.\n\n##### Keyword Arguments\n- **lambda**: `double`.\n\n  parameter defining the smooth term weight.\n\n- **kappa**: `double`.\n\n  parameter defining the increasing factor of the weight of the gradient data term.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  destination image.\n\nFor more details about L0 Smoother, see the original paper @cite xu2011image.\n\nPython prototype (for reference only):\n```python3\nl0Smooth(src[, dst[, lambda[, kappa]]]) -> dst\n```","ref":"Evision.XImgProc.html#l0Smooth/1"},{"type":"function","title":"Evision.XImgProc.l0Smooth/2","doc":"Global image smoothing via L0 gradient minimization.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  source image for filtering with unsigned 8-bit or signed 16-bit or floating-point depth.\n\n##### Keyword Arguments\n- **lambda**: `double`.\n\n  parameter defining the smooth term weight.\n\n- **kappa**: `double`.\n\n  parameter defining the increasing factor of the weight of the gradient data term.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  destination image.\n\nFor more details about L0 Smoother, see the original paper @cite xu2011image.\n\nPython prototype (for reference only):\n```python3\nl0Smooth(src[, dst[, lambda[, kappa]]]) -> dst\n```","ref":"Evision.XImgProc.html#l0Smooth/2"},{"type":"function","title":"Evision.XImgProc.niBlackThreshold/1","doc":"","ref":"Evision.XImgProc.html#niBlackThreshold/1"},{"type":"function","title":"Evision.XImgProc.niBlackThreshold/5","doc":"Performs thresholding on input images using Niblack's technique or some of the\npopular variations it inspired.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source 8-bit single-channel image.\n\n- **maxValue**: `double`.\n\n  Non-zero value assigned to the pixels for which the condition is satisfied,\n  used with the THRESH_BINARY and THRESH_BINARY_INV thresholding types.\n\n- **type**: `integer()`.\n\n  Thresholding type, see cv::ThresholdTypes.\n\n- **blockSize**: `integer()`.\n\n  Size of a pixel neighborhood that is used to calculate a threshold value\n  for the pixel: 3, 5, 7, and so on.\n\n- **k**: `double`.\n\n  The user-adjustable parameter used by Niblack and inspired techniques. For Niblack, this is\n  normally a value between 0 and 1 that is multiplied with the standard deviation and subtracted from\n  the mean.\n\n##### Keyword Arguments\n- **binarizationMethod**: `integer()`.\n\n  Binarization method to use. By default, Niblack's technique is used.\n  Other techniques can be specified, see cv::ximgproc::LocalBinarizationMethods.\n\n- **r**: `double`.\n\n  The user-adjustable parameter used by Sauvola's technique. This is the dynamic range\n  of standard deviation.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and the same type as src.\n\nThe function transforms a grayscale image to a binary image according to the formulae:\n- **THRESH_BINARY**\n  \\f[dst(x,y) =  \\fork{\\texttt{maxValue}}{if \\(src(x,y) > T(x,y)\\)}{0}{otherwise}\\f]\n\n- **THRESH_BINARY_INV**\n  \\f[dst(x,y) =  \\fork{0}{if \\(src(x,y) > T(x,y)\\)}{\\texttt{maxValue}}{otherwise}\\f]\n  where \\f$T(x,y)\\f$ is a threshold calculated individually for each pixel.\n\nThe threshold value \\f$T(x, y)\\f$ is determined based on the binarization method chosen. For\nclassic Niblack, it is the mean minus \\f$ k \\f$ times standard deviation of\n\\f$\\texttt{blockSize} \\times\\texttt{blockSize}\\f$ neighborhood of \\f$(x, y)\\f$.\nThe function can't process the image in-place.\n@sa  threshold, adaptiveThreshold\n\nPython prototype (for reference only):\n```python3\nniBlackThreshold(_src, maxValue, type, blockSize, k[, _dst[, binarizationMethod[, r]]]) -> _dst\n```","ref":"Evision.XImgProc.html#niBlackThreshold/5"},{"type":"function","title":"Evision.XImgProc.niBlackThreshold/6","doc":"Performs thresholding on input images using Niblack's technique or some of the\npopular variations it inspired.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source 8-bit single-channel image.\n\n- **maxValue**: `double`.\n\n  Non-zero value assigned to the pixels for which the condition is satisfied,\n  used with the THRESH_BINARY and THRESH_BINARY_INV thresholding types.\n\n- **type**: `integer()`.\n\n  Thresholding type, see cv::ThresholdTypes.\n\n- **blockSize**: `integer()`.\n\n  Size of a pixel neighborhood that is used to calculate a threshold value\n  for the pixel: 3, 5, 7, and so on.\n\n- **k**: `double`.\n\n  The user-adjustable parameter used by Niblack and inspired techniques. For Niblack, this is\n  normally a value between 0 and 1 that is multiplied with the standard deviation and subtracted from\n  the mean.\n\n##### Keyword Arguments\n- **binarizationMethod**: `integer()`.\n\n  Binarization method to use. By default, Niblack's technique is used.\n  Other techniques can be specified, see cv::ximgproc::LocalBinarizationMethods.\n\n- **r**: `double`.\n\n  The user-adjustable parameter used by Sauvola's technique. This is the dynamic range\n  of standard deviation.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and the same type as src.\n\nThe function transforms a grayscale image to a binary image according to the formulae:\n- **THRESH_BINARY**\n  \\f[dst(x,y) =  \\fork{\\texttt{maxValue}}{if \\(src(x,y) > T(x,y)\\)}{0}{otherwise}\\f]\n\n- **THRESH_BINARY_INV**\n  \\f[dst(x,y) =  \\fork{0}{if \\(src(x,y) > T(x,y)\\)}{\\texttt{maxValue}}{otherwise}\\f]\n  where \\f$T(x,y)\\f$ is a threshold calculated individually for each pixel.\n\nThe threshold value \\f$T(x, y)\\f$ is determined based on the binarization method chosen. For\nclassic Niblack, it is the mean minus \\f$ k \\f$ times standard deviation of\n\\f$\\texttt{blockSize} \\times\\texttt{blockSize}\\f$ neighborhood of \\f$(x, y)\\f$.\nThe function can't process the image in-place.\n@sa  threshold, adaptiveThreshold\n\nPython prototype (for reference only):\n```python3\nniBlackThreshold(_src, maxValue, type, blockSize, k[, _dst[, binarizationMethod[, r]]]) -> _dst\n```","ref":"Evision.XImgProc.html#niBlackThreshold/6"},{"type":"function","title":"Evision.XImgProc.peiLinNormalization/1","doc":"PeiLinNormalization\n\n##### Positional Arguments\n- **i**: `Evision.Mat`\n\n##### Return\n- **t**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nPeiLinNormalization(I[, T]) -> T\n```","ref":"Evision.XImgProc.html#peiLinNormalization/1"},{"type":"function","title":"Evision.XImgProc.peiLinNormalization/2","doc":"PeiLinNormalization\n\n##### Positional Arguments\n- **i**: `Evision.Mat`\n\n##### Return\n- **t**: `Evision.Mat.t()`.\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nPeiLinNormalization(I[, T]) -> T\n```","ref":"Evision.XImgProc.html#peiLinNormalization/2"},{"type":"function","title":"Evision.XImgProc.qconj/1","doc":"calculates conjugate of a quaternion image.\n\n##### Positional Arguments\n- **qimg**: `Evision.Mat`\n\n##### Return\n- **qcimg**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nqconj(qimg[, qcimg]) -> qcimg\n```","ref":"Evision.XImgProc.html#qconj/1"},{"type":"function","title":"Evision.XImgProc.qconj/2","doc":"calculates conjugate of a quaternion image.\n\n##### Positional Arguments\n- **qimg**: `Evision.Mat`\n\n##### Return\n- **qcimg**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nqconj(qimg[, qcimg]) -> qcimg\n```","ref":"Evision.XImgProc.html#qconj/2"},{"type":"function","title":"Evision.XImgProc.qdft/1","doc":"","ref":"Evision.XImgProc.html#qdft/1"},{"type":"function","title":"Evision.XImgProc.qdft/3","doc":"Performs a forward or inverse Discrete quaternion Fourier transform of a 2D quaternion array.\n\n##### Positional Arguments\n- **img**: `Evision.Mat`\n- **flags**: `integer()`\n- **sideLeft**: `bool`\n\n##### Return\n- **qimg**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nqdft(img, flags, sideLeft[, qimg]) -> qimg\n```","ref":"Evision.XImgProc.html#qdft/3"},{"type":"function","title":"Evision.XImgProc.qdft/4","doc":"Performs a forward or inverse Discrete quaternion Fourier transform of a 2D quaternion array.\n\n##### Positional Arguments\n- **img**: `Evision.Mat`\n- **flags**: `integer()`\n- **sideLeft**: `bool`\n\n##### Return\n- **qimg**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nqdft(img, flags, sideLeft[, qimg]) -> qimg\n```","ref":"Evision.XImgProc.html#qdft/4"},{"type":"function","title":"Evision.XImgProc.qmultiply/1","doc":"","ref":"Evision.XImgProc.html#qmultiply/1"},{"type":"function","title":"Evision.XImgProc.qmultiply/2","doc":"Calculates the per-element quaternion product of two arrays\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`\n- **src2**: `Evision.Mat`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nqmultiply(src1, src2[, dst]) -> dst\n```","ref":"Evision.XImgProc.html#qmultiply/2"},{"type":"function","title":"Evision.XImgProc.qmultiply/3","doc":"Calculates the per-element quaternion product of two arrays\n\n##### Positional Arguments\n- **src1**: `Evision.Mat`\n- **src2**: `Evision.Mat`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nqmultiply(src1, src2[, dst]) -> dst\n```","ref":"Evision.XImgProc.html#qmultiply/3"},{"type":"function","title":"Evision.XImgProc.qunitary/1","doc":"divides each element by its modulus.\n\n##### Positional Arguments\n- **qimg**: `Evision.Mat`\n\n##### Return\n- **qnimg**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nqunitary(qimg[, qnimg]) -> qnimg\n```","ref":"Evision.XImgProc.html#qunitary/1"},{"type":"function","title":"Evision.XImgProc.qunitary/2","doc":"divides each element by its modulus.\n\n##### Positional Arguments\n- **qimg**: `Evision.Mat`\n\n##### Return\n- **qnimg**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\nqunitary(qimg[, qnimg]) -> qnimg\n```","ref":"Evision.XImgProc.html#qunitary/2"},{"type":"function","title":"Evision.XImgProc.radonTransform/1","doc":"Calculate Radon Transform of an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **theta**: `double`.\n- **start_angle**: `double`.\n- **end_angle**: `double`.\n- **crop**: `bool`.\n- **norm**: `bool`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n This function calculates the Radon Transform of a given image in any range.\n See https://engineering.purdue.edu/~malcolm/pct/CTI_Ch03.pdf for detail.\n If the input type is CV_8U, the output will be CV_32S.\n If the input type is CV_32F or CV_64F, the output will be CV_64F\n The output size will be num_of_integral x src_diagonal_length.\n If crop is selected, the input image will be crop into square then circle,\n and output size will be num_of_integral x min_edge.\n\nPython prototype (for reference only):\n```python3\nRadonTransform(src[, dst[, theta[, start_angle[, end_angle[, crop[, norm]]]]]]) -> dst\n```","ref":"Evision.XImgProc.html#radonTransform/1"},{"type":"function","title":"Evision.XImgProc.radonTransform/2","doc":"Calculate Radon Transform of an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n\n##### Keyword Arguments\n- **theta**: `double`.\n- **start_angle**: `double`.\n- **end_angle**: `double`.\n- **crop**: `bool`.\n- **norm**: `bool`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n This function calculates the Radon Transform of a given image in any range.\n See https://engineering.purdue.edu/~malcolm/pct/CTI_Ch03.pdf for detail.\n If the input type is CV_8U, the output will be CV_32S.\n If the input type is CV_32F or CV_64F, the output will be CV_64F\n The output size will be num_of_integral x src_diagonal_length.\n If crop is selected, the input image will be crop into square then circle,\n and output size will be num_of_integral x min_edge.\n\nPython prototype (for reference only):\n```python3\nRadonTransform(src[, dst[, theta[, start_angle[, end_angle[, crop[, norm]]]]]]) -> dst\n```","ref":"Evision.XImgProc.html#radonTransform/2"},{"type":"function","title":"Evision.XImgProc.readGT/1","doc":"Function for reading ground truth disparity maps. Supports basic Middlebury\nand MPI-Sintel formats. Note that the resulting disparity map is scaled by 16.\n\n##### Positional Arguments\n- **src_path**: `String`.\n\n  path to the image, containing ground-truth disparity map\n\n##### Return\n- **retval**: `integer()`\n- **dst**: `Evision.Mat.t()`.\n\n  output disparity map, CV_16S depth\n\n@result returns zero if successfully read the ground truth\n\nPython prototype (for reference only):\n```python3\nreadGT(src_path[, dst]) -> retval, dst\n```","ref":"Evision.XImgProc.html#readGT/1"},{"type":"function","title":"Evision.XImgProc.readGT/2","doc":"Function for reading ground truth disparity maps. Supports basic Middlebury\nand MPI-Sintel formats. Note that the resulting disparity map is scaled by 16.\n\n##### Positional Arguments\n- **src_path**: `String`.\n\n  path to the image, containing ground-truth disparity map\n\n##### Return\n- **retval**: `integer()`\n- **dst**: `Evision.Mat.t()`.\n\n  output disparity map, CV_16S depth\n\n@result returns zero if successfully read the ground truth\n\nPython prototype (for reference only):\n```python3\nreadGT(src_path[, dst]) -> retval, dst\n```","ref":"Evision.XImgProc.html#readGT/2"},{"type":"function","title":"Evision.XImgProc.rollingGuidanceFilter/1","doc":"Applies the rolling guidance filter to an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source 8-bit or floating-point, 1-channel or 3-channel image.\n\n##### Keyword Arguments\n- **d**: `integer()`.\n\n  Diameter of each pixel neighborhood that is used during filtering. If it is non-positive,\n  it is computed from sigmaSpace .\n\n- **sigmaColor**: `double`.\n\n  Filter sigma in the color space. A larger value of the parameter means that\n  farther colors within the pixel neighborhood (see sigmaSpace ) will be mixed together, resulting in\n  larger areas of semi-equal color.\n\n- **sigmaSpace**: `double`.\n\n  Filter sigma in the coordinate space. A larger value of the parameter means that\n  farther pixels will influence each other as long as their colors are close enough (see sigmaColor ).\n  When d\\>0 , it specifies the neighborhood size regardless of sigmaSpace . Otherwise, d is\n  proportional to sigmaSpace .\n\n- **numOfIter**: `integer()`.\n\n  Number of iterations of joint edge-preserving filtering applied on the source image.\n\n- **borderType**: `integer()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and type as src.\n\nFor more details, please see @cite zhang2014rolling\n\n**Note**: rollingGuidanceFilter uses jointBilateralFilter as the edge-preserving filter.\n@sa jointBilateralFilter, bilateralFilter, amFilter\n\nPython prototype (for reference only):\n```python3\nrollingGuidanceFilter(src[, dst[, d[, sigmaColor[, sigmaSpace[, numOfIter[, borderType]]]]]]) -> dst\n```","ref":"Evision.XImgProc.html#rollingGuidanceFilter/1"},{"type":"function","title":"Evision.XImgProc.rollingGuidanceFilter/2","doc":"Applies the rolling guidance filter to an image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source 8-bit or floating-point, 1-channel or 3-channel image.\n\n##### Keyword Arguments\n- **d**: `integer()`.\n\n  Diameter of each pixel neighborhood that is used during filtering. If it is non-positive,\n  it is computed from sigmaSpace .\n\n- **sigmaColor**: `double`.\n\n  Filter sigma in the color space. A larger value of the parameter means that\n  farther colors within the pixel neighborhood (see sigmaSpace ) will be mixed together, resulting in\n  larger areas of semi-equal color.\n\n- **sigmaSpace**: `double`.\n\n  Filter sigma in the coordinate space. A larger value of the parameter means that\n  farther pixels will influence each other as long as their colors are close enough (see sigmaColor ).\n  When d\\>0 , it specifies the neighborhood size regardless of sigmaSpace . Otherwise, d is\n  proportional to sigmaSpace .\n\n- **numOfIter**: `integer()`.\n\n  Number of iterations of joint edge-preserving filtering applied on the source image.\n\n- **borderType**: `integer()`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and type as src.\n\nFor more details, please see @cite zhang2014rolling\n\n**Note**: rollingGuidanceFilter uses jointBilateralFilter as the edge-preserving filter.\n@sa jointBilateralFilter, bilateralFilter, amFilter\n\nPython prototype (for reference only):\n```python3\nrollingGuidanceFilter(src[, dst[, d[, sigmaColor[, sigmaSpace[, numOfIter[, borderType]]]]]]) -> dst\n```","ref":"Evision.XImgProc.html#rollingGuidanceFilter/2"},{"type":"function","title":"Evision.XImgProc.thinning/1","doc":"Applies a binary blob thinning operation, to achieve a skeletization of the input image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source 8-bit single-channel image, containing binary blobs, with blobs having 255 pixel values.\n\n##### Keyword Arguments\n- **thinningType**: `integer()`.\n\n  Value that defines which thinning algorithm should be used. See cv::ximgproc::ThinningTypes\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and the same type as src. The function can work in-place.\n\nThe function transforms a binary blob image into a skeletized form using the technique of Zhang-Suen.\n\nPython prototype (for reference only):\n```python3\nthinning(src[, dst[, thinningType]]) -> dst\n```","ref":"Evision.XImgProc.html#thinning/1"},{"type":"function","title":"Evision.XImgProc.thinning/2","doc":"Applies a binary blob thinning operation, to achieve a skeletization of the input image.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Source 8-bit single-channel image, containing binary blobs, with blobs having 255 pixel values.\n\n##### Keyword Arguments\n- **thinningType**: `integer()`.\n\n  Value that defines which thinning algorithm should be used. See cv::ximgproc::ThinningTypes\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Destination image of the same size and the same type as src. The function can work in-place.\n\nThe function transforms a binary blob image into a skeletized form using the technique of Zhang-Suen.\n\nPython prototype (for reference only):\n```python3\nthinning(src[, dst[, thinningType]]) -> dst\n```","ref":"Evision.XImgProc.html#thinning/2"},{"type":"function","title":"Evision.XImgProc.transformFD/1","doc":"","ref":"Evision.XImgProc.html#transformFD/1"},{"type":"function","title":"Evision.XImgProc.transformFD/2","doc":"transform a contour\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n- **t**: `Evision.Mat`\n\n##### Keyword Arguments\n- **fdContour**: `bool`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ntransformFD(src, t[, dst[, fdContour]]) -> dst\n```","ref":"Evision.XImgProc.html#transformFD/2"},{"type":"function","title":"Evision.XImgProc.transformFD/3","doc":"transform a contour\n\n##### Positional Arguments\n- **src**: `Evision.Mat`\n- **t**: `Evision.Mat`\n\n##### Keyword Arguments\n- **fdContour**: `bool`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\nPython prototype (for reference only):\n```python3\ntransformFD(src, t[, dst[, fdContour]]) -> dst\n```","ref":"Evision.XImgProc.html#transformFD/3"},{"type":"function","title":"Evision.XImgProc.weightedMedianFilter/1","doc":"","ref":"Evision.XImgProc.html#weightedMedianFilter/1"},{"type":"function","title":"Evision.XImgProc.weightedMedianFilter/3","doc":"Applies weighted median filter to an image.\n\n##### Positional Arguments\n- **joint**: `Evision.Mat`\n- **src**: `Evision.Mat`\n- **r**: `integer()`\n\n##### Keyword Arguments\n- **sigma**: `double`.\n- **weightType**: `integer()`.\n- **mask**: `Evision.Mat`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n For more details about this implementation, please see @cite zhang2014100+\n\n@sa medianBlur, jointBilateralFilter\n\nPython prototype (for reference only):\n```python3\nweightedMedianFilter(joint, src, r[, dst[, sigma[, weightType[, mask]]]]) -> dst\n```","ref":"Evision.XImgProc.html#weightedMedianFilter/3"},{"type":"function","title":"Evision.XImgProc.weightedMedianFilter/4","doc":"Applies weighted median filter to an image.\n\n##### Positional Arguments\n- **joint**: `Evision.Mat`\n- **src**: `Evision.Mat`\n- **r**: `integer()`\n\n##### Keyword Arguments\n- **sigma**: `double`.\n- **weightType**: `integer()`.\n- **mask**: `Evision.Mat`.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n For more details about this implementation, please see @cite zhang2014100+\n\n@sa medianBlur, jointBilateralFilter\n\nPython prototype (for reference only):\n```python3\nweightedMedianFilter(joint, src, r[, dst[, sigma[, weightType[, mask]]]]) -> dst\n```","ref":"Evision.XImgProc.html#weightedMedianFilter/4"},{"type":"type","title":"Evision.XImgProc.t/0","doc":"Type that represents an `XImgProc` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.AdaptiveManifoldFilter","doc":"","ref":"Evision.XImgProc.AdaptiveManifoldFilter.html"},{"type":"function","title":"Evision.XImgProc.AdaptiveManifoldFilter.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.AdaptiveManifoldFilter.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XImgProc.AdaptiveManifoldFilter.html#clear/1"},{"type":"function","title":"Evision.XImgProc.AdaptiveManifoldFilter.collectGarbage/1","doc":"collectGarbage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.AdaptiveManifoldFilter.t()`\n\nPython prototype (for reference only):\n```python3\ncollectGarbage() -> None\n```","ref":"Evision.XImgProc.AdaptiveManifoldFilter.html#collectGarbage/1"},{"type":"function","title":"Evision.XImgProc.AdaptiveManifoldFilter.create/0","doc":"create\n##### Return\n- **retval**: `Evision.XImgProc.AdaptiveManifoldFilter.t()`\n\nPython prototype (for reference only):\n```python3\ncreate() -> retval\n```","ref":"Evision.XImgProc.AdaptiveManifoldFilter.html#create/0"},{"type":"function","title":"Evision.XImgProc.AdaptiveManifoldFilter.create/1","doc":"","ref":"Evision.XImgProc.AdaptiveManifoldFilter.html#create/1"},{"type":"function","title":"Evision.XImgProc.AdaptiveManifoldFilter.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.AdaptiveManifoldFilter.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XImgProc.AdaptiveManifoldFilter.html#empty/1"},{"type":"function","title":"Evision.XImgProc.AdaptiveManifoldFilter.filter/1","doc":"","ref":"Evision.XImgProc.AdaptiveManifoldFilter.html#filter/1"},{"type":"function","title":"Evision.XImgProc.AdaptiveManifoldFilter.filter/2","doc":"Apply high-dimensional filtering using adaptive manifolds.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.AdaptiveManifoldFilter.t()`\n- **src**: `Evision.Mat`.\n\n  filtering image with any numbers of channels.\n\n##### Keyword Arguments\n- **joint**: `Evision.Mat`.\n\n  optional joint (also called as guided) image with any numbers of channels.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image.\n\nPython prototype (for reference only):\n```python3\nfilter(src[, dst[, joint]]) -> dst\n```","ref":"Evision.XImgProc.AdaptiveManifoldFilter.html#filter/2"},{"type":"function","title":"Evision.XImgProc.AdaptiveManifoldFilter.filter/3","doc":"Apply high-dimensional filtering using adaptive manifolds.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.AdaptiveManifoldFilter.t()`\n- **src**: `Evision.Mat`.\n\n  filtering image with any numbers of channels.\n\n##### Keyword Arguments\n- **joint**: `Evision.Mat`.\n\n  optional joint (also called as guided) image with any numbers of channels.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image.\n\nPython prototype (for reference only):\n```python3\nfilter(src[, dst[, joint]]) -> dst\n```","ref":"Evision.XImgProc.AdaptiveManifoldFilter.html#filter/3"},{"type":"function","title":"Evision.XImgProc.AdaptiveManifoldFilter.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.AdaptiveManifoldFilter.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XImgProc.AdaptiveManifoldFilter.html#getDefaultName/1"},{"type":"function","title":"Evision.XImgProc.AdaptiveManifoldFilter.read/1","doc":"","ref":"Evision.XImgProc.AdaptiveManifoldFilter.html#read/1"},{"type":"function","title":"Evision.XImgProc.AdaptiveManifoldFilter.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.AdaptiveManifoldFilter.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XImgProc.AdaptiveManifoldFilter.html#read/2"},{"type":"function","title":"Evision.XImgProc.AdaptiveManifoldFilter.save/1","doc":"","ref":"Evision.XImgProc.AdaptiveManifoldFilter.html#save/1"},{"type":"function","title":"Evision.XImgProc.AdaptiveManifoldFilter.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.AdaptiveManifoldFilter.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XImgProc.AdaptiveManifoldFilter.html#save/2"},{"type":"function","title":"Evision.XImgProc.AdaptiveManifoldFilter.write/1","doc":"","ref":"Evision.XImgProc.AdaptiveManifoldFilter.html#write/1"},{"type":"function","title":"Evision.XImgProc.AdaptiveManifoldFilter.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.AdaptiveManifoldFilter.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XImgProc.AdaptiveManifoldFilter.html#write/2"},{"type":"function","title":"Evision.XImgProc.AdaptiveManifoldFilter.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.AdaptiveManifoldFilter.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XImgProc.AdaptiveManifoldFilter.html#write/3"},{"type":"type","title":"Evision.XImgProc.AdaptiveManifoldFilter.t/0","doc":"Type that represents an `XImgProc.AdaptiveManifoldFilter` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.AdaptiveManifoldFilter.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.AngleRangeOption","doc":"","ref":"Evision.XImgProc.AngleRangeOption.html"},{"type":"function","title":"Evision.XImgProc.AngleRangeOption.cv_ARO_0_45/0","doc":"","ref":"Evision.XImgProc.AngleRangeOption.html#cv_ARO_0_45/0"},{"type":"function","title":"Evision.XImgProc.AngleRangeOption.cv_ARO_45_90/0","doc":"","ref":"Evision.XImgProc.AngleRangeOption.html#cv_ARO_45_90/0"},{"type":"function","title":"Evision.XImgProc.AngleRangeOption.cv_ARO_45_135/0","doc":"","ref":"Evision.XImgProc.AngleRangeOption.html#cv_ARO_45_135/0"},{"type":"function","title":"Evision.XImgProc.AngleRangeOption.cv_ARO_90_135/0","doc":"","ref":"Evision.XImgProc.AngleRangeOption.html#cv_ARO_90_135/0"},{"type":"function","title":"Evision.XImgProc.AngleRangeOption.cv_ARO_315_0/0","doc":"","ref":"Evision.XImgProc.AngleRangeOption.html#cv_ARO_315_0/0"},{"type":"function","title":"Evision.XImgProc.AngleRangeOption.cv_ARO_315_45/0","doc":"","ref":"Evision.XImgProc.AngleRangeOption.html#cv_ARO_315_45/0"},{"type":"function","title":"Evision.XImgProc.AngleRangeOption.cv_ARO_315_135/0","doc":"","ref":"Evision.XImgProc.AngleRangeOption.html#cv_ARO_315_135/0"},{"type":"function","title":"Evision.XImgProc.AngleRangeOption.cv_ARO_CTR_HOR/0","doc":"","ref":"Evision.XImgProc.AngleRangeOption.html#cv_ARO_CTR_HOR/0"},{"type":"function","title":"Evision.XImgProc.AngleRangeOption.cv_ARO_CTR_VER/0","doc":"","ref":"Evision.XImgProc.AngleRangeOption.html#cv_ARO_CTR_VER/0"},{"type":"type","title":"Evision.XImgProc.AngleRangeOption.enum/0","doc":"","ref":"Evision.XImgProc.AngleRangeOption.html#t:enum/0"},{"type":"module","title":"Evision.XImgProc.ContourFitting","doc":"","ref":"Evision.XImgProc.ContourFitting.html"},{"type":"function","title":"Evision.XImgProc.ContourFitting.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ContourFitting.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XImgProc.ContourFitting.html#clear/1"},{"type":"function","title":"Evision.XImgProc.ContourFitting.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ContourFitting.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XImgProc.ContourFitting.html#empty/1"},{"type":"function","title":"Evision.XImgProc.ContourFitting.estimateTransformation/1","doc":"","ref":"Evision.XImgProc.ContourFitting.html#estimateTransformation/1"},{"type":"function","title":"Evision.XImgProc.ContourFitting.estimateTransformation/3","doc":"Fit two closed curves using fourier descriptors. More details in @cite PersoonFu1977 and @cite BergerRaghunathan1998\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ContourFitting.t()`\n- **src**: `Evision.Mat`.\n\n  Contour defining first shape.\n\n- **dst**: `Evision.Mat`.\n\n  Contour defining second shape (Target).\n\n##### Keyword Arguments\n- **fdContour**: `bool`.\n\n  false then src and dst are contours and true src and dst are fourier descriptors.\n\n##### Return\n- **alphaPhiST**: `Evision.Mat.t()`.\n\n  : \\f$ \\alpha \\f$=alphaPhiST(0,0), \\f$ \\phi \\f$=alphaPhiST(0,1) (in radian), s=alphaPhiST(0,2), Tx=alphaPhiST(0,3), Ty=alphaPhiST(0,4) rotation center\n\n- **dist**: `double`.\n\n  distance between src and dst after matching.\n\nPython prototype (for reference only):\n```python3\nestimateTransformation(src, dst[, alphaPhiST[, fdContour]]) -> alphaPhiST, dist\n```","ref":"Evision.XImgProc.ContourFitting.html#estimateTransformation/3"},{"type":"function","title":"Evision.XImgProc.ContourFitting.estimateTransformation/4","doc":"Fit two closed curves using fourier descriptors. More details in @cite PersoonFu1977 and @cite BergerRaghunathan1998\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ContourFitting.t()`\n- **src**: `Evision.Mat`.\n\n  Contour defining first shape.\n\n- **dst**: `Evision.Mat`.\n\n  Contour defining second shape (Target).\n\n##### Keyword Arguments\n- **fdContour**: `bool`.\n\n  false then src and dst are contours and true src and dst are fourier descriptors.\n\n##### Return\n- **alphaPhiST**: `Evision.Mat.t()`.\n\n  : \\f$ \\alpha \\f$=alphaPhiST(0,0), \\f$ \\phi \\f$=alphaPhiST(0,1) (in radian), s=alphaPhiST(0,2), Tx=alphaPhiST(0,3), Ty=alphaPhiST(0,4) rotation center\n\n- **dist**: `double`.\n\n  distance between src and dst after matching.\n\nPython prototype (for reference only):\n```python3\nestimateTransformation(src, dst[, alphaPhiST[, fdContour]]) -> alphaPhiST, dist\n```","ref":"Evision.XImgProc.ContourFitting.html#estimateTransformation/4"},{"type":"function","title":"Evision.XImgProc.ContourFitting.getCtrSize/1","doc":"getCtrSize\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ContourFitting.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@returns number of fourier descriptors\n\nPython prototype (for reference only):\n```python3\ngetCtrSize() -> retval\n```","ref":"Evision.XImgProc.ContourFitting.html#getCtrSize/1"},{"type":"function","title":"Evision.XImgProc.ContourFitting.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ContourFitting.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XImgProc.ContourFitting.html#getDefaultName/1"},{"type":"function","title":"Evision.XImgProc.ContourFitting.getFDSize/1","doc":"getFDSize\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ContourFitting.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@returns number of fourier descriptors used for optimal curve matching\n\nPython prototype (for reference only):\n```python3\ngetFDSize() -> retval\n```","ref":"Evision.XImgProc.ContourFitting.html#getFDSize/1"},{"type":"function","title":"Evision.XImgProc.ContourFitting.read/1","doc":"","ref":"Evision.XImgProc.ContourFitting.html#read/1"},{"type":"function","title":"Evision.XImgProc.ContourFitting.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ContourFitting.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XImgProc.ContourFitting.html#read/2"},{"type":"function","title":"Evision.XImgProc.ContourFitting.save/1","doc":"","ref":"Evision.XImgProc.ContourFitting.html#save/1"},{"type":"function","title":"Evision.XImgProc.ContourFitting.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ContourFitting.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XImgProc.ContourFitting.html#save/2"},{"type":"function","title":"Evision.XImgProc.ContourFitting.setCtrSize/1","doc":"","ref":"Evision.XImgProc.ContourFitting.html#setCtrSize/1"},{"type":"function","title":"Evision.XImgProc.ContourFitting.setCtrSize/2","doc":"set number of Fourier descriptors used in estimateTransformation\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ContourFitting.t()`\n- **n**: `integer()`.\n\n  number of Fourier descriptors equal to number of contour points after resampling.\n\nPython prototype (for reference only):\n```python3\nsetCtrSize(n) -> None\n```","ref":"Evision.XImgProc.ContourFitting.html#setCtrSize/2"},{"type":"function","title":"Evision.XImgProc.ContourFitting.setFDSize/1","doc":"","ref":"Evision.XImgProc.ContourFitting.html#setFDSize/1"},{"type":"function","title":"Evision.XImgProc.ContourFitting.setFDSize/2","doc":"set number of Fourier descriptors when estimateTransformation used vector \n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ContourFitting.t()`\n- **n**: `integer()`.\n\n  number of fourier descriptors used for optimal curve matching.\n\nPython prototype (for reference only):\n```python3\nsetFDSize(n) -> None\n```","ref":"Evision.XImgProc.ContourFitting.html#setFDSize/2"},{"type":"function","title":"Evision.XImgProc.ContourFitting.write/1","doc":"","ref":"Evision.XImgProc.ContourFitting.html#write/1"},{"type":"function","title":"Evision.XImgProc.ContourFitting.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ContourFitting.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XImgProc.ContourFitting.html#write/2"},{"type":"function","title":"Evision.XImgProc.ContourFitting.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ContourFitting.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XImgProc.ContourFitting.html#write/3"},{"type":"type","title":"Evision.XImgProc.ContourFitting.t/0","doc":"Type that represents an `XImgProc.ContourFitting` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.ContourFitting.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.DTFilter","doc":"","ref":"Evision.XImgProc.DTFilter.html"},{"type":"function","title":"Evision.XImgProc.DTFilter.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DTFilter.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XImgProc.DTFilter.html#clear/1"},{"type":"function","title":"Evision.XImgProc.DTFilter.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DTFilter.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XImgProc.DTFilter.html#empty/1"},{"type":"function","title":"Evision.XImgProc.DTFilter.filter/1","doc":"","ref":"Evision.XImgProc.DTFilter.html#filter/1"},{"type":"function","title":"Evision.XImgProc.DTFilter.filter/2","doc":"Produce domain transform filtering operation on source image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DTFilter.t()`\n- **src**: `Evision.Mat`.\n\n  filtering image with unsigned 8-bit or floating-point 32-bit depth and up to 4 channels.\n\n##### Keyword Arguments\n- **dDepth**: `integer()`.\n\n  optional depth of the output image. dDepth can be set to -1, which will be equivalent\n  to src.depth().\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  destination image.\n\nPython prototype (for reference only):\n```python3\nfilter(src[, dst[, dDepth]]) -> dst\n```","ref":"Evision.XImgProc.DTFilter.html#filter/2"},{"type":"function","title":"Evision.XImgProc.DTFilter.filter/3","doc":"Produce domain transform filtering operation on source image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DTFilter.t()`\n- **src**: `Evision.Mat`.\n\n  filtering image with unsigned 8-bit or floating-point 32-bit depth and up to 4 channels.\n\n##### Keyword Arguments\n- **dDepth**: `integer()`.\n\n  optional depth of the output image. dDepth can be set to -1, which will be equivalent\n  to src.depth().\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  destination image.\n\nPython prototype (for reference only):\n```python3\nfilter(src[, dst[, dDepth]]) -> dst\n```","ref":"Evision.XImgProc.DTFilter.html#filter/3"},{"type":"function","title":"Evision.XImgProc.DTFilter.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DTFilter.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XImgProc.DTFilter.html#getDefaultName/1"},{"type":"function","title":"Evision.XImgProc.DTFilter.read/1","doc":"","ref":"Evision.XImgProc.DTFilter.html#read/1"},{"type":"function","title":"Evision.XImgProc.DTFilter.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DTFilter.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XImgProc.DTFilter.html#read/2"},{"type":"function","title":"Evision.XImgProc.DTFilter.save/1","doc":"","ref":"Evision.XImgProc.DTFilter.html#save/1"},{"type":"function","title":"Evision.XImgProc.DTFilter.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DTFilter.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XImgProc.DTFilter.html#save/2"},{"type":"function","title":"Evision.XImgProc.DTFilter.write/1","doc":"","ref":"Evision.XImgProc.DTFilter.html#write/1"},{"type":"function","title":"Evision.XImgProc.DTFilter.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DTFilter.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XImgProc.DTFilter.html#write/2"},{"type":"function","title":"Evision.XImgProc.DTFilter.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DTFilter.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XImgProc.DTFilter.html#write/3"},{"type":"type","title":"Evision.XImgProc.DTFilter.t/0","doc":"Type that represents an `XImgProc.DTFilter` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.DTFilter.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.DisparityFilter","doc":"","ref":"Evision.XImgProc.DisparityFilter.html"},{"type":"function","title":"Evision.XImgProc.DisparityFilter.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DisparityFilter.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XImgProc.DisparityFilter.html#clear/1"},{"type":"function","title":"Evision.XImgProc.DisparityFilter.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DisparityFilter.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XImgProc.DisparityFilter.html#empty/1"},{"type":"function","title":"Evision.XImgProc.DisparityFilter.filter/1","doc":"","ref":"Evision.XImgProc.DisparityFilter.html#filter/1"},{"type":"function","title":"Evision.XImgProc.DisparityFilter.filter/3","doc":"Apply filtering to the disparity map.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DisparityFilter.t()`\n- **disparity_map_left**: `Evision.Mat`.\n\n  disparity map of the left view, 1 channel, CV_16S type. Implicitly assumes that disparity\n  values are scaled by 16 (one-pixel disparity corresponds to the value of 16 in the disparity map). Disparity map\n  can have any resolution, it will be automatically resized to fit left_view resolution.\n\n- **left_view**: `Evision.Mat`.\n\n  left view of the original stereo-pair to guide the filtering process, 8-bit single-channel\n  or three-channel image.\n\n##### Keyword Arguments\n- **disparity_map_right**: `Evision.Mat`.\n\n  optional argument, some implementations might also use the disparity map\n  of the right view to compute confidence maps, for instance.\n\n- **rOI**: `Rect`.\n\n  region of the disparity map to filter. Optional, usually it should be set automatically.\n\n- **right_view**: `Evision.Mat`.\n\n  optional argument, some implementations might also use the right view of the original\n  stereo-pair.\n\n##### Return\n- **filtered_disparity_map**: `Evision.Mat.t()`.\n\n  output disparity map.\n\nPython prototype (for reference only):\n```python3\nfilter(disparity_map_left, left_view[, filtered_disparity_map[, disparity_map_right[, ROI[, right_view]]]]) -> filtered_disparity_map\n```","ref":"Evision.XImgProc.DisparityFilter.html#filter/3"},{"type":"function","title":"Evision.XImgProc.DisparityFilter.filter/4","doc":"Apply filtering to the disparity map.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DisparityFilter.t()`\n- **disparity_map_left**: `Evision.Mat`.\n\n  disparity map of the left view, 1 channel, CV_16S type. Implicitly assumes that disparity\n  values are scaled by 16 (one-pixel disparity corresponds to the value of 16 in the disparity map). Disparity map\n  can have any resolution, it will be automatically resized to fit left_view resolution.\n\n- **left_view**: `Evision.Mat`.\n\n  left view of the original stereo-pair to guide the filtering process, 8-bit single-channel\n  or three-channel image.\n\n##### Keyword Arguments\n- **disparity_map_right**: `Evision.Mat`.\n\n  optional argument, some implementations might also use the disparity map\n  of the right view to compute confidence maps, for instance.\n\n- **rOI**: `Rect`.\n\n  region of the disparity map to filter. Optional, usually it should be set automatically.\n\n- **right_view**: `Evision.Mat`.\n\n  optional argument, some implementations might also use the right view of the original\n  stereo-pair.\n\n##### Return\n- **filtered_disparity_map**: `Evision.Mat.t()`.\n\n  output disparity map.\n\nPython prototype (for reference only):\n```python3\nfilter(disparity_map_left, left_view[, filtered_disparity_map[, disparity_map_right[, ROI[, right_view]]]]) -> filtered_disparity_map\n```","ref":"Evision.XImgProc.DisparityFilter.html#filter/4"},{"type":"function","title":"Evision.XImgProc.DisparityFilter.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DisparityFilter.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XImgProc.DisparityFilter.html#getDefaultName/1"},{"type":"function","title":"Evision.XImgProc.DisparityFilter.read/1","doc":"","ref":"Evision.XImgProc.DisparityFilter.html#read/1"},{"type":"function","title":"Evision.XImgProc.DisparityFilter.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DisparityFilter.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XImgProc.DisparityFilter.html#read/2"},{"type":"function","title":"Evision.XImgProc.DisparityFilter.save/1","doc":"","ref":"Evision.XImgProc.DisparityFilter.html#save/1"},{"type":"function","title":"Evision.XImgProc.DisparityFilter.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DisparityFilter.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XImgProc.DisparityFilter.html#save/2"},{"type":"function","title":"Evision.XImgProc.DisparityFilter.write/1","doc":"","ref":"Evision.XImgProc.DisparityFilter.html#write/1"},{"type":"function","title":"Evision.XImgProc.DisparityFilter.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DisparityFilter.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XImgProc.DisparityFilter.html#write/2"},{"type":"function","title":"Evision.XImgProc.DisparityFilter.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DisparityFilter.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XImgProc.DisparityFilter.html#write/3"},{"type":"type","title":"Evision.XImgProc.DisparityFilter.t/0","doc":"Type that represents an `XImgProc.DisparityFilter` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.DisparityFilter.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.DisparityWLSFilter","doc":"","ref":"Evision.XImgProc.DisparityWLSFilter.html"},{"type":"function","title":"Evision.XImgProc.DisparityWLSFilter.getConfidenceMap/1","doc":"Get the confidence map that was used in the last filter call. It is a CV_32F one-channel image\nwith values ranging from 0.0 (totally untrusted regions of the raw disparity map) to 255.0 (regions containing\ncorrect disparity values with a high degree of confidence).\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DisparityWLSFilter.t()`\n\n##### Return\n- **retval**: `Evision.Mat.t()`\n\nPython prototype (for reference only):\n```python3\ngetConfidenceMap() -> retval\n```","ref":"Evision.XImgProc.DisparityWLSFilter.html#getConfidenceMap/1"},{"type":"function","title":"Evision.XImgProc.DisparityWLSFilter.getDepthDiscontinuityRadius/1","doc":"DepthDiscontinuityRadius is a parameter used in confidence computation. It defines the size of\nlow-confidence regions around depth discontinuities.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DisparityWLSFilter.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetDepthDiscontinuityRadius() -> retval\n```","ref":"Evision.XImgProc.DisparityWLSFilter.html#getDepthDiscontinuityRadius/1"},{"type":"function","title":"Evision.XImgProc.DisparityWLSFilter.getLambda/1","doc":"Lambda is a parameter defining the amount of regularization during filtering. Larger values force\nfiltered disparity map edges to adhere more to source image edges. Typical value is 8000.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DisparityWLSFilter.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetLambda() -> retval\n```","ref":"Evision.XImgProc.DisparityWLSFilter.html#getLambda/1"},{"type":"function","title":"Evision.XImgProc.DisparityWLSFilter.getLRCthresh/1","doc":"LRCthresh is a threshold of disparity difference used in left-right-consistency check during\nconfidence map computation. The default value of 24 (1.5 pixels) is virtually always good enough.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DisparityWLSFilter.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetLRCthresh() -> retval\n```","ref":"Evision.XImgProc.DisparityWLSFilter.html#getLRCthresh/1"},{"type":"function","title":"Evision.XImgProc.DisparityWLSFilter.getROI/1","doc":"Get the ROI used in the last filter call\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DisparityWLSFilter.t()`\n\n##### Return\n- **retval**: `Rect`\n\nPython prototype (for reference only):\n```python3\ngetROI() -> retval\n```","ref":"Evision.XImgProc.DisparityWLSFilter.html#getROI/1"},{"type":"function","title":"Evision.XImgProc.DisparityWLSFilter.getSigmaColor/1","doc":"SigmaColor is a parameter defining how sensitive the filtering process is to source image edges.\nLarge values can lead to disparity leakage through low-contrast edges. Small values can make the filter too\nsensitive to noise and textures in the source image. Typical values range from 0.8 to 2.0.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DisparityWLSFilter.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetSigmaColor() -> retval\n```","ref":"Evision.XImgProc.DisparityWLSFilter.html#getSigmaColor/1"},{"type":"function","title":"Evision.XImgProc.DisparityWLSFilter.setDepthDiscontinuityRadius/1","doc":"","ref":"Evision.XImgProc.DisparityWLSFilter.html#setDepthDiscontinuityRadius/1"},{"type":"function","title":"Evision.XImgProc.DisparityWLSFilter.setDepthDiscontinuityRadius/2","doc":"setDepthDiscontinuityRadius\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DisparityWLSFilter.t()`\n- **disc_radius**: `integer()`\n\n@see getDepthDiscontinuityRadius\n\nPython prototype (for reference only):\n```python3\nsetDepthDiscontinuityRadius(_disc_radius) -> None\n```","ref":"Evision.XImgProc.DisparityWLSFilter.html#setDepthDiscontinuityRadius/2"},{"type":"function","title":"Evision.XImgProc.DisparityWLSFilter.setLambda/1","doc":"","ref":"Evision.XImgProc.DisparityWLSFilter.html#setLambda/1"},{"type":"function","title":"Evision.XImgProc.DisparityWLSFilter.setLambda/2","doc":"setLambda\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DisparityWLSFilter.t()`\n- **lambda**: `double`\n\n@see getLambda\n\nPython prototype (for reference only):\n```python3\nsetLambda(_lambda) -> None\n```","ref":"Evision.XImgProc.DisparityWLSFilter.html#setLambda/2"},{"type":"function","title":"Evision.XImgProc.DisparityWLSFilter.setLRCthresh/1","doc":"","ref":"Evision.XImgProc.DisparityWLSFilter.html#setLRCthresh/1"},{"type":"function","title":"Evision.XImgProc.DisparityWLSFilter.setLRCthresh/2","doc":"setLRCthresh\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DisparityWLSFilter.t()`\n- **lRC_thresh**: `integer()`\n\n@see getLRCthresh\n\nPython prototype (for reference only):\n```python3\nsetLRCthresh(_LRC_thresh) -> None\n```","ref":"Evision.XImgProc.DisparityWLSFilter.html#setLRCthresh/2"},{"type":"function","title":"Evision.XImgProc.DisparityWLSFilter.setSigmaColor/1","doc":"","ref":"Evision.XImgProc.DisparityWLSFilter.html#setSigmaColor/1"},{"type":"function","title":"Evision.XImgProc.DisparityWLSFilter.setSigmaColor/2","doc":"setSigmaColor\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.DisparityWLSFilter.t()`\n- **sigma_color**: `double`\n\n@see getSigmaColor\n\nPython prototype (for reference only):\n```python3\nsetSigmaColor(_sigma_color) -> None\n```","ref":"Evision.XImgProc.DisparityWLSFilter.html#setSigmaColor/2"},{"type":"type","title":"Evision.XImgProc.DisparityWLSFilter.t/0","doc":"Type that represents an `XImgProc.DisparityWLSFilter` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.DisparityWLSFilter.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.EdgeAwareFiltersList","doc":"","ref":"Evision.XImgProc.EdgeAwareFiltersList.html"},{"type":"function","title":"Evision.XImgProc.EdgeAwareFiltersList.cv_AM_FILTER/0","doc":"","ref":"Evision.XImgProc.EdgeAwareFiltersList.html#cv_AM_FILTER/0"},{"type":"function","title":"Evision.XImgProc.EdgeAwareFiltersList.cv_DTF_IC/0","doc":"","ref":"Evision.XImgProc.EdgeAwareFiltersList.html#cv_DTF_IC/0"},{"type":"function","title":"Evision.XImgProc.EdgeAwareFiltersList.cv_DTF_NC/0","doc":"","ref":"Evision.XImgProc.EdgeAwareFiltersList.html#cv_DTF_NC/0"},{"type":"function","title":"Evision.XImgProc.EdgeAwareFiltersList.cv_DTF_RF/0","doc":"","ref":"Evision.XImgProc.EdgeAwareFiltersList.html#cv_DTF_RF/0"},{"type":"function","title":"Evision.XImgProc.EdgeAwareFiltersList.cv_GUIDED_FILTER/0","doc":"","ref":"Evision.XImgProc.EdgeAwareFiltersList.html#cv_GUIDED_FILTER/0"},{"type":"type","title":"Evision.XImgProc.EdgeAwareFiltersList.enum/0","doc":"","ref":"Evision.XImgProc.EdgeAwareFiltersList.html#t:enum/0"},{"type":"module","title":"Evision.XImgProc.EdgeAwareInterpolator","doc":"","ref":"Evision.XImgProc.EdgeAwareInterpolator.html"},{"type":"function","title":"Evision.XImgProc.EdgeAwareInterpolator.getFGSLambda/1","doc":"getFGSLambda\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeAwareInterpolator.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setFGSLambda/2`\n\nPython prototype (for reference only):\n```python3\ngetFGSLambda() -> retval\n```","ref":"Evision.XImgProc.EdgeAwareInterpolator.html#getFGSLambda/1"},{"type":"function","title":"Evision.XImgProc.EdgeAwareInterpolator.getFGSSigma/1","doc":"getFGSSigma\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeAwareInterpolator.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setFGSLambda/2`\n\nPython prototype (for reference only):\n```python3\ngetFGSSigma() -> retval\n```","ref":"Evision.XImgProc.EdgeAwareInterpolator.html#getFGSSigma/1"},{"type":"function","title":"Evision.XImgProc.EdgeAwareInterpolator.getK/1","doc":"getK\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeAwareInterpolator.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setK/2`\n\nPython prototype (for reference only):\n```python3\ngetK() -> retval\n```","ref":"Evision.XImgProc.EdgeAwareInterpolator.html#getK/1"},{"type":"function","title":"Evision.XImgProc.EdgeAwareInterpolator.getLambda/1","doc":"getLambda\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeAwareInterpolator.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setLambda/2`\n\nPython prototype (for reference only):\n```python3\ngetLambda() -> retval\n```","ref":"Evision.XImgProc.EdgeAwareInterpolator.html#getLambda/1"},{"type":"function","title":"Evision.XImgProc.EdgeAwareInterpolator.getSigma/1","doc":"getSigma\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeAwareInterpolator.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setSigma/2`\n\nPython prototype (for reference only):\n```python3\ngetSigma() -> retval\n```","ref":"Evision.XImgProc.EdgeAwareInterpolator.html#getSigma/1"},{"type":"function","title":"Evision.XImgProc.EdgeAwareInterpolator.getUsePostProcessing/1","doc":"getUsePostProcessing\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeAwareInterpolator.t()`\n\n##### Return\n- **retval**: `bool`\n\n@see `setUsePostProcessing/2`\n\nPython prototype (for reference only):\n```python3\ngetUsePostProcessing() -> retval\n```","ref":"Evision.XImgProc.EdgeAwareInterpolator.html#getUsePostProcessing/1"},{"type":"function","title":"Evision.XImgProc.EdgeAwareInterpolator.setCostMap/1","doc":"","ref":"Evision.XImgProc.EdgeAwareInterpolator.html#setCostMap/1"},{"type":"function","title":"Evision.XImgProc.EdgeAwareInterpolator.setCostMap/2","doc":"Interface to provide a more elaborated cost map, i.e. edge map, for the edge-aware term.\nThis implementation is based on a rather simple gradient-based edge map estimation.\nTo used more complex edge map estimator (e.g. StructuredEdgeDetection that has been\nused in the original publication) that may lead to improved accuracies, the internal\nedge map estimation can be bypassed here.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeAwareInterpolator.t()`\n- **costMap**: `Evision.Mat`.\n\n  a type CV_32FC1 Mat is required.\n\n@see cv::ximgproc::createSuperpixelSLIC\n\nPython prototype (for reference only):\n```python3\nsetCostMap(_costMap) -> None\n```","ref":"Evision.XImgProc.EdgeAwareInterpolator.html#setCostMap/2"},{"type":"function","title":"Evision.XImgProc.EdgeAwareInterpolator.setFGSLambda/1","doc":"","ref":"Evision.XImgProc.EdgeAwareInterpolator.html#setFGSLambda/1"},{"type":"function","title":"Evision.XImgProc.EdgeAwareInterpolator.setFGSLambda/2","doc":"Sets the respective fastGlobalSmootherFilter() parameter.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeAwareInterpolator.t()`\n- **lambda**: `float`\n\nPython prototype (for reference only):\n```python3\nsetFGSLambda(_lambda) -> None\n```","ref":"Evision.XImgProc.EdgeAwareInterpolator.html#setFGSLambda/2"},{"type":"function","title":"Evision.XImgProc.EdgeAwareInterpolator.setFGSSigma/1","doc":"","ref":"Evision.XImgProc.EdgeAwareInterpolator.html#setFGSSigma/1"},{"type":"function","title":"Evision.XImgProc.EdgeAwareInterpolator.setFGSSigma/2","doc":"setFGSSigma\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeAwareInterpolator.t()`\n- **sigma**: `float`\n\n@see `setFGSLambda/2`\n\nPython prototype (for reference only):\n```python3\nsetFGSSigma(_sigma) -> None\n```","ref":"Evision.XImgProc.EdgeAwareInterpolator.html#setFGSSigma/2"},{"type":"function","title":"Evision.XImgProc.EdgeAwareInterpolator.setK/1","doc":"","ref":"Evision.XImgProc.EdgeAwareInterpolator.html#setK/1"},{"type":"function","title":"Evision.XImgProc.EdgeAwareInterpolator.setK/2","doc":"K is a number of nearest-neighbor matches considered, when fitting a locally affine\nmodel. Usually it should be around 128. However, lower values would make the interpolation\nnoticeably faster.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeAwareInterpolator.t()`\n- **k**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetK(_k) -> None\n```","ref":"Evision.XImgProc.EdgeAwareInterpolator.html#setK/2"},{"type":"function","title":"Evision.XImgProc.EdgeAwareInterpolator.setLambda/1","doc":"","ref":"Evision.XImgProc.EdgeAwareInterpolator.html#setLambda/1"},{"type":"function","title":"Evision.XImgProc.EdgeAwareInterpolator.setLambda/2","doc":"Lambda is a parameter defining the weight of the edge-aware term in geodesic distance,\nshould be in the range of 0 to 1000.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeAwareInterpolator.t()`\n- **lambda**: `float`\n\nPython prototype (for reference only):\n```python3\nsetLambda(_lambda) -> None\n```","ref":"Evision.XImgProc.EdgeAwareInterpolator.html#setLambda/2"},{"type":"function","title":"Evision.XImgProc.EdgeAwareInterpolator.setSigma/1","doc":"","ref":"Evision.XImgProc.EdgeAwareInterpolator.html#setSigma/1"},{"type":"function","title":"Evision.XImgProc.EdgeAwareInterpolator.setSigma/2","doc":"Sigma is a parameter defining how fast the weights decrease in the locally-weighted affine\nfitting. Higher values can help preserve fine details, lower values can help to get rid of noise in the\noutput flow.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeAwareInterpolator.t()`\n- **sigma**: `float`\n\nPython prototype (for reference only):\n```python3\nsetSigma(_sigma) -> None\n```","ref":"Evision.XImgProc.EdgeAwareInterpolator.html#setSigma/2"},{"type":"function","title":"Evision.XImgProc.EdgeAwareInterpolator.setUsePostProcessing/1","doc":"","ref":"Evision.XImgProc.EdgeAwareInterpolator.html#setUsePostProcessing/1"},{"type":"function","title":"Evision.XImgProc.EdgeAwareInterpolator.setUsePostProcessing/2","doc":"Sets whether the fastGlobalSmootherFilter() post-processing is employed. It is turned on by\ndefault.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeAwareInterpolator.t()`\n- **use_post_proc**: `bool`\n\nPython prototype (for reference only):\n```python3\nsetUsePostProcessing(_use_post_proc) -> None\n```","ref":"Evision.XImgProc.EdgeAwareInterpolator.html#setUsePostProcessing/2"},{"type":"type","title":"Evision.XImgProc.EdgeAwareInterpolator.t/0","doc":"Type that represents an `XImgProc.EdgeAwareInterpolator` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.EdgeAwareInterpolator.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.EdgeBoxes","doc":"","ref":"Evision.XImgProc.EdgeBoxes.html"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XImgProc.EdgeBoxes.html#clear/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XImgProc.EdgeBoxes.html#empty/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.getAlpha/1","doc":"Returns the step size of sliding window search.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetAlpha() -> retval\n```","ref":"Evision.XImgProc.EdgeBoxes.html#getAlpha/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.getBeta/1","doc":"Returns the nms threshold for object proposals.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetBeta() -> retval\n```","ref":"Evision.XImgProc.EdgeBoxes.html#getBeta/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.getBoundingBoxes/1","doc":"","ref":"Evision.XImgProc.EdgeBoxes.html#getBoundingBoxes/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.getBoundingBoxes/3","doc":"Returns array containing proposal boxes.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n- **edge_map**: `Evision.Mat`.\n\n  edge image.\n\n- **orientation_map**: `Evision.Mat`.\n\n  orientation map.\n\n##### Return\n- **boxes**: `[Rect]`.\n\n  proposal boxes.\n\n- **scores**: `Evision.Mat.t()`.\n\n  of the proposal boxes, provided a vector of float types.\n\nPython prototype (for reference only):\n```python3\ngetBoundingBoxes(edge_map, orientation_map[, scores]) -> boxes, scores\n```","ref":"Evision.XImgProc.EdgeBoxes.html#getBoundingBoxes/3"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.getBoundingBoxes/4","doc":"Returns array containing proposal boxes.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n- **edge_map**: `Evision.Mat`.\n\n  edge image.\n\n- **orientation_map**: `Evision.Mat`.\n\n  orientation map.\n\n##### Return\n- **boxes**: `[Rect]`.\n\n  proposal boxes.\n\n- **scores**: `Evision.Mat.t()`.\n\n  of the proposal boxes, provided a vector of float types.\n\nPython prototype (for reference only):\n```python3\ngetBoundingBoxes(edge_map, orientation_map[, scores]) -> boxes, scores\n```","ref":"Evision.XImgProc.EdgeBoxes.html#getBoundingBoxes/4"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.getClusterMinMag/1","doc":"Returns the cluster min magnitude.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetClusterMinMag() -> retval\n```","ref":"Evision.XImgProc.EdgeBoxes.html#getClusterMinMag/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XImgProc.EdgeBoxes.html#getDefaultName/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.getEdgeMergeThr/1","doc":"Returns the edge merge threshold.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetEdgeMergeThr() -> retval\n```","ref":"Evision.XImgProc.EdgeBoxes.html#getEdgeMergeThr/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.getEdgeMinMag/1","doc":"Returns the edge min magnitude.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetEdgeMinMag() -> retval\n```","ref":"Evision.XImgProc.EdgeBoxes.html#getEdgeMinMag/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.getEta/1","doc":"Returns adaptation rate for nms threshold.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetEta() -> retval\n```","ref":"Evision.XImgProc.EdgeBoxes.html#getEta/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.getGamma/1","doc":"Returns the affinity sensitivity.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetGamma() -> retval\n```","ref":"Evision.XImgProc.EdgeBoxes.html#getGamma/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.getKappa/1","doc":"Returns the scale sensitivity.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetKappa() -> retval\n```","ref":"Evision.XImgProc.EdgeBoxes.html#getKappa/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.getMaxAspectRatio/1","doc":"Returns the max aspect ratio of boxes.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetMaxAspectRatio() -> retval\n```","ref":"Evision.XImgProc.EdgeBoxes.html#getMaxAspectRatio/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.getMaxBoxes/1","doc":"Returns the max number of boxes to detect.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMaxBoxes() -> retval\n```","ref":"Evision.XImgProc.EdgeBoxes.html#getMaxBoxes/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.getMinBoxArea/1","doc":"Returns the minimum area of boxes.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetMinBoxArea() -> retval\n```","ref":"Evision.XImgProc.EdgeBoxes.html#getMinBoxArea/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.getMinScore/1","doc":"Returns the min score of boxes to detect.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetMinScore() -> retval\n```","ref":"Evision.XImgProc.EdgeBoxes.html#getMinScore/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.read/1","doc":"","ref":"Evision.XImgProc.EdgeBoxes.html#read/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XImgProc.EdgeBoxes.html#read/2"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.save/1","doc":"","ref":"Evision.XImgProc.EdgeBoxes.html#save/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XImgProc.EdgeBoxes.html#save/2"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setAlpha/1","doc":"","ref":"Evision.XImgProc.EdgeBoxes.html#setAlpha/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setAlpha/2","doc":"Sets the step size of sliding window search.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n- **value**: `float`\n\nPython prototype (for reference only):\n```python3\nsetAlpha(value) -> None\n```","ref":"Evision.XImgProc.EdgeBoxes.html#setAlpha/2"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setBeta/1","doc":"","ref":"Evision.XImgProc.EdgeBoxes.html#setBeta/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setBeta/2","doc":"Sets the nms threshold for object proposals.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n- **value**: `float`\n\nPython prototype (for reference only):\n```python3\nsetBeta(value) -> None\n```","ref":"Evision.XImgProc.EdgeBoxes.html#setBeta/2"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setClusterMinMag/1","doc":"","ref":"Evision.XImgProc.EdgeBoxes.html#setClusterMinMag/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setClusterMinMag/2","doc":"Sets the cluster min magnitude.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n- **value**: `float`\n\nPython prototype (for reference only):\n```python3\nsetClusterMinMag(value) -> None\n```","ref":"Evision.XImgProc.EdgeBoxes.html#setClusterMinMag/2"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setEdgeMergeThr/1","doc":"","ref":"Evision.XImgProc.EdgeBoxes.html#setEdgeMergeThr/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setEdgeMergeThr/2","doc":"Sets the edge merge threshold.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n- **value**: `float`\n\nPython prototype (for reference only):\n```python3\nsetEdgeMergeThr(value) -> None\n```","ref":"Evision.XImgProc.EdgeBoxes.html#setEdgeMergeThr/2"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setEdgeMinMag/1","doc":"","ref":"Evision.XImgProc.EdgeBoxes.html#setEdgeMinMag/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setEdgeMinMag/2","doc":"Sets the edge min magnitude.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n- **value**: `float`\n\nPython prototype (for reference only):\n```python3\nsetEdgeMinMag(value) -> None\n```","ref":"Evision.XImgProc.EdgeBoxes.html#setEdgeMinMag/2"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setEta/1","doc":"","ref":"Evision.XImgProc.EdgeBoxes.html#setEta/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setEta/2","doc":"Sets the adaptation rate for nms threshold.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n- **value**: `float`\n\nPython prototype (for reference only):\n```python3\nsetEta(value) -> None\n```","ref":"Evision.XImgProc.EdgeBoxes.html#setEta/2"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setGamma/1","doc":"","ref":"Evision.XImgProc.EdgeBoxes.html#setGamma/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setGamma/2","doc":"Sets the affinity sensitivity\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n- **value**: `float`\n\nPython prototype (for reference only):\n```python3\nsetGamma(value) -> None\n```","ref":"Evision.XImgProc.EdgeBoxes.html#setGamma/2"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setKappa/1","doc":"","ref":"Evision.XImgProc.EdgeBoxes.html#setKappa/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setKappa/2","doc":"Sets the scale sensitivity.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n- **value**: `float`\n\nPython prototype (for reference only):\n```python3\nsetKappa(value) -> None\n```","ref":"Evision.XImgProc.EdgeBoxes.html#setKappa/2"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setMaxAspectRatio/1","doc":"","ref":"Evision.XImgProc.EdgeBoxes.html#setMaxAspectRatio/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setMaxAspectRatio/2","doc":"Sets the max aspect ratio of boxes.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n- **value**: `float`\n\nPython prototype (for reference only):\n```python3\nsetMaxAspectRatio(value) -> None\n```","ref":"Evision.XImgProc.EdgeBoxes.html#setMaxAspectRatio/2"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setMaxBoxes/1","doc":"","ref":"Evision.XImgProc.EdgeBoxes.html#setMaxBoxes/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setMaxBoxes/2","doc":"Sets max number of boxes to detect.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n- **value**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMaxBoxes(value) -> None\n```","ref":"Evision.XImgProc.EdgeBoxes.html#setMaxBoxes/2"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setMinBoxArea/1","doc":"","ref":"Evision.XImgProc.EdgeBoxes.html#setMinBoxArea/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setMinBoxArea/2","doc":"Sets the minimum area of boxes.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n- **value**: `float`\n\nPython prototype (for reference only):\n```python3\nsetMinBoxArea(value) -> None\n```","ref":"Evision.XImgProc.EdgeBoxes.html#setMinBoxArea/2"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setMinScore/1","doc":"","ref":"Evision.XImgProc.EdgeBoxes.html#setMinScore/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.setMinScore/2","doc":"Sets the min score of boxes to detect.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n- **value**: `float`\n\nPython prototype (for reference only):\n```python3\nsetMinScore(value) -> None\n```","ref":"Evision.XImgProc.EdgeBoxes.html#setMinScore/2"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.write/1","doc":"","ref":"Evision.XImgProc.EdgeBoxes.html#write/1"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XImgProc.EdgeBoxes.html#write/2"},{"type":"function","title":"Evision.XImgProc.EdgeBoxes.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeBoxes.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XImgProc.EdgeBoxes.html#write/3"},{"type":"type","title":"Evision.XImgProc.EdgeBoxes.t/0","doc":"Type that represents an `XImgProc.EdgeBoxes` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.EdgeBoxes.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.EdgeDrawing","doc":"","ref":"Evision.XImgProc.EdgeDrawing.html"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeDrawing.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XImgProc.EdgeDrawing.html#clear/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.detectEdges/1","doc":"","ref":"Evision.XImgProc.EdgeDrawing.html#detectEdges/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.detectEdges/2","doc":"Detects edges in a grayscale image and prepares them to detect lines and ellipses.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeDrawing.t()`\n- **src**: `Evision.Mat`.\n\n  8-bit, single-channel, grayscale input image.\n\nPython prototype (for reference only):\n```python3\ndetectEdges(src) -> None\n```","ref":"Evision.XImgProc.EdgeDrawing.html#detectEdges/2"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.detectEllipses/1","doc":"Detects circles and ellipses.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeDrawing.t()`\n\n##### Return\n- **ellipses**: `Evision.Mat.t()`.\n\n  output Vec<6d> contains center point and perimeter for circles, center point, axes and angle for ellipses.\n\n**Note**: you should call detectEdges() before calling this function.\n\nPython prototype (for reference only):\n```python3\ndetectEllipses([, ellipses]) -> ellipses\n```","ref":"Evision.XImgProc.EdgeDrawing.html#detectEllipses/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.detectEllipses/2","doc":"Detects circles and ellipses.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeDrawing.t()`\n\n##### Return\n- **ellipses**: `Evision.Mat.t()`.\n\n  output Vec<6d> contains center point and perimeter for circles, center point, axes and angle for ellipses.\n\n**Note**: you should call detectEdges() before calling this function.\n\nPython prototype (for reference only):\n```python3\ndetectEllipses([, ellipses]) -> ellipses\n```","ref":"Evision.XImgProc.EdgeDrawing.html#detectEllipses/2"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.detectLines/1","doc":"Detects lines.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeDrawing.t()`\n\n##### Return\n- **lines**: `Evision.Mat.t()`.\n\n  output Vec<4f> contains the start point and the end point of detected lines.\n\n**Note**: you should call detectEdges() before calling this function.\n\nPython prototype (for reference only):\n```python3\ndetectLines([, lines]) -> lines\n```","ref":"Evision.XImgProc.EdgeDrawing.html#detectLines/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.detectLines/2","doc":"Detects lines.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeDrawing.t()`\n\n##### Return\n- **lines**: `Evision.Mat.t()`.\n\n  output Vec<4f> contains the start point and the end point of detected lines.\n\n**Note**: you should call detectEdges() before calling this function.\n\nPython prototype (for reference only):\n```python3\ndetectLines([, lines]) -> lines\n```","ref":"Evision.XImgProc.EdgeDrawing.html#detectLines/2"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeDrawing.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XImgProc.EdgeDrawing.html#empty/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeDrawing.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XImgProc.EdgeDrawing.html#getDefaultName/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.getEdgeImage/1","doc":"returns Edge Image prepared by detectEdges() function.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeDrawing.t()`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  returns 8-bit, single-channel output image.\n\nPython prototype (for reference only):\n```python3\ngetEdgeImage([, dst]) -> dst\n```","ref":"Evision.XImgProc.EdgeDrawing.html#getEdgeImage/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.getEdgeImage/2","doc":"returns Edge Image prepared by detectEdges() function.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeDrawing.t()`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  returns 8-bit, single-channel output image.\n\nPython prototype (for reference only):\n```python3\ngetEdgeImage([, dst]) -> dst\n```","ref":"Evision.XImgProc.EdgeDrawing.html#getEdgeImage/2"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.getGradientImage/1","doc":"returns Gradient Image prepared by detectEdges() function.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeDrawing.t()`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  returns 16-bit, single-channel output image.\n\nPython prototype (for reference only):\n```python3\ngetGradientImage([, dst]) -> dst\n```","ref":"Evision.XImgProc.EdgeDrawing.html#getGradientImage/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.getGradientImage/2","doc":"returns Gradient Image prepared by detectEdges() function.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeDrawing.t()`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  returns 16-bit, single-channel output image.\n\nPython prototype (for reference only):\n```python3\ngetGradientImage([, dst]) -> dst\n```","ref":"Evision.XImgProc.EdgeDrawing.html#getGradientImage/2"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.getSegmentIndicesOfLines/1","doc":"Returns for each line found in detectLines() its edge segment index in getSegments()\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeDrawing.t()`\n\n##### Return\n- **retval**: `[integer()]`\n\nPython prototype (for reference only):\n```python3\ngetSegmentIndicesOfLines() -> retval\n```","ref":"Evision.XImgProc.EdgeDrawing.html#getSegmentIndicesOfLines/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.getSegments/1","doc":"Returns std::vector > of detected edge segments, see detectEdges()\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeDrawing.t()`\n\n##### Return\n- **retval**: `[[Point]]`\n\nPython prototype (for reference only):\n```python3\ngetSegments() -> retval\n```","ref":"Evision.XImgProc.EdgeDrawing.html#getSegments/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.read/1","doc":"","ref":"Evision.XImgProc.EdgeDrawing.html#read/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeDrawing.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XImgProc.EdgeDrawing.html#read/2"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.save/1","doc":"","ref":"Evision.XImgProc.EdgeDrawing.html#save/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeDrawing.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XImgProc.EdgeDrawing.html#save/2"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.setParams/1","doc":"","ref":"Evision.XImgProc.EdgeDrawing.html#setParams/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.setParams/2","doc":"sets parameters.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeDrawing.t()`\n- **parameters**: `Evision.XImgProc.EdgeDrawing.Params.t()`.\n\n  Parameters of the algorithm\n\nthis function is meant to be used for parameter setting in other languages than c++ like python.\n\nPython prototype (for reference only):\n```python3\nsetParams(parameters) -> None\n```","ref":"Evision.XImgProc.EdgeDrawing.html#setParams/2"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.write/1","doc":"","ref":"Evision.XImgProc.EdgeDrawing.html#write/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeDrawing.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XImgProc.EdgeDrawing.html#write/2"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.EdgeDrawing.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XImgProc.EdgeDrawing.html#write/3"},{"type":"type","title":"Evision.XImgProc.EdgeDrawing.t/0","doc":"Type that represents an `XImgProc.EdgeDrawing` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.EdgeDrawing.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.EdgeDrawing.GradientOperator","doc":"","ref":"Evision.XImgProc.EdgeDrawing.GradientOperator.html"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.GradientOperator.cv_LSD/0","doc":"","ref":"Evision.XImgProc.EdgeDrawing.GradientOperator.html#cv_LSD/0"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.GradientOperator.cv_PREWITT/0","doc":"","ref":"Evision.XImgProc.EdgeDrawing.GradientOperator.html#cv_PREWITT/0"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.GradientOperator.cv_SCHARR/0","doc":"","ref":"Evision.XImgProc.EdgeDrawing.GradientOperator.html#cv_SCHARR/0"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.GradientOperator.cv_SOBEL/0","doc":"","ref":"Evision.XImgProc.EdgeDrawing.GradientOperator.html#cv_SOBEL/0"},{"type":"type","title":"Evision.XImgProc.EdgeDrawing.GradientOperator.enum/0","doc":"","ref":"Evision.XImgProc.EdgeDrawing.GradientOperator.html#t:enum/0"},{"type":"module","title":"Evision.XImgProc.EdgeDrawing.Params","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.get_AnchorThresholdValue/1","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#get_AnchorThresholdValue/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.get_EdgeDetectionOperator/1","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#get_EdgeDetectionOperator/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.get_GradientThresholdValue/1","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#get_GradientThresholdValue/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.get_LineFitErrorThreshold/1","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#get_LineFitErrorThreshold/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.get_MaxDistanceBetweenTwoLines/1","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#get_MaxDistanceBetweenTwoLines/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.get_MaxErrorThreshold/1","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#get_MaxErrorThreshold/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.get_MinLineLength/1","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#get_MinLineLength/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.get_MinPathLength/1","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#get_MinPathLength/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.get_NFAValidation/1","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#get_NFAValidation/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.get_PFmode/1","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#get_PFmode/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.get_ScanInterval/1","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#get_ScanInterval/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.get_Sigma/1","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#get_Sigma/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.get_SumFlag/1","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#get_SumFlag/1"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.set_AnchorThresholdValue/2","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#set_AnchorThresholdValue/2"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.set_EdgeDetectionOperator/2","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#set_EdgeDetectionOperator/2"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.set_GradientThresholdValue/2","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#set_GradientThresholdValue/2"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.set_LineFitErrorThreshold/2","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#set_LineFitErrorThreshold/2"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.set_MaxDistanceBetweenTwoLines/2","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#set_MaxDistanceBetweenTwoLines/2"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.set_MaxErrorThreshold/2","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#set_MaxErrorThreshold/2"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.set_MinLineLength/2","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#set_MinLineLength/2"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.set_MinPathLength/2","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#set_MinPathLength/2"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.set_NFAValidation/2","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#set_NFAValidation/2"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.set_PFmode/2","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#set_PFmode/2"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.set_ScanInterval/2","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#set_ScanInterval/2"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.set_Sigma/2","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#set_Sigma/2"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.set_SumFlag/2","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#set_SumFlag/2"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.ximgproc_EdgeDrawing_Params/0","doc":"EdgeDrawing_Params\n##### Return\n- **self**: `Evision.XImgProc.EdgeDrawing.Params.t()`\n\nPython prototype (for reference only):\n```python3\nEdgeDrawing_Params() ->  \n```","ref":"Evision.XImgProc.EdgeDrawing.Params.html#ximgproc_EdgeDrawing_Params/0"},{"type":"function","title":"Evision.XImgProc.EdgeDrawing.Params.ximgproc_EdgeDrawing_Params/1","doc":"","ref":"Evision.XImgProc.EdgeDrawing.Params.html#ximgproc_EdgeDrawing_Params/1"},{"type":"type","title":"Evision.XImgProc.EdgeDrawing.Params.t/0","doc":"Type that represents an `XImgProc.EdgeDrawing.Params` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.EdgeDrawing.Params.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.FastBilateralSolverFilter","doc":"","ref":"Evision.XImgProc.FastBilateralSolverFilter.html"},{"type":"function","title":"Evision.XImgProc.FastBilateralSolverFilter.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastBilateralSolverFilter.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XImgProc.FastBilateralSolverFilter.html#clear/1"},{"type":"function","title":"Evision.XImgProc.FastBilateralSolverFilter.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastBilateralSolverFilter.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XImgProc.FastBilateralSolverFilter.html#empty/1"},{"type":"function","title":"Evision.XImgProc.FastBilateralSolverFilter.filter/1","doc":"","ref":"Evision.XImgProc.FastBilateralSolverFilter.html#filter/1"},{"type":"function","title":"Evision.XImgProc.FastBilateralSolverFilter.filter/3","doc":"Apply smoothing operation to the source image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastBilateralSolverFilter.t()`\n- **src**: `Evision.Mat`.\n\n  source image for filtering with unsigned 8-bit or signed 16-bit or floating-point 32-bit depth and up to 3 channels.\n\n- **confidence**: `Evision.Mat`.\n\n  confidence image with unsigned 8-bit or floating-point 32-bit confidence and 1 channel.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  destination image.\n\n**Note**: Confidence images with CV_8U depth are expected to in [0, 255] and CV_32F in [0, 1] range.\n\nPython prototype (for reference only):\n```python3\nfilter(src, confidence[, dst]) -> dst\n```","ref":"Evision.XImgProc.FastBilateralSolverFilter.html#filter/3"},{"type":"function","title":"Evision.XImgProc.FastBilateralSolverFilter.filter/4","doc":"Apply smoothing operation to the source image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastBilateralSolverFilter.t()`\n- **src**: `Evision.Mat`.\n\n  source image for filtering with unsigned 8-bit or signed 16-bit or floating-point 32-bit depth and up to 3 channels.\n\n- **confidence**: `Evision.Mat`.\n\n  confidence image with unsigned 8-bit or floating-point 32-bit confidence and 1 channel.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  destination image.\n\n**Note**: Confidence images with CV_8U depth are expected to in [0, 255] and CV_32F in [0, 1] range.\n\nPython prototype (for reference only):\n```python3\nfilter(src, confidence[, dst]) -> dst\n```","ref":"Evision.XImgProc.FastBilateralSolverFilter.html#filter/4"},{"type":"function","title":"Evision.XImgProc.FastBilateralSolverFilter.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastBilateralSolverFilter.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XImgProc.FastBilateralSolverFilter.html#getDefaultName/1"},{"type":"function","title":"Evision.XImgProc.FastBilateralSolverFilter.read/1","doc":"","ref":"Evision.XImgProc.FastBilateralSolverFilter.html#read/1"},{"type":"function","title":"Evision.XImgProc.FastBilateralSolverFilter.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastBilateralSolverFilter.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XImgProc.FastBilateralSolverFilter.html#read/2"},{"type":"function","title":"Evision.XImgProc.FastBilateralSolverFilter.save/1","doc":"","ref":"Evision.XImgProc.FastBilateralSolverFilter.html#save/1"},{"type":"function","title":"Evision.XImgProc.FastBilateralSolverFilter.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastBilateralSolverFilter.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XImgProc.FastBilateralSolverFilter.html#save/2"},{"type":"function","title":"Evision.XImgProc.FastBilateralSolverFilter.write/1","doc":"","ref":"Evision.XImgProc.FastBilateralSolverFilter.html#write/1"},{"type":"function","title":"Evision.XImgProc.FastBilateralSolverFilter.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastBilateralSolverFilter.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XImgProc.FastBilateralSolverFilter.html#write/2"},{"type":"function","title":"Evision.XImgProc.FastBilateralSolverFilter.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastBilateralSolverFilter.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XImgProc.FastBilateralSolverFilter.html#write/3"},{"type":"type","title":"Evision.XImgProc.FastBilateralSolverFilter.t/0","doc":"Type that represents an `XImgProc.FastBilateralSolverFilter` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.FastBilateralSolverFilter.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.FastGlobalSmootherFilter","doc":"","ref":"Evision.XImgProc.FastGlobalSmootherFilter.html"},{"type":"function","title":"Evision.XImgProc.FastGlobalSmootherFilter.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastGlobalSmootherFilter.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XImgProc.FastGlobalSmootherFilter.html#clear/1"},{"type":"function","title":"Evision.XImgProc.FastGlobalSmootherFilter.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastGlobalSmootherFilter.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XImgProc.FastGlobalSmootherFilter.html#empty/1"},{"type":"function","title":"Evision.XImgProc.FastGlobalSmootherFilter.filter/1","doc":"","ref":"Evision.XImgProc.FastGlobalSmootherFilter.html#filter/1"},{"type":"function","title":"Evision.XImgProc.FastGlobalSmootherFilter.filter/2","doc":"Apply smoothing operation to the source image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastGlobalSmootherFilter.t()`\n- **src**: `Evision.Mat`.\n\n  source image for filtering with unsigned 8-bit or signed 16-bit or floating-point 32-bit depth and up to 4 channels.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  destination image.\n\nPython prototype (for reference only):\n```python3\nfilter(src[, dst]) -> dst\n```","ref":"Evision.XImgProc.FastGlobalSmootherFilter.html#filter/2"},{"type":"function","title":"Evision.XImgProc.FastGlobalSmootherFilter.filter/3","doc":"Apply smoothing operation to the source image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastGlobalSmootherFilter.t()`\n- **src**: `Evision.Mat`.\n\n  source image for filtering with unsigned 8-bit or signed 16-bit or floating-point 32-bit depth and up to 4 channels.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  destination image.\n\nPython prototype (for reference only):\n```python3\nfilter(src[, dst]) -> dst\n```","ref":"Evision.XImgProc.FastGlobalSmootherFilter.html#filter/3"},{"type":"function","title":"Evision.XImgProc.FastGlobalSmootherFilter.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastGlobalSmootherFilter.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XImgProc.FastGlobalSmootherFilter.html#getDefaultName/1"},{"type":"function","title":"Evision.XImgProc.FastGlobalSmootherFilter.read/1","doc":"","ref":"Evision.XImgProc.FastGlobalSmootherFilter.html#read/1"},{"type":"function","title":"Evision.XImgProc.FastGlobalSmootherFilter.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastGlobalSmootherFilter.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XImgProc.FastGlobalSmootherFilter.html#read/2"},{"type":"function","title":"Evision.XImgProc.FastGlobalSmootherFilter.save/1","doc":"","ref":"Evision.XImgProc.FastGlobalSmootherFilter.html#save/1"},{"type":"function","title":"Evision.XImgProc.FastGlobalSmootherFilter.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastGlobalSmootherFilter.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XImgProc.FastGlobalSmootherFilter.html#save/2"},{"type":"function","title":"Evision.XImgProc.FastGlobalSmootherFilter.write/1","doc":"","ref":"Evision.XImgProc.FastGlobalSmootherFilter.html#write/1"},{"type":"function","title":"Evision.XImgProc.FastGlobalSmootherFilter.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastGlobalSmootherFilter.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XImgProc.FastGlobalSmootherFilter.html#write/2"},{"type":"function","title":"Evision.XImgProc.FastGlobalSmootherFilter.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastGlobalSmootherFilter.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XImgProc.FastGlobalSmootherFilter.html#write/3"},{"type":"type","title":"Evision.XImgProc.FastGlobalSmootherFilter.t/0","doc":"Type that represents an `XImgProc.FastGlobalSmootherFilter` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.FastGlobalSmootherFilter.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.FastLineDetector","doc":"","ref":"Evision.XImgProc.FastLineDetector.html"},{"type":"function","title":"Evision.XImgProc.FastLineDetector.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastLineDetector.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XImgProc.FastLineDetector.html#clear/1"},{"type":"function","title":"Evision.XImgProc.FastLineDetector.detect/1","doc":"","ref":"Evision.XImgProc.FastLineDetector.html#detect/1"},{"type":"function","title":"Evision.XImgProc.FastLineDetector.detect/2","doc":"Finds lines in the input image.\nThis is the output of the default parameters of the algorithm on the above\nshown image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastLineDetector.t()`\n- **image**: `Evision.Mat`.\n\n  A grayscale (CV_8UC1) input image. If only a roi needs to be\n  selected, use: `fld_ptr-\\>detect(image(roi), lines, ...);\n  lines += Scalar(roi.x, roi.y, roi.x, roi.y);`\n\n##### Return\n- **lines**: `Evision.Mat.t()`.\n\n  A vector of Vec4f elements specifying the beginning\n  and ending point of a line.  Where Vec4f is (x1, y1, x2, y2), point\n  1 is the start, point 2 - end. Returned lines are directed so that the\n  brighter side is on their left.\n\n![image](pics/corridor_fld.jpg)\n\nPython prototype (for reference only):\n```python3\ndetect(image[, lines]) -> lines\n```","ref":"Evision.XImgProc.FastLineDetector.html#detect/2"},{"type":"function","title":"Evision.XImgProc.FastLineDetector.detect/3","doc":"Finds lines in the input image.\nThis is the output of the default parameters of the algorithm on the above\nshown image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastLineDetector.t()`\n- **image**: `Evision.Mat`.\n\n  A grayscale (CV_8UC1) input image. If only a roi needs to be\n  selected, use: `fld_ptr-\\>detect(image(roi), lines, ...);\n  lines += Scalar(roi.x, roi.y, roi.x, roi.y);`\n\n##### Return\n- **lines**: `Evision.Mat.t()`.\n\n  A vector of Vec4f elements specifying the beginning\n  and ending point of a line.  Where Vec4f is (x1, y1, x2, y2), point\n  1 is the start, point 2 - end. Returned lines are directed so that the\n  brighter side is on their left.\n\n![image](pics/corridor_fld.jpg)\n\nPython prototype (for reference only):\n```python3\ndetect(image[, lines]) -> lines\n```","ref":"Evision.XImgProc.FastLineDetector.html#detect/3"},{"type":"function","title":"Evision.XImgProc.FastLineDetector.drawSegments/1","doc":"","ref":"Evision.XImgProc.FastLineDetector.html#drawSegments/1"},{"type":"function","title":"Evision.XImgProc.FastLineDetector.drawSegments/3","doc":"Draws the line segments on a given image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastLineDetector.t()`\n- **lines**: `Evision.Mat`.\n\n  A vector of the lines that needed to be drawn.\n\n##### Keyword Arguments\n- **draw_arrow**: `bool`.\n\n  If true, arrow heads will be drawn.\n\n- **linecolor**: `Evision.scalar()`.\n\n  Line color.\n\n- **linethickness**: `integer()`.\n\n  Line thickness.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  The image, where the lines will be drawn. Should be bigger\n  or equal to the image, where the lines were found.\n\nPython prototype (for reference only):\n```python3\ndrawSegments(image, lines[, draw_arrow[, linecolor[, linethickness]]]) -> image\n```","ref":"Evision.XImgProc.FastLineDetector.html#drawSegments/3"},{"type":"function","title":"Evision.XImgProc.FastLineDetector.drawSegments/4","doc":"Draws the line segments on a given image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastLineDetector.t()`\n- **lines**: `Evision.Mat`.\n\n  A vector of the lines that needed to be drawn.\n\n##### Keyword Arguments\n- **draw_arrow**: `bool`.\n\n  If true, arrow heads will be drawn.\n\n- **linecolor**: `Evision.scalar()`.\n\n  Line color.\n\n- **linethickness**: `integer()`.\n\n  Line thickness.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  The image, where the lines will be drawn. Should be bigger\n  or equal to the image, where the lines were found.\n\nPython prototype (for reference only):\n```python3\ndrawSegments(image, lines[, draw_arrow[, linecolor[, linethickness]]]) -> image\n```","ref":"Evision.XImgProc.FastLineDetector.html#drawSegments/4"},{"type":"function","title":"Evision.XImgProc.FastLineDetector.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastLineDetector.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XImgProc.FastLineDetector.html#empty/1"},{"type":"function","title":"Evision.XImgProc.FastLineDetector.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastLineDetector.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XImgProc.FastLineDetector.html#getDefaultName/1"},{"type":"function","title":"Evision.XImgProc.FastLineDetector.read/1","doc":"","ref":"Evision.XImgProc.FastLineDetector.html#read/1"},{"type":"function","title":"Evision.XImgProc.FastLineDetector.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastLineDetector.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XImgProc.FastLineDetector.html#read/2"},{"type":"function","title":"Evision.XImgProc.FastLineDetector.save/1","doc":"","ref":"Evision.XImgProc.FastLineDetector.html#save/1"},{"type":"function","title":"Evision.XImgProc.FastLineDetector.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastLineDetector.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XImgProc.FastLineDetector.html#save/2"},{"type":"function","title":"Evision.XImgProc.FastLineDetector.write/1","doc":"","ref":"Evision.XImgProc.FastLineDetector.html#write/1"},{"type":"function","title":"Evision.XImgProc.FastLineDetector.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastLineDetector.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XImgProc.FastLineDetector.html#write/2"},{"type":"function","title":"Evision.XImgProc.FastLineDetector.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.FastLineDetector.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XImgProc.FastLineDetector.html#write/3"},{"type":"type","title":"Evision.XImgProc.FastLineDetector.t/0","doc":"Type that represents an `XImgProc.FastLineDetector` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.FastLineDetector.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.GraphSegmentation","doc":"","ref":"Evision.XImgProc.GraphSegmentation.html"},{"type":"function","title":"Evision.XImgProc.GraphSegmentation.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GraphSegmentation.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XImgProc.GraphSegmentation.html#clear/1"},{"type":"function","title":"Evision.XImgProc.GraphSegmentation.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GraphSegmentation.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XImgProc.GraphSegmentation.html#empty/1"},{"type":"function","title":"Evision.XImgProc.GraphSegmentation.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GraphSegmentation.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XImgProc.GraphSegmentation.html#getDefaultName/1"},{"type":"function","title":"Evision.XImgProc.GraphSegmentation.getK/1","doc":"getK\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GraphSegmentation.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetK() -> retval\n```","ref":"Evision.XImgProc.GraphSegmentation.html#getK/1"},{"type":"function","title":"Evision.XImgProc.GraphSegmentation.getMinSize/1","doc":"getMinSize\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GraphSegmentation.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetMinSize() -> retval\n```","ref":"Evision.XImgProc.GraphSegmentation.html#getMinSize/1"},{"type":"function","title":"Evision.XImgProc.GraphSegmentation.getSigma/1","doc":"getSigma\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GraphSegmentation.t()`\n\n##### Return\n- **retval**: `double`\n\nPython prototype (for reference only):\n```python3\ngetSigma() -> retval\n```","ref":"Evision.XImgProc.GraphSegmentation.html#getSigma/1"},{"type":"function","title":"Evision.XImgProc.GraphSegmentation.processImage/1","doc":"","ref":"Evision.XImgProc.GraphSegmentation.html#processImage/1"},{"type":"function","title":"Evision.XImgProc.GraphSegmentation.processImage/2","doc":"Segment an image and store output in dst\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GraphSegmentation.t()`\n- **src**: `Evision.Mat`.\n\n  The input image. Any number of channel (1 (Eg: Gray), 3 (Eg: RGB), 4 (Eg: RGB-D)) can be provided\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  The output segmentation. It's a CV_32SC1 Mat with the same number of cols and rows as input image, with an unique, sequential, id for each pixel.\n\nPython prototype (for reference only):\n```python3\nprocessImage(src[, dst]) -> dst\n```","ref":"Evision.XImgProc.GraphSegmentation.html#processImage/2"},{"type":"function","title":"Evision.XImgProc.GraphSegmentation.processImage/3","doc":"Segment an image and store output in dst\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GraphSegmentation.t()`\n- **src**: `Evision.Mat`.\n\n  The input image. Any number of channel (1 (Eg: Gray), 3 (Eg: RGB), 4 (Eg: RGB-D)) can be provided\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  The output segmentation. It's a CV_32SC1 Mat with the same number of cols and rows as input image, with an unique, sequential, id for each pixel.\n\nPython prototype (for reference only):\n```python3\nprocessImage(src[, dst]) -> dst\n```","ref":"Evision.XImgProc.GraphSegmentation.html#processImage/3"},{"type":"function","title":"Evision.XImgProc.GraphSegmentation.read/1","doc":"","ref":"Evision.XImgProc.GraphSegmentation.html#read/1"},{"type":"function","title":"Evision.XImgProc.GraphSegmentation.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GraphSegmentation.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XImgProc.GraphSegmentation.html#read/2"},{"type":"function","title":"Evision.XImgProc.GraphSegmentation.save/1","doc":"","ref":"Evision.XImgProc.GraphSegmentation.html#save/1"},{"type":"function","title":"Evision.XImgProc.GraphSegmentation.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GraphSegmentation.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XImgProc.GraphSegmentation.html#save/2"},{"type":"function","title":"Evision.XImgProc.GraphSegmentation.setK/1","doc":"","ref":"Evision.XImgProc.GraphSegmentation.html#setK/1"},{"type":"function","title":"Evision.XImgProc.GraphSegmentation.setK/2","doc":"setK\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GraphSegmentation.t()`\n- **k**: `float`\n\nPython prototype (for reference only):\n```python3\nsetK(k) -> None\n```","ref":"Evision.XImgProc.GraphSegmentation.html#setK/2"},{"type":"function","title":"Evision.XImgProc.GraphSegmentation.setMinSize/1","doc":"","ref":"Evision.XImgProc.GraphSegmentation.html#setMinSize/1"},{"type":"function","title":"Evision.XImgProc.GraphSegmentation.setMinSize/2","doc":"setMinSize\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GraphSegmentation.t()`\n- **min_size**: `integer()`\n\nPython prototype (for reference only):\n```python3\nsetMinSize(min_size) -> None\n```","ref":"Evision.XImgProc.GraphSegmentation.html#setMinSize/2"},{"type":"function","title":"Evision.XImgProc.GraphSegmentation.setSigma/1","doc":"","ref":"Evision.XImgProc.GraphSegmentation.html#setSigma/1"},{"type":"function","title":"Evision.XImgProc.GraphSegmentation.setSigma/2","doc":"setSigma\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GraphSegmentation.t()`\n- **sigma**: `double`\n\nPython prototype (for reference only):\n```python3\nsetSigma(sigma) -> None\n```","ref":"Evision.XImgProc.GraphSegmentation.html#setSigma/2"},{"type":"function","title":"Evision.XImgProc.GraphSegmentation.write/1","doc":"","ref":"Evision.XImgProc.GraphSegmentation.html#write/1"},{"type":"function","title":"Evision.XImgProc.GraphSegmentation.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GraphSegmentation.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XImgProc.GraphSegmentation.html#write/2"},{"type":"function","title":"Evision.XImgProc.GraphSegmentation.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GraphSegmentation.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XImgProc.GraphSegmentation.html#write/3"},{"type":"type","title":"Evision.XImgProc.GraphSegmentation.t/0","doc":"Type that represents an `XImgProc.GraphSegmentation` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.GraphSegmentation.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.GuidedFilter","doc":"","ref":"Evision.XImgProc.GuidedFilter.html"},{"type":"function","title":"Evision.XImgProc.GuidedFilter.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GuidedFilter.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XImgProc.GuidedFilter.html#clear/1"},{"type":"function","title":"Evision.XImgProc.GuidedFilter.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GuidedFilter.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XImgProc.GuidedFilter.html#empty/1"},{"type":"function","title":"Evision.XImgProc.GuidedFilter.filter/1","doc":"","ref":"Evision.XImgProc.GuidedFilter.html#filter/1"},{"type":"function","title":"Evision.XImgProc.GuidedFilter.filter/2","doc":"Apply (Fast) Guided Filter to the filtering image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GuidedFilter.t()`\n- **src**: `Evision.Mat`.\n\n  filtering image with any numbers of channels.\n\n##### Keyword Arguments\n- **dDepth**: `integer()`.\n\n  optional depth of the output image. dDepth can be set to -1, which will be equivalent\n  to src.depth().\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image.\n\nPython prototype (for reference only):\n```python3\nfilter(src[, dst[, dDepth]]) -> dst\n```","ref":"Evision.XImgProc.GuidedFilter.html#filter/2"},{"type":"function","title":"Evision.XImgProc.GuidedFilter.filter/3","doc":"Apply (Fast) Guided Filter to the filtering image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GuidedFilter.t()`\n- **src**: `Evision.Mat`.\n\n  filtering image with any numbers of channels.\n\n##### Keyword Arguments\n- **dDepth**: `integer()`.\n\n  optional depth of the output image. dDepth can be set to -1, which will be equivalent\n  to src.depth().\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  output image.\n\nPython prototype (for reference only):\n```python3\nfilter(src[, dst[, dDepth]]) -> dst\n```","ref":"Evision.XImgProc.GuidedFilter.html#filter/3"},{"type":"function","title":"Evision.XImgProc.GuidedFilter.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GuidedFilter.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XImgProc.GuidedFilter.html#getDefaultName/1"},{"type":"function","title":"Evision.XImgProc.GuidedFilter.read/1","doc":"","ref":"Evision.XImgProc.GuidedFilter.html#read/1"},{"type":"function","title":"Evision.XImgProc.GuidedFilter.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GuidedFilter.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XImgProc.GuidedFilter.html#read/2"},{"type":"function","title":"Evision.XImgProc.GuidedFilter.save/1","doc":"","ref":"Evision.XImgProc.GuidedFilter.html#save/1"},{"type":"function","title":"Evision.XImgProc.GuidedFilter.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GuidedFilter.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XImgProc.GuidedFilter.html#save/2"},{"type":"function","title":"Evision.XImgProc.GuidedFilter.write/1","doc":"","ref":"Evision.XImgProc.GuidedFilter.html#write/1"},{"type":"function","title":"Evision.XImgProc.GuidedFilter.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GuidedFilter.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XImgProc.GuidedFilter.html#write/2"},{"type":"function","title":"Evision.XImgProc.GuidedFilter.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.GuidedFilter.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XImgProc.GuidedFilter.html#write/3"},{"type":"type","title":"Evision.XImgProc.GuidedFilter.t/0","doc":"Type that represents an `XImgProc.GuidedFilter` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.GuidedFilter.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.HoughDeskewOption","doc":"","ref":"Evision.XImgProc.HoughDeskewOption.html"},{"type":"function","title":"Evision.XImgProc.HoughDeskewOption.cv_HDO_DESKEW/0","doc":"","ref":"Evision.XImgProc.HoughDeskewOption.html#cv_HDO_DESKEW/0"},{"type":"function","title":"Evision.XImgProc.HoughDeskewOption.cv_HDO_RAW/0","doc":"","ref":"Evision.XImgProc.HoughDeskewOption.html#cv_HDO_RAW/0"},{"type":"type","title":"Evision.XImgProc.HoughDeskewOption.enum/0","doc":"","ref":"Evision.XImgProc.HoughDeskewOption.html#t:enum/0"},{"type":"module","title":"Evision.XImgProc.HoughOp","doc":"","ref":"Evision.XImgProc.HoughOp.html"},{"type":"function","title":"Evision.XImgProc.HoughOp.cv_FHT_ADD/0","doc":"","ref":"Evision.XImgProc.HoughOp.html#cv_FHT_ADD/0"},{"type":"function","title":"Evision.XImgProc.HoughOp.cv_FHT_AVE/0","doc":"","ref":"Evision.XImgProc.HoughOp.html#cv_FHT_AVE/0"},{"type":"function","title":"Evision.XImgProc.HoughOp.cv_FHT_MAX/0","doc":"","ref":"Evision.XImgProc.HoughOp.html#cv_FHT_MAX/0"},{"type":"function","title":"Evision.XImgProc.HoughOp.cv_FHT_MIN/0","doc":"","ref":"Evision.XImgProc.HoughOp.html#cv_FHT_MIN/0"},{"type":"type","title":"Evision.XImgProc.HoughOp.enum/0","doc":"","ref":"Evision.XImgProc.HoughOp.html#t:enum/0"},{"type":"module","title":"Evision.XImgProc.LocalBinarizationMethods","doc":"","ref":"Evision.XImgProc.LocalBinarizationMethods.html"},{"type":"function","title":"Evision.XImgProc.LocalBinarizationMethods.cv_BINARIZATION_NIBLACK/0","doc":"","ref":"Evision.XImgProc.LocalBinarizationMethods.html#cv_BINARIZATION_NIBLACK/0"},{"type":"function","title":"Evision.XImgProc.LocalBinarizationMethods.cv_BINARIZATION_NICK/0","doc":"","ref":"Evision.XImgProc.LocalBinarizationMethods.html#cv_BINARIZATION_NICK/0"},{"type":"function","title":"Evision.XImgProc.LocalBinarizationMethods.cv_BINARIZATION_SAUVOLA/0","doc":"","ref":"Evision.XImgProc.LocalBinarizationMethods.html#cv_BINARIZATION_SAUVOLA/0"},{"type":"function","title":"Evision.XImgProc.LocalBinarizationMethods.cv_BINARIZATION_WOLF/0","doc":"","ref":"Evision.XImgProc.LocalBinarizationMethods.html#cv_BINARIZATION_WOLF/0"},{"type":"type","title":"Evision.XImgProc.LocalBinarizationMethods.enum/0","doc":"","ref":"Evision.XImgProc.LocalBinarizationMethods.html#t:enum/0"},{"type":"module","title":"Evision.XImgProc.RFFeatureGetter","doc":"","ref":"Evision.XImgProc.RFFeatureGetter.html"},{"type":"function","title":"Evision.XImgProc.RFFeatureGetter.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RFFeatureGetter.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XImgProc.RFFeatureGetter.html#clear/1"},{"type":"function","title":"Evision.XImgProc.RFFeatureGetter.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RFFeatureGetter.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XImgProc.RFFeatureGetter.html#empty/1"},{"type":"function","title":"Evision.XImgProc.RFFeatureGetter.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RFFeatureGetter.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XImgProc.RFFeatureGetter.html#getDefaultName/1"},{"type":"function","title":"Evision.XImgProc.RFFeatureGetter.getFeatures/1","doc":"","ref":"Evision.XImgProc.RFFeatureGetter.html#getFeatures/1"},{"type":"function","title":"Evision.XImgProc.RFFeatureGetter.getFeatures/8","doc":"getFeatures\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RFFeatureGetter.t()`\n- **src**: `Evision.Mat`\n- **features**: `Evision.Mat`\n- **gnrmRad**: `integer()`\n- **gsmthRad**: `integer()`\n- **shrink**: `integer()`\n- **outNum**: `integer()`\n- **gradNum**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetFeatures(src, features, gnrmRad, gsmthRad, shrink, outNum, gradNum) -> None\n```","ref":"Evision.XImgProc.RFFeatureGetter.html#getFeatures/8"},{"type":"function","title":"Evision.XImgProc.RFFeatureGetter.read/1","doc":"","ref":"Evision.XImgProc.RFFeatureGetter.html#read/1"},{"type":"function","title":"Evision.XImgProc.RFFeatureGetter.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RFFeatureGetter.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XImgProc.RFFeatureGetter.html#read/2"},{"type":"function","title":"Evision.XImgProc.RFFeatureGetter.save/1","doc":"","ref":"Evision.XImgProc.RFFeatureGetter.html#save/1"},{"type":"function","title":"Evision.XImgProc.RFFeatureGetter.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RFFeatureGetter.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XImgProc.RFFeatureGetter.html#save/2"},{"type":"function","title":"Evision.XImgProc.RFFeatureGetter.write/1","doc":"","ref":"Evision.XImgProc.RFFeatureGetter.html#write/1"},{"type":"function","title":"Evision.XImgProc.RFFeatureGetter.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RFFeatureGetter.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XImgProc.RFFeatureGetter.html#write/2"},{"type":"function","title":"Evision.XImgProc.RFFeatureGetter.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RFFeatureGetter.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XImgProc.RFFeatureGetter.html#write/3"},{"type":"type","title":"Evision.XImgProc.RFFeatureGetter.t/0","doc":"Type that represents an `XImgProc.RFFeatureGetter` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.RFFeatureGetter.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.RICInterpolator","doc":"","ref":"Evision.XImgProc.RICInterpolator.html"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.getAlpha/1","doc":"getAlpha\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Return\n- **retval**: `float`\n\n@copybrief setAlpha\n@see `setAlpha/2`\n\nPython prototype (for reference only):\n```python3\ngetAlpha() -> retval\n```","ref":"Evision.XImgProc.RICInterpolator.html#getAlpha/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.getFGSLambda/1","doc":"getFGSLambda\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Return\n- **retval**: `float`\n\n@copybrief setFGSLambda\n@see `setFGSLambda/2`\n\nPython prototype (for reference only):\n```python3\ngetFGSLambda() -> retval\n```","ref":"Evision.XImgProc.RICInterpolator.html#getFGSLambda/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.getFGSSigma/1","doc":"getFGSSigma\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Return\n- **retval**: `float`\n\n@copybrief setFGSSigma\n@see `setFGSSigma/2`\n\nPython prototype (for reference only):\n```python3\ngetFGSSigma() -> retval\n```","ref":"Evision.XImgProc.RICInterpolator.html#getFGSSigma/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.getK/1","doc":"getK\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@copybrief setK\n@see `setK/2`\n\nPython prototype (for reference only):\n```python3\ngetK() -> retval\n```","ref":"Evision.XImgProc.RICInterpolator.html#getK/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.getMaxFlow/1","doc":"getMaxFlow\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Return\n- **retval**: `float`\n\n@copybrief setMaxFlow\n@see `setMaxFlow/2`\n\nPython prototype (for reference only):\n```python3\ngetMaxFlow() -> retval\n```","ref":"Evision.XImgProc.RICInterpolator.html#getMaxFlow/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.getModelIter/1","doc":"getModelIter\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@copybrief setModelIter\n@see `setModelIter/2`\n\nPython prototype (for reference only):\n```python3\ngetModelIter() -> retval\n```","ref":"Evision.XImgProc.RICInterpolator.html#getModelIter/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.getRefineModels/1","doc":"getRefineModels\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Return\n- **retval**: `bool`\n\n@copybrief setRefineModels\n@see `setRefineModels/2`\n\nPython prototype (for reference only):\n```python3\ngetRefineModels() -> retval\n```","ref":"Evision.XImgProc.RICInterpolator.html#getRefineModels/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.getSuperpixelMode/1","doc":"getSuperpixelMode\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@copybrief setSuperpixelMode\n@see `setSuperpixelMode/2`\n\nPython prototype (for reference only):\n```python3\ngetSuperpixelMode() -> retval\n```","ref":"Evision.XImgProc.RICInterpolator.html#getSuperpixelMode/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.getSuperpixelNNCnt/1","doc":"getSuperpixelNNCnt\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@copybrief setSuperpixelNNCnt\n@see `setSuperpixelNNCnt/2`\n\nPython prototype (for reference only):\n```python3\ngetSuperpixelNNCnt() -> retval\n```","ref":"Evision.XImgProc.RICInterpolator.html#getSuperpixelNNCnt/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.getSuperpixelRuler/1","doc":"getSuperpixelRuler\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Return\n- **retval**: `float`\n\n@copybrief setSuperpixelRuler\n@see `setSuperpixelRuler/2`\n\nPython prototype (for reference only):\n```python3\ngetSuperpixelRuler() -> retval\n```","ref":"Evision.XImgProc.RICInterpolator.html#getSuperpixelRuler/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.getSuperpixelSize/1","doc":"getSuperpixelSize\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@copybrief setSuperpixelSize\n@see `setSuperpixelSize/2`\n\nPython prototype (for reference only):\n```python3\ngetSuperpixelSize() -> retval\n```","ref":"Evision.XImgProc.RICInterpolator.html#getSuperpixelSize/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.getUseGlobalSmootherFilter/1","doc":"getUseGlobalSmootherFilter\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Return\n- **retval**: `bool`\n\n@copybrief setUseGlobalSmootherFilter\n@see `setUseGlobalSmootherFilter/2`\n\nPython prototype (for reference only):\n```python3\ngetUseGlobalSmootherFilter() -> retval\n```","ref":"Evision.XImgProc.RICInterpolator.html#getUseGlobalSmootherFilter/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.getUseVariationalRefinement/1","doc":"getUseVariationalRefinement\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Return\n- **retval**: `bool`\n\n@copybrief setUseVariationalRefinement\n@see `setUseVariationalRefinement/2`\n\nPython prototype (for reference only):\n```python3\ngetUseVariationalRefinement() -> retval\n```","ref":"Evision.XImgProc.RICInterpolator.html#getUseVariationalRefinement/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setAlpha/1","doc":"Alpha is a parameter defining a global weight for transforming geodesic distance into weight.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **alpha**: `float`.\n\nPython prototype (for reference only):\n```python3\nsetAlpha([, alpha]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setAlpha/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setAlpha/2","doc":"Alpha is a parameter defining a global weight for transforming geodesic distance into weight.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **alpha**: `float`.\n\nPython prototype (for reference only):\n```python3\nsetAlpha([, alpha]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setAlpha/2"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setCostMap/1","doc":"","ref":"Evision.XImgProc.RICInterpolator.html#setCostMap/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setCostMap/2","doc":"Interface to provide a more elaborated cost map, i.e. edge map, for the edge-aware term.\nThis implementation is based on a rather simple gradient-based edge map estimation.\nTo used more complex edge map estimator (e.g. StructuredEdgeDetection that has been\nused in the original publication) that may lead to improved accuracies, the internal\nedge map estimation can be bypassed here.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n- **costMap**: `Evision.Mat`.\n\n  a type CV_32FC1 Mat is required.\n\n@see cv::ximgproc::createSuperpixelSLIC\n\nPython prototype (for reference only):\n```python3\nsetCostMap(costMap) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setCostMap/2"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setFGSLambda/1","doc":"Sets the respective fastGlobalSmootherFilter() parameter.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **lambda**: `float`.\n\nPython prototype (for reference only):\n```python3\nsetFGSLambda([, lambda]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setFGSLambda/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setFGSLambda/2","doc":"Sets the respective fastGlobalSmootherFilter() parameter.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **lambda**: `float`.\n\nPython prototype (for reference only):\n```python3\nsetFGSLambda([, lambda]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setFGSLambda/2"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setFGSSigma/1","doc":"Sets the respective fastGlobalSmootherFilter() parameter.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **sigma**: `float`.\n\nPython prototype (for reference only):\n```python3\nsetFGSSigma([, sigma]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setFGSSigma/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setFGSSigma/2","doc":"Sets the respective fastGlobalSmootherFilter() parameter.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **sigma**: `float`.\n\nPython prototype (for reference only):\n```python3\nsetFGSSigma([, sigma]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setFGSSigma/2"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setK/1","doc":"K is a number of nearest-neighbor matches considered, when fitting a locally affine\nmodel for a superpixel segment. However, lower values would make the interpolation\nnoticeably faster. The original implementation of @cite Hu2017 uses 32.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **k**: `integer()`.\n\nPython prototype (for reference only):\n```python3\nsetK([, k]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setK/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setK/2","doc":"K is a number of nearest-neighbor matches considered, when fitting a locally affine\nmodel for a superpixel segment. However, lower values would make the interpolation\nnoticeably faster. The original implementation of @cite Hu2017 uses 32.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **k**: `integer()`.\n\nPython prototype (for reference only):\n```python3\nsetK([, k]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setK/2"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setMaxFlow/1","doc":"MaxFlow is a threshold to validate the predictions using a certain piece-wise affine model.\nIf the prediction exceeds the treshold the translational model will be applied instead.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **maxFlow**: `float`.\n\nPython prototype (for reference only):\n```python3\nsetMaxFlow([, maxFlow]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setMaxFlow/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setMaxFlow/2","doc":"MaxFlow is a threshold to validate the predictions using a certain piece-wise affine model.\nIf the prediction exceeds the treshold the translational model will be applied instead.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **maxFlow**: `float`.\n\nPython prototype (for reference only):\n```python3\nsetMaxFlow([, maxFlow]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setMaxFlow/2"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setModelIter/1","doc":"Parameter defining the number of iterations for piece-wise affine model estimation.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **modelIter**: `integer()`.\n\nPython prototype (for reference only):\n```python3\nsetModelIter([, modelIter]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setModelIter/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setModelIter/2","doc":"Parameter defining the number of iterations for piece-wise affine model estimation.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **modelIter**: `integer()`.\n\nPython prototype (for reference only):\n```python3\nsetModelIter([, modelIter]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setModelIter/2"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setRefineModels/1","doc":"Parameter to choose wether additional refinement of the piece-wise affine models is employed.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **refineModles**: `bool`.\n\nPython prototype (for reference only):\n```python3\nsetRefineModels([, refineModles]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setRefineModels/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setRefineModels/2","doc":"Parameter to choose wether additional refinement of the piece-wise affine models is employed.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **refineModles**: `bool`.\n\nPython prototype (for reference only):\n```python3\nsetRefineModels([, refineModles]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setRefineModels/2"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setSuperpixelMode/1","doc":"Parameter to choose superpixel algorithm variant to use:\n- cv::ximgproc::SLICType SLIC segments image using a desired region_size (value: 100)\n- cv::ximgproc::SLICType SLICO will optimize using adaptive compactness factor (value: 101)\n- cv::ximgproc::SLICType MSLIC will optimize using manifold methods resulting in more content-sensitive superpixels (value: 102).\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **mode**: `integer()`.\n\n@see cv::ximgproc::createSuperpixelSLIC\n\nPython prototype (for reference only):\n```python3\nsetSuperpixelMode([, mode]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setSuperpixelMode/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setSuperpixelMode/2","doc":"Parameter to choose superpixel algorithm variant to use:\n- cv::ximgproc::SLICType SLIC segments image using a desired region_size (value: 100)\n- cv::ximgproc::SLICType SLICO will optimize using adaptive compactness factor (value: 101)\n- cv::ximgproc::SLICType MSLIC will optimize using manifold methods resulting in more content-sensitive superpixels (value: 102).\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **mode**: `integer()`.\n\n@see cv::ximgproc::createSuperpixelSLIC\n\nPython prototype (for reference only):\n```python3\nsetSuperpixelMode([, mode]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setSuperpixelMode/2"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setSuperpixelNNCnt/1","doc":"Parameter defines the number of nearest-neighbor matches for each superpixel considered, when fitting a locally affine\nmodel.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **spNN**: `integer()`.\n\nPython prototype (for reference only):\n```python3\nsetSuperpixelNNCnt([, spNN]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setSuperpixelNNCnt/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setSuperpixelNNCnt/2","doc":"Parameter defines the number of nearest-neighbor matches for each superpixel considered, when fitting a locally affine\nmodel.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **spNN**: `integer()`.\n\nPython prototype (for reference only):\n```python3\nsetSuperpixelNNCnt([, spNN]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setSuperpixelNNCnt/2"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setSuperpixelRuler/1","doc":"Parameter to tune enforcement of superpixel smoothness factor used for oversegmentation.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **ruler**: `float`.\n\n@see cv::ximgproc::createSuperpixelSLIC\n\nPython prototype (for reference only):\n```python3\nsetSuperpixelRuler([, ruler]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setSuperpixelRuler/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setSuperpixelRuler/2","doc":"Parameter to tune enforcement of superpixel smoothness factor used for oversegmentation.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **ruler**: `float`.\n\n@see cv::ximgproc::createSuperpixelSLIC\n\nPython prototype (for reference only):\n```python3\nsetSuperpixelRuler([, ruler]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setSuperpixelRuler/2"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setSuperpixelSize/1","doc":"Get the internal cost, i.e. edge map, used for estimating the edge-aware term.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **spSize**: `integer()`.\n\n@see `setCostMap/2`\n\nPython prototype (for reference only):\n```python3\nsetSuperpixelSize([, spSize]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setSuperpixelSize/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setSuperpixelSize/2","doc":"Get the internal cost, i.e. edge map, used for estimating the edge-aware term.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **spSize**: `integer()`.\n\n@see `setCostMap/2`\n\nPython prototype (for reference only):\n```python3\nsetSuperpixelSize([, spSize]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setSuperpixelSize/2"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setUseGlobalSmootherFilter/1","doc":"Sets whether the fastGlobalSmootherFilter() post-processing is employed.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **use_FGS**: `bool`.\n\nPython prototype (for reference only):\n```python3\nsetUseGlobalSmootherFilter([, use_FGS]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setUseGlobalSmootherFilter/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setUseGlobalSmootherFilter/2","doc":"Sets whether the fastGlobalSmootherFilter() post-processing is employed.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **use_FGS**: `bool`.\n\nPython prototype (for reference only):\n```python3\nsetUseGlobalSmootherFilter([, use_FGS]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setUseGlobalSmootherFilter/2"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setUseVariationalRefinement/1","doc":"Parameter to choose wether the VariationalRefinement post-processing  is employed.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **use_variational_refinement**: `bool`.\n\nPython prototype (for reference only):\n```python3\nsetUseVariationalRefinement([, use_variational_refinement]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setUseVariationalRefinement/1"},{"type":"function","title":"Evision.XImgProc.RICInterpolator.setUseVariationalRefinement/2","doc":"Parameter to choose wether the VariationalRefinement post-processing  is employed.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RICInterpolator.t()`\n\n##### Keyword Arguments\n- **use_variational_refinement**: `bool`.\n\nPython prototype (for reference only):\n```python3\nsetUseVariationalRefinement([, use_variational_refinement]) -> None\n```","ref":"Evision.XImgProc.RICInterpolator.html#setUseVariationalRefinement/2"},{"type":"type","title":"Evision.XImgProc.RICInterpolator.t/0","doc":"Type that represents an `XImgProc.RICInterpolator` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.RICInterpolator.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.RidgeDetectionFilter","doc":"","ref":"Evision.XImgProc.RidgeDetectionFilter.html"},{"type":"function","title":"Evision.XImgProc.RidgeDetectionFilter.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RidgeDetectionFilter.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XImgProc.RidgeDetectionFilter.html#clear/1"},{"type":"function","title":"Evision.XImgProc.RidgeDetectionFilter.create/0","doc":"Create pointer to the Ridge detection filter.\n##### Keyword Arguments\n- **ddepth**: `integer()`.\n\n  Specifies output image depth. Defualt is CV_32FC1\n\n- **dx**: `integer()`.\n\n  Order of derivative x, default is 1\n\n- **dy**: `integer()`.\n\n  Order of derivative y, default is 1\n\n- **ksize**: `integer()`.\n\n  Sobel kernel size , default is 3\n\n- **out_dtype**: `integer()`.\n\n  Converted format for output, default is CV_8UC1\n\n- **scale**: `double`.\n\n  Optional scale value for derivative values, default is 1\n\n- **delta**: `double`.\n\n  Optional bias added to output, default is 0\n\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method, default is BORDER_DEFAULT\n\n##### Return\n- **retval**: `RidgeDetectionFilter`\n\n@see Sobel, threshold, getStructuringElement, morphologyEx.( for additional refinement)\n\nPython prototype (for reference only):\n```python3\ncreate([, ddepth[, dx[, dy[, ksize[, out_dtype[, scale[, delta[, borderType]]]]]]]]) -> retval\n```","ref":"Evision.XImgProc.RidgeDetectionFilter.html#create/0"},{"type":"function","title":"Evision.XImgProc.RidgeDetectionFilter.create/1","doc":"Create pointer to the Ridge detection filter.\n##### Keyword Arguments\n- **ddepth**: `integer()`.\n\n  Specifies output image depth. Defualt is CV_32FC1\n\n- **dx**: `integer()`.\n\n  Order of derivative x, default is 1\n\n- **dy**: `integer()`.\n\n  Order of derivative y, default is 1\n\n- **ksize**: `integer()`.\n\n  Sobel kernel size , default is 3\n\n- **out_dtype**: `integer()`.\n\n  Converted format for output, default is CV_8UC1\n\n- **scale**: `double`.\n\n  Optional scale value for derivative values, default is 1\n\n- **delta**: `double`.\n\n  Optional bias added to output, default is 0\n\n- **borderType**: `integer()`.\n\n  Pixel extrapolation method, default is BORDER_DEFAULT\n\n##### Return\n- **retval**: `RidgeDetectionFilter`\n\n@see Sobel, threshold, getStructuringElement, morphologyEx.( for additional refinement)\n\nPython prototype (for reference only):\n```python3\ncreate([, ddepth[, dx[, dy[, ksize[, out_dtype[, scale[, delta[, borderType]]]]]]]]) -> retval\n```","ref":"Evision.XImgProc.RidgeDetectionFilter.html#create/1"},{"type":"function","title":"Evision.XImgProc.RidgeDetectionFilter.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RidgeDetectionFilter.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XImgProc.RidgeDetectionFilter.html#empty/1"},{"type":"function","title":"Evision.XImgProc.RidgeDetectionFilter.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RidgeDetectionFilter.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XImgProc.RidgeDetectionFilter.html#getDefaultName/1"},{"type":"function","title":"Evision.XImgProc.RidgeDetectionFilter.getRidgeFilteredImage/1","doc":"","ref":"Evision.XImgProc.RidgeDetectionFilter.html#getRidgeFilteredImage/1"},{"type":"function","title":"Evision.XImgProc.RidgeDetectionFilter.getRidgeFilteredImage/2","doc":"Apply Ridge detection filter on input image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RidgeDetectionFilter.t()`\n- **img**: `Evision.Mat`.\n\n  InputArray as supported by Sobel. img can be 1-Channel or 3-Channels.\n\n##### Return\n- **out**: `Evision.Mat.t()`.\n\n  OutputAray of structure as RidgeDetectionFilter::ddepth. Output image with ridges.\n\nPython prototype (for reference only):\n```python3\ngetRidgeFilteredImage(_img[, out]) -> out\n```","ref":"Evision.XImgProc.RidgeDetectionFilter.html#getRidgeFilteredImage/2"},{"type":"function","title":"Evision.XImgProc.RidgeDetectionFilter.getRidgeFilteredImage/3","doc":"Apply Ridge detection filter on input image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RidgeDetectionFilter.t()`\n- **img**: `Evision.Mat`.\n\n  InputArray as supported by Sobel. img can be 1-Channel or 3-Channels.\n\n##### Return\n- **out**: `Evision.Mat.t()`.\n\n  OutputAray of structure as RidgeDetectionFilter::ddepth. Output image with ridges.\n\nPython prototype (for reference only):\n```python3\ngetRidgeFilteredImage(_img[, out]) -> out\n```","ref":"Evision.XImgProc.RidgeDetectionFilter.html#getRidgeFilteredImage/3"},{"type":"function","title":"Evision.XImgProc.RidgeDetectionFilter.read/1","doc":"","ref":"Evision.XImgProc.RidgeDetectionFilter.html#read/1"},{"type":"function","title":"Evision.XImgProc.RidgeDetectionFilter.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RidgeDetectionFilter.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XImgProc.RidgeDetectionFilter.html#read/2"},{"type":"function","title":"Evision.XImgProc.RidgeDetectionFilter.save/1","doc":"","ref":"Evision.XImgProc.RidgeDetectionFilter.html#save/1"},{"type":"function","title":"Evision.XImgProc.RidgeDetectionFilter.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RidgeDetectionFilter.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XImgProc.RidgeDetectionFilter.html#save/2"},{"type":"function","title":"Evision.XImgProc.RidgeDetectionFilter.write/1","doc":"","ref":"Evision.XImgProc.RidgeDetectionFilter.html#write/1"},{"type":"function","title":"Evision.XImgProc.RidgeDetectionFilter.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RidgeDetectionFilter.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XImgProc.RidgeDetectionFilter.html#write/2"},{"type":"function","title":"Evision.XImgProc.RidgeDetectionFilter.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.RidgeDetectionFilter.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XImgProc.RidgeDetectionFilter.html#write/3"},{"type":"type","title":"Evision.XImgProc.RidgeDetectionFilter.t/0","doc":"Type that represents an `XImgProc.RidgeDetectionFilter` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.RidgeDetectionFilter.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.SLICType","doc":"","ref":"Evision.XImgProc.SLICType.html"},{"type":"function","title":"Evision.XImgProc.SLICType.cv_MSLIC/0","doc":"","ref":"Evision.XImgProc.SLICType.html#cv_MSLIC/0"},{"type":"function","title":"Evision.XImgProc.SLICType.cv_SLIC/0","doc":"","ref":"Evision.XImgProc.SLICType.html#cv_SLIC/0"},{"type":"function","title":"Evision.XImgProc.SLICType.cv_SLICO/0","doc":"","ref":"Evision.XImgProc.SLICType.html#cv_SLICO/0"},{"type":"type","title":"Evision.XImgProc.SLICType.enum/0","doc":"","ref":"Evision.XImgProc.SLICType.html#t:enum/0"},{"type":"module","title":"Evision.XImgProc.ScanSegment","doc":"","ref":"Evision.XImgProc.ScanSegment.html"},{"type":"function","title":"Evision.XImgProc.ScanSegment.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ScanSegment.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XImgProc.ScanSegment.html#clear/1"},{"type":"function","title":"Evision.XImgProc.ScanSegment.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ScanSegment.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XImgProc.ScanSegment.html#empty/1"},{"type":"function","title":"Evision.XImgProc.ScanSegment.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ScanSegment.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XImgProc.ScanSegment.html#getDefaultName/1"},{"type":"function","title":"Evision.XImgProc.ScanSegment.getLabelContourMask/1","doc":"Returns the mask of the superpixel segmentation stored in the ScanSegment object.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ScanSegment.t()`\n\n##### Keyword Arguments\n- **thick_line**: `bool`.\n\n  If false, the border is only one pixel wide, otherwise all pixels at the border are masked.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  Return: CV_8UC1 image mask where -1 indicates that the pixel is a superpixel border, and 0 otherwise.\n\nThe function return the boundaries of the superpixel segmentation.\n\nPython prototype (for reference only):\n```python3\ngetLabelContourMask([, image[, thick_line]]) -> image\n```","ref":"Evision.XImgProc.ScanSegment.html#getLabelContourMask/1"},{"type":"function","title":"Evision.XImgProc.ScanSegment.getLabelContourMask/2","doc":"Returns the mask of the superpixel segmentation stored in the ScanSegment object.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ScanSegment.t()`\n\n##### Keyword Arguments\n- **thick_line**: `bool`.\n\n  If false, the border is only one pixel wide, otherwise all pixels at the border are masked.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  Return: CV_8UC1 image mask where -1 indicates that the pixel is a superpixel border, and 0 otherwise.\n\nThe function return the boundaries of the superpixel segmentation.\n\nPython prototype (for reference only):\n```python3\ngetLabelContourMask([, image[, thick_line]]) -> image\n```","ref":"Evision.XImgProc.ScanSegment.html#getLabelContourMask/2"},{"type":"function","title":"Evision.XImgProc.ScanSegment.getLabels/1","doc":"Returns the segmentation labeling of the image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ScanSegment.t()`\n\n##### Return\n- **labels_out**: `Evision.Mat.t()`.\n\n  Return: A CV_32UC1 integer array containing the labels of the superpixel\n  segmentation. The labels are in the range [0, getNumberOfSuperpixels()].\n\nEach label represents a superpixel, and each pixel is assigned to one superpixel label.\n\nPython prototype (for reference only):\n```python3\ngetLabels([, labels_out]) -> labels_out\n```","ref":"Evision.XImgProc.ScanSegment.html#getLabels/1"},{"type":"function","title":"Evision.XImgProc.ScanSegment.getLabels/2","doc":"Returns the segmentation labeling of the image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ScanSegment.t()`\n\n##### Return\n- **labels_out**: `Evision.Mat.t()`.\n\n  Return: A CV_32UC1 integer array containing the labels of the superpixel\n  segmentation. The labels are in the range [0, getNumberOfSuperpixels()].\n\nEach label represents a superpixel, and each pixel is assigned to one superpixel label.\n\nPython prototype (for reference only):\n```python3\ngetLabels([, labels_out]) -> labels_out\n```","ref":"Evision.XImgProc.ScanSegment.html#getLabels/2"},{"type":"function","title":"Evision.XImgProc.ScanSegment.getNumberOfSuperpixels/1","doc":"Returns the actual superpixel segmentation from the last image processed using iterate.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ScanSegment.t()`\n\n##### Return\n- **retval**: `integer()`\n\nReturns zero if no image has been processed.\n\nPython prototype (for reference only):\n```python3\ngetNumberOfSuperpixels() -> retval\n```","ref":"Evision.XImgProc.ScanSegment.html#getNumberOfSuperpixels/1"},{"type":"function","title":"Evision.XImgProc.ScanSegment.iterate/1","doc":"","ref":"Evision.XImgProc.ScanSegment.html#iterate/1"},{"type":"function","title":"Evision.XImgProc.ScanSegment.iterate/2","doc":"Calculates the superpixel segmentation on a given image with the initialized\nparameters in the ScanSegment object.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ScanSegment.t()`\n- **img**: `Evision.Mat`.\n\n  Input image. Supported format: CV_8UC3. Image size must match with the initialized\n  image size with the function createScanSegment(). It MUST be in Lab color space.\n\nThis function can be called again for other images without the need of initializing the algorithm with createScanSegment().\nThis save the computational cost of allocating memory for all the structures of the algorithm.\n\nPython prototype (for reference only):\n```python3\niterate(img) -> None\n```","ref":"Evision.XImgProc.ScanSegment.html#iterate/2"},{"type":"function","title":"Evision.XImgProc.ScanSegment.read/1","doc":"","ref":"Evision.XImgProc.ScanSegment.html#read/1"},{"type":"function","title":"Evision.XImgProc.ScanSegment.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ScanSegment.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XImgProc.ScanSegment.html#read/2"},{"type":"function","title":"Evision.XImgProc.ScanSegment.save/1","doc":"","ref":"Evision.XImgProc.ScanSegment.html#save/1"},{"type":"function","title":"Evision.XImgProc.ScanSegment.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ScanSegment.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XImgProc.ScanSegment.html#save/2"},{"type":"function","title":"Evision.XImgProc.ScanSegment.write/1","doc":"","ref":"Evision.XImgProc.ScanSegment.html#write/1"},{"type":"function","title":"Evision.XImgProc.ScanSegment.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ScanSegment.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XImgProc.ScanSegment.html#write/2"},{"type":"function","title":"Evision.XImgProc.ScanSegment.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.ScanSegment.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XImgProc.ScanSegment.html#write/3"},{"type":"type","title":"Evision.XImgProc.ScanSegment.t/0","doc":"Type that represents an `XImgProc.ScanSegment` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.ScanSegment.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation","doc":"","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.addGraphSegmentation/1","doc":"","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#addGraphSegmentation/1"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.addGraphSegmentation/2","doc":"Add a new graph segmentation in the list of graph segementations to process.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.t()`\n- **g**: `Evision.XImgProc.GraphSegmentation.t()`.\n\n  The graph segmentation\n\nPython prototype (for reference only):\n```python3\naddGraphSegmentation(g) -> None\n```","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#addGraphSegmentation/2"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.addImage/1","doc":"","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#addImage/1"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.addImage/2","doc":"Add a new image in the list of images to process.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.t()`\n- **img**: `Evision.Mat`.\n\n  The image\n\nPython prototype (for reference only):\n```python3\naddImage(img) -> None\n```","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#addImage/2"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.addStrategy/1","doc":"","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#addStrategy/1"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.addStrategy/2","doc":"Add a new strategy in the list of strategy to process.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.t()`\n- **s**: `Evision.XImgProc.SelectiveSearchSegmentationStrategy.t()`.\n\n  The strategy\n\nPython prototype (for reference only):\n```python3\naddStrategy(s) -> None\n```","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#addStrategy/2"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#clear/1"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.clearGraphSegmentations/1","doc":"Clear the list of graph segmentations to process;\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.t()`\n\nPython prototype (for reference only):\n```python3\nclearGraphSegmentations() -> None\n```","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#clearGraphSegmentations/1"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.clearImages/1","doc":"Clear the list of images to process\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.t()`\n\nPython prototype (for reference only):\n```python3\nclearImages() -> None\n```","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#clearImages/1"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.clearStrategies/1","doc":"Clear the list of strategy to process;\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.t()`\n\nPython prototype (for reference only):\n```python3\nclearStrategies() -> None\n```","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#clearStrategies/1"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#empty/1"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#getDefaultName/1"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.process/1","doc":"Based on all images, graph segmentations and stragies, computes all possible rects and return them\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.t()`\n\n##### Return\n- **rects**: `[Rect]`.\n\n  The list of rects. The first ones are more relevents than the lasts ones.\n\nPython prototype (for reference only):\n```python3\nprocess() -> rects\n```","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#process/1"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.read/1","doc":"","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#read/1"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#read/2"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.save/1","doc":"","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#save/1"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#save/2"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.setBaseImage/1","doc":"","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#setBaseImage/1"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.setBaseImage/2","doc":"Set a image used by switch* functions to initialize the class\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.t()`\n- **img**: `Evision.Mat`.\n\n  The image\n\nPython prototype (for reference only):\n```python3\nsetBaseImage(img) -> None\n```","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#setBaseImage/2"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.switchToSelectiveSearchFast/1","doc":"Initialize the class with the 'Selective search fast' parameters describled in @cite uijlings2013selective.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.t()`\n\n##### Keyword Arguments\n- **base_k**: `integer()`.\n\n  The k parameter for the first graph segmentation\n\n- **inc_k**: `integer()`.\n\n  The increment of the k parameter for all graph segmentations\n\n- **sigma**: `float`.\n\n  The sigma parameter for the graph segmentation\n\nPython prototype (for reference only):\n```python3\nswitchToSelectiveSearchFast([, base_k[, inc_k[, sigma]]]) -> None\n```","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#switchToSelectiveSearchFast/1"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.switchToSelectiveSearchFast/2","doc":"Initialize the class with the 'Selective search fast' parameters describled in @cite uijlings2013selective.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.t()`\n\n##### Keyword Arguments\n- **base_k**: `integer()`.\n\n  The k parameter for the first graph segmentation\n\n- **inc_k**: `integer()`.\n\n  The increment of the k parameter for all graph segmentations\n\n- **sigma**: `float`.\n\n  The sigma parameter for the graph segmentation\n\nPython prototype (for reference only):\n```python3\nswitchToSelectiveSearchFast([, base_k[, inc_k[, sigma]]]) -> None\n```","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#switchToSelectiveSearchFast/2"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.switchToSelectiveSearchQuality/1","doc":"Initialize the class with the 'Selective search fast' parameters describled in @cite uijlings2013selective.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.t()`\n\n##### Keyword Arguments\n- **base_k**: `integer()`.\n\n  The k parameter for the first graph segmentation\n\n- **inc_k**: `integer()`.\n\n  The increment of the k parameter for all graph segmentations\n\n- **sigma**: `float`.\n\n  The sigma parameter for the graph segmentation\n\nPython prototype (for reference only):\n```python3\nswitchToSelectiveSearchQuality([, base_k[, inc_k[, sigma]]]) -> None\n```","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#switchToSelectiveSearchQuality/1"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.switchToSelectiveSearchQuality/2","doc":"Initialize the class with the 'Selective search fast' parameters describled in @cite uijlings2013selective.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.t()`\n\n##### Keyword Arguments\n- **base_k**: `integer()`.\n\n  The k parameter for the first graph segmentation\n\n- **inc_k**: `integer()`.\n\n  The increment of the k parameter for all graph segmentations\n\n- **sigma**: `float`.\n\n  The sigma parameter for the graph segmentation\n\nPython prototype (for reference only):\n```python3\nswitchToSelectiveSearchQuality([, base_k[, inc_k[, sigma]]]) -> None\n```","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#switchToSelectiveSearchQuality/2"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.switchToSingleStrategy/1","doc":"Initialize the class with the 'Single stragegy' parameters describled in @cite uijlings2013selective.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.t()`\n\n##### Keyword Arguments\n- **k**: `integer()`.\n\n  The k parameter for the graph segmentation\n\n- **sigma**: `float`.\n\n  The sigma parameter for the graph segmentation\n\nPython prototype (for reference only):\n```python3\nswitchToSingleStrategy([, k[, sigma]]) -> None\n```","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#switchToSingleStrategy/1"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.switchToSingleStrategy/2","doc":"Initialize the class with the 'Single stragegy' parameters describled in @cite uijlings2013selective.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.t()`\n\n##### Keyword Arguments\n- **k**: `integer()`.\n\n  The k parameter for the graph segmentation\n\n- **sigma**: `float`.\n\n  The sigma parameter for the graph segmentation\n\nPython prototype (for reference only):\n```python3\nswitchToSingleStrategy([, k[, sigma]]) -> None\n```","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#switchToSingleStrategy/2"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.write/1","doc":"","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#write/1"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#write/2"},{"type":"function","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#write/3"},{"type":"type","title":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.t/0","doc":"Type that represents an `XImgProc.Segmentation.SelectiveSearchSegmentation` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.Segmentation.SelectiveSearchSegmentation.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.SelectiveSearchSegmentation","doc":"","ref":"Evision.XImgProc.SelectiveSearchSegmentation.html"},{"type":"type","title":"Evision.XImgProc.SelectiveSearchSegmentation.t/0","doc":"Type that represents an `XImgProc.SelectiveSearchSegmentation` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.SelectiveSearchSegmentation.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategy","doc":"","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.html"},{"type":"function","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SelectiveSearchSegmentationStrategy.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.html#clear/1"},{"type":"function","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SelectiveSearchSegmentationStrategy.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.html#empty/1"},{"type":"function","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.get/1","doc":"","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.html#get/1"},{"type":"function","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.get/3","doc":"Return the score between two regions (between 0 and 1)\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SelectiveSearchSegmentationStrategy.t()`\n- **r1**: `integer()`.\n\n  The first region\n\n- **r2**: `integer()`.\n\n  The second region\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\nget(r1, r2) -> retval\n```","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.html#get/3"},{"type":"function","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SelectiveSearchSegmentationStrategy.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.html#getDefaultName/1"},{"type":"function","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.merge/1","doc":"","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.html#merge/1"},{"type":"function","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.merge/3","doc":"Inform the strategy that two regions will be merged\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SelectiveSearchSegmentationStrategy.t()`\n- **r1**: `integer()`.\n\n  The first region\n\n- **r2**: `integer()`.\n\n  The second region\n\nPython prototype (for reference only):\n```python3\nmerge(r1, r2) -> None\n```","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.html#merge/3"},{"type":"function","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.read/1","doc":"","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.html#read/1"},{"type":"function","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SelectiveSearchSegmentationStrategy.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.html#read/2"},{"type":"function","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.save/1","doc":"","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.html#save/1"},{"type":"function","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SelectiveSearchSegmentationStrategy.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.html#save/2"},{"type":"function","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.setImage/1","doc":"","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.html#setImage/1"},{"type":"function","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.setImage/4","doc":"Set a initial image, with a segmentation.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SelectiveSearchSegmentationStrategy.t()`\n- **img**: `Evision.Mat`.\n\n  The input image. Any number of channel can be provided\n\n- **regions**: `Evision.Mat`.\n\n  A segmentation of the image. The parameter must be the same size of img.\n\n- **sizes**: `Evision.Mat`.\n\n  The sizes of different regions\n\n##### Keyword Arguments\n- **image_id**: `integer()`.\n\n  If not set to -1, try to cache pre-computations. If the same set og (img, regions, size) is used, the image_id need to be the same.\n\nPython prototype (for reference only):\n```python3\nsetImage(img, regions, sizes[, image_id]) -> None\n```","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.html#setImage/4"},{"type":"function","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.setImage/5","doc":"Set a initial image, with a segmentation.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SelectiveSearchSegmentationStrategy.t()`\n- **img**: `Evision.Mat`.\n\n  The input image. Any number of channel can be provided\n\n- **regions**: `Evision.Mat`.\n\n  A segmentation of the image. The parameter must be the same size of img.\n\n- **sizes**: `Evision.Mat`.\n\n  The sizes of different regions\n\n##### Keyword Arguments\n- **image_id**: `integer()`.\n\n  If not set to -1, try to cache pre-computations. If the same set og (img, regions, size) is used, the image_id need to be the same.\n\nPython prototype (for reference only):\n```python3\nsetImage(img, regions, sizes[, image_id]) -> None\n```","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.html#setImage/5"},{"type":"function","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.write/1","doc":"","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.html#write/1"},{"type":"function","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SelectiveSearchSegmentationStrategy.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.html#write/2"},{"type":"function","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SelectiveSearchSegmentationStrategy.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.html#write/3"},{"type":"type","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.t/0","doc":"Type that represents an `XImgProc.SelectiveSearchSegmentationStrategy` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategy.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategyColor","doc":"","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategyColor.html"},{"type":"type","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategyColor.t/0","doc":"Type that represents an `XImgProc.SelectiveSearchSegmentationStrategyColor` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategyColor.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategyFill","doc":"","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategyFill.html"},{"type":"type","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategyFill.t/0","doc":"Type that represents an `XImgProc.SelectiveSearchSegmentationStrategyFill` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategyFill.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategyMultiple","doc":"","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategyMultiple.html"},{"type":"function","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategyMultiple.addStrategy/1","doc":"","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategyMultiple.html#addStrategy/1"},{"type":"function","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategyMultiple.addStrategy/3","doc":"Add a new sub-strategy\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SelectiveSearchSegmentationStrategyMultiple.t()`\n- **g**: `Evision.XImgProc.SelectiveSearchSegmentationStrategy.t()`.\n\n  The strategy\n\n- **weight**: `float`.\n\n  The weight of the strategy\n\nPython prototype (for reference only):\n```python3\naddStrategy(g, weight) -> None\n```","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategyMultiple.html#addStrategy/3"},{"type":"function","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategyMultiple.clearStrategies/1","doc":"Remove all sub-strategies\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SelectiveSearchSegmentationStrategyMultiple.t()`\n\nPython prototype (for reference only):\n```python3\nclearStrategies() -> None\n```","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategyMultiple.html#clearStrategies/1"},{"type":"type","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategyMultiple.t/0","doc":"Type that represents an `XImgProc.SelectiveSearchSegmentationStrategyMultiple` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategyMultiple.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategySize","doc":"","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategySize.html"},{"type":"type","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategySize.t/0","doc":"Type that represents an `XImgProc.SelectiveSearchSegmentationStrategySize` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategySize.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategyTexture","doc":"","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategyTexture.html"},{"type":"type","title":"Evision.XImgProc.SelectiveSearchSegmentationStrategyTexture.t/0","doc":"Type that represents an `XImgProc.SelectiveSearchSegmentationStrategyTexture` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.SelectiveSearchSegmentationStrategyTexture.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.SparseMatchInterpolator","doc":"","ref":"Evision.XImgProc.SparseMatchInterpolator.html"},{"type":"function","title":"Evision.XImgProc.SparseMatchInterpolator.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SparseMatchInterpolator.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XImgProc.SparseMatchInterpolator.html#clear/1"},{"type":"function","title":"Evision.XImgProc.SparseMatchInterpolator.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SparseMatchInterpolator.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XImgProc.SparseMatchInterpolator.html#empty/1"},{"type":"function","title":"Evision.XImgProc.SparseMatchInterpolator.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SparseMatchInterpolator.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XImgProc.SparseMatchInterpolator.html#getDefaultName/1"},{"type":"function","title":"Evision.XImgProc.SparseMatchInterpolator.interpolate/1","doc":"","ref":"Evision.XImgProc.SparseMatchInterpolator.html#interpolate/1"},{"type":"function","title":"Evision.XImgProc.SparseMatchInterpolator.interpolate/5","doc":"Interpolate input sparse matches.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SparseMatchInterpolator.t()`\n- **from_image**: `Evision.Mat`.\n\n  first of the two matched images, 8-bit single-channel or three-channel.\n\n- **from_points**: `Evision.Mat`.\n\n  points of the from_image for which there are correspondences in the\n  to_image (Point2f vector or Mat of depth CV_32F)\n\n- **to_image**: `Evision.Mat`.\n\n  second of the two matched images, 8-bit single-channel or three-channel.\n\n- **to_points**: `Evision.Mat`.\n\n  points in the to_image corresponding to from_points\n  (Point2f vector or Mat of depth CV_32F)\n\n##### Return\n- **dense_flow**: `Evision.Mat.t()`.\n\n  output dense matching (two-channel CV_32F image)\n\nPython prototype (for reference only):\n```python3\ninterpolate(from_image, from_points, to_image, to_points[, dense_flow]) -> dense_flow\n```","ref":"Evision.XImgProc.SparseMatchInterpolator.html#interpolate/5"},{"type":"function","title":"Evision.XImgProc.SparseMatchInterpolator.interpolate/6","doc":"Interpolate input sparse matches.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SparseMatchInterpolator.t()`\n- **from_image**: `Evision.Mat`.\n\n  first of the two matched images, 8-bit single-channel or three-channel.\n\n- **from_points**: `Evision.Mat`.\n\n  points of the from_image for which there are correspondences in the\n  to_image (Point2f vector or Mat of depth CV_32F)\n\n- **to_image**: `Evision.Mat`.\n\n  second of the two matched images, 8-bit single-channel or three-channel.\n\n- **to_points**: `Evision.Mat`.\n\n  points in the to_image corresponding to from_points\n  (Point2f vector or Mat of depth CV_32F)\n\n##### Return\n- **dense_flow**: `Evision.Mat.t()`.\n\n  output dense matching (two-channel CV_32F image)\n\nPython prototype (for reference only):\n```python3\ninterpolate(from_image, from_points, to_image, to_points[, dense_flow]) -> dense_flow\n```","ref":"Evision.XImgProc.SparseMatchInterpolator.html#interpolate/6"},{"type":"function","title":"Evision.XImgProc.SparseMatchInterpolator.read/1","doc":"","ref":"Evision.XImgProc.SparseMatchInterpolator.html#read/1"},{"type":"function","title":"Evision.XImgProc.SparseMatchInterpolator.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SparseMatchInterpolator.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XImgProc.SparseMatchInterpolator.html#read/2"},{"type":"function","title":"Evision.XImgProc.SparseMatchInterpolator.save/1","doc":"","ref":"Evision.XImgProc.SparseMatchInterpolator.html#save/1"},{"type":"function","title":"Evision.XImgProc.SparseMatchInterpolator.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SparseMatchInterpolator.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XImgProc.SparseMatchInterpolator.html#save/2"},{"type":"function","title":"Evision.XImgProc.SparseMatchInterpolator.write/1","doc":"","ref":"Evision.XImgProc.SparseMatchInterpolator.html#write/1"},{"type":"function","title":"Evision.XImgProc.SparseMatchInterpolator.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SparseMatchInterpolator.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XImgProc.SparseMatchInterpolator.html#write/2"},{"type":"function","title":"Evision.XImgProc.SparseMatchInterpolator.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SparseMatchInterpolator.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XImgProc.SparseMatchInterpolator.html#write/3"},{"type":"type","title":"Evision.XImgProc.SparseMatchInterpolator.t/0","doc":"Type that represents an `XImgProc.SparseMatchInterpolator` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.SparseMatchInterpolator.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.StructuredEdgeDetection","doc":"","ref":"Evision.XImgProc.StructuredEdgeDetection.html"},{"type":"function","title":"Evision.XImgProc.StructuredEdgeDetection.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.StructuredEdgeDetection.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XImgProc.StructuredEdgeDetection.html#clear/1"},{"type":"function","title":"Evision.XImgProc.StructuredEdgeDetection.computeOrientation/1","doc":"","ref":"Evision.XImgProc.StructuredEdgeDetection.html#computeOrientation/1"},{"type":"function","title":"Evision.XImgProc.StructuredEdgeDetection.computeOrientation/2","doc":"The function computes orientation from edge image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.StructuredEdgeDetection.t()`\n- **src**: `Evision.Mat`.\n\n  edge image.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  orientation image.\n\nPython prototype (for reference only):\n```python3\ncomputeOrientation(src[, dst]) -> dst\n```","ref":"Evision.XImgProc.StructuredEdgeDetection.html#computeOrientation/2"},{"type":"function","title":"Evision.XImgProc.StructuredEdgeDetection.computeOrientation/3","doc":"The function computes orientation from edge image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.StructuredEdgeDetection.t()`\n- **src**: `Evision.Mat`.\n\n  edge image.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  orientation image.\n\nPython prototype (for reference only):\n```python3\ncomputeOrientation(src[, dst]) -> dst\n```","ref":"Evision.XImgProc.StructuredEdgeDetection.html#computeOrientation/3"},{"type":"function","title":"Evision.XImgProc.StructuredEdgeDetection.detectEdges/1","doc":"","ref":"Evision.XImgProc.StructuredEdgeDetection.html#detectEdges/1"},{"type":"function","title":"Evision.XImgProc.StructuredEdgeDetection.detectEdges/2","doc":"The function detects edges in src and draw them to dst.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.StructuredEdgeDetection.t()`\n- **src**: `Evision.Mat`.\n\n  source image (RGB, float, in [0;1]) to detect edges\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  destination image (grayscale, float, in [0;1]) where edges are drawn\n\nThe algorithm underlies this function is much more robust to texture presence, than common\napproaches, e.g. Sobel\n@sa Sobel, Canny\n\nPython prototype (for reference only):\n```python3\ndetectEdges(src[, dst]) -> dst\n```","ref":"Evision.XImgProc.StructuredEdgeDetection.html#detectEdges/2"},{"type":"function","title":"Evision.XImgProc.StructuredEdgeDetection.detectEdges/3","doc":"The function detects edges in src and draw them to dst.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.StructuredEdgeDetection.t()`\n- **src**: `Evision.Mat`.\n\n  source image (RGB, float, in [0;1]) to detect edges\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  destination image (grayscale, float, in [0;1]) where edges are drawn\n\nThe algorithm underlies this function is much more robust to texture presence, than common\napproaches, e.g. Sobel\n@sa Sobel, Canny\n\nPython prototype (for reference only):\n```python3\ndetectEdges(src[, dst]) -> dst\n```","ref":"Evision.XImgProc.StructuredEdgeDetection.html#detectEdges/3"},{"type":"function","title":"Evision.XImgProc.StructuredEdgeDetection.edgesNms/1","doc":"","ref":"Evision.XImgProc.StructuredEdgeDetection.html#edgesNms/1"},{"type":"function","title":"Evision.XImgProc.StructuredEdgeDetection.edgesNms/3","doc":"The function edgenms in edge image and suppress edges where edge is stronger in orthogonal direction.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.StructuredEdgeDetection.t()`\n- **edge_image**: `Evision.Mat`.\n\n  edge image from detectEdges function.\n\n- **orientation_image**: `Evision.Mat`.\n\n  orientation image from computeOrientation function.\n\n##### Keyword Arguments\n- **r**: `integer()`.\n\n  radius for NMS suppression.\n\n- **s**: `integer()`.\n\n  radius for boundary suppression.\n\n- **m**: `float`.\n\n  multiplier for conservative suppression.\n\n- **isParallel**: `bool`.\n\n  enables/disables parallel computing.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  suppressed image (grayscale, float, in [0;1])\n\nPython prototype (for reference only):\n```python3\nedgesNms(edge_image, orientation_image[, dst[, r[, s[, m[, isParallel]]]]]) -> dst\n```","ref":"Evision.XImgProc.StructuredEdgeDetection.html#edgesNms/3"},{"type":"function","title":"Evision.XImgProc.StructuredEdgeDetection.edgesNms/4","doc":"The function edgenms in edge image and suppress edges where edge is stronger in orthogonal direction.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.StructuredEdgeDetection.t()`\n- **edge_image**: `Evision.Mat`.\n\n  edge image from detectEdges function.\n\n- **orientation_image**: `Evision.Mat`.\n\n  orientation image from computeOrientation function.\n\n##### Keyword Arguments\n- **r**: `integer()`.\n\n  radius for NMS suppression.\n\n- **s**: `integer()`.\n\n  radius for boundary suppression.\n\n- **m**: `float`.\n\n  multiplier for conservative suppression.\n\n- **isParallel**: `bool`.\n\n  enables/disables parallel computing.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  suppressed image (grayscale, float, in [0;1])\n\nPython prototype (for reference only):\n```python3\nedgesNms(edge_image, orientation_image[, dst[, r[, s[, m[, isParallel]]]]]) -> dst\n```","ref":"Evision.XImgProc.StructuredEdgeDetection.html#edgesNms/4"},{"type":"function","title":"Evision.XImgProc.StructuredEdgeDetection.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.StructuredEdgeDetection.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XImgProc.StructuredEdgeDetection.html#empty/1"},{"type":"function","title":"Evision.XImgProc.StructuredEdgeDetection.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.StructuredEdgeDetection.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XImgProc.StructuredEdgeDetection.html#getDefaultName/1"},{"type":"function","title":"Evision.XImgProc.StructuredEdgeDetection.read/1","doc":"","ref":"Evision.XImgProc.StructuredEdgeDetection.html#read/1"},{"type":"function","title":"Evision.XImgProc.StructuredEdgeDetection.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.StructuredEdgeDetection.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XImgProc.StructuredEdgeDetection.html#read/2"},{"type":"function","title":"Evision.XImgProc.StructuredEdgeDetection.save/1","doc":"","ref":"Evision.XImgProc.StructuredEdgeDetection.html#save/1"},{"type":"function","title":"Evision.XImgProc.StructuredEdgeDetection.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.StructuredEdgeDetection.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XImgProc.StructuredEdgeDetection.html#save/2"},{"type":"function","title":"Evision.XImgProc.StructuredEdgeDetection.write/1","doc":"","ref":"Evision.XImgProc.StructuredEdgeDetection.html#write/1"},{"type":"function","title":"Evision.XImgProc.StructuredEdgeDetection.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.StructuredEdgeDetection.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XImgProc.StructuredEdgeDetection.html#write/2"},{"type":"function","title":"Evision.XImgProc.StructuredEdgeDetection.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.StructuredEdgeDetection.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XImgProc.StructuredEdgeDetection.html#write/3"},{"type":"type","title":"Evision.XImgProc.StructuredEdgeDetection.t/0","doc":"Type that represents an `XImgProc.StructuredEdgeDetection` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.StructuredEdgeDetection.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.SuperpixelLSC","doc":"","ref":"Evision.XImgProc.SuperpixelLSC.html"},{"type":"function","title":"Evision.XImgProc.SuperpixelLSC.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelLSC.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XImgProc.SuperpixelLSC.html#clear/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelLSC.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelLSC.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XImgProc.SuperpixelLSC.html#empty/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelLSC.enforceLabelConnectivity/1","doc":"Enforce label connectivity.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelLSC.t()`\n\n##### Keyword Arguments\n- **min_element_size**: `integer()`.\n\n  The minimum element size in percents that should be absorbed into a bigger\n  superpixel. Given resulted average superpixel size valid value should be in 0-100 range, 25 means\n  that less then a quarter sized superpixel should be absorbed, this is default.\n\nThe function merge component that is too small, assigning the previously found adjacent label\nto this component. Calling this function may change the final number of superpixels.\n\nPython prototype (for reference only):\n```python3\nenforceLabelConnectivity([, min_element_size]) -> None\n```","ref":"Evision.XImgProc.SuperpixelLSC.html#enforceLabelConnectivity/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelLSC.enforceLabelConnectivity/2","doc":"Enforce label connectivity.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelLSC.t()`\n\n##### Keyword Arguments\n- **min_element_size**: `integer()`.\n\n  The minimum element size in percents that should be absorbed into a bigger\n  superpixel. Given resulted average superpixel size valid value should be in 0-100 range, 25 means\n  that less then a quarter sized superpixel should be absorbed, this is default.\n\nThe function merge component that is too small, assigning the previously found adjacent label\nto this component. Calling this function may change the final number of superpixels.\n\nPython prototype (for reference only):\n```python3\nenforceLabelConnectivity([, min_element_size]) -> None\n```","ref":"Evision.XImgProc.SuperpixelLSC.html#enforceLabelConnectivity/2"},{"type":"function","title":"Evision.XImgProc.SuperpixelLSC.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelLSC.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XImgProc.SuperpixelLSC.html#getDefaultName/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelLSC.getLabelContourMask/1","doc":"Returns the mask of the superpixel segmentation stored in SuperpixelLSC object.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelLSC.t()`\n\n##### Keyword Arguments\n- **thick_line**: `bool`.\n\n  If false, the border is only one pixel wide, otherwise all pixels at the border\n  are masked.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  Return: CV_8U1 image mask where -1 indicates that the pixel is a superpixel border,\n  and 0 otherwise.\n\nThe function return the boundaries of the superpixel segmentation.\n\nPython prototype (for reference only):\n```python3\ngetLabelContourMask([, image[, thick_line]]) -> image\n```","ref":"Evision.XImgProc.SuperpixelLSC.html#getLabelContourMask/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelLSC.getLabelContourMask/2","doc":"Returns the mask of the superpixel segmentation stored in SuperpixelLSC object.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelLSC.t()`\n\n##### Keyword Arguments\n- **thick_line**: `bool`.\n\n  If false, the border is only one pixel wide, otherwise all pixels at the border\n  are masked.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  Return: CV_8U1 image mask where -1 indicates that the pixel is a superpixel border,\n  and 0 otherwise.\n\nThe function return the boundaries of the superpixel segmentation.\n\nPython prototype (for reference only):\n```python3\ngetLabelContourMask([, image[, thick_line]]) -> image\n```","ref":"Evision.XImgProc.SuperpixelLSC.html#getLabelContourMask/2"},{"type":"function","title":"Evision.XImgProc.SuperpixelLSC.getLabels/1","doc":"Returns the segmentation labeling of the image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelLSC.t()`\n\n##### Return\n- **labels_out**: `Evision.Mat.t()`.\n\n  Return: A CV_32SC1 integer array containing the labels of the superpixel\n  segmentation. The labels are in the range [0, getNumberOfSuperpixels()].\n\nEach label represents a superpixel, and each pixel is assigned to one superpixel label.\n\nThe function returns an image with the labels of the superpixel segmentation. The labels are in\nthe range [0, getNumberOfSuperpixels()].\n\nPython prototype (for reference only):\n```python3\ngetLabels([, labels_out]) -> labels_out\n```","ref":"Evision.XImgProc.SuperpixelLSC.html#getLabels/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelLSC.getLabels/2","doc":"Returns the segmentation labeling of the image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelLSC.t()`\n\n##### Return\n- **labels_out**: `Evision.Mat.t()`.\n\n  Return: A CV_32SC1 integer array containing the labels of the superpixel\n  segmentation. The labels are in the range [0, getNumberOfSuperpixels()].\n\nEach label represents a superpixel, and each pixel is assigned to one superpixel label.\n\nThe function returns an image with the labels of the superpixel segmentation. The labels are in\nthe range [0, getNumberOfSuperpixels()].\n\nPython prototype (for reference only):\n```python3\ngetLabels([, labels_out]) -> labels_out\n```","ref":"Evision.XImgProc.SuperpixelLSC.html#getLabels/2"},{"type":"function","title":"Evision.XImgProc.SuperpixelLSC.getNumberOfSuperpixels/1","doc":"Calculates the actual amount of superpixels on a given segmentation computed\nand stored in SuperpixelLSC object.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelLSC.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNumberOfSuperpixels() -> retval\n```","ref":"Evision.XImgProc.SuperpixelLSC.html#getNumberOfSuperpixels/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelLSC.iterate/1","doc":"Calculates the superpixel segmentation on a given image with the initialized\nparameters in the SuperpixelLSC object.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelLSC.t()`\n\n##### Keyword Arguments\n- **num_iterations**: `integer()`.\n\n  Number of iterations. Higher number improves the result.\n\nThis function can be called again without the need of initializing the algorithm with\ncreateSuperpixelLSC(). This save the computational cost of allocating memory for all the\nstructures of the algorithm.\n\nThe function computes the superpixels segmentation of an image with the parameters initialized\nwith the function createSuperpixelLSC(). The algorithms starts from a grid of superpixels and\nthen refines the boundaries by proposing updates of edges boundaries.\n\nPython prototype (for reference only):\n```python3\niterate([, num_iterations]) -> None\n```","ref":"Evision.XImgProc.SuperpixelLSC.html#iterate/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelLSC.iterate/2","doc":"Calculates the superpixel segmentation on a given image with the initialized\nparameters in the SuperpixelLSC object.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelLSC.t()`\n\n##### Keyword Arguments\n- **num_iterations**: `integer()`.\n\n  Number of iterations. Higher number improves the result.\n\nThis function can be called again without the need of initializing the algorithm with\ncreateSuperpixelLSC(). This save the computational cost of allocating memory for all the\nstructures of the algorithm.\n\nThe function computes the superpixels segmentation of an image with the parameters initialized\nwith the function createSuperpixelLSC(). The algorithms starts from a grid of superpixels and\nthen refines the boundaries by proposing updates of edges boundaries.\n\nPython prototype (for reference only):\n```python3\niterate([, num_iterations]) -> None\n```","ref":"Evision.XImgProc.SuperpixelLSC.html#iterate/2"},{"type":"function","title":"Evision.XImgProc.SuperpixelLSC.read/1","doc":"","ref":"Evision.XImgProc.SuperpixelLSC.html#read/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelLSC.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelLSC.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XImgProc.SuperpixelLSC.html#read/2"},{"type":"function","title":"Evision.XImgProc.SuperpixelLSC.save/1","doc":"","ref":"Evision.XImgProc.SuperpixelLSC.html#save/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelLSC.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelLSC.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XImgProc.SuperpixelLSC.html#save/2"},{"type":"function","title":"Evision.XImgProc.SuperpixelLSC.write/1","doc":"","ref":"Evision.XImgProc.SuperpixelLSC.html#write/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelLSC.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelLSC.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XImgProc.SuperpixelLSC.html#write/2"},{"type":"function","title":"Evision.XImgProc.SuperpixelLSC.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelLSC.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XImgProc.SuperpixelLSC.html#write/3"},{"type":"type","title":"Evision.XImgProc.SuperpixelLSC.t/0","doc":"Type that represents an `XImgProc.SuperpixelLSC` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.SuperpixelLSC.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.SuperpixelSEEDS","doc":"","ref":"Evision.XImgProc.SuperpixelSEEDS.html"},{"type":"function","title":"Evision.XImgProc.SuperpixelSEEDS.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSEEDS.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XImgProc.SuperpixelSEEDS.html#clear/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelSEEDS.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSEEDS.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XImgProc.SuperpixelSEEDS.html#empty/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelSEEDS.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSEEDS.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XImgProc.SuperpixelSEEDS.html#getDefaultName/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelSEEDS.getLabelContourMask/1","doc":"Returns the mask of the superpixel segmentation stored in SuperpixelSEEDS object.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSEEDS.t()`\n\n##### Keyword Arguments\n- **thick_line**: `bool`.\n\n  If false, the border is only one pixel wide, otherwise all pixels at the border\n  are masked.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  Return: CV_8UC1 image mask where -1 indicates that the pixel is a superpixel border,\n  and 0 otherwise.\n\nThe function return the boundaries of the superpixel segmentation.\n**Note**: \n- (Python) A demo on how to generate superpixels in images from the webcam can be found at\n  opencv_source_code/samples/python2/seeds.py\n\n- (cpp) A demo on how to generate superpixels in images from the webcam can be found at\n  opencv_source_code/modules/ximgproc/samples/seeds.cpp. By adding a file image as a command\n  line argument, the static image will be used instead of the webcam.\n\n- It will show a window with the video from the webcam with the superpixel boundaries marked\n  in red (see below). Use Space to switch between different output modes. At the top of the\n  window there are 4 sliders, from which the user can change on-the-fly the number of\n  superpixels, the number of block levels, the strength of the boundary prior term to modify\n  the shape, and the number of iterations at pixel level. This is useful to play with the\n  parameters and set them to the user convenience. In the console the frame-rate of the\n  algorithm is indicated.\n\n![image](pics/superpixels_demo.png)\n\nPython prototype (for reference only):\n```python3\ngetLabelContourMask([, image[, thick_line]]) -> image\n```","ref":"Evision.XImgProc.SuperpixelSEEDS.html#getLabelContourMask/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelSEEDS.getLabelContourMask/2","doc":"Returns the mask of the superpixel segmentation stored in SuperpixelSEEDS object.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSEEDS.t()`\n\n##### Keyword Arguments\n- **thick_line**: `bool`.\n\n  If false, the border is only one pixel wide, otherwise all pixels at the border\n  are masked.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  Return: CV_8UC1 image mask where -1 indicates that the pixel is a superpixel border,\n  and 0 otherwise.\n\nThe function return the boundaries of the superpixel segmentation.\n**Note**: \n- (Python) A demo on how to generate superpixels in images from the webcam can be found at\n  opencv_source_code/samples/python2/seeds.py\n\n- (cpp) A demo on how to generate superpixels in images from the webcam can be found at\n  opencv_source_code/modules/ximgproc/samples/seeds.cpp. By adding a file image as a command\n  line argument, the static image will be used instead of the webcam.\n\n- It will show a window with the video from the webcam with the superpixel boundaries marked\n  in red (see below). Use Space to switch between different output modes. At the top of the\n  window there are 4 sliders, from which the user can change on-the-fly the number of\n  superpixels, the number of block levels, the strength of the boundary prior term to modify\n  the shape, and the number of iterations at pixel level. This is useful to play with the\n  parameters and set them to the user convenience. In the console the frame-rate of the\n  algorithm is indicated.\n\n![image](pics/superpixels_demo.png)\n\nPython prototype (for reference only):\n```python3\ngetLabelContourMask([, image[, thick_line]]) -> image\n```","ref":"Evision.XImgProc.SuperpixelSEEDS.html#getLabelContourMask/2"},{"type":"function","title":"Evision.XImgProc.SuperpixelSEEDS.getLabels/1","doc":"Returns the segmentation labeling of the image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSEEDS.t()`\n\n##### Return\n- **labels_out**: `Evision.Mat.t()`.\n\n  Return: A CV_32UC1 integer array containing the labels of the superpixel\n  segmentation. The labels are in the range [0, getNumberOfSuperpixels()].\n\nEach label represents a superpixel, and each pixel is assigned to one superpixel label.\n\nThe function returns an image with ssthe labels of the superpixel segmentation. The labels are in\nthe range [0, getNumberOfSuperpixels()].\n\nPython prototype (for reference only):\n```python3\ngetLabels([, labels_out]) -> labels_out\n```","ref":"Evision.XImgProc.SuperpixelSEEDS.html#getLabels/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelSEEDS.getLabels/2","doc":"Returns the segmentation labeling of the image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSEEDS.t()`\n\n##### Return\n- **labels_out**: `Evision.Mat.t()`.\n\n  Return: A CV_32UC1 integer array containing the labels of the superpixel\n  segmentation. The labels are in the range [0, getNumberOfSuperpixels()].\n\nEach label represents a superpixel, and each pixel is assigned to one superpixel label.\n\nThe function returns an image with ssthe labels of the superpixel segmentation. The labels are in\nthe range [0, getNumberOfSuperpixels()].\n\nPython prototype (for reference only):\n```python3\ngetLabels([, labels_out]) -> labels_out\n```","ref":"Evision.XImgProc.SuperpixelSEEDS.html#getLabels/2"},{"type":"function","title":"Evision.XImgProc.SuperpixelSEEDS.getNumberOfSuperpixels/1","doc":"Calculates the superpixel segmentation on a given image stored in SuperpixelSEEDS object.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSEEDS.t()`\n\n##### Return\n- **retval**: `integer()`\n\nThe function computes the superpixels segmentation of an image with the parameters initialized\nwith the function createSuperpixelSEEDS().\n\nPython prototype (for reference only):\n```python3\ngetNumberOfSuperpixels() -> retval\n```","ref":"Evision.XImgProc.SuperpixelSEEDS.html#getNumberOfSuperpixels/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelSEEDS.iterate/1","doc":"","ref":"Evision.XImgProc.SuperpixelSEEDS.html#iterate/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelSEEDS.iterate/2","doc":"Calculates the superpixel segmentation on a given image with the initialized\nparameters in the SuperpixelSEEDS object.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSEEDS.t()`\n- **img**: `Evision.Mat`.\n\n  Input image. Supported formats: CV_8U, CV_16U, CV_32F. Image size & number of\n  channels must match with the initialized image size & channels with the function\n  createSuperpixelSEEDS(). It should be in HSV or Lab color space. Lab is a bit better, but also\n  slower.\n\n##### Keyword Arguments\n- **num_iterations**: `integer()`.\n\n  Number of pixel level iterations. Higher number improves the result.\n\nThis function can be called again for other images without the need of initializing the\nalgorithm with createSuperpixelSEEDS(). This save the computational cost of allocating memory\nfor all the structures of the algorithm.\n\nThe function computes the superpixels segmentation of an image with the parameters initialized\nwith the function createSuperpixelSEEDS(). The algorithms starts from a grid of superpixels and\nthen refines the boundaries by proposing updates of blocks of pixels that lie at the boundaries\nfrom large to smaller size, finalizing with proposing pixel updates. An illustrative example\ncan be seen below.\n![image](pics/superpixels_blocks2.png)\n\nPython prototype (for reference only):\n```python3\niterate(img[, num_iterations]) -> None\n```","ref":"Evision.XImgProc.SuperpixelSEEDS.html#iterate/2"},{"type":"function","title":"Evision.XImgProc.SuperpixelSEEDS.iterate/3","doc":"Calculates the superpixel segmentation on a given image with the initialized\nparameters in the SuperpixelSEEDS object.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSEEDS.t()`\n- **img**: `Evision.Mat`.\n\n  Input image. Supported formats: CV_8U, CV_16U, CV_32F. Image size & number of\n  channels must match with the initialized image size & channels with the function\n  createSuperpixelSEEDS(). It should be in HSV or Lab color space. Lab is a bit better, but also\n  slower.\n\n##### Keyword Arguments\n- **num_iterations**: `integer()`.\n\n  Number of pixel level iterations. Higher number improves the result.\n\nThis function can be called again for other images without the need of initializing the\nalgorithm with createSuperpixelSEEDS(). This save the computational cost of allocating memory\nfor all the structures of the algorithm.\n\nThe function computes the superpixels segmentation of an image with the parameters initialized\nwith the function createSuperpixelSEEDS(). The algorithms starts from a grid of superpixels and\nthen refines the boundaries by proposing updates of blocks of pixels that lie at the boundaries\nfrom large to smaller size, finalizing with proposing pixel updates. An illustrative example\ncan be seen below.\n![image](pics/superpixels_blocks2.png)\n\nPython prototype (for reference only):\n```python3\niterate(img[, num_iterations]) -> None\n```","ref":"Evision.XImgProc.SuperpixelSEEDS.html#iterate/3"},{"type":"function","title":"Evision.XImgProc.SuperpixelSEEDS.read/1","doc":"","ref":"Evision.XImgProc.SuperpixelSEEDS.html#read/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelSEEDS.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSEEDS.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XImgProc.SuperpixelSEEDS.html#read/2"},{"type":"function","title":"Evision.XImgProc.SuperpixelSEEDS.save/1","doc":"","ref":"Evision.XImgProc.SuperpixelSEEDS.html#save/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelSEEDS.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSEEDS.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XImgProc.SuperpixelSEEDS.html#save/2"},{"type":"function","title":"Evision.XImgProc.SuperpixelSEEDS.write/1","doc":"","ref":"Evision.XImgProc.SuperpixelSEEDS.html#write/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelSEEDS.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSEEDS.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XImgProc.SuperpixelSEEDS.html#write/2"},{"type":"function","title":"Evision.XImgProc.SuperpixelSEEDS.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSEEDS.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XImgProc.SuperpixelSEEDS.html#write/3"},{"type":"type","title":"Evision.XImgProc.SuperpixelSEEDS.t/0","doc":"Type that represents an `XImgProc.SuperpixelSEEDS` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.SuperpixelSEEDS.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.SuperpixelSLIC","doc":"","ref":"Evision.XImgProc.SuperpixelSLIC.html"},{"type":"function","title":"Evision.XImgProc.SuperpixelSLIC.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSLIC.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XImgProc.SuperpixelSLIC.html#clear/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelSLIC.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSLIC.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XImgProc.SuperpixelSLIC.html#empty/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelSLIC.enforceLabelConnectivity/1","doc":"Enforce label connectivity.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSLIC.t()`\n\n##### Keyword Arguments\n- **min_element_size**: `integer()`.\n\n  The minimum element size in percents that should be absorbed into a bigger\n  superpixel. Given resulted average superpixel size valid value should be in 0-100 range, 25 means\n  that less then a quarter sized superpixel should be absorbed, this is default.\n\nThe function merge component that is too small, assigning the previously found adjacent label\nto this component. Calling this function may change the final number of superpixels.\n\nPython prototype (for reference only):\n```python3\nenforceLabelConnectivity([, min_element_size]) -> None\n```","ref":"Evision.XImgProc.SuperpixelSLIC.html#enforceLabelConnectivity/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelSLIC.enforceLabelConnectivity/2","doc":"Enforce label connectivity.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSLIC.t()`\n\n##### Keyword Arguments\n- **min_element_size**: `integer()`.\n\n  The minimum element size in percents that should be absorbed into a bigger\n  superpixel. Given resulted average superpixel size valid value should be in 0-100 range, 25 means\n  that less then a quarter sized superpixel should be absorbed, this is default.\n\nThe function merge component that is too small, assigning the previously found adjacent label\nto this component. Calling this function may change the final number of superpixels.\n\nPython prototype (for reference only):\n```python3\nenforceLabelConnectivity([, min_element_size]) -> None\n```","ref":"Evision.XImgProc.SuperpixelSLIC.html#enforceLabelConnectivity/2"},{"type":"function","title":"Evision.XImgProc.SuperpixelSLIC.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSLIC.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XImgProc.SuperpixelSLIC.html#getDefaultName/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelSLIC.getLabelContourMask/1","doc":"Returns the mask of the superpixel segmentation stored in SuperpixelSLIC object.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSLIC.t()`\n\n##### Keyword Arguments\n- **thick_line**: `bool`.\n\n  If false, the border is only one pixel wide, otherwise all pixels at the border\n  are masked.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  Return: CV_8U1 image mask where -1 indicates that the pixel is a superpixel border,\n  and 0 otherwise.\n\nThe function return the boundaries of the superpixel segmentation.\n\nPython prototype (for reference only):\n```python3\ngetLabelContourMask([, image[, thick_line]]) -> image\n```","ref":"Evision.XImgProc.SuperpixelSLIC.html#getLabelContourMask/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelSLIC.getLabelContourMask/2","doc":"Returns the mask of the superpixel segmentation stored in SuperpixelSLIC object.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSLIC.t()`\n\n##### Keyword Arguments\n- **thick_line**: `bool`.\n\n  If false, the border is only one pixel wide, otherwise all pixels at the border\n  are masked.\n\n##### Return\n- **image**: `Evision.Mat.t()`.\n\n  Return: CV_8U1 image mask where -1 indicates that the pixel is a superpixel border,\n  and 0 otherwise.\n\nThe function return the boundaries of the superpixel segmentation.\n\nPython prototype (for reference only):\n```python3\ngetLabelContourMask([, image[, thick_line]]) -> image\n```","ref":"Evision.XImgProc.SuperpixelSLIC.html#getLabelContourMask/2"},{"type":"function","title":"Evision.XImgProc.SuperpixelSLIC.getLabels/1","doc":"Returns the segmentation labeling of the image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSLIC.t()`\n\n##### Return\n- **labels_out**: `Evision.Mat.t()`.\n\n  Return: A CV_32SC1 integer array containing the labels of the superpixel\n  segmentation. The labels are in the range [0, getNumberOfSuperpixels()].\n\nEach label represents a superpixel, and each pixel is assigned to one superpixel label.\n\nThe function returns an image with the labels of the superpixel segmentation. The labels are in\nthe range [0, getNumberOfSuperpixels()].\n\nPython prototype (for reference only):\n```python3\ngetLabels([, labels_out]) -> labels_out\n```","ref":"Evision.XImgProc.SuperpixelSLIC.html#getLabels/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelSLIC.getLabels/2","doc":"Returns the segmentation labeling of the image.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSLIC.t()`\n\n##### Return\n- **labels_out**: `Evision.Mat.t()`.\n\n  Return: A CV_32SC1 integer array containing the labels of the superpixel\n  segmentation. The labels are in the range [0, getNumberOfSuperpixels()].\n\nEach label represents a superpixel, and each pixel is assigned to one superpixel label.\n\nThe function returns an image with the labels of the superpixel segmentation. The labels are in\nthe range [0, getNumberOfSuperpixels()].\n\nPython prototype (for reference only):\n```python3\ngetLabels([, labels_out]) -> labels_out\n```","ref":"Evision.XImgProc.SuperpixelSLIC.html#getLabels/2"},{"type":"function","title":"Evision.XImgProc.SuperpixelSLIC.getNumberOfSuperpixels/1","doc":"Calculates the actual amount of superpixels on a given segmentation computed\nand stored in SuperpixelSLIC object.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSLIC.t()`\n\n##### Return\n- **retval**: `integer()`\n\nPython prototype (for reference only):\n```python3\ngetNumberOfSuperpixels() -> retval\n```","ref":"Evision.XImgProc.SuperpixelSLIC.html#getNumberOfSuperpixels/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelSLIC.iterate/1","doc":"Calculates the superpixel segmentation on a given image with the initialized\nparameters in the SuperpixelSLIC object.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSLIC.t()`\n\n##### Keyword Arguments\n- **num_iterations**: `integer()`.\n\n  Number of iterations. Higher number improves the result.\n\nThis function can be called again without the need of initializing the algorithm with\ncreateSuperpixelSLIC(). This save the computational cost of allocating memory for all the\nstructures of the algorithm.\n\nThe function computes the superpixels segmentation of an image with the parameters initialized\nwith the function createSuperpixelSLIC(). The algorithms starts from a grid of superpixels and\nthen refines the boundaries by proposing updates of edges boundaries.\n\nPython prototype (for reference only):\n```python3\niterate([, num_iterations]) -> None\n```","ref":"Evision.XImgProc.SuperpixelSLIC.html#iterate/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelSLIC.iterate/2","doc":"Calculates the superpixel segmentation on a given image with the initialized\nparameters in the SuperpixelSLIC object.\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSLIC.t()`\n\n##### Keyword Arguments\n- **num_iterations**: `integer()`.\n\n  Number of iterations. Higher number improves the result.\n\nThis function can be called again without the need of initializing the algorithm with\ncreateSuperpixelSLIC(). This save the computational cost of allocating memory for all the\nstructures of the algorithm.\n\nThe function computes the superpixels segmentation of an image with the parameters initialized\nwith the function createSuperpixelSLIC(). The algorithms starts from a grid of superpixels and\nthen refines the boundaries by proposing updates of edges boundaries.\n\nPython prototype (for reference only):\n```python3\niterate([, num_iterations]) -> None\n```","ref":"Evision.XImgProc.SuperpixelSLIC.html#iterate/2"},{"type":"function","title":"Evision.XImgProc.SuperpixelSLIC.read/1","doc":"","ref":"Evision.XImgProc.SuperpixelSLIC.html#read/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelSLIC.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSLIC.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XImgProc.SuperpixelSLIC.html#read/2"},{"type":"function","title":"Evision.XImgProc.SuperpixelSLIC.save/1","doc":"","ref":"Evision.XImgProc.SuperpixelSLIC.html#save/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelSLIC.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSLIC.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XImgProc.SuperpixelSLIC.html#save/2"},{"type":"function","title":"Evision.XImgProc.SuperpixelSLIC.write/1","doc":"","ref":"Evision.XImgProc.SuperpixelSLIC.html#write/1"},{"type":"function","title":"Evision.XImgProc.SuperpixelSLIC.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSLIC.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XImgProc.SuperpixelSLIC.html#write/2"},{"type":"function","title":"Evision.XImgProc.SuperpixelSLIC.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XImgProc.SuperpixelSLIC.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XImgProc.SuperpixelSLIC.html#write/3"},{"type":"type","title":"Evision.XImgProc.SuperpixelSLIC.t/0","doc":"Type that represents an `XImgProc.SuperpixelSLIC` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XImgProc.SuperpixelSLIC.html#t:t/0"},{"type":"module","title":"Evision.XImgProc.ThinningTypes","doc":"","ref":"Evision.XImgProc.ThinningTypes.html"},{"type":"function","title":"Evision.XImgProc.ThinningTypes.cv_THINNING_GUOHALL/0","doc":"","ref":"Evision.XImgProc.ThinningTypes.html#cv_THINNING_GUOHALL/0"},{"type":"function","title":"Evision.XImgProc.ThinningTypes.cv_THINNING_ZHANGSUEN/0","doc":"","ref":"Evision.XImgProc.ThinningTypes.html#cv_THINNING_ZHANGSUEN/0"},{"type":"type","title":"Evision.XImgProc.ThinningTypes.enum/0","doc":"","ref":"Evision.XImgProc.ThinningTypes.html#t:enum/0"},{"type":"module","title":"Evision.XImgProc.WMFWeightType","doc":"","ref":"Evision.XImgProc.WMFWeightType.html"},{"type":"function","title":"Evision.XImgProc.WMFWeightType.cv_WMF_COS/0","doc":"","ref":"Evision.XImgProc.WMFWeightType.html#cv_WMF_COS/0"},{"type":"function","title":"Evision.XImgProc.WMFWeightType.cv_WMF_EXP/0","doc":"","ref":"Evision.XImgProc.WMFWeightType.html#cv_WMF_EXP/0"},{"type":"function","title":"Evision.XImgProc.WMFWeightType.cv_WMF_IV1/0","doc":"","ref":"Evision.XImgProc.WMFWeightType.html#cv_WMF_IV1/0"},{"type":"function","title":"Evision.XImgProc.WMFWeightType.cv_WMF_IV2/0","doc":"","ref":"Evision.XImgProc.WMFWeightType.html#cv_WMF_IV2/0"},{"type":"function","title":"Evision.XImgProc.WMFWeightType.cv_WMF_JAC/0","doc":"","ref":"Evision.XImgProc.WMFWeightType.html#cv_WMF_JAC/0"},{"type":"function","title":"Evision.XImgProc.WMFWeightType.cv_WMF_OFF/0","doc":"","ref":"Evision.XImgProc.WMFWeightType.html#cv_WMF_OFF/0"},{"type":"type","title":"Evision.XImgProc.WMFWeightType.enum/0","doc":"","ref":"Evision.XImgProc.WMFWeightType.html#t:enum/0"},{"type":"module","title":"Evision.XPhoto","doc":"","ref":"Evision.XPhoto.html"},{"type":"function","title":"Evision.XPhoto.applyChannelGains/1","doc":"","ref":"Evision.XPhoto.html#applyChannelGains/1"},{"type":"function","title":"Evision.XPhoto.applyChannelGains/4","doc":"Implements an efficient fixed-point approximation for applying channel gains, which is\nthe last step of multiple white balance algorithms.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input three-channel image in the BGR color space (either CV_8UC3 or CV_16UC3)\n\n- **gainB**: `float`.\n\n  gain for the B channel\n\n- **gainG**: `float`.\n\n  gain for the G channel\n\n- **gainR**: `float`.\n\n  gain for the R channel\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image of the same size and type as src.\n\nPython prototype (for reference only):\n```python3\napplyChannelGains(src, gainB, gainG, gainR[, dst]) -> dst\n```","ref":"Evision.XPhoto.html#applyChannelGains/4"},{"type":"function","title":"Evision.XPhoto.applyChannelGains/5","doc":"Implements an efficient fixed-point approximation for applying channel gains, which is\nthe last step of multiple white balance algorithms.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input three-channel image in the BGR color space (either CV_8UC3 or CV_16UC3)\n\n- **gainB**: `float`.\n\n  gain for the B channel\n\n- **gainG**: `float`.\n\n  gain for the G channel\n\n- **gainR**: `float`.\n\n  gain for the R channel\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image of the same size and type as src.\n\nPython prototype (for reference only):\n```python3\napplyChannelGains(src, gainB, gainG, gainR[, dst]) -> dst\n```","ref":"Evision.XPhoto.html#applyChannelGains/5"},{"type":"function","title":"Evision.XPhoto.bm3dDenoising/1","doc":"Performs image denoising using the Block-Matching and 3D-filtering algorithm\n  with several computational\noptimizations. Noise expected to be a gaussian white noise.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit or 16-bit 1-channel image.\n\n##### Keyword Arguments\n- **h**: `float`.\n\n  Parameter regulating filter strength. Big h value perfectly removes noise but also\n  removes image details, smaller h value preserves details but also preserves some noise.\n\n- **templateWindowSize**: `integer()`.\n\n  Size in pixels of the template patch that is used for block-matching.\n  Should be power of 2.\n\n- **searchWindowSize**: `integer()`.\n\n  Size in pixels of the window that is used to perform block-matching.\n  Affect performance linearly: greater searchWindowsSize - greater denoising time.\n  Must be larger than templateWindowSize.\n\n- **blockMatchingStep1**: `integer()`.\n\n  Block matching threshold for the first step of BM3D (hard thresholding),\n  i.e. maximum distance for which two blocks are considered similar.\n  Value expressed in euclidean distance.\n\n- **blockMatchingStep2**: `integer()`.\n\n  Block matching threshold for the second step of BM3D (Wiener filtering),\n  i.e. maximum distance for which two blocks are considered similar.\n  Value expressed in euclidean distance.\n\n- **groupSize**: `integer()`.\n\n  Maximum size of the 3D group for collaborative filtering.\n\n- **slidingStep**: `integer()`.\n\n  Sliding step to process every next reference block.\n\n- **beta**: `float`.\n\n  Kaiser window parameter that affects the sidelobe attenuation of the transform of the\n  window. Kaiser window is used in order to reduce border effects. To prevent usage of the window,\n  set beta to zero.\n\n- **normType**: `integer()`.\n\n  Norm used to calculate distance between blocks. L2 is slower than L1\n  but yields more accurate results.\n\n- **step**: `integer()`.\n\n  Step of BM3D to be executed. Allowed are only BM3D_STEP1 and BM3D_STEPALL.\n  BM3D_STEP2 is not allowed as it requires basic estimate to be present.\n\n- **transformType**: `integer()`.\n\n  Type of the orthogonal transform used in collaborative filtering step.\n  Currently only Haar transform is supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as src.\n\nThis function expected to be applied to grayscale images. Advanced usage of this function\ncan be manual denoising of colored image in different colorspaces.\n@sa\nfastNlMeansDenoising\n\nPython prototype (for reference only):\n```python3\nbm3dDenoising(src[, dst[, h[, templateWindowSize[, searchWindowSize[, blockMatchingStep1[, blockMatchingStep2[, groupSize[, slidingStep[, beta[, normType[, step[, transformType]]]]]]]]]]]]) -> dst\n```","ref":"Evision.XPhoto.html#bm3dDenoising/1"},{"type":"function","title":"Evision.XPhoto.bm3dDenoising/2","doc":"#### Variant 1:\nPerforms image denoising using the Block-Matching and 3D-filtering algorithm\n  with several computational\noptimizations. Noise expected to be a gaussian white noise.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit or 16-bit 1-channel image.\n\n##### Keyword Arguments\n- **h**: `float`.\n\n  Parameter regulating filter strength. Big h value perfectly removes noise but also\n  removes image details, smaller h value preserves details but also preserves some noise.\n\n- **templateWindowSize**: `integer()`.\n\n  Size in pixels of the template patch that is used for block-matching.\n  Should be power of 2.\n\n- **searchWindowSize**: `integer()`.\n\n  Size in pixels of the window that is used to perform block-matching.\n  Affect performance linearly: greater searchWindowsSize - greater denoising time.\n  Must be larger than templateWindowSize.\n\n- **blockMatchingStep1**: `integer()`.\n\n  Block matching threshold for the first step of BM3D (hard thresholding),\n  i.e. maximum distance for which two blocks are considered similar.\n  Value expressed in euclidean distance.\n\n- **blockMatchingStep2**: `integer()`.\n\n  Block matching threshold for the second step of BM3D (Wiener filtering),\n  i.e. maximum distance for which two blocks are considered similar.\n  Value expressed in euclidean distance.\n\n- **groupSize**: `integer()`.\n\n  Maximum size of the 3D group for collaborative filtering.\n\n- **slidingStep**: `integer()`.\n\n  Sliding step to process every next reference block.\n\n- **beta**: `float`.\n\n  Kaiser window parameter that affects the sidelobe attenuation of the transform of the\n  window. Kaiser window is used in order to reduce border effects. To prevent usage of the window,\n  set beta to zero.\n\n- **normType**: `integer()`.\n\n  Norm used to calculate distance between blocks. L2 is slower than L1\n  but yields more accurate results.\n\n- **step**: `integer()`.\n\n  Step of BM3D to be executed. Possible variants are: step 1, step 2, both steps.\n\n- **transformType**: `integer()`.\n\n  Type of the orthogonal transform used in collaborative filtering step.\n  Currently only Haar transform is supported.\n\n##### Return\n- **dstStep1**: `Evision.Mat.t()`.\n\n  Output image of the first step of BM3D with the same size and type as src.\n\n- **dstStep2**: `Evision.Mat.t()`.\n\n  Output image of the second step of BM3D with the same size and type as src.\n\nThis function expected to be applied to grayscale images. Advanced usage of this function\ncan be manual denoising of colored image in different colorspaces.\n@sa\nfastNlMeansDenoising\n\nPython prototype (for reference only):\n```python3\nbm3dDenoising(src, dstStep1[, dstStep2[, h[, templateWindowSize[, searchWindowSize[, blockMatchingStep1[, blockMatchingStep2[, groupSize[, slidingStep[, beta[, normType[, step[, transformType]]]]]]]]]]]]) -> dstStep1, dstStep2\n```\n#### Variant 2:\nPerforms image denoising using the Block-Matching and 3D-filtering algorithm\n  with several computational\noptimizations. Noise expected to be a gaussian white noise.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit or 16-bit 1-channel image.\n\n##### Keyword Arguments\n- **h**: `float`.\n\n  Parameter regulating filter strength. Big h value perfectly removes noise but also\n  removes image details, smaller h value preserves details but also preserves some noise.\n\n- **templateWindowSize**: `integer()`.\n\n  Size in pixels of the template patch that is used for block-matching.\n  Should be power of 2.\n\n- **searchWindowSize**: `integer()`.\n\n  Size in pixels of the window that is used to perform block-matching.\n  Affect performance linearly: greater searchWindowsSize - greater denoising time.\n  Must be larger than templateWindowSize.\n\n- **blockMatchingStep1**: `integer()`.\n\n  Block matching threshold for the first step of BM3D (hard thresholding),\n  i.e. maximum distance for which two blocks are considered similar.\n  Value expressed in euclidean distance.\n\n- **blockMatchingStep2**: `integer()`.\n\n  Block matching threshold for the second step of BM3D (Wiener filtering),\n  i.e. maximum distance for which two blocks are considered similar.\n  Value expressed in euclidean distance.\n\n- **groupSize**: `integer()`.\n\n  Maximum size of the 3D group for collaborative filtering.\n\n- **slidingStep**: `integer()`.\n\n  Sliding step to process every next reference block.\n\n- **beta**: `float`.\n\n  Kaiser window parameter that affects the sidelobe attenuation of the transform of the\n  window. Kaiser window is used in order to reduce border effects. To prevent usage of the window,\n  set beta to zero.\n\n- **normType**: `integer()`.\n\n  Norm used to calculate distance between blocks. L2 is slower than L1\n  but yields more accurate results.\n\n- **step**: `integer()`.\n\n  Step of BM3D to be executed. Allowed are only BM3D_STEP1 and BM3D_STEPALL.\n  BM3D_STEP2 is not allowed as it requires basic estimate to be present.\n\n- **transformType**: `integer()`.\n\n  Type of the orthogonal transform used in collaborative filtering step.\n  Currently only Haar transform is supported.\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image with the same size and type as src.\n\nThis function expected to be applied to grayscale images. Advanced usage of this function\ncan be manual denoising of colored image in different colorspaces.\n@sa\nfastNlMeansDenoising\n\nPython prototype (for reference only):\n```python3\nbm3dDenoising(src[, dst[, h[, templateWindowSize[, searchWindowSize[, blockMatchingStep1[, blockMatchingStep2[, groupSize[, slidingStep[, beta[, normType[, step[, transformType]]]]]]]]]]]]) -> dst\n```","ref":"Evision.XPhoto.html#bm3dDenoising/2"},{"type":"function","title":"Evision.XPhoto.bm3dDenoising/3","doc":"Performs image denoising using the Block-Matching and 3D-filtering algorithm\n  with several computational\noptimizations. Noise expected to be a gaussian white noise.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input 8-bit or 16-bit 1-channel image.\n\n##### Keyword Arguments\n- **h**: `float`.\n\n  Parameter regulating filter strength. Big h value perfectly removes noise but also\n  removes image details, smaller h value preserves details but also preserves some noise.\n\n- **templateWindowSize**: `integer()`.\n\n  Size in pixels of the template patch that is used for block-matching.\n  Should be power of 2.\n\n- **searchWindowSize**: `integer()`.\n\n  Size in pixels of the window that is used to perform block-matching.\n  Affect performance linearly: greater searchWindowsSize - greater denoising time.\n  Must be larger than templateWindowSize.\n\n- **blockMatchingStep1**: `integer()`.\n\n  Block matching threshold for the first step of BM3D (hard thresholding),\n  i.e. maximum distance for which two blocks are considered similar.\n  Value expressed in euclidean distance.\n\n- **blockMatchingStep2**: `integer()`.\n\n  Block matching threshold for the second step of BM3D (Wiener filtering),\n  i.e. maximum distance for which two blocks are considered similar.\n  Value expressed in euclidean distance.\n\n- **groupSize**: `integer()`.\n\n  Maximum size of the 3D group for collaborative filtering.\n\n- **slidingStep**: `integer()`.\n\n  Sliding step to process every next reference block.\n\n- **beta**: `float`.\n\n  Kaiser window parameter that affects the sidelobe attenuation of the transform of the\n  window. Kaiser window is used in order to reduce border effects. To prevent usage of the window,\n  set beta to zero.\n\n- **normType**: `integer()`.\n\n  Norm used to calculate distance between blocks. L2 is slower than L1\n  but yields more accurate results.\n\n- **step**: `integer()`.\n\n  Step of BM3D to be executed. Possible variants are: step 1, step 2, both steps.\n\n- **transformType**: `integer()`.\n\n  Type of the orthogonal transform used in collaborative filtering step.\n  Currently only Haar transform is supported.\n\n##### Return\n- **dstStep1**: `Evision.Mat.t()`.\n\n  Output image of the first step of BM3D with the same size and type as src.\n\n- **dstStep2**: `Evision.Mat.t()`.\n\n  Output image of the second step of BM3D with the same size and type as src.\n\nThis function expected to be applied to grayscale images. Advanced usage of this function\ncan be manual denoising of colored image in different colorspaces.\n@sa\nfastNlMeansDenoising\n\nPython prototype (for reference only):\n```python3\nbm3dDenoising(src, dstStep1[, dstStep2[, h[, templateWindowSize[, searchWindowSize[, blockMatchingStep1[, blockMatchingStep2[, groupSize[, slidingStep[, beta[, normType[, step[, transformType]]]]]]]]]]]]) -> dstStep1, dstStep2\n```","ref":"Evision.XPhoto.html#bm3dDenoising/3"},{"type":"function","title":"Evision.XPhoto.createGrayworldWB/0","doc":"Creates an instance of GrayworldWB\n##### Return\n- **retval**: `Evision.XPhoto.GrayworldWB.t()`\n\nPython prototype (for reference only):\n```python3\ncreateGrayworldWB() -> retval\n```","ref":"Evision.XPhoto.html#createGrayworldWB/0"},{"type":"function","title":"Evision.XPhoto.createGrayworldWB/1","doc":"","ref":"Evision.XPhoto.html#createGrayworldWB/1"},{"type":"function","title":"Evision.XPhoto.createLearningBasedWB/0","doc":"Creates an instance of LearningBasedWB\n##### Keyword Arguments\n- **path_to_model**: `String`.\n\n  Path to a .yml file with the model. If not specified, the default model is used\n\n##### Return\n- **retval**: `Evision.XPhoto.LearningBasedWB.t()`\n\nPython prototype (for reference only):\n```python3\ncreateLearningBasedWB([, path_to_model]) -> retval\n```","ref":"Evision.XPhoto.html#createLearningBasedWB/0"},{"type":"function","title":"Evision.XPhoto.createLearningBasedWB/1","doc":"Creates an instance of LearningBasedWB\n##### Keyword Arguments\n- **path_to_model**: `String`.\n\n  Path to a .yml file with the model. If not specified, the default model is used\n\n##### Return\n- **retval**: `Evision.XPhoto.LearningBasedWB.t()`\n\nPython prototype (for reference only):\n```python3\ncreateLearningBasedWB([, path_to_model]) -> retval\n```","ref":"Evision.XPhoto.html#createLearningBasedWB/1"},{"type":"function","title":"Evision.XPhoto.createSimpleWB/0","doc":"Creates an instance of SimpleWB\n##### Return\n- **retval**: `Evision.XPhoto.SimpleWB.t()`\n\nPython prototype (for reference only):\n```python3\ncreateSimpleWB() -> retval\n```","ref":"Evision.XPhoto.html#createSimpleWB/0"},{"type":"function","title":"Evision.XPhoto.createSimpleWB/1","doc":"","ref":"Evision.XPhoto.html#createSimpleWB/1"},{"type":"function","title":"Evision.XPhoto.createTonemapDurand/0","doc":"Creates TonemapDurand object\n##### Keyword Arguments\n- **gamma**: `float`.\n\n  gamma value for gamma correction. See createTonemap\n\n- **contrast**: `float`.\n\n  resulting contrast on logarithmic scale, i. e. log(max / min), where max and min\n  are maximum and minimum luminance values of the resulting image.\n\n- **saturation**: `float`.\n\n  saturation enhancement value. See createTonemapDrago\n\n- **sigma_color**: `float`.\n\n  bilateral filter sigma in color space\n\n- **sigma_space**: `float`.\n\n  bilateral filter sigma in coordinate space\n\n##### Return\n- **retval**: `Evision.XPhoto.TonemapDurand.t()`\n\nYou need to set the OPENCV_ENABLE_NONFREE option in cmake to use those. Use them at your own risk.\n\nPython prototype (for reference only):\n```python3\ncreateTonemapDurand([, gamma[, contrast[, saturation[, sigma_color[, sigma_space]]]]]) -> retval\n```","ref":"Evision.XPhoto.html#createTonemapDurand/0"},{"type":"function","title":"Evision.XPhoto.createTonemapDurand/1","doc":"Creates TonemapDurand object\n##### Keyword Arguments\n- **gamma**: `float`.\n\n  gamma value for gamma correction. See createTonemap\n\n- **contrast**: `float`.\n\n  resulting contrast on logarithmic scale, i. e. log(max / min), where max and min\n  are maximum and minimum luminance values of the resulting image.\n\n- **saturation**: `float`.\n\n  saturation enhancement value. See createTonemapDrago\n\n- **sigma_color**: `float`.\n\n  bilateral filter sigma in color space\n\n- **sigma_space**: `float`.\n\n  bilateral filter sigma in coordinate space\n\n##### Return\n- **retval**: `Evision.XPhoto.TonemapDurand.t()`\n\nYou need to set the OPENCV_ENABLE_NONFREE option in cmake to use those. Use them at your own risk.\n\nPython prototype (for reference only):\n```python3\ncreateTonemapDurand([, gamma[, contrast[, saturation[, sigma_color[, sigma_space]]]]]) -> retval\n```","ref":"Evision.XPhoto.html#createTonemapDurand/1"},{"type":"function","title":"Evision.XPhoto.dctDenoising/1","doc":"","ref":"Evision.XPhoto.html#dctDenoising/1"},{"type":"function","title":"Evision.XPhoto.dctDenoising/3","doc":"The function implements simple dct-based denoising\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  source image\n\n- **dst**: `Evision.Mat`.\n\n  destination image\n\n- **sigma**: `double`.\n\n  expected noise standard deviation\n\n##### Keyword Arguments\n- **psize**: `integer()`.\n\n  size of block side where dct is computed\n\n .\n\n@sa\nfastNlMeansDenoising\n\nPython prototype (for reference only):\n```python3\ndctDenoising(src, dst, sigma[, psize]) -> None\n```","ref":"Evision.XPhoto.html#dctDenoising/3"},{"type":"function","title":"Evision.XPhoto.dctDenoising/4","doc":"The function implements simple dct-based denoising\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  source image\n\n- **dst**: `Evision.Mat`.\n\n  destination image\n\n- **sigma**: `double`.\n\n  expected noise standard deviation\n\n##### Keyword Arguments\n- **psize**: `integer()`.\n\n  size of block side where dct is computed\n\n .\n\n@sa\nfastNlMeansDenoising\n\nPython prototype (for reference only):\n```python3\ndctDenoising(src, dst, sigma[, psize]) -> None\n```","ref":"Evision.XPhoto.html#dctDenoising/4"},{"type":"function","title":"Evision.XPhoto.inpaint/1","doc":"","ref":"Evision.XPhoto.html#inpaint/1"},{"type":"function","title":"Evision.XPhoto.inpaint/4","doc":"The function implements different single-image inpainting algorithms.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  source image\n  - #INPAINT_SHIFTMAP: it could be of any type and any number of channels from 1 to 4. In case of\n    3- and 4-channels images the function expect them in CIELab colorspace or similar one, where first\n    color component shows intensity, while second and third shows colors. Nonetheless you can try any\n    colorspaces.\n  - #INPAINT_FSR_BEST or #INPAINT_FSR_FAST: 1-channel grayscale or 3-channel BGR image.\n\n- **mask**: `Evision.Mat`.\n\n  mask (#CV_8UC1), where non-zero pixels indicate valid image area, while zero pixels\n  indicate area to be inpainted\n\n- **dst**: `Evision.Mat`.\n\n  destination image\n\n- **algorithmType**: `integer()`.\n\n  see xphoto::InpaintTypes\n\nSee the original papers @cite He2012 (Shiftmap) or @cite GenserPCS2018 and @cite SeilerTIP2015 (FSR) for details.\n\nPython prototype (for reference only):\n```python3\ninpaint(src, mask, dst, algorithmType) -> None\n```","ref":"Evision.XPhoto.html#inpaint/4"},{"type":"function","title":"Evision.XPhoto.oilPainting/1","doc":"","ref":"Evision.XPhoto.html#oilPainting/1"},{"type":"function","title":"Evision.XPhoto.oilPainting/3","doc":"oilPainting\nSee the book @cite Holzmann1988 for details.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input three-channel or one channel image (either CV_8UC3 or CV_8UC1)\n\n- **size**: `integer()`.\n\n  neighbouring size is 2-size+1\n\n- **dynRatio**: `integer()`.\n\n  image is divided by dynRatio before histogram processing\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image of the same size and type as src.\n\nPython prototype (for reference only):\n```python3\noilPainting(src, size, dynRatio[, dst]) -> dst\n```","ref":"Evision.XPhoto.html#oilPainting/3"},{"type":"function","title":"Evision.XPhoto.oilPainting/4","doc":"#### Variant 1:\noilPainting\nSee the book @cite Holzmann1988 for details.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input three-channel or one channel image (either CV_8UC3 or CV_8UC1)\n\n- **size**: `integer()`.\n\n  neighbouring size is 2-size+1\n\n- **dynRatio**: `integer()`.\n\n  image is divided by dynRatio before histogram processing\n\n- **code**: `integer()`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image of the same size and type as src.\n\nPython prototype (for reference only):\n```python3\noilPainting(src, size, dynRatio, code[, dst]) -> dst\n```\n#### Variant 2:\noilPainting\nSee the book @cite Holzmann1988 for details.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input three-channel or one channel image (either CV_8UC3 or CV_8UC1)\n\n- **size**: `integer()`.\n\n  neighbouring size is 2-size+1\n\n- **dynRatio**: `integer()`.\n\n  image is divided by dynRatio before histogram processing\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image of the same size and type as src.\n\nPython prototype (for reference only):\n```python3\noilPainting(src, size, dynRatio[, dst]) -> dst\n```","ref":"Evision.XPhoto.html#oilPainting/4"},{"type":"function","title":"Evision.XPhoto.oilPainting/5","doc":"oilPainting\nSee the book @cite Holzmann1988 for details.\n\n##### Positional Arguments\n- **src**: `Evision.Mat`.\n\n  Input three-channel or one channel image (either CV_8UC3 or CV_8UC1)\n\n- **size**: `integer()`.\n\n  neighbouring size is 2-size+1\n\n- **dynRatio**: `integer()`.\n\n  image is divided by dynRatio before histogram processing\n\n- **code**: `integer()`\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  Output image of the same size and type as src.\n\nPython prototype (for reference only):\n```python3\noilPainting(src, size, dynRatio, code[, dst]) -> dst\n```","ref":"Evision.XPhoto.html#oilPainting/5"},{"type":"type","title":"Evision.XPhoto.t/0","doc":"Type that represents an `XPhoto` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XPhoto.html#t:t/0"},{"type":"module","title":"Evision.XPhoto.Bm3dSteps","doc":"","ref":"Evision.XPhoto.Bm3dSteps.html"},{"type":"function","title":"Evision.XPhoto.Bm3dSteps.cv_BM3D_STEP1/0","doc":"","ref":"Evision.XPhoto.Bm3dSteps.html#cv_BM3D_STEP1/0"},{"type":"function","title":"Evision.XPhoto.Bm3dSteps.cv_BM3D_STEP2/0","doc":"","ref":"Evision.XPhoto.Bm3dSteps.html#cv_BM3D_STEP2/0"},{"type":"function","title":"Evision.XPhoto.Bm3dSteps.cv_BM3D_STEPALL/0","doc":"","ref":"Evision.XPhoto.Bm3dSteps.html#cv_BM3D_STEPALL/0"},{"type":"type","title":"Evision.XPhoto.Bm3dSteps.enum/0","doc":"","ref":"Evision.XPhoto.Bm3dSteps.html#t:enum/0"},{"type":"module","title":"Evision.XPhoto.GrayworldWB","doc":"","ref":"Evision.XPhoto.GrayworldWB.html"},{"type":"function","title":"Evision.XPhoto.GrayworldWB.getSaturationThreshold/1","doc":"Maximum saturation for a pixel to be included in the\ngray-world assumption\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.GrayworldWB.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setSaturationThreshold/2`\n\nPython prototype (for reference only):\n```python3\ngetSaturationThreshold() -> retval\n```","ref":"Evision.XPhoto.GrayworldWB.html#getSaturationThreshold/1"},{"type":"function","title":"Evision.XPhoto.GrayworldWB.setSaturationThreshold/1","doc":"","ref":"Evision.XPhoto.GrayworldWB.html#setSaturationThreshold/1"},{"type":"function","title":"Evision.XPhoto.GrayworldWB.setSaturationThreshold/2","doc":"setSaturationThreshold\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.GrayworldWB.t()`\n- **val**: `float`\n\n@see `getSaturationThreshold/1`\n\nPython prototype (for reference only):\n```python3\nsetSaturationThreshold(val) -> None\n```","ref":"Evision.XPhoto.GrayworldWB.html#setSaturationThreshold/2"},{"type":"type","title":"Evision.XPhoto.GrayworldWB.t/0","doc":"Type that represents an `XPhoto.GrayworldWB` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XPhoto.GrayworldWB.html#t:t/0"},{"type":"module","title":"Evision.XPhoto.InpaintTypes","doc":"","ref":"Evision.XPhoto.InpaintTypes.html"},{"type":"function","title":"Evision.XPhoto.InpaintTypes.cv_INPAINT_FSR_BEST/0","doc":"","ref":"Evision.XPhoto.InpaintTypes.html#cv_INPAINT_FSR_BEST/0"},{"type":"function","title":"Evision.XPhoto.InpaintTypes.cv_INPAINT_FSR_FAST/0","doc":"","ref":"Evision.XPhoto.InpaintTypes.html#cv_INPAINT_FSR_FAST/0"},{"type":"function","title":"Evision.XPhoto.InpaintTypes.cv_INPAINT_SHIFTMAP/0","doc":"","ref":"Evision.XPhoto.InpaintTypes.html#cv_INPAINT_SHIFTMAP/0"},{"type":"type","title":"Evision.XPhoto.InpaintTypes.enum/0","doc":"","ref":"Evision.XPhoto.InpaintTypes.html#t:enum/0"},{"type":"module","title":"Evision.XPhoto.LearningBasedWB","doc":"","ref":"Evision.XPhoto.LearningBasedWB.html"},{"type":"function","title":"Evision.XPhoto.LearningBasedWB.extractSimpleFeatures/1","doc":"","ref":"Evision.XPhoto.LearningBasedWB.html#extractSimpleFeatures/1"},{"type":"function","title":"Evision.XPhoto.LearningBasedWB.extractSimpleFeatures/2","doc":"Implements the feature extraction part of the algorithm.\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.LearningBasedWB.t()`\n- **src**: `Evision.Mat`.\n\n  Input three-channel image (BGR color space is assumed).\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  An array of four (r,g) chromaticity tuples corresponding to the features listed above.\n\nIn accordance with @cite Cheng2015 , computes the following features for the input image:\n1. Chromaticity of an average (R,G,B) tuple\n2. Chromaticity of the brightest (R,G,B) tuple (while ignoring saturated pixels)\n3. Chromaticity of the dominant (R,G,B) tuple (the one that has the highest value in the RGB histogram)\n4. Mode of the chromaticity palette, that is constructed by taking 300 most common colors according to\nthe RGB histogram and projecting them on the chromaticity plane. Mode is the most high-density point\nof the palette, which is computed by a straightforward fixed-bandwidth kernel density estimator with\na Epanechnikov kernel function.\n\nPython prototype (for reference only):\n```python3\nextractSimpleFeatures(src[, dst]) -> dst\n```","ref":"Evision.XPhoto.LearningBasedWB.html#extractSimpleFeatures/2"},{"type":"function","title":"Evision.XPhoto.LearningBasedWB.extractSimpleFeatures/3","doc":"Implements the feature extraction part of the algorithm.\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.LearningBasedWB.t()`\n- **src**: `Evision.Mat`.\n\n  Input three-channel image (BGR color space is assumed).\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  An array of four (r,g) chromaticity tuples corresponding to the features listed above.\n\nIn accordance with @cite Cheng2015 , computes the following features for the input image:\n1. Chromaticity of an average (R,G,B) tuple\n2. Chromaticity of the brightest (R,G,B) tuple (while ignoring saturated pixels)\n3. Chromaticity of the dominant (R,G,B) tuple (the one that has the highest value in the RGB histogram)\n4. Mode of the chromaticity palette, that is constructed by taking 300 most common colors according to\nthe RGB histogram and projecting them on the chromaticity plane. Mode is the most high-density point\nof the palette, which is computed by a straightforward fixed-bandwidth kernel density estimator with\na Epanechnikov kernel function.\n\nPython prototype (for reference only):\n```python3\nextractSimpleFeatures(src[, dst]) -> dst\n```","ref":"Evision.XPhoto.LearningBasedWB.html#extractSimpleFeatures/3"},{"type":"function","title":"Evision.XPhoto.LearningBasedWB.getHistBinNum/1","doc":"Defines the size of one dimension of a three-dimensional RGB histogram that is used internally\nby the algorithm. It often makes sense to increase the number of bins for images with higher bit depth\n(e.g. 256 bins for a 12 bit image).\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.LearningBasedWB.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setHistBinNum/2`\n\nPython prototype (for reference only):\n```python3\ngetHistBinNum() -> retval\n```","ref":"Evision.XPhoto.LearningBasedWB.html#getHistBinNum/1"},{"type":"function","title":"Evision.XPhoto.LearningBasedWB.getRangeMaxVal/1","doc":"Maximum possible value of the input image (e.g. 255 for 8 bit images,\n4095 for 12 bit images)\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.LearningBasedWB.t()`\n\n##### Return\n- **retval**: `integer()`\n\n@see `setRangeMaxVal/2`\n\nPython prototype (for reference only):\n```python3\ngetRangeMaxVal() -> retval\n```","ref":"Evision.XPhoto.LearningBasedWB.html#getRangeMaxVal/1"},{"type":"function","title":"Evision.XPhoto.LearningBasedWB.getSaturationThreshold/1","doc":"Threshold that is used to determine saturated pixels, i.e. pixels where at least one of the\nchannels exceeds \\f$\\texttt{saturation\\_threshold}\\times\\texttt{range\\_max\\_val}\\f$ are ignored.\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.LearningBasedWB.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setSaturationThreshold/2`\n\nPython prototype (for reference only):\n```python3\ngetSaturationThreshold() -> retval\n```","ref":"Evision.XPhoto.LearningBasedWB.html#getSaturationThreshold/1"},{"type":"function","title":"Evision.XPhoto.LearningBasedWB.setHistBinNum/1","doc":"","ref":"Evision.XPhoto.LearningBasedWB.html#setHistBinNum/1"},{"type":"function","title":"Evision.XPhoto.LearningBasedWB.setHistBinNum/2","doc":"setHistBinNum\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.LearningBasedWB.t()`\n- **val**: `integer()`\n\n@see `getHistBinNum/1`\n\nPython prototype (for reference only):\n```python3\nsetHistBinNum(val) -> None\n```","ref":"Evision.XPhoto.LearningBasedWB.html#setHistBinNum/2"},{"type":"function","title":"Evision.XPhoto.LearningBasedWB.setRangeMaxVal/1","doc":"","ref":"Evision.XPhoto.LearningBasedWB.html#setRangeMaxVal/1"},{"type":"function","title":"Evision.XPhoto.LearningBasedWB.setRangeMaxVal/2","doc":"setRangeMaxVal\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.LearningBasedWB.t()`\n- **val**: `integer()`\n\n@see `getRangeMaxVal/1`\n\nPython prototype (for reference only):\n```python3\nsetRangeMaxVal(val) -> None\n```","ref":"Evision.XPhoto.LearningBasedWB.html#setRangeMaxVal/2"},{"type":"function","title":"Evision.XPhoto.LearningBasedWB.setSaturationThreshold/1","doc":"","ref":"Evision.XPhoto.LearningBasedWB.html#setSaturationThreshold/1"},{"type":"function","title":"Evision.XPhoto.LearningBasedWB.setSaturationThreshold/2","doc":"setSaturationThreshold\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.LearningBasedWB.t()`\n- **val**: `float`\n\n@see `getSaturationThreshold/1`\n\nPython prototype (for reference only):\n```python3\nsetSaturationThreshold(val) -> None\n```","ref":"Evision.XPhoto.LearningBasedWB.html#setSaturationThreshold/2"},{"type":"type","title":"Evision.XPhoto.LearningBasedWB.t/0","doc":"Type that represents an `XPhoto.LearningBasedWB` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XPhoto.LearningBasedWB.html#t:t/0"},{"type":"module","title":"Evision.XPhoto.SimpleWB","doc":"","ref":"Evision.XPhoto.SimpleWB.html"},{"type":"function","title":"Evision.XPhoto.SimpleWB.getInputMax/1","doc":"Input image range maximum value\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.SimpleWB.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setInputMax/2`\n\nPython prototype (for reference only):\n```python3\ngetInputMax() -> retval\n```","ref":"Evision.XPhoto.SimpleWB.html#getInputMax/1"},{"type":"function","title":"Evision.XPhoto.SimpleWB.getInputMin/1","doc":"Input image range minimum value\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.SimpleWB.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setInputMin/2`\n\nPython prototype (for reference only):\n```python3\ngetInputMin() -> retval\n```","ref":"Evision.XPhoto.SimpleWB.html#getInputMin/1"},{"type":"function","title":"Evision.XPhoto.SimpleWB.getOutputMax/1","doc":"Output image range maximum value\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.SimpleWB.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setOutputMax/2`\n\nPython prototype (for reference only):\n```python3\ngetOutputMax() -> retval\n```","ref":"Evision.XPhoto.SimpleWB.html#getOutputMax/1"},{"type":"function","title":"Evision.XPhoto.SimpleWB.getOutputMin/1","doc":"Output image range minimum value\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.SimpleWB.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setOutputMin/2`\n\nPython prototype (for reference only):\n```python3\ngetOutputMin() -> retval\n```","ref":"Evision.XPhoto.SimpleWB.html#getOutputMin/1"},{"type":"function","title":"Evision.XPhoto.SimpleWB.getP/1","doc":"Percent of top/bottom values to ignore\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.SimpleWB.t()`\n\n##### Return\n- **retval**: `float`\n\n@see `setP/2`\n\nPython prototype (for reference only):\n```python3\ngetP() -> retval\n```","ref":"Evision.XPhoto.SimpleWB.html#getP/1"},{"type":"function","title":"Evision.XPhoto.SimpleWB.setInputMax/1","doc":"","ref":"Evision.XPhoto.SimpleWB.html#setInputMax/1"},{"type":"function","title":"Evision.XPhoto.SimpleWB.setInputMax/2","doc":"setInputMax\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.SimpleWB.t()`\n- **val**: `float`\n\n@see `getInputMax/1`\n\nPython prototype (for reference only):\n```python3\nsetInputMax(val) -> None\n```","ref":"Evision.XPhoto.SimpleWB.html#setInputMax/2"},{"type":"function","title":"Evision.XPhoto.SimpleWB.setInputMin/1","doc":"","ref":"Evision.XPhoto.SimpleWB.html#setInputMin/1"},{"type":"function","title":"Evision.XPhoto.SimpleWB.setInputMin/2","doc":"setInputMin\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.SimpleWB.t()`\n- **val**: `float`\n\n@see `getInputMin/1`\n\nPython prototype (for reference only):\n```python3\nsetInputMin(val) -> None\n```","ref":"Evision.XPhoto.SimpleWB.html#setInputMin/2"},{"type":"function","title":"Evision.XPhoto.SimpleWB.setOutputMax/1","doc":"","ref":"Evision.XPhoto.SimpleWB.html#setOutputMax/1"},{"type":"function","title":"Evision.XPhoto.SimpleWB.setOutputMax/2","doc":"setOutputMax\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.SimpleWB.t()`\n- **val**: `float`\n\n@see `getOutputMax/1`\n\nPython prototype (for reference only):\n```python3\nsetOutputMax(val) -> None\n```","ref":"Evision.XPhoto.SimpleWB.html#setOutputMax/2"},{"type":"function","title":"Evision.XPhoto.SimpleWB.setOutputMin/1","doc":"","ref":"Evision.XPhoto.SimpleWB.html#setOutputMin/1"},{"type":"function","title":"Evision.XPhoto.SimpleWB.setOutputMin/2","doc":"setOutputMin\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.SimpleWB.t()`\n- **val**: `float`\n\n@see `getOutputMin/1`\n\nPython prototype (for reference only):\n```python3\nsetOutputMin(val) -> None\n```","ref":"Evision.XPhoto.SimpleWB.html#setOutputMin/2"},{"type":"function","title":"Evision.XPhoto.SimpleWB.setP/1","doc":"","ref":"Evision.XPhoto.SimpleWB.html#setP/1"},{"type":"function","title":"Evision.XPhoto.SimpleWB.setP/2","doc":"setP\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.SimpleWB.t()`\n- **val**: `float`\n\n@see `getP/1`\n\nPython prototype (for reference only):\n```python3\nsetP(val) -> None\n```","ref":"Evision.XPhoto.SimpleWB.html#setP/2"},{"type":"type","title":"Evision.XPhoto.SimpleWB.t/0","doc":"Type that represents an `XPhoto.SimpleWB` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XPhoto.SimpleWB.html#t:t/0"},{"type":"module","title":"Evision.XPhoto.TonemapDurand","doc":"","ref":"Evision.XPhoto.TonemapDurand.html"},{"type":"function","title":"Evision.XPhoto.TonemapDurand.getContrast/1","doc":"getContrast\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.TonemapDurand.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetContrast() -> retval\n```","ref":"Evision.XPhoto.TonemapDurand.html#getContrast/1"},{"type":"function","title":"Evision.XPhoto.TonemapDurand.getSaturation/1","doc":"getSaturation\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.TonemapDurand.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetSaturation() -> retval\n```","ref":"Evision.XPhoto.TonemapDurand.html#getSaturation/1"},{"type":"function","title":"Evision.XPhoto.TonemapDurand.getSigmaColor/1","doc":"getSigmaColor\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.TonemapDurand.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetSigmaColor() -> retval\n```","ref":"Evision.XPhoto.TonemapDurand.html#getSigmaColor/1"},{"type":"function","title":"Evision.XPhoto.TonemapDurand.getSigmaSpace/1","doc":"getSigmaSpace\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.TonemapDurand.t()`\n\n##### Return\n- **retval**: `float`\n\nPython prototype (for reference only):\n```python3\ngetSigmaSpace() -> retval\n```","ref":"Evision.XPhoto.TonemapDurand.html#getSigmaSpace/1"},{"type":"function","title":"Evision.XPhoto.TonemapDurand.setContrast/1","doc":"","ref":"Evision.XPhoto.TonemapDurand.html#setContrast/1"},{"type":"function","title":"Evision.XPhoto.TonemapDurand.setContrast/2","doc":"setContrast\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.TonemapDurand.t()`\n- **contrast**: `float`\n\nPython prototype (for reference only):\n```python3\nsetContrast(contrast) -> None\n```","ref":"Evision.XPhoto.TonemapDurand.html#setContrast/2"},{"type":"function","title":"Evision.XPhoto.TonemapDurand.setSaturation/1","doc":"","ref":"Evision.XPhoto.TonemapDurand.html#setSaturation/1"},{"type":"function","title":"Evision.XPhoto.TonemapDurand.setSaturation/2","doc":"setSaturation\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.TonemapDurand.t()`\n- **saturation**: `float`\n\nPython prototype (for reference only):\n```python3\nsetSaturation(saturation) -> None\n```","ref":"Evision.XPhoto.TonemapDurand.html#setSaturation/2"},{"type":"function","title":"Evision.XPhoto.TonemapDurand.setSigmaColor/1","doc":"","ref":"Evision.XPhoto.TonemapDurand.html#setSigmaColor/1"},{"type":"function","title":"Evision.XPhoto.TonemapDurand.setSigmaColor/2","doc":"setSigmaColor\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.TonemapDurand.t()`\n- **sigma_color**: `float`\n\nPython prototype (for reference only):\n```python3\nsetSigmaColor(sigma_color) -> None\n```","ref":"Evision.XPhoto.TonemapDurand.html#setSigmaColor/2"},{"type":"function","title":"Evision.XPhoto.TonemapDurand.setSigmaSpace/1","doc":"","ref":"Evision.XPhoto.TonemapDurand.html#setSigmaSpace/1"},{"type":"function","title":"Evision.XPhoto.TonemapDurand.setSigmaSpace/2","doc":"setSigmaSpace\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.TonemapDurand.t()`\n- **sigma_space**: `float`\n\nPython prototype (for reference only):\n```python3\nsetSigmaSpace(sigma_space) -> None\n```","ref":"Evision.XPhoto.TonemapDurand.html#setSigmaSpace/2"},{"type":"type","title":"Evision.XPhoto.TonemapDurand.t/0","doc":"Type that represents an `XPhoto.TonemapDurand` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XPhoto.TonemapDurand.html#t:t/0"},{"type":"module","title":"Evision.XPhoto.TransformTypes","doc":"","ref":"Evision.XPhoto.TransformTypes.html"},{"type":"function","title":"Evision.XPhoto.TransformTypes.cv_HAAR/0","doc":"","ref":"Evision.XPhoto.TransformTypes.html#cv_HAAR/0"},{"type":"type","title":"Evision.XPhoto.TransformTypes.enum/0","doc":"","ref":"Evision.XPhoto.TransformTypes.html#t:enum/0"},{"type":"module","title":"Evision.XPhoto.WhiteBalancer","doc":"","ref":"Evision.XPhoto.WhiteBalancer.html"},{"type":"function","title":"Evision.XPhoto.WhiteBalancer.balanceWhite/1","doc":"","ref":"Evision.XPhoto.WhiteBalancer.html#balanceWhite/1"},{"type":"function","title":"Evision.XPhoto.WhiteBalancer.balanceWhite/2","doc":"Applies white balancing to the input image\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.WhiteBalancer.t()`\n- **src**: `Evision.Mat`.\n\n  Input image\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  White balancing result\n\n@sa cvtColor, equalizeHist\n\nPython prototype (for reference only):\n```python3\nbalanceWhite(src[, dst]) -> dst\n```","ref":"Evision.XPhoto.WhiteBalancer.html#balanceWhite/2"},{"type":"function","title":"Evision.XPhoto.WhiteBalancer.balanceWhite/3","doc":"Applies white balancing to the input image\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.WhiteBalancer.t()`\n- **src**: `Evision.Mat`.\n\n  Input image\n\n##### Return\n- **dst**: `Evision.Mat.t()`.\n\n  White balancing result\n\n@sa cvtColor, equalizeHist\n\nPython prototype (for reference only):\n```python3\nbalanceWhite(src[, dst]) -> dst\n```","ref":"Evision.XPhoto.WhiteBalancer.html#balanceWhite/3"},{"type":"function","title":"Evision.XPhoto.WhiteBalancer.clear/1","doc":"Clears the algorithm state\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.WhiteBalancer.t()`\n\nPython prototype (for reference only):\n```python3\nclear() -> None\n```","ref":"Evision.XPhoto.WhiteBalancer.html#clear/1"},{"type":"function","title":"Evision.XPhoto.WhiteBalancer.empty/1","doc":"Returns true if the Algorithm is empty (e.g. in the very beginning or after unsuccessful read\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.WhiteBalancer.t()`\n\n##### Return\n- **retval**: `bool`\n\nPython prototype (for reference only):\n```python3\nempty() -> retval\n```","ref":"Evision.XPhoto.WhiteBalancer.html#empty/1"},{"type":"function","title":"Evision.XPhoto.WhiteBalancer.getDefaultName/1","doc":"getDefaultName\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.WhiteBalancer.t()`\n\n##### Return\n- **retval**: `String`\n\nReturns the algorithm string identifier.\nThis string is used as top level xml/yml node tag when the object is saved to a file or string.\n\nPython prototype (for reference only):\n```python3\ngetDefaultName() -> retval\n```","ref":"Evision.XPhoto.WhiteBalancer.html#getDefaultName/1"},{"type":"function","title":"Evision.XPhoto.WhiteBalancer.read/1","doc":"","ref":"Evision.XPhoto.WhiteBalancer.html#read/1"},{"type":"function","title":"Evision.XPhoto.WhiteBalancer.read/2","doc":"Reads algorithm parameters from a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.WhiteBalancer.t()`\n- **func**: `Evision.FileNode`\n\nPython prototype (for reference only):\n```python3\nread(fn) -> None\n```","ref":"Evision.XPhoto.WhiteBalancer.html#read/2"},{"type":"function","title":"Evision.XPhoto.WhiteBalancer.save/1","doc":"","ref":"Evision.XPhoto.WhiteBalancer.html#save/1"},{"type":"function","title":"Evision.XPhoto.WhiteBalancer.save/2","doc":"save\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.WhiteBalancer.t()`\n- **filename**: `String`\n\nSaves the algorithm to a file.\nIn order to make this method work, the derived class must implement Algorithm::write(FileStorage& fs).\n\nPython prototype (for reference only):\n```python3\nsave(filename) -> None\n```","ref":"Evision.XPhoto.WhiteBalancer.html#save/2"},{"type":"function","title":"Evision.XPhoto.WhiteBalancer.write/1","doc":"","ref":"Evision.XPhoto.WhiteBalancer.html#write/1"},{"type":"function","title":"Evision.XPhoto.WhiteBalancer.write/2","doc":"Stores algorithm parameters in a file storage\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.WhiteBalancer.t()`\n- **fs**: `Evision.FileStorage`\n\nPython prototype (for reference only):\n```python3\nwrite(fs) -> None\n```","ref":"Evision.XPhoto.WhiteBalancer.html#write/2"},{"type":"function","title":"Evision.XPhoto.WhiteBalancer.write/3","doc":"write\n\n##### Positional Arguments\n- **self**: `Evision.XPhoto.WhiteBalancer.t()`\n- **fs**: `Evision.FileStorage`\n- **name**: `String`\n\nHas overloading in C++\n\nPython prototype (for reference only):\n```python3\nwrite(fs, name) -> None\n```","ref":"Evision.XPhoto.WhiteBalancer.html#write/3"},{"type":"type","title":"Evision.XPhoto.WhiteBalancer.t/0","doc":"Type that represents an `XPhoto.WhiteBalancer` struct.\n\n- **ref**. `reference()`\n\n  The underlying erlang resource variable.","ref":"Evision.XPhoto.WhiteBalancer.html#t:t/0"},{"type":"module","title":"Evision.Zoo","doc":"Evision Model Zoo","ref":"Evision.Zoo.html"},{"type":"function","title":"Evision.Zoo.available_backend_and_target/0","doc":"","ref":"Evision.Zoo.html#available_backend_and_target/0"},{"type":"function","title":"Evision.Zoo.backends/0","doc":"","ref":"Evision.Zoo.html#backends/0"},{"type":"function","title":"Evision.Zoo.cache_dir/0","doc":"","ref":"Evision.Zoo.html#cache_dir/0"},{"type":"function","title":"Evision.Zoo.download/3","doc":"","ref":"Evision.Zoo.html#download/3"},{"type":"function","title":"Evision.Zoo.targets/0","doc":"","ref":"Evision.Zoo.html#targets/0"},{"type":"function","title":"Evision.Zoo.targets_reverse_lookup/0","doc":"","ref":"Evision.Zoo.html#targets_reverse_lookup/0"},{"type":"function","title":"Evision.Zoo.to_quoted_backend_and_target/1","doc":"","ref":"Evision.Zoo.html#to_quoted_backend_and_target/1"},{"type":"type","title":"Evision.Zoo.smartcell_option/0","doc":"","ref":"Evision.Zoo.html#t:smartcell_option/0"},{"type":"type","title":"Evision.Zoo.smartcell_param/0","doc":"","ref":"Evision.Zoo.html#t:smartcell_param/0"},{"type":"type","title":"Evision.Zoo.smartcell_param_map/0","doc":"","ref":"Evision.Zoo.html#t:smartcell_param_map/0"},{"type":"type","title":"Evision.Zoo.smartcell_params/0","doc":"","ref":"Evision.Zoo.html#t:smartcell_params/0"},{"type":"type","title":"Evision.Zoo.smartcell_tasks/0","doc":"","ref":"Evision.Zoo.html#t:smartcell_tasks/0"},{"type":"type","title":"Evision.Zoo.variant/0","doc":"","ref":"Evision.Zoo.html#t:variant/0"},{"type":"module","title":"Evision.Zoo.FaceDetection","doc":"Face detection model collection.","ref":"Evision.Zoo.FaceDetection.html"},{"type":"function","title":"Evision.Zoo.FaceDetection.id/0","doc":"","ref":"Evision.Zoo.FaceDetection.html#id/0"},{"type":"function","title":"Evision.Zoo.FaceDetection.label/0","doc":"","ref":"Evision.Zoo.FaceDetection.html#label/0"},{"type":"function","title":"Evision.Zoo.FaceDetection.module_list/0","doc":"","ref":"Evision.Zoo.FaceDetection.html#module_list/0"},{"type":"function","title":"Evision.Zoo.FaceDetection.modules/0","doc":"","ref":"Evision.Zoo.FaceDetection.html#modules/0"},{"type":"function","title":"Evision.Zoo.FaceDetection.smartcell_tasks/0","doc":"","ref":"Evision.Zoo.FaceDetection.html#smartcell_tasks/0"},{"type":"function","title":"Evision.Zoo.FaceDetection.to_quoted/1","doc":"Generate quoted code from smart cell attrs.","ref":"Evision.Zoo.FaceDetection.html#to_quoted/1"},{"type":"module","title":"Evision.Zoo.FaceDetection.YuNet","doc":"YuNet is a light-weight, fast and accurate face detection model","ref":"Evision.Zoo.FaceDetection.YuNet.html"},{"type":"function","title":"Evision.Zoo.FaceDetection.YuNet.default_config/0","doc":"Default configuration.","ref":"Evision.Zoo.FaceDetection.YuNet.html#default_config/0"},{"type":"function","title":"Evision.Zoo.FaceDetection.YuNet.docs/0","doc":"Docs in smart cell.","ref":"Evision.Zoo.FaceDetection.YuNet.html#docs/0"},{"type":"function","title":"Evision.Zoo.FaceDetection.YuNet.infer/2","doc":"Inference.\n\n##### Positional arguments\n- **self**: `Evision.FaceDetectorYN.t()`.\n\n  An initialized FaceDetectorYN model.\n\n- **image**: `Evision.Mat.maybe_mat_in()`.\n\n  Input image.","ref":"Evision.Zoo.FaceDetection.YuNet.html#infer/2"},{"type":"function","title":"Evision.Zoo.FaceDetection.YuNet.init/2","doc":"Initialize model.\n\n##### Positional arguments\n- **model**: `String.t()` | `:default_model | `:quant_model`.\n\n  - When `model` is a string, it will be treat as the path to a weight file\n    and `init/2` will load the model from it.\n\n  - When `model` is either `:default_model` or `:quant_model`, `init/2` will\n    download and load the predefined model.\n\n##### Keyword arguments\n- **input_size**: `{width=pos_integer(), height=pos_integer()}`\n\n  Input size of the image. It can be adjusted later with `setInputSize/2`.\n\n  Defaults to `{320, 320}`.\n\n- **conf_threshold**: `number()`.\n\n  Confidence threshold. Defaults to `0.9`\n\n- **nms_threshold**: `number()`.\n\n  NMS threshold. Defaults to `0.3`\n\n- **top_k**: `pos_integer()`.\n\n  Top k results.\n\n- **cache_dir**: `String.t()`.\n\n  Path to the cache directory.\n\n  Optional. Defaults to `:filename.basedir(:user_cache, \"\", ...)`\n\n- **backend**: `integer()`.\n\n  Specify the backend.\n\n  Optional. Defaults to `Evision.Constant.cv_DNN_BACKEND_OPENCV()`.\n\n- **target**: `integer()`.\n\n  Specify the target.\n\n  Optional. Defaults to `Evision.Constant.cv_DNN_TARGET_CPU()`.","ref":"Evision.Zoo.FaceDetection.YuNet.html#init/2"},{"type":"function","title":"Evision.Zoo.FaceDetection.YuNet.init/3","doc":"","ref":"Evision.Zoo.FaceDetection.YuNet.html#init/3"},{"type":"function","title":"Evision.Zoo.FaceDetection.YuNet.model_info/1","doc":"Model URL and filename of predefined model.","ref":"Evision.Zoo.FaceDetection.YuNet.html#model_info/1"},{"type":"function","title":"Evision.Zoo.FaceDetection.YuNet.setInputSize/2","doc":"Set the input size.\n\n`infer/2` will call this function automatically.\n\n##### Positional arguments\n- **self**: `Evision.FaceDetectorYN.t()`.\n\n  An initialized FaceDetectorYN model.\n\n- **size**: `{width=pos_integer(), height=pos_integer()}`.\n\n  Input size of the image.","ref":"Evision.Zoo.FaceDetection.YuNet.html#setInputSize/2"},{"type":"function","title":"Evision.Zoo.FaceDetection.YuNet.smartcell_params/0","doc":"Customizable parameters from smart cell.","ref":"Evision.Zoo.FaceDetection.YuNet.html#smartcell_params/0"},{"type":"function","title":"Evision.Zoo.FaceDetection.YuNet.smartcell_tasks/0","doc":"Smart cell tasks.\n\nA list of variants of the current model.","ref":"Evision.Zoo.FaceDetection.YuNet.html#smartcell_tasks/0"},{"type":"function","title":"Evision.Zoo.FaceDetection.YuNet.to_quoted/1","doc":"Generate quoted code from smart cell attrs.","ref":"Evision.Zoo.FaceDetection.YuNet.html#to_quoted/1"},{"type":"function","title":"Evision.Zoo.FaceDetection.YuNet.visualize/3","doc":"Visualize the result.\n\n##### Positional arguments\n- **image**: `Evision.Mat.maybe_mat_in()`.\n\n  Original image.\n\n- **results**: `Evision.Mat.maybe_mat_in()`, `nil`.\n\n  Results given by `infer/2`.\n\n##### Keyword arguments\n- **box_color**: `{blue=integer(), green=integer(), red=integer()}`.\n\n  Values should be in `[0, 255]`. Defaults to `{0, 255, 0}`.\n\n  Specify the color of the bounding box.\n\n- **text_color**: `{blue=integer(), green=integer(), red=integer()}`.\n\n  Values should be in `[0, 255]`. Defaults to `{0, 0, 255}`.\n\n  Specify the color of the text (confidence value).\n\n##### Return\nAn image with bounding boxes and corresponding confidence values.","ref":"Evision.Zoo.FaceDetection.YuNet.html#visualize/3"},{"type":"module","title":"Evision.Zoo.FaceRecognition","doc":"Face recognition model collection.","ref":"Evision.Zoo.FaceRecognition.html"},{"type":"function","title":"Evision.Zoo.FaceRecognition.id/0","doc":"","ref":"Evision.Zoo.FaceRecognition.html#id/0"},{"type":"function","title":"Evision.Zoo.FaceRecognition.label/0","doc":"","ref":"Evision.Zoo.FaceRecognition.html#label/0"},{"type":"function","title":"Evision.Zoo.FaceRecognition.module_list/0","doc":"","ref":"Evision.Zoo.FaceRecognition.html#module_list/0"},{"type":"function","title":"Evision.Zoo.FaceRecognition.modules/0","doc":"","ref":"Evision.Zoo.FaceRecognition.html#modules/0"},{"type":"function","title":"Evision.Zoo.FaceRecognition.smartcell_tasks/0","doc":"","ref":"Evision.Zoo.FaceRecognition.html#smartcell_tasks/0"},{"type":"function","title":"Evision.Zoo.FaceRecognition.to_quoted/1","doc":"Generate quoted code from smart cell attrs.","ref":"Evision.Zoo.FaceRecognition.html#to_quoted/1"},{"type":"module","title":"Evision.Zoo.FaceRecognition.SFace","doc":"SFace: Sigmoid-Constrained Hypersphere Loss for Robust Face Recognition","ref":"Evision.Zoo.FaceRecognition.SFace.html"},{"type":"function","title":"Evision.Zoo.FaceRecognition.SFace.default_config/0","doc":"Default configuration.","ref":"Evision.Zoo.FaceRecognition.SFace.html#default_config/0"},{"type":"function","title":"Evision.Zoo.FaceRecognition.SFace.docs/0","doc":"Docs in smart cell.","ref":"Evision.Zoo.FaceRecognition.SFace.html#docs/0"},{"type":"function","title":"Evision.Zoo.FaceRecognition.SFace.infer/3","doc":"Get feature for the input face image.\n\n##### Positional arguments\n- **self**: `Evision.FaceRecognizerSF.t()`.\n\n  An initialized FaceRecognizerSF model.\n\n- **face_image**: `Evision.Mat.maybe_mat_in()`.\n\n  Input face image.\n\n- **bbox**: `Evision.Mat.maybe_mat_in()`.\n\n  Optional bounding box that specifies the face location in the given image.\n\n  Defaults to `nil`.\n\n  When `bbox` is not `nil`, `preprocess/3` will crop the face from given image\n  and use the cropped image as the input.\n\n  Otherwise, `face_image` will be set as the input.","ref":"Evision.Zoo.FaceRecognition.SFace.html#infer/3"},{"type":"function","title":"Evision.Zoo.FaceRecognition.SFace.init/2","doc":"Initialize model.\n\n##### Positional arguments\n- **model**: `String.t()` | `:default_model` | `:quant_model`.\n\n  - When `model` is a string, it will be treat as the path to a weight file\n    and `init/2` will load the model from it.\n\n  - When `model` is either `:default_model` or `:quant_model`, `init/2` will\n    download and load the predefined model.\n\n##### Keyword arguments\n- **cache_dir**: `String.t()`.\n\n  Path to the cache directory.\n\n  Optional. Defaults to `:filename.basedir(:user_cache, \"\", ...)`\n\n- **backend**: `integer()`.\n\n  Specify the backend.\n\n  Optional. Defaults to `Evision.Constant.cv_DNN_BACKEND_OPENCV()`.\n\n- **target**: `integer()`.\n\n  Specify the target.\n\n  Optional. Defaults to `Evision.Constant.cv_DNN_TARGET_CPU()`.","ref":"Evision.Zoo.FaceRecognition.SFace.html#init/2"},{"type":"function","title":"Evision.Zoo.FaceRecognition.SFace.match/4","doc":"Compare two faces.\n\n##### Positional Arguments\n- **self**: `Evision.FaceRecognizerSF.t()`\n\n- **original**: `Evision.Mat.maybe_mat_in()`.\n\n  Original face.\n\n- **comparison**: `Evision.Mat.maybe_mat_in()`.\n\n  Comparison face.\n\n##### Keyword Arguments\n- **distance_type**: `atom`.\n\n  Either `:cosine_similarity` or `:l2_norm`. Defaults to `:cosine_similarity`.\n\n- **cosine_threshold**: `number()`.\n\n  Defaults to `0.363`.\n\n- **l2_norm_threshold**: `number()`.\n\n  Defaults to `1.128`.\n\n- **detector_module**: `module()`.\n\n  Face detector module. Defaults to `Evision.Zoo.FaceDetection.YuNet`.\n\n- **detector_model**: `String.t()` | `atom()`.\n\n  Face detector model name or path to model weights. Defaults to `:default_model`.\n\n- **detector_opts**: `Keyword.t()`.\n\n  Face detector initialization options. Defaults to `[]`.\n\n##### Return\nA map with three keys.\n\n- **matched**: `boolean()`\n\n  `true` if two faces match, `false` otherwise.\n\n- **measure**: `\"cosine_score\"` | \"`l2_norm_distance`\"\n\n  Distance type.\n\n- **retval**: `number()`\n\n  - When `measure == \"cosine_score\"`, `retval` is the cosine similarity score.\n  - When `measure == \"l2_norm_distance\"`, `retval` is the L2 norm distance.","ref":"Evision.Zoo.FaceRecognition.SFace.html#match/4"},{"type":"function","title":"Evision.Zoo.FaceRecognition.SFace.match_feature/4","doc":"Compare two face features.\n\n##### Positional Arguments\n- **self**: `Evision.FaceRecognizerSF.t()`\n\n- **face1_feat**: `Evision.Mat.maybe_mat_in()`.\n\n  Feature value of face 1.\n\n- **face2_feat**: `Evision.Mat.maybe_mat_in()`.\n\n  Feature value of face 2.\n\n##### Keyword Arguments\n- **distance_type**: `atom`.\n\n  Either `:cosine_similarity` or `:l2_norm`. Defaults to `:cosine_similarity`.\n\n- **cosine_threshold**: `number()`.\n\n  Defaults to `0.363`.\n\n- **l2_norm_threshold**: `number()`.\n\n  Defaults to `1.128`.\n\n##### Return\nA map with three keys.\n\n- **matched**: `boolean()`\n\n  `true` if two faces match, `false` otherwise.\n\n- **measure**: `\"cosine_score\"` | \"`l2_norm_distance`\"\n\n  Distance type.\n\n- **retval**: `number()`\n\n  - When `measure == \"cosine_score\"`, `retval` is the cosine similarity score.\n  - When `measure == \"l2_norm_distance\"`, `retval` is the L2 norm distance.","ref":"Evision.Zoo.FaceRecognition.SFace.html#match_feature/4"},{"type":"function","title":"Evision.Zoo.FaceRecognition.SFace.model_info/1","doc":"Model URL and filename of predefined model.","ref":"Evision.Zoo.FaceRecognition.SFace.html#model_info/1"},{"type":"function","title":"Evision.Zoo.FaceRecognition.SFace.preprocess/3","doc":"Preprocessing the input face image.\n\n`infer/3` will call this function automatically.\n\n##### Positional arguments\n- **self**: `Evision.FaceRecognizerSF.t()`.\n\n  An initialized FaceRecognizerSF model.\n\n- **face_image**: `Evision.Mat.maybe_mat_in()`.\n\n  Input face image.\n\n- **bbox**: `Evision.Mat.maybe_mat_in()`.\n\n  Optional bounding box that specifies the face location in the given image.\n\n  Defaults to `nil`.\n\n  When `bbox` is not `nil`, `preprocess/3` will crop the face from given image\n  and return the cropped image.\n\n  Otherwise, `face_image` will be returned.","ref":"Evision.Zoo.FaceRecognition.SFace.html#preprocess/3"},{"type":"function","title":"Evision.Zoo.FaceRecognition.SFace.smartcell_params/0","doc":"Customizable parameters from smart cell.","ref":"Evision.Zoo.FaceRecognition.SFace.html#smartcell_params/0"},{"type":"function","title":"Evision.Zoo.FaceRecognition.SFace.smartcell_tasks/0","doc":"Smart cell tasks.\n\nA list of variants of the current model.","ref":"Evision.Zoo.FaceRecognition.SFace.html#smartcell_tasks/0"},{"type":"function","title":"Evision.Zoo.FaceRecognition.SFace.to_quoted/1","doc":"Generate quoted code from smart cell attrs.","ref":"Evision.Zoo.FaceRecognition.SFace.html#to_quoted/1"},{"type":"module","title":"Evision.Zoo.ImageClassification","doc":"Image classfication model collection.","ref":"Evision.Zoo.ImageClassification.html"},{"type":"function","title":"Evision.Zoo.ImageClassification.id/0","doc":"","ref":"Evision.Zoo.ImageClassification.html#id/0"},{"type":"function","title":"Evision.Zoo.ImageClassification.label/0","doc":"","ref":"Evision.Zoo.ImageClassification.html#label/0"},{"type":"function","title":"Evision.Zoo.ImageClassification.module_list/0","doc":"","ref":"Evision.Zoo.ImageClassification.html#module_list/0"},{"type":"function","title":"Evision.Zoo.ImageClassification.modules/0","doc":"","ref":"Evision.Zoo.ImageClassification.html#modules/0"},{"type":"function","title":"Evision.Zoo.ImageClassification.smartcell_tasks/0","doc":"","ref":"Evision.Zoo.ImageClassification.html#smartcell_tasks/0"},{"type":"function","title":"Evision.Zoo.ImageClassification.to_quoted/1","doc":"Generate quoted code from smart cell attrs.","ref":"Evision.Zoo.ImageClassification.html#to_quoted/1"},{"type":"module","title":"Evision.Zoo.ImageClassification.MobileNetV1","doc":"MobileNets: Efficient Convolutional Neural Networks for Mobile Vision Applications","ref":"Evision.Zoo.ImageClassification.MobileNetV1.html"},{"type":"function","title":"Evision.Zoo.ImageClassification.MobileNetV1.default_config/0","doc":"Default configuration.","ref":"Evision.Zoo.ImageClassification.MobileNetV1.html#default_config/0"},{"type":"function","title":"Evision.Zoo.ImageClassification.MobileNetV1.docs/0","doc":"Docs in smart cell.","ref":"Evision.Zoo.ImageClassification.MobileNetV1.html#docs/0"},{"type":"function","title":"Evision.Zoo.ImageClassification.MobileNetV1.get_labels/1","doc":"Get labels.\n\n##### Keyword arguments\n- **labels_path**: `String.t()`.\n\n  Path to the label file. Defaults to `nil`.\n\n  When `labels_path` is `nil`, `get_labels/1` will try to\n  download the default label file.\n\n- **cache_dir**: `String.t()`.\n\n  Path to the cache directory.\n\n  Optional. Defaults to `:filename.basedir(:user_cache, \"\", ...)`\n\n##### Returns\nA list of labels.","ref":"Evision.Zoo.ImageClassification.MobileNetV1.html#get_labels/1"},{"type":"function","title":"Evision.Zoo.ImageClassification.MobileNetV1.infer/3","doc":"Inference.\n\n##### Positional arguments\n- **self**: `Evision.DNN.Net.t()`.\n\n  An initialized MobileNetV1 model.\n\n- **image**: `Evision.Mat.maybe_mat_in()`.\n\n  Input image.\n\n##### Keyword arguments\n- **top_k**: `pos_integer()`.\n\n  Get top k results.\n\n  Optional. Defaults to `5`.","ref":"Evision.Zoo.ImageClassification.MobileNetV1.html#infer/3"},{"type":"function","title":"Evision.Zoo.ImageClassification.MobileNetV1.init/2","doc":"Initialize model.\n\n##### Positional arguments\n- **model**: `String.t()` | `:default_model` | `:quant_model`.\n\n  - When `model` is a string, it will be treat as the path to a weight file\n    and `init/2` will load the model from it.\n\n  - When `model` is either `:default_model` or `:quant_model`, `init/2` will\n    download and load the predefined model.\n\n##### Keyword arguments\n- **cache_dir**: `String.t()`.\n\n  Path to the cache directory.\n\n  Optional. Defaults to `:filename.basedir(:user_cache, \"\", ...)`\n\n- **backend**: `integer()`.\n\n  Specify the backend.\n\n  Optional. Defaults to `Evision.Constant.cv_DNN_BACKEND_OPENCV()`.\n\n- **target**: `integer()`.\n\n  Specify the target.\n\n  Optional. Defaults to `Evision.Constant.cv_DNN_TARGET_CPU()`.","ref":"Evision.Zoo.ImageClassification.MobileNetV1.html#init/2"},{"type":"function","title":"Evision.Zoo.ImageClassification.MobileNetV1.labels/0","doc":"Default label file URL and filename.","ref":"Evision.Zoo.ImageClassification.MobileNetV1.html#labels/0"},{"type":"function","title":"Evision.Zoo.ImageClassification.MobileNetV1.model_info/1","doc":"Model URL and filename of predefined model.","ref":"Evision.Zoo.ImageClassification.MobileNetV1.html#model_info/1"},{"type":"function","title":"Evision.Zoo.ImageClassification.MobileNetV1.preprocess/1","doc":"Preprocessing the input image.\n\n`infer/3` will call this function automatically.\n\n##### Positional arguments\n- **image**: `Evision.Mat.maybe_mat_in()`.\n\n  Input image.","ref":"Evision.Zoo.ImageClassification.MobileNetV1.html#preprocess/1"},{"type":"function","title":"Evision.Zoo.ImageClassification.MobileNetV1.smartcell_params/0","doc":"Customizable parameters from smart cell.","ref":"Evision.Zoo.ImageClassification.MobileNetV1.html#smartcell_params/0"},{"type":"function","title":"Evision.Zoo.ImageClassification.MobileNetV1.smartcell_tasks/0","doc":"Smart cell tasks.\n\nA list of variants of the current model.","ref":"Evision.Zoo.ImageClassification.MobileNetV1.html#smartcell_tasks/0"},{"type":"function","title":"Evision.Zoo.ImageClassification.MobileNetV1.to_quoted/1","doc":"Generate quoted code from smart cell attrs.","ref":"Evision.Zoo.ImageClassification.MobileNetV1.html#to_quoted/1"},{"type":"module","title":"Evision.Zoo.ImageClassification.MobileNetV2","doc":"MobileNets: Efficient Convolutional Neural Networks for Mobile Vision Applications","ref":"Evision.Zoo.ImageClassification.MobileNetV2.html"},{"type":"function","title":"Evision.Zoo.ImageClassification.MobileNetV2.default_config/0","doc":"Default configuration.","ref":"Evision.Zoo.ImageClassification.MobileNetV2.html#default_config/0"},{"type":"function","title":"Evision.Zoo.ImageClassification.MobileNetV2.docs/0","doc":"Docs in smart cell.","ref":"Evision.Zoo.ImageClassification.MobileNetV2.html#docs/0"},{"type":"function","title":"Evision.Zoo.ImageClassification.MobileNetV2.get_labels/1","doc":"Get labels.\n\n##### Keyword arguments\n- **labels_path**: `String.t()`.\n\n  Path to the label file. Defaults to `nil`.\n\n  When `labels_path` is `nil`, `get_labels/1` will try to\n  download the default label file.\n\n- **cache_dir**: `String.t()`.\n\n  Path to the cache directory.\n\n  Optional. Defaults to `:filename.basedir(:user_cache, \"\", ...)`\n\n##### Returns\nA list of labels.","ref":"Evision.Zoo.ImageClassification.MobileNetV2.html#get_labels/1"},{"type":"function","title":"Evision.Zoo.ImageClassification.MobileNetV2.infer/3","doc":"Inference.\n\n##### Positional arguments\n- **self**: `Evision.DNN.Net.t()`.\n\n  An initialized MobileNetV2 model.\n\n- **image**: `Evision.Mat.maybe_mat_in()`.\n\n  Input image.\n\n##### Keyword arguments\n- **top_k**: `pos_integer()`.\n\n  Get top k results.\n\n  Optional. Defaults to `5`.","ref":"Evision.Zoo.ImageClassification.MobileNetV2.html#infer/3"},{"type":"function","title":"Evision.Zoo.ImageClassification.MobileNetV2.init/2","doc":"Initialize model.\n\n##### Positional arguments\n- **model**: `String.t()` | `:default_model` | `:quant_model`.\n\n  - When `model` is a string, it will be treat as the path to a weight file\n    and `init/2` will load the model from it.\n\n  - When `model` is either `:default_model` or `:quant_model`, `init/2` will\n    download and load the predefined model.\n\n##### Keyword arguments\n- **cache_dir**: `String.t()`.\n\n  Path to the cache directory.\n\n  Optional. Defaults to `:filename.basedir(:user_cache, \"\", ...)`\n\n- **backend**: `integer()`.\n\n  Specify the backend.\n\n  Optional. Defaults to `Evision.Constant.cv_DNN_BACKEND_OPENCV()`.\n\n- **target**: `integer()`.\n\n  Specify the target.\n\n  Optional. Defaults to `Evision.Constant.cv_DNN_TARGET_CPU()`.","ref":"Evision.Zoo.ImageClassification.MobileNetV2.html#init/2"},{"type":"function","title":"Evision.Zoo.ImageClassification.MobileNetV2.labels/0","doc":"Default label file URL and filename.","ref":"Evision.Zoo.ImageClassification.MobileNetV2.html#labels/0"},{"type":"function","title":"Evision.Zoo.ImageClassification.MobileNetV2.model_info/1","doc":"Model URL and filename of predefined model.","ref":"Evision.Zoo.ImageClassification.MobileNetV2.html#model_info/1"},{"type":"function","title":"Evision.Zoo.ImageClassification.MobileNetV2.preprocess/1","doc":"Preprocessing the input image.\n\n`infer/3` will call this function automatically.\n\n##### Positional arguments\n- **image**: `Evision.Mat.maybe_mat_in()`.\n\n  Input image.","ref":"Evision.Zoo.ImageClassification.MobileNetV2.html#preprocess/1"},{"type":"function","title":"Evision.Zoo.ImageClassification.MobileNetV2.smartcell_params/0","doc":"Customizable parameters from smart cell.","ref":"Evision.Zoo.ImageClassification.MobileNetV2.html#smartcell_params/0"},{"type":"function","title":"Evision.Zoo.ImageClassification.MobileNetV2.smartcell_tasks/0","doc":"Smart cell tasks.\n\nA list of variants of the current model.","ref":"Evision.Zoo.ImageClassification.MobileNetV2.html#smartcell_tasks/0"},{"type":"function","title":"Evision.Zoo.ImageClassification.MobileNetV2.to_quoted/1","doc":"Generate quoted code from smart cell attrs.","ref":"Evision.Zoo.ImageClassification.MobileNetV2.html#to_quoted/1"},{"type":"module","title":"Evision.Zoo.ImageClassification.PPResNet","doc":"Deep Residual Learning for Image Recognition.","ref":"Evision.Zoo.ImageClassification.PPResNet.html"},{"type":"function","title":"Evision.Zoo.ImageClassification.PPResNet.default_config/0","doc":"Default configuration.","ref":"Evision.Zoo.ImageClassification.PPResNet.html#default_config/0"},{"type":"function","title":"Evision.Zoo.ImageClassification.PPResNet.docs/0","doc":"Docs in smart cell.","ref":"Evision.Zoo.ImageClassification.PPResNet.html#docs/0"},{"type":"function","title":"Evision.Zoo.ImageClassification.PPResNet.get_labels/1","doc":"Get labels.\n\n##### Keyword arguments\n- **labels_path**: `String.t()`.\n\n  Path to the label file. Defaults to `nil`.\n\n  When `labels_path` is `nil`, `get_labels/1` will try to\n  download the default label file.\n\n- **cache_dir**: `String.t()`.\n\n  Path to the cache directory.\n\n  Optional. Defaults to `:filename.basedir(:user_cache, \"\", ...)`\n\n##### Returns\nA list of labels.","ref":"Evision.Zoo.ImageClassification.PPResNet.html#get_labels/1"},{"type":"function","title":"Evision.Zoo.ImageClassification.PPResNet.infer/3","doc":"Inference.\n\n##### Positional arguments\n- **self**: `Evision.DNN.Net.t()`.\n\n  An initialized PPResNet model.\n\n- **image**: `Evision.Mat.maybe_mat_in()`.\n\n  Input image.\n\n##### Keyword arguments\n- **top_k**: `pos_integer()`.\n\n  Get top k results.\n\n  Optional. Defaults to `5`.","ref":"Evision.Zoo.ImageClassification.PPResNet.html#infer/3"},{"type":"function","title":"Evision.Zoo.ImageClassification.PPResNet.init/2","doc":"Initialize model.\n\n##### Positional arguments\n- **model**: `String.t()` | `:default_model` | `:quant_model`.\n\n  - When `model` is a string, it will be treat as the path to a weight file\n    and `init/2` will load the model from it.\n\n  - When `model` is either `:default_model` or `:quant_model`, `init/2` will\n    download and load the predefined model.\n\n##### Keyword arguments\n- **cache_dir**: `String.t()`.\n\n  Path to the cache directory.\n\n  Optional. Defaults to `:filename.basedir(:user_cache, \"\", ...)`\n\n- **backend**: `integer()`.\n\n  Specify the backend.\n\n  Optional. Defaults to `Evision.Constant.cv_DNN_BACKEND_OPENCV()`.\n\n- **target**: `integer()`.\n\n  Specify the target.\n\n  Optional. Defaults to `Evision.Constant.cv_DNN_TARGET_CPU()`.","ref":"Evision.Zoo.ImageClassification.PPResNet.html#init/2"},{"type":"function","title":"Evision.Zoo.ImageClassification.PPResNet.labels/0","doc":"Default label file URL and filename.","ref":"Evision.Zoo.ImageClassification.PPResNet.html#labels/0"},{"type":"function","title":"Evision.Zoo.ImageClassification.PPResNet.model_info/1","doc":"Model URL and filename of predefined model.","ref":"Evision.Zoo.ImageClassification.PPResNet.html#model_info/1"},{"type":"function","title":"Evision.Zoo.ImageClassification.PPResNet.preprocess/1","doc":"Preprocessing the input image.\n\n`infer/3` will call this function automatically.\n\n##### Positional arguments\n- **image**: `Evision.Mat.maybe_mat_in()`.\n\n  Input image.","ref":"Evision.Zoo.ImageClassification.PPResNet.html#preprocess/1"},{"type":"function","title":"Evision.Zoo.ImageClassification.PPResNet.smartcell_params/0","doc":"Customizable parameters from smart cell.","ref":"Evision.Zoo.ImageClassification.PPResNet.html#smartcell_params/0"},{"type":"function","title":"Evision.Zoo.ImageClassification.PPResNet.smartcell_tasks/0","doc":"Smart cell tasks.\n\nA list of variants of the current model.","ref":"Evision.Zoo.ImageClassification.PPResNet.html#smartcell_tasks/0"},{"type":"function","title":"Evision.Zoo.ImageClassification.PPResNet.to_quoted/1","doc":"Generate quoted code from smart cell attrs.","ref":"Evision.Zoo.ImageClassification.PPResNet.html#to_quoted/1"},{"type":"module","title":"Evision.Zoo.ImageSegmentation","doc":"Image segmentation model collection.","ref":"Evision.Zoo.ImageSegmentation.html"},{"type":"function","title":"Evision.Zoo.ImageSegmentation.color_map/1","doc":"","ref":"Evision.Zoo.ImageSegmentation.html#color_map/1"},{"type":"function","title":"Evision.Zoo.ImageSegmentation.id/0","doc":"","ref":"Evision.Zoo.ImageSegmentation.html#id/0"},{"type":"function","title":"Evision.Zoo.ImageSegmentation.label/0","doc":"","ref":"Evision.Zoo.ImageSegmentation.html#label/0"},{"type":"function","title":"Evision.Zoo.ImageSegmentation.module_list/0","doc":"","ref":"Evision.Zoo.ImageSegmentation.html#module_list/0"},{"type":"function","title":"Evision.Zoo.ImageSegmentation.modules/0","doc":"","ref":"Evision.Zoo.ImageSegmentation.html#modules/0"},{"type":"function","title":"Evision.Zoo.ImageSegmentation.smartcell_tasks/0","doc":"","ref":"Evision.Zoo.ImageSegmentation.html#smartcell_tasks/0"},{"type":"function","title":"Evision.Zoo.ImageSegmentation.to_quoted/1","doc":"Generate quoted code from smart cell attrs.","ref":"Evision.Zoo.ImageSegmentation.html#to_quoted/1"},{"type":"module","title":"Evision.Zoo.ImageSegmentation.PPHumanSeg","doc":"PP-Human Segmentation model.","ref":"Evision.Zoo.ImageSegmentation.PPHumanSeg.html"},{"type":"function","title":"Evision.Zoo.ImageSegmentation.PPHumanSeg.default_config/0","doc":"Default configuration.","ref":"Evision.Zoo.ImageSegmentation.PPHumanSeg.html#default_config/0"},{"type":"function","title":"Evision.Zoo.ImageSegmentation.PPHumanSeg.docs/0","doc":"Docs in smart cell.","ref":"Evision.Zoo.ImageSegmentation.PPHumanSeg.html#docs/0"},{"type":"function","title":"Evision.Zoo.ImageSegmentation.PPHumanSeg.infer/2","doc":"Inference.\n\n##### Positional arguments\n- **self**: `Evision.DNN.Net.t()`.\n\n  An initialized PPHumanSeg model.\n\n- **image**: `Evision.Mat.maybe_mat_in()`.\n\n  Input image.","ref":"Evision.Zoo.ImageSegmentation.PPHumanSeg.html#infer/2"},{"type":"function","title":"Evision.Zoo.ImageSegmentation.PPHumanSeg.init/2","doc":"Initialize model.\n\n##### Positional arguments\n- **model**: `String.t()` | `:default_model` | `:quant_model`.\n\n  - When `model` is a string, it will be treat as the path to a weight file\n    and `init/2` will load the model from it.\n\n  - When `model` is either `:default_model` or `:quant_model`, `init/2` will\n    download and load the predefined model.\n\n##### Keyword arguments\n- **cache_dir**: `String.t()`.\n\n  Path to the cache directory.\n\n  Optional. Defaults to `:filename.basedir(:user_cache, \"\", ...)`\n\n- **backend**: `integer()`.\n\n  Specify the backend.\n\n  Optional. Defaults to `Evision.Constant.cv_DNN_BACKEND_OPENCV()`.\n\n- **target**: `integer()`.\n\n  Specify the target.\n\n  Optional. Defaults to `Evision.Constant.cv_DNN_TARGET_CPU()`.","ref":"Evision.Zoo.ImageSegmentation.PPHumanSeg.html#init/2"},{"type":"function","title":"Evision.Zoo.ImageSegmentation.PPHumanSeg.model_info/1","doc":"Model URL and filename of predefined model.","ref":"Evision.Zoo.ImageSegmentation.PPHumanSeg.html#model_info/1"},{"type":"function","title":"Evision.Zoo.ImageSegmentation.PPHumanSeg.preprocess/1","doc":"Preprocessing the input image.\n\n`infer/2` will call this function automatically.\n\n##### Positional arguments\n- **image**: `Evision.Mat.maybe_mat_in()`.\n\n  Input image.","ref":"Evision.Zoo.ImageSegmentation.PPHumanSeg.html#preprocess/1"},{"type":"function","title":"Evision.Zoo.ImageSegmentation.PPHumanSeg.smartcell_params/0","doc":"Customizable parameters from smart cell.","ref":"Evision.Zoo.ImageSegmentation.PPHumanSeg.html#smartcell_params/0"},{"type":"function","title":"Evision.Zoo.ImageSegmentation.PPHumanSeg.smartcell_tasks/0","doc":"Smart cell tasks.\n\nA list of variants of the current model.","ref":"Evision.Zoo.ImageSegmentation.PPHumanSeg.html#smartcell_tasks/0"},{"type":"function","title":"Evision.Zoo.ImageSegmentation.PPHumanSeg.to_quoted/1","doc":"Generate quoted code from smart cell attrs.","ref":"Evision.Zoo.ImageSegmentation.PPHumanSeg.html#to_quoted/1"},{"type":"function","title":"Evision.Zoo.ImageSegmentation.PPHumanSeg.visualize/3","doc":"Visualize the result.\n\n##### Positional arguments\n- **image**: `Evision.Mat.maybe_mat_in()`.\n\n  Original image.\n\n- **results**: `Evision.Mat.maybe_mat_in()`.\n\n  Results given by `infer/2`.\n\n##### Keyword arguments\n- **weight**: `number()`.\n\n  A number in `[0.0, 1.0]`. Defaults to `0.6`.\n\n  Specify the weight of the original image. The weight of the segmentation visualization image\n  will be `1 - weight`.\n\n##### Return\nA list that contains two images (`Evision.Mat.t()`).\n\n- The first one is the original image with the segmentation overlay.\n- The second one is the segmentation image.","ref":"Evision.Zoo.ImageSegmentation.PPHumanSeg.html#visualize/3"},{"type":"module","title":"Evision.Zoo.TextDetection","doc":"Text detection model collection.","ref":"Evision.Zoo.TextDetection.html"},{"type":"function","title":"Evision.Zoo.TextDetection.id/0","doc":"","ref":"Evision.Zoo.TextDetection.html#id/0"},{"type":"function","title":"Evision.Zoo.TextDetection.label/0","doc":"","ref":"Evision.Zoo.TextDetection.html#label/0"},{"type":"function","title":"Evision.Zoo.TextDetection.module_list/0","doc":"","ref":"Evision.Zoo.TextDetection.html#module_list/0"},{"type":"function","title":"Evision.Zoo.TextDetection.modules/0","doc":"","ref":"Evision.Zoo.TextDetection.html#modules/0"},{"type":"function","title":"Evision.Zoo.TextDetection.smartcell_tasks/0","doc":"","ref":"Evision.Zoo.TextDetection.html#smartcell_tasks/0"},{"type":"function","title":"Evision.Zoo.TextDetection.to_quoted/1","doc":"Generate quoted code from smart cell attrs.","ref":"Evision.Zoo.TextDetection.html#to_quoted/1"},{"type":"module","title":"Evision.Zoo.TextDetection.DB","doc":"Real-time Scene Text Detection with Differentiable Binarization\n\n- `IC15` model is trained on IC15 dataset, which can detect English text instances only.\n- `TD500` model is trained on TD500 dataset, which can detect both English & Chinese instances.","ref":"Evision.Zoo.TextDetection.DB.html"},{"type":"function","title":"Evision.Zoo.TextDetection.DB.default_config/0","doc":"Default configuration.","ref":"Evision.Zoo.TextDetection.DB.html#default_config/0"},{"type":"function","title":"Evision.Zoo.TextDetection.DB.docs/0","doc":"Docs in smart cell.","ref":"Evision.Zoo.TextDetection.DB.html#docs/0"},{"type":"function","title":"Evision.Zoo.TextDetection.DB.infer/2","doc":"Inference.\n\n##### Positional arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`.\n\n  An initialized `Evision.DNN.TextDetectionModelDB` model.\n\n- **image**: `Evision.Mat.maybe_mat_in()`.\n\n  Input image.\n\n##### Return\n`{detections, confidence}`","ref":"Evision.Zoo.TextDetection.DB.html#infer/2"},{"type":"function","title":"Evision.Zoo.TextDetection.DB.init/2","doc":"Initialize model.\n\n##### Positional arguments\n- **model**: `String.t()` | `:ic15_resnet18` | `:ic15_resnet50` | `:td500_resnet18` | `:td500_resnet50`\n\n  - When `model` is a string, it will be treat as the path to a weight file\n    and `init/2` will load the model from it.\n\n  - When `model` is one of `:ic15_resnet18`, `:ic15_resnet50`, `:td500_resnet18` or `:td500_resnet50`,\n    `init/2` will download and load the predefined model.\n\n##### Keyword arguments\n- **cache_dir**: `String.t()`.\n\n  Path to the cache directory.\n\n  Optional. Defaults to `:filename.basedir(:user_cache, \"\", ...)`\n\n- **backend**: `integer()`.\n\n  Specify the backend.\n\n  Optional. Defaults to `Evision.Constant.cv_DNN_BACKEND_OPENCV()`.\n\n- **target**: `integer()`.\n\n  Specify the target.\n\n  Optional. Defaults to `Evision.Constant.cv_DNN_TARGET_CPU()`.","ref":"Evision.Zoo.TextDetection.DB.html#init/2"},{"type":"function","title":"Evision.Zoo.TextDetection.DB.model_info/1","doc":"Model URL and filename of predefined model.","ref":"Evision.Zoo.TextDetection.DB.html#model_info/1"},{"type":"function","title":"Evision.Zoo.TextDetection.DB.smartcell_params/0","doc":"Customizable parameters from smart cell.","ref":"Evision.Zoo.TextDetection.DB.html#smartcell_params/0"},{"type":"function","title":"Evision.Zoo.TextDetection.DB.smartcell_tasks/0","doc":"Smart cell tasks.\n\nA list of variants of the current model.","ref":"Evision.Zoo.TextDetection.DB.html#smartcell_tasks/0"},{"type":"function","title":"Evision.Zoo.TextDetection.DB.to_quoted/1","doc":"Generate quoted code from smart cell attrs.","ref":"Evision.Zoo.TextDetection.DB.html#to_quoted/1"},{"type":"function","title":"Evision.Zoo.TextDetection.DB.visualize/4","doc":"Visualize the result.\n\n##### Positional arguments\n- **image**: `Evision.Mat.maybe_mat_in()`.\n\n  Original image.\n\n- **detections**: `list({{number(), number()}, {number(), number()}, number()})`.\n\n  Rotation retangulars.\n\n- **confidences**: `list(number())`.\n\n  Confidence values.\n\n##### Keyword arguments\n- **box_color**: `{blue=integer(), green=integer(), red=integer()}`.\n\n  Values should be in `[0, 255]`. Defaults to `{0, 255, 0}`.\n\n  Specify the color of the bounding box.\n\n- **text_color**: `{blue=integer(), green=integer(), red=integer()}`.\n\n  Values should be in `[0, 255]`. Defaults to `{0, 0, 255}`.\n\n  Specify the color of the text (confidence value).","ref":"Evision.Zoo.TextDetection.DB.html#visualize/4"},{"type":"module","title":"Evision.Zoo.TextDetection.PPOCRV3","doc":"Real-time Scene Text Detection with PP-OCRv3","ref":"Evision.Zoo.TextDetection.PPOCRV3.html"},{"type":"function","title":"Evision.Zoo.TextDetection.PPOCRV3.default_config/0","doc":"Default configuration.","ref":"Evision.Zoo.TextDetection.PPOCRV3.html#default_config/0"},{"type":"function","title":"Evision.Zoo.TextDetection.PPOCRV3.docs/0","doc":"Docs in smart cell.","ref":"Evision.Zoo.TextDetection.PPOCRV3.html#docs/0"},{"type":"function","title":"Evision.Zoo.TextDetection.PPOCRV3.infer/2","doc":"Inference.\n\n##### Positional arguments\n- **self**: `Evision.DNN.TextDetectionModelDB.t()`.\n\n  An initialized `Evision.DNN.TextDetectionModelDB` model.\n\n- **image**: `Evision.Mat.maybe_mat_in()`.\n\n  Input image.\n\n##### Return\n`{detections, confidence}`","ref":"Evision.Zoo.TextDetection.PPOCRV3.html#infer/2"},{"type":"function","title":"Evision.Zoo.TextDetection.PPOCRV3.init/2","doc":"Initialize model.\n\n##### Positional arguments\n- **model**: `String.t()` | `:en` | `:cn`\n\n  - When `model` is a string, it will be treat as the path to a weight file\n    and `init/2` will load the model from it.\n\n  - When `model` is one of `:en` and `:cn`,\n    `init/2` will download and load the predefined model.\n\n##### Keyword arguments\n- **cache_dir**: `String.t()`.\n\n  Path to the cache directory.\n\n  Optional. Defaults to `:filename.basedir(:user_cache, \"\", ...)`\n\n- **backend**: `integer()`.\n\n  Specify the backend.\n\n  Optional. Defaults to `Evision.Constant.cv_DNN_BACKEND_OPENCV()`.\n\n- **target**: `integer()`.\n\n  Specify the target.\n\n  Optional. Defaults to `Evision.Constant.cv_DNN_TARGET_CPU()`.","ref":"Evision.Zoo.TextDetection.PPOCRV3.html#init/2"},{"type":"function","title":"Evision.Zoo.TextDetection.PPOCRV3.model_info/1","doc":"Model URL and filename of predefined model.","ref":"Evision.Zoo.TextDetection.PPOCRV3.html#model_info/1"},{"type":"function","title":"Evision.Zoo.TextDetection.PPOCRV3.smartcell_params/0","doc":"Customizable parameters from smart cell.","ref":"Evision.Zoo.TextDetection.PPOCRV3.html#smartcell_params/0"},{"type":"function","title":"Evision.Zoo.TextDetection.PPOCRV3.smartcell_tasks/0","doc":"Smart cell tasks.\n\nA list of variants of the current model.","ref":"Evision.Zoo.TextDetection.PPOCRV3.html#smartcell_tasks/0"},{"type":"function","title":"Evision.Zoo.TextDetection.PPOCRV3.to_quoted/1","doc":"Generate quoted code from smart cell attrs.","ref":"Evision.Zoo.TextDetection.PPOCRV3.html#to_quoted/1"},{"type":"function","title":"Evision.Zoo.TextDetection.PPOCRV3.visualize/4","doc":"Visualize the result.\n\n##### Positional arguments\n- **image**: `Evision.Mat.maybe_mat_in()`.\n\n  Original image.\n\n- **detections**: `list({{number(), number()}, {number(), number()}, number()})`.\n\n  Rotation retangulars.\n\n- **confidences**: `list(number())`.\n\n  Confidence values.\n\n##### Keyword arguments\n- **box_color**: `{blue=integer(), green=integer(), red=integer()}`.\n\n  Values should be in `[0, 255]`. Defaults to `{0, 255, 0}`.\n\n  Specify the color of the bounding box.\n\n- **text_color**: `{blue=integer(), green=integer(), red=integer()}`.\n\n  Values should be in `[0, 255]`. Defaults to `{0, 0, 255}`.\n\n  Specify the color of the text (confidence value).","ref":"Evision.Zoo.TextDetection.PPOCRV3.html#visualize/4"},{"type":"module","title":"Evision.Zoo.TextRecognition","doc":"Text recognition model collection.","ref":"Evision.Zoo.TextRecognition.html"},{"type":"function","title":"Evision.Zoo.TextRecognition.id/0","doc":"","ref":"Evision.Zoo.TextRecognition.html#id/0"},{"type":"function","title":"Evision.Zoo.TextRecognition.label/0","doc":"","ref":"Evision.Zoo.TextRecognition.html#label/0"},{"type":"function","title":"Evision.Zoo.TextRecognition.module_list/0","doc":"","ref":"Evision.Zoo.TextRecognition.html#module_list/0"},{"type":"function","title":"Evision.Zoo.TextRecognition.modules/0","doc":"","ref":"Evision.Zoo.TextRecognition.html#modules/0"},{"type":"function","title":"Evision.Zoo.TextRecognition.smartcell_tasks/0","doc":"","ref":"Evision.Zoo.TextRecognition.html#smartcell_tasks/0"},{"type":"function","title":"Evision.Zoo.TextRecognition.to_quoted/1","doc":"Generate quoted code from smart cell attrs.","ref":"Evision.Zoo.TextRecognition.html#to_quoted/1"},{"type":"module","title":"Evision.Zoo.TextRecognition.CRNN","doc":"An End-to-End Trainable Neural Network for Image-based Sequence Recognition and Its Application to Scene Text Recognition.\n\n'FP16' or 'INT8' stands for 'model quantized into FP16' or 'model quantized into int8'.\n\n- `CRNN_EN` and it variants can detect digits (0-9) and letters (return lowercase letters a-z).\n- `CRNN_CH` and it variants can detect digits (0-9), upper/lower-case letters (a-z and A-Z), and some special characters.\n- `CRNN_CN` and it variants can detect digits (0-9), upper/lower-case letters (a-z and A-Z), some Chinese characters and some special characters.","ref":"Evision.Zoo.TextRecognition.CRNN.html"},{"type":"function","title":"Evision.Zoo.TextRecognition.CRNN.charset_36_EN/0","doc":"Charset that contains digits (0~9) and letters (return lowercase letters a~z).\n\nContent copied from `charset_36_EN.txt`.","ref":"Evision.Zoo.TextRecognition.CRNN.html#charset_36_EN/0"},{"type":"function","title":"Evision.Zoo.TextRecognition.CRNN.charset_94_CH/0","doc":"Charset that contains digits (0~9), upper/lower-case letters (a~z and A~Z),\nand some special characters.\n\nContent copied from `charset_94_CH.txt`.","ref":"Evision.Zoo.TextRecognition.CRNN.html#charset_94_CH/0"},{"type":"function","title":"Evision.Zoo.TextRecognition.CRNN.charset_3944_CN/0","doc":"Charset that contains digits (0~9), upper/lower-case letters (a~z and A~Z),\nsome Chinese characters and some special characters.\n\nContent copied from `charset_94_CH.txt`.","ref":"Evision.Zoo.TextRecognition.CRNN.html#charset_3944_CN/0"},{"type":"function","title":"Evision.Zoo.TextRecognition.CRNN.charset_info/1","doc":"","ref":"Evision.Zoo.TextRecognition.CRNN.html#charset_info/1"},{"type":"function","title":"Evision.Zoo.TextRecognition.CRNN.chartset_info/1","doc":"","ref":"Evision.Zoo.TextRecognition.CRNN.html#chartset_info/1"},{"type":"function","title":"Evision.Zoo.TextRecognition.CRNN.default_config/0","doc":"Default configuration.","ref":"Evision.Zoo.TextRecognition.CRNN.html#default_config/0"},{"type":"function","title":"Evision.Zoo.TextRecognition.CRNN.docs/0","doc":"Docs in smart cell.","ref":"Evision.Zoo.TextRecognition.CRNN.html#docs/0"},{"type":"function","title":"Evision.Zoo.TextRecognition.CRNN.get_charset/1","doc":"Get charset","ref":"Evision.Zoo.TextRecognition.CRNN.html#get_charset/1"},{"type":"function","title":"Evision.Zoo.TextRecognition.CRNN.infer/4","doc":"Inference.\n\n##### Positional arguments\n- **self**: `Evision.DNN.Net.t()`.\n\n  An initialized CRNN model.\n\n- **image**: `Evision.Mat.maybe_mat_in()`.\n\n  Input image.\n\n- **rotation_box**: `Evision.Mat.maybe_mat_in()`.\n\n  Rotation box.\n\n##### Keyword arguments\n- **charset**: `[binary]` | `:en` | `:ch` | `:cn`\n\n  Required. The corresponding charset for the model.\n\n- **to_gray**: `boolean`.\n\n  Required. The input image need to be converted to grayscale if the model is `:en*`.\n\n  Please set to `true` if the model is `:en*`.","ref":"Evision.Zoo.TextRecognition.CRNN.html#infer/4"},{"type":"function","title":"Evision.Zoo.TextRecognition.CRNN.init/2","doc":"Initialize model.\n\n##### Positional arguments\n- **model**: `String.t()` | `:en` | `:en_fp16` | `:en_int8` | `:ch` | `:ch_fp16` | `:ch_int8` | `:cn` | `:cn_int8`.\n\n  - When `model` is a string, it will be treat as the path to a weight file\n    and `init/2` will load the model from it.\n\n  - When `model` is one the allowed atoms, `init/2` will download and load the predefined model.\n\n##### Keyword arguments\n- **cache_dir**: `String.t()`.\n\n  Path to the cache directory.\n\n  Optional. Defaults to `:filename.basedir(:user_cache, \"\", ...)`\n\n- **backend**: `integer()`.\n\n  Specify the backend.\n\n  Optional. Defaults to `Evision.Constant.cv_DNN_BACKEND_OPENCV()`.\n\n- **target**: `integer()`.\n\n  Specify the target.\n\n  Optional. Defaults to `Evision.Constant.cv_DNN_TARGET_CPU()`.","ref":"Evision.Zoo.TextRecognition.CRNN.html#init/2"},{"type":"function","title":"Evision.Zoo.TextRecognition.CRNN.input_size/0","doc":"Get default input size","ref":"Evision.Zoo.TextRecognition.CRNN.html#input_size/0"},{"type":"function","title":"Evision.Zoo.TextRecognition.CRNN.model_info/1","doc":"Model URL and filename of predefined model.","ref":"Evision.Zoo.TextRecognition.CRNN.html#model_info/1"},{"type":"function","title":"Evision.Zoo.TextRecognition.CRNN.postprocess/2","doc":"Postprocessing the results.\n\n`infer/4` will call this function automatically.\n\n##### Positional arguments\n- **image**: `Evision.Mat.maybe_mat_in()`.\n\n  Input image.","ref":"Evision.Zoo.TextRecognition.CRNN.html#postprocess/2"},{"type":"function","title":"Evision.Zoo.TextRecognition.CRNN.preprocess/3","doc":"Preprocessing the input image.\n\n`infer/4` will call this function automatically.\n\n##### Positional arguments\n- **image**: `Evision.Mat.maybe_mat_in()`.\n\n  Input image.","ref":"Evision.Zoo.TextRecognition.CRNN.html#preprocess/3"},{"type":"function","title":"Evision.Zoo.TextRecognition.CRNN.smartcell_params/0","doc":"Customizable parameters from smart cell.","ref":"Evision.Zoo.TextRecognition.CRNN.html#smartcell_params/0"},{"type":"function","title":"Evision.Zoo.TextRecognition.CRNN.smartcell_tasks/0","doc":"Smart cell tasks.\n\nA list of variants of the current model.","ref":"Evision.Zoo.TextRecognition.CRNN.html#smartcell_tasks/0"},{"type":"function","title":"Evision.Zoo.TextRecognition.CRNN.target_vertices/0","doc":"Get default target vertices","ref":"Evision.Zoo.TextRecognition.CRNN.html#target_vertices/0"},{"type":"function","title":"Evision.Zoo.TextRecognition.CRNN.to_quoted/1","doc":"Generate quoted code from smart cell attrs.","ref":"Evision.Zoo.TextRecognition.CRNN.html#to_quoted/1"},{"type":"function","title":"Evision.Zoo.TextRecognition.CRNN.visualize/5","doc":"Visualize the result.\n\n##### Positional arguments\n- **image**: `Evision.Mat.maybe_mat_in()`.\n\n  Original image.\n\n- **results**: `Evision.Mat.maybe_mat_in()`.\n\n  Results given by `infer/2`.\n\n##### Keyword arguments\n- **box_color**: `{blue=integer(), green=integer(), red=integer()}`.\n\n  Values should be in `[0, 255]`. Defaults to `{0, 255, 0}`.\n\n  Specify the color of the bounding box.\n\n- **text_color**: `{blue=integer(), green=integer(), red=integer()}`.\n\n  Values should be in `[0, 255]`. Defaults to `{0, 0, 255}`.\n\n  Specify the color of the text (confidence value).","ref":"Evision.Zoo.TextRecognition.CRNN.html#visualize/5"},{"type":"task","title":"mix evision.fetch","doc":"A task responsible for downloading the precompiled NIFs for a given module.\n\nThis task must only be used by package creators who want to ship the\nprecompiled NIFs. The goal is to download the precompiled packages and\ngenerate a checksum to check-in alongside the project in the the Hex repository.\nThis is done by passing the `--all` flag.\n\nYou can also use the `--only-local` flag to download only the precompiled\npackage for use during development.\n\nYou can use the `--ignore-unavailable` flag to ignore any NIFs that are not available.\nThis is useful when you are developing a new NIF that does not support all platforms.\n\nThis task also accept the `--print` flag to print the checksums.","ref":"Mix.Tasks.Evision.Fetch.html"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.2.9 (2024-08-17) - Changelog","doc":"[Browse the Repository](https://github.com/cocoa-xu/evision/tree/v0.2.9) | [Released Assets](https://github.com/cocoa-xu/evision/releases/tag/v0.2.9)","ref":"changelog.html#v0-2-9-2024-08-17"},{"type":"extras","title":"Fixes - Changelog","doc":"- Include the `c_src/evision_consts.h` in the package.","ref":"changelog.html#fixes"},{"type":"extras","title":"v0.2.8 (2024-08-04) - Changelog","doc":"[Browse the Repository](https://github.com/cocoa-xu/evision/tree/v0.2.8) | [Released Assets](https://github.com/cocoa-xu/evision/releases/tag/v0.2.8)","ref":"changelog.html#v0-2-8-2024-08-04"},{"type":"extras","title":"Fixes - Changelog","doc":"- Fixed inheritance issues for classes that have any of the following base classes:\n  - `cv::img_hash::ImgHashBase`\n  - `cv::legacy::Tracker`\n  - `cv::phase_unwrapping::PhaseUnwrapping`\n  - `cv::rapid::Tracker`\n  - `cv::reg::Map`\n  - `cv::reg::Mapper`\n  - `cv::structured_light::StructuredLightPattern`\n  - `BackgroundSubtractor`","ref":"changelog.html#fixes"},{"type":"extras","title":"v0.2.7 (2024-07-03) - Changelog","doc":"[Browse the Repository](https://github.com/cocoa-xu/evision/tree/v0.2.7) | [Released Assets](https://github.com/cocoa-xu/evision/releases/tag/v0.2.7)","ref":"changelog.html#v0-2-7-2024-07-03"},{"type":"extras","title":"Breaking changes (compile-time and CUDA users only) - Changelog","doc":"- `EVISION_CUDA_VERSION`, now it should be the major version of CUDA, e.g., `12`.\n- `EVISION_CUDNN_VERSION`, it should be the major version of cuDNN, e.g., `9`.","ref":"changelog.html#breaking-changes-compile-time-and-cuda-users-only"},{"type":"extras","title":"Changes - Changelog","doc":"- Added precompiled version with CUDA 12.x and cudnn 9.x for aarch64-linux-gnu.","ref":"changelog.html#changes"},{"type":"extras","title":"v0.2.5 (2024-07-01) - Changelog","doc":"[Browse the Repository](https://github.com/cocoa-xu/evision/tree/v0.2.5) | [Released Assets](https://github.com/cocoa-xu/evision/releases/tag/v0.2.5)","ref":"changelog.html#v0-2-5-2024-07-01"},{"type":"extras","title":"Changes - Changelog","doc":"- Validate possible keyword arguments for functions that accept named arguments.\n\n    ```elixir\n    iex> img = Evision.imread(\"test/testdata/dog.jpg\")\n\n    # valid keyword argument\n    iex> Evision.applyColorMap(src: img, colormap: Evision.Constant.cv_COLORMAP_AUTUMN)\n    %Evision.Mat{\n      channels: 3,\n      dims: 2,\n      type: {:u, 8},\n      raw_type: 16,\n      shape: {576, 768, 3},\n      ref: #Reference<0.97833242.1116078104.245977>\n    }\n    \n    # list all possible keyword arguments if the user provides any invalid ones\n    iex> Evision.applyColorMap(src: img, colorMap: Evision.Constant.cv_COLORMAP_AUTUMN)\n    ** (ArgumentError) unknown keys [:colorMap] in [src: %Evision.Mat{channels: 3, dims: 2, type: {:u, 8}, raw_type: 16, shape: {576, 768, 3}, ref: #Reference<0.97833242.1116078110.246705>}, colorMap: 0], the allowed keys are: [:dst, :colormap, :userColor, :src]\n        (elixir 1.18.0-dev) lib/keyword.ex:362: Keyword.validate!/2\n        (evision 0.2.4) lib/generated/evision.ex:4603: Evision.applyColorMap/1\n        iex:4: (file)\n    ```\n\n- Generated typed enums for OpenCV's `cv::flann`.\n- \n  This should include the following enums and place them in the corresponding modules.\n\n  - `flann_algorithm_t`\n  - `flann_centers_init_t`\n  - `flann_log_level_t`\n  - `flann_distance_t`\n  - `flann_datatype_t`\n\n  For example, `flann_algorithm_t` will be put in the `Evision.Flann.Algorithm` module:\n\n  ```elixir\n  defmodule Evision.Flann.Algorithm do\n    @type enum :: integer()\n    @doc enum: true\n    def cv_FLANN_INDEX_LINEAR, do: 0\n    @doc enum: true\n    def cv_FLANN_INDEX_KDTREE, do: 1\n    @doc enum: true\n    def cv_FLANN_INDEX_KMEANS, do: 2\n    @doc enum: true\n    def cv_FLANN_INDEX_COMPOSITE, do: 3\n    @doc enum: true\n    def cv_FLANN_INDEX_KDTREE_SINGLE, do: 4\n    @doc enum: true\n    def cv_FLANN_INDEX_HIERARCHICAL, do: 5\n    @doc enum: true\n    def cv_FLANN_INDEX_LSH, do: 6\n    @doc enum: true\n    def cv_FLANN_INDEX_SAVED, do: 254\n    @doc enum: true\n    def cv_FLANN_INDEX_AUTOTUNED, do: 255\n  end\n  ```","ref":"changelog.html#changes"},{"type":"extras","title":"v0.2.4 (2024-06-20) - Changelog","doc":"[Browse the Repository](https://github.com/cocoa-xu/evision/tree/v0.2.4) | [Released Assets](https://github.com/cocoa-xu/evision/releases/tag/v0.2.4)","ref":"changelog.html#v0-2-4-2024-06-20"},{"type":"extras","title":"Changes - Changelog","doc":"- Allow users to use named arguments.","ref":"changelog.html#changes"},{"type":"extras","title":"v0.2.3 (2024-06-17) - Changelog","doc":"[Browse the Repository](https://github.com/cocoa-xu/evision/tree/v0.2.3) | [Released Assets](https://github.com/cocoa-xu/evision/releases/tag/v0.2.3)","ref":"changelog.html#v0-2-3-2024-06-17"},{"type":"extras","title":"Added - Changelog","doc":"- Experimental support for use shared CUDA memory via `Evision.CUDA.GpuMat.from_pointer/{3,4}`.","ref":"changelog.html#added"},{"type":"extras","title":"v0.2.2 (2024-06-15) - Changelog","doc":"[Browse the Repository](https://github.com/cocoa-xu/evision/tree/v0.2.2) | [Released Assets](https://github.com/cocoa-xu/evision/releases/tag/v0.2.2)","ref":"changelog.html#v0-2-2-2024-06-15"},{"type":"extras","title":"Added - Changelog","doc":"- Experimental support for CUDA shared memory via `Evision.CUDA.GpuMat.to_pointer/{1,2}`.\n- Experimental support for Gleam. See [gleam_evision_demo](https://github.com/cocoa-xu/gleam_evision_demo) for more information.","ref":"changelog.html#added"},{"type":"extras","title":"Changes - Changelog","doc":"- General improvements to the typespecs. Enumerators now also have their own modules.\n- Experimental support for using Nx.tensor directly without calling helper functions like `Evision.Mat.from_nx/1`, `Evision.Mat.from_nx_2d/1` and `Evision.Mat.last_dim_as_channel/1` .\n- Support `/AOS` (arithmetic op src) marks in OpenCV source code.\n\n  This should make evision's behaviour in line with OpenCV (C++ and Python).\n\n  For example, in `Evision.add/2`, the expected behaviour should be different when src1/src2 are single number and they are tuple/array.\n\n  `add(src, X)` where `X` is a number (or `Nx.tensor(X)`), it means `add(src, {X,X,X,X})`\n\n  while `add(src, {X})` (or `add(src, Nx.tensor([X]))`) means `add(src, {X,0,0,0})`.\n- Allow a single number to be passed as `Evision.Mat.maybe_mat_in()` and `Evision.scalar()`.\n- Allow a n-tuple (containing n numbers) to be passed as `Evision.Mat.maybe_mat_in()` and `Evision.scalar()`.\n- `Evision.Mat` now implements `Nx.LazyContainer` protocol.","ref":"changelog.html#changes"},{"type":"extras","title":"Fixes - Changelog","doc":"- Fixed Erlang bindings when converting from Elixir structs to Erlang records and vice versa.","ref":"changelog.html#fixes"},{"type":"extras","title":"v0.2.1 (2024-06-04) - Changelog","doc":"[Browse the Repository](https://github.com/cocoa-xu/evision/tree/v0.2.1) | [Released Assets](https://github.com/cocoa-xu/evision/releases/tag/v0.2.1)","ref":"changelog.html#v0-2-1-2024-06-04"},{"type":"extras","title":"Fixes - Changelog","doc":"- Fixed function specs where type hints for sub-classes were using the type of their parent-classes.","ref":"changelog.html#fixes"},{"type":"extras","title":"v0.2.0 (2024-06-03) - Changelog","doc":"[Browse the Repository](https://github.com/cocoa-xu/evision/tree/v0.2.0) | [Released Assets](https://github.com/cocoa-xu/evision/releases/tag/v0.2.0)","ref":"changelog.html#v0-2-0-2024-06-03"},{"type":"extras","title":"Changes - Changelog","doc":"- Uses OpenCV 4.10.0. Some APIs may have changed, please see OpenCV's release note for more information.\n\nChange logs for `v0.1.x` can be found in the [CHANGELOG.v0.1.md](https://github.com/cocoa-xu/evision/blob/main/CHANGELOG.v0.1.md)","ref":"changelog.html#changes"},{"type":"extras","title":"Evision Quick Start","doc":"# Evision Quick Start\n\nThis document is a cheatsheet on how to use `evision`.","ref":"cheatsheet.html"},{"type":"extras","title":"Read & Write An Image - Evision Quick Start","doc":"","ref":"cheatsheet.html#read-write-an-image"},{"type":"extras","title":"Read An Image - Evision Quick Start","doc":"#### Evision.imread\n\n```elixir\n# Read an image\niex> img = Evision.imread(\"image.png\")\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {1080, 1920, 3},\n  ref: #Reference<0.664400266.3733323795.187022>\n}\n\n# Read and get the number of channels\niex> %Evision.Mat{channels: c} = img = Evision.imread(\"image.png\")\niex> c\n3\n```","ref":"cheatsheet.html#read-an-image"},{"type":"extras","title":"Read a color image as a grayscale one - Evision Quick Start","doc":"#### Evision.imread with `flags`\n```elixir\niex> img = Evision.imread(\"image.png\", flags: Evision.Constant.cv_IMREAD_GRAYSCALE())\n%Evision.Mat{\n  channels: 1,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 0,\n  shape: {1080, 1920},\n  ref: #Reference<0.664400266.3733323795.187022>\n}\n```","ref":"cheatsheet.html#read-a-color-image-as-a-grayscale-one"},{"type":"extras","title":"Read a PNG image that has an alpha channel - Evision Quick Start","doc":"#### Evision.imread with `flags`\n```elixir\niex> img = Evision.imread(\"image.png\", flags: Evision.Constant.cv_IMREAD_UNCHANGED())\n%Evision.Mat{\n  channels: 4,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 24,\n  shape: {1080, 1920, 4},\n  ref: #Reference<0.664400266.3733323795.187022>\n}\n```","ref":"cheatsheet.html#read-a-png-image-that-has-an-alpha-channel"},{"type":"extras","title":"Write An Image - Evision Quick Start","doc":"#### Evision.imwrite\n\nThe file extension decides the image encoder of the output image.\n\n```elixir\n# as PNG\nEvision.imwrite(\"filename.png\", image)\n\n# as JPEG\nEvision.imwrite(\"filename.jpeg\", image)\n```","ref":"cheatsheet.html#write-an-image"},{"type":"extras","title":"Access A Sub-region/matrix - Evision Quick Start","doc":"","ref":"cheatsheet.html#access-a-sub-region-matrix"},{"type":"extras","title":"Get A Sub-area of An Image - Evision Quick Start","doc":"```elixir\niex> img = Evision.imread(\"image.png\")\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {1080, 1920, 3},\n  ref: #Reference<0.664400266.3733323795.187022>\n}\n\n# Note that Elixir Range is inclusive, 0..1 gives [0, 1]\niex> img[[0..100, 0..100]]\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {101, 101, 3},\n  ref: #Reference<0.664400266.3733323795.187023>\n}\n```","ref":"cheatsheet.html#get-a-sub-area-of-an-image"},{"type":"extras","title":"Extract One Channel of An Image - Evision Quick Start","doc":"```elixir\niex> img = Evision.imread(\"image.png\")\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {1080, 1920, 3},\n  ref: #Reference<0.664400266.3733323795.187022>\n}\n\n# by default OpenCV uses BGR format, therefore\n# the following code will extract the red-channel\niex> img[[:all, :all, 2]]\n%Evision.Mat{\n  channels: 1,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 0,\n  shape: {1080, 1920},\n  ref: #Reference<0.664400266.3733323795.187023>\n}\n```","ref":"cheatsheet.html#extract-one-channel-of-an-image"},{"type":"extras","title":"Extract An Abritray Continuous Sub-matrix - Evision Quick Start","doc":"```elixir\niex> img = Evision.imread(\"image.png\")\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {1080, 1920, 3},\n  ref: #Reference<0.664400266.3733323795.187022>\n}\n\n# as of now, the step size has to be 1\niex> img[[100..200, 10..50, 0..1]]\n%Evision.Mat{\n  channels: 2,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 8,\n  shape: {101, 41, 2},\n  ref: #Reference<0.664400266.3733323795.187024>\n}\n```","ref":"cheatsheet.html#extract-an-abritray-continuous-sub-matrix"},{"type":"extras","title":"Interact with Nx.Tensor - Evision Quick Start","doc":"","ref":"cheatsheet.html#interact-with-nx-tensor"},{"type":"extras","title":"Convert to Nx.Tensor - Evision Quick Start","doc":"```elixir\niex> img = Evision.imread(\"image.png\")\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {1080, 1920, 3},\n  ref: #Reference<0.664400266.3733323795.187022>\n}\n\niex> t = Evision.Mat.to_nx(img)\n#Nx.Tensor \n```\n\nIt works the same for any `Evision.Mat`.\n\n```elixir\niex> mat = Evision.Mat.ones({2, 3, 4, 5}, :u8)\n%Evision.Mat{\n  channels: 1,\n  dims: 4,\n  type: {:u, 8},\n  raw_type: 0,\n  shape: {2, 3, 4, 5},\n  ref: #Reference<0.2233780127.1059454995.175627>\n}\niex> t = Evision.Mat.to_nx(mat)\n#Nx.Tensor \n```","ref":"cheatsheet.html#convert-to-nx-tensor"},{"type":"extras","title":"Convert From Nx.Tensor - Evision Quick Start","doc":"From abritray `Nx.Tensor`.\n\n```elixir\niex> t = Nx.iota({3, 5, 7}, type: :u8)\niex> Evision.Mat.from_nx(t)\n%Evision.Mat{\n  channels: 1,\n  dims: 4,\n  type: {:u, 8},\n  raw_type: 0,\n  shape: {2, 3, 4, 5},\n  ref: #Reference<0.2233780127.1059454995.175631>\n}\n```\nHowever, please note that type `:s64`, `:u32` and `:u64` are not supported by OpenCV. \n\nAnother thing to note is that, some OpenCV functions expect the input to be a \"valid 2D image\",\nin such cases, `Evision.Mat.from_nx_2d/1` should be used instead. Please see the cheat below.\n\n```elixir\niex> image_tensor = Nx.broadcast(Nx.tensor(0, type: :u8), {720, 1280, 3})\niex> Evision.Mat.from_nx_2d(image_tensor)\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {720, 1280, 3},\n  ref: #Reference<0.2233780127.1059454995.175632>\n}\n\n# compare the results\n# note the differences in `channels`, `dims` and `raw_type`\niex> Evision.Mat.from_nx(image_tensor)\n%Evision.Mat{\n  channels: 1,\n  dims: 3,\n  type: {:u, 8},\n  raw_type: 0,\n  shape: {720, 1280, 3},\n  ref: #Reference<0.2233780127.1059454995.175633>\n}\n```","ref":"cheatsheet.html#convert-from-nx-tensor"},{"type":"extras","title":"README","doc":"[![Hex.pm](https://img.shields.io/hexpm/v/evision.svg?style=flat&color=blue)](https://hex.pm/packages/evision)\n\n| OS               | Arch           | ABI  | Build Status | Has Precompiled Library |\n|------------------|----------------|------|--------------|-------------------------|\n| Linux            | x86_64         | gnu  |[![CI](https://github.com/cocoa-xu/evision/actions/workflows/linux-x86_64.yml/badge.svg)](https://github.com/cocoa-xu/evision/actions/workflows/linux-x86_64.yml) | Yes |\n| Linux            | x86_64         | musl |[![CI](https://github.com/cocoa-xu/evision/actions/workflows/linux-precompile-musl.yml/badge.svg)](https://github.com/cocoa-xu/evision/actions/workflows/linux-precompile-musl.yml) | Yes |\n| Linux            | aarch64        | gnu  |[![linux-precompile](https://github.com/cocoa-xu/evision/actions/workflows/linux-precompile-gnu.yml/badge.svg)](https://github.com/cocoa-xu/evision/actions/workflows/linux-precompile-gnu.yml) | Yes |\n| Linux            | aarch64        | musl |[![linux-precompile](https://github.com/cocoa-xu/evision/actions/workflows/linux-precompile-musl.yml/badge.svg)](https://github.com/cocoa-xu/evision/actions/workflows/linux-precompile-musl.yml) | Yes |\n| Linux            | armv6 (armhf)  | gnueabihf |[![linux-precompile](https://github.com/cocoa-xu/evision/actions/workflows/linux-precompile-gnu.yml/badge.svg)](https://github.com/cocoa-xu/evision/actions/workflows/linux-precompile-gnu.yml) | Yes |\n| Linux            | armv7l (armhf) | gnueabihf |[![linux-precompile](https://github.com/cocoa-xu/evision/actions/workflows/linux-precompile-gnu.yml/badge.svg)](https://github.com/cocoa-xu/evision/actions/workflows/linux-precompile-gnu.yml) | Yes |\n| Linux            | ppc64le        | gnu  |[![linux-precompile](https://github.com/cocoa-xu/evision/actions/workflows/linux-precompile-gnu.yml/badge.svg)](https://github.com/cocoa-xu/evision/actions/workflows/linux-precompile-gnu.yml) | Yes |\n| Linux            | s390x          | gnu  |[![linux-precompile](https://github.com/cocoa-xu/evision/actions/workflows/linux-precompile-gnu.yml/badge.svg)](https://github.com/cocoa-xu/evision/actions/workflows/linux-precompile-gnu.yml) | Yes |\n| Linux            | riscv64        | gnu  |[![linux-precompile](https://github.com/cocoa-xu/evision/actions/workflows/linux-precompile-gnu.yml/badge.svg)](https://github.com/cocoa-xu/evision/actions/workflows/linux-precompile-gnu.yml) | Yes |\n| Linux            | riscv64        | musl |[![linux-precompile](https://github.com/cocoa-xu/evision/actions/workflows/linux-precompile-musl.yml/badge.svg)](https://github.com/cocoa-xu/evision/actions/workflows/linux-precompile-musl.yml) | Yes |\n| macOS 12 Monterey | x86_64        | darwin |[![CI](https://github.com/cocoa-xu/evision/actions/workflows/macos-x86_64.yml/badge.svg)](https://github.com/cocoa-xu/evision/actions/workflows/macos-x86_64.yml) | Yes |\n| macOS 14 Sonoma  | aarch64       | darwin |[![macos-precompile](https://github.com/cocoa-xu/evision/actions/workflows/macos-precompile.yml/badge.svg)](https://github.com/cocoa-xu/evision/actions/workflows/macos-precompile.yml) | Yes |\n| Windows 2022     | x86_64         | msvc |[![CI](https://github.com/cocoa-xu/evision/actions/workflows/windows-x86_64.yml/badge.svg)](https://github.com/cocoa-xu/evision/actions/workflows/windows-x86_64.yml) | Yes |\n| Windows 2022     | aarch64        | msvc |[![CI](https://github.com/cocoa-xu/evision/actions/workflows/windows-x86_64.yml/badge.svg)](https://github.com/cocoa-xu/evision/actions/workflows/windows-precompile.yml) | Yes |","ref":"readme.html"},{"type":"extras","title":"Installation - README","doc":"In order to use `evision`, you will need Elixir installed. Then create an Elixir project via the `mix` build tool:\n\n```sh\n$ mix new my_app\n```\n\nThen you can add `evision` as a dependency in your `mix.exs`.\n\n```elixir\ndef deps do\n  [\n    {:evision, \"~> 0.2\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Use Precompiled Library (Default) - README","doc":"The following environment variables can be set based on your needs.\n\n(Note that precompiled binaries do not use FFmpeg. If you'd like to use FFmpeg, please compile from source (please see instructions in the next section) and set corresponding environment variables. We're considering this option at the moment.)\n\n \n\n Advanced Options \n\n#### TARGET_ABI\n**Required if and only if the target is using musl libc.**\n\n```shell\n# (for nerves project, this environment variable is set by nerves)\nexport TARGET_ABI=musl\n## (for armv7l which uses hard-float ABI (armhf))\nexport TARGET_ABI=musleabihf\n```\n\nThis variable will only be checked when identifying the musl libc ABI so that the correct precompiled binaries can be downloaded. Therefore, \n\n1. You don't need to keep it in the runtime environment.\n2. If you want to change it later, the directory `_build/${MIX_ENV}/lib/evision` needs to be deleted first.\n\nThe default value for the `TARGET_ABI` env var is obtained using the following elixir code\n\n```elixir\ntarget_abi = List.last(String.split(to_string(:erlang.system_info(:system_architecture)), \"-\"))\ntarget_abi =\n  case target_abi do\n    \"darwin\" <> _ -> \"darwin\"\n    \"win32\" ->\n      {compiler_id, _} = :erlang.system_info(:c_compiler_used)\n      case compiler_id do\n        :msc -> \"msvc\"\n        _ -> to_string(compiler_id)\n      end\n    _ -> target_abi\n  end\n```\n\n#### EVISION_PREFER_PRECOMPILED\n```shell\n# optional. \n# set this to \"false\" if you prefer :evision to be compiled from source\n# \n# default value is \"true\", and :evision will prefer to use precompiled binaries (if available)\nexport EVISION_PREFER_PRECOMPILED=false\n```\n\nThis variable will only be checked whenever the `mix compile` task is invoked directly (`mix compile`) or indirectly (`mix test`). And in the Makefile we would skip everything if `_build/${MIX_ENV}/lib/evision/priv/evision.so` is presented. Therefore,\n\n1. You don't need to keep it in the runtime environment.\n2. If you want to change it later, the directory `_build/${MIX_ENV}/lib/evision` needs to be deleted first.\n\n**If you found the precompiled binaries do not suit your needs (e.g., perhaps you need OpenCV to be compiled with FFmpeg to handle more video formats.), it's possible to override the behaviour by setting the environment variable `EVISION_PREFER_PRECOMPILED` to `false`, and then please delete `_build/${MIX_ENV}/lib/evision` and recompile evision**\n\n**Also, for Linux users only, the precompiled binary is not compiled with GTK support, therefore functions like `Evision.HighGui.imshow/2` will not work. However, you can either use `Evision.Wx.imshow/2` (if Erlang on your system is compiled with `wxWidgets`), or set the environment variable `EVISION_PREFER_PRECOMPILED` to `false` so that OpenCV can detect available HighGui backend when compiling from source.**\n\n```shell\nexport EVISION_PREFER_PRECOMPILED=false\n```\n\nFor livebook users, \n```elixir\nMix.install([\n  {:evision, \"~> 0.2\"}\n], system_env: [\n  {\"EVISION_PREFER_PRECOMPILED\", \"false\"}\n])\n```\n\n#### EVISION_ENABLE_CONTRIB\nSet environment variable `EVISION_ENABLE_CONTRIB` to `true` to enable modules from [opencv_contrib](https://github.com/opencv/opencv_contrib).\n\n```bash\n# enable opencv_contrib modules (default)\nexport EVISION_ENABLE_CONTRIB=true\n\n# disable opencv_contrib modules\nexport EVISION_ENABLE_CONTRIB=false\n```\n\nThis variable will only be checked whenever the `mix compile` task is invoked directly (`mix compile`) or indirectly (`mix test`). And in the Makefile we would skip everything if `_build/${MIX_ENV}/lib/evision/priv/evision.so` is presented. Therefore,\n\n1. You don't need to keep it in the runtime environment.\n2. If you want to change it later from `false` to `true`, you can delete the file `_build/${MIX_ENV}/lib/evision/priv/evision.so`, set `EVISION_ENABLE_CONTRIB` to `true`, and then execute `mix compile`.\n\nDefaults to `true` because for precompiled binaries, including these \"extra\" modules only increases less than 20 MBs (tested on `aarch64-apple-darwin`) in size.\n\nHowever, 20 MBs for Nerves users can be a huge deal (still depending on your device, for example, +20 MBs is often much more acceptable for RPIs as they are usually equipped with >= 8 GB microSD cards while being absolutely a luxury thing for some other embedded devices).\n\n#### EVISION_ENABLE_CUDA\nSet environment variable `EVISION_ENABLE_CONTRIB` to `true` to enable CUDA support from [opencv_contrib](https://github.com/opencv/opencv_contrib). Defaults to `false`.\n\nNote that `EVISION_ENABLE_CONTRIB` will need to be `true` as well.\n\n```bash\n# enable CUDA support\nexport EVISION_ENABLE_CUDA=true","ref":"readme.html#use-precompiled-library-default"},{"type":"extras","title":"set a CUDA version that matches your local CUDA driver - README","doc":"## (this environment variable is only required for users who'd like to use precompiled binaries)","ref":"readme.html#set-a-cuda-version-that-matches-your-local-cuda-driver"},{"type":"extras","title":"available ones are - README","doc":"","ref":"readme.html#available-ones-are"},{"type":"extras","title":"11, for CUDA 11.x, built with CUDA 11.8.0 - README","doc":"","ref":"readme.html#11-for-cuda-11-x-built-with-cuda-11-8-0"},{"type":"extras","title":"12, for CUDA 12.x, built with CUDA 12.5.0 - README","doc":"export EVISION_CUDA_VERSION=11","ref":"readme.html#12-for-cuda-12-x-built-with-cuda-12-5-0"},{"type":"extras","title":"set a CUDNN version that matches your local CUDNN shared library - README","doc":"## (this environment variable is only required for users who'd like to use precompiled binaries)","ref":"readme.html#set-a-cudnn-version-that-matches-your-local-cudnn-shared-library"},{"type":"extras","title":"available ones are - README","doc":"","ref":"readme.html#available-ones-are"},{"type":"extras","title":"8, for CUDA 11.x or 12.x, built with CUDNN 8.9.7 - README","doc":"","ref":"readme.html#8-for-cuda-11-x-or-12-x-built-with-cudnn-8-9-7"},{"type":"extras","title":"9, for CUDA 11.x or 12.x, built with CUDNN 9.2.0 - README","doc":"export EVISION_CUDNN_VERSION=9","ref":"readme.html#9-for-cuda-11-x-or-12-x-built-with-cudnn-9-2-0"},{"type":"extras","title":"opencv_contrib modules is enabled by default - README","doc":"export EVISION_ENABLE_CONTRIB=true\n\n# disable CUDA support (default) \nexport EVISION_ENABLE_CUDA=false\n```\n\n##### IMPORTANT NOTE FOR WINDOWS USERS\nIf `EVISION_ENABLE_CUDA` is `true`, please also set CUDA runtime dir otherwise `Evision` will fail to load.\n\n###### cmd\n```cmd\nset EVISION_CUDA_RUNTIME_DIR=C:/PATH/TO/YOUR/CUDA/RUNTIME/BIN\n```\n\nAlso, please don't quote even if there are spaces in the path\n\n```cmd\nset EVISION_CUDA_RUNTIME_DIR=C:/PATH WITH SPACE/TO/YOUR/CUDA/RUNTIME/BIN\n```\n\n###### Powershell\n```pwsh\n$Env:EVISION_CUDA_RUNTIME_DIR=\"C:/PATH/TO/YOUR/CUDA/RUNTIME/BIN\"\n$Env:EVISION_CUDA_RUNTIME_DIR=\"C:/PATH WITH SPACE/TO/YOUR/CUDA/RUNTIME/BIN\"\n```\n\n#### EVISION_PRECOMPILED_CACHE_DIR\n```shell\n# optional.","ref":"readme.html#opencv_contrib-modules-is-enabled-by-default"},{"type":"extras","title":"set the cache directory for the precompiled archive file - README","doc":"export EVISION_PRECOMPILED_CACHE_DIR=\"$(pwd)/.cache\"\n```","ref":"readme.html#set-the-cache-directory-for-the-precompiled-archive-file"},{"type":"extras","title":"Examples - README","doc":"Some [examples](https://github.com/cocoa-xu/evision/tree/main/examples) are available in the `examples` directory.","ref":"readme.html#examples"},{"type":"extras","title":"Description - README","doc":"`evision` will pull OpenCV source code from GitHub, then parse and automatically generate corresponding OpenCV-Elixir bindings.\n\nThis project uses and modifies `gen2.py` and `hdr_parser.py` from the `python` module in the [OpenCV repo](https://github.com/opencv/opencv) so that they output header files that can be used in Elixir bindings. \n\nWe hope this project can largely reduce the work of manually porting OpenCV functions/modules to Elixir.\n\nCompatible OpenCV versions:\n- 4.5.3\n- 4.5.4\n- 4.5.5\n- 4.6.0\n- 4.7.0\n- 4.8.0\n- 4.9.0\n- 4.10.0\n\nby compatible, it means these versions can compile successfully, and I tested a small range of functions. Tons of tests\nshould be written, and then we can have a list for tested OpenCV versions.","ref":"readme.html#description"},{"type":"extras","title":"Docs - README","doc":"Online docs for the latest released version is available on Hex.pm, [https://hexdocs.pm/evision/](https://hexdocs.pm/evision/).","ref":"readme.html#docs"},{"type":"extras","title":"Useful links - README","doc":"- [Installation](https://github.com/cocoa-xu/evision?tab=readme-ov-file#installation)\n- [Use Precompiled Library (Default)](https://github.com/cocoa-xu/evision?tab=readme-ov-file#use-precompiled-library-default)\n- [Compile evision from source](https://github.com/cocoa-xu/evision/wiki/Compile-evision-from-source)\n- [Nerves Support](https://github.com/cocoa-xu/evision/wiki/Nerves-Support)\n- [Register Builtin Smart Cells](https://github.com/cocoa-xu/evision/wiki/Register-Builtin-Smart-Cells)\n- [Integration with Nx](https://github.com/cocoa-xu/evision/wiki/Integration-with-Nx)\n- [Access behaviour (Getting a sub-area of an image)](https://github.com/cocoa-xu/evision/wiki/Access-behaviour-(Getting-a-sub%E2%80%90area-of-an-image))","ref":"readme.html#useful-links"},{"type":"extras","title":"Acknowledgements - README","doc":"- `gen2.py`, `hdr_parser.py`, and `c_src/erlcompat.hpp` were directly copied from the `python` module in the [OpenCV repo](https://github.com/opencv/opencv). Changes applied.\n- `Makefile`, `CMakeLists.txt`, and `c_src/nif_utils.hpp` were also copied from the `torchx` module in the [elixir-nx repo](https://github.com/elixir-nx/nx). Minor changes applied.","ref":"readme.html#acknowledgements"},{"type":"extras","title":"Evision Example - Get Started with Some Basic Functions","doc":"<!-- vim: syntax=markdown -->\n\n<!-- livebook:{\"persist_outputs\":true} -->\n\n# Evision Example - Get Started with Some Basic Functions\n\n```elixir\nMix.install([\n  {:evision, \"~> 0.2\"},\n  {:kino, \"~> 0.7\"},\n  {:req, \"~> 0.3\"}\n], system_env: [\n  # optional, defaults to `true`\n  # set `EVISION_PREFER_PRECOMPILED` to `false`\n  # if you prefer `:evision` to be compiled from source\n  # note that to compile from source, you may need at least 1GB RAM\n  {\"EVISION_PREFER_PRECOMPILED\", true},\n\n  # optional, defaults to `true`\n  # set `EVISION_ENABLE_CONTRIB` to `false`\n  # if you don't need modules from `opencv_contrib`\n  {\"EVISION_ENABLE_CONTRIB\", true},\n\n  # optional, defaults to `false`\n  # set `EVISION_ENABLE_CUDA` to `true`\n  # if you wish to use CUDA related functions\n  # note that `EVISION_ENABLE_CONTRIB` also has to be `true`\n  # because cuda related modules come from the `opencv_contrib` repo\n  {\"EVISION_ENABLE_CUDA\", false},\n\n  # required when\n  # - `EVISION_ENABLE_CUDA` is `true`\n  # - and `EVISION_PREFER_PRECOMPILED` is `true`\n  #\n  # set `EVISION_CUDA_VERSION` to the version that matches\n  # your local CUDA runtime version\n  #\n  # current available versions are\n  # - 118\n  # - 121\n  {\"EVISION_CUDA_VERSION\", \"118\"},\n\n  # require for Windows users when\n  # - `EVISION_ENABLE_CUDA` is `true`\n  # set `EVISION_CUDA_RUNTIME_DIR` to the directory that contains\n  # CUDA runtime libraries\n  {\"EVISION_CUDA_RUNTIME_DIR\", \"C:/PATH/TO/CUDA/RUNTIME\"}\n])\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```","ref":"getting_started.html"},{"type":"extras","title":"Define Some Helper Functions - Evision Example - Get Started with Some Basic Functions","doc":"```elixir\ndefmodule Helper do\n  def download!(url, save_as, overwrite? \\\\ false) do\n    unless File.exists?(save_as) do\n      Req.get!(url, http_errors: :raise, output: save_as, cache: not overwrite?)\n    end\n\n    :ok\n  end\nend\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n{:module, Helper, <<70, 79, 82, 49, 0, 0, 10, ...>>, {:download!, 3}}\n```","ref":"getting_started.html#define-some-helper-functions"},{"type":"extras","title":"Read an Image From File - Evision Example - Get Started with Some Basic Functions","doc":"```elixir\nalias Evision, as: Cv\n\n# Download the test image\nlenna_test_image_path = Path.join(__DIR__, \"lenna_test_image.png\")\nHelper.download!(\n  \"https://upload.wikimedia.org/wikipedia/en/7/7d/Lenna_%28test_image%29.png\",\n  lenna_test_image_path\n)\n\n# Read the test image\nmat = Cv.imread(lenna_test_image_path)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {512, 512, 3},\n  ref: #Reference<0.2845725607.2514092053.18350>\n}\n```","ref":"getting_started.html#read-an-image-from-file"},{"type":"extras","title":"Encode an Image - Evision Example - Get Started with Some Basic Functions","doc":"```elixir\nencoded = Cv.imencode(\".png\", mat)\nKino.Image.new(encoded, :png)\n```","ref":"getting_started.html#encode-an-image"},{"type":"extras","title":"Resize an Image - Evision Example - Get Started with Some Basic Functions","doc":"```elixir\nresized_mat = Cv.resize(mat, {_width = 256, _height = 128})\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {128, 256, 3},\n  ref: #Reference<0.2845725607.2514092052.18171>\n}\n```\n\n```elixir\nencoded = Cv.imencode(\".png\", resized_mat)\nKino.Image.new(encoded, :png)\n```","ref":"getting_started.html#resize-an-image"},{"type":"extras","title":"Get a Subarea in an Image - Evision Example - Get Started with Some Basic Functions","doc":"`Evision.Mat.roi`\n\n```elixir\nCv.imencode(\".png\", Cv.Mat.roi(mat, {10, 10, 130, 200}))\n|> Kino.Image.new(:png)\n```","ref":"getting_started.html#get-a-subarea-in-an-image"},{"type":"extras","title":"Encode and Decode Image in Memory - Evision Example - Get Started with Some Basic Functions","doc":"```elixir\n# encode in memory\nencoded_in_memory = Cv.imencode(\".png\", resized_mat)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n<<137, 80, 78, 71, 13, 10, 26, 10, 0, 0, 0, 13, 73, 72, 68, 82, 0, 0, 1, 0, 0, 0, 0, 128, 8, 2, 0,\n  0, 0, 107, 215, 32, 93, 0, 0, 32, 0, 73, 68, 65, 84, 120, 1, 20, 193, 93, 175, 110, 105, 118,\n  ...>>\n```\n\n```elixir\n# decode in memory\ndecoded_mat = Cv.imdecode(encoded_in_memory, Cv.Constant.cv_IMREAD_ANYCOLOR())\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {128, 256, 3},\n  ref: #Reference<0.2845725607.2514092052.18187>\n}\n```","ref":"getting_started.html#encode-and-decode-image-in-memory"},{"type":"extras","title":"Read an PNG File With/Without Alpha Channel - Evision Example - Get Started with Some Basic Functions","doc":"```elixir\n# download the test image (has alpha channel)\ndownload_path = Path.join(__DIR__, \"test.png\")\nHelper.download!(\"https://github.com/cocoa-xu/evision/raw/main/test/testdata/test.png\", download_path)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```\n\n```elixir\nwithout_alpha = Cv.imread(download_path)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {2, 3, 3},\n  ref: #Reference<0.2845725607.2514092053.18729>\n}\n```\n\n```elixir\nCv.imread(download_path, flags: Cv.Constant.cv_IMREAD_UNCHANGED())\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 4,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 24,\n  shape: {2, 3, 4},\n  ref: #Reference<0.2845725607.2514092053.18730>\n}\n```","ref":"getting_started.html#read-an-png-file-with-without-alpha-channel"},{"type":"extras","title":"Read an Image and Convert It to Grayscale in a Single Call - Evision Example - Get Started with Some Basic Functions","doc":"```elixir\ngray_scale_mat = Cv.imread(lenna_test_image_path, flags: Cv.Constant.cv_IMREAD_GRAYSCALE())\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 1,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 0,\n  shape: {512, 512},\n  ref: #Reference<0.2845725607.2514092053.18731>\n}\n```\n\n```elixir\ngray_scale = Cv.imencode(\".png\", gray_scale_mat)\nKino.Image.new(gray_scale, :png)\n```","ref":"getting_started.html#read-an-image-and-convert-it-to-grayscale-in-a-single-call"},{"type":"extras","title":"Evision Example - QRCode Encoding and Decoding","doc":"<!-- vim: syntax=markdown -->\n\n<!-- livebook:{\"persist_outputs\":true} -->\n\n# Evision Example - QRCode Encoding and Decoding\n\n```elixir\nMix.install([\n  {:evision, \"~> 0.2\"},\n  {:kino, \"~> 0.7\"},\n  {:req, \"~> 0.3\"}\n], system_env: [\n  # optional, defaults to `true`\n  # set `EVISION_PREFER_PRECOMPILED` to `false`\n  # if you prefer `:evision` to be compiled from source\n  # note that to compile from source, you may need at least 1GB RAM\n  {\"EVISION_PREFER_PRECOMPILED\", true},\n\n  # optional, defaults to `true`\n  # set `EVISION_ENABLE_CONTRIB` to `false`\n  # if you don't need modules from `opencv_contrib`\n  {\"EVISION_ENABLE_CONTRIB\", true},\n\n  # optional, defaults to `false`\n  # set `EVISION_ENABLE_CUDA` to `true`\n  # if you wish to use CUDA related functions\n  # note that `EVISION_ENABLE_CONTRIB` also has to be `true`\n  # because cuda related modules come from the `opencv_contrib` repo\n  {\"EVISION_ENABLE_CUDA\", false},\n\n  # required when \n  # - `EVISION_ENABLE_CUDA` is `true`\n  # - and `EVISION_PREFER_PRECOMPILED` is `true`\n  #\n  # set `EVISION_CUDA_VERSION` to the version that matches \n  # your local CUDA runtime version\n  #\n  # current available versions are\n  # - 118\n  # - 121\n  {\"EVISION_CUDA_VERSION\", \"118\"},\n\n  # require for Windows users when \n  # - `EVISION_ENABLE_CUDA` is `true`\n  # set `EVISION_CUDA_RUNTIME_DIR` to the directory that contains\n  # CUDA runtime libraries\n  {\"EVISION_CUDA_RUNTIME_DIR\", \"C:/PATH/TO/CUDA/RUNTIME\"}\n])\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```","ref":"qrcode.html"},{"type":"extras","title":"Encode A String to QRCode - Evision Example - QRCode Encoding and Decoding","doc":"```elixir\n# let's encode this example string\nstring_to_encode = \"This is a string!\"\n\n# the result image will be in minimal possible size\n# which is what it should be to avoid unnecessary memory allocations\n# because it would be easier to let the user to resize the result image\n# (most of the time we need to resize it to fit our needs anyway, this saves one call to resize)\n%Evision.Mat{} =\n  minimal_qrcode = Evision.QRCodeEncoder.encode(Evision.QRCodeEncoder.create(), string_to_encode)\n\n# for this example, we can resize it to 300x300\nqrcode = Evision.resize(minimal_qrcode, {300, 300}, interpolation: Evision.Constant.cv_INTER_AREA())\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 1,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 0,\n  shape: {300, 300},\n  ref: #Reference<0.2207498009.3335389204.191169>\n}\n```","ref":"qrcode.html#encode-a-string-to-qrcode"},{"type":"extras","title":"Read the String Back From the Encoded QRCode - Evision Example - QRCode Encoding and Decoding","doc":"```elixir\n{decoded_string, points, straight_qrcode} =\n  Evision.QRCodeDetector.detectAndDecode(Evision.QRCodeDetector.qrCodeDetector(), qrcode)\n\ndecoded_string\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n\"This is a string!\"\n```","ref":"qrcode.html#read-the-string-back-from-the-encoded-qrcode"},{"type":"extras","title":"The Second Value In the Returned Tuple - Evision Example - QRCode Encoding and Decoding","doc":"```elixir\n# `points` is the keypoints for the QRCode\n# the shape would be {1, 4, 2}, in which:\n#  - 1: number of QRCode\n#  - 4: always 4, 4 keypoints: top_left, bottom_left, bottom_right, top_right\n#  - 2: always 2, (x, y)\npoints = Evision.Mat.to_nx(points, Nx.BinaryBackend)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n#Nx.Tensor \n```\n\n```elixir\n# here we take the first QRCode's keypoints\nkeypoints = Nx.as_type(points[0], :s32)\n\n{top_left, bottom_right} = {\n  List.to_tuple(Nx.to_flat_list(keypoints[0])),\n  List.to_tuple(Nx.to_flat_list(keypoints[2]))\n}\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n{{24, 24}, {275, 275}}\n```\n\n```elixir\n{{row_start, col_start}, {row_end, col_end}} = {top_left, bottom_right}\nqrcode[[col_start..col_end, row_start..row_end]]\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 1,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 0,\n  shape: {252, 252},\n  ref: #Reference<0.2207498009.3335389204.191179>\n}\n```","ref":"qrcode.html#the-second-value-in-the-returned-tuple"},{"type":"extras","title":"The Third Value In the Returned Tuple - Evision Example - QRCode Encoding and Decoding","doc":"```elixir\n# the third value is `straight_qrcode`, which is the minimal possible image\n# for the QRCode\nEvision.resize(straight_qrcode, {300, 300}, interpolation: Evision.Constant.cv_INTER_AREA())\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 1,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 0,\n  shape: {300, 300},\n  ref: #Reference<0.2207498009.3335389204.191182>\n}\n```","ref":"qrcode.html#the-third-value-in-the-returned-tuple"},{"type":"extras","title":"Evision Example - Warp Perspective","doc":"# Evision Example - Warp Perspective\n\n```elixir\nMix.install(\n  [\n    {:evision, \"~> 0.1.31\"},\n    {:kino, \"~> 0.9.0\"},\n    {:req, \"~> 0.3.0\"}\n  ],\n  system_env: [\n    # optional, defaults to `true`\n    # set `EVISION_PREFER_PRECOMPILED` to `false`\n    # if you prefer `:evision` to be compiled from source\n    # note that to compile from source, you may need at least 1GB RAM\n    {\"EVISION_PREFER_PRECOMPILED\", true},\n\n    # optional, defaults to `true`\n    # set `EVISION_ENABLE_CONTRIB` to `false`\n    # if you don't need modules from `opencv_contrib`\n    {\"EVISION_ENABLE_CONTRIB\", true},\n\n    # optional, defaults to `false`\n    # set `EVISION_ENABLE_CUDA` to `true`\n    # if you wish to use CUDA related functions\n    # note that `EVISION_ENABLE_CONTRIB` also has to be `true`\n    # because cuda related modules come from the `opencv_contrib` repo\n    {\"EVISION_ENABLE_CUDA\", false},\n\n    # required when\n    # - `EVISION_ENABLE_CUDA` is `true`\n    # - and `EVISION_PREFER_PRECOMPILED` is `true`\n    #\n    # set `EVISION_CUDA_VERSION` to the version that matches\n    # your local CUDA runtime version\n    #\n    # current available versions are\n    # - 111\n    # - 114\n    # - 118\n    {\"EVISION_CUDA_VERSION\", \"118\"},\n\n    # require for Windows users when\n    # - `EVISION_ENABLE_CUDA` is `true`\n    # set `EVISION_CUDA_RUNTIME_DIR` to the directory that contains\n    # CUDA runtime libraries\n    {\"EVISION_CUDA_RUNTIME_DIR\", \"C:/PATH/TO/CUDA/RUNTIME\"}\n  ]\n)\n```","ref":"warp_perspective.html"},{"type":"extras","title":"Introduction - Evision Example - Warp Perspective","doc":"This notebook will demonstrate how to perform [perspective transformation](https://en.wikipedia.org/wiki/3D_projection#Perspective_projection).\n\nIt's useful to alias the module as something shorter when we make extensive use of the functions from certain modules.\n\n```elixir\nalias Evision, as: Cv\n```","ref":"warp_perspective.html#introduction"},{"type":"extras","title":"Define Some Helper Functions - Evision Example - Warp Perspective","doc":"Let's prepare helper functions for preparing resources.\n\n```elixir\ndefmodule Helper do\n  def download!(url, overwrite \\\\ false) do\n    save_as = Path.join(System.tmp_dir!(), URI.encode_www_form(url))\n    unless File.exists?(save_as) || overwrite, do: Req.get!(url, output: save_as)\n    save_as\n  end\n\nend\n```","ref":"warp_perspective.html#define-some-helper-functions"},{"type":"extras","title":"Read the Test Image - Evision Example - Warp Perspective","doc":"```elixir\n# Read the test image\ntest_img_mat =\n  \"https://raw.githubusercontent.com/cocoa-xu/evision/main/test/testdata/warp_perspective.png\"\n  |> Helper.download!()\n  |> Cv.imread()\n```","ref":"warp_perspective.html#read-the-test-image"},{"type":"extras","title":"Function hypot: returns the Euclidean norm - Evision Example - Warp Perspective","doc":"This function calcululates the Euclidean norm, which is useful when we want to\nknow the length of a line segment between two points\n([Euclidean distance](https://en.wikipedia.org/wiki/Euclidean_distance)).\n\n```elixir\n# hypot.(list(number())) function returns the Euclidean norm\nhypot = fn l -> :math.sqrt(Enum.sum(Enum.map(l, fn i -> i * i end))) end\n```","ref":"warp_perspective.html#function-hypot-returns-the-euclidean-norm"},{"type":"extras","title":"Calculate the Output Coordinates for Corners - Evision Example - Warp Perspective","doc":"```elixir\n# specify input coordinates for corners of red quadrilateral\ntop_left = [136, 113]\ntop_right = [206, 130]\nbottom_right = [173, 207]\nbottom_left = [132, 196]\n\ninput_points = Nx.tensor([top_left, top_right, bottom_right, bottom_left], type: :f32)\n\n# get top and left dimensions and set to output dimensions of red rectangle\noutput_width =\n  hypot.([\n    Nx.to_number(Nx.subtract(input_points[[0, 0]], input_points[[1, 0]])),\n    Nx.to_number(Nx.subtract(input_points[[0, 1]], input_points[[1, 1]]))\n  ])\n  |> round()\n\noutput_height =\n  hypot.([\n    Nx.to_number(Nx.subtract(input_points[[0, 0]], input_points[[3, 0]])),\n    Nx.to_number(Nx.subtract(input_points[[0, 1]], input_points[[3, 1]]))\n  ])\n  |> round()\n\nIO.puts(\"width: #{output_width}, height: #{output_height}\")\n\n# set upper left coordinates for output rectangle\nx = Nx.to_number(input_points[[0, 0]])\ny = Nx.to_number(input_points[[0, 1]])\n\n# specify output coordinates for corners of red quadrilateral\ntop_left = [x, y]\ntop_right = [x + output_width - 1, y]\nbottom_right = [x + output_width - 1, y + output_height - 1]\nbottom_left = [x, y + output_height - 1]\n\noutput_points = Nx.tensor([top_left, top_right, bottom_right, bottom_left], type: :f32)\n```","ref":"warp_perspective.html#calculate-the-output-coordinates-for-corners"},{"type":"extras","title":"Compute Perspective Matrix - Evision Example - Warp Perspective","doc":"```elixir\nperspective_matrix = Cv.getPerspectiveTransform(input_points, output_points)\nKino.Tree.new(perspective_matrix)\n```","ref":"warp_perspective.html#compute-perspective-matrix"},{"type":"extras","title":"Perspective Transformation - Evision Example - Warp Perspective","doc":"```elixir\n{img_height, img_width, _} = Cv.Mat.shape(test_img_mat)\n\n# do perspective transformation setting area outside input to black\n# Note that output size is the same as the input image size\noutput_img_mat =\n  Cv.warpPerspective(\n    test_img_mat,\n    perspective_matrix,\n    {img_width, img_height},\n    flags: Cv.Constant.cv_INTER_LINEAR(),\n    borderMode: Cv.Constant.cv_BORDER_CONSTANT(),\n    borderValue: {0, 0, 0}\n  )\n\n[\n  [\"Input image\", test_img_mat],\n  [\"Output image\", output_img_mat]\n]\n|> Enum.map(fn [label, img] ->\n  Kino.Layout.grid([img, Kino.Markdown.new(\"**#{label}**\")], boxed: true)\nend)\n|> Kino.Layout.grid(columns: 2)\n```","ref":"warp_perspective.html#perspective-transformation"},{"type":"extras","title":"Evision Example - Warp Polar and Reverse","doc":"<!-- livebook:{\"persist_outputs\":true} -->\n\n# Evision Example - Warp Polar and Reverse\n\n```elixir\nMix.install([\n  {:evision, \"~> 0.2\"},\n  {:kino, \"~> 0.7\"},\n  {:req, \"~> 0.3\"}\n], system_env: [\n  # optional, defaults to `true`\n  # set `EVISION_PREFER_PRECOMPILED` to `false`\n  # if you prefer `:evision` to be compiled from source\n  # note that to compile from source, you may need at least 1GB RAM\n  {\"EVISION_PREFER_PRECOMPILED\", true},\n\n  # optional, defaults to `true`\n  # set `EVISION_ENABLE_CONTRIB` to `false`\n  # if you don't need modules from `opencv_contrib`\n  {\"EVISION_ENABLE_CONTRIB\", true},\n\n  # optional, defaults to `false`\n  # set `EVISION_ENABLE_CUDA` to `true`\n  # if you wish to use CUDA related functions\n  # note that `EVISION_ENABLE_CONTRIB` also has to be `true`\n  # because cuda related modules come from the `opencv_contrib` repo\n  {\"EVISION_ENABLE_CUDA\", false},\n\n  # required when \n  # - `EVISION_ENABLE_CUDA` is `true`\n  # - and `EVISION_PREFER_PRECOMPILED` is `true`\n  #\n  # set `EVISION_CUDA_VERSION` to the version that matches \n  # your local CUDA runtime version\n  #\n  # current available versions are\n  # - 118\n  # - 121\n  {\"EVISION_CUDA_VERSION\", \"118\"},\n\n  # require for Windows users when \n  # - `EVISION_ENABLE_CUDA` is `true`\n  # set `EVISION_CUDA_RUNTIME_DIR` to the directory that contains\n  # CUDA runtime libraries\n  {\"EVISION_CUDA_RUNTIME_DIR\", \"C:/PATH/TO/CUDA/RUNTIME\"}\n])\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```","ref":"warp_polar.html"},{"type":"extras","title":"Define Some Helper Functions - Evision Example - Warp Polar and Reverse","doc":"```elixir\ndefmodule Helper do\n  def download!(url, save_as, overwrite? \\\\ false) do\n    unless File.exists?(save_as) do\n      Req.get!(url, http_errors: :raise, output: save_as, cache: not overwrite?)\n    end\n\n    :ok\n  end\nend\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n{:module, Helper, <<70, 79, 82, 49, 0, 0, 10, ...>>, {:download!, 3}}\n```","ref":"warp_polar.html#define-some-helper-functions"},{"type":"extras","title":"Load the Test Image - Evision Example - Warp Polar and Reverse","doc":"```elixir\ntest_image_path = Path.join(__DIR__, \"warp_polar.png\")\n\nHelper.download!(\n  \"https://raw.githubusercontent.com/cocoa-xu/evision/main/test/testdata/warp_polar.png\",\n  test_image_path\n)\n\n# Read the test image\n%Evision.Mat{shape: {rows, cols, 3}} = src = Evision.imread(test_image_path)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {412, 561, 3},\n  ref: #Reference<0.1535381621.3478519834.195361>\n}\n```\n\nThe centre point (relative to the source image) of the circle locates at `{x=224, y=206}`.\n\nOf course, you might ask *\"how do we find the centre of that circle by code\"* or maybe first you wanna ask *\"how do we detect if there is any circle in any given image\"*. And these questions fall outside the scope of this livebook, and there are really plenty of ways to do it.","ref":"warp_polar.html#load-the-test-image"},{"type":"extras","title":"Max Radius - Evision Example - Warp Polar and Reverse","doc":"`max_radius` decides the bounding circle. If some part of the bounding circle is outside the range of the source image, then we need to ask OpenCV to fill these outliners by adding another flag `Evision.Constant.cv_WARP_FILL_OUTLIERS()`.\n\nWe can first plot the bounding circle for some visualisation.\n\n```elixir\ncentre = {x = 224, y = 206}\nmax_radius = 0.93 * min(x, y)\nred_color = {0, 0, 255}\n\n# convert max_radius to an integer \n# because Evision.circle expects an integer input for the\n# radius parameter\nint_max_radius = trunc(max_radius)\n\nEvision.circle(src, centre, int_max_radius, red_color, thickness: 2)\n\n# please click the \"Image\" tab in the output below to see the visualised result\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {412, 561, 3},\n  ref: #Reference<0.1535381621.3478519828.194184>\n}\n```\n\nThe processed image will look like this:\n\n```elixir\nEvision.warpPolar(\n  src,\n  {0, 0},\n  centre,\n  int_max_radius,\n  Evision.Constant.cv_INTER_LINEAR() + Evision.Constant.cv_WARP_FILL_OUTLIERS()\n)\n\n# please click the \"Image\" tab in the output below to see the visualised result\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {600, 191, 3},\n  ref: #Reference<0.1535381621.3478519828.194187>\n}\n```\n\nif the max radius is too large, then we will have some outliners, as you can see that the red circle (in the output below) is not entirely inside the source image\n\n```elixir\nint_max_radius = trunc(1.2 * min(x, y))\n\nEvision.circle(src, centre, int_max_radius, red_color, thickness: 2)\n\n# please click the \"Image\" tab in the output below to see the visualised result\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {412, 561, 3},\n  ref: #Reference<0.1535381621.3478519828.194190>\n}\n```\n\nAnd in such cases, OpenCV will have to fill outliners (in this example, filled outliners reside in the black areas on the right hand side of the output image)\n\n```elixir\nEvision.warpPolar(\n  src,\n  {0, 0},\n  centre,\n  int_max_radius,\n  Evision.Constant.cv_INTER_LINEAR() + Evision.Constant.cv_WARP_FILL_OUTLIERS()\n)\n\n# please click the \"Image\" tab in the output below to see the visualised result\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {776, 247, 3},\n  ref: #Reference<0.1535381621.3478519828.194193>\n}\n```","ref":"warp_polar.html#max-radius"},{"type":"extras","title":"dsize - Evision Example - Warp Polar and Reverse","doc":"The next thing is `dsize={width, height}`, and there are three options:\n\n* if both values in `dsize <=0` (default), the destination image will have (almost) same area of source bounding circle\n\n  $\\begin{array}{l} dsize.area \\leftarrow (maxRadius^2 \\cdot \\Pi) \\\\ dsize.width = \\texttt{round}(maxRadius) \\\\ dsize.height = \\texttt{round}(maxRadius \\cdot \\Pi) \\\\ \\end{array}$\n\n* if only `dsize.height <= 0`, the destination image area will be proportional to the bounding circle area but scaled by `Kx * Kx`:\n\n  $\\begin{array}{l} dsize.height = \\texttt{round}(dsize.width \\cdot \\Pi) \\\\ \\end{array}$\n\n* if both values in `dsize > 0`, the destination image will have the given size therefore the area of the bounding circle will be scaled to `dsize`.\n\n<!-- livebook:{\"break_markdown\":true} -->\n\n#### dsize - option 1\n\nWe can first try `dsize={0, 0}`.\n\n```elixir\ndsize = {0, 0}\nmax_radius = 0.93 * min(x, y)\n\nEvision.warpPolar(\n  src,\n  dsize,\n  centre,\n  max_radius,\n  Evision.Constant.cv_INTER_LINEAR() + Evision.Constant.cv_WARP_FILL_OUTLIERS()\n)\n\n# please click the \"Image\" tab in the output below to see the visualised result\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {602, 192, 3},\n  ref: #Reference<0.1535381621.3478519828.194205>\n}\n```\n\nLooks good. What about `dsize = {240, 800}`\n\n<!-- livebook:{\"break_markdown\":true} -->\n\n#### dsize - option 2\n\nonly `dsize.height <= 0`\n\n```elixir\ndsize = {150, -1}\nmax_radius = 0.93 * min(x, y)\n\nEvision.warpPolar(\n  src,\n  dsize,\n  centre,\n  max_radius,\n  Evision.Constant.cv_INTER_LINEAR() + Evision.Constant.cv_WARP_FILL_OUTLIERS()\n)\n\n# please click the \"Image\" tab in the output below to see the visualised result\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {471, 150, 3},\n  ref: #Reference<0.1535381621.3478519828.194208>\n}\n```\n\n#### dsize - option 3\n\nboth values in `dsize > 0`\n\n```elixir\ndsize = {240, 400}\nmax_radius = 0.93 * min(x, y)\n\nEvision.warpPolar(\n  src,\n  dsize,\n  centre,\n  max_radius,\n  Evision.Constant.cv_INTER_LINEAR() + Evision.Constant.cv_WARP_FILL_OUTLIERS()\n)\n\n# please click the \"Image\" tab in the output below to see the visualised result\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {400, 240, 3},\n  ref: #Reference<0.1535381621.3478519828.194211>\n}\n```","ref":"warp_polar.html#dsize"},{"type":"extras","title":"Remaps to Semilog-Polar Coordinates Space - Evision Example - Warp Polar and Reverse","doc":"```elixir\ndsize = {0, 0}\nmax_radius = 0.93 * min(x, y)\n\nlog_polar_img =\n  Evision.warpPolar(\n    src,\n    dsize,\n    centre,\n    max_radius,\n    Evision.Constant.cv_INTER_LINEAR() + Evision.Constant.cv_WARP_FILL_OUTLIERS() + Evision.Constant.cv_WARP_POLAR_LOG()\n  )\n\n# please click the \"Image\" tab in the output below to see the visualised result\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {602, 192, 3},\n  ref: #Reference<0.1535381621.3478519828.194229>\n}\n```","ref":"warp_polar.html#remaps-to-semilog-polar-coordinates-space"},{"type":"extras","title":"Reverse the Transformation - Evision Example - Warp Polar and Reverse","doc":"#### From Semilog-Polar Coordinates Space\n\n`log_polar_img` is the result image in the cell above.\n\n```elixir\nshape = Evision.Mat.shape(src)\ndsize = {elem(shape, 1), elem(shape, 0)}\n\nEvision.warpPolar(\n  log_polar_img,\n  dsize,\n  centre,\n  max_radius,\n  Evision.Constant.cv_INTER_LINEAR() + Evision.Constant.cv_WARP_FILL_OUTLIERS() +\n    Evision.Constant.cv_WARP_POLAR_LOG() + Evision.Constant.cv_WARP_INVERSE_MAP()\n)\n\n# please click the \"Image\" tab in the output below to see the visualised result\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {412, 561, 3},\n  ref: #Reference<0.1535381621.3478519828.194247>\n}\n```\n\n#### From Polar Coordinates Space\n\n```elixir\ndsize = {0, 0}\nmax_radius = 0.93 * min(x, y)\n\nlinear_polar_img =\n  Evision.warpPolar(\n    src,\n    dsize,\n    centre,\n    max_radius,\n    Evision.Constant.cv_INTER_LINEAR() + Evision.Constant.cv_WARP_FILL_OUTLIERS()\n  )\n\n# reverse the transformation\nshape = Evision.Mat.shape(src)\ndsize = {elem(shape, 1), elem(shape, 0)}\n\nEvision.warpPolar(\n  linear_polar_img,\n  dsize,\n  centre,\n  max_radius,\n  Evision.Constant.cv_INTER_LINEAR() + Evision.Constant.cv_WARP_FILL_OUTLIERS() +\n    Evision.Constant.cv_WARP_INVERSE_MAP()\n)\n\n# please click the \"Image\" tab in the output below to see the visualised result\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {412, 561, 3},\n  ref: #Reference<0.1535381621.3478519828.194251>\n}\n```","ref":"warp_polar.html#reverse-the-transformation"},{"type":"extras","title":"Find and Draw Contours in an Image","doc":"<!-- livebook:{\"persist_outputs\":true} -->\n\n# Find and Draw Contours in an Image\n\n```elixir\nMix.install([\n  {:evision, \"~> 0.2\"},\n  {:kino, \"~> 0.7\"},\n  {:req, \"~> 0.3\"}\n], system_env: [\n  # optional, defaults to `true`\n  # set `EVISION_PREFER_PRECOMPILED` to `false`\n  # if you prefer `:evision` to be compiled from source\n  # note that to compile from source, you may need at least 1GB RAM\n  {\"EVISION_PREFER_PRECOMPILED\", true},\n\n  # optional, defaults to `true`\n  # set `EVISION_ENABLE_CONTRIB` to `false`\n  # if you don't need modules from `opencv_contrib`\n  {\"EVISION_ENABLE_CONTRIB\", true},\n\n  # optional, defaults to `false`\n  # set `EVISION_ENABLE_CUDA` to `true`\n  # if you wish to use CUDA related functions\n  # note that `EVISION_ENABLE_CONTRIB` also has to be `true`\n  # because cuda related modules come from the `opencv_contrib` repo\n  {\"EVISION_ENABLE_CUDA\", false},\n\n  # required when \n  # - `EVISION_ENABLE_CUDA` is `true`\n  # - and `EVISION_PREFER_PRECOMPILED` is `true`\n  #\n  # set `EVISION_CUDA_VERSION` to the version that matches \n  # your local CUDA runtime version\n  #\n  # current available versions are\n  # - 118\n  # - 121\n  {\"EVISION_CUDA_VERSION\", \"118\"},\n\n  # require for Windows users when \n  # - `EVISION_ENABLE_CUDA` is `true`\n  # set `EVISION_CUDA_RUNTIME_DIR` to the directory that contains\n  # CUDA runtime libraries\n  {\"EVISION_CUDA_RUNTIME_DIR\", \"C:/PATH/TO/CUDA/RUNTIME\"}\n])\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```","ref":"find_and_draw_contours.html"},{"type":"extras","title":"Helper Function - Find and Draw Contours in an Image","doc":"```elixir\ndefmodule Helper do\n  def download!(url, save_as, overwrite? \\\\ false) do\n    unless File.exists?(save_as) do\n      Req.get!(url, http_errors: :raise, output: save_as, cache: not overwrite?)\n    end\n\n    :ok\n  end\nend\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n{:module, Helper, <<70, 79, 82, 49, 0, 0, 10, ...>>, {:download!, 3}}\n```\n\n```elixir\nHelper.download!(\"https://docs.opencv.org/4.x/pca_test1.jpg\", \"pca_test.jpg\")\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```","ref":"find_and_draw_contours.html#helper-function"},{"type":"extras","title":"Load Image As Gray Scale - Find and Draw Contours in an Image","doc":"```elixir\ngray = Evision.imread(\"pca_test.jpg\", flags: Evision.Constant.cv_IMREAD_GRAYSCALE())\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 1,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 0,\n  shape: {600, 800},\n  ref: #Reference<0.2172638371.2268463131.71223>\n}\n```","ref":"find_and_draw_contours.html#load-image-as-gray-scale"},{"type":"extras","title":"Get A Binary Image - Find and Draw Contours in an Image","doc":"```elixir\n# import Bitwise so that we can use `|||` (bitwise or)\nimport Bitwise\n\n# binarization\n{_, bw} =\n  Evision.threshold(gray, 50, 255, Evision.Constant.cv_THRESH_BINARY() ||| Evision.Constant.cv_THRESH_OTSU())\n\nbw\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 1,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 0,\n  shape: {600, 800},\n  ref: #Reference<0.2172638371.2268463122.70922>\n}\n```","ref":"find_and_draw_contours.html#get-a-binary-image"},{"type":"extras","title":"Find All Contours in the Binary Image - Find and Draw Contours in an Image","doc":"```elixir\n# Find all the contours in the thresholded image\n{contours, _} = Evision.findContours(bw, Evision.Constant.cv_RETR_LIST(), Evision.Constant.cv_CHAIN_APPROX_NONE())\n\nIO.puts(\"Find #{Enum.count(contours)} contour(s)\")\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\nFind 7 contour(s)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```","ref":"find_and_draw_contours.html#find-all-contours-in-the-binary-image"},{"type":"extras","title":"Ignore Contours That Are Too Small or Too Large - Find and Draw Contours in an Image","doc":"```elixir\nminimal_area = 100\nmaximal_area = 100_000\n\ncontours =\n  Enum.reject(contours, fn c ->\n    # Calculate the area of each contour\n    area = Evision.contourArea(c)\n    # Ignore contours that are too small or too large\n    # (return true to reject)\n    area   maximal_area\n  end)\n\nIO.puts(\"#{Enum.count(contours)} contour(s) remains\")\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n6 contour(s) remains\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```","ref":"find_and_draw_contours.html#ignore-contours-that-are-too-small-or-too-large"},{"type":"extras","title":"Draw All Contours - Find and Draw Contours in an Image","doc":"```elixir\n# color in {Blue, Green, Red}, range from 0-255\nedge_color = {0, 0, 255}\n\n# draw all contours by setting `index` to `-1`\nindex = -1\n\n# Load image in color\nsrc = Evision.imread(\"pca_test.jpg\")\n\n# draw all contours on the color image\nEvision.drawContours(src, contours, index, edge_color, thickness: 2)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {600, 800, 3},\n  ref: #Reference<0.2172638371.2268463122.70944>\n}\n```","ref":"find_and_draw_contours.html#draw-all-contours"},{"type":"extras","title":"Evision Example - Stitching Multiple Photos into A Panorama Photo","doc":"<!-- vim: syntax=markdown -->\n\n<!-- livebook:{\"persist_outputs\":true} -->\n\n# Evision Example - Stitching Multiple Photos into A Panorama Photo\n\n```elixir\nMix.install([\n  {:evision, \"~> 0.2\"},\n  {:kino, \"~> 0.7\"},\n  {:req, \"~> 0.3\"}\n], system_env: [\n  # optional, defaults to `true`\n  # set `EVISION_PREFER_PRECOMPILED` to `false`\n  # if you prefer `:evision` to be compiled from source\n  # note that to compile from source, you may need at least 1GB RAM\n  {\"EVISION_PREFER_PRECOMPILED\", true},\n\n  # optional, defaults to `true`\n  # set `EVISION_ENABLE_CONTRIB` to `false`\n  # if you don't need modules from `opencv_contrib`\n  {\"EVISION_ENABLE_CONTRIB\", true},\n\n  # optional, defaults to `false`\n  # set `EVISION_ENABLE_CUDA` to `true`\n  # if you wish to use CUDA related functions\n  # note that `EVISION_ENABLE_CONTRIB` also has to be `true`\n  # because cuda related modules come from the `opencv_contrib` repo\n  {\"EVISION_ENABLE_CUDA\", false},\n\n  # required when \n  # - `EVISION_ENABLE_CUDA` is `true`\n  # - and `EVISION_PREFER_PRECOMPILED` is `true`\n  #\n  # set `EVISION_CUDA_VERSION` to the version that matches \n  # your local CUDA runtime version\n  #\n  # current available versions are\n  # - 118\n  # - 121\n  {\"EVISION_CUDA_VERSION\", \"118\"},\n\n  # require for Windows users when \n  # - `EVISION_ENABLE_CUDA` is `true`\n  # set `EVISION_CUDA_RUNTIME_DIR` to the directory that contains\n  # CUDA runtime libraries\n  {\"EVISION_CUDA_RUNTIME_DIR\", \"C:/PATH/TO/CUDA/RUNTIME\"}\n])\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```","ref":"stitching.html"},{"type":"extras","title":"Define Some Helper Functions - Evision Example - Stitching Multiple Photos into A Panorama Photo","doc":"```elixir\ndefmodule Helper do\n  def download!(url, save_as, overwrite? \\\\ false) do\n    unless File.exists?(save_as) do\n      Req.get!(url, http_errors: :raise, output: save_as, cache: not overwrite?)\n    end\n\n    :ok\n  end\nend\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n{:module, Helper, <<70, 79, 82, 49, 0, 0, 10, ...>>, {:download!, 3}}\n```","ref":"stitching.html#define-some-helper-functions"},{"type":"extras","title":"Download Test Images - Evision Example - Stitching Multiple Photos into A Panorama Photo","doc":"```elixir\n# change to the file's directory\n# or somewhere you have write permission\nFile.cd!(__DIR__)\n\n# https://github.com/opencv/opencv_extra/tree/4.x/testdata/stitching\nHelper.download!(\n  \"https://raw.githubusercontent.com/opencv/opencv_extra/master/testdata/stitching/a1.png\",\n  \"a1.png\"\n)\n\nHelper.download!(\n  \"https://raw.githubusercontent.com/opencv/opencv_extra/master/testdata/stitching/a2.png\",\n  \"a2.png\"\n)\n\nHelper.download!(\n  \"https://raw.githubusercontent.com/opencv/opencv_extra/master/testdata/stitching/a3.png\",\n  \"a3.png\"\n)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```","ref":"stitching.html#download-test-images"},{"type":"extras","title":"Stitching - Evision Example - Stitching Multiple Photos into A Panorama Photo","doc":"```elixir\nalias Evision, as: Cv\n\na1 = Cv.imread(\"./a1.png\")\na2 = Cv.imread(\"./a2.png\")\na3 = Cv.imread(\"./a3.png\")\nsticher = Cv.Stitcher.create()\n{status_code, result} = Cv.Stitcher.stitch(sticher, [a1, a2, a3])\n0 = status_code\n# status_code should be 0 (OK),\n# for other status_code, please refer to https://github.com/opencv/opencv/blob/4.5.4/modules/stitching/include/opencv2/stitching.hpp#L152\n\nCv.imencode(\".png\", result)\n|> Kino.Image.new(:png)\n```","ref":"stitching.html#stitching"},{"type":"extras","title":"Evision Example - Principal Components Analysis","doc":"<!-- vim: syntax=markdown -->\n\n<!-- livebook:{\"persist_outputs\":true} -->\n\n# Evision Example - Principal Components Analysis\n\n```elixir\nMix.install([\n  {:evision, \"~> 0.2\"},\n  {:kino, \"~> 0.7\"},\n  {:req, \"~> 0.3\"}\n], system_env: [\n  # optional, defaults to `true`\n  # set `EVISION_PREFER_PRECOMPILED` to `false`\n  # if you prefer `:evision` to be compiled from source\n  # note that to compile from source, you may need at least 1GB RAM\n  {\"EVISION_PREFER_PRECOMPILED\", true},\n\n  # optional, defaults to `true`\n  # set `EVISION_ENABLE_CONTRIB` to `false`\n  # if you don't need modules from `opencv_contrib`\n  {\"EVISION_ENABLE_CONTRIB\", true},\n\n  # optional, defaults to `false`\n  # set `EVISION_ENABLE_CUDA` to `true`\n  # if you wish to use CUDA related functions\n  # note that `EVISION_ENABLE_CONTRIB` also has to be `true`\n  # because cuda related modules come from the `opencv_contrib` repo\n  {\"EVISION_ENABLE_CUDA\", false},\n\n  # required when\n  # - `EVISION_ENABLE_CUDA` is `true`\n  # - and `EVISION_PREFER_PRECOMPILED` is `true`\n  #\n  # set `EVISION_CUDA_VERSION` to the version that matches\n  # your local CUDA runtime version\n  #\n  # current available versions are\n  # - 118\n  # - 121\n  {\"EVISION_CUDA_VERSION\", \"118\"},\n\n  # require for Windows users when\n  # - `EVISION_ENABLE_CUDA` is `true`\n  # set `EVISION_CUDA_RUNTIME_DIR` to the directory that contains\n  # CUDA runtime libraries\n  {\"EVISION_CUDA_RUNTIME_DIR\", \"C:/PATH/TO/CUDA/RUNTIME\"}\n])\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```","ref":"pca.html"},{"type":"extras","title":"Helper Function - Evision Example - Principal Components Analysis","doc":"```elixir\ndefmodule Helper do\n  def download!(url, save_as, overwrite? \\\\ false) do\n    unless File.exists?(save_as) do\n      Req.get!(url, http_errors: :raise, output: save_as, cache: not overwrite?)\n    end\n\n    :ok\n  end\nend\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n{:module, Helper, <<70, 79, 82, 49, 0, 0, 10, ...>>, {:download!, 3}}\n```","ref":"pca.html#helper-function"},{"type":"extras","title":"alias - Evision Example - Principal Components Analysis","doc":"```elixir\nalias Evision, as: Cv\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\nEvision\n```","ref":"pca.html#alias"},{"type":"extras","title":"Download the test image - Evision Example - Principal Components Analysis","doc":"```elixir\nHelper.download!(\"https://docs.opencv.org/4.x/pca_test1.jpg\", \"pca_test.jpg\")\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```\n\n```elixir\nimport Bitwise\n\n# Load image in grayscale\ngray = Cv.imread(\"pca_test.jpg\", flags: Cv.Constant.cv_IMREAD_GRAYSCALE())\n\n# Convert image to binary\n{_, bw} = Cv.threshold(gray, 50, 255, Cv.Constant.cv_THRESH_BINARY() ||| Cv.Constant.cv_THRESH_OTSU())\n\n# Find all the contours in the thresholded image\n{contours, _} = Cv.findContours(bw, Cv.Constant.cv_RETR_LIST(), Cv.Constant.cv_CHAIN_APPROX_NONE())\n\ncontours =\n  contours\n  # Calculate the area of each contour\n  |> Enum.map(&{Cv.contourArea(&1), &1})\n  # Ignore contours that are too small or too large\n  |> Enum.reject(fn {area, _c} -> area < 100 or area > 100_000 end)\n\n# area\nEnum.map(contours, &elem(&1, 0))\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n[17192.0, 16830.0, 16150.5, 15367.5, 15571.0, 14842.0]\n```\n\nPCA analysis\n\n```elixir\ncontours = Enum.map(contours, &elem(&1, 1))\n\npca_analysis =\n  for c <- contours, reduce: [] do\n    acc ->\n      # Construct a buffer used by the pca analysis\n      %Evision.Mat{shape: shape, type: type} = c\n      sz = elem(shape, 0)\n      pts_binary = Cv.Mat.to_binary(c)\n      data_pts = Cv.Mat.from_binary(pts_binary, type, sz, 2, 1)\n      data_pts = Cv.Mat.as_type(data_pts, {:f, 64})\n\n      # Perform PCA analysis\n      {mean, eigenvectors, eigenvalues} = Cv.pcaCompute2(data_pts, Cv.Mat.empty())\n      eigenvectors = Cv.Mat.to_nx(eigenvectors, Nx.BinaryBackend)\n      eigenvalues = Cv.Mat.to_nx(eigenvalues, Nx.BinaryBackend)\n\n      # Store the center of the object\n      < > =\n        Cv.Mat.to_binary(mean)\n\n      centre_x = trunc(centre_x)\n      centre_y = trunc(centre_y)\n\n      # Store the eigenvalues and eigenvectors\n      eval00 = Nx.slice(eigenvalues, [0, 0], [1, 1]) |> Nx.to_flat_list() |> Enum.at(0)\n      eval10 = Nx.slice(eigenvalues, [1, 0], [1, 1]) |> Nx.to_flat_list() |> Enum.at(0)\n\n      evec00 = Nx.slice(eigenvectors, [0, 0], [1, 1]) |> Nx.to_flat_list() |> Enum.at(0)\n      evec01 = Nx.slice(eigenvectors, [0, 1], [1, 1]) |> Nx.to_flat_list() |> Enum.at(0)\n      evec10 = Nx.slice(eigenvectors, [1, 0], [1, 1]) |> Nx.to_flat_list() |> Enum.at(0)\n      evec11 = Nx.slice(eigenvectors, [1, 1], [1, 1]) |> Nx.to_flat_list() |> Enum.at(0)\n\n      # Calculate the principal components\n      p1 =\n        {trunc(Float.round(centre_x + 0.02 * evec00 * eval00)),\n         trunc(Float.round(centre_y + 0.02 * evec01 * eval00))}\n\n      p2 =\n        {trunc(Float.round(centre_x - 0.02 * evec10 * eval10)),\n         trunc(Float.round(centre_y - 0.02 * evec11 * eval10))}\n\n      cntr = {centre_x, centre_y}\n      [{cntr, p1, p2} | acc]\n  end\n\npca_analysis = Enum.reverse(pca_analysis)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n[\n  {{430, 407}, {691, 338}, {427, 397}},\n  {{439, 326}, {697, 264}, {437, 317}},\n  {{433, 239}, {683, 182}, {431, 230}},\n  {{420, 169}, {666, 127}, {419, 161}},\n  {{191, 291}, {176, 52}, {200, 290}},\n  {{407, 90}, {645, 49}, {406, 82}}\n]\n```","ref":"pca.html#download-the-test-image"},{"type":"extras","title":"visualisation - Evision Example - Principal Components Analysis","doc":"```elixir\nsrc = Cv.imread(\"pca_test.jpg\")\n\n# Draw each contour\nsrc =\n  for index <- 0..(Enum.count(contours) - 1), reduce: src do\n    src ->\n      Cv.drawContours(src, contours, index, {0, 0, 255}, thickness: 2)\n  end\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {600, 800, 3},\n  ref: #Reference<0.1624340523.638451732.91783>\n}\n```\n\nA helper function\n\n```elixir\ndefmodule PACHelper do\n  def drawAxis(src, {px, py}, {qx, qy}, colour, scale) do\n    angle = :math.atan2(py - qy, px - qx)\n    hypotenuse = :math.sqrt((py - qy) * (py - qy) + (px - qx) * (px - qx))\n    qx = trunc(px - scale * hypotenuse * :math.cos(angle))\n    qy = trunc(py - scale * hypotenuse * :math.sin(angle))\n    src = Cv.line(src, {px, py}, {qx, qy}, colour, thickness: 1, style: Cv.Constant.cv_LINE_AA())\n\n    px = trunc(qx + 9 * :math.cos(angle + :math.pi() / 4))\n    py = trunc(qy + 9 * :math.sin(angle + :math.pi() / 4))\n    src = Cv.line(src, {px, py}, {qx, qy}, colour, thickness: 1, style: Cv.Constant.cv_LINE_AA())\n\n    px = trunc(qx + 9 * :math.cos(angle - :math.pi() / 4))\n    py = trunc(qy + 9 * :math.sin(angle - :math.pi() / 4))\n    Cv.line(src, {px, py}, {qx, qy}, colour, thickness: 1, style: Cv.Constant.cv_LINE_AA())\n  end\nend\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n{:module, PACHelper, <<70, 79, 82, 49, 0, 0, 13, ...>>, {:drawAxis, 5}}\n```","ref":"pca.html#visualisation"},{"type":"extras","title":"Draw the principal components - Evision Example - Principal Components Analysis","doc":"```elixir\nsrc =\n  for {cntr, p1, p2} <- pca_analysis, reduce: src do\n    src ->\n      src = Cv.circle(src, cntr, 3, {255, 0, 255}, thickness: 2)\n      src = PACHelper.drawAxis(src, cntr, p1, {0, 255, 0}, 1)\n      PACHelper.drawAxis(src, cntr, p2, {255, 255, 0}, 5)\n  end\n\nresult = Cv.imencode(\".png\", src)\n\nKino.Image.new(result, :png)\n```","ref":"pca.html#draw-the-principal-components"},{"type":"extras","title":"Evision Example - High Dynamic Range Imaging","doc":"<!-- vim: syntax=markdown -->\n\n<!-- livebook:{\"persist_outputs\":true} -->\n\n# Evision Example - High Dynamic Range Imaging\n\n```elixir\nMix.install([\n  {:evision, \"~> 0.2\"},\n  {:kino, \"~> 0.7\"},\n  {:req, \"~> 0.3\"}\n], system_env: [\n  # optional, defaults to `true`\n  # set `EVISION_PREFER_PRECOMPILED` to `false`\n  # if you prefer `:evision` to be compiled from source\n  # note that to compile from source, you may need at least 1GB RAM\n  {\"EVISION_PREFER_PRECOMPILED\", true},\n\n  # optional, defaults to `true`\n  # set `EVISION_ENABLE_CONTRIB` to `false`\n  # if you don't need modules from `opencv_contrib`\n  {\"EVISION_ENABLE_CONTRIB\", true},\n\n  # optional, defaults to `false`\n  # set `EVISION_ENABLE_CUDA` to `true`\n  # if you wish to use CUDA related functions\n  # note that `EVISION_ENABLE_CONTRIB` also has to be `true`\n  # because cuda related modules come from the `opencv_contrib` repo\n  {\"EVISION_ENABLE_CUDA\", false},\n\n  # required when \n  # - `EVISION_ENABLE_CUDA` is `true`\n  # - and `EVISION_PREFER_PRECOMPILED` is `true`\n  #\n  # set `EVISION_CUDA_VERSION` to the version that matches \n  # your local CUDA runtime version\n  #\n  # current available versions are\n  # - 118\n  # - 121\n  {\"EVISION_CUDA_VERSION\", \"118\"},\n\n  # require for Windows users when \n  # - `EVISION_ENABLE_CUDA` is `true`\n  # set `EVISION_CUDA_RUNTIME_DIR` to the directory that contains\n  # CUDA runtime libraries\n  {\"EVISION_CUDA_RUNTIME_DIR\", \"C:/PATH/TO/CUDA/RUNTIME\"}\n])\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```","ref":"photo-hdr.html"},{"type":"extras","title":"Define Some Helper Functions - Evision Example - High Dynamic Range Imaging","doc":"```elixir\ndefmodule Helper do\n  def download!(url, save_as, overwrite? \\\\ false) do\n    unless File.exists?(save_as) do\n      Req.get!(url, http_errors: :raise, output: save_as, cache: not overwrite?)\n    end\n\n    :ok\n  end\n\n  @doc \"\"\"\n  This function chunks binary data by every requested `chunk_size`\n\n  To make it more general, this function allows the length of the last chunk\n  to be less than the request `chunk_size`.\n\n  For example, if you have a 7-byte binary data, and you'd like to chunk it by every\n  4 bytes, then this function will return two chunks with the first gives you the\n  byte 0 to 3, and the second one gives byte 4 to 6.\n  \"\"\"\n  def chunk_binary(binary, chunk_size) when is_binary(binary) do\n    total_bytes = byte_size(binary)\n    full_chunks = div(total_bytes, chunk_size)\n\n    chunks =\n      if full_chunks > 0 do\n        for i <- 0..(full_chunks - 1), reduce: [] do\n          acc -> [:binary.part(binary, chunk_size * i, chunk_size) | acc]\n        end\n      else\n        []\n      end\n\n    remaining = rem(total_bytes, chunk_size)\n\n    chunks =\n      if remaining > 0 do\n        [:binary.part(binary, chunk_size * full_chunks, remaining) | chunks]\n      else\n        chunks\n      end\n\n    Enum.reverse(chunks)\n  end\nend\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n{:module, Helper, <<70, 79, 82, 49, 0, 0, 16, ...>>, {:chunk_binary, 2}}\n```","ref":"photo-hdr.html#define-some-helper-functions"},{"type":"extras","title":"Download the Test Images - Evision Example - High Dynamic Range Imaging","doc":"```elixir\nalias Evision, as: Cv\n\n# change to the file's directory\n# or somewhere you have write permission\nFile.cd!(__DIR__)\n\n# create a directory for storing the test images\nFile.mkdir_p!(\"photo_hdr_test\")\n\nexposure_filenames =\n  0..15\n  |> Enum.map(&Integer.to_string(&1))\n  |> Enum.map(&String.pad_leading(&1, 2, \"0\"))\n  |> Enum.map(&(\"memorial\" <> &1 <> \".png\"))\n\nexposure_file_urls =\n  exposure_filenames\n  |> Enum.map(\n    &(\"https://raw.githubusercontent.com/opencv/opencv_extra/4.x/testdata/cv/hdr/exposures/\" <> &1)\n  )\n\nexposure_file_save_paths =\n  exposure_filenames\n  |> Enum.map(&Path.join([__DIR__, \"photo_hdr_test\", &1]))\n\nexposure_file_urls\n|> Enum.zip(exposure_file_save_paths)\n|> Enum.map(fn {url, save_as} -> Helper.download!(url, save_as) end)\n|> Enum.all?(&(:ok = &1))\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\ntrue\n```","ref":"photo-hdr.html#download-the-test-images"},{"type":"extras","title":"Download `list.txt` that Stores the Exposure Sequences - Evision Example - High Dynamic Range Imaging","doc":"```elixir\nlist_txt_file = Path.join([__DIR__, \"photo_hdr_test\", \"list.txt\"])\n\nHelper.download!(\n  \"https://raw.githubusercontent.com/opencv/opencv_extra/4.x/testdata/cv/hdr/exposures/list.txt\",\n  list_txt_file\n)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```","ref":"photo-hdr.html#download-list-txt-that-stores-the-exposure-sequences"},{"type":"extras","title":"Load the Exposure Sequences - Evision Example - High Dynamic Range Imaging","doc":"```elixir\n# Firstly we load input images and exposure times from user-defined folder.\n# The folder should contain images and list.txt - file that contains file names and inverse exposure times.\nexposure_sequences =\n  list_txt_file\n  |> File.read!()\n  |> String.split(\"\\n\")\n  |> Enum.reject(&(String.length(&1) == 0))\n  |> Enum.map(&String.split(&1, \" \"))\n  |> Enum.map(&List.to_tuple(&1))\n  |> Enum.map(fn {image_filename, times} ->\n    mat = Cv.imread(Path.join([__DIR__, \"photo_hdr_test\", image_filename]))\n    {val, \"\"} = Float.parse(times)\n    {mat, 1 / val}\n  end)\n\nimages =\n  exposure_sequences\n  |> Enum.map(&elem(&1, 0))\n\n# `times` HAS to be float32, otherwise OpenCV will crash\ntimes =\n  exposure_sequences\n  |> Enum.map(&elem(&1, 1))\n  |> Enum.into(<<>>, fn d -> < > end)\n  |> Cv.Mat.from_binary_by_shape({:f, 32}, {1, Enum.count(images)})\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 1,\n  dims: 2,\n  type: {:f, 32},\n  raw_type: 5,\n  shape: {1, 16},\n  ref: #Reference<0.741743058.1175846932.38571>\n}\n```","ref":"photo-hdr.html#load-the-exposure-sequences"},{"type":"extras","title":"Estimate Camera Response - Evision Example - High Dynamic Range Imaging","doc":"```elixir\n# It is necessary to know camera response function (CRF) for a lot of HDR construction algorithms.\n# We use one of the calibration algorithms to estimate inverse CRF for all 256 pixel values.\ncalibrate = Cv.createCalibrateDebevec()\nresponse = Cv.CalibrateDebevec.process(calibrate, images, times)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:f, 32},\n  raw_type: 21,\n  shape: {256, 1, 3},\n  ref: #Reference<0.741743058.1175846932.38575>\n}\n```","ref":"photo-hdr.html#estimate-camera-response"},{"type":"extras","title":"Process and Get the HDR Image - Evision Example - High Dynamic Range Imaging","doc":"```elixir\n# We use Debevec's weighting scheme to construct HDR image\n# using response calculated in the previous item.\nmerge_debevec = Cv.createMergeDebevec()\nhdr = Cv.MergeDebevec.process(merge_debevec, images, times, response: response)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:f, 32},\n  raw_type: 21,\n  shape: {714, 484, 3},\n  ref: #Reference<0.741743058.1175846932.38579>\n}\n```","ref":"photo-hdr.html#process-and-get-the-hdr-image"},{"type":"extras","title":"Tonemap the HDR image - Evision Example - High Dynamic Range Imaging","doc":"```elixir\n# Since we want to see our results on common LDR display we have to map our HDR image to 8-bit range\n# preserving most details.\n# It is the main goal of tonemapping methods.\n# We use tonemapper with bilateral filtering and set 2.2 as the value for gamma correction.\ntonemap = Cv.createTonemap(gamma: 2.2)\nldr = Cv.Tonemap.process(tonemap, hdr)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:f, 32},\n  raw_type: 21,\n  shape: {714, 484, 3},\n  ref: #Reference<0.741743058.1175846932.38583>\n}\n```","ref":"photo-hdr.html#tonemap-the-hdr-image"},{"type":"extras","title":"Perform Exposure Fusions - Evision Example - High Dynamic Range Imaging","doc":"```elixir\n# There is an alternative way to merge our exposures in case when we don't need HDR image.\n# This process is called exposure fusion and produces LDR image that doesn't require gamma correction.\n# It also doesn't use exposure values of the photographs.\nmerge_mertens = Cv.createMergeMertens()\nfusion = Cv.MergeMertens.process(merge_mertens, images)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:f, 32},\n  raw_type: 21,\n  shape: {714, 484, 3},\n  ref: #Reference<0.741743058.1175846932.38587>\n}\n```","ref":"photo-hdr.html#perform-exposure-fusions"},{"type":"extras","title":"Write Fusion - Evision Example - High Dynamic Range Imaging","doc":"```elixir\noutput_fusion_file = Path.join([__DIR__, \"photo_hdr_test\", \"fusion.png\"])\n\nresult =\n  fusion\n  |> Cv.Mat.to_nx(Nx.BinaryBackend)\n  |> Nx.multiply(255)\n  |> Nx.clip(0, 255)\n  |> Nx.as_type({:u, 8})\n  |> Cv.Mat.from_nx_2d()\n  |> then(fn result ->\n    Cv.imwrite(output_fusion_file, result)\n    result\n  end)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {714, 484, 3},\n  ref: #Reference<0.741743058.1175846932.38590>\n}\n```\n\n```elixir\nresult = Cv.imencode(\".png\", result)\n\nKino.Image.new(result, :png)\n```","ref":"photo-hdr.html#write-fusion"},{"type":"extras","title":"Write LDR Image - Evision Example - High Dynamic Range Imaging","doc":"```elixir\noutput_ldr_file = Path.join([__DIR__, \"photo_hdr_test\", \"ldr.png\"])\nf32_shape = Cv.Mat.shape(ldr)\nnan = <<0, 0, 192, 255>>\npositive_inf = <<0, 0, 128, 127>>\nnegative_inf = <<0, 0, 128, 255>>\n\nresult =\n  ldr\n  |> Cv.Mat.to_binary()\n  |> Helper.chunk_binary(4)\n  |> Enum.map(fn f32 ->\n    case f32 do\n      ^nan ->\n        <<0, 0, 0, 0>>\n\n      ^positive_inf ->\n        <<0, 0, 0, 0>>\n\n      ^negative_inf ->\n        <<0, 0, 0, 0>>\n\n      # legal value\n      _ ->\n        f32\n    end\n  end)\n  |> IO.iodata_to_binary()\n  |> Nx.from_binary({:f, 32})\n  |> Nx.reshape(f32_shape)\n  |> Nx.multiply(255)\n  |> Nx.clip(0, 255)\n  |> Nx.as_type({:u, 8})\n  |> Cv.Mat.from_nx_2d()\n\nresult = Cv.imencode(\".png\", result)\n\nKino.Image.new(result, :png)\n```","ref":"photo-hdr.html#write-ldr-image"},{"type":"extras","title":"Write HDR Image - Evision Example - High Dynamic Range Imaging","doc":"```elixir\noutput_hdr_file = Path.join([__DIR__, \"photo_hdr_test\", \"hdr.hdr\"])\nCv.imwrite(output_hdr_file, hdr)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\ntrue\n```","ref":"photo-hdr.html#write-hdr-image"},{"type":"extras","title":"Sudoku Puzzle Extractor","doc":"<!-- livebook:{\"persist_outputs\":true} -->\n\n# Sudoku Puzzle Extractor\n\n```elixir\nMix.install([\n  {:evision, \"~> 0.2\"},\n  {:kino, \"~> 0.7\"},\n  {:req, \"~> 0.3\"},\n  {:torchx, \"~> 0.4\"},\n  {:nx, \"~> 0.4\"},\n  {:scidata, \"~> 0.1\"},\n  {:axon, \"~> 0.3.0\"}\n], system_env: [\n  # optional, defaults to `true`\n  # set `EVISION_PREFER_PRECOMPILED` to `false`\n  # if you prefer `:evision` to be compiled from source\n  # note that to compile from source, you may need at least 1GB RAM\n  {\"EVISION_PREFER_PRECOMPILED\", true},\n\n  # optional, defaults to `true`\n  # set `EVISION_ENABLE_CONTRIB` to `false`\n  # if you don't need modules from `opencv_contrib`\n  {\"EVISION_ENABLE_CONTRIB\", true},\n\n  # optional, defaults to `false`\n  # set `EVISION_ENABLE_CUDA` to `true`\n  # if you wish to use CUDA related functions\n  # note that `EVISION_ENABLE_CONTRIB` also has to be `true`\n  # because cuda related modules come from the `opencv_contrib` repo\n  {\"EVISION_ENABLE_CUDA\", false},\n\n  # required when \n  # - `EVISION_ENABLE_CUDA` is `true`\n  # - and `EVISION_PREFER_PRECOMPILED` is `true`\n  #\n  # set `EVISION_CUDA_VERSION` to the version that matches \n  # your local CUDA runtime version\n  #\n  # current available versions are\n  # - 118\n  # - 121\n  {\"EVISION_CUDA_VERSION\", \"118\"},\n\n  # require for Windows users when \n  # - `EVISION_ENABLE_CUDA` is `true`\n  # set `EVISION_CUDA_RUNTIME_DIR` to the directory that contains\n  # CUDA runtime libraries\n  {\"EVISION_CUDA_RUNTIME_DIR\", \"C:/PATH/TO/CUDA/RUNTIME\"}\n])\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```","ref":"sudoku.html"},{"type":"extras","title":"References - Sudoku Puzzle Extractor","doc":"Some code in this example was basically literal translation from the code in [OpenCV Sudoku Solver and OCR - PyImageSearch](https://pyimagesearch.com/2020/08/10/opencv-sudoku-solver-and-ocr/). The sample input image is also taken from that post.\n\nThe code of the neural network was taken from https://github.com/elixir-nx/axon/blob/main/examples/vision/mnist.exs with some minor changes.","ref":"sudoku.html#references"},{"type":"extras","title":"Define Some Helper Functions - Sudoku Puzzle Extractor","doc":"```elixir\ndefmodule Helper do\n  def download!(url, save_as, overwrite? \\\\ false) do\n    unless File.exists?(save_as) do\n      Req.get!(url, http_errors: :raise, output: save_as, cache: not overwrite?)\n    end\n\n    :ok\n  end\nend\n```\n\nDownload the test image.\n\n```elixir\nHelper.download!(\n  \"https://raw.githubusercontent.com/cocoa-xu/evision/main/test/testdata/sudoku_puzzle.webp\",\n  \"sudoku_puzzle.webp\"\n)\n```","ref":"sudoku.html#define-some-helper-functions"},{"type":"extras","title":"Load Original Image and Convert It to Gray Scale - Sudoku Puzzle Extractor","doc":"```elixir\n# read the original image\noriginal = Evision.imread(\"sudoku_puzzle.webp\")\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {1024, 962, 3},\n  ref: #Reference<0.736436033.3583639578.183370>\n}\n```\n\n```elixir\n# convert it to grayscale\ngray = Evision.cvtColor(original, Evision.Constant.cv_COLOR_BGR2GRAY())\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 1,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 0,\n  shape: {1024, 962},\n  ref: #Reference<0.736436033.3588096019.145887>\n}\n```\n\n```elixir\n# apply some Gaussian Blue to the image\n# we are doing so to reduce the noise and prepare it for the next step\nblurred = Evision.gaussianBlur(gray, {7, 7}, 3)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 1,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 0,\n  shape: {1024, 962},\n  ref: #Reference<0.736436033.3588096019.145890>\n}\n```\n\n```elixir\n# binarization with Evision.adaptiveThreshold\nbw =\n  Evision.adaptiveThreshold(\n    blurred,\n    255,\n    Evision.Constant.cv_ADAPTIVE_THRESH_GAUSSIAN_C(),\n    Evision.Constant.cv_THRESH_BINARY(),\n    11,\n    2\n  )\n\n# bitwise not\nthreshold = Evision.Mat.bitwise_not(bw)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 1,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 0,\n  shape: {1024, 962},\n  ref: #Reference<0.736436033.3588096019.145894>\n}\n```","ref":"sudoku.html#load-original-image-and-convert-it-to-gray-scale"},{"type":"extras","title":"Find the Sudoku Puzzle - Sudoku Puzzle Extractor","doc":"```elixir\n# First thing first, we need to find all the contours in the thresholded image\n{contours, _} =\n  Evision.findContours(\n    threshold,\n    Evision.Constant.cv_RETR_EXTERNAL(),\n    Evision.Constant.cv_CHAIN_APPROX_SIMPLE()\n  )\n\nIO.puts(\"Find #{Enum.count(contours)} contour(s)\")\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\nFind 377 contour(s)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```\n\n```elixir\n# and our assumptions are that\n#   1. the contour that contains the puzzle should be fairly large: \n#      hence we are sorting them by their area in descending order\ncontours =\n  Enum.sort_by(contours, fn c ->\n    -Evision.contourArea(c)\n  end)\n\nIO.puts(\"area of the largest contour: #{Evision.contourArea(Enum.at(contours, 0))}\")\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\narea of the largest contour: 430559.5\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```\n\n```elixir\n# 2.the puzzle should be a rectangular\n#   which means its contour should be approximately an rectangular\n#   which means the approximated polygonal of the contour should have 4 corners (keypoints)\n#   hence we will need to find the contour which its approximated polygonal's shape is {4, 1, 2}\npuzzle_keypoints =\n  Enum.reduce_while(contours, nil, fn c, _acc ->\n    peri = Evision.arcLength(c, true)\n    approx = Evision.approxPolyDP(c, 0.02 * peri, true)\n\n    case approx.shape do\n      {4, 1, 2} ->\n        {:halt, approx}\n\n      _ ->\n        {:cont, nil}\n    end\n  end)\n\nif puzzle_keypoints do\n  IO.puts(\"Found puzzle\")\n  Evision.drawContours(original, [puzzle_keypoints], -1, {0, 255, 0}, thickness: 2)\nelse\n  IO.puts(\"\"\"\n  Could not find Sudoku puzzle outline.\n  Try debugging your thresholding and contour steps.\n  \"\"\")\nend\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\nFound puzzle\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {1024, 962, 3},\n  ref: #Reference<0.736436033.3588096019.146280>\n}\n```","ref":"sudoku.html#find-the-sudoku-puzzle"},{"type":"extras","title":"Extract the Puzzle - Sudoku Puzzle Extractor","doc":"To extract the puzzle, we need to apply some affine transformations.\n\nTo apply any affine transformations, we will first need to know the four corners/points, namely,\n\n1. Top left\n2. Top right\n3. Bottom right\n4. Bottom left\n\nAnd these four points have to be arranged in the order above -- so that when you connect them 1 => 2 => 3=> 4 => 1, they can form a closed rectangular.\n\n```elixir\n# this function will arrange the keypoints in the order discussed above\norder_points = fn pts ->\n  # the top-left point will have the smallest sum, whereas\n  # the bottom-right point will have the largest sum\n  sum = Nx.sum(pts, axes: [1])\n  tl = pts[Nx.argmin(sum)]\n  br = pts[Nx.argmax(sum)]\n\n  # now, compute the difference between the points, the\n  # top-right point will have the smallest difference,\n  # whereas the bottom-left will have the largest difference\n  diff = Nx.subtract(pts[[0..3, 1]], pts[[0..3, 0]])\n  tr = pts[Nx.argmin(diff)]\n  bl = pts[Nx.argmax(diff)]\n  {tl, tr, br, bl}\nend\n\ninput =\n  Evision.Mat.as_shape(puzzle_keypoints, {4, 2})\n  |> Evision.Mat.to_nx(Nx.BinaryBackend)\n  |> Nx.as_type(:f32)\n\n{tl, tr, br, bl} = order_points.(input)\nrect = Nx.stack([tl, tr, br, bl])\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n#Nx.Tensor \n```\n\nAfter that, we can calculate the expected output height and width.\n\n```elixir\npoint_distance = fn p1, p2 ->\n  round(\n    Nx.to_number(\n      Nx.sqrt(\n        Nx.add(\n          Nx.power(Nx.subtract(p1[[0]], p2[[0]]), 2),\n          Nx.power(Nx.subtract(p1[[1]], p2[[1]]), 2)\n        )\n      )\n    )\n  )\nend\n\n# compute the width of the new image, which will be the\n# maximum distance between bottom-right and bottom-left\n# x-coordiates or the top-right and top-left x-coordinates\noutput_width =\n  Nx.to_number(\n    Nx.max(\n      point_distance.(br, bl),\n      point_distance.(tr, tl)\n    )\n  )\n\n# compute the height of the new image, which will be the\n# maximum distance between the top-right and bottom-right\n# y-coordinates or the top-left and bottom-left y-coordinates\noutput_height =\n  Nx.to_number(\n    Nx.max(\n      point_distance.(tr, br),\n      point_distance.(tl, bl)\n    )\n  )\n\n{output_height, output_width}\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n{609, 771}\n```\n\nThen we specify output coordinates for corners of the puzzle, [`top-left`, `top-right`, `bottom-right`, `bottom-left`] as `output`.\n\n```elixir\noutput =\n  Nx.tensor(\n    [\n      [0, 0],\n      [output_width - 1, 0],\n      [output_width - 1, output_height - 1],\n      [0, output_height - 1]\n    ],\n    type: :f32\n  )\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n#Nx.Tensor \n```\n\nGet the perspective transformation matrix and warp perspective for both the original image and the grayscale one\n\n```elixir\nmatrix = Evision.getPerspectiveTransform(rect, output)\n\npuzzle =\n  Evision.warpPerspective(\n    original,\n    matrix,\n    {output_width, output_height},\n    flags: Evision.Constant.cv_INTER_LINEAR(),\n    borderMode: Evision.Constant.cv_BORDER_CONSTANT(),\n    borderValue: {0, 0, 0}\n  )\n\npuzzle_gray =\n  Evision.warpPerspective(\n    gray,\n    matrix,\n    {output_width, output_height},\n    flags: Evision.Constant.cv_INTER_LINEAR(),\n    borderMode: Evision.Constant.cv_BORDER_CONSTANT(),\n    borderValue: {0, 0, 0}\n  )\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 1,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 0,\n  shape: {609, 771},\n  ref: #Reference<0.736436033.3588096019.146349>\n}\n```\n\nSince the Sudoku puzzel is 9x9, we can resize it to a square\n\n```elixir\n{h, w} = puzzle_gray.shape\nlen = max(h, w)\npuzzle_gray = Evision.resize(puzzle_gray, {len, len})\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 1,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 0,\n  shape: {771, 771},\n  ref: #Reference<0.736436033.3588096019.146352>\n}\n```","ref":"sudoku.html#extract-the-puzzle"},{"type":"extras","title":"Extract Digits in Each Cell of the Puzzle - Sudoku Puzzle Extractor","doc":"Let's start with the basic case, the top-left one.\n\n```elixir\nstep = len / 9\ncurrent_cell = puzzle_gray[[0..round(step), 0..round(step)]]\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 1,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 0,\n  shape: {87, 87},\n  ref: #Reference<0.736436033.3588096019.146355>\n}\n```\n\n```elixir\n# import Bitwise so that we can use `|||` (bitwise or)\nimport Bitwise\n\nextract_digit = fn cell ->\n  # get a binary image of the cell\n  {_, threshold} =\n    Evision.threshold(cell, 10, 255, Evision.Constant.cv_THRESH_BINARY_INV() ||| Evision.Constant.cv_THRESH_OTSU())\n\n  # cut off border\n  {h, w} = threshold.shape\n  threshold = threshold[[8..(h - 8), 8..(w - 8)]]\n\n  # find contours in the thresholded cell\n  {contours, _} =\n    Evision.findContours(\n      threshold,\n      Evision.Constant.cv_RETR_EXTERNAL(),\n      Evision.Constant.cv_CHAIN_APPROX_SIMPLE()\n    )\n\n  # if no contours were found than this is an empty cell\n  unless Enum.count(contours) == 0 do\n    # otherwise, find the largest contour in the cell and create a\n    # mask for the contour\n    c = Enum.max_by(contours, &Evision.contourArea/1)\n    mask = Evision.Mat.zeros(threshold.shape, :u8)\n    mask = Evision.drawContours(mask, [c], -1, {255}, thickness: 2)\n\n    # compute the percentage of masked pixels relative to the total\n    # area of the image\n    {h, w} = threshold.shape\n    percent_filled = Evision.countNonZero(mask) / (w * h)\n\n    # if less than 5% of the mask is filled then we are looking at\n    # noise and can safely ignore the contour\n    unless percent_filled < 0.05 do\n      threshold\n    end\n  end\nend\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n#Function<42.3316493/1 in :erl_eval.expr/6>\n```\n\nLet's try this for the top-left cell\n\n```elixir\ncurrent_cell = extract_digit.(current_cell)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 1,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 0,\n  shape: {72, 72},\n  ref: #Reference<0.736436033.3588096019.146359>\n}\n```\n\nAnd it looks great!","ref":"sudoku.html#extract-digits-in-each-cell-of-the-puzzle"},{"type":"extras","title":"Train A Neural Network that Recognizes Digits - Sudoku Puzzle Extractor","doc":"```elixir\n# Here I'm using :torchx as the backend\n# you can use :exla or other nx backend\nNx.default_backend(Torchx.Backend)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n{Torchx.Backend, []}\n```\n\nDefine the neural network module, `MNIST`.\n\nCode from https://github.com/elixir-nx/axon/blob/main/examples/vision/mnist.exs with minor changes.\n\n```elixir\ndefmodule MNIST do\n  require Axon\n\n  def transform_images({bin, type, shape}) do\n    bin\n    |> Nx.from_binary(type, backend: Torchx.Backend)\n    # 28, 28})\n    |> Nx.reshape({elem(shape, 0), 784})\n    |> Nx.as_type(:f32)\n    |> Nx.divide(255.0)\n    |> Nx.to_batched(500, leftover: :discard)\n    |> Enum.to_list()\n    # Test split\n    |> Enum.split(-3)\n  end\n\n  def transform_labels({bin, type, _}) do\n    bin\n    |> Nx.from_binary(type, backend: Torchx.Backend)\n    |> Nx.new_axis(-1)\n    |> Nx.equal(Nx.tensor(Enum.to_list(0..9)))\n    |> Nx.to_batched(500, leftover: :discard)\n    |> Enum.to_list()\n    # Test split\n    |> Enum.split(-3)\n  end\n\n  def build_model(input_shape) do\n    Axon.input(\"input\", shape: input_shape)\n    |> Axon.dense(128, activation: :relu)\n    |> Axon.dropout()\n    |> Axon.dense(10, activation: :softmax)\n  end\n\n  def train_model(model, train_images, train_labels, epochs) do\n    model\n    |> Axon.Loop.trainer(:categorical_cross_entropy, Axon.Optimizers.adamw(0.005))\n    |> Axon.Loop.metric(:accuracy, \"Accuracy\")\n    |> Axon.Loop.run(Stream.zip(train_images, train_labels), %{}, epochs: epochs)\n  end\n\n  def test_model(model, model_state, test_images, test_labels) do\n    model\n    |> Axon.Loop.evaluator()\n    |> Axon.Loop.metric(:accuracy, \"Accuracy\")\n    |> Axon.Loop.run(Stream.zip(test_images, test_labels), model_state)\n  end\nend\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n{:module, MNIST, <<70, 79, 82, 49, 0, 0, 16, ...>>, {:test_model, 4}}\n```\n\nGet the MNIST dataset and prepare the model.\n\n```elixir\n{images, labels} = Scidata.MNIST.download()\n\n{train_images, test_images} = MNIST.transform_images(images)\n{train_labels, test_labels} = MNIST.transform_labels(labels)\n\nmodel = MNIST.build_model({nil, 784})\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n#Axon \n```","ref":"sudoku.html#train-a-neural-network-that-recognizes-digits"},{"type":"extras","title":"Train and Test the MNIST Model - Sudoku Puzzle Extractor","doc":"```elixir\nIO.puts(\"Training Model...\")\nnum_epoch = 5\nmodel_state = MNIST.train_model(model, train_images, train_labels, num_epoch)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\nTraining Model...\nEpoch: 0, Batch: 100, Accuracy: 0.8545348 loss: 0.4818023\nEpoch: 1, Batch: 100, Accuracy: 0.9332873 loss: 0.3481621\nEpoch: 2, Batch: 100, Accuracy: 0.9500000 loss: 0.2871155\nEpoch: 3, Batch: 100, Accuracy: 0.9596242 loss: 0.2489783\nEpoch: 4, Batch: 100, Accuracy: 0.9664556 loss: 0.2216917\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%{\n  \"dense_0\" => %{\n    \"bias\" => #Nx.Tensor ,\n    \"kernel\" => #Nx.Tensor \n  },\n  \"dense_1\" => %{\n    \"bias\" => #Nx.Tensor ,\n    \"kernel\" => #Nx.Tensor \n  }\n}\n```\n\n```elixir\nIO.puts(\"Testing Model...\")\nMNIST.test_model(model, model_state, test_images, test_labels)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\nTesting Model...\nBatch: 2, Accuracy: 0.9813333\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%{\n  0 => %{\n    \"Accuracy\" => #Nx.Tensor \n  }\n}\n```","ref":"sudoku.html#train-and-test-the-mnist-model"},{"type":"extras","title":"Apply the Trained Neural Network to the Digits Extracted from the Puzzle - Sudoku Puzzle Extractor","doc":"```elixir\n# Get the predict function\n{_init_fn, predict_fn} = Axon.build(model)\n\n# make a helper function for our use -- predict the digit in the cell\npredict_cell = fn predict_fn, model_state, input_cell ->\n  input_cell =\n    Nx.as_type(Evision.Mat.to_nx(Evision.resize(input_cell, {28, 28}), Torchx.Backend), :f32)\n    |> Nx.reshape({1, 784})\n    |> Nx.divide(255.0)\n\n  pred = predict_fn.(model_state, input_cell)\n  Nx.to_number(Nx.argmax(pred))\nend\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n#Function<40.3316493/3 in :erl_eval.expr/6>\n```\n\nLet's use the top-left one as input\n\n```elixir\npred = predict_cell.(predict_fn, model_state, current_cell)\n\nIO.puts(\"Prediction: #{pred}\")\ncurrent_cell\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\nPrediction: 8\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 1,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 0,\n  shape: {72, 72},\n  ref: #Reference<0.736436033.3588096019.146359>\n}\n```\n\nLooks good! Now if we do this for each cell in the puzzle, we can get what we want\n\n```elixir\nstep = trunc(step)\n\ndigits =\n  for x <- 0..8, y <- 0..8 do\n    x1 = step * x\n    y1 = step * y\n\n    # remember that we return nil if extract_digit thinks there is no\n    # digits present in the cell \n    current_cell = extract_digit.(puzzle_gray[[x1..(x1 + step), y1..(y1 + step)]])\n\n    if current_cell do\n      # if there is a digit, we use the neural network to predict its value\n      predict_cell.(predict_fn, model_state, current_cell)\n    else\n      # otherwise we use `0` for empty ones\n      # this should be okay since in normal sudoku puzzle we only use 1-9\n      0\n    end\n  end\n\nextracted_puzzle = Nx.reshape(Nx.tensor(digits), {9, 9})\nIO.inspect(extracted_puzzle, limit: :infinity)\n:ok\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n#Nx.Tensor \n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```","ref":"sudoku.html#apply-the-trained-neural-network-to-the-digits-extracted-from-the-puzzle"},{"type":"extras","title":"Visualise the Results - Sudoku Puzzle Extractor","doc":"```elixir\n{h, w, _} = puzzle.shape\nlen = max(h, w)\npuzzle = Evision.resize(puzzle, {len, len})\n\nfor x <- 0..8, y <- 0..8, reduce: puzzle do\n  vis ->\n    # compute the coordinates of where the digit will be drawn\n    # on the output puzzle image\n    {x1, y1} = {step * x, step * y}\n    {x2, y2} = {step + x1, step + y1}\n    textX = trunc((x2 - x1) * 0.33) + x1\n    textY = trunc((y2 - y1) * -0.2) + y2\n\n    text = to_string(Nx.to_number(extracted_puzzle[[y, x]]))\n\n    Evision.putText(\n      vis,\n      text,\n      {textX, textY},\n      Evision.Constant.cv_FONT_HERSHEY_SIMPLEX(),\n      0.9,\n      {0, 255, 255},\n      thickness: 2\n    )\nend\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {771, 771, 3},\n  ref: #Reference<0.736436033.3588620308.228888>\n}\n```","ref":"sudoku.html#visualise-the-results"},{"type":"extras","title":"Evision Example - Simple use of Evision in a Machine Learning Pipeline with Nx and torhcx","doc":"<!-- vim: syntax=markdown -->\n\n<!-- livebook:{\"persist_outputs\":true} -->\n\n# Evision Example - Simple use of Evision in a Machine Learning Pipeline with Nx and torhcx\n\n```elixir\nMix.install([\n  {:evision, \"~> 0.2\"},\n  {:req, \"~> 0.3\"},\n  {:torchx, \"~> 0.3\"},\n  {:nx, \"~> 0.3\", override: true},\n  {:kino, \"~> 0.7\"},\n  {:scidata, \"~> 0.1\"}\n], system_env: [\n  # optional, defaults to `true`\n  # set `EVISION_PREFER_PRECOMPILED` to `false`\n  # if you prefer `:evision` to be compiled from source\n  # note that to compile from source, you may need at least 1GB RAM\n  {\"EVISION_PREFER_PRECOMPILED\", true},\n\n  # optional, defaults to `true`\n  # set `EVISION_ENABLE_CONTRIB` to `false`\n  # if you don't need modules from `opencv_contrib`\n  {\"EVISION_ENABLE_CONTRIB\", true},\n\n  # optional, defaults to `false`\n  # set `EVISION_ENABLE_CUDA` to `true`\n  # if you wish to use CUDA related functions\n  # note that `EVISION_ENABLE_CONTRIB` also has to be `true`\n  # because cuda related modules come from the `opencv_contrib` repo\n  {\"EVISION_ENABLE_CUDA\", false},\n\n  # required when\n  # - `EVISION_ENABLE_CUDA` is `true`\n  # - and `EVISION_PREFER_PRECOMPILED` is `true`\n  #\n  # set `EVISION_CUDA_VERSION` to the version that matches\n  # your local CUDA runtime version\n  #\n  # current available versions are\n  # - 118\n  # - 121\n  {\"EVISION_CUDA_VERSION\", \"118\"},\n\n  # require for Windows users when\n  # - `EVISION_ENABLE_CUDA` is `true`\n  # set `EVISION_CUDA_RUNTIME_DIR` to the directory that contains\n  # CUDA runtime libraries\n  {\"EVISION_CUDA_RUNTIME_DIR\", \"C:/PATH/TO/CUDA/RUNTIME\"}\n])\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```","ref":"cifar10.html"},{"type":"extras","title":"Define Some Helper Functions and Download the Test Image - Evision Example - Simple use of Evision in a Machine Learning Pipeline with Nx and torhcx","doc":"```elixir\n# change to the file's directory\n# or somewhere you have write permission\nFile.cd!(__DIR__)\n\ndefmodule Helper do\n  def download!(url, save_as, overwrite? \\\\ false) do\n    unless File.exists?(save_as) do\n      Req.get!(url, http_errors: :raise, output: save_as, cache: not overwrite?)\n    end\n\n    :ok\n  end\nend\n\nHelper.download!(\n  \"https://upload.wikimedia.org/wikipedia/commons/thumb/3/3a/Cat03.jpg/1200px-Cat03.jpg\",\n  \"cat.jpg\"\n)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```","ref":"cifar10.html#define-some-helper-functions-and-download-the-test-image"},{"type":"extras","title":"Read the Test Image - Evision Example - Simple use of Evision in a Machine Learning Pipeline with Nx and torhcx","doc":"```elixir\n# in real-life use cases, the input source might be a camera\n# instead of downloading a file and reading it\n\nalias Evision, as: Cv\n\nimg = Cv.imread(\"cat.jpg\", flags: Cv.Constant.cv_IMREAD_ANYCOLOR())\nresized_img = Cv.resize(img, {128, 128})\n\nCv.imencode(\".png\", resized_img)\n|> Kino.Image.new(:png)\n```","ref":"cifar10.html#read-the-test-image"},{"type":"extras","title":"Select a Default Nx Backend - Evision Example - Simple use of Evision in a Machine Learning Pipeline with Nx and torhcx","doc":"```elixir\n# by default we don't have the LibTorch backend\n# but if you listed :torchx as a dependency\n# then please uncomment the following line to use the LibTorch backend\n# Similarly for the EXLA backend\n# Nx.default_backend(Torchx.Backend)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\nnil\n```","ref":"cifar10.html#select-a-default-nx-backend"},{"type":"extras","title":"Write a Module for the CIFAR10 Dataset - Evision Example - Simple use of Evision in a Machine Learning Pipeline with Nx and torhcx","doc":"```elixir\ndefmodule CIFAR10Dataset do\n  defp transform_images({bin, type, shape}, backend) do\n    bin\n    |> Nx.from_binary(type, backend: backend)\n    |> Nx.reshape({elem(shape, 0), 3 * 32 * 32}, names: [:batch, :input])\n    |> Nx.divide(255.0)\n  end\n\n  defp transform_labels({bin, type, _}, backend) do\n    bin\n    |> Nx.from_binary(type, backend: backend)\n  end\n\n  def fetch(backend \\\\ Torchx.Backend) do\n    {images, labels} = Scidata.CIFAR10.download()\n    {transform_images(images, backend), transform_labels(labels, backend)}\n  end\nend\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n{:module, CIFAR10Dataset, <<70, 79, 82, 49, 0, 0, 10, ...>>, {:fetch, 1}}\n```","ref":"cifar10.html#write-a-module-for-the-cifar10-dataset"},{"type":"extras","title":"Write A Tiny Linear Neural Network - Evision Example - Simple use of Evision in a Machine Learning Pipeline with Nx and torhcx","doc":"```elixir\n# training code\n# based on https://github.com/elixir-nx/nx/blob/e4454423f7be39d3adc9dea76526185fbfaf7a58/exla/examples/mnist.exs\n\ndefmodule DenseNN do\n  import Nx.Defn\n\n  defn init_random_params do\n    # 3 layers\n    #  1. Dense(32) with sigmoid\n    #  2. Dense(24) with sigmoid\n    #  3. Dense(10) with softmax\n    w1 = Nx.random_normal({3072, 32}, 0.0, 0.1, names: [:input, :layer1])\n    b1 = Nx.random_normal({32}, 0.0, 0.1, names: [:layer1])\n    w2 = Nx.random_normal({32, 24}, 0.0, 0.1, names: [:layer1, :layer2])\n    b2 = Nx.random_normal({24}, 0.0, 0.1, names: [:layer2])\n    w3 = Nx.random_normal({24, 10}, 0.0, 0.1, names: [:layer2, :output])\n    b3 = Nx.random_normal({10}, 0.0, 0.1, names: [:output])\n    {w1, b1, w2, b2, w3, b3}\n  end\n\n  defn softmax(logits) do\n    Nx.exp(logits) /\n      Nx.sum(Nx.exp(logits), axes: [:output], keep_axes: true)\n  end\n\n  defn predict({w1, b1, w2, b2, w3, b3}, batch) do\n    batch\n    |> Nx.dot(w1)\n    |> Nx.add(b1)\n    |> Nx.sigmoid()\n    |> Nx.dot(w2)\n    |> Nx.add(b2)\n    |> Nx.sigmoid()\n    |> Nx.dot(w3)\n    |> Nx.add(b3)\n    |> softmax()\n  end\n\n  defn accuracy({w1, b1, w2, b2, w3, b3}, batch_images, batch_labels) do\n    Nx.mean(\n      Nx.equal(\n        Nx.argmax(batch_labels, axis: :output),\n        Nx.argmax(predict({w1, b1, w2, b2, w3, b3}, batch_images), axis: :output)\n      )\n      |> Nx.as_type({:s, 8})\n    )\n  end\n\n  defn loss({w1, b1, w2, b2, w3, b3}, batch_images, batch_labels) do\n    preds = predict({w1, b1, w2, b2, w3, b3}, batch_images)\n    -Nx.sum(Nx.mean(Nx.log(preds) * batch_labels, axes: [:output]))\n  end\n\n  defn update({w1, b1, w2, b2, w3, b3} = params, batch_images, batch_labels, step) do\n    {grad_w1, grad_b1, grad_w2, grad_b2, grad_w3, grad_b3} =\n      grad(params, &loss(&1, batch_images, batch_labels))\n\n    {\n      w1 - grad_w1 * step,\n      b1 - grad_b1 * step,\n      w2 - grad_w2 * step,\n      b2 - grad_b2 * step,\n      w3 - grad_w3 * step,\n      b3 - grad_b3 * step\n    }\n  end\n\n  defn update_with_averages(\n         {_, _, _, _, _, _} = cur_params,\n         imgs,\n         tar,\n         avg_loss,\n         avg_accuracy,\n         total\n       ) do\n    batch_loss = loss(cur_params, imgs, tar)\n    batch_accuracy = accuracy(cur_params, imgs, tar)\n    avg_loss = avg_loss + batch_loss / total\n    avg_accuracy = avg_accuracy + batch_accuracy / total\n    {update(cur_params, imgs, tar, 0.01), avg_loss, avg_accuracy}\n  end\n\n  def train_epoch(cur_params, x, labels) do\n    total_batches = Enum.count(x)\n\n    x\n    |> Enum.zip(labels)\n    |> Enum.reduce({cur_params, Nx.tensor(0.0), Nx.tensor(0.0)}, fn\n      {x, tar}, {cur_params, avg_loss, avg_accuracy} ->\n        update_with_averages(cur_params, x, tar, avg_loss, avg_accuracy, total_batches)\n    end)\n  end\n\n  def train(x, labels, params, opts \\\\ []) do\n    epochs = opts[:epochs] || 5\n\n    for epoch <- 1..epochs, reduce: params do\n      cur_params ->\n        {time, {new_params, epoch_avg_loss, epoch_avg_acc}} =\n          :timer.tc(__MODULE__, :train_epoch, [cur_params, x, labels])\n\n        epoch_avg_loss =\n          epoch_avg_loss\n          |> Nx.backend_transfer()\n          |> Nx.to_number()\n\n        epoch_avg_acc =\n          epoch_avg_acc\n          |> Nx.backend_transfer()\n          |> Nx.to_number()\n\n        IO.puts(\n          \"Epoch #{epoch} Time: #{time / 1_000_000}s, loss: #{Float.round(epoch_avg_loss, 3)}, acc: #{Float.round(epoch_avg_acc, 3)}\"\n        )\n\n        new_params\n    end\n  end\nend\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n{:module, DenseNN, <<70, 79, 82, 49, 0, 0, 45, ...>>, {:train, 4}}\n```","ref":"cifar10.html#write-a-tiny-linear-neural-network"},{"type":"extras","title":"Convert Label to One-hot Encoding - Evision Example - Simple use of Evision in a Machine Learning Pipeline with Nx and torhcx","doc":"```elixir\ndefmodule Helper do\n  def to_onehot_single(0, oh, _pos) do\n    oh\n  end\n\n  def to_onehot_single(count, oh, pos) do\n    cur = count - 1\n\n    case cur == pos do\n      true -> to_onehot_single(count - 1, [1] ++ oh, pos)\n      _ -> to_onehot_single(count - 1, [0] ++ oh, pos)\n    end\n  end\n\n  def to_onehot_single(0, _pos) do\n    []\n  end\n\n  def to_onehot_single(count, pos) do\n    to_onehot_single(count, [], pos)\n  end\n\n  def to_onehot(labels, unique_classes) do\n    for(\n      l <- Nx.to_flat_list(labels),\n      do: Nx.tensor([to_onehot_single(unique_classes, l)])\n    )\n    |> Nx.concatenate()\n    |> Nx.reshape({:auto, unique_classes}, names: [:batch, :output])\n  end\nend\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n{:module, Helper, <<70, 79, 82, 49, 0, 0, 10, ...>>, {:to_onehot, 2}}\n```","ref":"cifar10.html#convert-label-to-one-hot-encoding"},{"type":"extras","title":"Train the Neural Network - Evision Example - Simple use of Evision in a Machine Learning Pipeline with Nx and torhcx","doc":"```elixir\ndefmodule Demo do\n  require CIFAR10Dataset\n  require DenseNN\n  require Helper\n\n  def load_dataset(backend) do\n    {uSec, result} = :timer.tc(fn -> CIFAR10Dataset.fetch(backend) end)\n    IO.puts(\"[Time] load dataset: #{uSec / 1000.0} ms\")\n    result\n  end\n\n  def to_batched_input(x_training, y_training, batch_size) do\n    unique_classes = 10\n\n    x_training_batched =\n      x_training\n      # uint8 to float\n      |> Nx.as_type({:f, 32})\n      # flatten\n      |> Nx.reshape({:auto, 3072})\n      |> Nx.to_batched(batch_size)\n\n    y_training_batched =\n      y_training\n      |> Helper.to_onehot(unique_classes)\n      |> Nx.as_type({:f, 32})\n      |> Nx.to_batched(batch_size)\n\n    {x_training_batched, y_training_batched}\n  end\n\n  def init_random_params do\n    {uSec, result} = :timer.tc(fn -> DenseNN.init_random_params() end)\n    IO.puts(\"[Time] init random params: #{uSec / 1000.0} ms\")\n    result\n  end\n\n  def run(opts \\\\ []) do\n    epochs = opts[:epochs] || 5\n    backend = opts[:backend] || Nx.BinaryBackend\n    batch_size = opts[:batch_size] || 300\n    Nx.default_backend(backend)\n\n    params = init_random_params()\n    {x_training, y_training} = load_dataset(backend)\n\n    {x_training_batched, y_training_batched} =\n      to_batched_input(x_training, y_training, batch_size)\n\n    DenseNN.train(\n      x_training_batched,\n      y_training_batched,\n      params,\n      epochs: epochs\n    )\n  end\nend\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n{:module, Demo, <<70, 79, 82, 49, 0, 0, 18, ...>>, {:run, 1}}\n```\n\n```elixir\nparams = Demo.run(backend: Torchx.Backend, epochs: 50)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n[Time] init random params: 19.537 ms\n[Time] load dataset: 8473.881 ms\nEpoch 1 Time: 1.801972s, loss: 68.817, acc: 0.122\nEpoch 2 Time: 1.526419s, loss: 64.754, acc: 0.183\nEpoch 3 Time: 1.474312s, loss: 62.076, acc: 0.211\nEpoch 4 Time: 1.463488s, loss: 60.709, acc: 0.247\nEpoch 5 Time: 1.495513s, loss: 58.924, acc: 0.276\nEpoch 6 Time: 1.50393s, loss: 57.685, acc: 0.296\nEpoch 7 Time: 1.401566s, loss: 56.825, acc: 0.311\nEpoch 8 Time: 1.552453s, loss: 56.041, acc: 0.325\nEpoch 9 Time: 2.047746s, loss: 55.225, acc: 0.336\nEpoch 10 Time: 1.500972s, loss: 54.438, acc: 0.346\nEpoch 11 Time: 1.449009s, loss: 53.76, acc: 0.355\nEpoch 12 Time: 1.456149s, loss: 53.171, acc: 0.361\nEpoch 13 Time: 1.636981s, loss: 52.639, acc: 0.366\nEpoch 14 Time: 1.519201s, loss: 52.153, acc: 0.372\nEpoch 15 Time: 1.582178s, loss: 51.709, acc: 0.377\nEpoch 16 Time: 1.524292s, loss: 51.303, acc: 0.381\nEpoch 17 Time: 1.472452s, loss: 50.93, acc: 0.386\nEpoch 18 Time: 1.500321s, loss: 50.584, acc: 0.39\nEpoch 19 Time: 1.503371s, loss: 50.258, acc: 0.395\nEpoch 20 Time: 1.504718s, loss: 49.949, acc: 0.399\nEpoch 21 Time: 1.579238s, loss: 49.654, acc: 0.403\nEpoch 22 Time: 1.571431s, loss: 49.373, acc: 0.407\nEpoch 23 Time: 1.683039s, loss: 49.105, acc: 0.411\nEpoch 24 Time: 1.526153s, loss: 48.852, acc: 0.414\nEpoch 25 Time: 1.519478s, loss: 48.609, acc: 0.418\nEpoch 26 Time: 1.417229s, loss: 48.374, acc: 0.42\nEpoch 27 Time: 1.711816s, loss: 48.146, acc: 0.423\nEpoch 28 Time: 1.628203s, loss: 47.925, acc: 0.427\nEpoch 29 Time: 1.601898s, loss: 47.71, acc: 0.431\nEpoch 30 Time: 1.552816s, loss: 47.503, acc: 0.434\nEpoch 31 Time: 1.483635s, loss: 47.302, acc: 0.437\nEpoch 32 Time: 1.500484s, loss: 47.104, acc: 0.44\nEpoch 33 Time: 1.514314s, loss: 46.912, acc: 0.442\nEpoch 34 Time: 1.560259s, loss: 46.731, acc: 0.445\nEpoch 35 Time: 1.505326s, loss: 46.556, acc: 0.447\nEpoch 36 Time: 1.492348s, loss: 46.388, acc: 0.45\nEpoch 37 Time: 1.479754s, loss: 46.226, acc: 0.452\nEpoch 38 Time: 1.556336s, loss: 46.069, acc: 0.454\nEpoch 39 Time: 1.512166s, loss: 45.916, acc: 0.455\nEpoch 40 Time: 1.525349s, loss: 45.765, acc: 0.458\nEpoch 41 Time: 1.536424s, loss: 45.617, acc: 0.46\nEpoch 42 Time: 1.496241s, loss: 45.656, acc: 0.46\nEpoch 43 Time: 1.473638s, loss: 45.358, acc: 0.462\nEpoch 44 Time: 1.504573s, loss: 45.18, acc: 0.465\nEpoch 45 Time: 1.502319s, loss: 45.129, acc: 0.465\nEpoch 46 Time: 1.515625s, loss: 45.035, acc: 0.466\nEpoch 47 Time: 1.496521s, loss: 44.82, acc: 0.468\nEpoch 48 Time: 1.501526s, loss: 44.838, acc: 0.468\nEpoch 49 Time: 1.500548s, loss: 44.607, acc: 0.472\nEpoch 50 Time: 1.522726s, loss: 44.57, acc: 0.471\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n{#Nx.Tensor ,\n #Nx.Tensor ,\n #Nx.Tensor ,\n #Nx.Tensor ,\n #Nx.Tensor ,\n #Nx.Tensor }\n```","ref":"cifar10.html#train-the-neural-network"},{"type":"extras","title":"Classify the Test Image with the Neural Network - Evision Example - Simple use of Evision in a Machine Learning Pipeline with Nx and torhcx","doc":"```elixir\nresized_img = Cv.resize(img, {128, 128})\n\nCv.imencode(\".png\", resized_img)\n|> Kino.Image.new(:png)\n```\n\n```elixir\nclasses = [:airplane, :automobile, :bird, :cat, :deer, :dog, :frog, :horse, :ship, :truck]\n\ninput_tensor =\n  img\n  |> Cv.resize({32, 32})\n  |> Cv.Mat.to_nx(Nx.BinaryBackend)\n  |> Nx.backend_transfer(Torchx.Backend)\n  |> Nx.flatten()\n\npred =\n  params\n  |> DenseNN.predict(input_tensor)\n  |> Nx.argmax()\n  |> Nx.to_number()\n\nEnum.at(classes, pred)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:cat\n```","ref":"cifar10.html#classify-the-test-image-with-the-neural-network"},{"type":"extras","title":"Evision.DNN Example - Object Detection Task with GoogleNet","doc":"<!-- vim: syntax=markdown -->\n\n<!-- livebook:{\"persist_outputs\":true} -->\n\n# Evision.DNN Example - Object Detection Task with GoogleNet\n\n```elixir\n# set `EVISION_PREFER_PRECOMPILED` to `false` \n# if you prefer `:evision` to be compiled from source\n# note that to compile from source, you may need at least 1GB RAM\n# System.put_env(\"EVISION_PREFER_PRECOMPILED\", \"false\")\n\nMix.install([\n  {:evision, \"~> 0.2\"},\n  {:kino, \"~> 0.7\"},\n  {:req, \"~> 0.3\"}\n], system_env: [\n  # optional, defaults to `true`\n  # set `EVISION_PREFER_PRECOMPILED` to `false`\n  # if you prefer `:evision` to be compiled from source\n  # note that to compile from source, you may need at least 1GB RAM\n  {\"EVISION_PREFER_PRECOMPILED\", true},\n\n  # optional, defaults to `true`\n  # set `EVISION_ENABLE_CONTRIB` to `false`\n  # if you don't need modules from `opencv_contrib`\n  {\"EVISION_ENABLE_CONTRIB\", true},\n\n  # optional, defaults to `false`\n  # set `EVISION_ENABLE_CUDA` to `true`\n  # if you wish to use CUDA related functions\n  # note that `EVISION_ENABLE_CONTRIB` also has to be `true`\n  # because cuda related modules come from the `opencv_contrib` repo\n  {\"EVISION_ENABLE_CUDA\", false},\n\n  # required when \n  # - `EVISION_ENABLE_CUDA` is `true`\n  # - and `EVISION_PREFER_PRECOMPILED` is `true`\n  #\n  # set `EVISION_CUDA_VERSION` to the version that matches \n  # your local CUDA runtime version\n  #\n  # current available versions are\n  # - 118\n  # - 121\n  {\"EVISION_CUDA_VERSION\", \"118\"},\n\n  # require for Windows users when \n  # - `EVISION_ENABLE_CUDA` is `true`\n  # set `EVISION_CUDA_RUNTIME_DIR` to the directory that contains\n  # CUDA runtime libraries\n  {\"EVISION_CUDA_RUNTIME_DIR\", \"C:/PATH/TO/CUDA/RUNTIME\"}\n])\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```","ref":"dnn-googlenet.html"},{"type":"extras","title":"Define Some Helper Functions - Evision.DNN Example - Object Detection Task with GoogleNet","doc":"```elixir\ndefmodule Helper do\n  def download!(url, save_as, overwrite? \\\\ false) do\n    unless File.exists?(save_as) do\n      Req.get!(url, http_errors: :raise, output: save_as, cache: not overwrite?)\n    end\n\n    :ok\n  end\nend\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n{:module, Helper, <<70, 79, 82, 49, 0, 0, 10, ...>>, {:download!, 3}}\n```","ref":"dnn-googlenet.html#define-some-helper-functions"},{"type":"extras","title":"Download GoogLeNet Model and A Test Image - Evision.DNN Example - Object Detection Task with GoogleNet","doc":"* Model parameters. `bvlc_googlenet.caffemodel`\n* Model config. `bvlc_googlenet.prototxt`\n* List of class names. `classification_classes_ILSVRC2012.txt`\n* Test image. `space_shuttle.jpg`\n\n```elixir\n# change to the file's directory\n# or somewhere you have write permission\nFile.cd!(__DIR__)\n\nHelper.download!(\n  \"http://dl.caffe.berkeleyvision.org/bvlc_googlenet.caffemodel\",\n  \"bvlc_googlenet.caffemodel\"\n)\n\nHelper.download!(\n  \"https://raw.githubusercontent.com/opencv/opencv_extra/master/testdata/dnn/bvlc_googlenet.prototxt\",\n  \"bvlc_googlenet.prototxt\"\n)\n\nHelper.download!(\n  \"https://raw.githubusercontent.com/opencv/opencv/master/samples/data/dnn/classification_classes_ILSVRC2012.txt\",\n  \"classification_classes_ILSVRC2012.txt\"\n)\n\nHelper.download!(\"https://docs.opencv.org/4.5.4/space_shuttle.jpg\", \"space_shuttle.jpg\")\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```","ref":"dnn-googlenet.html#download-googlenet-model-and-a-test-image"},{"type":"extras","title":"Read Class Names - Evision.DNN Example - Object Detection Task with GoogleNet","doc":"```elixir\nclasses =\n  \"classification_classes_ILSVRC2012.txt\"\n  |> File.read!()\n  |> String.split(\"\\n\")\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n[\"tench, Tinca tinca\", \"goldfish, Carassius auratus\",\n \"great white shark, white shark, man-eater, man-eating shark, Carcharodon carcharias\",\n \"tiger shark, Galeocerdo cuvieri\", \"hammerhead, hammerhead shark\",\n \"electric ray, crampfish, numbfish, torpedo\", \"stingray\", \"cock\", \"hen\",\n \"ostrich, Struthio camelus\", \"brambling, Fringilla montifringilla\",\n \"goldfinch, Carduelis carduelis\", \"house finch, linnet, Carpodacus mexicanus\", \"junco, snowbird\",\n \"indigo bunting, indigo finch, indigo bird, Passerina cyanea\",\n \"robin, American robin, Turdus migratorius\", \"bulbul\", \"jay\", \"magpie\", \"chickadee\",\n \"water ouzel, dipper\", \"kite\", \"bald eagle, American eagle, Haliaeetus leucocephalus\", \"vulture\",\n \"great grey owl, great gray owl, Strix nebulosa\",\n \"European fire salamander, Salamandra salamandra\", \"common newt, Triturus vulgaris\", \"eft\",\n \"spotted salamander, Ambystoma maculatum\", \"axolotl, mud puppy, Ambystoma mexicanum\",\n \"bullfrog, Rana catesbeiana\", \"tree frog, tree-frog\",\n \"tailed frog, bell toad, ribbed toad, tailed toad, Ascaphus trui\",\n \"loggerhead, loggerhead turtle, Caretta caretta\",\n \"leatherback turtle, leatherback, leathery turtle, Dermochelys coriacea\", \"mud turtle\", \"terrapin\",\n \"box turtle, box tortoise\", \"banded gecko\", \"common iguana, iguana, Iguana iguana\",\n \"American chameleon, anole, Anolis carolinensis\", \"whiptail, whiptail lizard\", \"agama\",\n \"frilled lizard, Chlamydosaurus kingi\", \"alligator lizard\", \"Gila monster, Heloderma suspectum\",\n \"green lizard, Lacerta viridis\", \"African chameleon, Chamaeleo chamaeleon\",\n \"Komodo dragon, Komodo lizard, dragon lizard, giant lizard, Varanus komodoensis\",\n \"African crocodile, Nile crocodile, Crocodylus niloticus\", ...]\n```","ref":"dnn-googlenet.html#read-class-names"},{"type":"extras","title":"Load the GoogLeNet Model - Evision.DNN Example - Object Detection Task with GoogleNet","doc":"```elixir\nalias Evision, as: Cv\n\nmodel =\n  Cv.DNN.readNet(\"bvlc_googlenet.caffemodel\",\n    config: \"bvlc_googlenet.prototxt\",\n    framework: \"\"\n  )\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.DNN.Net{ref: #Reference<0.4003430890.1440088085.55917>}\n```","ref":"dnn-googlenet.html#load-the-googlenet-model"},{"type":"extras","title":"Set Backend and Target - Evision.DNN Example - Object Detection Task with GoogleNet","doc":"```elixir\n# \"0: automatically (by default), \"\n# \"1: Halide language (http://halide-lang.org/), \"\n# \"2: Intel's Deep Learning Inference Engine (https://software.intel.com/openvino-toolkit), \"\n# \"3: OpenCV implementation, \"\n# \"4: VKCOM, \"\n# \"5: CUDA\nmodel = Cv.DNN.Net.setPreferableBackend(model, 0)\n\n# \"0: CPU target (by default), \"\n# \"1: OpenCL, \"\n# \"2: OpenCL fp16 (half-float precision), \"\n# \"3: VPU, \"\n# \"4: Vulkan, \"\n# \"6: CUDA, \"\n# \"7: CUDA fp16 (half-float preprocess)\nmodel = Cv.DNN.Net.setPreferableTarget(model, 0)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.DNN.Net{ref: #Reference<0.4003430890.1440088085.55917>}\n```","ref":"dnn-googlenet.html#set-backend-and-target"},{"type":"extras","title":"Read the Test Image and Set It as the Input - Evision.DNN Example - Object Detection Task with GoogleNet","doc":"```elixir\nmat = Cv.imread(\"space_shuttle.jpg\")\n\nblob =\n  Cv.DNN.blobFromImage(mat,\n    scalefactor: 1,\n    swapRB: true,\n    mean: [-104, -117, -123],\n    size: [224, 224]\n  )\n\nmodel = Cv.DNN.Net.setInput(model, blob, name: \"\", scalefactor: 1.0, mean: [0, 0, 0])\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.DNN.Net{ref: #Reference<0.4003430890.1440088085.55917>}\n```","ref":"dnn-googlenet.html#read-the-test-image-and-set-it-as-the-input"},{"type":"extras","title":"Run the Forward Function - Evision.DNN Example - Object Detection Task with GoogleNet","doc":"```elixir\nstart_time = :os.system_time(:millisecond)\npred = Cv.DNN.Net.forward(model, outputName: \"\")\nend_time = :os.system_time(:millisecond)\n\"Inference time=>#{end_time - start_time} ms\"\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n\"Inference time=>49 ms\"\n```","ref":"dnn-googlenet.html#run-the-forward-function"},{"type":"extras","title":"Get the Classification Result - Evision.DNN Example - Object Detection Task with GoogleNet","doc":"```elixir\npred = pred |> Cv.Mat.to_nx(Nx.BinaryBackend)\npred_class_id = pred |> Nx.argmax() |> Nx.to_flat_list() |> Enum.at(0)\n\nconfidence =\n  pred\n  |> Nx.take(Nx.tensor(pred_class_id), axis: 1)\n  |> Nx.to_flat_list()\n  |> Enum.at(0)\n\nclass_label =\n  classes\n  |> Enum.at(pred_class_id)\n\n\"Predict result: #{class_label}=>#{Float.round(confidence * 100, 2)}\"\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n\"Predict result: space shuttle=>99.13\"\n```","ref":"dnn-googlenet.html#get-the-classification-result"},{"type":"extras","title":"Evision.DNN Example - Generic Object Detection Task","doc":"<!-- vim: syntax=markdown -->\n\n<!-- livebook:{\"persist_outputs\":true} -->\n\n# Evision.DNN Example - Generic Object Detection Task\n\n```elixir\n# set `EVISION_PREFER_PRECOMPILED` to `false`\n# if you prefer `:evision` to be compiled from source\n# note that to compile from source, you may need at least 1GB RAM\n# System.put_env(\"EVISION_PREFER_PRECOMPILED\", \"false\")\n\nMix.install([\n  {:evision, \"~> 0.2\"},\n  {:req, \"~> 0.3\"},\n  {:kino, \"~> 0.7\"}\n], system_env: [\n  # optional, defaults to `true`\n  # set `EVISION_PREFER_PRECOMPILED` to `false`\n  # if you prefer `:evision` to be compiled from source\n  # note that to compile from source, you may need at least 1GB RAM\n  {\"EVISION_PREFER_PRECOMPILED\", true},\n\n  # optional, defaults to `true`\n  # set `EVISION_ENABLE_CONTRIB` to `false`\n  # if you don't need modules from `opencv_contrib`\n  {\"EVISION_ENABLE_CONTRIB\", true},\n\n  # optional, defaults to `false`\n  # set `EVISION_ENABLE_CUDA` to `true`\n  # if you wish to use CUDA related functions\n  # note that `EVISION_ENABLE_CONTRIB` also has to be `true`\n  # because cuda related modules come from the `opencv_contrib` repo\n  {\"EVISION_ENABLE_CUDA\", false},\n\n  # required when\n  # - `EVISION_ENABLE_CUDA` is `true`\n  # - and `EVISION_PREFER_PRECOMPILED` is `true`\n  #\n  # set `EVISION_CUDA_VERSION` to the version that matches\n  # your local CUDA runtime version\n  #\n  # current available versions are\n  # - 118\n  # - 121\n  {\"EVISION_CUDA_VERSION\", \"118\"},\n\n  # require for Windows users when\n  # - `EVISION_ENABLE_CUDA` is `true`\n  # set `EVISION_CUDA_RUNTIME_DIR` to the directory that contains\n  # CUDA runtime libraries\n  {\"EVISION_CUDA_RUNTIME_DIR\", \"C:/PATH/TO/CUDA/RUNTIME\"}\n])\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```","ref":"dnn-detection-model.html"},{"type":"extras","title":"Define Some Helper Functions - Evision.DNN Example - Generic Object Detection Task","doc":"```elixir\ndefmodule Helper do\n  def download!(url, save_as, overwrite? \\\\ false) do\n    unless File.exists?(save_as) do\n      Req.get!(url, http_errors: :raise, output: save_as, cache: not overwrite?)\n    end\n\n    :ok\n  end\nend\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n{:module, Helper, <<70, 79, 82, 49, 0, 0, 10, ...>>, {:download!, 3}}\n```","ref":"dnn-detection-model.html#define-some-helper-functions"},{"type":"extras","title":"Write the Generic DetectionModel Module - Evision.DNN Example - Generic Object Detection Task","doc":"```elixir\nalias Evision, as: Cv\n\n# change to the file's directory\n# or somewhere you have write permission\nFile.cd!(__DIR__)\n\ndefmodule DetectionModel do\n  def visualise_pred(mat, _labels, []), do: {:ok, mat}\n\n  def visualise_pred(mat, labels, [translated_out | outs]) do\n    {:ok, mat} = _visualise_pred(mat, labels, translated_out)\n    visualise_pred(mat, labels, outs)\n  end\n\n  defp _visualise_pred(mat, _labels, []), do: {:ok, mat}\n\n  defp _visualise_pred(mat, labels, [{class_id, confidence, l, t, r, b} | outs]) do\n    confidence = \"#{Float.round(confidence, 2)}\"\n    label = Enum.at(labels, class_id)\n    text = \"#{label}: #{confidence}\"\n    mat = Cv.rectangle(mat, {l, t}, {r, b}, {255, 0, 0})\n\n    {{label_weight, label_height}, baseline} =\n      Cv.getTextSize(text, Cv.Constant.cv_FONT_HERSHEY_SIMPLEX(), 0.5, 1)\n\n    label_weight = trunc(label_weight)\n    label_height = trunc(label_height)\n    top = max(t, label_height)\n\n    mat =\n      Cv.rectangle(mat, {l, top - label_height}, {l + label_weight, top + baseline}, {\n        255,\n        255,\n        255\n      })\n\n    mat = Cv.putText(mat, text, {l, top}, Cv.Constant.cv_FONT_HERSHEY_SIMPLEX(), 0.5, {0, 0, 255})\n\n    _visualise_pred(mat, labels, outs)\n  end\n\n  def postprocess(mat, detections, net, confidence_threshold) do\n    out_layers = Cv.DNN.Net.getUnconnectedOutLayers(net)\n    out_layer = Cv.DNN.Net.getLayer(net, Enum.at(out_layers, 0))\n    out_layer_type = Cv.DNN.Layer.get_type(out_layer) |> IO.iodata_to_binary()\n    _postprocess(mat, detections, net, confidence_threshold, out_layer_type, [])\n  end\n\n  defp _postprocess(_mat, [], _net, _confidence_threshold, <<\"DetectionOutput\">>, acc),\n    do: {:ok, Enum.reverse(acc)}\n\n  defp _postprocess(\n         %Evision.Mat{shape: {h, w, _}} = mat,\n         [outs | detections],\n         net,\n         confidence_threshold,\n         <<\"DetectionOutput\">>,\n         acc\n       ) do\n    data = Cv.Mat.to_binary(outs)\n    {:ok, translated_outs} = _translate_outs(confidence_threshold, data, h, w, [])\n\n    _postprocess(mat, detections, net, confidence_threshold, \"DetectionOutput\", [\n      translated_outs | acc\n    ])\n  end\n\n  defp _translate_outs(_confidence_threshold, <<>>, _h, _w, acc), do: {:ok, acc}\n\n  defp _translate_outs(\n         confidence_threshold,\n         <<_batch_id::float-size(32)-little, class_id::float-size(32)-little,\n           confidence::float-size(32)-little, left::float-size(32)-little,\n           top::float-size(32)-little, right::float-size(32)-little,\n           bottom::float-size(32)-little, rest::binary>>,\n         h,\n         w,\n         acc\n       ) do\n    if confidence > confidence_threshold do\n      [class_id, l, t, r, b] =\n        Enum.map([class_id, left, top, right, bottom], fn f -> trunc(f) end)\n\n      width = r - l + 1\n      height = b - t + 1\n\n      [l, t, r, b] =\n        if width <= 2 or height <= 2 do\n          Enum.map([left * w, top * h, right * w, bottom * h], fn f -> trunc(f) end)\n        else\n          [l, t, r, b]\n        end\n\n      _translate_outs(confidence_threshold, rest, h, w, [\n        {class_id - 1, confidence, l, t, r, b} | acc\n      ])\n    else\n      _translate_outs(confidence_threshold, rest, h, w, acc)\n    end\n  end\n\n  def get_labels(class_label_file) do\n    class_label_file\n    |> File.read!()\n    |> String.split(\"\\n\")\n  end\n\n  def predict(mat, model, out_names, opts \\\\ []) do\n    blob = Cv.DNN.blobFromImage(mat, opts)\n\n    model = Cv.DNN.Net.setInput(model, blob, name: \"\", scalefactor: 1.0, mean: [0, 0, 0])\n\n    start_time = :os.system_time(:millisecond)\n    detections = Cv.DNN.Net.forward(model, outBlobNames: out_names)\n    end_time = :os.system_time(:millisecond)\n    IO.puts(\"Inference time=>#{end_time - start_time} ms\")\n    {:ok, mat, detections}\n  end\n\n  def predict_file(image_file, model, out_names, opts \\\\ []) do\n    predict(Cv.imread(image_file), model, out_names, opts)\n  end\n\n  def get_model(params, config, framework \\\\ \"\") do\n    net =\n      Cv.DNN.readNet(params,\n        config: config,\n        framework: framework\n      )\n\n    out_names = Cv.DNN.Net.getUnconnectedOutLayersNames(net)\n    {:ok, net, out_names}\n  end\nend\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n{:module, DetectionModel, <<70, 79, 82, 49, 0, 0, 34, ...>>, {:get_model, 3}}\n```","ref":"dnn-detection-model.html#write-the-generic-detectionmodel-module"},{"type":"extras","title":"Example Detect Model: SSD MobileNetv2 - Evision.DNN Example - Generic Object Detection Task","doc":"Basic steps:\n\n1. Download model weights and config file, as well as a list of class names.\n2. `DetectionModel.get_model`.\n3. `DetectionModel.get_labels`.\n4. `DetectionModel.predict` and specify some preprocessing parameters.\n5. `DetectionModel.postprocess`. This translates nerual network outputs to data that is easier to read/use.\n6. `DetectionModel.visualise_pred` if you want to see the result.\n\n```elixir\ndefmodule SSDMobileNetV2 do\n  defp download_model() do\n    Helper.download!(\n      \"https://raw.githubusercontent.com/opencv/opencv_extra/master/testdata/dnn/ssd_mobilenet_v2_coco_2018_03_29.pbtxt\",\n      \"ssd_mobilenet_v2_coco_2018_03_29.pbtxt\"\n    )\n\n    Helper.download!(\n      \"https://raw.githubusercontent.com/cocoa-xu/evision/main/test/testdata/models/coco_names.txt\",\n      \"coco_names.txt\"\n    )\n\n    graph_pb = \"ssd_mobilenet_v2_coco_2018_03_29/frozen_inference_graph.pb\"\n\n    if !File.exists?(graph_pb) do\n      Helper.download!(\n        \"http://download.tensorflow.org/models/object_detection/ssd_mobilenet_v2_coco_2018_03_29.tar.gz\",\n        \"ssd_mobilenet_v2_coco_2018_03_29.tar.gz\"\n      )\n\n      \"ssd_mobilenet_v2_coco_2018_03_29.tar.gz\"\n      |> File.read!()\n      |> :zlib.gunzip()\n      |> then(&:erl_tar.extract({:binary, &1}, [:memory, :compressed]))\n      |> elem(1)\n      |> Enum.map(fn {filename, content} -> {List.to_string(filename), content} end)\n      |> Enum.reject(\n        &(elem(&1, 0) != \"ssd_mobilenet_v2_coco_2018_03_29/frozen_inference_graph.pb\")\n      )\n      |> Enum.at(0)\n      |> then(fn {_filename, content} ->\n        File.mkdir_p!(\"ssd_mobilenet_v2_coco_2018_03_29\")\n        File.write!(graph_pb, content)\n        :ok\n      end)\n    else\n      :ok\n    end\n  end\n\n  def get_detection_model() do\n    :ok = download_model()\n    graph_pb = \"ssd_mobilenet_v2_coco_2018_03_29/frozen_inference_graph.pb\"\n\n    {:ok, net, out_names} =\n      DetectionModel.get_model(\n        graph_pb,\n        \"ssd_mobilenet_v2_coco_2018_03_29.pbtxt\"\n      )\n\n    labels = DetectionModel.get_labels(\"coco_names.txt\")\n    {net, out_names, labels}\n  end\n\n  def predict_file_and_show(filename, confidence_threshold \\\\ 0.5) when is_binary(filename) do\n    {net, out_names, labels} = get_detection_model()\n\n    {:ok, mat, detections} =\n      DetectionModel.predict_file(filename, net, out_names,\n        scalefactor: 1,\n        swapRB: true,\n        mean: [0, 0, 0],\n        size: [300, 300]\n      )\n\n    {:ok, translated_outs} =\n      DetectionModel.postprocess(mat, detections, net, confidence_threshold)\n\n    {:ok, mat} = DetectionModel.visualise_pred(mat, labels, translated_outs)\n    mat\n  end\n\n  def predict_and_show(net, out_names, labels, mat, confidence_threshold \\\\ 0.5)\n      when is_reference(mat) do\n    {:ok, mat, detections} =\n      DetectionModel.predict(mat, net, out_names,\n        scalefactor: 1,\n        swapRB: true,\n        mean: [0, 0, 0],\n        size: [300, 300]\n      )\n\n    {:ok, translated_outs} =\n      DetectionModel.postprocess(mat, detections, net, confidence_threshold)\n\n    {:ok, mat} = DetectionModel.visualise_pred(mat, labels, translated_outs)\n    mat\n  end\nend\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n{:module, SSDMobileNetV2, <<70, 79, 82, 49, 0, 0, 22, ...>>, {:predict_and_show, 5}}\n```","ref":"dnn-detection-model.html#example-detect-model-ssd-mobilenetv2"},{"type":"extras","title":"Detect Objects in An Image - Evision.DNN Example - Generic Object Detection Task","doc":"```elixir\nHelper.download!(\n  \"https://raw.githubusercontent.com/cocoa-xu/evision/main/test/dnn_detection_test.jpg\",\n  \"dnn_detection_test.jpg\"\n)\n\n%Evision.Mat{type: type} = mat = SSDMobileNetV2.predict_file_and_show(\"dnn_detection_test.jpg\")\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\nInference time=>35 ms\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 3,\n  dims: 2,\n  type: {:u, 8},\n  raw_type: 16,\n  shape: {586, 872, 3},\n  ref: #Reference<0.1834280076.3317825552.216669>\n}\n```\n\n```elixir\nCv.imencode(\".png\", mat)\n|> Kino.Image.new(:png)\n```","ref":"dnn-detection-model.html#detect-objects-in-an-image"},{"type":"extras","title":"Detect Objects in a Video Stream - Evision.DNN Example - Generic Object Detection Task","doc":"```elixir\n# if you have a camera available\n# uncomment the line below\n# video = Cv.VideoCapture.videoCapture(0)\n\n# or the OpenCV library you compiled can decode video files\n# uncomment the line below\n# video = Cv.VideoCapture.videoCapture(\"/path/to/your/video/file\")\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\nnil\n```\n\n```elixir\ndefmodule VideoDetection do\n  def detect(video, widget, max_frames \\\\ 30 * 60)\n      when is_reference(video) and is_integer(max_frames) do\n    {net, out_names, labels} = SSDMobileNetV2.get_detection_model()\n    frame_read = Cv.VideoCapture.read(video)\n    _detect(net, out_names, labels, frame_read, video, widget, max_frames)\n  end\n\n  defp _detect(_, _, _, _, _, _, 0), do: :ok\n\n  defp _detect(net, out_names, labels, frame, video, widget, left_frames)\n       when left_frames > 0 or left_frames < 0 do\n    mat = SSDMobileNetV2.predict_and_show(net, out_names, labels, frame)\n\n    Cv.imencode(\".png\", mat)\n    |> Kino.Image.new(:png)\n    |> then(&Kino.Frame.render(widget, &1))\n\n    frame_read = Cv.VideoCapture.read(video)\n\n    if left_frames > 0 do\n      _detect(net, out_names, labels, frame_read, video, widget, left_frames - 1)\n    else\n      _detect(net, out_names, labels, frame_read, video, widget, left_frames)\n    end\n  end\nend\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n{:module, VideoDetection, <<70, 79, 82, 49, 0, 0, 12, ...>>, {:_detect, 7}}\n```","ref":"dnn-detection-model.html#detect-objects-in-a-video-stream"},{"type":"extras","title":"Run the detection - Evision.DNN Example - Generic Object Detection Task","doc":"```elixir\nwidget = Kino.Frame.new() |> Kino.render()\n# read 1,800 frames at most\n# change the number to negative values to\n# detect objects until OpenCV cannot read\n# new frame from the video stream\nVideoDetection.detect(video, widget, 1800)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n\"Inference time=>48 ms\"\n```","ref":"dnn-detection-model.html#run-the-detection"},{"type":"extras","title":"Evision.DNN Example - Benchmark using Densenet121","doc":"<!-- vim: syntax=markdown -->\n\n<!-- livebook:{\"persist_outputs\":true} -->\n\n# Evision.DNN Example - Benchmark using Densenet121\n\n```elixir\nMix.install([\n  {:evision, \"~> 0.2\"},\n  {:kino, \"~> 0.7\"},\n  {:req, \"~> 0.3\"}\n], system_env: [\n  # optional, defaults to `true`\n  # set `EVISION_PREFER_PRECOMPILED` to `false`\n  # if you prefer `:evision` to be compiled from source\n  # note that to compile from source, you may need at least 1GB RAM\n  {\"EVISION_PREFER_PRECOMPILED\", true},\n\n  # optional, defaults to `true`\n  # set `EVISION_ENABLE_CONTRIB` to `false`\n  # if you don't need modules from `opencv_contrib`\n  {\"EVISION_ENABLE_CONTRIB\", true},\n\n  # optional, defaults to `false`\n  # set `EVISION_ENABLE_CUDA` to `true`\n  # if you wish to use CUDA related functions\n  # note that `EVISION_ENABLE_CONTRIB` also has to be `true`\n  # because cuda related modules come from the `opencv_contrib` repo\n  {\"EVISION_ENABLE_CUDA\", false},\n\n  # required when \n  # - `EVISION_ENABLE_CUDA` is `true`\n  # - and `EVISION_PREFER_PRECOMPILED` is `true`\n  #\n  # set `EVISION_CUDA_VERSION` to the version that matches \n  # your local CUDA runtime version\n  #\n  # current available versions are\n  # - 118\n  # - 121\n  {\"EVISION_CUDA_VERSION\", \"118\"},\n\n  # require for Windows users when \n  # - `EVISION_ENABLE_CUDA` is `true`\n  # set `EVISION_CUDA_RUNTIME_DIR` to the directory that contains\n  # CUDA runtime libraries\n  {\"EVISION_CUDA_RUNTIME_DIR\", \"C:/PATH/TO/CUDA/RUNTIME\"}\n])\n```","ref":"densenet121_benchmark.html"},{"type":"extras","title":"Define Some Helper Functions - Evision.DNN Example - Benchmark using Densenet121","doc":"```elixir\ndefmodule Helper do\n  def download!(url, save_as, overwrite? \\\\ false) do\n    unless File.exists?(save_as) do\n      Req.get!(url, http_errors: :raise, output: save_as, cache: not overwrite?)\n    end\n\n    :ok\n  end\nend\n```","ref":"densenet121_benchmark.html#define-some-helper-functions"},{"type":"extras","title":"Write the Benchmark Module - Evision.DNN Example - Benchmark using Densenet121","doc":"```elixir\nalias Evision, as: Cv\n\ndefmodule DetectionModel do\n  def benchmark(times, mat, model, out_names, opts \\\\ []) do\n    mean = opts[:mean] || [0, 0, 0]\n    scalefactor = opts[:scalefactor] || 1.0\n\n    for _ <- 1..times, reduce: {[], []} do\n      {forward_only, all} ->\n        start_time_1 = :os.system_time(:millisecond)\n        blob = Cv.DNN.blobFromImage(mat, opts)\n        model = Cv.DNN.Net.setInput(model, blob, name: \"\", scalefactor: scalefactor, mean: mean)\n\n        start_time_2 = :os.system_time(:millisecond)\n        _detections = Cv.DNN.Net.forward(model, outBlobNames: out_names)\n        end_time = :os.system_time(:millisecond)\n\n        inference_time_1 = end_time - start_time_1\n        inference_time_2 = end_time - start_time_2\n        IO.puts(\"Inference time=>#{inference_time_2} ms\")\n        {[inference_time_2 | forward_only], [inference_time_1 | all]}\n    end\n  end\n\n  def get_model(filename) do\n    net = Cv.DNN.readNetFromONNX(filename)\n    out_names = Cv.DNN.Net.getUnconnectedOutLayersNames(net)\n    {:ok, net, out_names}\n  end\nend\n```","ref":"densenet121_benchmark.html#write-the-benchmark-module"},{"type":"extras","title":"Write the DenseNet121 Module - Evision.DNN Example - Benchmark using Densenet121","doc":"```elixir\ndefmodule DenseNet121 do\n  defp download_model(opset_version) when opset_version in [3, 6, 7, 8, 9, 12] do\n    onnx_filename = \"densenet-#{opset_version}.onnx\"\n    test_filename = \"CyprusShorthair.jpg\"\n\n    Helper.download!(\n      \"https://github.com/onnx/models/raw/main/vision/classification/densenet-121/model/densenet-#{opset_version}.onnx\",\n      onnx_filename\n    )\n\n    Helper.download!(\n      \"https://upload.wikimedia.org/wikipedia/commons/b/b9/CyprusShorthair.jpg\",\n      \"CyprusShorthair.jpg\"\n    )\n\n    {onnx_filename, test_filename}\n  end\n\n  def get_detection_model(opset_version \\\\ 12) do\n    {onnx_filename, test_filename} = download_model(opset_version)\n    {:ok, net, out_names} = DetectionModel.get_model(onnx_filename)\n    test_mat = Cv.imread(test_filename)\n    {net, out_names, test_mat}\n  end\n\n  def benchmark(times, opset_version \\\\ 12) do\n    {net, out_names, test_mat} = get_detection_model(opset_version)\n\n    DetectionModel.benchmark(times, test_mat, net, out_names,\n      scalefactor: 1,\n      swapRB: true,\n      mean: {128, 128, 128},\n      size: {224, 224}\n    )\n  end\nend\n```","ref":"densenet121_benchmark.html#write-the-densenet121-module"},{"type":"extras","title":"Load and Run - Evision.DNN Example - Benchmark using Densenet121","doc":"```elixir\n{forward_only, all} = DenseNet121.benchmark(50)\navg_forward_only = Enum.sum(forward_only) / Enum.count(forward_only)\navg_all = Enum.sum(all) / Enum.count(all)\n{avg_forward_only, avg_all}\n```","ref":"densenet121_benchmark.html#load-and-run"},{"type":"extras","title":"Evision.ML.SVM Example - Support Vector Machine","doc":"<!-- vim: syntax=markdown -->\n\n<!-- livebook:{\"persist_outputs\":true} -->\n\n# Evision.ML.SVM Example - Support Vector Machine\n\n```elixir\nMix.install([\n  {:evision, \"~> 0.2\"},\n  {:kino, \"~> 0.7\"},\n  {:req, \"~> 0.3\"}\n], system_env: [\n  # optional, defaults to `true`\n  # set `EVISION_PREFER_PRECOMPILED` to `false`\n  # if you prefer `:evision` to be compiled from source\n  # note that to compile from source, you may need at least 1GB RAM\n  {\"EVISION_PREFER_PRECOMPILED\", true},\n\n  # optional, defaults to `true`\n  # set `EVISION_ENABLE_CONTRIB` to `false`\n  # if you don't need modules from `opencv_contrib`\n  {\"EVISION_ENABLE_CONTRIB\", true},\n\n  # optional, defaults to `false`\n  # set `EVISION_ENABLE_CUDA` to `true`\n  # if you wish to use CUDA related functions\n  # note that `EVISION_ENABLE_CONTRIB` also has to be `true`\n  # because cuda related modules come from the `opencv_contrib` repo\n  {\"EVISION_ENABLE_CUDA\", false},\n\n  # required when\n  # - `EVISION_ENABLE_CUDA` is `true`\n  # - and `EVISION_PREFER_PRECOMPILED` is `true`\n  #\n  # set `EVISION_CUDA_VERSION` to the version that matches\n  # your local CUDA runtime version\n  #\n  # current available versions are\n  # - 118\n  # - 121\n  {\"EVISION_CUDA_VERSION\", \"118\"},\n\n  # require for Windows users when\n  # - `EVISION_ENABLE_CUDA` is `true`\n  # set `EVISION_CUDA_RUNTIME_DIR` to the directory that contains\n  # CUDA runtime libraries\n  {\"EVISION_CUDA_RUNTIME_DIR\", \"C:/PATH/TO/CUDA/RUNTIME\"}\n])\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n:ok\n```","ref":"ml-svm.html"},{"type":"extras","title":"Set Up Training Data - Evision.ML.SVM Example - Support Vector Machine","doc":"This example is based on the [Introduction to Support Vector Machines](https://docs.Cv.org/4.x/d1/d73/tutorial_introduction_to_svm.html) from Cv.\n\n<!-- livebook:{\"break_markdown\":true} -->\n\n```elixir\nalias Evision, as: Cv\n\nlabels = [1, -1, -1, -1]\ntraining_data = [[501, 10], [255, 10], [501, 255], [10, 501]]\n\nlabels_mat = Cv.Mat.literal(labels, :s32)\ntraining_data_mat = Cv.Mat.literal(training_data, :f32)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n%Evision.Mat{\n  channels: 1,\n  dims: 2,\n  type: {:f, 32},\n  raw_type: 5,\n  shape: {4, 2},\n  ref: #Reference<0.1481828880.2785148948.120970>\n}\n```","ref":"ml-svm.html#set-up-training-data"},{"type":"extras","title":"Create an SVM and Train It With the Data - Evision.ML.SVM Example - Support Vector Machine","doc":"```elixir\nsvm = Cv.ML.SVM.create()\nsvm = Cv.ML.SVM.setType(svm, Cv.Constant.cv_C_SVC())\nsvm = Cv.ML.SVM.setKernel(svm, Cv.Constant.cv_LINEAR())\nsvm = Cv.ML.SVM.setTermCriteria(svm, {Cv.Constant.cv_MAX_ITER(), 100, 0.000001})\ntrue = Cv.ML.SVM.train(svm, training_data_mat, Cv.Constant.cv_ROW_SAMPLE(), labels_mat)\ntrue = Cv.ML.SVM.isTrained(svm)\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\ntrue\n```","ref":"ml-svm.html#create-an-svm-and-train-it-with-the-data"},{"type":"extras","title":"Get Support Vectors - Evision.ML.SVM Example - Support Vector Machine","doc":"```elixir\n%Evision.Mat{shape: {rows, cols}} = sv = Cv.ML.SVM.getUncompressedSupportVectors(svm)\nsv_binary = Cv.Mat.to_binary(sv)\nfloat_bytes = 4\n\nsupport_vector =\n  for i <- (rows - 1)..0, reduce: [] do\n    support_vector ->\n      current_vector =\n        for j <- (cols - 1)..0, reduce: [] do\n          vec ->\n            < > =\n              :binary.part(sv_binary, (i * cols + j) * float_bytes, 4)\n\n            [trunc(float_data) | vec]\n        end\n\n      [current_vector | support_vector]\n  end\n\n[[501, 10], [255, 10], [501, 255]] = support_vector\nsupport_vector\n```\n\n<!-- livebook:{\"output\":true} -->\n\n```\n[[501, 10], [255, 10], [501, 255]]\n```","ref":"ml-svm.html#get-support-vectors"},{"type":"extras","title":"Visualise the Training Result in A Response Map - Evision.ML.SVM Example - Support Vector Machine","doc":"```elixir\ngreen = [0, 255, 0]\nblue = [255, 0, 0]\nwidth = 512\nheight = 512\n\nresponse_data =\n  for x <- (width - 1)..0, y <- (height - 1)..0, reduce: [] do\n    acc ->\n      sample =\n        Cv.Mat.from_binary(\n          < >,\n          {:f, 32},\n          1,\n          2,\n          1\n        )\n\n      {_, %Cv.Mat{shape: {1, 1}} = response_mat} = Cv.ML.SVM.predict(svm, sample)\n      < > = Cv.Mat.to_binary(response_mat)\n      response = trunc(response)\n\n      case response do\n        1 ->\n          [green | acc]\n\n        -1 ->\n          [blue | acc]\n      end\n  end\n\nresponse_data = response_data |> List.flatten() |> IO.iodata_to_binary()\nresponse_map = Cv.Mat.from_binary(response_data, {:u, 8}, height, width, 3)\n\n# show the training data\nthickness = 1\n\nresponse_map =\n  Cv.circle(response_map, List.to_tuple(Enum.at(training_data, 0)), 5, {0, 0, 0},\n    thickness: thickness\n  )\n\nresponse_map =\n  Cv.circle(response_map, List.to_tuple(Enum.at(training_data, 1)), 5, {255, 255, 255},\n    thickness: thickness\n  )\n\nresponse_map =\n  Cv.circle(response_map, List.to_tuple(Enum.at(training_data, 2)), 5, {255, 255, 255},\n    thickness: thickness\n  )\n\nresponse_map =\n  Cv.circle(response_map, List.to_tuple(Enum.at(training_data, 3)), 5, {255, 255, 255},\n    thickness: thickness\n  )\n\n# show support vectors\nresponse_map =\n  Cv.circle(response_map, List.to_tuple(Enum.at(support_vector, 0)), 6, {128, 128, 128},\n    thickness: thickness\n  )\n\nresponse_map =\n  Cv.circle(response_map, List.to_tuple(Enum.at(support_vector, 1)), 6, {128, 128, 128},\n    thickness: thickness\n  )\n\nresponse_map =\n  Cv.circle(response_map, List.to_tuple(Enum.at(support_vector, 2)), 6, {128, 128, 128},\n    thickness: thickness\n  )\n\nCv.imencode(\".png\", response_map)\n|> Kino.Image.new(:png)\n```","ref":"ml-svm.html#visualise-the-training-result-in-a-response-map"},{"type":"extras","title":"Evision.ML Example - Decision Tree and Random Forest","doc":"<!-- vim: syntax=markdown -->\n\n<!-- livebook:{\"persist_outputs\":true} -->\n\n# Evision.ML Example - Decision Tree and Random Forest\n\n```elixir\nMix.install([\n  {:evision, \"~> 0.2\"},\n  {:kino, \"~> 0.7\"},\n  {:scidata, \"~> 0.1\"},\n  {:nx, \"~> 0.4\", override: true},\n  {:scholar, \"~> 0.1\", github: \"elixir-nx/scholar\"}\n], system_env: [\n  # optional, defaults to `true`\n  # set `EVISION_PREFER_PRECOMPILED` to `false`\n  # if you prefer `:evision` to be compiled from source\n  # note that to compile from source, you may need at least 1GB RAM\n  {\"EVISION_PREFER_PRECOMPILED\", true},\n\n  # optional, defaults to `true`\n  # set `EVISION_ENABLE_CONTRIB` to `false`\n  # if you don't need modules from `opencv_contrib`\n  {\"EVISION_ENABLE_CONTRIB\", true},\n\n  # optional, defaults to `false`\n  # set `EVISION_ENABLE_CUDA` to `true`\n  # if you wish to use CUDA related functions\n  # note that `EVISION_ENABLE_CONTRIB` also has to be `true`\n  # because cuda related modules come from the `opencv_contrib` repo\n  {\"EVISION_ENABLE_CUDA\", false},\n\n  # required when \n  # - `EVISION_ENABLE_CUDA` is `true`\n  # - and `EVISION_PREFER_PRECOMPILED` is `true`\n  #\n  # set `EVISION_CUDA_VERSION` to the version that matches \n  # your local CUDA runtime version\n  #\n  # current available versions are\n  # - 118\n  # - 121\n  {\"EVISION_CUDA_VERSION\", \"118\"},\n\n  # require for Windows users when \n  # - `EVISION_ENABLE_CUDA` is `true`\n  # set `EVISION_CUDA_RUNTIME_DIR` to the directory that contains\n  # CUDA runtime libraries\n  {\"EVISION_CUDA_RUNTIME_DIR\", \"C:/PATH/TO/CUDA/RUNTIME\"}\n])\n```","ref":"ml-decision_tree_and_random_forest.html"},{"type":"extras","title":"Register SmartCells - Evision.ML Example - Decision Tree and Random Forest","doc":"```elixir\n:ok = Evision.SmartCell.register_smartcells()\n```","ref":"ml-decision_tree_and_random_forest.html#register-smartcells"},{"type":"extras","title":"Download the Dataset - Evision.ML Example - Decision Tree and Random Forest","doc":"","ref":"ml-decision_tree_and_random_forest.html#download-the-dataset"},{"type":"extras","title":"Get the Wine dataset with `Scidata` - Evision.ML Example - Decision Tree and Random Forest","doc":"```elixir\n{features, labels} = Scidata.Wine.download()\n:ok\n```","ref":"ml-decision_tree_and_random_forest.html#get-the-wine-dataset-with-scidata"},{"type":"extras","title":"Make a dataset with `Evision.ML.TrainData` - Evision.ML Example - Decision Tree and Random Forest","doc":"<!-- livebook:{\"attrs\":{\"data_layout\":\"row\",\"shuffle_dataset\":true,\"split_ratio\":0.8,\"to_variable\":\"dataset\",\"x\":\"features\",\"x_type\":\"f32\",\"y\":\"labels\",\"y_type\":\"s32\"},\"kind\":\"Elixir.Evision.SmartCell.ML.TrainData\",\"livebook_object\":\"smart_cell\"} -->\n\n```elixir\ndataset =\n  Evision.ML.TrainData.create(\n    Evision.Mat.from_nx(Nx.tensor(features, type: :f32, backend: Evision.Backend)),\n    Evision.Constant.cv_ROW_SAMPLE(),\n    Evision.Mat.from_nx(Nx.tensor(labels, type: :s32, backend: Evision.Backend))\n  )\n  |> Evision.ML.TrainData.setTrainTestSplitRatio(0.8, shuffle: true)\n\nIO.puts(\"#Samples: #{Evision.ML.TrainData.getNSamples(dataset)}\")\nIO.puts(\"#Training samples: #{Evision.ML.TrainData.getNTrainSamples(dataset)}\")\nIO.puts(\"#Test samples: #{Evision.ML.TrainData.getNTestSamples(dataset)}\")\n```","ref":"ml-decision_tree_and_random_forest.html#make-a-dataset-with-evision-ml-traindata"},{"type":"extras","title":"Train the Dataset with Decision Tree, `Evision.ML.DTrees` - Evision.ML Example - Decision Tree and Random Forest","doc":"<!-- livebook:{\"attrs\":{\"cv_folds\":0,\"data_from\":\"traindata_var\",\"max_categories\":3,\"max_depth\":8,\"min_sample_count\":10,\"to_variable\":\"dtree\",\"traindata_var\":\"dataset\"},\"kind\":\"Elixir.Evision.SmartCell.ML.DTrees\",\"livebook_object\":\"smart_cell\"} -->\n\n```elixir\ndtree =\n  Evision.ML.DTrees.create()\n  |> Evision.ML.DTrees.setMaxDepth(8)\n  |> Evision.ML.DTrees.setMaxCategories(3)\n  |> Evision.ML.DTrees.setCVFolds(0)\n  |> Evision.ML.DTrees.setMinSampleCount(10)\n\n(\n  Evision.ML.DTrees.train(dtree, dataset)\n\n  dtree\n  |> Evision.ML.DTrees.calcError(dataset, false)\n  |> then(&IO.puts(\"Training Error: #{elem(&1, 0)}\"))\n\n  dtree\n  |> Evision.ML.DTrees.calcError(dataset, true)\n  |> then(&IO.puts(\"Test Error: #{elem(&1, 0)}\"))\n)\n```","ref":"ml-decision_tree_and_random_forest.html#train-the-dataset-with-decision-tree-evision-ml-dtrees"},{"type":"extras","title":"Calculate Confusion Matrix - Evision.ML Example - Decision Tree and Random Forest","doc":"```elixir\n{_test_error, results} = Evision.ML.DTrees.calcError(dtree, dataset, true)\n\ny_true =\n  Evision.Mat.to_nx(results, Nx.BinaryBackend)\n  |> Nx.reshape({:auto})\n  |> Nx.as_type(:s32)\n\ny_pred =\n  Evision.Mat.to_nx(Evision.ML.TrainData.getTestResponses(dataset), Nx.BinaryBackend)\n  |> Nx.reshape({:auto})\n  |> Nx.as_type(:s32)\n\nScholar.Metrics.confusion_matrix(y_true, y_pred, num_classes: 3)\n```","ref":"ml-decision_tree_and_random_forest.html#calculate-confusion-matrix"},{"type":"extras","title":"Save the Trained Model and Load It Back - Evision.ML Example - Decision Tree and Random Forest","doc":"It's also possible to save the trained model to a file and load it back!\n\n```elixir\n# save to file\nfilename = Path.join(__DIR__, \"dtree.bin\")\nEvision.ML.DTrees.save(dtree, filename)\n\n# load from file\ndtree_from_file = Evision.ML.DTrees.load(filename)\n\n# they should give the same results!\n{test_error, _results} = Evision.ML.DTrees.calcError(dtree, dataset, true)\n{test_error_2, _results} = Evision.ML.DTrees.calcError(dtree_from_file, dataset, true)\ntest_error == test_error_2\n```","ref":"ml-decision_tree_and_random_forest.html#save-the-trained-model-and-load-it-back"},{"type":"extras","title":"Train the Dataset with Random Forest, `Evision.ML.RTrees` - Evision.ML Example - Decision Tree and Random Forest","doc":"<!-- livebook:{\"attrs\":{\"active_var_count\":0,\"calculate_var_importance\":false,\"data_from\":\"traindata\",\"dtrees\":{\"cv_folds\":0,\"data_from\":\"traindata_var\",\"max_categories\":3,\"max_depth\":10,\"min_sample_count\":10,\"to_variable\":\"dtree\",\"traindata_var\":\"dataset\"},\"term_criteria_count\":30,\"term_criteria_eps\":5.0e-5,\"term_criteria_type\":\"max_count+eps\",\"to_variable\":\"rtree\",\"traindata\":{\"data_layout\":\"row\",\"shuffle_dataset\":true,\"split_ratio\":0.8,\"to_variable\":\"dataset\",\"x\":\"features\",\"x_type\":\"f32\",\"y\":\"labels\",\"y_type\":\"s32\"},\"traindata_var\":\"dataset\"},\"kind\":\"Elixir.Evision.SmartCell.ML.RTrees\",\"livebook_object\":\"smart_cell\"} -->\n\n```elixir\nrtree =\n  Evision.ML.RTrees.create()\n  |> Evision.ML.RTrees.setMaxDepth(10)\n  |> Evision.ML.RTrees.setMaxCategories(3)\n  |> Evision.ML.RTrees.setCVFolds(0)\n  |> Evision.ML.RTrees.setMinSampleCount(10)\n  |> Evision.ML.RTrees.setActiveVarCount(0)\n  |> Evision.ML.RTrees.setCalculateVarImportance(false)\n\nrtree =\n  Evision.ML.RTrees.setTermCriteria(\n    rtree,\n    {Evision.Constant.cv_MAX_ITER() + Evision.Constant.cv_EPS(), 30, 5.0e-5}\n  )\n\n(\n  (\n    dataset =\n      Evision.ML.TrainData.create(\n        Evision.Mat.from_nx(Nx.tensor(features, type: :f32, backend: Evision.Backend)),\n        Evision.Constant.cv_ROW_SAMPLE(),\n        Evision.Mat.from_nx(Nx.tensor(labels, type: :s32, backend: Evision.Backend))\n      )\n      |> Evision.ML.TrainData.setTrainTestSplitRatio(0.8, shuffle: true)\n\n    IO.puts(\"#Samples: #{Evision.ML.TrainData.getNSamples(dataset)}\")\n    IO.puts(\"#Training samples: #{Evision.ML.TrainData.getNTrainSamples(dataset)}\")\n    IO.puts(\"#Test samples: #{Evision.ML.TrainData.getNTestSamples(dataset)}\")\n  )\n\n  Evision.ML.RTrees.train(rtree, dataset)\n\n  rtree\n  |> Evision.ML.RTrees.calcError(dataset, false)\n  |> then(&IO.puts(\"Training Error: #{elem(&1, 0)}\"))\n\n  rtree\n  |> Evision.ML.RTrees.calcError(dataset, true)\n  |> then(&IO.puts(\"Test Error: #{elem(&1, 0)}\"))\n)\n```","ref":"ml-decision_tree_and_random_forest.html#train-the-dataset-with-random-forest-evision-ml-rtrees"},{"type":"extras","title":"Calculate Confusion Matrix - Evision.ML Example - Decision Tree and Random Forest","doc":"```elixir\n{_test_error, results} = Evision.ML.RTrees.calcError(rtree, dataset, true)\n\ny_true =\n  Evision.Mat.to_nx(results, Nx.BinaryBackend)\n  |> Nx.reshape({:auto})\n  |> Nx.as_type(:s32)\n\ny_pred =\n  Evision.Mat.to_nx(Evision.ML.TrainData.getTestResponses(dataset), Nx.BinaryBackend)\n  |> Nx.reshape({:auto})\n  |> Nx.as_type(:s32)\n\nScholar.Metrics.confusion_matrix(y_true, y_pred, num_classes: 3)\n```","ref":"ml-decision_tree_and_random_forest.html#calculate-confusion-matrix"},{"type":"extras","title":"Save the Trained Model and Load It Back - Evision.ML Example - Decision Tree and Random Forest","doc":"```elixir\n# save to file\nfilename = Path.join(__DIR__, \"rtree.bin\")\nEvision.ML.RTrees.save(rtree, filename)\n\n# load from file\nrtree_from_file = Evision.ML.RTrees.load(filename)\n\n# they should give the same results!\n{test_error, _results} = Evision.ML.RTrees.calcError(rtree, dataset, true)\n{test_error_2, _results} = Evision.ML.RTrees.calcError(rtree_from_file, dataset, true)\ntest_error == test_error_2\n```","ref":"ml-decision_tree_and_random_forest.html#save-the-trained-model-and-load-it-back"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}